(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   6265842,     202475]*)
(*NotebookOutlinePosition[   6266647,     202503]*)
(*  CellTagsIndexPosition[   6266603,     202499]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Discrete-Time Fourier Transform (DTFT) examples", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " definitions"
}], "Section"],

Cell[CellGroupData[{

Cell["Load needed packages for this notebook", "Subsection"],

Cell[BoxData[{
    \(\(<< Graphics`Colors`;\)\), "\[IndentingNewLine]", 
    \(\(<< Calculus`FourierTransform`;\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Set up defaults", "Subsection"],

Cell[CellGroupData[{

Cell["Turn off annoying warning messages", "Subsubsection"],

Cell[BoxData[{
    \(\(Off[General::spell];\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Set default options for specific functions", "Subsubsection"],

Cell[BoxData[{
    \(\(SetOptions[Plot, Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[ListPlot, Frame \[Rule] True, \ PlotJoined \[Rule] True, \ 
        Axes \[Rule] {True, False}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[Fourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[InverseFourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[FourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\), "\
\[IndentingNewLine]", 
    \(\(SetOptions[FourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\), "\
\[IndentingNewLine]", 
    \(\(SetOptions[InverseFourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualization functions", "Subsection"],

Cell[CellGroupData[{

Cell["Fix time variable for sampled signals", "Subsubsection"],

Cell[BoxData[
    \(\(FixTime[signal_, 
          sampleRate_] := \[IndentingNewLine]Module[{time, 
            data}, \[IndentingNewLine]time = 
            Table[i/sampleRate, {i, 1, 
                Length[signal]}]; \[IndentingNewLine]data\  = \ {time, 
                signal} // Transpose\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate periodic waveform from one period", "Subsubsection"],

Cell["\<\
PeriodicSignal[f, {dmin, dmax}, {t, min, max}] generates a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax].\
\>", "Text"],

Cell[BoxData[
    \(\(PeriodicSignal[
          f_, {dmin_, dmax_}, {t_, min_, 
            max_}] := \[IndentingNewLine]Module[{T, imin, 
            imax}, \[IndentingNewLine]T\  = \ 
            dmax\  - \ dmin; \[IndentingNewLine]imin = 
            Floor[\((min - dmin)\)/T]; \[IndentingNewLine]imax = 
            Ceiling[\((max - dmax)\)/T]; \ \[IndentingNewLine]Sum[
            f[t - i\ T]\ \((UnitStep[t - dmin - i\ T]\  - \ 
                  UnitStep[t - dmax - i\ T])\), {i, imin, 
              imax}]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot periodic waveforms", "Subsubsection"],

Cell[TextData[{
  "PeriodicPlot[f, {dmin, dmax}, {t, min, max}, opts] plots a a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax]. The 'opts' argument \
passed plotting options to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Plot[ ]."
}], "Text"],

Cell[BoxData[
    \(\(PeriodicPlot[f_, {dmin_, dmax_}, {t_, min_, max_}, 
          opts___] := \[IndentingNewLine]Module[{fnc}, \[IndentingNewLine]fnc \
= PeriodicSignal[f, {dmin, dmax}, {t, min, max}]; \[IndentingNewLine]Plot[
            fnc, {t, min, max}, opts]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot discrete-time signal as sequence of amplitude lines", \
"Subsubsection"],

Cell[BoxData[
    \(\(DiscreteListPlot[signal_, color_:  Black, 
          opts___] := \[IndentingNewLine]Module[{data, g1, 
            g2}, \[IndentingNewLine]If[
            Length[signal[\([1]\)]]\  \[Equal] \ 2, \[IndentingNewLine]data = 
              signal, \[IndentingNewLine]data = 
              FixTime[signal, 
                1]\[IndentingNewLine]]; \[IndentingNewLine]g1 = \
\(Line[{{#[\([1]\)], 0}, {#[\([1]\)], #[\([2]\)]}}] &\)\  /@ \ 
              data; \[IndentingNewLine]g2 = \({PointSize[ .015], 
                  Point[#]} &\)\  /@ \ data; \[IndentingNewLine]Show[
            Graphics[{color, g1, g2}], 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot discrete-time signal as sequence of amplitude lines", \
"Subsubsection"],

Cell[BoxData[
    \(\(DiscreteListPlot2[signal_, color_:  Black, 
          opts___] := \[IndentingNewLine]Module[{data, g1, 
            g2}, \[IndentingNewLine]If[
            Length[signal[\([1]\)]]\  \[Equal] \ 2, \[IndentingNewLine]data = 
              signal, \[IndentingNewLine]data = 
              FixTime[signal, 
                1]\[IndentingNewLine]]; \[IndentingNewLine]g1 = \
\(Line[{{#[\([1]\)], 0}, {#[\([1]\)], #[\([2]\)]}}] &\)\  /@ \ 
              data; \[IndentingNewLine]g2 = \({PointSize[ .005], 
                  Point[#]} &\)\  /@ \ data; \[IndentingNewLine]Show[
            Graphics[{color, g1, g2}], 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fourier rearrange", "Subsection"],

Cell[TextData[{
  "FourierRearrange[fft] rearranges the result of an FFT (",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Fourier[ ]), to a easier to visualize the spectrum represented \
by 'fft'. The length of the list 'fft' is assumed to be even; if it is not, \
the last term in 'fft' is dropped. "
}], "Text"],

Cell[BoxData[
    \(\(FourierRearrange[fft_, \ 
          samplingRate_] := \[IndentingNewLine]Module[{fft2, n, 
            n2}, \[IndentingNewLine]If[EvenQ[Length[fft]], \ 
            fft2\  = \ fft, \ 
            fft2\  = \ Drop[fft, \(-1\)]]; \ \[IndentingNewLine]n = 
            Length[fft]; 
          n2 = n/2; \[IndentingNewLine]{Table[\ 
                samplingRate\ i/n, {i, \(-n2\) + 1, n2}], 
              Take[fft2, {n2 + 2, n2*2}]~Join~Take[fft2, {1, n2 + 1}]} // 
            Transpose\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Short-cut functions", "Subsection"],

Cell[CellGroupData[{

Cell["Dirac delta function", "Subsubsection"],

Cell[BoxData[
    \(\(\[Delta][t_] := DiracDelta[t];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Unit step function", "Subsubsection"],

Cell[BoxData[
    \(\(u[t_] := UnitStep[t];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Pulse of width ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(p[t_, w_] := u[t + w/2] - u[t - w/2];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Hack to plot ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](t)\)]]
}], "Subsection"],

Cell[BoxData[
    \(PlotConvert[X_, 
        w_] := \[IndentingNewLine]X\  /. \ {\[Delta][a_] \[Rule] 
            p[a, w]}\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampler (CT to DT converter)", "Subsection"],

Cell[BoxData[
    \(\(sampler[xc_, fs_, 
          range_: {0, 5}] := \[IndentingNewLine]Table[{n, xc[n/fs]}, {n, 
            range[\([1]\)]*fs, range[\([2]\)]*fs}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampled frequency spectrum", "Subsection"],

Cell[BoxData[
    \(\(SampledSpectrum[X_, f_, fs_, n_:  5] := \[IndentingNewLine]Sum[
          X[f - k\ fs], {k, \(-n\), n}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definition of DTFT", "Subsection"],

Cell[BoxData[
    \(\(DTFT[
          xd_, \[Theta]_] := \[IndentingNewLine]Module[{n, xn, n1, 
            n2}, \[IndentingNewLine]{n, xn}\  = \ 
            xd\  // \ Transpose; \[IndentingNewLine]n1\  = \ First[n]; \ 
          n2\  = \ Last[n]; \[IndentingNewLine]Sum[
            xn[\([k - n1 + 1]\)]\ Exp[\(-I\)\ k\ \[Theta]], {k, n1, 
              n2}]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Discrete-time Fourier transform (DTFT) analytic example", "Section"],

Cell[CellGroupData[{

Cell["Discrete-time pulse of width 2M", "Subsection"],

Cell[BoxData[
    \(\(pulse[n_, \ M_] := 
        If[n\  < \ \(-M\)\  || \ n\  > \ M, \ 0, \ 1];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symmetric discrete-time pulse of width 2M", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dtft1\  = \ \[Sum]\+\(n = \(-M\)\)\%M E\^\(\(-I\)\ n\ \
\[Theta]\);\)\), "\[IndentingNewLine]", 
    \(dtft1\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ M\ \[Theta]\)\
\ \((\(-1\) + \[ExponentialE]\^\(2\ \[ImaginaryI]\ M\ \[Theta] + \
\[ImaginaryI]\ \[Theta]\))\)\)\/\(\(-1\) + \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\)\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dtft2\  = \ \(dtft1\  // \ FullSimplify\)\  // \ 
          TrigReduce;\)\), "\[IndentingNewLine]", 
    \(dtft2\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(csc(\[Theta]\/2)\)\ \(sin(
        M\ \[Theta] + \[Theta]\/2)\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot results for some sample M", "Subsection"],

Cell[CellGroupData[{

Cell["M = 0", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = 0;\)\), "\[IndentingNewLine]", 
    \(\(g10\  = \ 
        DiscreteListPlot[Table[{n, \ pulse[n, \ m]}, {n, \(-20\), 20}], Blue, 
          Frame \[Rule] True, \ Axes \[Rule] {True, False}, \ 
          PlotRange \[Rule] {\(- .05\), 2.05}, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g20\  = \ 
        Plot[Evaluate[
            dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-\[Pi]\), \ \[Pi]}, 
          PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g30\  = \ 
        Plot[Evaluate[dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-2\) \[Pi], \ 
            2  \[Pi]}, PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g40\  = \ 
        Plot[Evaluate[dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-4\) \[Pi], \ 
            4  \[Pi]}, PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g10, g20}, {g30, g40}}], \ 
        ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.0147151 0.294302 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-6)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-4)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-2)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(2)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(4)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(6)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.08317 0 m
.08317 .00375 L
s
.12106 0 m
.12106 .00375 L
s
.15895 0 m
.15895 .00375 L
s
.23474 0 m
.23474 .00375 L
s
.27264 0 m
.27264 .00375 L
s
.31053 0 m
.31053 .00375 L
s
.38632 0 m
.38632 .00375 L
s
.42421 0 m
.42421 .00375 L
s
.46211 0 m
.46211 .00375 L
s
.53789 0 m
.53789 .00375 L
s
.57579 0 m
.57579 .00375 L
s
.61368 0 m
.61368 .00375 L
s
.68947 0 m
.68947 .00375 L
s
.72736 0 m
.72736 .00375 L
s
.76526 0 m
.76526 .00375 L
s
.84105 0 m
.84105 .00375 L
s
.87894 0 m
.87894 .00375 L
s
.91683 0 m
.91683 .00375 L
s
.00738 0 m
.00738 .00375 L
s
.99262 0 m
.99262 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.08317 .61428 m
.08317 .61803 L
s
.12106 .61428 m
.12106 .61803 L
s
.15895 .61428 m
.15895 .61803 L
s
.23474 .61428 m
.23474 .61803 L
s
.27264 .61428 m
.27264 .61803 L
s
.31053 .61428 m
.31053 .61803 L
s
.38632 .61428 m
.38632 .61803 L
s
.42421 .61428 m
.42421 .61803 L
s
.46211 .61428 m
.46211 .61803 L
s
.53789 .61428 m
.53789 .61803 L
s
.57579 .61428 m
.57579 .61803 L
s
.61368 .61428 m
.61368 .61803 L
s
.68947 .61428 m
.68947 .61803 L
s
.72736 .61428 m
.72736 .61803 L
s
.76526 .61428 m
.76526 .61803 L
s
.84105 .61428 m
.84105 .61803 L
s
.87894 .61428 m
.87894 .61803 L
s
.91683 .61428 m
.91683 .61803 L
s
.00738 .61428 m
.00738 .61803 L
s
.99262 .61428 m
.99262 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.037894 0.0147151 0.294302 [
[.12106 -0.0125 -9 -9 ]
[.12106 -0.0125 9 0 ]
[.31053 -0.0125 -6 -9 ]
[.31053 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.68947 -0.0125 -3 -9 ]
[.68947 -0.0125 3 0 ]
[.87894 -0.0125 -6 -9 ]
[.87894 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12106 0 m
.12106 .00625 L
s
[(-10)] .12106 -0.0125 0 1 Mshowa
.31053 0 m
.31053 .00625 L
s
[(-5)] .31053 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.68947 0 m
.68947 .00625 L
s
[(5)] .68947 -0.0125 0 1 Mshowa
.87894 0 m
.87894 .00625 L
s
[(10)] .87894 -0.0125 0 1 Mshowa
.125 Mabswid
.15895 0 m
.15895 .00375 L
s
.19685 0 m
.19685 .00375 L
s
.23474 0 m
.23474 .00375 L
s
.27264 0 m
.27264 .00375 L
s
.34842 0 m
.34842 .00375 L
s
.38632 0 m
.38632 .00375 L
s
.42421 0 m
.42421 .00375 L
s
.46211 0 m
.46211 .00375 L
s
.53789 0 m
.53789 .00375 L
s
.57579 0 m
.57579 .00375 L
s
.61368 0 m
.61368 .00375 L
s
.65158 0 m
.65158 .00375 L
s
.72736 0 m
.72736 .00375 L
s
.76526 0 m
.76526 .00375 L
s
.80315 0 m
.80315 .00375 L
s
.84105 0 m
.84105 .00375 L
s
.08317 0 m
.08317 .00375 L
s
.04527 0 m
.04527 .00375 L
s
.00738 0 m
.00738 .00375 L
s
.91683 0 m
.91683 .00375 L
s
.95473 0 m
.95473 .00375 L
s
.99262 0 m
.99262 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.12106 .61178 m
.12106 .61803 L
s
.31053 .61178 m
.31053 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.68947 .61178 m
.68947 .61803 L
s
.87894 .61178 m
.87894 .61803 L
s
.125 Mabswid
.15895 .61428 m
.15895 .61803 L
s
.19685 .61428 m
.19685 .61803 L
s
.23474 .61428 m
.23474 .61803 L
s
.27264 .61428 m
.27264 .61803 L
s
.34842 .61428 m
.34842 .61803 L
s
.38632 .61428 m
.38632 .61803 L
s
.42421 .61428 m
.42421 .61803 L
s
.46211 .61428 m
.46211 .61803 L
s
.53789 .61428 m
.53789 .61803 L
s
.57579 .61428 m
.57579 .61803 L
s
.61368 .61428 m
.61368 .61803 L
s
.65158 .61428 m
.65158 .61803 L
s
.72736 .61428 m
.72736 .61803 L
s
.76526 .61428 m
.76526 .61803 L
s
.80315 .61428 m
.80315 .61803 L
s
.84105 .61428 m
.84105 .61803 L
s
.08317 .61428 m
.08317 .61803 L
s
.04527 .61428 m
.04527 .61803 L
s
.00738 .61428 m
.00738 .61803 L
s
.91683 .61428 m
.91683 .61803 L
s
.95473 .61428 m
.95473 .61803 L
s
.99262 .61428 m
.99262 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.0147151 0.294302 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.04762 .01472 m
.04762 .01472 L
s
.07143 .01472 m
.07143 .01472 L
s
.09524 .01472 m
.09524 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.14286 .01472 m
.14286 .01472 L
s
.16667 .01472 m
.16667 .01472 L
s
.19048 .01472 m
.19048 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.2381 .01472 m
.2381 .01472 L
s
.2619 .01472 m
.2619 .01472 L
s
.28571 .01472 m
.28571 .01472 L
s
.30952 .01472 m
.30952 .01472 L
s
.33333 .01472 m
.33333 .01472 L
s
.35714 .01472 m
.35714 .01472 L
s
.38095 .01472 m
.38095 .01472 L
s
.40476 .01472 m
.40476 .01472 L
s
.42857 .01472 m
.42857 .01472 L
s
.45238 .01472 m
.45238 .01472 L
s
.47619 .01472 m
.47619 .01472 L
s
.5 .01472 m
.5 .30902 L
s
.52381 .01472 m
.52381 .01472 L
s
.54762 .01472 m
.54762 .01472 L
s
.57143 .01472 m
.57143 .01472 L
s
.59524 .01472 m
.59524 .01472 L
s
.61905 .01472 m
.61905 .01472 L
s
.64286 .01472 m
.64286 .01472 L
s
.66667 .01472 m
.66667 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.71429 .01472 m
.71429 .01472 L
s
.7381 .01472 m
.7381 .01472 L
s
.7619 .01472 m
.7619 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.80952 .01472 m
.80952 .01472 L
s
.83333 .01472 m
.83333 .01472 L
s
.85714 .01472 m
.85714 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.90476 .01472 m
.90476 .01472 L
s
.92857 .01472 m
.92857 .01472 L
s
.95238 .01472 m
.95238 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.04762 .01472 Mdot
.07143 .01472 Mdot
.09524 .01472 Mdot
.11905 .01472 Mdot
.14286 .01472 Mdot
.16667 .01472 Mdot
.19048 .01472 Mdot
.21429 .01472 Mdot
.2381 .01472 Mdot
.2619 .01472 Mdot
.28571 .01472 Mdot
.30952 .01472 Mdot
.33333 .01472 Mdot
.35714 .01472 Mdot
.38095 .01472 Mdot
.40476 .01472 Mdot
.42857 .01472 Mdot
.45238 .01472 Mdot
.47619 .01472 Mdot
.5 .30902 Mdot
.52381 .01472 Mdot
.54762 .01472 Mdot
.57143 .01472 Mdot
.59524 .01472 Mdot
.61905 .01472 Mdot
.64286 .01472 Mdot
.66667 .01472 Mdot
.69048 .01472 Mdot
.71429 .01472 Mdot
.7381 .01472 Mdot
.7619 .01472 Mdot
.78571 .01472 Mdot
.80952 .01472 Mdot
.83333 .01472 Mdot
.85714 .01472 Mdot
.88095 .01472 Mdot
.90476 .01472 Mdot
.92857 .01472 Mdot
.95238 .01472 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.0147151 0.294302 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00:oooool3o`0001gooooo0ol0000Kooooo`Go0000
6Oooool2o`0001_ooooo1Ol0000Mooooo`?o00006oooool3o`0004_ooooo0ol00004ooooo`;o0000
8Oooool3o`0002?ooooo0_l0000Tooooo`?o00008Oooool3o`0000Cooooo0_l0000Sooooo`00:_oo
ool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooooooool06oooool01?l0003ooooo
ooooool0000Hooooo`04o`000?ooooooooooo`0001_ooooo00Co0000oooooooooooo00007_ooool0
0ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool00000Boooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0001oooooo00Go0000ooooooooooooooooo`00000Qooooo`04
o`000?ooooooooooo`0002;ooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008_ooool002Cooooo1Ol000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo01;ooooo1Ol000000ooooooo0000o`000003o`0001Gooooo1Ol00003
ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00007?ooool00ol0003ooooooooo
o`0Kooooo`Go00006_ooool01Ol0003ooooooooooooooooo000004?ooooo1Ol00003ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00006Oooool5o`0000Gooooo00?o0000oooooooo
ool07oooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Rooooo`00:_ooool4o`0001_ooooo00Co0000oooo
oooooooo00007oooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0001gooooo00?o
0000ooooooooool06_ooool01?l0003oooooooooool0000Kooooo`Co0000C?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool07oooool01?l0003o
ooooooooool0000Vooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Rooooo`00:_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo0000
01cooooo00Go0000ooooooooooooooooo`00000Hooooo`04o`000?ooooooooooo`0001[ooooo00Go
0000ooooooooooooooooo`00000Looooo`03o`000?oooooo000001_ooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001oooooo1?l0000Rooooo`04
o`000?ooooooooooo`0002;ooooo1?l0000Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00008_ooool002_ooooo00?o0000ooooooooool07Oooool2o`0001cooooo00Go0000oooo
ooooooooooooo`00000Hooooo`04o`000?ooooooooooo`0001[ooooo00Go0000oooooooooooooooo
o`00000Mooooo`;o00007?ooool00ol0003oooooooooo`1;ooooo`;o00001?ooool01?l0003ooooo
ooooool0000Oooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00008_ooool00ol0
003oooooooooo`0Rooooo`;o00001?ooool01?l0003oooooooooool0000Rooooo`00;?ooool2o`00
01kooooo00?o0000ooooooooool06oooool3o`0001[ooooo0_l0000Looooo`?o00007oooool00ol0
003oooooooooo`0Kooooo`;o0000C?ooool00ol0003oooooooooo`03ooooo`;o00008?ooool5o`00
02;ooooo0_l0000Sooooo`Go00008Oooool00ol0003oooooooooo`03ooooo`;o00008oooool00?oo
oooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0027ooooocol0000[oooo
om3o00003Oooool001[ooooo0_l00005ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o
00009Oooool2o`0000Cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000000gooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00004oooo
o`;o0000boooool2o`0002Cooooo00Co0000oooooooooooo00000oooool2o`000<cooooo0_l0000=
ooooo`006Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0<_ooooo00?o0000
ooooooooool08_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo0<cooooo00?o
0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0boooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`006_ooool2o`0000Gooooo
00?o0000ooooooooool0boooool00ol0003oooooooooo`0Sooooo`;o00001?ooool00ol0003ooooo
ooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Q
ooooo`03o`000?oooooooooo0<[ooooo0_l0000[ooooo`;o0000c?ooool2o`0000gooooo000Qoooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`00
0?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooo
oooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooo
oooo00_ooooo000Qooooo`03o`000?oooooooooo0<[ooooo0_l0000[ooooo`;o0000c?ooool2o`00
00gooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo
000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qoooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<[ooooo0_l0000[ooooo`;o
0000c?ooool2o`0000gooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oo
oooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oo
oooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo
0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo
00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<[ooooo
0_l0000[ooooo`;o0000c?ooool2o`0000gooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Q
ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000>ooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo01Oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03
o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0boooool00ol0
003oooooooooo`0Fooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool000gooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<_ooooo00?o
0000ooooooooool05_ooool01?l0003oooooooooool0000;ooooo`05o`000?ooooooooooooooool0
0000c_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo00;ooooo0_l0003;ooooo`;o00006?ooool01?l0003oooooooooool0000;oooo
o`04o`000?ooooooooooooooo`;o0000c?ooool2o`0000gooooo000=ooooo`04o`000?oooooooooo
o`0000Oooooo1?l00005ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool05_ooool0
1?l0003oooooooooool00007ooooo`Co00001?ooool00ol0003oooooooooo`3<ooooo`03o`000?oo
oooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool0
2oooool000kooooo0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`3;ooooo`03o`000?oo
oooooooo01Oooooo0_l00008ooooo`Go00000oooool00ol0003oooooooooo`3<ooooo`03o`000?oo
oooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo
0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo
00_ooooo000Qooooo`03o`000?oooooooooo0<[ooooo0_l0000[ooooo`;o0000c?ooool2o`0000go
oooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Q
ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03
o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03
o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<[ooooo0_l0000[ooooo`;o0000
c?ooool2o`0000gooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooo
oooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooo
oooo00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<_o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_o
oooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<[ooooo0_l0
000[ooooo`;o0000c?ooool2o`0000gooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qoooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`00
0?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Qooooo`03o`000?oooooo
oooo0<[ooooo0_l0000[ooooo`;o0000c?ooool2o`0000gooooo000Qooooo`03o`000?oooooooooo
0<_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo
00_ooooo000Qooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Iooooo`?o00001Oooool00ol0003ooooo
ooooo`3;ooooo`03o`000?oooooooooo02;ooooo0ol00004ooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool02oooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`04oooo
o`;o00000oooooo5ool000?ooooo0_l0000Uooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
olKoo`000oooool2o`0000gooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0;ooooo`006Oooool2o`0000Kooooo00?o0000ooooooooool0
boooool00ol0003oooooooooo`0Rooooo`;o00001Oooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0booo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0
003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3:ooooo`;o0000:oooool2o`000<co
oooo0_l0000=ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0;ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;oooo
o`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3:ooooo`;o0000
:oooool2o`000<cooooo0_l0000=ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool0
0ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003o
ooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003ooooooooo
o`3:ooooo`;o0000:oooool2o`000<cooooo0_l0000=ooooo`008Oooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;
ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`00
8Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool0
0ol0003oooooooooo`3:ooooo`;o0000:oooool2o`000<cooooo0_l0000=ooooo`008Oooool00ol0
003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003ooooo
ooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0;ooooo`003Oooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o
0000ooooooooool0boooool00ol0003oooooooooo`0Fooooo`?o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00001?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000>
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo0<_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo
000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool2o`000<_ooooo0_l0
000Iooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0_l0003<ooooo`;o0000
3Oooool000kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0<_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0;ooooo`05o`000?oo
ooooooooooooool00000c_ooool00ol0003oooooooooo`0;ooooo`003_ooool00ol0003ooooooooo
o`07ooooo`Co00001Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool01oooool4o`0000Cooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0;ooooo`003Oooool2o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo01Kooooo0_l00009ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`003_ooool00ol0003oooooooooo`07oooo
o`Go00001?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool01oooool5o`0000?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;oooo
o`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3:ooooo`;o0000
:oooool2o`000<cooooo0_l0000=ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool0
0ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003o
ooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0;ooooo`008Oooool00ol0003oooooooooo`3:ooooo`;o0000:oooool2o`000<cooooo0_l0000=
ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`00
8Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool0
0ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3:ooooo`;o0000:oooool2o`00
0<cooooo0_l0000=ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003ooooo
ooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0;ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;
ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Oooool00ol0003oooooooooo`3:ooooo`;o
0000:oooool2o`000<cooooo0_l0000=ooooo`008Oooool00ol0003oooooooooo`3;ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008Ooo
ool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0;ooooo`006?ooool5o`0000Cooooo00?o0000ooooooooool0boooool0
0ol0003oooooooooo`0Qooooo`Go00000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooo
oooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0boooool0
0ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0<_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0<cooooo00?o0000ooooooooool02oooool001_ooooo00?o0000ooooooooool00oooool2o`00
0<_ooooo0_l0000Vooooo`03o`000?oooooooooo00;ooooo0_l0003<ooooo`;o00003Oooool001So
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Qooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0;ooooo`006?ooool01Ol0003ooooooooooooooooo000000Cooooo0_l00007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo0_l0000Sooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000003Ooo
ool001Wooooo0ol00005oooooloo00009?ooool3o`0000Coooood?l0000=ooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooolWoooo
o`?o00006oooool5o`0001_ooooo0ol0000Kooooo`;o00007?ooool3o`0001_ooooo1Ol0000Koooo
o`?o00005oooool002;ooooo1Ol00003ooooo`;o0000:?ooool3o`0000Cooooo0_l0000Yooooo`;o
0000:oooool3o`0000Cooooo0_l0000Xooooo`Go00000oooool2o`0003Oooooo00Go0000oooooooo
ooooooooo`00000Kooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool06Oooool0
1?l0003oooooooooool0000Looooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo0000
6_ooool01Ol0003ooooooooooooooooo000001Kooooo000Sooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002Oooooo00Co0000oooooooooooo0000:oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0002Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000`oooo
o`Go00001Oooool00ol0003oooooooooo`0Booooo`Go00000oooool00ol0003oooooooooo`0Doooo
o`Go00000oooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0001cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Cooooo000Loooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00023ooooo1Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0003Sooooo0_l0000Nooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool0000Looooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool06oooool2o`0001Oooooo000Uooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00009oooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000007?ooool0
0ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool06_oo
ool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool05?ooool002;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002Sooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`0002_ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool0000fooooo`05o`000?ooooooooooooooool000006_ooool01Ol0
003ooooooooooooooooo000001_ooooo0_l0000Kooooo`04o`000?ooooooooooo`0001_ooooo0_l0
000Looooo`05o`000?ooooooooooooooool000006_ooool01Ol0003ooooooooooooooooo000001Ko
oooo000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Woooo
o`;o00001?ooool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`0002[ooooo0_l0
0004ooooo`04o`000?ooooooooooo`0002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0003Oooooo0ol0000Looooo`?o00007Oooool00ol0003oooooooooo`0Joooo
o`;o00007Oooool00ol0003oooooooooo`0Kooooo`?o00007?ooool3o`0001Oooooo000Sooooo`?o
00001?ooool2o`0002Wooooo00?o0000ooooooooool00oooool2o`0002Wooooo0_l0000/ooooo`03
o`000?oooooooooo00?ooooo0_l0000Yooooo`?o00001?ooool2o`000?oooooo2oooool00?oooooo
nOooool00?oooooonOooool00?oooooonOooool0023ooooocol0000Vooooo`;o00001?ooooo@o`00
00gooooo000Jooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000002Gooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00003Oooool001Wooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooooooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o00Coooooo`00ool00?oo003o0_ooool3o`00
o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00
o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`Kooooo0ol00?l2ooooo`?o003o0_ooool3o`00
o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00
o`04ooooool00?oo003oo`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2
ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2
ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000?ooooo1?l0
0003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l0
0003o`00o`;o00000ol00?l2o`0000?o003o00Co0000o`00ool00?oo003o0_l00003o`00o`;o0000
0ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o0000
0ol00?l2o`0000?o003o0_l00003o`00o`;o000000Co003oo`000?l0003o00000ol00?l2o`0000?o
003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o
003o0_l00003o`00o`04o`000?l00?oo003oo`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00
o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00
o`;o00000ol00?l3o`0002Gooooo00Co0000oooooooooooo00000oooool2o`000<cooooo0_l0000=
ooooo`006Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`?o003o0_oo
ool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_oo
ool3o`00o`;ooooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool01?l00?ooooooooooooooool3o`00o`;ooooo0ol00?l2ooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o
003o00Coooooo`00ool00?oo003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00
o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00
o`;ooooo00?o0000ooooooooool08oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo0<cooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool08oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02ooo
ool001Wooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1Tooooo`03o`00oooo
oooooooo06Cooooo00?o0000ooooooooool09?ooool2o`0000Cooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0;ooooo`006_ooool2o`0000Cooooo00?o0000ooooooooool0I?ooool0
0ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool0
0ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo
06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo
00_ooooo000Pooooo`;o0000IOooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[o
oooo0_l0003<ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0I?ooool00ol00?oooooo
ooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000P
ooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000oooo
ooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03
o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03
o`000?oooooooooo00_ooooo000Pooooo`;o0000IOooool00ol00?ooooooooooo`1Tooooo`03o`00
0?oooooooooo02[ooooo0_l0003<ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0I?oo
ool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooo
oooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooo
oooo00_ooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool0I?ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023o
oooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003ooooo
ooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000IOooool00ol00?oooooooooo
o`1Tooooo`03o`000?oooooooooo02[ooooo0_l0003<ooooo`;o00003Oooool0023ooooo00?o0000
ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Toooo
o`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o003ooooooooo
ool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000oooooooo
ool02oooool0023ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?oo
ool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000IOooool0
0ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo0_l0003<ooooo`;o00003Oooool0
023ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003o
ooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo06Cooooo
00?o003oooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool02oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0
0004ooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool0I?ooool00ol0003ooooooooo
o`0Hooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool0
I?ooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool000go
oooo00Co0000oooooooooooo00002oooool01?l0003oooooooooooooool3o`0006Cooooo00?o003o
ooooooooool0Hoooool2o`0001Wooooo00Co0000oooooooooooo00002oooool01?l0003ooooooooo
ooooool2o`000<cooooo0_l0000=ooooo`003Oooool01?l0003oooooooooool0000;ooooo`05o`00
0?ooooooooooooooool00000I_ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo01Oo
oooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooooooooooo00000<kooooo00?o0000
ooooooooool02oooool000gooooo00Co0000oooooooooooo00001oooool4o`0000Cooooo00?o0000
ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo01Oooooo00Co0000
oooooooooooo00001oooool4o`0000Cooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo01Oooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool02oooool000kooooo0_l00008ooooo`Go00000oooool00ol0003ooooooooo
o`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool06?ooool2o`0000Sooooo1Ol0
0003ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000
ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Toooo
o`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool2o`000<cooooo0_l0000=oooo
o`008?ooool2o`0006Gooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0
I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`00oooo
oooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oo
oooooooo00_ooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool0I?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0
023ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003o
ooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000IOooool00ol00?oooooo
ooooo`1Tooooo`03o`000?oooooooooo02[ooooo0_l0003<ooooo`;o00003Oooool0023ooooo00?o
0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1T
ooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3<
ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o003ooooo
ooooool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000oooo
ooooool02oooool0023ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`00
8?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000IOoo
ool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo0_l0003<ooooo`;o00003Ooo
ool0023ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0
003oooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo06Co
oooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<co
oooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0I?ooool00ol00?oooooo
ooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000P
ooooo`;o0000IOooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo0_l0003<
ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Toooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;oooo
o`008?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Iooooo`?o0000
1?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0
8oooool3o`0000Cooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`006_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool0I?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo06?ooooo0ol00?mUooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo
00?ooooo0ol0001Sooooo`?o003oI?ooool2o`0002Kooooo00?o0000ooooooooool00oooool2o`00
00?oooooa_oo0003ooooo`;o00003Oooool001[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Sooooo`?o003oIOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`006Oooool2o`0000Gooooo
00?o0000ooooooooool0boooool00ol0003oooooooooo`0Sooooo`;o00001Oooool00ol0003ooooo
ooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0boooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;
ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool2o`000<cooooo00?o0000oooooooo
ool0:_ooool2o`000<cooooo0_l0000=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?oo
ool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0
003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool2o`000<cooooo
00?o0000ooooooooool0:_ooool2o`000<cooooo0_l0000=ooooo`008?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;oooo
o`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?oo
ool2o`000<cooooo00?o0000ooooooooool0:_ooool2o`000<cooooo0_l0000=ooooo`008?ooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool0
0ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003o
ooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0;ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool0:_ooool2o`000<cooooo0_l0000=
ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`00
8?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0;ooooo`003Oooool3o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Cooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Gooooo`?o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`3<ooooo`03o`000?oo
oooooooo00_ooooo000>ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo00_ooooo000>ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo
0ol0003:ooooo`;o00006_ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooooooo`;o
0000c?ooool2o`0000gooooo000>ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooo
ooooo`00003=ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool01Ol0003o
oooooooooooooooo00000<kooooo00?o0000ooooooooool02oooool000kooooo00?o0000oooooooo
ool01oooool4o`0000Cooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Oooooo1?l00004ooooo`03o`000?oooooooooo0<cooooo00?o0000oooooooo
ool02oooool000gooooo0_l00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
boooool00ol0003oooooooooo`0Gooooo`;o00002Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0<cooooo00?o0000ooooooooool02oooool000kooooo00?o0000ooooooooool01ooo
ool5o`0000?ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Oooooo1Ol00003ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02ooo
ool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo0<cooooo00?o0000ooooooooool02oooool0023ooooo0_l0003<ooooo`03o`000?oooooooooo
02[ooooo0_l0003<ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo
00?o0000ooooooooool0boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0boooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000
ooooooooool02oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo0_l0003<ooooo`03
o`000?oooooooooo02[ooooo0_l0003<ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0
boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool0
2oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0boooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0
023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0boooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo
0_l0003<ooooo`03o`000?oooooooooo02[ooooo0_l0003<ooooo`;o00003Oooool0023ooooo00?o
0000ooooooooool0boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o
0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000oooo
ooooool0boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000oooo
ooooool02oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0
boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool0
2oooool0023ooooo0_l0003<ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo02[ooooo0_l0003<ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0boooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023o
oooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<co
oooo00?o0000ooooooooool02oooool001Sooooo1Ol00003ooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool08_ooool5o`0000?ooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0;ooooo`006Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool08oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo0<co
oooo00?o0000ooooooooool02oooool001[ooooo00?o0000ooooooooool00oooool3o`000<[ooooo
0_l0000Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0;ooooo`006oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`;o0000c?ooool2o`0000gooooo000H
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo02oooooo00Go0000ooooooooooooooooo`00000Tooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool001Sooooo00Go0000ooooooooooooooooo`000003oooooloo00009?ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`0000gooooo000Iooooo`?o0000n?ooool3o`0000Coooood?l0000=
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-8.71096, \
-0.362782, 0.0638556, 0.016444}, {{262.875, 490.688}, {303, 162.25}} -> \
{-49.4256, -0.362782, 0.127711, 0.016444}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-27.7031, -2.91994, 0.203806, 0.0164882}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-12.3564, -2.90954, 0.0319279, 0.016444}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["M = 1", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = 1;\)\), "\[IndentingNewLine]", 
    \(\(g1a\  = \ 
        DiscreteListPlot[Table[{n, \ pulse[n, \ m]}, {n, \(-20\), 20}], Blue, 
          Frame \[Rule] True, \ Axes \[Rule] {True, False}, \ 
          PlotRange \[Rule] {\(- .05\), 2.05}, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g2a\  = \ 
        Plot[Evaluate[
            dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-\[Pi]\), \ \[Pi]}, 
          PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g3a\  = \ 
        Plot[Evaluate[dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-2\) \[Pi], \ 
            2  \[Pi]}, PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g4a\  = \ 
        Plot[Evaluate[dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-4\) \[Pi], \ 
            4  \[Pi]}, PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1a, g2a}, {g3a, g4a}}], \ 
        ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.161866 0.147151 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -12 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-6)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-4)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-2)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(2)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(4)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(6)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.08317 0 m
.08317 .00375 L
s
.12106 0 m
.12106 .00375 L
s
.15895 0 m
.15895 .00375 L
s
.23474 0 m
.23474 .00375 L
s
.27264 0 m
.27264 .00375 L
s
.31053 0 m
.31053 .00375 L
s
.38632 0 m
.38632 .00375 L
s
.42421 0 m
.42421 .00375 L
s
.46211 0 m
.46211 .00375 L
s
.53789 0 m
.53789 .00375 L
s
.57579 0 m
.57579 .00375 L
s
.61368 0 m
.61368 .00375 L
s
.68947 0 m
.68947 .00375 L
s
.72736 0 m
.72736 .00375 L
s
.76526 0 m
.76526 .00375 L
s
.84105 0 m
.84105 .00375 L
s
.87894 0 m
.87894 .00375 L
s
.91683 0 m
.91683 .00375 L
s
.00738 0 m
.00738 .00375 L
s
.99262 0 m
.99262 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(-1)] -0.0125 .01471 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.08317 .61428 m
.08317 .61803 L
s
.12106 .61428 m
.12106 .61803 L
s
.15895 .61428 m
.15895 .61803 L
s
.23474 .61428 m
.23474 .61803 L
s
.27264 .61428 m
.27264 .61803 L
s
.31053 .61428 m
.31053 .61803 L
s
.38632 .61428 m
.38632 .61803 L
s
.42421 .61428 m
.42421 .61803 L
s
.46211 .61428 m
.46211 .61803 L
s
.53789 .61428 m
.53789 .61803 L
s
.57579 .61428 m
.57579 .61803 L
s
.61368 .61428 m
.61368 .61803 L
s
.68947 .61428 m
.68947 .61803 L
s
.72736 .61428 m
.72736 .61803 L
s
.76526 .61428 m
.76526 .61803 L
s
.84105 .61428 m
.84105 .61803 L
s
.87894 .61428 m
.87894 .61803 L
s
.91683 .61428 m
.91683 .61803 L
s
.00738 .61428 m
.00738 .61803 L
s
.99262 .61428 m
.99262 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02499 .60328 L
.02605 .60319 L
.02729 .60301 L
.02846 .60277 L
.03053 .60216 L
.03279 .60126 L
.03527 .59996 L
.0379 .59825 L
.04262 .5943 L
.05205 .58312 L
.06244 .5659 L
.0842 .51473 L
.10458 .45142 L
.14335 .3071 L
.18458 .15507 L
.20517 .0934 L
.21519 .06887 L
.22428 .05023 L
.2338 .03472 L
.24277 .02404 L
.2477 .01987 L
.25224 .01711 L
.25461 .01608 L
.25597 .01562 L
.25722 .01528 L
.25853 .01501 L
.25925 .0149 L
.25994 .01481 L
.26115 .01473 L
.26184 .01472 L
.26248 .01472 L
.26365 .01479 L
.26489 .01494 L
.26595 .01513 L
.26711 .01541 L
.2697 .01627 L
.2721 .01738 L
.27647 .02014 L
.28114 .02415 L
.28669 .03032 L
.29194 .03752 L
.30174 .05445 L
.32176 .10182 L
.34021 .15832 L
.37961 .30382 L
.4175 .4455 L
.43858 .51185 L
.45784 .55895 L
.46737 .57646 L
Mistroke
.4724 .58402 L
.47776 .59073 L
.48291 .59586 L
.48757 .59937 L
.48982 .60067 L
.49225 .60178 L
.49337 .60219 L
.49455 .60256 L
.49565 .60283 L
.49666 .60303 L
.49789 .6032 L
.49854 .60326 L
.49922 .6033 L
.50037 .60332 L
.50164 .60325 L
.50276 .60312 L
.50398 .60291 L
.50512 .60265 L
.50617 .60234 L
.50854 .60145 L
.51113 .60015 L
.51634 .5965 L
.52094 .59215 L
.52585 .58636 L
.53469 .57303 L
.54496 .55304 L
.55607 .52637 L
.57624 .46655 L
.61721 .31615 L
.65666 .16887 L
.6765 .10667 L
.6946 .06186 L
.70461 .04298 L
.71409 .02936 L
.71929 .02373 L
.7241 .01972 L
.72661 .01809 L
.72938 .01666 L
.73077 .01609 L
.73228 .01558 L
.73369 .01521 L
.735 .01496 L
.73627 .0148 L
.73747 .01472 L
.73855 .01472 L
.73973 .01478 L
.741 .01493 L
.74165 .01504 L
.74236 .01518 L
.74362 .0155 L
Mistroke
.74478 .01586 L
.74705 .01677 L
.74949 .01803 L
.7539 .02109 L
.75897 .02581 L
.76451 .03241 L
.77459 .04818 L
.79428 .09194 L
.81525 .15451 L
.85686 .3079 L
.89694 .45656 L
.91533 .51343 L
.92577 .54056 L
.93551 .56194 L
.94506 .57884 L
.94997 .58588 L
.9553 .59221 L
.95822 .59508 L
.96091 .59736 L
.96344 .59916 L
.96623 .60078 L
.96872 .60189 L
.97106 .60264 L
.97235 .60294 L
.97353 .60314 L
.97483 .60327 L
.97548 .60331 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.037894 0.161864 0.147152 [
[.12106 -0.0125 -9 -9 ]
[.12106 -0.0125 9 0 ]
[.31053 -0.0125 -6 -9 ]
[.31053 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.68947 -0.0125 -3 -9 ]
[.68947 -0.0125 3 0 ]
[.87894 -0.0125 -6 -9 ]
[.87894 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -12 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .16186 -6 -4.5 ]
[-0.0125 .16186 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12106 0 m
.12106 .00625 L
s
[(-10)] .12106 -0.0125 0 1 Mshowa
.31053 0 m
.31053 .00625 L
s
[(-5)] .31053 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.68947 0 m
.68947 .00625 L
s
[(5)] .68947 -0.0125 0 1 Mshowa
.87894 0 m
.87894 .00625 L
s
[(10)] .87894 -0.0125 0 1 Mshowa
.125 Mabswid
.15895 0 m
.15895 .00375 L
s
.19685 0 m
.19685 .00375 L
s
.23474 0 m
.23474 .00375 L
s
.27264 0 m
.27264 .00375 L
s
.34842 0 m
.34842 .00375 L
s
.38632 0 m
.38632 .00375 L
s
.42421 0 m
.42421 .00375 L
s
.46211 0 m
.46211 .00375 L
s
.53789 0 m
.53789 .00375 L
s
.57579 0 m
.57579 .00375 L
s
.61368 0 m
.61368 .00375 L
s
.65158 0 m
.65158 .00375 L
s
.72736 0 m
.72736 .00375 L
s
.76526 0 m
.76526 .00375 L
s
.80315 0 m
.80315 .00375 L
s
.84105 0 m
.84105 .00375 L
s
.08317 0 m
.08317 .00375 L
s
.04527 0 m
.04527 .00375 L
s
.00738 0 m
.00738 .00375 L
s
.91683 0 m
.91683 .00375 L
s
.95473 0 m
.95473 .00375 L
s
.99262 0 m
.99262 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(-1)] -0.0125 .01471 1 0 Mshowa
0 .16186 m
.00625 .16186 L
s
[(0)] -0.0125 .16186 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04414 m
.00375 .04414 L
s
0 .07357 m
.00375 .07357 L
s
0 .103 m
.00375 .103 L
s
0 .13243 m
.00375 .13243 L
s
0 .19129 m
.00375 .19129 L
s
0 .22072 m
.00375 .22072 L
s
0 .25015 m
.00375 .25015 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.12106 .61178 m
.12106 .61803 L
s
.31053 .61178 m
.31053 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.68947 .61178 m
.68947 .61803 L
s
.87894 .61178 m
.87894 .61803 L
s
.125 Mabswid
.15895 .61428 m
.15895 .61803 L
s
.19685 .61428 m
.19685 .61803 L
s
.23474 .61428 m
.23474 .61803 L
s
.27264 .61428 m
.27264 .61803 L
s
.34842 .61428 m
.34842 .61803 L
s
.38632 .61428 m
.38632 .61803 L
s
.42421 .61428 m
.42421 .61803 L
s
.46211 .61428 m
.46211 .61803 L
s
.53789 .61428 m
.53789 .61803 L
s
.57579 .61428 m
.57579 .61803 L
s
.61368 .61428 m
.61368 .61803 L
s
.65158 .61428 m
.65158 .61803 L
s
.72736 .61428 m
.72736 .61803 L
s
.76526 .61428 m
.76526 .61803 L
s
.80315 .61428 m
.80315 .61803 L
s
.84105 .61428 m
.84105 .61803 L
s
.08317 .61428 m
.08317 .61803 L
s
.04527 .61428 m
.04527 .61803 L
s
.00738 .61428 m
.00738 .61803 L
s
.91683 .61428 m
.91683 .61803 L
s
.95473 .61428 m
.95473 .61803 L
s
.99262 .61428 m
.99262 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .16186 m
1 .16186 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04414 m
1 .04414 L
s
.99625 .07357 m
1 .07357 L
s
.99625 .103 m
1 .103 L
s
.99625 .13243 m
1 .13243 L
s
.99625 .19129 m
1 .19129 L
s
.99625 .22072 m
1 .22072 L
s
.99625 .25015 m
1 .25015 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02499 .60318 L
.02605 .6028 L
.02729 .60208 L
.02846 .60111 L
.03053 .5987 L
.03279 .5951 L
.03527 .58997 L
.0379 .58321 L
.04262 .56781 L
.05205 .52529 L
.06244 .46315 L
.08274 .31359 L
.09394 .22772 L
.10458 .15252 L
.11464 .09261 L
.11995 .06685 L
.12562 .04464 L
.12831 .03612 L
.13085 .02935 L
.13333 .02397 L
.1356 .02009 L
.13777 .01737 L
.13886 .01635 L
.14005 .01552 L
.14125 .01498 L
.14254 .01472 L
.14376 .0148 L
.14487 .01513 L
.14605 .01575 L
.14715 .0166 L
.14837 .01782 L
.14967 .01946 L
.15234 .02388 L
.15478 .02916 L
.15925 .04182 L
.16395 .05915 L
.17387 .10788 L
.18471 .17671 L
.20596 .3368 L
.22527 .47619 L
.23491 .53175 L
.23999 .55544 L
.24536 .5757 L
.25006 .58905 L
.25273 .59473 L
.25401 .59695 L
.25522 .59876 L
.25632 .60013 L
.25751 .60135 L
Mistroke
.2586 .6022 L
.25961 .60278 L
.26081 .6032 L
.26189 .60332 L
.26314 .60316 L
.26432 .60272 L
.26549 .60201 L
.26674 .60093 L
.26899 .59819 L
.27167 .5936 L
.27411 .58819 L
.27942 .57245 L
.28444 .55281 L
.2933 .50798 L
.30292 .4471 L
.32234 .3019 L
.33266 .22309 L
.34376 .14547 L
.35435 .08431 L
.35898 .0628 L
.36405 .04351 L
.36637 .03622 L
.36886 .02958 L
.371 .0248 L
.37332 .02066 L
.37469 .01872 L
.37595 .01727 L
.37716 .01618 L
.37844 .01536 L
.37958 .01491 L
.38065 .01472 L
.38182 .01479 L
.38307 .01517 L
.38429 .01585 L
.38498 .01637 L
.38563 .01695 L
.38835 .0203 L
.3907 .02439 L
.39323 .03003 L
.399 .04746 L
.40429 .06878 L
.41408 .12021 L
.4244 .1879 L
.44435 .33901 L
.46248 .47046 L
.47187 .52591 L
.47682 .54997 L
.48207 .57097 L
.48473 .57975 L
.48767 .58787 L
Mistroke
.49037 .59386 L
.49283 .59807 L
.49405 .59969 L
.49537 .60112 L
.49609 .60175 L
.49676 .60225 L
.49745 .60265 L
.49809 .60294 L
.49934 .60327 L
.50047 .6033 L
.50169 .60303 L
.50301 .60239 L
.50425 .60147 L
.50538 .60035 L
.50793 .5969 L
.51029 .59254 L
.51252 .58739 L
.51752 .57241 L
.52296 .55092 L
.53391 .49315 L
.54403 .42601 L
.5643 .27202 L
.57422 .19769 L
.58332 .13613 L
.592 .08654 L
.5966 .06488 L
.6015 .04571 L
.60409 .03734 L
.60644 .03084 L
.60884 .02533 L
.61104 .02125 L
.61352 .01783 L
.61483 .01653 L
.6155 .016 L
.61621 .01554 L
.61741 .01499 L
.61853 .01474 L
.61922 .01472 L
.61987 .01478 L
.62109 .01514 L
.62234 .01582 L
.62304 .01635 L
.62369 .01692 L
.62614 .01985 L
.62836 .02356 L
.63071 .02854 L
.6356 .04233 L
.64095 .06251 L
.65048 .11026 L
.65935 .16608 L
Mistroke
.69833 .45564 L
.70854 .51827 L
.71392 .54545 L
.71963 .56906 L
.72461 .58488 L
.72744 .59177 L
.7301 .59679 L
.73135 .59866 L
.73253 .60015 L
.73361 .60126 L
.73476 .60218 L
.736 .60287 L
.73715 .60323 L
.73786 .60331 L
.73852 .6033 L
.73977 .60303 L
.74093 .6025 L
.74217 .60162 L
.74335 .6005 L
.74442 .59923 L
.74704 .59516 L
.74952 .59003 L
.75446 .57629 L
.75984 .5562 L
.76943 .50832 L
.77831 .4526 L
.79855 .30179 L
.81756 .1612 L
.8264 .10635 L
.83572 .06051 L
.84059 .04233 L
.84317 .03448 L
.84593 .0275 L
.84847 .02238 L
.85078 .01885 L
.8519 .01753 L
.8531 .01638 L
.85425 .01557 L
.8553 .01506 L
.85655 .01475 L
.85774 .01475 L
.8588 .01499 L
.85997 .01553 L
.86123 .01642 L
.86257 .01773 L
.86499 .02099 L
.86744 .0255 L
.86974 .03083 L
.87405 .04353 L
.87922 .06326 L
Mistroke
.88397 .08544 L
.89469 .14773 L
.91514 .29717 L
.93422 .44049 L
.94365 .50129 L
.95257 .54798 L
.9575 .56824 L
.9601 .57718 L
.96286 .58529 L
.96517 .59097 L
.96773 .59601 L
.96885 .59781 L
.97005 .59946 L
.97109 .60066 L
.97223 .60171 L
.97323 .60242 L
.97416 .6029 L
.97514 .60321 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.0147151 0.294302 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.04762 .01472 m
.04762 .01472 L
s
.07143 .01472 m
.07143 .01472 L
s
.09524 .01472 m
.09524 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.14286 .01472 m
.14286 .01472 L
s
.16667 .01472 m
.16667 .01472 L
s
.19048 .01472 m
.19048 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.2381 .01472 m
.2381 .01472 L
s
.2619 .01472 m
.2619 .01472 L
s
.28571 .01472 m
.28571 .01472 L
s
.30952 .01472 m
.30952 .01472 L
s
.33333 .01472 m
.33333 .01472 L
s
.35714 .01472 m
.35714 .01472 L
s
.38095 .01472 m
.38095 .01472 L
s
.40476 .01472 m
.40476 .01472 L
s
.42857 .01472 m
.42857 .01472 L
s
.45238 .01472 m
.45238 .01472 L
s
.47619 .01472 m
.47619 .30902 L
s
.5 .01472 m
.5 .30902 L
s
.52381 .01472 m
.52381 .30902 L
s
.54762 .01472 m
.54762 .01472 L
s
.57143 .01472 m
.57143 .01472 L
s
.59524 .01472 m
.59524 .01472 L
s
.61905 .01472 m
.61905 .01472 L
s
.64286 .01472 m
.64286 .01472 L
s
.66667 .01472 m
.66667 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.71429 .01472 m
.71429 .01472 L
s
.7381 .01472 m
.7381 .01472 L
s
.7619 .01472 m
.7619 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.80952 .01472 m
.80952 .01472 L
s
.83333 .01472 m
.83333 .01472 L
s
.85714 .01472 m
.85714 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.90476 .01472 m
.90476 .01472 L
s
.92857 .01472 m
.92857 .01472 L
s
.95238 .01472 m
.95238 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.04762 .01472 Mdot
.07143 .01472 Mdot
.09524 .01472 Mdot
.11905 .01472 Mdot
.14286 .01472 Mdot
.16667 .01472 Mdot
.19048 .01472 Mdot
.21429 .01472 Mdot
.2381 .01472 Mdot
.2619 .01472 Mdot
.28571 .01472 Mdot
.30952 .01472 Mdot
.33333 .01472 Mdot
.35714 .01472 Mdot
.38095 .01472 Mdot
.40476 .01472 Mdot
.42857 .01472 Mdot
.45238 .01472 Mdot
.47619 .30902 Mdot
.5 .30902 Mdot
.52381 .30902 Mdot
.54762 .01472 Mdot
.57143 .01472 Mdot
.59524 .01472 Mdot
.61905 .01472 Mdot
.64286 .01472 Mdot
.66667 .01472 Mdot
.69048 .01472 Mdot
.71429 .01472 Mdot
.7381 .01472 Mdot
.7619 .01472 Mdot
.78571 .01472 Mdot
.80952 .01472 Mdot
.83333 .01472 Mdot
.85714 .01472 Mdot
.88095 .01472 Mdot
.90476 .01472 Mdot
.92857 .01472 Mdot
.95238 .01472 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.161866 0.147151 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01475 L
.02729 .01479 L
.02846 .01485 L
.03053 .015 L
.03279 .01523 L
.03527 .01556 L
.0379 .01599 L
.04262 .01698 L
.04749 .0183 L
.05205 .01981 L
.06244 .02422 L
.07305 .03011 L
.08274 .03668 L
.10458 .05552 L
.14429 .10289 L
.18248 .16177 L
.22313 .23454 L
.26226 .3097 L
.30384 .3894 L
.34391 .46058 L
.38246 .51918 L
.402 .54393 L
.42346 .56659 L
.44388 .58338 L
.45301 .58929 L
.46295 .59457 L
.46838 .59694 L
.4734 .5988 L
.4781 .60026 L
.4833 .60154 L
.48553 .60198 L
.48794 .60239 L
.49002 .60268 L
.4923 .60294 L
.49473 .60314 L
.49605 .60322 L
.49728 .60327 L
.49844 .6033 L
.49949 .60332 L
.50071 .60332 L
.50186 .6033 L
.50301 .60326 L
.50425 .60321 L
.50542 .60313 L
.50648 .60305 L
.5091 .60279 L
.51158 .60246 L
.5165 .60158 L
Mistroke
.52187 .60026 L
.53144 .59701 L
.54032 .59297 L
.56088 .5799 L
.5795 .56376 L
.61962 .51633 L
.65822 .45702 L
.69928 .38356 L
.73882 .30761 L
.77684 .2346 L
.81732 .1621 L
.85628 .1021 L
.87613 .07654 L
.89769 .0533 L
.91843 .03582 L
.92832 .02927 L
.93759 .02421 L
.94643 .02037 L
.95595 .01733 L
.9611 .01617 L
.96369 .01572 L
.96652 .01531 L
.96894 .01505 L
.9703 .01494 L
.97153 .01485 L
.97268 .01479 L
.97393 .01475 L
.97511 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00:?ooool3o`0001gooooo0ol0000Kooooo`Go0000
6Oooool2o`0001_ooooo1Ol0000Mooooo`?o00006oooool3o`0004_ooooo0ol00004ooooo`;o0000
8Oooool3o`0002?ooooo0_l0000Tooooo`?o00008Oooool3o`0000Cooooo0_l0000Vooooo`009ooo
ool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooooooool06oooool01?l0003ooooo
ooooool0000Hooooo`04o`000?ooooooooooo`0001_ooooo00Co0000oooooooooooo00007_ooool0
0ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool00000Boooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0001oooooo00Go0000ooooooooooooooooo`00000Qooooo`04
o`000?ooooooooooo`0002;ooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00009Oooool0027ooooo1Ol000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo01;ooooo1Ol000000ooooooo0000o`000003o`0001Gooooo1Ol00003
ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00007?ooool00ol0003ooooooooo
o`0Kooooo`Go00006_ooool01Ol0003ooooooooooooooooo000004?ooooo1Ol00003ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00006Oooool5o`0000Gooooo00?o0000oooooooo
ool07oooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Uooooo`009oooool4o`0001_ooooo00Co0000oooo
oooooooo00007oooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0001gooooo00?o
0000ooooooooool06_ooool01?l0003oooooooooool0000Kooooo`Co0000C?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool07oooool01?l0003o
ooooooooool0000Vooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Uooooo`009oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo0000
01cooooo00Go0000ooooooooooooooooo`00000Hooooo`04o`000?ooooooooooo`0001[ooooo00Go
0000ooooooooooooooooo`00000Looooo`03o`000?oooooo000001_ooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001oooooo1?l0000Rooooo`04
o`000?ooooooooooo`0002;ooooo1?l0000Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00009Oooool002Sooooo00?o0000ooooooooool07Oooool2o`0001cooooo00Go0000oooo
ooooooooooooo`00000Hooooo`04o`000?ooooooooooo`0001[ooooo00Go0000oooooooooooooooo
o`00000Mooooo`;o00007?ooool00ol0003oooooooooo`1;ooooo`;o00001?ooool01?l0003ooooo
ooooool0000Oooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00008_ooool00ol0
003oooooooooo`0Rooooo`;o00001?ooool01?l0003oooooooooool0000Uooooo`00:Oooool2o`00
01kooooo00?o0000ooooooooool06oooool3o`0001[ooooo0_l0000Looooo`?o00007oooool00ol0
003oooooooooo`0Kooooo`;o0000C?ooool00ol0003oooooooooo`03ooooo`;o00008?ooool5o`00
02;ooooo0_l0000Sooooo`Go00008Oooool00ol0003oooooooooo`03ooooo`;o00009_ooool00?oo
oooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool001kooooocol0000[oooo
om3o00004?ooool001Kooooo0ol00005ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o
00009?ooool3o`0000Cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo0000013ooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
boooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0>ooooo`003oooool5o`0000?ooooo00?o0000ooooooooool01?oo
ool2o`0003;ooooo1?oo001Oooooo`?oo`00<oooool2o`0001gooooo1Ol00003ooooo`03o`000?oo
oooooooo00?ooooo0_l0000Kooooo`;oo`00;oooool3ool002kooooo0ooo000^ooooo`?oo`006ooo
ool2o`00013ooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool2
ool000?ooooo0_oo001Kooooo`;oo`000oooool2ool003;ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo0_oo00000oooooooo`00ooooo`0/
ooooo`;oo`0000?oooooool00?ooool0;?ooool2ool00003oooooooo003oo`0002gooooo00Coo`00
oooooooo003oo`006oooool00ol0003oooooooooo`0>ooooo`005oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02oooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`1G
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0;oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool01Ooo003ooooooooooooo
ooooo`0002cooooo00Goo`00ooooooooooooooooool0000/ooooo`05ool00?oooooooooooooooooo
0000;Oooool01?oo003ooooooooooooo000Kooooo`03o`000?oooooooooo00kooooo000Fooooo`;o
00001_ooool00ol0003oooooooooo`0^ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool0EOooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo02kooooo00?o0000oooooooo
ool08_ooool2o`0000Gooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo02Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Zooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo01Sooooo00?o0000ooooooooool03_ooool001Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0]ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0
EOooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo02gooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
:_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`0Hooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oo
oooooooo02gooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1Cooooo`03ool00?oo
oooooooo00Wooooo00?oo`00ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo01Sooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Xooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo02Oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Gooooo`03o`000?oo
oooooooo00kooooo000Nooooo`03o`000?oooooooooo02cooooo00?oo`00ooooooooool02_ooool0
0ooo003oooooooooo`1Booooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0:oooool2
o`0002_ooooo0_l0000Hooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool05_ooool2
o`00013ooooo000Nooooo`03o`000?oooooooooo02_ooooo00?oo`00ooooooooool03?ooool00ooo
003oooooooooo`1Aooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0:oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0Wooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool09_ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo02_o
oooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`1?ooooo`03ool00?oooooooooo00go
oooo00?oo`00ooooooooool0:oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Oo
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo02Oo
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo00ko
oooo000Nooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool03_ooool00ooo003ooooo
ooooo`1?ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0:_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0Uooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool09Oooool00ooo003ooooo
ooooo`07ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo02[ooooo00?o
o`00ooooooooool03oooool00ooo003oooooooooo`1=ooooo`03ool00?oooooooooo00oooooo00?o
o`00ooooooooool0:_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Kooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo00Oooooo00?o
o`00ooooooooool09?ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo02Gooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo00kooooo000N
ooooo`03o`000?oooooooooo02Wooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`1=
ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0:Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0U
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0F
ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo02Wooooo00?oo`00oooo
ooooool04?ooool00ooo003oooooooooo`1<ooooo`03ool00?oooooooooo017ooooo00?oo`00oooo
ooooool0:?ooool2o`0002_ooooo0_l0000Gooooo`03ool00?oooooooooo00Oooooo00?oo`00oooo
ooooool09?ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo02Cooooo00?oo`00oooo
ooooool01oooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool05Oooool2o`00013ooooo000Nooooo`03o`000?oooooooooo02Sooooo00?oo`00oooooooo
ool04_ooool00ooo003oooooooooo`1;ooooo`03ool00?oooooooooo017ooooo00?oo`00oooooooo
ool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Kooooo00?oo`00oooooooo
ool01oooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool09?ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo02?ooooo00?oo`00oooooooo
ool02?ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`00
0?oooooooooo02Sooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`1:ooooo`03ool0
0?oooooooooo01?ooooo00?oo`00ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo01Gooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Sooooo`03ool0
0?oooooooooo00Sooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`08ooooo`03ool0
0?oooooooooo02?ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Eooooo`03o`00
0?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo02Sooooo00?oo`00ooooooooool04ooo
ool00ooo003oooooooooo`19ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool0:?oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool02?oo
ool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool08ooo
ool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool02?oo
ool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooo
oooo02Oooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`19ooooo`03ool00?oooooo
oooo01Cooooo00?oo`00ooooooooool09oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo01Gooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Sooooo`03ool00?oooooo
oooo00Wooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`08ooooo`03ool00?oooooo
oooo02?ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooo
oooo00kooooo000Nooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool05?ooool00ooo
003oooooooooo`18ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool09oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`0Rooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool08oooool00ooo
003oooooooooo`08ooooo`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool02?ooool00ooo
003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo02Oo
oooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`17ooooo`03ool00?oooooooooo01Go
oooo00?oo`00ooooooooool09_ooool2o`0002_ooooo0_l0000Fooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo02;o
oooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool05?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo02Kooooo
00?oo`00ooooooooool05_ooool00ooo003oooooooooo`16ooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool09_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo
00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00[ooooo
00?oo`00ooooooooool08_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo027ooooo
00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo
000Nooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool05oooool00ooo003ooooooooo
o`15ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool09_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool02_ooool00ooo003ooooooooo
o`0Qooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool08Oooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool02_ooool00ooo003ooooooooo
o`0Dooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo02Kooooo00?oo`00
ooooooooool05oooool00ooo003oooooooooo`15ooooo`03ool00?oooooooooo01Oooooo00?oo`00
ooooooooool09_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Cooooo00?oo`00
ooooooooool02_ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00_ooooo00?oo`00
ooooooooool08Oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo027ooooo00?oo`00
ooooooooool02_ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo000Noooo
o`03o`000?oooooooooo02Gooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`14oooo
o`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool09Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Qoooo
o`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0:oooo
o`03ool00?oooooooooo027ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Doooo
o`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo02Gooooo00?oo`00oooooooo
ool06Oooool00ooo003oooooooooo`13ooooo`03ool00?oooooooooo01Wooooo00?oo`00oooooooo
ool09Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Cooooo00?oo`00oooooooo
ool02_ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00_ooooo00?oo`00oooooooo
ool08?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo023ooooo00?oo`00oooooooo
ool02oooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`00
0?oooooooooo02Gooooo00?oo`00ooooooooool06Oooool00ooo003oooooooooo`13ooooo`03ool0
0?oooooooooo01Wooooo00?oo`00ooooooooool09?ooool2o`0002_ooooo0_l0000Eooooo`03ool0
0?oooooooooo00_ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0;ooooo`03ool0
0?oooooooooo023ooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Pooooo`03ool0
0?oooooooooo00_ooooo00?oo`00ooooooooool04oooool2o`00013ooooo000Nooooo`03o`000?oo
oooooooo02Cooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`12ooooo`03ool00?oo
oooooooo01_ooooo00?oo`00ooooooooool09?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo01Cooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Oooooo`03ool00?oo
oooooooo00cooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0;ooooo`03ool00?oo
oooooooo023ooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Dooooo`03o`000?oo
oooooooo00kooooo000Nooooo`03o`000?oooooooooo02Cooooo00?oo`00ooooooooool06oooool0
0ooo003oooooooooo`11ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool09?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool02oooool0
0ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool07oooool0
0ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool03?ooool0
0ooo003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo
02Cooooo00?oo`00ooooooooool06oooool00ooo003oooooooooo`11ooooo`03ool00?oooooooooo
01_ooooo00?oo`00ooooooooool09?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
01?ooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo
00gooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo
01oooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo
00kooooo000Gooooo`;o00001Oooool00ol0003oooooooooo`0Sooooo`03ool00?oooooooooo01co
oooo00?oo`00ooooooooool0@?ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo02?o
oooo00?o0000ooooooooool08oooool2o`0000Cooooo00?o0000ooooooooool04oooool00ooo003o
ooooooooo`0<ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool03Oooool00ooo003o
ooooooooo`0Oooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool07_ooool00ooo003o
ooooooooo`0=ooooo`03ool00?oooooooooo01?ooooo00?o0000ooooooooool03_ooool001Kooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Sooooo`03ool00?oooooooooo01go
oooo00?oo`00ooooooooool0?oooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo02?o
oooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
01?ooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo
00gooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo
01kooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo
00kooooo000Fooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool08oooool00ooo
003oooooooooo`0Mooooo`03ool00?oooooooooo03oooooo00?oo`00ooooooooool07Oooool00ooo
003oooooooooo`0Sooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`0Cooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool07oooool0
0ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool03Oooool0
0ooo003oooooooooo`0Nooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool04oooool0
0ol0003oooooooooo`0>ooooo`005_ooool01?l0003oooooooooool00004ooooo`;o00009?ooool0
0ooo003oooooooooo`0Mooooo`03ool00?oooooooooo03kooooo00?oo`00ooooooooool07_ooool0
0ooo003oooooooooo`0Rooooo`;o00009?ooool01?l0003oooooooooool00003ooooo`;o00005?oo
ool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool03Ooo
ool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool07_oo
ool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01;ooooo0_l0000@ooooo`005_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool07_oo
ool00ooo003oooooooooo`0nooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool08_oo
ool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
4oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0
3_ooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0
7_ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01?ooooo00?o0000ooooooooool0
3_ooool001Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Rooooo`03ool0
0?oooooooooo01oooooo00?oo`00ooooooooool0?Oooool00ooo003oooooooooo`0Oooooo`03ool0
0?oooooooooo02;ooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo01?ooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Mooooo`03
ool00?oooooooooo00oooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0=ooooo`03
ool00?oooooooooo01kooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Booooo`03
o`000?oooooooooo00kooooo000Gooooo`;o00001Oooool00ol0003oooooooooo`0Rooooo`03ool0
0?oooooooooo01oooooo00?oo`00ooooooooool0?Oooool00ooo003oooooooooo`0Oooooo`03ool0
0?oooooooooo02;ooooo00?o0000ooooooooool08oooool2o`0000Cooooo00?o0000ooooooooool0
4_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0
3oooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0
7_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo01;ooooo00?o0000ooooooooool0
3_ooool001kooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`0Pooooo`03ool00?oo
oooooooo03cooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0Qooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`0>ooooo`03ool00?oo
oooooooo01gooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0Mooooo`03ool00?oo
oooooooo00gooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0?ooooo`03ool00?oo
oooooooo01;ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool08Oooool0
0ooo003oooooooooo`0Pooooo`03ool00?oooooooooo03cooooo00?oo`00ooooooooool08Oooool0
0ooo003oooooooooo`0Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04_ooool0
0ooo003oooooooooo`0>ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool03oooool0
0ooo003oooooooooo`0Looooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool07?ooool0
0ooo003oooooooooo`0?ooooo`03ool00?oooooooooo01;ooooo00?o0000ooooooooool03_ooool0
01kooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo
03_ooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0Pooooo`;o0000:oooool2o`00
01?ooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo
00oooooo00?oo`00ooooooooool07?ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo
01cooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0Aooooo`;o00004?ooool001ko
oooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo03_o
oooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0Qooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo01co
oooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0Looooo`03ool00?oooooooooo00oo
oooo00?oo`00ooooooooool07?ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo01;o
oooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool08?ooool00ooo003ooooo
ooooo`0Rooooo`03ool00?oooooooooo03[ooooo00?oo`00ooooooooool08oooool00ooo003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04_ooool00ooo003ooooo
ooooo`0?ooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool03oooool00ooo003ooooo
ooooo`0Looooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool07?ooool00ooo003ooooo
ooooo`0?ooooo`03ool00?oooooooooo01;ooooo00?o0000ooooooooool03_ooool001kooooo00?o
0000ooooooooool08?ooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo03Wooooo00?o
o`00ooooooooool08oooool00ooo003oooooooooo`0Pooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool04_ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo01_ooooo00?o
o`00ooooooooool04?ooool00ooo003oooooooooo`0Looooo`03ool00?oooooooooo00oooooo00?o
o`00ooooooooool07?ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo017ooooo00?o
0000ooooooooool03_ooool001kooooo00?o0000ooooooooool08?ooool00ooo003oooooooooo`0S
ooooo`03ool00?oooooooooo03Wooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`0P
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`0@
ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0K
ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool07?ooool00ooo003oooooooooo`0@
ooooo`03ool00?oooooooooo017ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000oooo
ooooool07oooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo03Sooooo00?oo`00oooo
ooooool09Oooool00ooo003oooooooooo`0Oooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool04Oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01_ooooo00?oo`00oooo
ooooool04Oooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo00oooooo00?oo`00oooo
ooooool06oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo017ooooo00?o0000oooo
ooooool03_ooool001kooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`0Tooooo`03
ool00?oooooooooo03Sooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`0Nooooo`;o
0000:oooool2o`0001;ooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0Kooooo`03
ool00?oooooooooo017ooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`0Aooooo`03
ool00?oooooooooo01[ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0@ooooo`;o
00004?ooool001kooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`0Uooooo`03ool0
0?oooooooooo03Oooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`0Oooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`0@ooooo`03ool0
0?oooooooooo01_ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Jooooo`03ool0
0?oooooooooo017ooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`0Aooooo`03ool0
0?oooooooooo017ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool07ooo
ool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo03Oooooo00?oo`00ooooooooool09Ooo
ool00ooo003oooooooooo`0Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04Ooo
ool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool04Ooo
ool00ooo003oooooooooo`0Jooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool06_oo
ool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo017ooooo00?o0000ooooooooool03_oo
ool001kooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooo
oooo03Kooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`0Nooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooo
oooo01[ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Jooooo`03ool00?oooooo
oooo017ooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooo
oooo017ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool07_ooool00ooo
003oooooooooo`0Vooooo`03ool00?oooooooooo03Kooooo00?oo`00ooooooooool09oooool00ooo
003oooooooooo`0Nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04Oooool00ooo
003oooooooooo`0Aooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool04Oooool00ooo
003oooooooooo`0Jooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool06_ooool00ooo
003oooooooooo`0Aooooo`03ool00?oooooooooo017ooooo00?o0000ooooooooool03_ooool001ko
oooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo03Go
oooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`0Nooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01Wo
oooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Jooooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo013o
oooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool07_ooool00ooo003ooooo
ooooo`0Wooooo`03ool00?oooooooooo03Gooooo00?oo`00ooooooooool09oooool00ooo003ooooo
ooooo`0Mooooo`;o0000:oooool2o`00017ooooo00?oo`00ooooooooool04_ooool00ooo003ooooo
ooooo`0Iooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool06Oooool00ooo003ooooo
ooooo`0Aooooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool04oooool00ooo003ooooo
ooooo`0?ooooo`;o00004?ooool001kooooo00?o0000ooooooooool07Oooool00ooo003ooooooooo
o`0Xooooo`03ool00?oooooooooo03Cooooo00?oo`00ooooooooool0:Oooool00ooo003ooooooooo
o`0Mooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04?ooool00ooo003ooooooooo
o`0Booooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool04oooool00ooo003ooooooooo
o`0Hooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool06Oooool00ooo003ooooooooo
o`0Cooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000
ooooooooool07Oooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo03Cooooo00?oo`00
ooooooooool0:Oooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool04?ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Sooooo00?oo`00
ooooooooool04oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01?ooooo00?oo`00
ooooooooool06?ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo013ooooo00?o0000
ooooooooool03_ooool001kooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`0Yoooo
o`03ool00?oooooooooo03?ooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`0Moooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`0Coooo
o`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Hoooo
o`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Coooo
o`03ool00?oooooooooo013ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000oooooooo
ool07?ooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo03?ooooo00?oo`00oooooooo
ool0:_ooool00ooo003oooooooooo`0Looooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool04?ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Sooooo00?oo`00oooooooo
ool04oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01?ooooo00?oo`00oooooooo
ool06?ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo013ooooo00?o0000oooooooo
ool03_ooool001kooooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`0Zooooo`03ool0
0?oooooooooo03;ooooo00?oo`00ooooooooool0:oooool00ooo003oooooooooo`0Looooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0Dooooo`03ool0
0?oooooooooo01Sooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Hooooo`03ool0
0?oooooooooo01?ooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Cooooo`03ool0
0?oooooooooo013ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool07?oo
ool00ooo003oooooooooo`0[ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool0:ooo
ool00ooo003oooooooooo`0Kooooo`;o0000:oooool2o`00013ooooo00?oo`00ooooooooool05?oo
ool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool06?oo
ool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?oo
ool00ooo003oooooooooo`0>ooooo`;o00004?ooool001kooooo00?o0000ooooooooool07?ooool0
0ooo003oooooooooo`0[ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool0:oooool0
0ooo003oooooooooo`0Looooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03oooool0
0ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool05Oooool0
0ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool05oooool0
0ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool03_ooool0
01kooooo00?o0000ooooooooool06oooool00ooo003oooooooooo`0/ooooo`03ool00?oooooooooo
033ooooo00?oo`00ooooooooool0;Oooool00ooo003oooooooooo`0Kooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo
01Oooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo
01?ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
00oooooo00?o0000ooooooooool03_ooool001Kooooo0ol00005ooooo`03o`000?oooooooooo01_o
oooo00?oo`00ooooooooool0;?ooool00ooo003oooooooooo`0`ooooo`03ool00?oooooooooo02go
oooo00?oo`00ooooooooool06oooool00ol0003oooooooooo`0Rooooo`?o00001?ooool00ol0003o
ooooooooo`0?ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05_ooool00ooo003o
ooooooooo`0Eooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool05Oooool00ooo003o
ooooooooo`0Fooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool03oooool00ol0003o
ooooooooo`0>ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo
00?oo`00ooooooooool0;Oooool00ooo003oooooooooo`0_ooooo`03ool00?oooooooooo02gooooo
00?oo`00ooooooooool06oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Kooooo
00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01Gooooo
00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00oooooo
00?o0000ooooooooool03_ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Jooooo`03ool00?oooooooooo02kooooo00?oo`00ooooooooool0;oooool00ooo003ooooooooo
o`0^ooooo`03ool00?oooooooooo01[ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool05_ooool00ooo003ooooooooo
o`0Fooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05_ooool00ooo003ooooooooo
o`0Eooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool05Oooool00ooo003ooooooooo
o`0?ooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooooooo00Cooooo0_l0000K
ooooo`03ool00?oooooooooo02kooooo00?oo`00ooooooooool0;_ooool00ooo003oooooooooo`0_
ooooo`03ool00?oooooooooo01Wooooo0_l0000Uooooo`03o`000?oooooooooo00?ooooo0_l0000?
ooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0E
ooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0F
ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool03_ooool2o`00013ooooo000Goooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0^oooo
o`03ool00?oooooooooo02kooooo00?oo`00ooooooooool0;oooool00ooo003oooooooooo`0Joooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>oooo
o`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Foooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0>oooo
o`005_ooool2o`0000Kooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`0_ooooo`03
ool00?oooooooooo02gooooo00?oo`00ooooooooool0;oooool00ooo003oooooooooo`0Jooooo`03
o`000?oooooooooo02;ooooo0_l00005ooooo`03o`000?oooooooooo00kooooo00?oo`00oooooooo
ool05_ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01Gooooo00?oo`00oooooooo
ool05_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Kooooo00?oo`00oooooooo
ool05_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0`ooooo`03ool0
0?oooooooooo02gooooo00?oo`00ooooooooool0<?ooool00ooo003oooooooooo`0Iooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03ool0
0?oooooooooo01Kooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Gooooo`03ool0
0?oooooooooo01Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Eooooo`03ool0
0?oooooooooo01Oooooo00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`007_oo
ool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo033ooooo00?oo`00ooooooooool0;?oo
ool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool05?oo
ool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool05Ooo
ool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooo
oooo037ooooo00?oo`00ooooooooool0:oooool00ooo003oooooooooo`0aooooo`03ool00?oooooo
oooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooo
oooo01Oooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooo
oooo01Cooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooo
oooo01Oooooo00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0
003oooooooooo`0Hooooo`03ool00?oooooooooo03;ooooo00?oo`00ooooooooool0:oooool00ooo
003oooooooooo`0aooooo`03ool00?oooooooooo01Sooooo0_l0000[ooooo`;o00003_ooool00ooo
003oooooooooo`0Hooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05oooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool05?ooool00ooo
003oooooooooo`0Gooooo`03ool00?oooooooooo00gooooo0_l0000@ooooo`007_ooool00ol0003o
ooooooooo`0Hooooo`03ool00?oooooooooo03;ooooo00?oo`00ooooooooool0:oooool00ooo003o
ooooooooo`0booooo`03ool00?oooooooooo01Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0=ooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ooo003o
ooooooooo`0Gooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05oooool00ooo003o
ooooooooo`0Dooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool03_ooool00ol0003o
ooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Hooooo`03ool00?oooooooooo03;ooooo
00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`0cooooo`03ool00?oooooooooo01Sooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo01Sooooo
00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Cooooo
00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003ooooooooo
o`0Hooooo`03ool00?oooooooooo03?ooooo00?oo`00ooooooooool0:Oooool00ooo003ooooooooo
o`0cooooo`03ool00?oooooooooo01Sooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0=ooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool05?ooool00ooo003ooooooooo
o`0Gooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool05oooool00ooo003ooooooooo
o`0Dooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool03Oooool00ol0003ooooooooo
o`0>ooooo`007_ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo03Cooooo00?oo`00
ooooooooool0:Oooool00ooo003oooooooooo`0dooooo`03ool00?oooooooooo01Oooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo01Wooooo00?oo`00
ooooooooool04_ooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo01?ooooo00?oo`00
ooooooooool05oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01Sooooo00?oo`00
ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Goooo
o`03ool00?oooooooooo03Cooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`0doooo
o`03ool00?oooooooooo01Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=oooo
o`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Ioooo
o`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Coooo
o`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0>oooo
o`007_ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo03Cooooo00?oo`00oooooooo
ool0:?ooool00ooo003oooooooooo`0eooooo`03ool00?oooooooooo01Kooooo0_l0000[ooooo`;o
00003_ooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo01;ooooo00?oo`00oooooooo
ool06Oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Sooooo00?oo`00oooooooo
ool04_ooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo00cooooo0_l0000@ooooo`00
7_ooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo03Gooooo00?oo`00ooooooooool0
9oooool00ooo003oooooooooo`0eooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0
6Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Fooooo`03ool00?oo
oooooooo03Kooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`0fooooo`03ool00?oo
oooooooo01Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`03ool00?oo
oooooooo01[ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Iooooo`03ool00?oo
oooooooo01;ooooo00?oo`00ooooooooool06Oooool00ooo003oooooooooo`0Booooo`03ool00?oo
oooooooo01Wooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`007_ooool0
0ol0003oooooooooo`0Fooooo`03ool00?oooooooooo03Kooooo00?oo`00ooooooooool09oooool0
0ooo003oooooooooo`0fooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool04_ooool0
0ooo003oooooooooo`0Iooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool06Oooool0
0ooo003oooooooooo`0Booooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo
03Oooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`0gooooo`03ool00?oooooooooo
01Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo
01[ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo
01;ooooo00?oo`00ooooooooool06Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo
01Wooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003o
ooooooooo`0Eooooo`03ool00?oooooooooo03Sooooo00?oo`00ooooooooool09Oooool00ooo003o
ooooooooo`0gooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0<ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool04Oooool00ooo003o
ooooooooo`0Jooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool06Oooool00ooo003o
ooooooooo`0Booooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool03?ooool00ol0003o
ooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo03Sooooo
00?oo`00ooooooooool09Oooool00ooo003oooooooooo`0hooooo`03ool00?oooooooooo01Cooooo
0_l0000[ooooo`;o00003Oooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo013ooooo
00?oo`00ooooooooool06oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo01Wooooo
00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Jooooo`03ool00?oooooooooo00_ooooo
0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo03Sooooo00?o
o`00ooooooooool09?ooool00ooo003oooooooooo`0iooooo`03ool00?oooooooooo01Gooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo01_ooooo00?o
o`00ooooooooool04?ooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo017ooooo00?o
o`00ooooooooool06Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo01_ooooo00?o
o`00ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0E
ooooo`03ool00?oooooooooo03Wooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`0i
ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<
ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0K
ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`0@
ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0>
ooooo`007_ooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo03[ooooo00?oo`00oooo
ooooool08oooool00ooo003oooooooooo`0iooooo`03ool00?oooooooooo01Gooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo01cooooo00?oo`00oooo
ooooool04?ooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo013ooooo00?oo`00oooo
ooooool06oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01_ooooo00?oo`00oooo
ooooool03?ooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Dooooo`03
ool00?oooooooooo03[ooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`0jooooo`03
ool00?oooooooooo01Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`03
ool00?oooooooooo01cooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0Kooooo`03
ool00?oooooooooo013ooooo00?oo`00ooooooooool06oooool00ooo003oooooooooo`0@ooooo`03
ool00?oooooooooo01_ooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`00
7_ooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo03[ooooo00?oo`00ooooooooool0
8_ooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool0
4?ooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0
6oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool0
3?ooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Dooooo`03ool00?oo
oooooooo03_ooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0kooooo`03ool00?oo
oooooooo01?ooooo0_l0000[ooooo`;o00003?ooool00ooo003oooooooooo`0Mooooo`03ool00?oo
oooooooo00oooooo00?oo`00ooooooooool07?ooool00ooo003oooooooooo`0?ooooo`03ool00?oo
oooooooo01_ooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0Looooo`03ool00?oo
oooooooo00[ooooo0_l0000@ooooo`007_ooool00ol0003oooooooooo`0Cooooo`03ool00?oooooo
oooo03cooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0looooo`03ool00?oooooo
oooo01?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooo
oooo01gooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooo
oooo00oooooo00?oo`00ooooooooool06oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooo
oooo01cooooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0
003oooooooooo`0Cooooo`03ool00?oooooooooo03cooooo00?oo`00ooooooooool08Oooool00ooo
003oooooooooo`0looooo`03ool00?oooooooooo01?ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0;ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool03_ooool00ooo
003oooooooooo`0Mooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool06oooool00ooo
003oooooooooo`0@ooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool02oooool00ol0
003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo03go
oooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0mooooo`03ool00?oooooooooo01?o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo01go
oooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo00oo
oooo00?oo`00ooooooooool07?ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo01go
oooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0>ooooo`005Oooool5o`0000Cooooo
00?o0000ooooooooool04_ooool00ooo003oooooooooo`0nooooo`03ool00?oooooooooo01oooooo
00?oo`00ooooooooool0?Oooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo
1Ol00003ooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool07Oooool00ooo003ooooo
ooooo`0>ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool03_ooool00ooo003ooooo
ooooo`0Mooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool07Oooool00ooo003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00kooooo000Fooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool04_ooool00ooo003oooooooooo`0nooooo`03ool00?oooooooooo01oooooo
00?oo`00ooooooooool0?_ooool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo02;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo01ko
oooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo00ko
oooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo01go
oooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0>ooooo`005oooool00ol0003ooooo
ooooo`04ooooo`;o00004oooool00ooo003oooooooooo`0nooooo`03ool00?oooooooooo01oooooo
00?oo`00ooooooooool0?_ooool00ooo003oooooooooo`0Aooooo`;o00009Oooool00ol0003ooooo
ooooo`03ooooo`;o00002oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo00kooooo
00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo01gooooo
00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo00[ooooo
0_l0000@ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o
o`00ooooooooool0?oooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo03oooooo00?o
o`00ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02_ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00gooooo00?o
o`00ooooooooool07_ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01gooooo00?o
o`00ooooooooool03_ooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo00[ooooo00?o
0000ooooooooool03_ooool001Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo017ooooo00?oo`00ooooooooool0@?ooool00ooo003oooooooooo`0Mooooo`03ool00?oo
oooooooo043ooooo00?oo`00ooooooooool04Oooool00ol0003oooooooooo`0Qooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo01oooooo
00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00gooooo
00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo01kooooo
00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`005Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`10ooooo`03ool0
0?oooooooooo01gooooo00?oo`00ooooooooool0@?ooool00ooo003oooooooooo`0Aooooo`03o`00
0?oooooooooo027ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00[o
oooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01oo
oooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo00go
oooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00ko
oooo000Fooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo047ooooo
00?oo`00ooooooooool07?ooool00ooo003oooooooooo`10ooooo`03ool00?oooooooooo017ooooo
00?o0000ooooooooool08_ooool3o`0000Cooooo00?o0000ooooooooool02_ooool00ooo003ooooo
ooooo`0Oooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool07oooool00ooo003ooooo
ooooo`0=ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool03?ooool00ooo003ooooo
ooooo`0Oooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool03_ooool001kooooo00?o
0000ooooooooool04?ooool00ooo003oooooooooo`12ooooo`03ool00?oooooooooo01_ooooo00?o
o`00ooooooooool0@_ooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool02_ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00cooooo00?o
o`00ooooooooool07oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01oooooo00?o
o`00ooooooooool03?ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00[ooooo00?o
0000ooooooooool03_ooool001kooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`12
ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool0@_ooool00ooo003oooooooooo`0?
ooooo`;o0000:oooool2o`0000[ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0<
ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0O
ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`09
ooooo`;o00004?ooool001kooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`12oooo
o`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool0@_ooool00ooo003oooooooooo`0@oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0Poooo
o`03ool00?oooooooooo00cooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0;oooo
o`03ool00?oooooooooo023ooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Ooooo
o`03ool00?oooooooooo00[ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000oooooooo
ool03oooool00ooo003oooooooooo`14ooooo`03ool00?oooooooooo01Wooooo00?oo`00oooooooo
ool0A?ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool02Oooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00_ooooo00?oo`00oooooooo
ool08?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo023ooooo00?oo`00oooooooo
ool02oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00Wooooo00?o0000oooooooo
ool03_ooool001kooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`14ooooo`03ool0
0?oooooooooo01Wooooo00?oo`00ooooooooool0A?ooool00ooo003oooooooooo`0?ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0Qooooo`03ool0
0?oooooooooo00[ooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0;ooooo`03ool0
0?oooooooooo023ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Qooooo`03ool0
0?oooooooooo00Wooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool03ooo
ool00ooo003oooooooooo`14ooooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool0A?oo
ool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02Ooo
ool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool08Ooo
ool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool02_oo
ool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool03_oo
ool001kooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`16ooooo`03ool00?oooooo
oooo01Oooooo00?oo`00ooooooooool0A_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0Qooooo`03ool00?oooooo
oooo00[ooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooo
oooo027ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooo
oooo00Wooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool03_ooool00ooo
003oooooooooo`16ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool0A_ooool00ooo
003oooooooooo`0>ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02Oooool00ooo
003oooooooooo`0Qooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool08Oooool00ooo
003oooooooooo`0:ooooo`03ool00?oooooooooo02;ooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`0Qooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool03_ooool001ko
oooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`16ooooo`03ool00?oooooooooo01Oo
oooo00?oo`00ooooooooool0A_ooool00ooo003oooooooooo`0=ooooo`;o0000:oooool2o`0000Wo
oooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo02;o
oooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Rooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`07ooooo`;o00004?ooool001kooooo
00?o0000ooooooooool03Oooool00ooo003oooooooooo`18ooooo`03ool00?oooooooooo01Gooooo
00?oo`00ooooooooool0B?ooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool02?ooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo00Sooooo
00?oo`00ooooooooool08oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo02;ooooo
00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo00Sooooo
00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool03Oooool00ooo003ooooooooo
o`18ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool0B?ooool00ooo003ooooooooo
o`0=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool00ooo003ooooooooo
o`0Sooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool08oooool00ooo003ooooooooo
o`08ooooo`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool02?ooool00ooo003ooooooooo
o`0Sooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool03_ooool001kooooo00?o0000
ooooooooool03Oooool00ooo003oooooooooo`18ooooo`03ool00?oooooooooo01Gooooo00?oo`00
ooooooooool0B?ooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool02?ooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo00Sooooo00?oo`00
ooooooooool08oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo02?ooooo00?oo`00
ooooooooool02?ooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo00Sooooo00?o0000
ooooooooool03_ooool001kooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`1:oooo
o`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool0B_ooool00ooo003oooooooooo`0<oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`0Soooo
o`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`08oooo
o`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0Soooo
o`03ool00?oooooooooo00Sooooo00?o0000ooooooooool03_ooool001kooooo00?o0000oooooooo
ool03?ooool00ooo003oooooooooo`1:ooooo`03ool00?oooooooooo01;ooooo00?oo`00oooooooo
ool0Boooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool01oooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool09?ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo02Cooooo00?oo`00oooooooo
ool01oooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo00Oooooo00?o0000oooooooo
ool03_ooool001kooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`1;ooooo`03ool0
0?oooooooooo017ooooo00?oo`00ooooooooool0Boooool00ooo003oooooooooo`0;ooooo`;o0000
:oooool2o`0000Sooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo02Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Uooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`06ooooo`;o0000
4?ooool001kooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`1<ooooo`03ool00?oo
oooooooo013ooooo00?oo`00ooooooooool0COooool00ooo003oooooooooo`0;ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0Uooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo02Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Uooooo`03ool00?oo
oooooooo00Oooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool02oooool0
0ooo003oooooooooo`1<ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0COooool0
0ooo003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool0
0ooo003oooooooooo`0Uooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool09Oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`0Uooooo`03ool00?oooooooooo00Oooooo00?o0000ooooooooool03_ooool0
01kooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`1=ooooo`03ool00?oooooooooo
00kooooo00?oo`00ooooooooool0Coooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
02Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo
00Kooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool02_ooool00ooo003o
ooooooooo`1>ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0Coooool00ooo003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01_ooool00ooo003o
ooooooooo`0Vooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool09oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool03_ooool001kooooo
00?o0000ooooooooool02_ooool00ooo003oooooooooo`1?ooooo`03ool00?oooooooooo00cooooo
00?oo`00ooooooooool0DOooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool01_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool09oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Oooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Kooooo
00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool02Oooool00ooo003ooooooooo
o`1Aooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0DOooool00ooo003ooooooooo
o`08ooooo`;o0000:oooool2o`0000Oooooo00?oo`00ooooooooool09oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0Wooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0:?ooool00ooo003ooooooooo
o`04ooooo`;o00004?ooool001kooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`1B
ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0Doooool00ooo003oooooooooo`08
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0X
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo02Wooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0X
ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03_ooool001kooooo00?o0000oooo
ooooool01oooool00ooo003oooooooooo`1Dooooo`03ool00?oooooooooo00Sooooo00?oo`00oooo
ooooool0EOooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0:?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Wooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00Gooooo00?o0000oooo
ooooool03_ooool001Kooooo0ol00005ooooo`03o`000?oooooooooo00Kooooo00?oo`00oooooooo
ool0E_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo05Oooooo00?oo`00oooooooo
ool01_ooool00ol0003oooooooooo`0Rooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`03
ool00?oooooooooo02[ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Yooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:_ooool01Ooo003oooooooooooooooooo`00
02cooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`005Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1Hoooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0FOooool00ooo003oooooooooo`05oooo
o`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Cooooo00?oo`00ooooooooool0:_ooool2ool000;ooooo00?oo`00ooooooooool0:oooool0
0ooo003oooooooooo`02ool002cooooo00Goo`00ooooooooooooooooool0000/ooooo`03ool00?oo
oooooooo00Cooooo00?o0000ooooooooool03_ooool001Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`;oo`00G?ooool2ool000?ooooo00?oo`00ooooooooool0F_ooool3
ool000Gooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo000000Gooooo0_oo
000]ooooo`04ool00?ooooooo`00ool002gooooo1?oo000]ooooo`;oo`0000?oooooool00?ooool0
;?ooool2ool000Gooooo00?o0000ooooooooool03_ooool001Oooooo0_l00005ooooo`;o00000ooo
ool2ool005oooooo0ooo001Oooooo`;oo`000oooool2o`0002Gooooo0_l00004ooooo`;o00000ooo
ool2ool002oooooo0_oo000_ooooo`;oo`00;oooool2ool002oooooo0_oo0003ooooo`;o00004?oo
ool001Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo000001Sooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00kooooo000E
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool2o`0002?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`00000@ooooo`005_ooool3o`0000Gooooocol0
000Tooooo`?o00001?ooooo@o`00013ooooo003oooooooWooooo003oooooooWooooo003oooooooWo
oooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWo
oooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWo
oooo003oooooooWooooo003oooooooWooooo003oooooobCooooo0ol0000Kooooo`Go00006oooool3
o`0001_ooooo0_l0000Looooo`?o00006oooool5o`0001_ooooo0ol0000Jooooo`008_ooool5o`00
00?ooooo0_l0000Xooooo`?o00001?ooool2o`0002Wooooo0_l0000[ooooo`?o00001?ooool2o`00
02Sooooo1Ol00003ooooo`;o0000=?ooool01Ol0003ooooooooooooooooo000001_ooooo00Co0000
oooooooooooo00007?ooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0001cooooo
00?o0000ooooooooool06oooool01?l0003oooooooooool0000Jooooo`05o`000?oooooooooooooo
ool000006Oooool002?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000X
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0002gooooo1Ol00005ooooo`03o`000?oooooo
oooo01;ooooo1Ol00003ooooo`03o`000?oooooooooo01Cooooo1Ol00003ooooo`03o`000?oooooo
oooo01Wooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool05oooool001cooooo1Ol00003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008?ooool5o`0000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`0002_ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo0000=Oooool2o`0001kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0I
ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Kooooo`;o00006_ooool002Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`04o`00
0?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Zoooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo01Sooooo00Go0000ooooooooooooooooo`00000Looooo`03o`000?oooooooooo01Wooooo00Co
0000oooooooooooo00007?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool0
00007_ooool00ol0003oooooooooo`0Gooooo`008_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002Oooooo00Co0000oooooooooooo0000:oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
03?ooooo00Go0000ooooooooooooooooo`00000Jooooo`05o`000?ooooooooooooooool000006ooo
ool2o`0001_ooooo00Co0000oooooooooooo00006oooool2o`0001cooooo00Go0000oooooooooooo
ooooo`00000Jooooo`05o`000?ooooooooooooooool000006Oooool002;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0002Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0002Oooooo00Co0000oooooooooooo0000:_ooool2o`0000Cooooo00Co0000oooooooooooo
00009oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000=?ooool3
o`0001cooooo0ol0000Mooooo`03o`000?oooooooooo01[ooooo0_l0000Mooooo`03o`000?oooooo
oooo01_ooooo0ol0000Looooo`?o00006_ooool002?ooooo0ol00004ooooo`;o0000:Oooool00ol0
003oooooooooo`03ooooo`;o0000:Oooool2o`0002cooooo00?o0000ooooooooool00oooool2o`00
02Wooooo0ol00004ooooo`;o0000ooooool;ooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`008?ooooo?o`0002;ooooo0ol00004ooooom3o00004?ooool001[ooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooooooool000008oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000@ooooo`006Ooo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`?o003o0_ooool3o`00o`;o
oooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;o
oooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l@oooo
o`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`?o003o0_ooool3o`00o`04ooooool00?oo003oo`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3
o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3
o`00o`;ooooo0ol00?l2ooooo`03o`000?oooooooooo01Wooooo1Ol00003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`006Oooool01?l0
003oooooooooool00003ooooo`Co00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2
o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`04o`000?l00?oo
003oo`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l0
0003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`?o000000Go003oo`000?l0003o0000
o`00o`04o`000004o`00ool0003o0000o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o
003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`04o`000?l00?oo003oo`00
o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00
o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l3o`0002?ooooo00?o0000oooo
ooooool00oooool2o`0000?ooooo1Ooo002mooooo`Coo`000oooool2o`00013ooooo000Iooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo0ol00?l2ooooo`?o003o0_ooool3
o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3
o`00o`04ooooool00?oo003oo`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol0
0?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooooooo`?o003o0_ooool3o`00o`;o
oooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`04
ooooool00?oo003oo`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07oooo
o`?oo`00]_ooool4ool000Sooooo00?o0000ooooooooool03_ooool001Wooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`1Pooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo023ooooo0_l00005ooooo`03o`000?oooooo
oooo00[ooooo0_oo002booooo`;oo`003?ooool00ol0003oooooooooo`0>ooooo`006Oooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo063ooooo00Go003oooooooooooooooooo`00
o`04ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0[Oooool2ool000kooooo00?o
0000ooooooooool03_ooool001[ooooo0_l00004ooooo`03o`000?oooooooooo063ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo0:_ooooo00?oo`00ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Pooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool03_ooool2ool00:[ooooo00?oo`00ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`008?ooool2o`00067ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo05oooooo00?o0000ooooooooool09oooool2o`00017ooooo0_oo002Wooooo`03ool00?oo
oooooooo00oooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`1Pooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool04_ooool00ooo003oooooooooo`2Sooooo`03ool00?oooooooooo017ooooo00?o
0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0H?ooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01?ooooo00?oo`00ooooooooool0XOooool00ooo003oooooooooo`0Booooo`03o`000?oo
oooooooo00kooooo000Pooooo`03o`000?oooooooooo063ooooo00Go003oooooooooooooooooo`00
o`04ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Cooooo`03ool00?oooooooooo0:3ooooo00?oo`00ooooooooool04oooool00ol0003ooooooooo
o`0>ooooo`008?ooool00ol0003oooooooooo`1Pooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05?oo
ool00ooo003oooooooooo`2Nooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool03_oo
ool0023ooooo00?o0000ooooooooool0H?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
003oooooooooool0Goooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Gooooo00?o
o`00ooooooooool0W?ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo000P
ooooo`;o0000HOooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0Gooo
ool00ol0003oooooooooo`0Wooooo`;o00005oooool00ooo003oooooooooo`2Jooooo`03ool00?oo
oooooooo01Gooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`1Pooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool05oooool00ooo003oooooooooo`2Hooooo`03ool00?oooooooooo01Oooooo00?o
0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0H?ooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01Oooooo00?oo`00ooooooooool0V?ooool00ooo003oooooooooo`0Gooooo`03o`000?oo
oooooooo00kooooo000Pooooo`03o`000?oooooooooo063ooooo00Go003oooooooooooooooooo`00
o`04ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Hooooo`03ool00?oooooooooo09Kooooo00?oo`00ooooooooool06?ooool00ol0003ooooooooo
o`0>ooooo`008?ooool00ol0003oooooooooo`1Pooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06Ooo
ool00ooo003oooooooooo`2Dooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool03_oo
ool0023ooooo00?o0000ooooooooool0H?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
003oooooooooool0Goooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01[ooooo00?o
o`00ooooooooool0T_ooool00ooo003oooooooooo`0Jooooo`03o`000?oooooooooo00kooooo000P
ooooo`;o0000HOooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0Gooo
ool00ol0003oooooooooo`0Wooooo`;o00007?ooool00ooo003oooooooooo`2@ooooo`03ool00?oo
oooooooo01[ooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`1Pooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool06oooool00ooo003oooooooooo`2@ooooo`03ool00?oooooooooo01_ooooo00?o
0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0H?ooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo01cooooo00?oo`00ooooooooool0S_ooool00ooo003oooooooooo`0Looooo`03o`000?oo
oooooooo00kooooo000Pooooo`03o`000?oooooooooo063ooooo00Go003oooooooooooooooooo`00
o`04ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Mooooo`03ool00?oooooooooo08cooooo00?oo`00ooooooooool07Oooool00ol0003ooooooooo
o`0>ooooo`008?ooool00ol0003oooooooooo`1Pooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07Ooo
ool00ooo003oooooooooo`2<ooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool03_oo
ool0023ooooo00?o0000ooooooooool0H?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
003oooooooooool0Goooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o
o`00ooooooooool0R_ooool00ooo003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo000P
ooooo`;o0000HOooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0Gooo
ool00ol0003oooooooooo`0Wooooo`;o00008?ooool00ooo003oooooooooo`28ooooo`03ool00?oo
oooooooo01kooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`1Pooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool07oooool00ooo003oooooooooo`28ooooo`03ool00?oooooooooo01oooooo00?o
0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0H?ooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo023ooooo00?oo`00ooooooooool0Q_ooool00ooo003oooooooooo`0Pooooo`03o`000?oo
oooooooo00kooooo000Pooooo`03o`000?oooooooooo063ooooo00Go003oooooooooooooooooo`00
o`04ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Qooooo`03ool00?oooooooooo08Cooooo00?oo`00ooooooooool08Oooool00ol0003ooooooooo
o`0>ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000
ooooooooool0H?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0Gooo
ool00ol0003oooooooooo`0Qooooo`;o00001?ooool00ol0003oooooooooo`0Qooooo`03ool00?oo
oooooooo08Cooooo00?oo`00ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`003Oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`1Pooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Oooooo`03
o`000?oooooooooo023ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Roooo
o`03ool00?oooooooooo08;ooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0>oooo
o`003Oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooooooo`?o0000H?ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0G_ooool2o`0002;ooooo00Co
0000oooooooooooo00000oooool2o`0002Cooooo00?oo`00ooooooooool0P?ooool00ooo003ooooo
ooooo`0Rooooo`;o00004?ooool000gooooo00Co0000oooooooooooo00002oooool01Ol0003ooooo
oooooooooooo000006;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
05oooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo02?ooooo00?oo`00ooooooooool0P?ooool00ooo003oooooooooo`0Sooooo`03o`000?oooooo
oooo00kooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo1?l00004ooooo`03o`000?oooooo
oooo063ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo05oooooo00?o
0000ooooooooool08?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo02Cooooo
00?oo`00ooooooooool0O_ooool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo00kooooo
000=ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Pooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Oooooo`03
o`000?oooooooooo023ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Toooo
o`03ool00?oooooooooo07kooooo00?oo`00ooooooooool09?ooool00ol0003oooooooooo`0>oooo
o`003_ooool2o`0000Sooooo1Ol00003ooooo`03o`000?oooooooooo063ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool08Oooool2o`00
00Cooooo00?o0000ooooooooool09Oooool00ooo003oooooooooo`1looooo`03ool00?oooooooooo
02Gooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0H?ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo02Gooooo00?oo`00ooooooooool0O?ooool00ooo003oooooooooo`0Uoooo
o`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo063ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool2o`00
02Oooooo00?oo`00ooooooooool0N_ooool00ooo003oooooooooo`0Uooooo`;o00004?ooool0023o
oooo0_l0001Qooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Ooooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`1joooo
o`03ool00?oooooooooo02Kooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooooooo
ool0H?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0Goooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool0N?ooool00ooo
003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo063o
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo05oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Xooooo`03ool00?oooooooooo07Kooooo00?oo`00oooo
ooooool0:?ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Pooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0:?ooool00ooo003oooooooooo`1fooooo`03ool00?oooooooooo
02Sooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0H?ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo02Wooooo00?oo`00ooooooooool0M?ooool00ooo003oooooooooo`0Yoooo
o`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo063ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Yooooo`03ool00?oooooooooo07Cooooo00?oo`00ooooooooool0:Oooool00ol0
003oooooooooo`0>ooooo`008?ooool2o`00067ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool2o`0002_ooooo00?oo`00oooo
ooooool0L_ooool00ooo003oooooooooo`0Yooooo`;o00004?ooool0023ooooo00?o0000oooooooo
ool0H?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0Goooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0L_ooool00ooo
003oooooooooo`0Zooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo063o
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo05oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo073ooooo00?oo`00oooo
ooooool0:oooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Pooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0:oooool00ooo003oooooooooo`1`ooooo`03ool00?oooooooooo
02_ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0H?ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo02cooooo00?oo`00ooooooooool0K_ooool00ooo003oooooooooo`0/oooo
o`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo063ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0/ooooo`03ool00?oooooooooo06kooooo00?oo`00ooooooooool0;?ooool00ol0
003oooooooooo`0>ooooo`008?ooool2o`00067ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool2o`0002kooooo00?oo`00oooo
ooooool0K?ooool00ooo003oooooooooo`0/ooooo`;o00004?ooool0023ooooo00?o0000oooooooo
ool0H?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0Goooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo02gooooo00?oo`00ooooooooool0K?ooool00ooo
003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo063o
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo05oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0^ooooo`03ool00?oooooooooo06[ooooo00?oo`00oooo
ooooool0;_ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Pooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0;_ooool00ooo003oooooooooo`1Zooooo`03ool00?oooooooooo
02kooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0H?ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo02oooooo00?oo`00ooooooooool0J?ooool00ooo003oooooooooo`0_oooo
o`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo063ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0_ooooo`03ool00?oooooooooo06Sooooo00?oo`00ooooooooool0;oooool00ol0
003oooooooooo`0>ooooo`008?ooool2o`00067ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool2o`00037ooooo00?oo`00oooo
ooooool0I_ooool00ooo003oooooooooo`0_ooooo`;o00004?ooool0023ooooo00?o0000oooooooo
ool0H?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0Goooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo033ooooo00?oo`00ooooooooool0I_ooool00ooo
003oooooooooo`0`ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo063o
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo05oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0aooooo`03ool00?oooooooooo06Cooooo00?oo`00oooo
ooooool0<Oooool00ol0003oooooooooo`0>ooooo`006Oooool3o`0000Cooooo00?o0000oooooooo
ool0H?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0Goooool00ol0
003oooooooooo`0Pooooo`?o00001?ooool00ol0003oooooooooo`0aooooo`03ool00?oooooooooo
06Cooooo00?oo`00ooooooooool0<Oooool00ol0003oooooooooo`0>ooooo`006_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo063ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo05oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo03;ooooo00?oo`00ooooooooool0H_ooool00ooo003oooooooooo`0boooo
o`03o`000?oooooooooo00kooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Goooool3o`00o`04ooooool00?oo003oo`00o`;ooooo0ol00?mPooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0booooo`03ool00?oooooooooo
06;ooooo00?oo`00ooooooooool0<_ooool00ol0003oooooooooo`0>ooooo`006_ooool00ol0003o
ooooooooo`03ooooo`?o0000Goooool3o`00o`04ooooool00?oo003oo`00o`;ooooo0ol00?mOoooo
o`;o00008oooool00ol0003oooooooooo`03ooooo`;o0000=?ooool00ooo003oooooooooo`1Poooo
o`03ool00?oooooooooo03;ooooo0_l0000@ooooo`006_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05oooooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003oH?ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool00ooo
003oooooooooo`1Pooooo`03ool00?oooooooooo03?ooooo00?o0000ooooooooool03_ooool001Wo
oooo0_l00005ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool08?ooool2o`0000Go
oooo00?o0000ooooooooool0=?ooool00ooo003oooooooooo`1Nooooo`03ool00?oooooooooo03Co
oooo00?o0000ooooooooool03_ooool001[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3;ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0dooooo`03ool00?oooooooooo05kooooo00?oo`00ooooooooool0=?ooool00ol0003ooooo
ooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0=Oooool00ooo003oooooooooo`1Looooo`03ool00?oooooooooo03Gooooo00?o
0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03Kooooo00?oo`00ooooooooool0Foooool00ooo003oooooooooo`0e
ooooo`03o`000?oooooooooo00kooooo000Pooooo`;o0000c?ooool00ol0003oooooooooo`0Woooo
o`;o0000=oooool00ooo003oooooooooo`1Jooooo`03ool00?oooooooooo03Gooooo0_l0000@oooo
o`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0=oooool00ooo003oooooooooo`1Iooooo`03ool00?oooooooooo03Kooooo00?o0000oooooooo
ool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo03Oooooo00?oo`00ooooooooool0F?ooool00ooo003oooooooooo`0gooooo`03o`00
0?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo05Kooooo00?oo`00ooooooooool0>?oo
ool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0>?ooool00ooo003oooooooooo`1Fooooo`03ool00?oooooo
oooo03Sooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo03Wooooo00?oo`00ooooooooool0E?ooool00ooo
003oooooooooo`0iooooo`03o`000?oooooooooo00kooooo000Pooooo`;o0000c?ooool00ol0003o
ooooooooo`0Wooooo`;o0000>_ooool00ooo003oooooooooo`1Dooooo`03ool00?oooooooooo03So
oooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0>_ooool00ooo003oooooooooo`1Booooo`03ool00?oooooooooo03[ooooo
00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo03_ooooo00?oo`00ooooooooool0DOooool00ooo003ooooooooo
o`0jooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0kooooo`03ool00?oooooooooo053ooooo00?oo`00
ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0??ooool00ooo003oooooooooo`1?oooo
o`03ool00?oooooooooo03_ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03cooooo00?oo`00oooooooo
ool0C_ooool00ooo003oooooooooo`0looooo`03o`000?oooooooooo00kooooo000Pooooo`;o0000
c?ooool00ol0003oooooooooo`0Wooooo`;o0000?_ooool00ooo003oooooooooo`1<ooooo`03ool0
0?oooooooooo03cooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0?Oooool00ooo003oooooooooo`1<ooooo`03ool00?oo
oooooooo03gooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03kooooo00?oo`00ooooooooool0B_ooool0
0ooo003oooooooooo`0nooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo
0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0nooooo`03ool00?oooooooooo
04[ooooo00?oo`00ooooooooool0?_ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0?oooool00ooo003o
ooooooooo`18ooooo`03ool00?oooooooooo03oooooo00?o0000ooooooooool03_ooool0023ooooo
00?o0000ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03oooooo
00?oo`00ooooooooool0Aoooool00ooo003oooooooooo`10ooooo`03o`000?oooooooooo00kooooo
000Pooooo`;o0000c?ooool00ol0003oooooooooo`0Wooooo`;o0000@Oooool00ooo003ooooooooo
o`16ooooo`03ool00?oooooooooo03oooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0@Oooool00ooo003oooooooooo`14
ooooo`03ool00?oooooooooo047ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooo
ooooool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo047ooooo00?oo`00oooo
ooooool0A?ooool00ooo003oooooooooo`11ooooo`03o`000?oooooooooo00kooooo000Pooooo`03
o`000?oooooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`12ooooo`03
ool00?oooooooooo04;ooooo00?oo`00ooooooooool0@_ooool00ol0003oooooooooo`0>ooooo`00
3Oooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0
boooool00ol0003oooooooooo`0Oooooo`Go00000oooool00ol0003oooooooooo`12ooooo`03ool0
0?oooooooooo047ooooo00?oo`00ooooooooool0@oooool00ol0003oooooooooo`0>ooooo`003_oo
ool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`3;ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`13ooooo`03ool00?oooooooooo043ooooo00?oo`00ooooooooool0@oooool00ol0003o
ooooooooo`0>ooooo`003_ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooooooo`?o
0000b_ooool2o`0002?ooooo00?o0000ooooooooool00oooool2o`0004Cooooo00?oo`00oooooooo
ool0?oooool00ooo003oooooooooo`13ooooo`;o00004?ooool000kooooo00?o0000ooooooooool0
2oooool01Ol0003ooooooooooooooooo00000<gooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04Cooooo00?oo`00ooooooooool0?_ooool00ooo003o
ooooooooo`14ooooo`03o`000?oooooooooo00kooooo000>ooooo`03o`000?oooooooooo00Oooooo
1?l00004ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool07oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0A?ooool00ooo003oooooooooo`0mooooo`03
ool00?oooooooooo04Gooooo00?o0000ooooooooool03_ooool000gooooo0_l00009ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Oooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`15ooooo`03ool00?oooooooooo03_o
oooo00?oo`00ooooooooool0A_ooool00ol0003oooooooooo`0>ooooo`003_ooool00ol0003ooooo
ooooo`07ooooo`Go00000oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo023ooooo
0ol00004ooooo`03o`000?oooooooooo04Kooooo00?oo`00ooooooooool0>_ooool00ooo003ooooo
ooooo`16ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`16ooooo`03ool00?oooooooooo03Wooooo00?o
o`00ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`008?ooool2o`000<cooooo00?o0000
ooooooooool09oooool2o`0004Sooooo00?oo`00ooooooooool0>?ooool00ooo003oooooooooo`16
ooooo`;o00004?ooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo04Sooooo00?oo`00ooooooooool0=_ooool00ooo003oooooooooo`18oooo
o`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`18ooooo`03ool00?oooooooooo03Gooooo00?oo`00oooooooo
ool0BOooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0BOooool00ooo003oooooooooo`0dooooo`03ool0
0?oooooooooo04Wooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0booo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04[ooooo00?oo`00ooooooooool0<_oo
ool00ooo003oooooooooo`1:ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooo
oooo0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1:ooooo`03ool00?oooooo
oooo03;ooooo00?oo`00ooooooooool0B_ooool00ol0003oooooooooo`0>ooooo`008?ooool2o`00
0<cooooo00?o0000ooooooooool09oooool2o`0004cooooo00?oo`00ooooooooool0<?ooool00ooo
003oooooooooo`1:ooooo`;o00004?ooool0023ooooo00?o0000ooooooooool0boooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool0;_ooool00ooo003o
ooooooooo`1<ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo02kooooo
00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0COooool00ooo003ooooooooo
o`0/ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04kooooo00?oo`00
ooooooooool0:_ooool00ooo003oooooooooo`1>ooooo`03o`000?oooooooooo00kooooo000Poooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1?oooo
o`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool0Coooool00ol0003oooooooooo`0>oooo
o`008?ooool2o`000<cooooo00?o0000ooooooooool09oooool2o`00057ooooo00?oo`00oooooooo
ool09_ooool00ooo003oooooooooo`1?ooooo`;o00004?ooool0023ooooo00?o0000ooooooooool0
boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo057ooooo00?oo`00ooooooooool0
9?ooool00ooo003oooooooooo`1Aooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oo
oooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Booooo`03ool00?oo
oooooooo02;ooooo00?oo`00ooooooooool0D_ooool00ol0003oooooooooo`0>ooooo`008?ooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Doooool0
0ooo003oooooooooo`0Pooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool03_ooool0
023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
05Cooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`1Dooooo`03o`000?oooooooooo
00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`1Eooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool0EOooool00ol0003o
ooooooooo`0>ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`1Fooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool0E_ooool00ol0003ooooo
ooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo0_l0
001Hooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0E_ooool2o`00013ooooo000P
ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1H
ooooo`03ool00?oooooooooo01Gooooo0_oo001Jooooo`03o`000?oooooooooo00kooooo000Poooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Ioooo
o`;oo`004oooool2ool005cooooo00?o0000ooooooooool03_ooool001Sooooo1Ol00003ooooo`03
o`000?oooooooooo0<_ooooo00?o0000ooooooooool08?ooool3o`0000Cooooo00?o0000oooooooo
ool0Foooool2ool000oooooo0_oo001Nooooo`03o`000?oooooooooo00kooooo000Iooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Oooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Mooooo`;oo`002oooool2ool0
063ooooo00?o0000ooooooooool03_ooool001[ooooo00?o0000ooooooooool00oooool3o`000<[o
oooo0_l0000Uooooo`05o`000?ooooooooooooooool00000HOooool4ool000Cooooo0ooo001Roooo
o`03o`000?oooooooooo00kooooo000Kooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Qooooo`;o00001?ooool2o`0006Cooooo1?oo001Tooooo`;o
00004?ooool001Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;oooool01Ol0003ooooooooooooooooo000002Gooooo00Go0000oooo
ooooooooooooo`000009ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool0
01Sooooo00Go0000ooooooooooooooooo`000003oooooloo00008Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`00013ooooo000Iooooo`?o0000mOooool3o`0000Coooood?l0000@ooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-8.51939, \
-1.72556, 0.0638556, 0.032888}, {{262.875, 490.688}, {303, 162.25}} -> \
{-49.0425, -1.72554, 0.127711, 0.0328877}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-27.7031, -2.91994, 0.203806, 0.0164882}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-12.2606, -6.81909, 0.0319279, 0.032888}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["M = 2", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = 2;\)\), "\[IndentingNewLine]", 
    \(\(g1b\  = \ 
        DiscreteListPlot[Table[{n, \ pulse[n, \ m]}, {n, \(-20\), 20}], Blue, 
          Frame \[Rule] True, \ Axes \[Rule] {True, False}, \ 
          PlotRange \[Rule] {\(- .05\), 2.05}, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g2b\  = \ 
        Plot[Evaluate[
            dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-\[Pi]\), \ \[Pi]}, 
          PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g3b\  = \ 
        Plot[Evaluate[dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-2\) \[Pi], \ 
            2  \[Pi]}, PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g4b\  = \ 
        Plot[Evaluate[dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-4\) \[Pi], \ 
            4  \[Pi]}, PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1b, g2b}, {g3b, g4b}}], \ 
        ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.132436 0.0941766 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03826 -12 -4.5 ]
[-0.0125 .03826 0 4.5 ]
[-0.0125 .13244 -6 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .22661 -6 -4.5 ]
[-0.0125 .22661 0 4.5 ]
[-0.0125 .32079 -6 -4.5 ]
[-0.0125 .32079 0 4.5 ]
[-0.0125 .41497 -6 -4.5 ]
[-0.0125 .41497 0 4.5 ]
[-0.0125 .50914 -6 -4.5 ]
[-0.0125 .50914 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-6)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-4)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-2)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(2)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(4)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(6)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.08317 0 m
.08317 .00375 L
s
.12106 0 m
.12106 .00375 L
s
.15895 0 m
.15895 .00375 L
s
.23474 0 m
.23474 .00375 L
s
.27264 0 m
.27264 .00375 L
s
.31053 0 m
.31053 .00375 L
s
.38632 0 m
.38632 .00375 L
s
.42421 0 m
.42421 .00375 L
s
.46211 0 m
.46211 .00375 L
s
.53789 0 m
.53789 .00375 L
s
.57579 0 m
.57579 .00375 L
s
.61368 0 m
.61368 .00375 L
s
.68947 0 m
.68947 .00375 L
s
.72736 0 m
.72736 .00375 L
s
.76526 0 m
.76526 .00375 L
s
.84105 0 m
.84105 .00375 L
s
.87894 0 m
.87894 .00375 L
s
.91683 0 m
.91683 .00375 L
s
.00738 0 m
.00738 .00375 L
s
.99262 0 m
.99262 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03826 m
.00625 .03826 L
s
[(-1)] -0.0125 .03826 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(0)] -0.0125 .13244 1 0 Mshowa
0 .22661 m
.00625 .22661 L
s
[(1)] -0.0125 .22661 1 0 Mshowa
0 .32079 m
.00625 .32079 L
s
[(2)] -0.0125 .32079 1 0 Mshowa
0 .41497 m
.00625 .41497 L
s
[(3)] -0.0125 .41497 1 0 Mshowa
0 .50914 m
.00625 .50914 L
s
[(4)] -0.0125 .50914 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(5)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .05709 m
.00375 .05709 L
s
0 .07593 m
.00375 .07593 L
s
0 .09477 m
.00375 .09477 L
s
0 .1136 m
.00375 .1136 L
s
0 .15127 m
.00375 .15127 L
s
0 .17011 m
.00375 .17011 L
s
0 .18894 m
.00375 .18894 L
s
0 .20778 m
.00375 .20778 L
s
0 .24545 m
.00375 .24545 L
s
0 .26428 m
.00375 .26428 L
s
0 .28312 m
.00375 .28312 L
s
0 .30195 m
.00375 .30195 L
s
0 .33962 m
.00375 .33962 L
s
0 .35846 m
.00375 .35846 L
s
0 .37729 m
.00375 .37729 L
s
0 .39613 m
.00375 .39613 L
s
0 .4338 m
.00375 .4338 L
s
0 .45264 m
.00375 .45264 L
s
0 .47147 m
.00375 .47147 L
s
0 .49031 m
.00375 .49031 L
s
0 .52798 m
.00375 .52798 L
s
0 .54681 m
.00375 .54681 L
s
0 .56565 m
.00375 .56565 L
s
0 .58448 m
.00375 .58448 L
s
0 .01942 m
.00375 .01942 L
s
0 .00059 m
.00375 .00059 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.08317 .61428 m
.08317 .61803 L
s
.12106 .61428 m
.12106 .61803 L
s
.15895 .61428 m
.15895 .61803 L
s
.23474 .61428 m
.23474 .61803 L
s
.27264 .61428 m
.27264 .61803 L
s
.31053 .61428 m
.31053 .61803 L
s
.38632 .61428 m
.38632 .61803 L
s
.42421 .61428 m
.42421 .61803 L
s
.46211 .61428 m
.46211 .61803 L
s
.53789 .61428 m
.53789 .61803 L
s
.57579 .61428 m
.57579 .61803 L
s
.61368 .61428 m
.61368 .61803 L
s
.68947 .61428 m
.68947 .61803 L
s
.72736 .61428 m
.72736 .61803 L
s
.76526 .61428 m
.76526 .61803 L
s
.84105 .61428 m
.84105 .61803 L
s
.87894 .61428 m
.87894 .61803 L
s
.91683 .61428 m
.91683 .61803 L
s
.00738 .61428 m
.00738 .61803 L
s
.99262 .61428 m
.99262 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03826 m
1 .03826 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .22661 m
1 .22661 L
s
.99375 .32079 m
1 .32079 L
s
.99375 .41497 m
1 .41497 L
s
.99375 .50914 m
1 .50914 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .05709 m
1 .05709 L
s
.99625 .07593 m
1 .07593 L
s
.99625 .09477 m
1 .09477 L
s
.99625 .1136 m
1 .1136 L
s
.99625 .15127 m
1 .15127 L
s
.99625 .17011 m
1 .17011 L
s
.99625 .18894 m
1 .18894 L
s
.99625 .20778 m
1 .20778 L
s
.99625 .24545 m
1 .24545 L
s
.99625 .26428 m
1 .26428 L
s
.99625 .28312 m
1 .28312 L
s
.99625 .30195 m
1 .30195 L
s
.99625 .33962 m
1 .33962 L
s
.99625 .35846 m
1 .35846 L
s
.99625 .37729 m
1 .37729 L
s
.99625 .39613 m
1 .39613 L
s
.99625 .4338 m
1 .4338 L
s
.99625 .45264 m
1 .45264 L
s
.99625 .47147 m
1 .47147 L
s
.99625 .49031 m
1 .49031 L
s
.99625 .52798 m
1 .52798 L
s
.99625 .54681 m
1 .54681 L
s
.99625 .56565 m
1 .56565 L
s
.99625 .58448 m
1 .58448 L
s
.99625 .01942 m
1 .01942 L
s
.99625 .00059 m
1 .00059 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02499 .60321 L
.02605 .60291 L
.02729 .60233 L
.02846 .60155 L
.03053 .59962 L
.03279 .59674 L
.03527 .59263 L
.0379 .58721 L
.04262 .57482 L
.05205 .54045 L
.06244 .48967 L
.10458 .21759 L
.11537 .15253 L
.12562 .09989 L
.13482 .06241 L
.14009 .04564 L
.14487 .03353 L
.14727 .02857 L
.14988 .02406 L
.15213 .02088 L
.1546 .01816 L
.15596 .01701 L
.15723 .01614 L
.15857 .01545 L
.15932 .01516 L
.16 .01496 L
.16122 .01475 L
.16192 .01472 L
.16255 .01473 L
.16373 .0149 L
.16497 .01525 L
.16612 .01574 L
.16718 .01633 L
.16955 .01811 L
.17164 .02021 L
.17385 .02292 L
.17852 .0303 L
.18364 .04067 L
.20325 .09623 L
.2242 .16365 L
.23444 .19151 L
.23984 .20349 L
.24555 .2137 L
.25054 .22032 L
.25338 .22305 L
.25474 .2241 L
.25603 .22492 L
.2572 .22552 L
.25847 .22603 L
Mistroke
.25962 .22636 L
.26069 .22654 L
.26196 .22661 L
.26312 .22654 L
.26376 .22644 L
.26445 .22629 L
.2657 .22591 L
.26694 .22537 L
.26808 .22474 L
.27063 .22289 L
.27299 .22062 L
.27523 .21799 L
.28024 .21048 L
.28568 .19994 L
.29663 .17233 L
.30675 .14142 L
.32705 .07584 L
.33698 .04822 L
.34132 .03814 L
.34607 .02892 L
.3483 .0253 L
.35067 .02199 L
.35272 .0196 L
.35495 .01753 L
.35626 .01657 L
.35746 .01585 L
.35862 .01533 L
.35984 .01495 L
.36093 .01476 L
.36195 .01472 L
.36307 .01481 L
.36428 .01509 L
.36558 .0156 L
.36679 .01627 L
.36812 .01722 L
.36954 .01848 L
.37191 .02117 L
.37452 .02501 L
.37934 .03443 L
.38387 .04608 L
.39369 .08031 L
.40403 .12861 L
.42253 .23893 L
.44247 .37317 L
.46061 .4855 L
.47 .53275 L
.48019 .57177 L
.48291 .57972 L
.48579 .58694 L
.48846 .59248 L
Mistroke
.49096 .59665 L
.49329 .59964 L
.49461 .60094 L
.4958 .60188 L
.49711 .60263 L
.49785 .60294 L
.49854 .60314 L
.49979 .60332 L
.5005 .6033 L
.50113 .60321 L
.50234 .60287 L
.50346 .60234 L
.50469 .60151 L
.50602 .60036 L
.50871 .59712 L
.51117 .59316 L
.51591 .58283 L
.5204 .56991 L
.53037 .53106 L
.54122 .47526 L
.56062 .35241 L
.58202 .20963 L
.59178 .15127 L
.60229 .09768 L
.60713 .07701 L
.61222 .05827 L
.61689 .04391 L
.62131 .03297 L
.62371 .0281 L
.62632 .02368 L
.62848 .02068 L
.63086 .01809 L
.6322 .01697 L
.63344 .01613 L
.63476 .01545 L
.6355 .01517 L
.63617 .01497 L
.63737 .01476 L
.63868 .01473 L
.63992 .0149 L
.64107 .01522 L
.64222 .0157 L
.64347 .01639 L
.64574 .01811 L
.64794 .02033 L
.64997 .02283 L
.65458 .03006 L
.65944 .0398 L
.67913 .09523 L
.69748 .1548 L
Mistroke
.70797 .18485 L
.71313 .19731 L
.71789 .20712 L
.72213 .2143 L
.72679 .22039 L
.72922 .22276 L
.73149 .22447 L
.73274 .2252 L
.73388 .22574 L
.73521 .2262 L
.73646 .22648 L
.7377 .2266 L
.7384 .22661 L
.73905 .22657 L
.74023 .22639 L
.74149 .22605 L
.74261 .22561 L
.74366 .22509 L
.74604 .22352 L
.74862 .22121 L
.75097 .21855 L
.75626 .21077 L
.7657 .19117 L
.77464 .16707 L
.79285 .10895 L
.80322 .07588 L
.81296 .04873 L
.81759 .03798 L
.82247 .02856 L
.82502 .02451 L
.82782 .02082 L
.83036 .01819 L
.83273 .01639 L
.83404 .01566 L
.83473 .01536 L
.83546 .01511 L
.8361 .01493 L
.83681 .0148 L
.83804 .01472 L
.83925 .01481 L
.84054 .01512 L
.84176 .0156 L
.84288 .01621 L
.84426 .01718 L
.84554 .0183 L
.84844 .02163 L
.851 .02549 L
.85373 .03054 L
.8591 .04337 L
.86404 .05847 L
Mistroke
.87517 .10357 L
.89535 .21715 L
.9158 .35399 L
.93488 .47475 L
.94431 .52408 L
.95323 .56123 L
.95816 .5771 L
.96076 .58403 L
.96352 .59026 L
.96584 .59458 L
.96839 .59835 L
.96951 .59967 L
.97071 .60086 L
.97175 .60171 L
.97289 .60243 L
.97372 .60282 L
.9745 .60308 L
.97532 .60326 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.037894 0.132436 0.0941767 [
[.12106 -0.0125 -9 -9 ]
[.12106 -0.0125 9 0 ]
[.31053 -0.0125 -6 -9 ]
[.31053 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.68947 -0.0125 -3 -9 ]
[.68947 -0.0125 3 0 ]
[.87894 -0.0125 -6 -9 ]
[.87894 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03826 -12 -4.5 ]
[-0.0125 .03826 0 4.5 ]
[-0.0125 .13244 -6 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .22661 -6 -4.5 ]
[-0.0125 .22661 0 4.5 ]
[-0.0125 .32079 -6 -4.5 ]
[-0.0125 .32079 0 4.5 ]
[-0.0125 .41497 -6 -4.5 ]
[-0.0125 .41497 0 4.5 ]
[-0.0125 .50914 -6 -4.5 ]
[-0.0125 .50914 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12106 0 m
.12106 .00625 L
s
[(-10)] .12106 -0.0125 0 1 Mshowa
.31053 0 m
.31053 .00625 L
s
[(-5)] .31053 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.68947 0 m
.68947 .00625 L
s
[(5)] .68947 -0.0125 0 1 Mshowa
.87894 0 m
.87894 .00625 L
s
[(10)] .87894 -0.0125 0 1 Mshowa
.125 Mabswid
.15895 0 m
.15895 .00375 L
s
.19685 0 m
.19685 .00375 L
s
.23474 0 m
.23474 .00375 L
s
.27264 0 m
.27264 .00375 L
s
.34842 0 m
.34842 .00375 L
s
.38632 0 m
.38632 .00375 L
s
.42421 0 m
.42421 .00375 L
s
.46211 0 m
.46211 .00375 L
s
.53789 0 m
.53789 .00375 L
s
.57579 0 m
.57579 .00375 L
s
.61368 0 m
.61368 .00375 L
s
.65158 0 m
.65158 .00375 L
s
.72736 0 m
.72736 .00375 L
s
.76526 0 m
.76526 .00375 L
s
.80315 0 m
.80315 .00375 L
s
.84105 0 m
.84105 .00375 L
s
.08317 0 m
.08317 .00375 L
s
.04527 0 m
.04527 .00375 L
s
.00738 0 m
.00738 .00375 L
s
.91683 0 m
.91683 .00375 L
s
.95473 0 m
.95473 .00375 L
s
.99262 0 m
.99262 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03826 m
.00625 .03826 L
s
[(-1)] -0.0125 .03826 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(0)] -0.0125 .13244 1 0 Mshowa
0 .22661 m
.00625 .22661 L
s
[(1)] -0.0125 .22661 1 0 Mshowa
0 .32079 m
.00625 .32079 L
s
[(2)] -0.0125 .32079 1 0 Mshowa
0 .41497 m
.00625 .41497 L
s
[(3)] -0.0125 .41497 1 0 Mshowa
0 .50914 m
.00625 .50914 L
s
[(4)] -0.0125 .50914 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(5)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .05709 m
.00375 .05709 L
s
0 .07593 m
.00375 .07593 L
s
0 .09476 m
.00375 .09476 L
s
0 .1136 m
.00375 .1136 L
s
0 .15127 m
.00375 .15127 L
s
0 .17011 m
.00375 .17011 L
s
0 .18894 m
.00375 .18894 L
s
0 .20778 m
.00375 .20778 L
s
0 .24545 m
.00375 .24545 L
s
0 .26428 m
.00375 .26428 L
s
0 .28312 m
.00375 .28312 L
s
0 .30195 m
.00375 .30195 L
s
0 .33962 m
.00375 .33962 L
s
0 .35846 m
.00375 .35846 L
s
0 .37729 m
.00375 .37729 L
s
0 .39613 m
.00375 .39613 L
s
0 .4338 m
.00375 .4338 L
s
0 .45264 m
.00375 .45264 L
s
0 .47147 m
.00375 .47147 L
s
0 .49031 m
.00375 .49031 L
s
0 .52798 m
.00375 .52798 L
s
0 .54681 m
.00375 .54681 L
s
0 .56565 m
.00375 .56565 L
s
0 .58448 m
.00375 .58448 L
s
0 .01942 m
.00375 .01942 L
s
0 .00059 m
.00375 .00059 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.12106 .61178 m
.12106 .61803 L
s
.31053 .61178 m
.31053 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.68947 .61178 m
.68947 .61803 L
s
.87894 .61178 m
.87894 .61803 L
s
.125 Mabswid
.15895 .61428 m
.15895 .61803 L
s
.19685 .61428 m
.19685 .61803 L
s
.23474 .61428 m
.23474 .61803 L
s
.27264 .61428 m
.27264 .61803 L
s
.34842 .61428 m
.34842 .61803 L
s
.38632 .61428 m
.38632 .61803 L
s
.42421 .61428 m
.42421 .61803 L
s
.46211 .61428 m
.46211 .61803 L
s
.53789 .61428 m
.53789 .61803 L
s
.57579 .61428 m
.57579 .61803 L
s
.61368 .61428 m
.61368 .61803 L
s
.65158 .61428 m
.65158 .61803 L
s
.72736 .61428 m
.72736 .61803 L
s
.76526 .61428 m
.76526 .61803 L
s
.80315 .61428 m
.80315 .61803 L
s
.84105 .61428 m
.84105 .61803 L
s
.08317 .61428 m
.08317 .61803 L
s
.04527 .61428 m
.04527 .61803 L
s
.00738 .61428 m
.00738 .61803 L
s
.91683 .61428 m
.91683 .61803 L
s
.95473 .61428 m
.95473 .61803 L
s
.99262 .61428 m
.99262 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03826 m
1 .03826 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .22661 m
1 .22661 L
s
.99375 .32079 m
1 .32079 L
s
.99375 .41497 m
1 .41497 L
s
.99375 .50914 m
1 .50914 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .05709 m
1 .05709 L
s
.99625 .07593 m
1 .07593 L
s
.99625 .09476 m
1 .09476 L
s
.99625 .1136 m
1 .1136 L
s
.99625 .15127 m
1 .15127 L
s
.99625 .17011 m
1 .17011 L
s
.99625 .18894 m
1 .18894 L
s
.99625 .20778 m
1 .20778 L
s
.99625 .24545 m
1 .24545 L
s
.99625 .26428 m
1 .26428 L
s
.99625 .28312 m
1 .28312 L
s
.99625 .30195 m
1 .30195 L
s
.99625 .33962 m
1 .33962 L
s
.99625 .35846 m
1 .35846 L
s
.99625 .37729 m
1 .37729 L
s
.99625 .39613 m
1 .39613 L
s
.99625 .4338 m
1 .4338 L
s
.99625 .45264 m
1 .45264 L
s
.99625 .47147 m
1 .47147 L
s
.99625 .49031 m
1 .49031 L
s
.99625 .52798 m
1 .52798 L
s
.99625 .54681 m
1 .54681 L
s
.99625 .56565 m
1 .56565 L
s
.99625 .58448 m
1 .58448 L
s
.99625 .01942 m
1 .01942 L
s
.99625 .00059 m
1 .00059 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02499 .60287 L
.02605 .60167 L
.02729 .59936 L
.02846 .59627 L
.03053 .58863 L
.03279 .57731 L
.03527 .56137 L
.0379 .54074 L
.04262 .49517 L
.06244 .24024 L
.0721 .12538 L
.07753 .07575 L
.08011 .05701 L
.0825 .04261 L
.08529 .02954 L
.08677 .0243 L
.08834 .01998 L
.08906 .01844 L
.08984 .01707 L
.09058 .01607 L
.09126 .01539 L
.09254 .01475 L
.09319 .01473 L
.0939 .01495 L
.09461 .01542 L
.09529 .01609 L
.09656 .01791 L
.09793 .02068 L
.09942 .02459 L
.1021 .03383 L
.10458 .04462 L
.11433 .1014 L
.12483 .16853 L
.12966 .19407 L
.1323 .20538 L
.13475 .21393 L
.13685 .21959 L
.13803 .22205 L
.13909 .22384 L
.14027 .2253 L
.14154 .22627 L
.14274 .22661 L
.14385 .22642 L
.14498 .22572 L
.14602 .22465 L
.14722 .22289 L
.14836 .22071 L
.15038 .21567 L
.15258 .20852 L
Mistroke
.15756 .18668 L
.16218 .16081 L
.17152 .10057 L
.17642 .06989 L
.1816 .04246 L
.18423 .03146 L
.18563 .02664 L
.18712 .02231 L
.18849 .01914 L
.18974 .01697 L
.191 .0155 L
.19219 .01481 L
.1934 .0148 L
.19467 .01558 L
.19577 .01691 L
.19697 .01908 L
.19826 .02225 L
.19965 .02664 L
.20216 .03717 L
.20442 .0495 L
.2069 .06598 L
.21188 .10815 L
.22078 .20819 L
.23174 .35434 L
.24207 .48399 L
.24658 .5298 L
.25135 .56757 L
.25384 .58226 L
.25516 .58854 L
.25658 .59406 L
.25788 .59802 L
.25907 .60068 L
.26026 .60243 L
.26139 .60323 L
.26255 .60318 L
.26363 .60234 L
.26482 .60054 L
.2661 .59756 L
.26737 .59357 L
.26871 .58825 L
.27111 .57599 L
.27541 .54565 L
.28011 .50153 L
.30049 .2409 L
.30532 .18001 L
.31056 .12169 L
.31518 .07932 L
.32008 .04546 L
.32279 .03197 L
.32433 .02604 L
Mistroke
.32578 .02162 L
.32711 .01854 L
.32832 .01652 L
.32899 .01573 L
.32972 .01513 L
.3304 .0148 L
.33104 .01472 L
.33235 .01516 L
.33358 .01631 L
.33468 .01795 L
.33587 .02032 L
.33855 .02784 L
.34102 .03718 L
.35088 .09146 L
.36146 .15977 L
.36658 .18836 L
.3691 .20009 L
.37143 .20925 L
.3735 .21587 L
.37579 .22141 L
.37697 .22351 L
.37809 .225 L
.37926 .22605 L
.38053 .22658 L
.38168 .22651 L
.38292 .22585 L
.38408 .22469 L
.38514 .22318 L
.38639 .22085 L
.38774 .21768 L
.39018 .21025 L
.39547 .1876 L
.40035 .16037 L
.40911 .10384 L
.41394 .07334 L
.41852 .04808 L
.42094 .03694 L
.42359 .02706 L
.42475 .02355 L
.42599 .02041 L
.42716 .01805 L
.42822 .01645 L
.42939 .01527 L
.43047 .01476 L
.43165 .01485 L
.4329 .01571 L
.43398 .0171 L
.435 .01894 L
.43611 .02157 L
.43729 .02511 L
Mistroke
.43996 .03575 L
.44285 .05153 L
.4481 .09097 L
.45322 .14141 L
.45794 .19653 L
.46772 .32573 L
.47825 .46205 L
.48334 .51718 L
.48818 .55878 L
.49029 .57296 L
.49253 .58523 L
.49382 .5909 L
.49499 .59514 L
.49617 .59852 L
.49728 .60089 L
.49841 .60249 L
.49947 .60323 L
.50063 .60319 L
.50188 .60216 L
.50318 .6 L
.50442 .59694 L
.50553 .59335 L
.50674 .58856 L
.50893 .57758 L
.51126 .56277 L
.51544 .5287 L
.52479 .42498 L
.5351 .28739 L
.54452 .16694 L
.54966 .11171 L
.55444 .0702 L
.55716 .05146 L
.55963 .03772 L
.56238 .02621 L
.56389 .02158 L
.56457 .01989 L
.56532 .01831 L
.56653 .01637 L
.56781 .01513 L
.56899 .01472 L
.5701 .01496 L
.57141 .01601 L
.5726 .01766 L
.57398 .02036 L
.57529 .02367 L
.57789 .03227 L
.58033 .04257 L
.5849 .06648 L
.59513 .13172 L
.6039 .18442 L
Mistroke
.60631 .19615 L
.60888 .20688 L
.61111 .21443 L
.61352 .22066 L
.61489 .22323 L
.61616 .22497 L
.61736 .22605 L
.61864 .22658 L
.61979 .2265 L
.62086 .22596 L
.62204 .22485 L
.62331 .22306 L
.62456 .22068 L
.62593 .21741 L
.6287 .20878 L
.63363 .18728 L
.65212 .07284 L
.65741 .0442 L
.66001 .03301 L
.66241 .02481 L
.66459 .01932 L
.66569 .01734 L
.6669 .01578 L
.66811 .01491 L
.66941 .01476 L
.67064 .01538 L
.67176 .01662 L
.67305 .01886 L
.67443 .02219 L
.67691 .03071 L
.67957 .04348 L
.68251 .06188 L
.68777 .10533 L
.69272 .15704 L
.71116 .39736 L
.71621 .46053 L
.72162 .51895 L
.72424 .54272 L
.72672 .56195 L
.72893 .57621 L
.73018 .58304 L
.73136 .58857 L
.73262 .59356 L
.73378 .59724 L
.73502 .60022 L
.7357 .60144 L
.73635 .60232 L
.73749 .6032 L
.73855 .60325 L
.73971 .60246 L
Mistroke
.74095 .60064 L
.74166 .59917 L
.7423 .59753 L
.74377 .59284 L
.74642 .58093 L
.74882 .56643 L
.75137 .54754 L
.76142 .44316 L
.77245 .29745 L
.78248 .16855 L
.78741 .1151 L
.79197 .07455 L
.79446 .05655 L
.79721 .04033 L
.79998 .02801 L
.80149 .02297 L
.80291 .01934 L
.80413 .01706 L
.80542 .0155 L
.80651 .01483 L
.80771 .01478 L
.80901 .01551 L
.80973 .01627 L
.81039 .01717 L
.81168 .01948 L
.81289 .02232 L
.81528 .02969 L
.81752 .03851 L
.82261 .06428 L
.83291 .12964 L
.84174 .18305 L
.84416 .19502 L
.84673 .20594 L
.84896 .21368 L
.85136 .2201 L
.85283 .22297 L
.85347 .22397 L
.85418 .22488 L
.85546 .22606 L
.85617 .22643 L
.85682 .22659 L
.85808 .22644 L
.85921 .22577 L
.86053 .22436 L
.86177 .22242 L
.86297 .22001 L
.86423 .21686 L
.86651 .20979 L
.87165 .18766 L
.88047 .13557 L
Mistroke
.89019 .07295 L
.89538 .04481 L
.89794 .03368 L
.90032 .02538 L
.90246 .0198 L
.90366 .01754 L
.90474 .01605 L
.90594 .01504 L
.90724 .01472 L
.90846 .01518 L
.90958 .01626 L
.91079 .01815 L
.91208 .02102 L
.9133 .02453 L
.91442 .02841 L
.91714 .04069 L
.91973 .05592 L
.92486 .09605 L
.93045 .153 L
.94982 .40473 L
.95513 .47008 L
.96085 .52967 L
.96348 .55203 L
.96625 .57157 L
.96862 .58474 L
.96987 .59034 L
.97121 .59523 L
.97191 .59732 L
.97256 .59901 L
.97379 .60143 L
.97494 .60281 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.0147151 0.294302 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.04762 .01472 m
.04762 .01472 L
s
.07143 .01472 m
.07143 .01472 L
s
.09524 .01472 m
.09524 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.14286 .01472 m
.14286 .01472 L
s
.16667 .01472 m
.16667 .01472 L
s
.19048 .01472 m
.19048 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.2381 .01472 m
.2381 .01472 L
s
.2619 .01472 m
.2619 .01472 L
s
.28571 .01472 m
.28571 .01472 L
s
.30952 .01472 m
.30952 .01472 L
s
.33333 .01472 m
.33333 .01472 L
s
.35714 .01472 m
.35714 .01472 L
s
.38095 .01472 m
.38095 .01472 L
s
.40476 .01472 m
.40476 .01472 L
s
.42857 .01472 m
.42857 .01472 L
s
.45238 .01472 m
.45238 .30902 L
s
.47619 .01472 m
.47619 .30902 L
s
.5 .01472 m
.5 .30902 L
s
.52381 .01472 m
.52381 .30902 L
s
.54762 .01472 m
.54762 .30902 L
s
.57143 .01472 m
.57143 .01472 L
s
.59524 .01472 m
.59524 .01472 L
s
.61905 .01472 m
.61905 .01472 L
s
.64286 .01472 m
.64286 .01472 L
s
.66667 .01472 m
.66667 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.71429 .01472 m
.71429 .01472 L
s
.7381 .01472 m
.7381 .01472 L
s
.7619 .01472 m
.7619 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.80952 .01472 m
.80952 .01472 L
s
.83333 .01472 m
.83333 .01472 L
s
.85714 .01472 m
.85714 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.90476 .01472 m
.90476 .01472 L
s
.92857 .01472 m
.92857 .01472 L
s
.95238 .01472 m
.95238 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.04762 .01472 Mdot
.07143 .01472 Mdot
.09524 .01472 Mdot
.11905 .01472 Mdot
.14286 .01472 Mdot
.16667 .01472 Mdot
.19048 .01472 Mdot
.21429 .01472 Mdot
.2381 .01472 Mdot
.2619 .01472 Mdot
.28571 .01472 Mdot
.30952 .01472 Mdot
.33333 .01472 Mdot
.35714 .01472 Mdot
.38095 .01472 Mdot
.40476 .01472 Mdot
.42857 .01472 Mdot
.45238 .30902 Mdot
.47619 .30902 Mdot
.5 .30902 Mdot
.52381 .30902 Mdot
.54762 .30902 Mdot
.57143 .01472 Mdot
.59524 .01472 Mdot
.61905 .01472 Mdot
.64286 .01472 Mdot
.66667 .01472 Mdot
.69048 .01472 Mdot
.71429 .01472 Mdot
.7381 .01472 Mdot
.7619 .01472 Mdot
.78571 .01472 Mdot
.80952 .01472 Mdot
.83333 .01472 Mdot
.85714 .01472 Mdot
.88095 .01472 Mdot
.90476 .01472 Mdot
.92857 .01472 Mdot
.95238 .01472 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.132436 0.0941768 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03826 -12 -4.5 ]
[-0.0125 .03826 0 4.5 ]
[-0.0125 .13244 -6 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .22661 -6 -4.5 ]
[-0.0125 .22661 0 4.5 ]
[-0.0125 .32079 -6 -4.5 ]
[-0.0125 .32079 0 4.5 ]
[-0.0125 .41497 -6 -4.5 ]
[-0.0125 .41497 0 4.5 ]
[-0.0125 .50914 -6 -4.5 ]
[-0.0125 .50914 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03826 m
.00625 .03826 L
s
[(-1)] -0.0125 .03826 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(0)] -0.0125 .13244 1 0 Mshowa
0 .22661 m
.00625 .22661 L
s
[(1)] -0.0125 .22661 1 0 Mshowa
0 .32079 m
.00625 .32079 L
s
[(2)] -0.0125 .32079 1 0 Mshowa
0 .41497 m
.00625 .41497 L
s
[(3)] -0.0125 .41497 1 0 Mshowa
0 .50914 m
.00625 .50914 L
s
[(4)] -0.0125 .50914 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(5)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .05709 m
.00375 .05709 L
s
0 .07593 m
.00375 .07593 L
s
0 .09477 m
.00375 .09477 L
s
0 .1136 m
.00375 .1136 L
s
0 .15127 m
.00375 .15127 L
s
0 .17011 m
.00375 .17011 L
s
0 .18894 m
.00375 .18894 L
s
0 .20778 m
.00375 .20778 L
s
0 .24545 m
.00375 .24545 L
s
0 .26428 m
.00375 .26428 L
s
0 .28312 m
.00375 .28312 L
s
0 .30195 m
.00375 .30195 L
s
0 .33963 m
.00375 .33963 L
s
0 .35846 m
.00375 .35846 L
s
0 .3773 m
.00375 .3773 L
s
0 .39613 m
.00375 .39613 L
s
0 .4338 m
.00375 .4338 L
s
0 .45264 m
.00375 .45264 L
s
0 .47147 m
.00375 .47147 L
s
0 .49031 m
.00375 .49031 L
s
0 .52798 m
.00375 .52798 L
s
0 .54681 m
.00375 .54681 L
s
0 .56565 m
.00375 .56565 L
s
0 .58448 m
.00375 .58448 L
s
0 .01942 m
.00375 .01942 L
s
0 .00059 m
.00375 .00059 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03826 m
1 .03826 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .22661 m
1 .22661 L
s
.99375 .32079 m
1 .32079 L
s
.99375 .41497 m
1 .41497 L
s
.99375 .50914 m
1 .50914 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .05709 m
1 .05709 L
s
.99625 .07593 m
1 .07593 L
s
.99625 .09477 m
1 .09477 L
s
.99625 .1136 m
1 .1136 L
s
.99625 .15127 m
1 .15127 L
s
.99625 .17011 m
1 .17011 L
s
.99625 .18894 m
1 .18894 L
s
.99625 .20778 m
1 .20778 L
s
.99625 .24545 m
1 .24545 L
s
.99625 .26428 m
1 .26428 L
s
.99625 .28312 m
1 .28312 L
s
.99625 .30195 m
1 .30195 L
s
.99625 .33963 m
1 .33963 L
s
.99625 .35846 m
1 .35846 L
s
.99625 .3773 m
1 .3773 L
s
.99625 .39613 m
1 .39613 L
s
.99625 .4338 m
1 .4338 L
s
.99625 .45264 m
1 .45264 L
s
.99625 .47147 m
1 .47147 L
s
.99625 .49031 m
1 .49031 L
s
.99625 .52798 m
1 .52798 L
s
.99625 .54681 m
1 .54681 L
s
.99625 .56565 m
1 .56565 L
s
.99625 .58448 m
1 .58448 L
s
.99625 .01942 m
1 .01942 L
s
.99625 .00059 m
1 .00059 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .22661 m
.02499 .2266 L
.02605 .22655 L
.02729 .22646 L
.02846 .22635 L
.03053 .22606 L
.03279 .22562 L
.03527 .225 L
.0379 .22418 L
.04262 .22229 L
.05205 .21695 L
.06244 .20875 L
.0842 .18467 L
.10458 .15551 L
.14335 .09263 L
.16306 .06269 L
.17347 .04881 L
.18458 .03611 L
.19538 .02625 L
.20517 .01975 L
.2099 .01753 L
.21238 .01661 L
.21501 .01583 L
.21731 .01532 L
.21862 .01509 L
.21984 .01493 L
.22096 .01482 L
.22199 .01476 L
.22317 .01472 L
.22428 .01472 L
.22542 .01477 L
.22665 .01486 L
.22781 .01499 L
.22887 .01515 L
.23134 .01565 L
.23394 .01638 L
.23648 .01731 L
.23884 .01836 L
.24419 .02142 L
.2531 .02859 L
.26261 .03915 L
.27286 .05382 L
.28396 .07349 L
.30411 .11849 L
.34503 .23884 L
.38443 .37147 L
.42232 .48855 L
.44177 .53667 L
.45261 .55855 L
.46266 .57523 L
Mistroke
.47279 .58829 L
.47814 .59358 L
.48384 .59798 L
.48645 .59956 L
.48927 .60096 L
.49194 .60199 L
.4932 .60237 L
.49438 .60267 L
.49555 .60291 L
.4966 .60308 L
.49778 .60322 L
.49903 .6033 L
.50024 .60332 L
.50155 .60327 L
.50279 .60316 L
.50394 .603 L
.50512 .60278 L
.50636 .60249 L
.50859 .60181 L
.51098 .60085 L
.51359 .59954 L
.51828 .5965 L
.52264 .59288 L
.53261 .5818 L
.54326 .56585 L
.56464 .52199 L
.58481 .46848 L
.62332 .34537 L
.6643 .20885 L
.68469 .14811 L
.70375 .09958 L
.72205 .06236 L
.73225 .04608 L
.74169 .034 L
.75185 .02429 L
.75721 .02053 L
.75995 .01897 L
.76291 .01757 L
.76547 .01658 L
.76783 .01586 L
.77009 .01533 L
.77122 .01513 L
.77246 .01495 L
.77317 .01488 L
.77385 .01482 L
.7751 .01474 L
.77581 .01472 L
.77646 .01472 L
.77717 .01472 L
.77793 .01475 L
Mistroke
.77918 .01483 L
.78035 .01495 L
.78164 .01513 L
.78302 .01538 L
.78556 .01598 L
.78827 .01683 L
.79313 .01888 L
.79892 .02216 L
.80417 .02589 L
.82426 .04604 L
.84352 .07225 L
.86435 .10513 L
.90537 .17038 L
.92581 .19682 L
.93579 .20713 L
.94488 .21477 L
.95264 .21986 L
.96 .2234 L
.96403 .2248 L
.96775 .22574 L
.9697 .2261 L
.97082 .22626 L
.97185 .22638 L
.97292 .22648 L
.97409 .22656 L
.97511 .2266 L
.97619 .22661 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00:?ooool3o`0001gooooo0ol0000Kooooo`Go0000
6Oooool2o`0001_ooooo1Ol0000Mooooo`?o00006oooool3o`0004_ooooo0ol00004ooooo`;o0000
8Oooool3o`0002?ooooo0_l0000Tooooo`?o00008Oooool3o`0000Cooooo0_l0000Vooooo`009ooo
ool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooooooool06oooool01?l0003ooooo
ooooool0000Hooooo`04o`000?ooooooooooo`0001_ooooo00Co0000oooooooooooo00007_ooool0
0ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool00000Boooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0001oooooo00Go0000ooooooooooooooooo`00000Qooooo`04
o`000?ooooooooooo`0002;ooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00009Oooool0027ooooo1Ol000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo01;ooooo1Ol000000ooooooo0000o`000003o`0001Gooooo1Ol00003
ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00007?ooool00ol0003ooooooooo
o`0Kooooo`Go00006_ooool01Ol0003ooooooooooooooooo000004?ooooo1Ol00003ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00006Oooool5o`0000Gooooo00?o0000oooooooo
ool07oooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Uooooo`009oooool4o`0001_ooooo00Co0000oooo
oooooooo00007oooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0001gooooo00?o
0000ooooooooool06_ooool01?l0003oooooooooool0000Kooooo`Co0000C?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool07oooool01?l0003o
ooooooooool0000Vooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Uooooo`009oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo0000
01cooooo00Go0000ooooooooooooooooo`00000Hooooo`04o`000?ooooooooooo`0001[ooooo00Go
0000ooooooooooooooooo`00000Looooo`03o`000?oooooo000001_ooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001oooooo1?l0000Rooooo`04
o`000?ooooooooooo`0002;ooooo1?l0000Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00009Oooool002Sooooo00?o0000ooooooooool07Oooool2o`0001cooooo00Go0000oooo
ooooooooooooo`00000Hooooo`04o`000?ooooooooooo`0001[ooooo00Go0000oooooooooooooooo
o`00000Mooooo`;o00007?ooool00ol0003oooooooooo`1;ooooo`;o00001?ooool01?l0003ooooo
ooooool0000Oooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00008_ooool00ol0
003oooooooooo`0Rooooo`;o00001?ooool01?l0003oooooooooool0000Uooooo`00:Oooool2o`00
01kooooo00?o0000ooooooooool06oooool3o`0001[ooooo0_l0000Looooo`?o00007oooool00ol0
003oooooooooo`0Kooooo`;o0000C?ooool00ol0003oooooooooo`03ooooo`;o00008?ooool5o`00
02;ooooo0_l0000Sooooo`Go00008Oooool00ol0003oooooooooo`03ooooo`;o00009_ooool00?oo
oooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool001kooooocol0000[oooo
om3o00004?ooool001kooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0000[ooooo`03
o`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00000@ooooo`00
7_ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0Mooooo`?oo`009_oo
ool3ool003Kooooo1?oo000Vooooo`?oo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo013ooooo0_oo000Cooooo`03ool00?oooooooooo01Wooooo0_oo000Cooooo`;oo`006_oo
ool2ool001?ooooo0_oo000Kooooo`;oo`004_ooool2ool001;ooooo00?o0000ooooooooool03_oo
ool001kooooo00?o0000ooooooooool07?ooool2ool000;ooooo00?oo`00ooooooooool08_ooool2
ool000;ooooo00?oo`00ooooooooool0<_ooool2ool000;ooooo00?oo`00ooooooooool08oooool0
1?oo003ooooooooooooo000Nooooo`;o0000:oooool2o`00013ooooo0ooo000Booooo`03ool00?oo
ooooo`0001[ooooo0ooo000Aooooo`03ool00?ooooooo`0001[ooooo00?oo`00oooooooo00004_oo
ool2ool001[ooooo00?oo`00oooooooo00004_ooool3ool0013ooooo0_l0000@ooooo`005_ooool3
o`0000Gooooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo027ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0aooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo01cooooo00?o0000ooooooooool08_ooool3o`0000Cooooo00?o0000ooooooooool03oooool0
1?oo003ooooooooooooo000Aooooo`03ool00?ooooooo`0001Wooooo0_oo00000oooooooo`00oooo
o`0@ooooo`04ool00?ooooooo`00ool001Sooooo0_oo00000oooooooo`00ooooo`0@ooooo`04ool0
0?ooooooooooool001Wooooo00?oo`00oooooooo00004Oooool01?oo003ooooooooooooo000Aoooo
o`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool06oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo023ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`0`ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool08?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01_ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo00Coo`00oooooooo
ooooo`004Oooool00ooo003oooooool0000Iooooo`04ool00?ooooooooooool0017ooooo00Coo`00
ooooooooooooo`006?ooool01?oo003ooooooooooooo000Aooooo`04ool00?ooooooooooool001So
oooo00Goo`00ooooooooooooooooool0000@ooooo`04ool00?ooooooooooool0017ooooo00?o0000
ooooooooool03_ooool000oooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01oooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`0_ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool08?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01_ooooo00?o0000oooo
ooooool06oooool5o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?oooo
o`04ool00?ooooooooooool0013ooooo00Coo`00ooooooooooooo`006Oooool01?oo003ooooooooo
oooo000Aooooo`04ool00?ooooooooooool001Sooooo00Goo`00ooooooooooooooooool0000@oooo
o`04ool00?ooooooooooool001Sooooo00Goo`00ooooooooooooooooool0000@ooooo`04ool00?oo
ooooooooool0017ooooo00?o0000ooooooooool03_ooool001Oooooo00?o0000ooooooooool01?oo
ool2o`0001cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Mooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool0;oooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo01kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Iooooo`;o00009Ooo
ool00ol0003oooooooooo`03ooooo`;o00003oooool01Ooo003oooooooooooooooooo`00013ooooo
00Goo`00ooooooooooooooooool0000Hooooo`05ool00?oooooooooooooooooo00003oooool01Ooo
003oooooooooooooooooo`0001Sooooo00Goo`00ooooooooooooooooool0000@ooooo`05ool00?oo
oooooooooooooooo00005oooool01Ooo003oooooooooooooooooo`00013ooooo00Goo`00oooooooo
ooooooooool0000?ooooo`;o00004?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Jooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool07Oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo02gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`0Nooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool06_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00gooooo00Goo`00ooooooooooooooooool0000Goooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03Oooool01Ooo003ooooooooooooooooo
o`0001Sooooo00Goo`00ooooooooooooooooool0000?ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool05Oooool01Ooo003oooooooooooooooooo`0000oooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo000Fooooo`;o00001_oo
ool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool06ooo
ool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo02gooooo00?oo`00ooooooooool01ooo
ool00ooo003oooooooooo`0Looooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool06_oo
ool00ol0003oooooooooo`0Rooooo`;o00001Oooool00ol0003oooooooooo`0>ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool03Oooool01Ooo003oooooooooooooooooo`0001Oooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool05?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00gooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo
00003oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03ool0
0?oooooooooo00Oooooo00?oo`00ooooooooool06oooool00ooo003oooooooooo`07ooooo`03ool0
0?oooooooooo02cooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Looooo`03ool0
0?oooooooooo00Oooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00gooooo00Goo`00ooooooooooooooooool0000Gooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00ko
oooo000Nooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool02?ooool00ooo003ooooo
ooooo`0Jooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0;?ooool00ooo003ooooo
ooooo`08ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool02?ooool00ooo003ooooo
ooooo`0Hooooo`;o0000:oooool2o`0000oooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`0=ooooo`05ool00?oooooooooooooooooo00005oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Dooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0<ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool03Oooool2o`00013ooooo000Nooooo`03o`00
0?oooooooooo01Sooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Iooooo`03ool0
0?oooooooooo00Wooooo00?oo`00ooooooooool0:oooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo01[ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Iooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Cooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0;ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool02_oo
ool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0:ooo
ool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool02?oo
ool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooo
oooo01Sooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooo
oooo00[ooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooo
oooo01Wooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Hooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo000Nooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool02oooool00ooo
003oooooooooo`0Gooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0:Oooool00ooo
003oooooooooo`0;ooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool02_ooool00ooo
003oooooooooo`0Gooooo`;o0000:oooool2o`0000kooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0Cooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03Oooool2o`00
013ooooo000Nooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool02oooool00ooo003o
ooooooooo`0Gooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0:Oooool00ooo003o
ooooooooo`0;ooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool02_ooool00ooo003o
ooooooooo`0Hooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02_ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo01Oooooo
00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00_ooooo
00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Hooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool03Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00_ooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool02_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool04oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00[ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
000Nooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool03Oooool00ooo003ooooooooo
o`0Eooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0:?ooool00ooo003ooooooooo
o`0=ooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool02oooool00ooo003ooooooooo
o`0Hooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`0Booooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02Oooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`09ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool04oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`0=ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo01Oooooo00?oo`00
ooooooooool03Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00gooooo00?oo`00
ooooooooool09oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01Gooooo00?oo`00
ooooooooool03Oooool00ooo003oooooooooo`0Fooooo`;o0000:oooool2o`0000kooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool04_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Wooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01;ooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool03?ooool2o`00013ooooo000Nooooo`03o`000?oooooooooo01Oooooo00?oo`00oooo
ooooool03Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00gooooo00?oo`00oooo
ooooool09oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool03Oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool03Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool02Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01;ooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool04_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo000Nooooo`03
o`000?oooooooooo01Oooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Dooooo`03
ool00?oooooooooo00kooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`0>ooooo`03
ool00?oooooooooo01Cooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Gooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Wooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Aooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo01;ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`09ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Wooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0
3_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0
9oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool0
3_ooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
3?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0
2?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oo
oooooooo01Kooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0Cooooo`03ool00?oo
oooooooo00kooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`0?ooooo`03ool00?oo
oooooooo01?ooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0Eooooo`;o0000:ooo
ool2o`0000gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`09ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`07ooooo`03ool00?oo
oooooooo00Sooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Booooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo01;ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`08ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool03?ooool2o`00013ooooo000Gooooo`;o00001Oooool0
0ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool04_ooool0
0ooo003oooooooooo`0@ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool04?ooool0
0ooo003oooooooooo`0Booooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool05_ooool0
0ol0003oooooooooo`0Sooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooo
oooo00Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo017ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`08ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00gooooo00?o0000ooooooooool03_ooool001Kooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0Fooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool04Oooool0
0ooo003oooooooooo`0@ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool04?ooool0
0ooo003oooooooooo`0Aooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool05_ooool0
0ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03?oo
ool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01ooo
ool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool04_oo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo000Fooooo`04o`000?oooooo
ooooo`0000Cooooo0_l0000Fooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool04Ooo
ool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool04?oo
ool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool05Ooo
ool2o`0002Cooooo00Co0000oooooooooooo00000oooool2o`0000gooooo00?oo`00ooooooooool0
1oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
4Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0
1oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0
2oooool2o`00013ooooo000Fooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
5Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0
4Oooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0
4?ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool0
8_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00cooooo00?oo`00oooooooo
ool01oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool04?ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool01oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo017ooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool03?ooool00ol0003oooooooooo`0>ooooo`005_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo01Gooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0@ooooo`03
ool00?oooooooooo017ooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`0Booooo`03
ool00?oooooooooo013ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Eooooo`03
o`000?oooooooooo02;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0<oooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07oooo
o`03ool00?oooooooooo013ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07oooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0Aoooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07oooo
o`03ool00?oooooooooo00cooooo00?o0000ooooooooool03_ooool001Kooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo01;ooooo00?oo`00oooo
ooooool03oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo02Cooooo00?oo`00oooo
ooooool04_ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo01;ooooo00?oo`00oooo
ooooool05Oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool03?ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00Sooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo013ooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00
ooooooooool04?ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Oooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo000Goooo
o`;o00001Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo01?ooooo00?oo`00oooo
ooooool03oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo02?ooooo00?oo`00oooo
ooooool04oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo01;ooooo00?oo`00oooo
ooooool05?ooool2o`0002Gooooo0_l00004ooooo`;o00003Oooool00ooo003oooooooooo`07oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0@oooo
o`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`08oooo
o`03ool00?oooooooooo013ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`08oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0;oooo
o`;o00004?ooool001kooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0Cooooo`03
ool00?oooooooooo00kooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Sooooo`03
ool00?oooooooooo01?ooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Booooo`03
ool00?oooooooooo01Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`03
ool00?oooooooooo00Sooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`08ooooo`03
ool00?oooooooooo00oooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Sooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`08ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0@ooooo`03
ool00?oooooooooo00Sooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`08ooooo`03
ool00?oooooooooo00cooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool0
5?ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0
4oooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool0
3_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0
4?ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
2?ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool0
3_ooool001kooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`0Dooooo`03ool00?oo
oooooooo00gooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Sooooo`03ool00?oo
oooooooo01Cooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Dooooo`03ool00?oo
oooooooo01Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`03ool00?oo
oooooooo00Wooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`08ooooo`03ool00?oo
oooooooo00oooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Sooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`08ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0@ooooo`03ool00?oo
oooooooo00Sooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`08ooooo`03ool00?oo
oooooooo00cooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool05?ooool0
0ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool05?ooool0
0ooo003oooooooooo`0Rooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool03?ooool0
0ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01?ooooo0_l0000[ooooo`;o00003?ooool0
0ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02?ooool0
0ooo003oooooooooo`0?ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`08ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool02?ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool04?ooool0
0ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02?ooool0
0ooo003oooooooooo`0;ooooo`;o00004?ooool001kooooo00?o0000ooooooooool04oooool00ooo
003oooooooooo`0Fooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Qooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool03?ooool00ooo
003oooooooooo`0Dooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0;ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`08ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool03oooool00ooo
003oooooooooo`09ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02?ooool00ooo
003oooooooooo`0@ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`08ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool03_ooool001ko
oooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo00_o
oooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo01Ko
oooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01Co
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00oo
oooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00[o
oooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00co
oooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool04oooool00ooo003ooooo
ooooo`0Fooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool05_ooool00ooo003ooooo
ooooo`0Qooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool02_ooool00ooo003ooooo
ooooo`0Eooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0;ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`09ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool02_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool03oooool00ooo003ooooo
ooooo`09ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02Oooool00ooo003ooooo
ooooo`0@ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`09ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool03_ooool001kooooo00?o
0000ooooooooool04oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Wooooo00?o
o`00ooooooooool05_ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo01Kooooo00?o
o`00ooooooooool02_ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01;ooooo0_l0
000[ooooo`;o00003?ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool02_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00[ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00oooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Wooooo00?o
o`00ooooooooool04?ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool02_ooool00ooo003oooooooooo`0:ooooo`;o00004?ooool001kooooo00?o0000
ooooooooool04oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Wooooo00?oo`00
ooooooooool05_ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo01Oooooo00?oo`00
ooooooooool02?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01?ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00[ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00kooooo00?oo`00
ooooooooool02_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00?oo`00
ooooooooool03oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool02_ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo00[ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00_ooooo00?o0000
ooooooooool03_ooool001kooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0Goooo
o`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Poooo
o`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Goooo
o`03ool00?oooooooooo01?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0;oooo
o`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0:oooo
o`03ool00?oooooooooo00kooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`09oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0?oooo
o`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0:oooo
o`03ool00?oooooooooo00_ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000oooooooo
ool04oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool06?ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo01Sooooo00?oo`00oooooooo
ool01oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01?ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00_ooooo00Goo`00oooooooo
ooooooooool0000=ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool02_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool03_ooool00ooo
003oooooooooo`0:ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02oooool00ooo
003oooooooooo`0?ooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool0000=
ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000oooo
ooooool04_ooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool06Oooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo01Wooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01;ooooo0_l0000[oooo
o`;o00003?ooool00ooo003oooooooooo`0;ooooo`05ool00?oooooooooooooooooo00003Oooool0
0ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00_ooooo00Goo`00ooooooooooooooooool0
000=ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool02oooool01Ooo003ooooooooo
ooooooooo`0000gooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0;ooooo`05ool0
0?oooooooooooooooooo00003Oooool00ooo003oooooooooo`0:ooooo`;o00004?ooool001Kooooo
0ol00005ooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool06_ooool00ooo003ooooo
ooooo`04ooooo`;oo`006oooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo01[ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Jooooo`03ool00?oooooooooo01;ooooo
00?o0000ooooooooool08_ooool3o`0000Cooooo00?o0000ooooooooool02oooool00ooo003ooooo
ooooo`0;ooooo`05ool00?oooooooooooooooooo00003Oooool00ooo003oooooooooo`0=ooooo`03
ool00?oooooooooo00cooooo00Goo`00ooooooooooooooooool0000=ooooo`03ool00?oooooooooo
00kooooo00?oo`00ooooooooool02oooool01Ooo003oooooooooooooooooo`0000gooooo00?oo`00
ooooooooool03_ooool00ooo003oooooooooo`0<ooooo`04ool00?ooooooooooool000gooooo00?o
o`00ooooooooool02oooool00ol0003oooooooooo`0>ooooo`005oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0J
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool06oooool00ooo003oooooooooo`0B
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:
ooooo`03ool00?oooooooooo00cooooo00Coo`00ooooooooooooo`003_ooool00ooo003ooooooooo
o`0=ooooo`03ool00?oooooooooo00cooooo00Coo`00ooooooooooooo`003_ooool00ooo003ooooo
ooooo`0>ooooo`03ool00?oooooooooo00_ooooo00Goo`00ooooooooooooooooool0000=ooooo`03
ool00?oooooooooo00kooooo00?oo`00ooooooooool03?ooool01?oo003ooooooooooooo000=oooo
o`03ool00?oooooooooo00_ooooo00?o0000ooooooooool03_ooool001Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo01_ooooo0_oo0003ooooo`03
ool00?oooooooooo01_ooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0Kooooo`;o
o`000_ooool00ooo003oooooooooo`0Looooo`03ool00?oooooooooo01;ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?oo`00oooooooo
ool03Oooool00ooo003oooooool0000>ooooo`03ool00?oooooooooo00gooooo00?oo`00oooooooo
ool03Oooool00ooo003oooooool0000>ooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo
ool03?ooool00ooo003oooooool0000>ooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo
ool03?ooool4ool000gooooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0>ooooo`00
5oooool00ol0003oooooooooo`04ooooo`;o00004oooool00ooo003oooooooooo`0Mooooo`?oo`00
7oooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo01gooooo0ooo000Oooooo`03ool0
0?oooooooooo017ooooo0_l0000Uooooo`03o`000?oooooooooo00?ooooo0_l0000;ooooo`03ool0
0?oooooooooo00gooooo0_oo000?ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0
3Oooool3ool000kooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0=ooooo`;oo`00
3_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00gooooo0_oo000>ooooo`03ool0
0?oooooooooo00[ooooo0_l0000@ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo00?oo`00ooooooooool0?oooool00ooo003oooooooooo`0Mooooo`03ool00?oo
oooooooo03oooooo00?oo`00ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0Nooooo`03ool00?oo
oooooooo00gooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0=ooooo`03ool00?oo
oooooooo01gooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Mooooo`03ool00?oo
oooooooo00_ooooo00?o0000ooooooooool03_ooool001Kooooo0_l00006ooooo`03o`000?oooooo
oooo017ooooo00?oo`00ooooooooool0@?ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooo
oooo043ooooo00?oo`00ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`;o00001Oooool0
0ol0003oooooooooo`0:ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool03Oooool0
0ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool07Oooool0
0ooo003oooooooooo`0>ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool02oooool0
0ol0003oooooooooo`0>ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
017ooooo00?oo`00ooooooooool0@?ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo
043ooooo00?oo`00ooooooooool04Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo
00gooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo
01gooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo
00_ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool04Oooool00ooo003o
ooooooooo`10ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0@?ooool00ooo003o
ooooooooo`0@ooooo`;o0000:oooool2o`0000_ooooo00?oo`00ooooooooool07oooool00ooo003o
ooooooooo`0<ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool03Oooool00ooo003o
ooooooooo`0Mooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool07Oooool00ooo003o
ooooooooo`0:ooooo`;o00004?ooool001kooooo00?o0000ooooooooool04Oooool00ooo003ooooo
ooooo`10ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0@?ooool00ooo003ooooo
ooooo`0Aooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ooo003ooooo
ooooo`0Oooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool07oooool00ooo003ooooo
ooooo`0=ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool03Oooool00ooo003ooooo
ooooo`0Nooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool03_ooool001kooooo00?o
0000ooooooooool04Oooool00ooo003oooooooooo`11ooooo`03ool00?oooooooooo01_ooooo00?o
o`00ooooooooool0@Oooool00ooo003oooooooooo`0Aooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool02_ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00cooooo00?o
o`00ooooooooool07oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01kooooo00?o
o`00ooooooooool03Oooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo00[ooooo00?o
0000ooooooooool03_ooool001kooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`11
ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool0@Oooool00ooo003oooooooooo`0A
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0O
ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0<
ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0N
ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000oooo
ooooool04Oooool00ooo003oooooooooo`11ooooo`03ool00?oooooooooo01_ooooo00?oo`00oooo
ooooool0@Oooool00ooo003oooooooooo`0@ooooo`;o0000:oooool2o`0000_ooooo00?oo`00oooo
ooooool07oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01oooooo00?oo`00oooo
ooooool03?ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00gooooo00?oo`00oooo
ooooool07_ooool00ooo003oooooooooo`09ooooo`;o00004?ooool001kooooo00?o0000oooooooo
ool04?ooool00ooo003oooooooooo`12ooooo`03ool00?oooooooooo01_ooooo00?oo`00oooooooo
ool0@_ooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool02_ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00cooooo00?oo`00oooooooo
ool07oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01oooooo00?oo`00oooooooo
ool03?ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00[ooooo00?o0000oooooooo
ool03_ooool001kooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`12ooooo`03ool0
0?oooooooooo01_ooooo00?oo`00ooooooooool0@_ooool00ooo003oooooooooo`0@ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0Pooooo`03ool0
0?oooooooooo00cooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0<ooooo`03ool0
0?oooooooooo01oooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Oooooo`03ool0
0?oooooooooo00[ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool04?oo
ool00ooo003oooooooooo`12ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool0@_oo
ool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02Ooo
ool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool08?oo
ool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool03?oo
ool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool03_oo
ool001kooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`12ooooo`03ool00?oooooo
oooo01[ooooo00?oo`00ooooooooool0@oooool00ooo003oooooooooo`0?ooooo`;o0000:oooool2
o`0000[ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooo
oooo023ooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooo
oooo00cooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`09ooooo`;o00004?ooool0
01kooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`13ooooo`03ool00?oooooooooo
01Wooooo00?oo`00ooooooooool0@oooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo
00_ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo
01oooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo
00[ooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool04?ooool00ooo003o
ooooooooo`13ooooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool0@oooool00ooo003o
ooooooooo`0@ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02Oooool00ooo003o
ooooooooo`0Pooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool08Oooool00ooo003o
ooooooooo`0;ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool03?ooool00ooo003o
ooooooooo`0Oooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool03_ooool001kooooo
00?o0000ooooooooool04?ooool00ooo003oooooooooo`13ooooo`03ool00?oooooooooo01Wooooo
00?oo`00ooooooooool0@oooool00ooo003oooooooooo`0?ooooo`;o0000:oooool2o`0000[ooooo
00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo027ooooo
00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00cooooo
00?oo`00ooooooooool07oooool00ooo003oooooooooo`09ooooo`;o00004?ooool001kooooo00?o
0000ooooooooool03oooool00ooo003oooooooooo`14ooooo`03ool00?oooooooooo01Wooooo00?o
o`00ooooooooool0A?ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool02Oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00_ooooo00?o
o`00ooooooooool08Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo01oooooo00?o
o`00ooooooooool03?ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo00[ooooo00?o
0000ooooooooool03_ooool001Gooooo1Ol00004ooooo`03o`000?oooooooooo00oooooo00?oo`00
ooooooooool0A?ooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo04Cooooo00?oo`00
ooooooooool03oooool00ol0003oooooooooo`0Qooooo`Go00000oooool00ol0003oooooooooo`09
ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Q
ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`0<
ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0>
ooooo`005_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00oooooo00?oo`00
ooooooooool0A?ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo04Gooooo00?oo`00
ooooooooool03oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool02Oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00_ooooo00?o
o`00ooooooooool08Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo023ooooo00?o
o`00ooooooooool02oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00Wooooo00?o
0000ooooooooool03_ooool001Oooooo00?o0000ooooooooool01?ooool2o`00013ooooo00?oo`00
ooooooooool0A?ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo04Gooooo00?oo`00
ooooooooool03_ooool2o`0002Gooooo00?o0000ooooooooool00oooool2o`0000[ooooo00?oo`00
ooooooooool08Oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo027ooooo00?oo`00
ooooooooool02oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00_ooooo00?oo`00
ooooooooool08?ooool00ooo003oooooooooo`08ooooo`;o00004?ooool001Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo04Gooooo00?oo`00oooo
ooooool05oooool00ooo003oooooooooo`15ooooo`03ool00?oooooooooo00oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?oo`00oooo
ooooool08Oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo027ooooo00?oo`00oooo
ooooool02_ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00_ooooo00?oo`00oooo
ooooool08?ooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo000Eooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo
04Gooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`15ooooo`03ool00?oooooooooo
00oooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool02Oooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00[ooooo00?oo`00
ooooooooool08Oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo027ooooo00?oo`00
ooooooooool02oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00Wooooo00?o0000
ooooooooool03_ooool001Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00oooooo00?oo`00ooooooooool0AOooool00ooo003oooooooooo`0Gooooo`03ool00?oooooo
oooo04Gooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0Qooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo027ooooo00?o
o`00ooooooooool02_ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00[ooooo00?o
o`00ooooooooool08Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo023ooooo00?o
o`00ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`005_ooool3o`0000Gooooo00?o0000
ooooooooool03_ooool00ooo003oooooooooo`16ooooo`03ool00?oooooooooo01Oooooo00?oo`00
ooooooooool0A_ooool00ooo003oooooooooo`0=ooooo`;o00009?ooool3o`0000Cooooo0_l00009
ooooo`03ool00?oooooooooo02;ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Q
ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0:
ooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool02?ooool2o`00013ooooo000Noooo
o`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0A_ooool00ooo003oooooooooo`0Foooo
o`03ool00?oooooooooo04Oooooo00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`09oooo
o`03ool00?oooooooooo02;ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Qoooo
o`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`09oooo
o`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo00kooooo00?oo`00oooooooo
ool0A_ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo04Oooooo00?oo`00oooooooo
ool03_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?oo`00oooooooo
ool08_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo02;ooooo00?oo`00oooooooo
ool02_ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00[ooooo00?oo`00oooooooo
ool08Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`00
0?oooooooooo00kooooo00?oo`00ooooooooool0A_ooool00ooo003oooooooooo`0Fooooo`03ool0
0?oooooooooo04Oooooo00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00Sooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo02;ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Qooooo`03ool0
0?oooooooooo00[ooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`09ooooo`03o`00
0?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0Aooo
ool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo04Oooooo00?oo`00ooooooooool03Ooo
ool2o`0002_ooooo0_l00009ooooo`03ool00?oooooooooo02;ooooo00?oo`00ooooooooool02Ooo
ool00ooo003oooooooooo`0Rooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool08Ooo
ool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool02?oo
ool2o`00013ooooo000Nooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0Aoooool0
0ooo003oooooooooo`0Eooooo`03ool00?oooooooooo04Oooooo00?oo`00ooooooooool03_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool08_ooool0
0ooo003oooooooooo`09ooooo`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool02Oooool0
0ooo003oooooooooo`0Qooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool08Oooool0
0ooo003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo
00kooooo00?oo`00ooooooooool0Aoooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
04Oooooo00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00Sooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo
02?ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo
00[ooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo
00kooooo000Nooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0B?ooool00ooo003o
ooooooooo`0Dooooo`03ool00?oooooooooo04Wooooo00?oo`00ooooooooool03Oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool08_ooool00ooo003o
ooooooooo`09ooooo`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool02Oooool00ooo003o
ooooooooo`0Rooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool08Oooool00ooo003o
ooooooooo`09ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo00gooooo
00?oo`00ooooooooool0B?ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo04Wooooo
00?oo`00ooooooooool03?ooool2o`0002_ooooo0_l00009ooooo`03ool00?oooooooooo02;ooooo
00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo00Wooooo
00?oo`00ooooooooool08_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo02;ooooo
00?oo`00ooooooooool01oooool2o`00013ooooo000Nooooo`03o`000?oooooooooo00gooooo00?o
o`00ooooooooool0B?ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo04Wooooo00?o
o`00ooooooooool03Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o
o`00ooooooooool08_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo02?ooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`0Rooooo`03ool00?oooooooooo00Wooooo00?o
o`00ooooooooool08_ooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo000N
ooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0B?ooool00ooo003oooooooooo`0D
ooooo`03ool00?oooooooooo04Wooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`09
ooooo`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0R
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`08
ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo00gooooo00?oo`00oooo
ooooool0BOooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo04Wooooo00?oo`00oooo
ooooool03Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?oo`00oooo
ooooool08oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo02?ooooo00?oo`00oooo
ooooool02Oooool00ooo003oooooooooo`0Rooooo`03ool00?oooooooooo00Wooooo00?oo`00oooo
ooooool08_ooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo000Nooooo`03
o`000?oooooooooo00gooooo00?oo`00ooooooooool0BOooool00ooo003oooooooooo`0Cooooo`03
ool00?oooooooooo04Wooooo00?oo`00ooooooooool03?ooool2o`0002_ooooo0_l00009ooooo`03
ool00?oooooooooo02?ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Sooooo`03
ool00?oooooooooo00Sooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`09ooooo`03
ool00?oooooooooo02;ooooo00?oo`00ooooooooool01oooool2o`00013ooooo000Fooooo`?o0000
1Oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo04Wooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`1;ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool0
8_ooool3o`0000Cooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0Tooooo`03ool0
0?oooooooooo00Sooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`08ooooo`03ool0
0?oooooooooo02?ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Rooooo`03ool0
0?oooooooooo00Sooooo00?o0000ooooooooool03_ooool001Gooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0B_ooool00ooo003ooooo
ooooo`0Booooo`03ool00?oooooooooo04_ooooo00?oo`00ooooooooool03?ooool00ol0003ooooo
ooooo`0Qooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`07ooooo`03
ool00?oooooooooo02Cooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Sooooo`03
ool00?oooooooooo00Sooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`09ooooo`03
ool00?oooooooooo02;ooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`00
6Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0
B_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo04_ooooo00?oo`00ooooooooool0
3?ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool000002Oooool00ooo003o
ooooooooo`0Tooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool09?ooool00ooo003o
ooooooooo`08ooooo`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool02?ooool00ooo003o
ooooooooo`0Sooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool03_ooool001Oooooo
0_l00005ooooo`;o00003Oooool00ooo003oooooooooo`1:ooooo`03ool00?oooooooooo01;ooooo
00?oo`00ooooooooool0Boooool00ooo003oooooooooo`0;ooooo`;o00009Oooool2o`0000Cooooo
0_l00008ooooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool01oooool00ooo003ooooo
ooooo`0Tooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool08oooool00ooo003ooooo
ooooo`08ooooo`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool01oooool2o`00013ooooo
000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ooo003ooooooooo
o`1;ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Boooool00ooo003ooooooooo
o`0<ooooo`03o`000?oooooooooo02Gooooo00Go0000ooooooooooooooooo`000009ooooo`03ool0
0?oooooooooo02Cooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0Tooooo`03ool0
0?oooooooooo00Sooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`08ooooo`03ool0
0?oooooooooo02?ooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`005Ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool03?ooool00ooo003ooooo
ooooo`1;ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Boooool00ooo003ooooo
ooooo`0<ooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Oooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`07ooooo`03
ool00?oooooooooo02Cooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Sooooo`03
ool00?oooooooooo00Sooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`07ooooo`03
o`000?oooooooooo00kooooo000Fooooo`?o00001Oooool00ol0003oooooooooo`0<ooooo`03ool0
0?oooooooooo04_ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1;ooooo`03ool0
0?oooooooooo00cooooo00?o0000ooooooooool08_ooool3o`0000Cooooo00?o0000ooooooooool0
1oooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0
9?ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0
1oooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo00Oooooo00?o0000ooooooooool0
3_ooool001kooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`1;ooooo`03ool00?oo
oooooooo013ooooo00?oo`00ooooooooool0COooool00ooo003oooooooooo`0:ooooo`;o0000:ooo
ool2o`0000Sooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`07ooooo`03ool00?oo
oooooooo02Gooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0Tooooo`03ool00?oo
oooooooo00Oooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`06ooooo`;o00004?oo
ool001kooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`1<ooooo`03ool00?oooooo
oooo013ooooo00?oo`00ooooooooool0COooool00ooo003oooooooooo`0;ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0Tooooo`03ool00?oooooo
oooo00Oooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooo
oooo02Cooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0Tooooo`03ool00?oooooo
oooo00Oooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool02oooool00ooo
003oooooooooo`1=ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0COooool00ooo
003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool00ooo
003oooooooooo`0Tooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool09Oooool00ooo
003oooooooooo`07ooooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool01oooool00ooo
003oooooooooo`0Tooooo`03ool00?oooooooooo00Oooooo00?o0000ooooooooool03_ooool001ko
oooo00?o0000ooooooooool02oooool00ooo003oooooooooo`1=ooooo`03ool00?oooooooooo00oo
oooo00?oo`00ooooooooool0COooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo00Oo
oooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo02Co
oooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo00Oo
oooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool02oooool00ooo003ooooo
ooooo`1=ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0COooool00ooo003ooooo
ooooo`0:ooooo`;o0000:oooool2o`0000Sooooo00?oo`00ooooooooool09Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0Uooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool09?ooool00ooo003ooooo
ooooo`06ooooo`;o00004?ooool001kooooo00?o0000ooooooooool02oooool00ooo003ooooooooo
o`1=ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0COooool00ooo003ooooooooo
o`0;ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool00ooo003ooooooooo
o`0Uooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool09Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool01oooool00ooo003ooooooooo
o`0Uooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool03_ooool001kooooo00?o0000
ooooooooool02oooool00ooo003oooooooooo`1=ooooo`03ool00?oooooooooo00kooooo00?oo`00
ooooooooool0Coooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool01_ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool09Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo02Gooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?o0000
ooooooooool03_ooool001kooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`1=oooo
o`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0Coooool00ooo003oooooooooo`0:oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0Voooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Voooo
o`03ool00?oooooooooo00Kooooo00?o0000ooooooooool03_ooool001kooooo00?o0000oooooooo
ool02_ooool00ooo003oooooooooo`1?ooooo`03ool00?oooooooooo00gooooo00?oo`00oooooooo
ool0Coooool00ooo003oooooooooo`09ooooo`;o0000:oooool2o`0000Oooooo00?oo`00oooooooo
ool09_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo02Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool09_ooool00ooo003oooooooooo`05ooooo`;o00004?ooool001kooooo00?o0000ooooooooool0
2_ooool00ooo003oooooooooo`1?ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0
Coooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
1_ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
9_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool0
3_ooool001kooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`1?ooooo`03ool00?oo
oooooooo00gooooo00?oo`00ooooooooool0Coooool00ooo003oooooooooo`0:ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0Vooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo02Gooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Vooooo`03ool00?oo
oooooooo00Kooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool02_ooool0
0ooo003oooooooooo`1?ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0D?ooool0
0ooo003oooooooooo`08ooooo`;o0000:oooool2o`0000Oooooo00?oo`00ooooooooool09_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`0Uooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool09_ooool0
0ooo003oooooooooo`05ooooo`;o00004?ooool001kooooo00?o0000ooooooooool02_ooool00ooo
003oooooooooo`1?ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0DOooool00ooo
003oooooooooo`09ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01_ooool00ooo
003oooooooooo`0Vooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool09oooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool03_ooool001Oo
oooo0ol00004ooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool0D?ooool00ooo003o
ooooooooo`0;ooooo`03ool00?oooooooooo057ooooo00?oo`00ooooooooool02Oooool00ol0003o
ooooooooo`0Sooooo`?o00000oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo02Ko
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Oo
oooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`006?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0DOooool00ooo003ooooo
ooooo`0;ooooo`03ool00?oooooooooo057ooooo00?oo`00ooooooooool02Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ooo003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool09oooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`0Xooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03_ooool001Gooooo1Ol0
0004ooooo`;o00002_ooool00ooo003oooooooooo`1Aooooo`03ool00?oooooooooo00_ooooo00?o
o`00ooooooooool0DOooool00ooo003oooooooooo`08ooooo`;o00008oooool5o`0000?ooooo0_l0
0007ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`0Wooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool01?ooool2o`00013ooooo000E
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool02Oooool00ooo003ooooooooo
o`1Aooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0D_ooool00ooo003ooooooooo
o`08ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`06ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`0Wooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool01Oooool00ol0003ooooo
ooooo`0>ooooo`005_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Sooooo00?o
o`00ooooooooool0D_ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo05;ooooo00?o
o`00ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo000000Cooooo00?o
0000ooooooooool01_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool09oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Oooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00Gooooo00?o
0000ooooooooool03_ooool001Oooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00?oo`00
ooooooooool0Doooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05?ooooo00?oo`00
ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`;o00001?ooool00ol0003oooooooooo`05
ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0W
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`0>
ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?oo`00oooo
ooooool0Doooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05?ooooo00?oo`00oooo
ooooool01oooool2o`0002Kooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00?oo`00oooo
ooooool0:?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Sooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool0:?ooool00ooo003oooooooooo`04ooooo`;o00004?ooool001kooooo00?o0000oooooooo
ool02?ooool00ooo003oooooooooo`1Cooooo`03ool00?oooooooooo00Wooooo00?oo`00oooooooo
ool0Doooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool01Oooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool0:?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Sooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00Gooooo00?o0000oooooooo
ool03_ooool001kooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`1Dooooo`03ool0
0?oooooooooo00Wooooo00?oo`00ooooooooool0E?ooool00ooo003oooooooooo`07ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Xooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo02Sooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Yooooo`03ool0
0?oooooooooo00Gooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool01ooo
ool00ooo003oooooooooo`1Dooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0E?oo
ool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Ooo
ool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0:Ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03_oo
ool001kooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`1Eooooo`03ool00?oooooo
oooo00Oooooo00?oo`00ooooooooool0EOooool00ooo003oooooooooo`06ooooo`;o0000:oooool2
o`0000Kooooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo02Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`04ooooo`;o00004?ooool0
01kooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`1Eooooo`03ool00?oooooooooo
00Oooooo00?oo`00ooooooooool0EOooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
02Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo
00Gooooo00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool01_ooool00ooo003o
ooooooooo`1Fooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0E_ooool00ooo003o
ooooooooo`06ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01?ooool00ooo003o
ooooooooo`0Zooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:Oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo02Wooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0Yooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03_ooool001kooooo
00?o0000ooooooooool01_ooool00ooo003oooooooooo`1Fooooo`03ool00?oooooooooo00Oooooo
00?oo`00ooooooooool0E_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool01?ooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02Wooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00Gooooo
00?o0000ooooooooool03_ooool001kooooo00?o0000ooooooooool01_ooool00ooo003ooooooooo
o`1Gooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0Eoooool00ooo003ooooooooo
o`05ooooo`;o0000:oooool2o`0000Gooooo00?oo`00ooooooooool0:_ooool01Ooo003ooooooooo
ooooooooo`0002cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Yooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`03ooooo`;o0000
4?ooool001kooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1Hooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool0F?ooool00ooo003oooooooooo`05ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0Zooooo`05ool00?oo
oooooooooooooooo0000;Oooool01?oo003ooooooooooooo000]ooooo`05ool00?oooooooooooooo
oooo0000;?ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo000Nooooo`03
o`000?oooooooooo00Gooooo00?oo`00ooooooooool0F?ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo05Sooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Cooooo00?oo`00ooooooooool0:oooool01?oo003ooooooooooooo000]oooo
o`04ool00?ooooooooooool002gooooo00Coo`00ooooooooooooo`00;Oooool00ooo003ooooooooo
o`04ooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooooooo00Gooooo00?oo`00
ooooooooool0F?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo05Wooooo00?oo`00
ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Cooooo00?oo`00
ooooooooool0:oooool01?oo003ooooooooooooo000]ooooo`04ool00?ooooooooooool002gooooo
00Coo`00ooooooooooooo`00;Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00ko
oooo000Nooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0F_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo05Wooooo00?oo`00ooooooooool01?ooool2o`0002_ooooo
0_l00005ooooo`03ool00?oooooooooo02_ooooo00Coo`00ooooooooooooo`00;Oooool01?oo003o
oooooooooooo000]ooooo`04ool00?ooooooooooool002gooooo00?oo`00ooooooooool00oooool2
o`00013ooooo000Fooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
05[ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Jooooo`03ool00?oooooooooo
00Cooooo00?o0000ooooooooool08_ooool3o`0000Cooooo00?o0000ooooooooool01?ooool00ooo
003oooooooooo`0[ooooo`04ool00?ooooooooooool002gooooo00Coo`00ooooooooooooo`00;Ooo
ool01?oo003ooooooooooooo000^ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool001Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo
0_oo001Mooooo`05ool00?oooooooooooooooooo0000GOooool00ooo003oooooooooo`04ooooo`03
o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool0;?ooool00ooo003oooooool0000^ooooo`04ool00?ooooooo`00
ool002kooooo00?oo`00oooooooo0000;_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooo
oooo00kooooo000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2ool0
05oooooo00?oo`00oooooooo0000Goooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo
02Gooooo00Go0000ooooooooooooooooo`000005ooooo`03ool00?oooooooooo02cooooo0ooo000_
ooooo`;oo`00;oooool3ool002kooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0>
ooooo`006Oooool00ol0003oooooooooo`02ooooo`;o00000oooool00ooo003oooooooooo`1Noooo
o`?oo`00H?ooool01?oo003oooooooooooooool2o`0002Oooooo00Co0000oooooooooooooooo0_l0
0003ooooo`03ool00?oooooooooo02kooooo0_oo000_ooooo`;oo`00;oooool2ool0033ooooo00Co
o`00oooooooooooooooo0_l0000@ooooo`005Oooool4o`0000Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027ooooo1?l00004ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00kooooo000Eooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0_l0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooo0000013ooooo000Eooooo`Go00001?ooooo?o`00
02?ooooo1Ol00003ooooom3o00004?ooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooo9?ooool3o`0001_ooooo1Ol0000Kooooo`?o
00006oooool2o`0001cooooo0ol0000Kooooo`Go00006oooool3o`0001[ooooo000Rooooo`Go0000
0oooool2o`0002Sooooo0ol00004ooooo`;o0000:Oooool2o`0002_ooooo0ol00004ooooo`;o0000
:?ooool5o`0000?ooooo0_l0000dooooo`05o`000?ooooooooooooooool000006oooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00007?ooool0
0ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0001[ooooo00Go0000oooooooooooooooo
o`00000Iooooo`008oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002So
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`04o`000?oooooooooo
o`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Xooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo0000;Oooool5o`0000Gooooo00?o0000oooooooo
ool04_ooool5o`0000?ooooo00?o0000ooooooooool05?ooool5o`0000?ooooo00?o0000oooooooo
ool06Oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Gooooo`007?ooool5o`0000?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Pooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0002Oooooo00Co0000oooooooooooo0000:oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000eooooo`;o00007_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Wo
oooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01_ooooo0_l0000Jooooo`009Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Oooooo00Co0000
oooooooooooo0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002[ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool06?ooool01Ol0003ooooooooooooooooo000001cooooo00?o0000ooooooooool06Oooool01?l0
003oooooooooool0000Looooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00
000Nooooo`03o`000?oooooooooo01Oooooo000Rooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00009oooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00009oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
<oooool01Ol0003ooooooooooooooooo000001[ooooo00Go0000ooooooooooooooooo`00000Koooo
o`;o00006oooool01?l0003oooooooooool0000Kooooo`;o00007?ooool01Ol0003ooooooooooooo
oooo000001[ooooo00Go0000ooooooooooooooooo`00000Iooooo`008_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00009oooool2o`0000Cooooo00Co0000oooooooo
oooo00009oooool01?l0003oooooooooool0000Zooooo`;o00001?ooool01?l0003oooooooooool0
000Wooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000dooooo`?o
00007?ooool3o`0001gooooo00?o0000ooooooooool06_ooool2o`0001gooooo00?o0000oooooooo
ool06oooool3o`0001cooooo0ol0000Jooooo`008oooool3o`0000Cooooo0_l0000Yooooo`03o`00
0?oooooooooo00?ooooo0_l0000Yooooo`;o0000;?ooool00ol0003oooooooooo`03ooooo`;o0000
:Oooool3o`0000Cooooo0_l0003oooooo`_ooooo003oooooooWooooo003oooooooWooooo003ooooo
ooWooooo000Poooooloo0000:Oooooo@o`00013ooooo000Jooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool01Ol0003ooooo
oooooooooooo000002Wooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`00013ooooo000Iooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_oo
ool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`04ooooool00?oo003oo`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o6_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`04ooooool00?oo003oo`00o`;ooooo0ol00?l2ooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0>ooooo`006Oooool01?l0003oooooooooool00003ooooo`Co
00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o
00000ol00?l2o`0000?o003o0_l00003o`00o`04o`000?l00?oo003oo`00o`;o00000ol00?l2o`00
00?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`00
00?o003o0ol000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l01?l00000
0ol00?oo0000o`000002o`000004o`00ool0003o0000o`0000?o003o0_l00003o`00o`;o00000ol0
0?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o00Co0000o`00ool00?oo003o
0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o
0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`?o0000:Oooool00ol0003ooooo
ooooo`0Yooooo`Koo`00K?ooool6ool002_ooooo00?o0000ooooooooool03_ooool001Wooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooooooool3o`00o`;ooooo0ol00?l2ooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o
003o00Coooooo`00ool00?oo003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00
o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l3ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003o
oooooooooooooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_oo
ool3o`00o`;ooooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool00ol0003oooooooooo`0Wooooo`;o0000:?ooool3ool000Cooooo
0ooo001Yooooo`;oo`001Oooool00ooo003oooooooooo`0Wooooo`;o00004?ooool001Wooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0F_ooool00ol0003oooooooooo`0Pooooo`?o00001?ooool00ol0003oooooooooo`0Uooooo`;o
o`002Oooool00ooo003oooooooooo`1Uooooo`;oo`002?ooool3ool002Oooooo00?o0000oooooooo
ool03_ooool001Wooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1Kooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool09?ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo
06?ooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo
00kooooo000Jooooo`;o00001?ooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0F_ooool00ol0003oooooooooo`0Iooooo`Go00000oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02?ooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1Qoooo
o`03ool00?oooooooooo00gooooo00?oo`00ooooooooool08oooool00ol0003oooooooooo`0>oooo
o`008?ooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo0_l0000Tooooo`03ool00?oooooooooo
00gooooo00?oo`00ooooooooool0H?ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo
027ooooo0_l0000@ooooo`008?ooool2o`0005cooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Joooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Roooo
o`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0G_ooool00ooo003oooooooooo`0@oooo
o`03ool00?oooooooooo027ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooooooo
ool0Foooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool08?ooool2o`00
00Gooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo
05gooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0Qooooo`03o`000?oooooooooo
00kooooo000Pooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Joooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qoooo
o`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0Foooool00ooo003oooooooooo`0Boooo
o`03ool00?oooooooooo023ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooooooo
ool0Foooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool09oooool2o`00
027ooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`1Jooooo`03ool00?oooooooooo
01?ooooo00?oo`00ooooooooool07oooool2o`00013ooooo000Pooooo`03o`000?oooooooooo05_o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool07oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo05Sooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`0Oooooo`03o`000?oooooooooo00kooooo000Pooooo`03
o`000?oooooooooo05_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
05Sooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Oooooo`03o`000?oooooooooo
00kooooo000Pooooo`;o0000G?ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo01Oooooo00?oo`00oooo
ooooool0E_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01kooooo00?o0000oooo
ooooool03_ooool0023ooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
05[ooooo00?o0000ooooooooool09oooool2o`0001kooooo00?oo`00ooooooooool06?ooool00ooo
003oooooooooo`1Fooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool07Oooool2o`00
013ooooo000Pooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Joooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`0Ioooo
o`03ool00?oooooooooo05Gooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Moooo
o`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo05_ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`1Jooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ooo
003oooooooooo`0Jooooo`03ool00?oooooooooo05Cooooo00?oo`00ooooooooool06_ooool00ooo
003oooooooooo`0Looooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo05_o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool06oooool00ooo003oooooooooo`0Looooo`03ool00?oooooooooo05?ooooo00?oo`00oooo
ooooool06oooool00ooo003oooooooooo`0Kooooo`03o`000?oooooooooo00kooooo000Pooooo`03
o`000?oooooooooo05_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo
02Oooooo0_l0000Looooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool0Doooool00ooo
003oooooooooo`0Kooooo`03ool00?oooooooooo01[ooooo0_l0000@ooooo`008?ooool2o`0005co
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool06_ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo05;ooooo00?oo`00oooo
ooooool07Oooool00ooo003oooooooooo`0Jooooo`03o`000?oooooooooo00kooooo000Pooooo`03
o`000?oooooooooo05_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo
057ooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo
00kooooo000Pooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Joooo
o`03o`000?oooooooooo02Oooooo0_l0000Jooooo`03ool00?oooooooooo01oooooo00?oo`00oooo
ooooool0D?ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo01Sooooo0_l0000@oooo
o`008?ooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool08Oooool00ooo
003oooooooooo`1?ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool06?ooool00ol0
003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0F_ooool00ol0003oooooooooo`0Qooooo`;o00001?ooool00ol0003oooooooooo`0Hoooo
o`03ool00?oooooooooo027ooooo00?oo`00ooooooooool0Coooool00ooo003oooooooooo`0Qoooo
o`03ool00?oooooooooo01Oooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooooooo
ool0Foooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool08?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool08_ooool0
0ooo003oooooooooo`1>ooooo`03ool00?oooooooooo02;ooooo00?oo`00ooooooooool05oooool0
0ol0003oooooooooo`0>ooooo`008?ooool2o`0005cooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1J
ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00000oooool2o`0001Oooooo00?o
o`00ooooooooool09?ooool00ooo003oooooooooo`1=ooooo`03ool00?oooooooooo02?ooooo00?o
o`00ooooooooool05Oooool2o`00013ooooo000Pooooo`03o`000?oooooooooo05_ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0
C?ooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool0
3_ooool0023ooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo
00?o0000ooooooooool08?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01Go
oooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`1<ooooo`03ool00?oooooooooo02Go
oooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003ooooo
ooooo`1Kooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Pooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`0Voooo
o`03ool00?oooooooooo04_ooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`0Doooo
o`03o`000?oooooooooo00kooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00001?ooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0
003oooooooooo`0Qooooo`;o00001?ooool2o`0001Gooooo00?oo`00ooooooooool09oooool00ooo
003oooooooooo`1:ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool04oooool2o`00
013ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0Xooooo`03ool00?oo
oooooooo04[ooooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`0Cooooo`03o`000?oo
oooooooo00kooooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooooooo
0ol0001Kooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool0FOooool2o`0002Wooooo00?o0000oooooooo
ool04oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo04Sooooo00?oo`00oooooooo
ool0:Oooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo000=ooooo`04o`00
0?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00001Mooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0F_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01;ooooo00?oo`00
ooooooooool0:_ooool00ooo003oooooooooo`18ooooo`03ool00?oooooooooo02[ooooo00?oo`00
ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`003Oooool01?l0003oooooooooool00007
ooooo`Co00001?ooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_oo
ool00ol0003oooooooooo`0Wooooo`;o00004_ooool00ooo003oooooooooo`0[ooooo`03ool00?oo
oooooooo04Sooooo00?oo`00ooooooooool0:oooool00ooo003oooooooooo`0@ooooo`;o00004?oo
ool000gooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool04Oooool00ooo003oooooooooo`0/ooooo`03ool00?oooooooooo04Kooooo
00?oo`00ooooooooool0;?ooool00ooo003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo
000>ooooo`;o00002?ooool5o`0000?ooooo00?o0000ooooooooool0Foooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo05[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0@ooooo`03ool0
0?oooooooooo02gooooo00?oo`00ooooooooool0A_ooool00ooo003oooooooooo`0]ooooo`03ool0
0?oooooooooo013ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0Fooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0?ooooo`03ool00?oooooooooo02kooooo00?oo`00ooooooooool0AOooool00ooo003ooooo
ooooo`0_ooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool03_ooool0023ooooo00?o
0000ooooooooool0Foooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool0
9oooool2o`0000oooooo00?oo`00ooooooooool0<?ooool00ooo003oooooooooo`14ooooo`03ool0
0?oooooooooo02oooooo00?oo`00ooooooooool03_ooool2o`00013ooooo000Pooooo`;o0000G?oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0=ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool0@oooool00ooo003ooooo
ooooo`0aooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool03_ooool0023ooooo00?o
0000ooooooooool0Foooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo03;ooooo00?oo`00ooooooooool0
@oooool00ooo003oooooooooo`0booooo`;oo`003_ooool00ol0003oooooooooo`0>ooooo`008?oo
ool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool0=?ooool00ooo003ooooo
ooooo`12ooooo`03ool00?oooooooooo03Cooooo00?oo`00ooooooooool02oooool00ol0003ooooo
ooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
F_ooool00ol0003oooooooooo`0Wooooo`;o00002oooool00ooo003oooooooooo`0eooooo`03ool0
0?oooooooooo047ooooo00?oo`00ooooooooool0=_ooool00ooo003oooooooooo`09ooooo`;o0000
4?ooool0023ooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo
00?o0000ooooooooool08?ooool3o`0000Cooooo00?o0000ooooooooool02Oooool00ooo003ooooo
ooooo`0fooooo`03ool00?oooooooooo047ooooo00?oo`00ooooooooool0=oooool2ool000[ooooo
00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0Foooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo05[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo0_oo000jooooo`03ool00?oooooooooo043ooooo00?oo`00ooooooooool0
>Oooool2ool000Sooooo00?o0000ooooooooool03_ooool0023ooooo0_l0001Looooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool3ool003cooooo00?oo`00ooooooooool0?oooool00ooo003ooooo
ooooo`0looooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03_ooool0023ooooo00?o
0000ooooooooool0Foooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`03ooooo`;o00000oooool3ool003kooooo00?oo`00ooooooooool0
?oooool00ooo003oooooooooo`0mooooo`?oo`000oooool2o`00013ooooo000Pooooo`03o`000?oo
oooooooo05_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`14ooooo`03ool00?oooooooooo03kooooo
00?oo`00ooooooooool0A?ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003ooooooooo
o`1Kooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Pooooo`;o0000
1Oooool00ol0003oooooooooo`14ooooo`03ool00?oooooooooo03gooooo00?oo`00ooooooooool0
AOooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Kooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0A?ooool00ooo003oooooooooo`0mooooo`03ool00?oooooooooo04Gooooo
00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0Foooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo05[ooooo00?o0000ooooooooool09oooool2o`0004Gooooo00?oo`00ooooooooool0
?Oooool00ooo003oooooooooo`14ooooo`;o00004?ooool0023ooooo0_l0001Looooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Gooooo
00?oo`00ooooooooool0??ooool00ooo003oooooooooo`15ooooo`03o`000?oooooooooo00kooooo
000Pooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0AOooool00ooo003oooooooooo`0kooooo`03ool0
0?oooooooooo04Kooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0Fooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`15ooooo`03ool00?oooooooooo03_ooooo00?oo`00ooooooooool0A_ooool00ol0003ooooo
ooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
F_ooool00ol0003oooooooooo`0Wooooo`;o0000Aoooool00ooo003oooooooooo`0jooooo`03ool0
0?oooooooooo04Gooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`1Kooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Kooooo
00?oo`00ooooooooool0>Oooool00ooo003oooooooooo`17ooooo`03o`000?oooooooooo00kooooo
000Pooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0A_ooool00ooo003oooooooooo`0iooooo`03ool0
0?oooooooooo04Oooooo00?o0000ooooooooool03_ooool0023ooooo0_l0001Looooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Wooooo`;o0000B?ooool00ooo003ooooo
ooooo`0hooooo`03ool00?oooooooooo04Kooooo0_l0000@ooooo`008?ooool00ol0003ooooooooo
o`1Kooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo04Oooooo00?oo`00ooooooooool0>?ooool00ooo003oooooooooo`17ooooo`03o`00
0?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1Jooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Aoooool00ooo003ooooo
ooooo`0gooooo`03ool00?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001Wooooo0ol0
0004ooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0B?ooool00ooo003oooooooooo`0fooooo`03ool0
0?oooooooooo04Sooooo00?o0000ooooooooool03_ooool001[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003ooooo
ooooo`0Wooooo`;o0000BOooool00ooo003oooooooooo`0fooooo`03ool00?oooooooooo04Oooooo
0_l0000@ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05[ooooo0ol0
0?l2ooooo`?o003o00Coooooo`00ool00?oo003o0_ooool3o`00o`;ooooo0ol00?mKooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0B?ooool00ooo003oooooooooo`0eooooo`03ool0
0?oooooooooo04Wooooo00?o0000ooooooooool03_ooool001[ooooo00?o0000ooooooooool00ooo
ool3o`0005[ooooo0ol00?l2ooooo`?o003o00Coooooo`00ool00?oo003o0_ooool3o`00o`;ooooo
0ol00?mJooooo`;o00008Oooool5o`0000?ooooo00?o0000ooooooooool0BOooool00ooo003ooooo
ooooo`0dooooo`03ool00?oooooooooo04Wooooo00?o0000ooooooooool03_ooool001[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Jooooo`?o003o0_ooool3o`00o`04ooooool0
0?oo003oo`00o`;ooooo0ol00?l2ooooo`?o003oFoooool00ol0003oooooooooo`0Pooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool0BOooool00ooo003oooooooooo`0dooooo`03
ool00?oooooooooo04Wooooo00?o0000ooooooooool03_ooool001Wooooo0_l00005ooooo`03o`00
0?oooooooooo0<_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`;o0000
B_ooool00ooo003oooooooooo`0dooooo`03ool00?oooooooooo04Sooooo0_l0000@ooooo`006_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04[ooooo00?oo`00ooooooooool0<_oo
ool00ooo003oooooooooo`1:ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooo
oooo0<_ooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool0B_ooool00ooo003oooooooooo`0booooo`03ool00?oooooooooo04[ooooo00?o
0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0O
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1:ooooo`03ool00?oo
oooooooo03;ooooo00?oo`00ooooooooool0B_ooool00ol0003oooooooooo`0>ooooo`008?ooool2
o`000<cooooo00?o0000ooooooooool08?ooool3o`0000Cooooo0_l0001<ooooo`03ool00?oooooo
oooo033ooooo00?oo`00ooooooooool0B_ooool2o`00013ooooo000Pooooo`03o`000?oooooooooo
0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo
033ooooo00?oo`00ooooooooool0Boooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Boooool00ooo003o
ooooooooo`0`ooooo`03ool00?oooooooooo04_ooooo00?o0000ooooooooool03_ooool0023ooooo
00?o0000ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04cooooo
00?oo`00ooooooooool0;oooool00ooo003oooooooooo`1;ooooo`03o`000?oooooooooo00kooooo
000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09oooool2o`0004gooooo00?o
o`00ooooooooool0;_ooool00ooo003oooooooooo`1;ooooo`;o00004?ooool0023ooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04cooooo00?oo`00
ooooooooool0;_ooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo00kooooo000Poooo
o`;o0000c?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04gooooo00?oo`00oooo
ooooool0;Oooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo00kooooo000Pooooo`03
o`000?oooooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1=ooooo`03
ool00?oooooooooo02cooooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`0>ooooo`00
8?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo0_l0001>ooooo`03ool0
0?oooooooooo02cooooo00?oo`00ooooooooool0C?ooool2o`00013ooooo000Pooooo`03o`000?oo
oooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1=ooooo`03ool00?oo
oooooooo02cooooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`0>ooooo`008?ooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0C_ooool0
0ooo003oooooooooo`0Zooooo`03ool00?oooooooooo04kooooo00?o0000ooooooooool03_ooool0
023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
04kooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`1>ooooo`03o`000?oooooooooo
00kooooo000Pooooo`;o0000c?ooool00ol0003oooooooooo`0Wooooo`;o0000Coooool00ooo003o
ooooooooo`0Zooooo`03ool00?oooooooooo04gooooo0_l0000@ooooo`008?ooool00ol0003ooooo
ooooo`3;ooooo`03o`000?oooooooooo023ooooo0ol00004ooooo`03o`000?oooooooooo04oooooo
00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo
000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool07oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool0Coooool00ooo003oooooooooo`0Xooooo`03ool0
0?oooooooooo04oooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0booo
ool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool00000DOooool00ooo003ooooo
ooooo`0Xooooo`03ool00?oooooooooo04oooooo00?o0000ooooooooool03_ooool0023ooooo00?o
0000ooooooooool0boooool00ol0003oooooooooo`0Qooooo`;o00001?ooool2o`00053ooooo00?o
o`00ooooooooool0:?ooool00ooo003oooooooooo`1>ooooo`;o00004?ooool0023ooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool00000D_oo
ool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool03_oo
ool0023ooooo0_l0003<ooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo053ooooo00?oo`00ooooooooool09_ooool00ooo003ooooooooo
o`1@ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000
ooooooooool08?ooool3o`0000Cooooo00?o0000ooooooooool0D?ooool00ooo003oooooooooo`0V
ooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooo
ooooool0boooool00ol0003oooooooooo`0Wooooo`;o0000D_ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo053ooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0DOooool00ooo003oooooooooo`0Tooooo`03
ool00?oooooooooo057ooooo00?o0000ooooooooool03_ooool000gooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`1Aooooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool0
DOooool00ol0003oooooooooo`0>ooooo`003_ooool00ol0003oooooooooo`07ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo
0_l0001Cooooo`03ool00?oooooooooo02;ooooo00?oo`00ooooooooool0DOooool2o`00013ooooo
000>ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0ol0003:ooooo`;o0000
:Oooool00ol0003oooooooooo`1Booooo`03ool00?oooooooooo02;ooooo00?oo`00ooooooooool0
D_ooool00ol0003oooooooooo`0>ooooo`003_ooool00ol0003oooooooooo`0;ooooo`05o`000?oo
ooooooooooooool00000cOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo05;ooooo
00?oo`00ooooooooool08_ooool00ooo003oooooooooo`1Booooo`03o`000?oooooooooo00kooooo
000>ooooo`03o`000?oooooooooo00Oooooo1?l00004ooooo`03o`000?oooooooooo0<_ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`1Booooo`03ool00?oooooooooo027ooooo00?o
o`00ooooooooool0Doooool00ol0003oooooooooo`0>ooooo`003Oooool2o`0000Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo0_l0001D
ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool0D_ooool2o`00013ooooo000>oooo
o`03o`000?oooooooooo00Oooooo1Ol00003ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1Cooooo`03ool00?oooooooooo023ooooo00?oo`00oooo
ooooool0Doooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0Doooool00ooo003oooooooooo`0Oooooo`03
ool00?oooooooooo05Cooooo00?o0000ooooooooool03_ooool0023ooooo0_l0003<ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0E?ooool00ooo003oooooooooo`0Nooooo`03ool0
0?oooooooooo05Cooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0booo
ool00ol0003oooooooooo`0Wooooo`;o0000EOooool00ooo003oooooooooo`0Nooooo`03ool00?oo
oooooooo05?ooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0E?ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooo
oooo05Gooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0
003oooooooooo`0Qooooo`?o00000oooool00ol0003oooooooooo`1Eooooo`03ool00?oooooooooo
01cooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Eooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool0EOooool00ol0003o
ooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01oooooo
1Ol00003ooooo`;o0000E_ooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo05Gooooo
0_l0000@ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool07oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool06_ooool00ooo003ooooo
ooooo`1Fooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o
0000ooooooooool08?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo05Kooooo00?o
o`00ooooooooool06_ooool00ooo003oooooooooo`1Fooooo`03o`000?oooooooooo00kooooo000P
ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool08Oooool2o`0000Cooooo00?o0000
ooooooooool0Eoooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo05Oooooo00?o0000
ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00;ooooo0_l0001Hooooo`03ool00?oooooooooo01Sooooo00?oo`00oooo
ooooool0E_ooool2o`00013ooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo01Oooooo00?oo`00oooooooo
ool0F?ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0F?ooool00ooo003oooooooooo`0Fooooo`03ool0
0?oooooooooo05Sooooo00?o0000ooooooooool03_ooool0023ooooo0_l0003<ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0F?ooool00ooo003oooooooooo`0Eooooo`03ool00?oo
oooooooo05Wooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool0
0ol0003oooooooooo`0Wooooo`;o0000F_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooo
oooo05Wooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0F_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo
05[ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool04?ooool00ooo003o
ooooooooo`1Kooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`1Kooooo`03ool00?oooooooooo013ooooo
00?oo`00ooooooooool0Foooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02Oooooo0_l0001Mooooo`03ool00?oooooooooo00kooooo00?o
o`00ooooooooool0Foooool2o`00013ooooo000Pooooo`;o0000c?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo05cooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`1L
ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1Mooooo`03ool00?oooooooooo00cooooo00?oo`00oooo
ooooool0GOooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`0;ooooo`03
ool00?oooooooooo05kooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0
boooool00ol0003oooooooooo`0Wooooo`;o0000Goooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo05kooooo0_l0000@ooooo`006?ooool5o`0000?ooooo00?o0000ooooooooool0booo
ool00ol0003oooooooooo`0Pooooo`?o00001?ooool00ol0003oooooooooo`1Oooooo`03ool00?oo
oooooooo00Oooooo00?oo`00ooooooooool0H?ooool00ol0003oooooooooo`0>ooooo`006Oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool07ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0H?ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo067ooooo00?o0000ooooooooool03_ooool001[ooooo00?o
0000ooooooooool00oooool3o`000<[ooooo0_l0000Uooooo`05o`000?ooooooooooooooool00000
Hoooool3ool000;ooooo0_oo001Tooooo`03o`000?oooooooooo00kooooo000Kooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Sooooo`04o`000?oo
ooooooooooooo`;o0000IOooool3ool006Cooooo0_l0000@ooooo`006?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`05o`00
0?ooooooooooooooool000008Oooool4o`0000Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00kooooo000Hooooo`05o`000?ooooooooooooooool0
00000oooooo?o`00027ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00004?ooool001Wooooo0ol0003doooo
o`Go00000oooooo@o`00013ooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003o
ooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-8.51939, \
-2.3837, 0.0638556, 0.0513875}, {{262.875, 490.688}, {303, 162.25}} -> \
{-49.0425, -2.38369, 0.127711, 0.0513874}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-27.7031, -2.91994, 0.203806, 0.0164882}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-12.2606, -10.3423, 0.0319279, 0.0513874}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["M = 4", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = 4;\)\), "\[IndentingNewLine]", 
    \(\(g1c\  = \ 
        DiscreteListPlot[Table[{n, \ pulse[n, \ m]}, {n, \(-20\), 20}], Blue, 
          Frame \[Rule] True, \ Axes \[Rule] {True, False}, \ 
          PlotRange \[Rule] {\(- .05\), 2.05}, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g2c\  = \ 
        Plot[Evaluate[
            dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-\[Pi]\), \ \[Pi]}, 
          PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g3c\  = \ 
        Plot[Evaluate[dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-2\) \[Pi], \ 
            2  \[Pi]}, PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g4c\  = \ 
        Plot[Evaluate[dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-4\) \[Pi], \ 
            4  \[Pi]}, PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1c, g2c}, {g3c, g4c}}], \ 
        ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.12344 0.0533199 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0168 -12 -4.5 ]
[-0.0125 .0168 0 4.5 ]
[-0.0125 .12344 -6 -4.5 ]
[-0.0125 .12344 0 4.5 ]
[-0.0125 .23008 -6 -4.5 ]
[-0.0125 .23008 0 4.5 ]
[-0.0125 .33672 -6 -4.5 ]
[-0.0125 .33672 0 4.5 ]
[-0.0125 .44336 -6 -4.5 ]
[-0.0125 .44336 0 4.5 ]
[-0.0125 .55 -6 -4.5 ]
[-0.0125 .55 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-6)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-4)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-2)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(2)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(4)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(6)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.08317 0 m
.08317 .00375 L
s
.12106 0 m
.12106 .00375 L
s
.15895 0 m
.15895 .00375 L
s
.23474 0 m
.23474 .00375 L
s
.27264 0 m
.27264 .00375 L
s
.31053 0 m
.31053 .00375 L
s
.38632 0 m
.38632 .00375 L
s
.42421 0 m
.42421 .00375 L
s
.46211 0 m
.46211 .00375 L
s
.53789 0 m
.53789 .00375 L
s
.57579 0 m
.57579 .00375 L
s
.61368 0 m
.61368 .00375 L
s
.68947 0 m
.68947 .00375 L
s
.72736 0 m
.72736 .00375 L
s
.76526 0 m
.76526 .00375 L
s
.84105 0 m
.84105 .00375 L
s
.87894 0 m
.87894 .00375 L
s
.91683 0 m
.91683 .00375 L
s
.00738 0 m
.00738 .00375 L
s
.99262 0 m
.99262 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0168 m
.00625 .0168 L
s
[(-2)] -0.0125 .0168 1 0 Mshowa
0 .12344 m
.00625 .12344 L
s
[(0)] -0.0125 .12344 1 0 Mshowa
0 .23008 m
.00625 .23008 L
s
[(2)] -0.0125 .23008 1 0 Mshowa
0 .33672 m
.00625 .33672 L
s
[(4)] -0.0125 .33672 1 0 Mshowa
0 .44336 m
.00625 .44336 L
s
[(6)] -0.0125 .44336 1 0 Mshowa
0 .55 m
.00625 .55 L
s
[(8)] -0.0125 .55 1 0 Mshowa
.125 Mabswid
0 .04346 m
.00375 .04346 L
s
0 .07012 m
.00375 .07012 L
s
0 .09678 m
.00375 .09678 L
s
0 .1501 m
.00375 .1501 L
s
0 .17676 m
.00375 .17676 L
s
0 .20342 m
.00375 .20342 L
s
0 .25674 m
.00375 .25674 L
s
0 .2834 m
.00375 .2834 L
s
0 .31006 m
.00375 .31006 L
s
0 .36338 m
.00375 .36338 L
s
0 .39004 m
.00375 .39004 L
s
0 .4167 m
.00375 .4167 L
s
0 .47002 m
.00375 .47002 L
s
0 .49668 m
.00375 .49668 L
s
0 .52334 m
.00375 .52334 L
s
0 .57666 m
.00375 .57666 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.08317 .61428 m
.08317 .61803 L
s
.12106 .61428 m
.12106 .61803 L
s
.15895 .61428 m
.15895 .61803 L
s
.23474 .61428 m
.23474 .61803 L
s
.27264 .61428 m
.27264 .61803 L
s
.31053 .61428 m
.31053 .61803 L
s
.38632 .61428 m
.38632 .61803 L
s
.42421 .61428 m
.42421 .61803 L
s
.46211 .61428 m
.46211 .61803 L
s
.53789 .61428 m
.53789 .61803 L
s
.57579 .61428 m
.57579 .61803 L
s
.61368 .61428 m
.61368 .61803 L
s
.68947 .61428 m
.68947 .61803 L
s
.72736 .61428 m
.72736 .61803 L
s
.76526 .61428 m
.76526 .61803 L
s
.84105 .61428 m
.84105 .61803 L
s
.87894 .61428 m
.87894 .61803 L
s
.91683 .61428 m
.91683 .61803 L
s
.00738 .61428 m
.00738 .61803 L
s
.99262 .61428 m
.99262 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0168 m
1 .0168 L
s
.99375 .12344 m
1 .12344 L
s
.99375 .23008 m
1 .23008 L
s
.99375 .33672 m
1 .33672 L
s
.99375 .44336 m
1 .44336 L
s
.99375 .55 m
1 .55 L
s
.125 Mabswid
.99625 .04346 m
1 .04346 L
s
.99625 .07012 m
1 .07012 L
s
.99625 .09678 m
1 .09678 L
s
.99625 .1501 m
1 .1501 L
s
.99625 .17676 m
1 .17676 L
s
.99625 .20342 m
1 .20342 L
s
.99625 .25674 m
1 .25674 L
s
.99625 .2834 m
1 .2834 L
s
.99625 .31006 m
1 .31006 L
s
.99625 .36338 m
1 .36338 L
s
.99625 .39004 m
1 .39004 L
s
.99625 .4167 m
1 .4167 L
s
.99625 .47002 m
1 .47002 L
s
.99625 .49668 m
1 .49668 L
s
.99625 .52334 m
1 .52334 L
s
.99625 .57666 m
1 .57666 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.06244 .28198 L
.07216 .1689 L
.0775 .11629 L
.08255 .07554 L
.08542 .05685 L
.08852 .0404 L
.09135 .02899 L
.0927 .02474 L
.09396 .02145 L
.09524 .01879 L
.09641 .01695 L
.09771 .01556 L
.09843 .01508 L
.09911 .01481 L
.09977 .01472 L
.10047 .0148 L
.10173 .0154 L
.1025 .01605 L
.10322 .01686 L
.10458 .01885 L
.10687 .02356 L
.10939 .03051 L
.11448 .0493 L
.12359 .09284 L
.13434 .14555 L
.13944 .16589 L
.14415 .18021 L
.14648 .18545 L
.14895 .18958 L
.15023 .19112 L
.15143 .19221 L
.15275 .19298 L
.15349 .19323 L
.15417 .19334 L
.15531 .19327 L
.15638 .19292 L
.15755 .19223 L
.15879 .19114 L
.16011 .18962 L
.16134 .18784 L
.16366 .18367 L
.16888 .17072 L
.1737 .15543 L
.18458 .11607 L
.18925 .10013 L
.19427 .08552 L
.1967 .07972 L
.19901 .07512 L
.20108 .0718 L
Mistroke
.20334 .06909 L
.20401 .06848 L
.20474 .06791 L
.20606 .06715 L
.20735 .06674 L
.20853 .06666 L
.20981 .06687 L
.21054 .06714 L
.21121 .06748 L
.21258 .06844 L
.21405 .06986 L
.21672 .07343 L
.21925 .07791 L
.22398 .08879 L
.24224 .14452 L
.24724 .15795 L
.24986 .16383 L
.25262 .16895 L
.25505 .17246 L
.25643 .174 L
.25771 .17513 L
.25889 .17592 L
.25996 .17641 L
.26119 .17671 L
.26236 .17674 L
.26351 .17652 L
.26477 .176 L
.26608 .17515 L
.26731 .17407 L
.26951 .17147 L
.27187 .16778 L
.27726 .15626 L
.28217 .14276 L
.29309 .10835 L
.29789 .09403 L
.3032 .08074 L
.30549 .07615 L
.30796 .07213 L
.30909 .07063 L
.31029 .0693 L
.31141 .06829 L
.31243 .06758 L
.31361 .06701 L
.31486 .06669 L
.31602 .06668 L
.31712 .06691 L
.3184 .06748 L
.31959 .0683 L
.32088 .06951 L
.32226 .07115 L
Mistroke
.32471 .07497 L
.32736 .08027 L
.33213 .09267 L
.34301 .12983 L
.35312 .1653 L
.35589 .17345 L
.35885 .18087 L
.36163 .18647 L
.36416 .19019 L
.36542 .19153 L
.36611 .19211 L
.36675 .19256 L
.36788 .1931 L
.36913 .19335 L
.36983 .19332 L
.37049 .19319 L
.37173 .19265 L
.37242 .19218 L
.37306 .19164 L
.37451 .19004 L
.37675 .18654 L
.37923 .18126 L
.38425 .1663 L
.39448 .12196 L
.40524 .06781 L
.40968 .04781 L
.41443 .03047 L
.41716 .02303 L
.41845 .02027 L
.41964 .01819 L
.42083 .01657 L
.42213 .01537 L
.42327 .01482 L
.42448 .01476 L
.42571 .01527 L
.42688 .01631 L
.42793 .01771 L
.42907 .01975 L
.43031 .02257 L
.43163 .02628 L
.434 .0348 L
.43868 .05857 L
.44291 .08785 L
.45336 .18747 L
.46318 .30448 L
.47298 .424 L
.47833 .48268 L
.48332 .52941 L
.48758 .56147 L
.48976 .57466 L
Mistroke
.49214 .58629 L
.49349 .59161 L
.49474 .59565 L
.49593 .59873 L
.4972 .60114 L
.49833 .60254 L
.49939 .60322 L
.50055 .60323 L
.50181 .60241 L
.50249 .60159 L
.50313 .60059 L
.50434 .59809 L
.50564 .59452 L
.50704 .58963 L
.50957 .57819 L
.5119 .5648 L
.51727 .52444 L
.52293 .46953 L
.54302 .22897 L
.55249 .12736 L
.5578 .08241 L
.56032 .06485 L
.56265 .0509 L
.56479 .04006 L
.56715 .03035 L
.56953 .02297 L
.57083 .01994 L
.57206 .01773 L
.57315 .01628 L
.5743 .01527 L
.57528 .01481 L
.57635 .01474 L
.57751 .01514 L
.57875 .01611 L
.57992 .01752 L
.58098 .0192 L
.58328 .02409 L
.58582 .03126 L
.59095 .0505 L
.60015 .09475 L
.60573 .12297 L
.61102 .14766 L
.61617 .16776 L
.61868 .1757 L
.62095 .1817 L
.62327 .18658 L
.62545 .18999 L
.62665 .19136 L
.62775 .19231 L
.62897 .193 L
Mistroke
.63025 .19333 L
.63145 .19328 L
.63275 .19284 L
.63397 .19205 L
.63508 .19104 L
.63639 .1895 L
.63781 .18741 L
.64039 .18256 L
.64565 .16903 L
.65124 .15074 L
.66127 .11426 L
.66585 .09882 L
.67066 .085 L
.67319 .07909 L
.67594 .07384 L
.67715 .07196 L
.67845 .07027 L
.67958 .06904 L
.68078 .06802 L
.68201 .06726 L
.68314 .06683 L
.68437 .06665 L
.68506 .06668 L
.68571 .0668 L
.68688 .06721 L
.68795 .06782 L
.68919 .0688 L
.69036 .06999 L
.69253 .07283 L
.69453 .07618 L
.69906 .08599 L
.70879 .11429 L
.71928 .147 L
.72411 .15956 L
.72674 .16521 L
.72919 .16956 L
.73129 .17251 L
.73237 .17374 L
.73353 .17484 L
.73481 .17576 L
.73602 .17636 L
.7372 .17669 L
.73829 .17676 L
.73942 .1766 L
.74045 .17624 L
.74165 .17559 L
.74278 .17473 L
.7448 .17264 L
.747 .16956 L
.75197 .15981 L
Mistroke
.75659 .14789 L
.76591 .11906 L
.77599 .08886 L
.77867 .08233 L
.7815 .07648 L
.78391 .07247 L
.7853 .07061 L
.78656 .06921 L
.78784 .06811 L
.78905 .06734 L
.79033 .06684 L
.79105 .06669 L
.79171 .06665 L
.79282 .06678 L
.79404 .0672 L
.79532 .06795 L
.79652 .06896 L
.7988 .07163 L
.80119 .07549 L
.80548 .08487 L
.81009 .09802 L
.81513 .11502 L
.82522 .15169 L
.83018 .16795 L
.83475 .18021 L
.83731 .18554 L
.84001 .18978 L
.84142 .19135 L
.84273 .19242 L
.84349 .19286 L
.84418 .19314 L
.84497 .19332 L
.84572 .19335 L
.84692 .19311 L
.8482 .19247 L
.84941 .19149 L
.8505 .19029 L
.85179 .1885 L
.85318 .18611 L
.8557 .18059 L
.86063 .16563 L
.86523 .1474 L
.87568 .09657 L
.88087 .0705 L
.88651 .0452 L
.8891 .03547 L
.89184 .02688 L
.89418 .02118 L
.89551 .01869 L
.89676 .01688 L
Mistroke
.89802 .01559 L
.89873 .01512 L
.89939 .01484 L
.9006 .01475 L
.90189 .01527 L
.90316 .01641 L
.90435 .01809 L
.90542 .02008 L
.90659 .02279 L
.90926 .03117 L
.91209 .04333 L
.91716 .07352 L
.92174 .10955 L
.92601 .14991 L
.93573 .25962 L
.94529 .37767 L
.95569 .49444 L
.96045 .53723 L
.96307 .55674 L
.96552 .57221 L
.96777 .58382 L
.96984 .59216 L
.97094 .59567 L
.97214 .59876 L
.97334 .60106 L
.97461 .60263 L
.97543 .60316 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.037894 0.123437 0.0533202 [
[.12106 -0.0125 -9 -9 ]
[.12106 -0.0125 9 0 ]
[.31053 -0.0125 -6 -9 ]
[.31053 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.68947 -0.0125 -3 -9 ]
[.68947 -0.0125 3 0 ]
[.87894 -0.0125 -6 -9 ]
[.87894 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0168 -12 -4.5 ]
[-0.0125 .0168 0 4.5 ]
[-0.0125 .12344 -6 -4.5 ]
[-0.0125 .12344 0 4.5 ]
[-0.0125 .23008 -6 -4.5 ]
[-0.0125 .23008 0 4.5 ]
[-0.0125 .33672 -6 -4.5 ]
[-0.0125 .33672 0 4.5 ]
[-0.0125 .44336 -6 -4.5 ]
[-0.0125 .44336 0 4.5 ]
[-0.0125 .55 -6 -4.5 ]
[-0.0125 .55 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12106 0 m
.12106 .00625 L
s
[(-10)] .12106 -0.0125 0 1 Mshowa
.31053 0 m
.31053 .00625 L
s
[(-5)] .31053 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.68947 0 m
.68947 .00625 L
s
[(5)] .68947 -0.0125 0 1 Mshowa
.87894 0 m
.87894 .00625 L
s
[(10)] .87894 -0.0125 0 1 Mshowa
.125 Mabswid
.15895 0 m
.15895 .00375 L
s
.19685 0 m
.19685 .00375 L
s
.23474 0 m
.23474 .00375 L
s
.27264 0 m
.27264 .00375 L
s
.34842 0 m
.34842 .00375 L
s
.38632 0 m
.38632 .00375 L
s
.42421 0 m
.42421 .00375 L
s
.46211 0 m
.46211 .00375 L
s
.53789 0 m
.53789 .00375 L
s
.57579 0 m
.57579 .00375 L
s
.61368 0 m
.61368 .00375 L
s
.65158 0 m
.65158 .00375 L
s
.72736 0 m
.72736 .00375 L
s
.76526 0 m
.76526 .00375 L
s
.80315 0 m
.80315 .00375 L
s
.84105 0 m
.84105 .00375 L
s
.08317 0 m
.08317 .00375 L
s
.04527 0 m
.04527 .00375 L
s
.00738 0 m
.00738 .00375 L
s
.91683 0 m
.91683 .00375 L
s
.95473 0 m
.95473 .00375 L
s
.99262 0 m
.99262 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0168 m
.00625 .0168 L
s
[(-2)] -0.0125 .0168 1 0 Mshowa
0 .12344 m
.00625 .12344 L
s
[(0)] -0.0125 .12344 1 0 Mshowa
0 .23008 m
.00625 .23008 L
s
[(2)] -0.0125 .23008 1 0 Mshowa
0 .33672 m
.00625 .33672 L
s
[(4)] -0.0125 .33672 1 0 Mshowa
0 .44336 m
.00625 .44336 L
s
[(6)] -0.0125 .44336 1 0 Mshowa
0 .55 m
.00625 .55 L
s
[(8)] -0.0125 .55 1 0 Mshowa
.125 Mabswid
0 .04346 m
.00375 .04346 L
s
0 .07012 m
.00375 .07012 L
s
0 .09678 m
.00375 .09678 L
s
0 .1501 m
.00375 .1501 L
s
0 .17676 m
.00375 .17676 L
s
0 .20342 m
.00375 .20342 L
s
0 .25674 m
.00375 .25674 L
s
0 .2834 m
.00375 .2834 L
s
0 .31006 m
.00375 .31006 L
s
0 .36338 m
.00375 .36338 L
s
0 .39004 m
.00375 .39004 L
s
0 .4167 m
.00375 .4167 L
s
0 .47002 m
.00375 .47002 L
s
0 .49668 m
.00375 .49668 L
s
0 .52334 m
.00375 .52334 L
s
0 .57666 m
.00375 .57666 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.12106 .61178 m
.12106 .61803 L
s
.31053 .61178 m
.31053 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.68947 .61178 m
.68947 .61803 L
s
.87894 .61178 m
.87894 .61803 L
s
.125 Mabswid
.15895 .61428 m
.15895 .61803 L
s
.19685 .61428 m
.19685 .61803 L
s
.23474 .61428 m
.23474 .61803 L
s
.27264 .61428 m
.27264 .61803 L
s
.34842 .61428 m
.34842 .61803 L
s
.38632 .61428 m
.38632 .61803 L
s
.42421 .61428 m
.42421 .61803 L
s
.46211 .61428 m
.46211 .61803 L
s
.53789 .61428 m
.53789 .61803 L
s
.57579 .61428 m
.57579 .61803 L
s
.61368 .61428 m
.61368 .61803 L
s
.65158 .61428 m
.65158 .61803 L
s
.72736 .61428 m
.72736 .61803 L
s
.76526 .61428 m
.76526 .61803 L
s
.80315 .61428 m
.80315 .61803 L
s
.84105 .61428 m
.84105 .61803 L
s
.08317 .61428 m
.08317 .61803 L
s
.04527 .61428 m
.04527 .61803 L
s
.00738 .61428 m
.00738 .61803 L
s
.91683 .61428 m
.91683 .61803 L
s
.95473 .61428 m
.95473 .61803 L
s
.99262 .61428 m
.99262 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0168 m
1 .0168 L
s
.99375 .12344 m
1 .12344 L
s
.99375 .23008 m
1 .23008 L
s
.99375 .33672 m
1 .33672 L
s
.99375 .44336 m
1 .44336 L
s
.99375 .55 m
1 .55 L
s
.125 Mabswid
.99625 .04346 m
1 .04346 L
s
.99625 .07012 m
1 .07012 L
s
.99625 .09678 m
1 .09678 L
s
.99625 .1501 m
1 .1501 L
s
.99625 .17676 m
1 .17676 L
s
.99625 .20342 m
1 .20342 L
s
.99625 .25674 m
1 .25674 L
s
.99625 .2834 m
1 .2834 L
s
.99625 .31006 m
1 .31006 L
s
.99625 .36338 m
1 .36338 L
s
.99625 .39004 m
1 .39004 L
s
.99625 .4167 m
1 .4167 L
s
.99625 .47002 m
1 .47002 L
s
.99625 .49668 m
1 .49668 L
s
.99625 .52334 m
1 .52334 L
s
.99625 .57666 m
1 .57666 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.04262 .29457 L
.04754 .17843 L
.0522 .09029 L
.05477 .055 L
.05622 .03989 L
.05756 .0291 L
.05869 .02238 L
.05993 .01745 L
.06123 .01497 L
.06244 .01502 L
.06309 .01592 L
.06379 .01758 L
.06506 .02226 L
.06631 .02872 L
.06746 .03621 L
.07286 .08426 L
.07785 .13434 L
.0803 .15586 L
.08255 .1721 L
.08383 .17946 L
.08524 .18582 L
.08597 .18837 L
.08665 .19028 L
.08737 .1918 L
.08815 .19286 L
.0888 .19329 L
.08951 .19329 L
.0908 .19205 L
.09205 .18937 L
.09321 .18567 L
.09457 .18004 L
.09583 .1736 L
.09873 .15562 L
.10458 .11332 L
.10685 .09809 L
.10928 .08432 L
.11067 .07796 L
.11194 .07333 L
.11321 .06986 L
.11441 .06772 L
.11567 .06671 L
.1163 .06667 L
.117 .067 L
.11823 .06849 L
.11938 .07091 L
.12007 .07284 L
.12073 .07497 L
.12197 .07972 L
.12476 .09346 L
Mistroke
.12977 .12431 L
.13222 .13974 L
.13447 .15262 L
.13649 .16237 L
.1387 .17046 L
.13985 .17343 L
.14092 .17537 L
.14205 .17652 L
.14327 .1767 L
.14451 .17575 L
.14521 .17472 L
.14585 .17346 L
.14704 .17039 L
.1483 .16612 L
.15048 .15654 L
.15288 .14342 L
.15781 .11239 L
.16039 .09662 L
.16311 .08247 L
.16426 .07762 L
.16548 .07332 L
.16618 .0713 L
.16682 .06977 L
.16807 .06764 L
.16919 .06673 L
.17041 .06687 L
.17155 .06807 L
.17261 .07009 L
.17367 .073 L
.17467 .07648 L
.17694 .08689 L
.18151 .116 L
.18651 .1523 L
.18914 .16941 L
.19059 .17733 L
.19195 .18354 L
.19312 .18779 L
.19439 .19109 L
.19507 .19228 L
.19579 .19306 L
.19708 .19322 L
.19826 .19194 L
.19935 .18952 L
.20056 .1855 L
.20184 .17967 L
.20424 .16485 L
.20683 .1438 L
.21155 .09755 L
.21581 .05588 L
.21816 .03688 L
Mistroke
.21932 .02927 L
.22039 .02347 L
.22161 .01855 L
.22225 .01673 L
.22294 .01541 L
.22416 .01476 L
.22527 .01614 L
.2264 .01958 L
.22762 .02568 L
.22878 .03375 L
.22984 .04316 L
.23225 .07159 L
.2349 .11342 L
.24024 .2253 L
.24589 .36394 L
.25125 .48625 L
.25358 .52964 L
.25605 .56603 L
.25734 .58045 L
.25803 .58674 L
.25877 .59241 L
.26006 .59954 L
.26128 .60288 L
.2625 .60292 L
.26365 .59995 L
.2649 .59338 L
.2656 .58823 L
.26624 .58266 L
.26893 .55021 L
.27146 .50773 L
.2808 .29242 L
.28568 .17754 L
.28835 .1237 L
.29084 .08189 L
.29354 .04757 L
.29497 .03428 L
.2957 .0288 L
.2965 .02387 L
.29723 .02033 L
.2979 .01783 L
.29854 .01614 L
.29923 .01506 L
.30054 .01501 L
.30172 .01713 L
.3119 .09395 L
.31459 .1212 L
.31746 .14808 L
.32012 .16868 L
.32143 .17679 L
.32264 .18292 L
Mistroke
.32376 .18736 L
.32494 .19075 L
.32613 .19275 L
.32744 .19333 L
.32853 .19255 L
.3297 .19049 L
.3308 .18743 L
.33181 .18374 L
.33427 .17168 L
.33696 .15466 L
.34186 .11916 L
.34425 .10253 L
.34685 .08702 L
.34804 .08112 L
.3493 .07588 L
.35037 .07229 L
.35155 .06933 L
.35226 .06807 L
.3529 .06727 L
.35365 .06675 L
.35435 .06666 L
.3556 .06748 L
.35631 .06847 L
.35697 .06973 L
.3581 .07263 L
.35935 .07685 L
.36188 .08824 L
.37094 .14349 L
.37314 .1556 L
.3755 .16606 L
.37685 .17062 L
.37808 .17372 L
.37931 .17576 L
.38048 .17667 L
.3817 .17655 L
.383 .17521 L
.3841 .17311 L
.38532 .16982 L
.38663 .16522 L
.38803 .15916 L
.39057 .1458 L
.39499 .11821 L
.39982 .08929 L
.40122 .0824 L
.40272 .07624 L
.40413 .07171 L
.40541 .06879 L
.40672 .06707 L
.40746 .06668 L
.40814 .06671 L
Mistroke
.40939 .06771 L
.41071 .07012 L
.4119 .07342 L
.41317 .07809 L
.41546 .08923 L
.42067 .12371 L
.42562 .15921 L
.42833 .17548 L
.42965 .18188 L
.43087 .18663 L
.43218 .19043 L
.43288 .19182 L
.4336 .19281 L
.43435 .1933 L
.43505 .19328 L
.43581 .19271 L
.43662 .19146 L
.43731 .18989 L
.43806 .18766 L
.43941 .18224 L
.44073 .17531 L
.44194 .16758 L
.44696 .1247 L
.45235 .07044 L
.45496 .04687 L
.45624 .03697 L
.45743 .02915 L
.45849 .02346 L
.45965 .01871 L
.46083 .01574 L
.46207 .01472 L
.46326 .01592 L
.4645 .01961 L
.46557 .02479 L
.46673 .03265 L
.46799 .04372 L
.46934 .05851 L
.47176 .09262 L
.47653 .18412 L
.48086 .28647 L
.48596 .41147 L
.48864 .47172 L
.49148 .52641 L
.49396 .56374 L
.49538 .57985 L
.4967 .59127 L
.49791 .59847 L
.49902 .60225 L
.5003 .60322 L
.50152 .60076 L
Mistroke
.50276 .59488 L
.50346 .59009 L
.50411 .58476 L
.50655 .55697 L
.50876 .52216 L
.51111 .47709 L
.52133 .23327 L
.52556 .14056 L
.52789 .09834 L
.53009 .06569 L
.53134 .05069 L
.5327 .03734 L
.53393 .0279 L
.53507 .02146 L
.53614 .01739 L
.53732 .01506 L
.53856 .01495 L
.53972 .01688 L
.54089 .02072 L
.54215 .02674 L
.54441 .04185 L
.54955 .08939 L
.55488 .14207 L
.55749 .16357 L
.55864 .17145 L
.5599 .17883 L
.56099 .18405 L
.56216 .18838 L
.5634 .19151 L
.56456 .19305 L
.5652 .19334 L
.56591 .19319 L
.56719 .1917 L
.56844 .18881 L
.5696 .18494 L
.57184 .17459 L
.57387 .16257 L
.57841 .13045 L
.5833 .09645 L
.58577 .08285 L
.58718 .07669 L
.58847 .07229 L
.58965 .06932 L
.59077 .06751 L
.59196 .06668 L
.59325 .06704 L
.59437 .06841 L
.59556 .07089 L
.59658 .07382 L
.5977 .07784 L
Mistroke
.60328 .10722 L
.60858 .14076 L
.61088 .15377 L
.61334 .16508 L
.61475 .17004 L
.61603 .17342 L
.61732 .17566 L
.61854 .17666 L
.61966 .17662 L
.62089 .1755 L
.62218 .17315 L
.62339 .16991 L
.62554 .16182 L
.62785 .15037 L
.63268 .12086 L
.63793 .08921 L
.63934 .08231 L
.64084 .07615 L
.64212 .072 L
.64285 .07012 L
.64353 .06874 L
.64485 .06704 L
.64554 .06669 L
.64627 .06672 L
.6475 .06773 L
.64819 .06883 L
.64884 .07019 L
.65014 .07388 L
.65136 .07849 L
.65366 .08976 L
.6588 .12395 L
.66381 .15989 L
.66627 .17466 L
.66851 .185 L
.66972 .189 L
.67087 .19165 L
.67208 .19313 L
.67277 .19335 L
.67341 .19315 L
.67411 .19245 L
.67477 .19135 L
.67602 .18811 L
.67671 .18564 L
.67735 .18295 L
.67879 .17548 L
.68101 .16053 L
.68307 .14336 L
.68777 .09731 L
.69016 .07324 L
.69269 .04988 L
Mistroke
.69485 .03339 L
.6961 .0259 L
.69724 .02057 L
.69849 .01662 L
.69914 .01539 L
.69983 .01477 L
.70099 .01532 L
.70226 .01835 L
.70297 .02122 L
.70362 .02457 L
.70508 .03467 L
.70643 .04725 L
.70771 .06193 L
.71246 .13912 L
.71762 .25356 L
.72224 .36782 L
.72721 .48161 L
.72961 .52706 L
.7319 .56163 L
.73395 .58436 L
.7351 .59342 L
.73618 .59923 L
.73742 .60281 L
.73859 .60305 L
.73964 .60067 L
.74077 .59539 L
.74201 .58643 L
.74332 .57351 L
.74566 .54209 L
.74823 .49669 L
.75063 .44625 L
.75607 .31515 L
.7613 .18999 L
.76624 .09409 L
.76898 .05594 L
.77052 .0398 L
.77194 .02847 L
.77314 .0216 L
.77446 .01679 L
.77512 .01544 L
.77583 .01476 L
.77712 .0155 L
.77781 .01687 L
.77845 .01875 L
.77966 .02371 L
.78096 .03095 L
.78236 .04073 L
.78723 .08513 L
.79259 .13857 L
.79552 .16306 L
Mistroke
.79695 .1728 L
.79825 .18015 L
.79949 .18568 L
.80066 .18956 L
.8019 .19219 L
.8026 .19301 L
.80324 .19333 L
.8045 .1928 L
.80522 .19182 L
.8059 .19047 L
.8066 .18862 L
.80725 .18655 L
.80872 .18066 L
.81096 .16881 L
.81341 .1529 L
.81834 .11703 L
.82088 .09972 L
.82363 .08399 L
.82489 .07824 L
.82622 .07333 L
.82736 .07016 L
.82862 .06783 L
.82983 .06675 L
.83094 .06679 L
.83222 .06803 L
.83344 .07036 L
.83456 .07345 L
.8356 .07706 L
.83795 .08761 L
.84314 .11844 L
.84587 .13582 L
.84874 .15254 L
.85127 .16443 L
.8527 .16959 L
.85339 .1716 L
.85404 .17321 L
.85527 .17545 L
.85639 .17654 L
.85759 .17668 L
.8589 .17561 L
.86017 .17338 L
.86137 .17026 L
.86267 .16577 L
.86408 .1598 L
.86959 .12847 L
.8744 .09825 L
.87702 .08423 L
.8783 .07859 L
.87946 .07431 L
.88062 .07093 L
Mistroke
.88171 .0686 L
.88286 .06711 L
.8841 .06666 L
.88539 .06747 L
.88603 .06838 L
.88674 .06975 L
.888 .07313 L
.88918 .07734 L
.89142 .08796 L
.89347 .10013 L
.89808 .13265 L
.90287 .16605 L
.9053 .17939 L
.90668 .18527 L
.90797 .18943 L
.90909 .19187 L
.91027 .19319 L
.91128 .19326 L
.91238 .19221 L
.91357 .18971 L
.91484 .1855 L
.91604 .18009 L
.91714 .17402 L
.92237 .13222 L
.92793 .07644 L
.93021 .05487 L
.93267 .03532 L
.93407 .02656 L
.93536 .02047 L
.93666 .01645 L
.93789 .01478 L
.93904 .01527 L
.94009 .01752 L
.9413 .02235 L
.94244 .02913 L
.9435 .0374 L
.94447 .04669 L
.94667 .07346 L
.94889 .10834 L
.95133 .15465 L
.95626 .26685 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.0147151 0.294302 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.04762 .01472 m
.04762 .01472 L
s
.07143 .01472 m
.07143 .01472 L
s
.09524 .01472 m
.09524 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.14286 .01472 m
.14286 .01472 L
s
.16667 .01472 m
.16667 .01472 L
s
.19048 .01472 m
.19048 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.2381 .01472 m
.2381 .01472 L
s
.2619 .01472 m
.2619 .01472 L
s
.28571 .01472 m
.28571 .01472 L
s
.30952 .01472 m
.30952 .01472 L
s
.33333 .01472 m
.33333 .01472 L
s
.35714 .01472 m
.35714 .01472 L
s
.38095 .01472 m
.38095 .01472 L
s
.40476 .01472 m
.40476 .30902 L
s
.42857 .01472 m
.42857 .30902 L
s
.45238 .01472 m
.45238 .30902 L
s
.47619 .01472 m
.47619 .30902 L
s
.5 .01472 m
.5 .30902 L
s
.52381 .01472 m
.52381 .30902 L
s
.54762 .01472 m
.54762 .30902 L
s
.57143 .01472 m
.57143 .30902 L
s
.59524 .01472 m
.59524 .30902 L
s
.61905 .01472 m
.61905 .01472 L
s
.64286 .01472 m
.64286 .01472 L
s
.66667 .01472 m
.66667 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.71429 .01472 m
.71429 .01472 L
s
.7381 .01472 m
.7381 .01472 L
s
.7619 .01472 m
.7619 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.80952 .01472 m
.80952 .01472 L
s
.83333 .01472 m
.83333 .01472 L
s
.85714 .01472 m
.85714 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.90476 .01472 m
.90476 .01472 L
s
.92857 .01472 m
.92857 .01472 L
s
.95238 .01472 m
.95238 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.04762 .01472 Mdot
.07143 .01472 Mdot
.09524 .01472 Mdot
.11905 .01472 Mdot
.14286 .01472 Mdot
.16667 .01472 Mdot
.19048 .01472 Mdot
.21429 .01472 Mdot
.2381 .01472 Mdot
.2619 .01472 Mdot
.28571 .01472 Mdot
.30952 .01472 Mdot
.33333 .01472 Mdot
.35714 .01472 Mdot
.38095 .01472 Mdot
.40476 .30902 Mdot
.42857 .30902 Mdot
.45238 .30902 Mdot
.47619 .30902 Mdot
.5 .30902 Mdot
.52381 .30902 Mdot
.54762 .30902 Mdot
.57143 .30902 Mdot
.59524 .30902 Mdot
.61905 .01472 Mdot
.64286 .01472 Mdot
.66667 .01472 Mdot
.69048 .01472 Mdot
.71429 .01472 Mdot
.7381 .01472 Mdot
.7619 .01472 Mdot
.78571 .01472 Mdot
.80952 .01472 Mdot
.83333 .01472 Mdot
.85714 .01472 Mdot
.88095 .01472 Mdot
.90476 .01472 Mdot
.92857 .01472 Mdot
.95238 .01472 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.123439 0.05332 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0168 -12 -4.5 ]
[-0.0125 .0168 0 4.5 ]
[-0.0125 .12344 -6 -4.5 ]
[-0.0125 .12344 0 4.5 ]
[-0.0125 .23008 -6 -4.5 ]
[-0.0125 .23008 0 4.5 ]
[-0.0125 .33672 -6 -4.5 ]
[-0.0125 .33672 0 4.5 ]
[-0.0125 .44336 -6 -4.5 ]
[-0.0125 .44336 0 4.5 ]
[-0.0125 .55 -6 -4.5 ]
[-0.0125 .55 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0168 m
.00625 .0168 L
s
[(-2)] -0.0125 .0168 1 0 Mshowa
0 .12344 m
.00625 .12344 L
s
[(0)] -0.0125 .12344 1 0 Mshowa
0 .23008 m
.00625 .23008 L
s
[(2)] -0.0125 .23008 1 0 Mshowa
0 .33672 m
.00625 .33672 L
s
[(4)] -0.0125 .33672 1 0 Mshowa
0 .44336 m
.00625 .44336 L
s
[(6)] -0.0125 .44336 1 0 Mshowa
0 .55 m
.00625 .55 L
s
[(8)] -0.0125 .55 1 0 Mshowa
.125 Mabswid
0 .04346 m
.00375 .04346 L
s
0 .07012 m
.00375 .07012 L
s
0 .09678 m
.00375 .09678 L
s
0 .1501 m
.00375 .1501 L
s
0 .17676 m
.00375 .17676 L
s
0 .20342 m
.00375 .20342 L
s
0 .25674 m
.00375 .25674 L
s
0 .2834 m
.00375 .2834 L
s
0 .31006 m
.00375 .31006 L
s
0 .36338 m
.00375 .36338 L
s
0 .39004 m
.00375 .39004 L
s
0 .4167 m
.00375 .4167 L
s
0 .47002 m
.00375 .47002 L
s
0 .49668 m
.00375 .49668 L
s
0 .52334 m
.00375 .52334 L
s
0 .57666 m
.00375 .57666 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0168 m
1 .0168 L
s
.99375 .12344 m
1 .12344 L
s
.99375 .23008 m
1 .23008 L
s
.99375 .33672 m
1 .33672 L
s
.99375 .44336 m
1 .44336 L
s
.99375 .55 m
1 .55 L
s
.125 Mabswid
.99625 .04346 m
1 .04346 L
s
.99625 .07012 m
1 .07012 L
s
.99625 .09678 m
1 .09678 L
s
.99625 .1501 m
1 .1501 L
s
.99625 .17676 m
1 .17676 L
s
.99625 .20342 m
1 .20342 L
s
.99625 .25674 m
1 .25674 L
s
.99625 .2834 m
1 .2834 L
s
.99625 .31006 m
1 .31006 L
s
.99625 .36338 m
1 .36338 L
s
.99625 .39004 m
1 .39004 L
s
.99625 .4167 m
1 .4167 L
s
.99625 .47002 m
1 .47002 L
s
.99625 .49668 m
1 .49668 L
s
.99625 .52334 m
1 .52334 L
s
.99625 .57666 m
1 .57666 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .17676 m
.02499 .17673 L
.02605 .17664 L
.02729 .17648 L
.02846 .17626 L
.03053 .17571 L
.03279 .1749 L
.03527 .17374 L
.0379 .17222 L
.04262 .16875 L
.05205 .15924 L
.06244 .14554 L
.08274 .11377 L
.09394 .09664 L
.10458 .08276 L
.10945 .07759 L
.11464 .07307 L
.11762 .07098 L
.12033 .06942 L
.12305 .0682 L
.12428 .06776 L
.12562 .06736 L
.12683 .06708 L
.12796 .06688 L
.12915 .06673 L
.13043 .06666 L
.13162 .06666 L
.13275 .06673 L
.13376 .06684 L
.13487 .06702 L
.13606 .06728 L
.13738 .06766 L
.14006 .06868 L
.14254 .06994 L
.14487 .07139 L
.14956 .07509 L
.1547 .08025 L
.16505 .09382 L
.18355 .1253 L
.20481 .16302 L
.21485 .17748 L
.21926 .1826 L
.22412 .18719 L
.2288 .19047 L
.23136 .19176 L
.2325 .19222 L
.23375 .19263 L
.23445 .19282 L
.2351 .19297 L
.23638 .1932 L
Mistroke
.23755 .19332 L
.23879 .19335 L
.23949 .19333 L
.24025 .19327 L
.24097 .19319 L
.24163 .19308 L
.24288 .1928 L
.2442 .19241 L
.24646 .19148 L
.24888 .19013 L
.25325 .18678 L
.25844 .1813 L
.26316 .17495 L
.2731 .15773 L
.28228 .13798 L
.30306 .08618 L
.31283 .06226 L
.32335 .03993 L
.32819 .03152 L
.33328 .02427 L
.33763 .01957 L
.34009 .01758 L
.34238 .01618 L
.34361 .01561 L
.34475 .01521 L
.34599 .0149 L
.34731 .01474 L
.34846 .01472 L
.34953 .01482 L
.3507 .01506 L
.35197 .01547 L
.35308 .01596 L
.3543 .01663 L
.35652 .01824 L
.35867 .0203 L
.36067 .02263 L
.36516 .0294 L
.37012 .03937 L
.38018 .06752 L
.39026 .10594 L
.3995 .14922 L
.42035 .26737 L
.44085 .39376 L
.45994 .49903 L
.4694 .54071 L
.47834 .57132 L
.48329 .5841 L
.48589 .58958 L
.48865 .5944 L
.49097 .59766 L
Mistroke
.4922 .59909 L
.49352 .6004 L
.49473 .60139 L
.49584 .60212 L
.49696 .60268 L
.49802 .60305 L
.49926 .60328 L
.49997 .60332 L
.50061 .60329 L
.5018 .60309 L
.50305 .60267 L
.50418 .6021 L
.50523 .60142 L
.50761 .59929 L
.5102 .59611 L
.51255 .59243 L
.51784 .58146 L
.52237 .56923 L
.52729 .55311 L
.53623 .51693 L
.57703 .28343 L
.5973 .16573 L
.60723 .11702 L
.61632 .07976 L
.62518 .05121 L
.62969 .0398 L
.6345 .03 L
.63704 .02581 L
.63935 .0226 L
.6417 .01991 L
.64386 .01794 L
.64639 .01623 L
.64772 .01559 L
.64839 .01533 L
.64912 .01511 L
.65035 .01484 L
.65149 .01473 L
.65219 .01472 L
.65285 .01475 L
.65409 .01492 L
.65534 .01524 L
.65605 .01548 L
.65669 .01574 L
.65914 .01706 L
.66137 .0187 L
.66371 .02087 L
.6686 .02674 L
.67395 .03507 L
.69236 .07471 L
.71356 .12812 L
Mistroke
.72359 .15098 L
.73285 .16864 L
.74246 .18236 L
.74752 .18745 L
.75007 .18943 L
.75289 .19115 L
.75415 .19176 L
.75535 .19225 L
.75644 .19261 L
.7576 .19292 L
.75885 .19316 L
.76002 .1933 L
.76074 .19334 L
.76141 .19335 L
.76267 .1933 L
.76378 .19317 L
.76496 .19296 L
.76597 .19271 L
.76707 .19237 L
.76953 .19136 L
.77183 .1901 L
.77683 .18638 L
.78228 .1809 L
.79218 .16772 L
.81073 .13582 L
.8301 .10138 L
.8404 .0862 L
.8458 .0797 L
.8515 .07416 L
.85654 .07048 L
.8594 .06893 L
.86077 .06832 L
.86206 .06784 L
.86323 .06747 L
.86451 .06715 L
.86567 .06692 L
.86674 .06678 L
.8679 .06668 L
.86917 .06665 L
.86981 .06667 L
.8705 .06671 L
.87174 .06684 L
.87301 .06705 L
.87418 .06731 L
.87684 .06816 L
.87918 .06918 L
.88167 .07054 L
.88644 .07392 L
.89075 .07779 L
.9008 .08939 L
Mistroke
.91003 .1025 L
.93086 .13547 L
.93996 .14896 L
.94971 .16126 L
.95531 .16694 L
.96041 .17108 L
.96287 .17269 L
.96554 .17414 L
.96806 .17523 L
.97039 .17598 L
.97181 .17631 L
.97315 .17654 L
.97391 .17664 L
.97461 .1767 L
.97538 .17674 L
.97619 .17676 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`009oooool3o`0001kooooo0ol0000Jooooo`Go0000
6_ooool2o`0001cooooo1Ol0000Looooo`?o00007?ooool3o`0004Wooooo0ol00004ooooo`;o0000
8_ooool3o`0002?ooooo0_l0000Tooooo`?o00008_ooool3o`0000Cooooo0_l0000Uooooo`009_oo
ool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool06_ooool01?l0003ooooo
ooooool0000Iooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00007Oooool0
0ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000BOooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`00023ooooo00Go0000ooooooooooooooooo`00000Qooooo`04
o`000?ooooooooooo`0002;ooooo00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00009?ooool0023ooooo1Ol000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo01?ooooo1Ol000000ooooooo0000o`000003o`0001Cooooo1Ol00003
ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00007Oooool00ol0003ooooooooo
o`0Jooooo`Go00006oooool01Ol0003ooooooooooooooooo0000047ooooo1Ol00003ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool5o`0000Gooooo00?o0000oooooooo
ool07oooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Tooooo`009_ooool4o`0001cooooo00Co0000oooo
oooooooo00007_ooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0001kooooo00?o
0000ooooooooool06Oooool01?l0003oooooooooool0000Looooo`Co0000B_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool07oooool01?l0003o
ooooooooool0000Vooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Tooooo`009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo0000
01_ooooo00Go0000ooooooooooooooooo`00000Iooooo`04o`000?ooooooooooo`0001_ooooo00Go
0000ooooooooooooooooo`00000Kooooo`03o`000?oooooo000001cooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00023ooooo1?l0000Rooooo`04
o`000?ooooooooooo`0002;ooooo1?l0000Sooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00009?ooool002Oooooo00?o0000ooooooooool07_ooool2o`0001_ooooo00Go0000oooo
ooooooooooooo`00000Iooooo`04o`000?ooooooooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000Looooo`;o00007Oooool00ol0003oooooooooo`19ooooo`;o00001?ooool01?l0003ooooo
ooooool0000Pooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00008_ooool00ol0
003oooooooooo`0Sooooo`;o00001?ooool01?l0003oooooooooool0000Tooooo`00:?ooool2o`00
01oooooo00?o0000ooooooooool06_ooool3o`0001_ooooo0_l0000Mooooo`?o00007_ooool00ol0
003oooooooooo`0Looooo`;o0000B_ooool00ol0003oooooooooo`03ooooo`;o00008Oooool5o`00
02;ooooo0_l0000Sooooo`Go00008_ooool00ol0003oooooooooo`03ooooo`;o00009Oooool00?oo
oooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool001coooood_l0000Yoooo
om;o00003oooool001Cooooo1Ol00003ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool2o`00023ooooo1Ol00004ooooo`03o`000?oooooo000000Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooo`00000?ooooo`005Oooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo0<kooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo0<kooooo00?o0000ooooooooool03Oooool000kooooo1Ol00003ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool2ool004;ooooo00?oo`00oooooooo
ool07?ooool2ool004;ooooo0_oo000Cooooo`03o`000?oooooooooo01Sooooo1Ol00003ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0Oooooo`03
ool00?oooooooooo00cooooo0_oo000Pooooo`;oo`003_ooool2ool0023ooooo0_oo000>ooooo`03
ool00?oooooooooo01oooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`00
5oooool00ol0003oooooooooo`02ooooo`?o00004Oooool3ool0047ooooo00?oo`00oooooooo0000
7Oooool00ooo003oooooool00011ooooo`?oo`004Oooool2o`0002?ooooo00?o0000ooooooooool0
0oooool2o`0000_ooooo00?oo`00ooooooooool07_ooool2ool000kooooo0_oo000Pooooo`;oo`00
3_ooool2ool0023ooooo0_oo000>ooooo`;oo`007oooool2ool000_ooooo0_l0000?ooooo`005?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool01?oo003ooooo
oooooooo0010ooooo`03ool00?ooooooo`0001cooooo00Coo`00ooooooooooooo`00@?ooool01?oo
003ooooooooooooo000Booooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00Wooooo00?oo`00oooooooo00007oooool00ooo003oooooool0
000=ooooo`;oo`008?ooool2ool000kooooo0_oo000Pooooo`;oo`003_ooool2ool001oooooo00?o
o`00oooooooo00002oooool00ol0003oooooooooo`0=ooooo`005?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool04Oooool01?oo003ooooooooooooo000oooooo`05ool0
0?oooooooooooooooooo00006oooool01?oo003ooooooooooooo0010ooooo`04ool00?oooooooooo
ool001;ooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool02Oooool00ooo003oooooool0000Oooooo`03ool00?ooooooo`0000gooooo0_oo
000Pooooo`;oo`003_ooool2ool0023ooooo0_oo000=ooooo`03ool00?ooooooo`0001oooooo00?o
o`00oooooooo00002oooool00ol0003oooooooooo`0=ooooo`005Oooool3o`0000Cooooo00?o0000
ooooooooool04Oooool01?oo003ooooooooooooo000oooooo`05ool00?oooooooooooooooooo0000
6oooool01Ooo003oooooooooooooooooo`0003oooooo00Coo`00ooooooooooooo`004_ooool00ol0
003oooooooooo`0Oooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`03ool00?ooooooo`00
01oooooo00?oo`00oooooooo00003Oooool2ool0023ooooo00?oo`00oooooooo00003Oooool2ool0
01oooooo00?oo`00oooooooo00003Oooool00ooo003oooooool0000Oooooo`03ool00?ooooooo`00
00_ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool04?ooool01Ooo003o
ooooooooooooooooo`0003oooooo00Goo`00ooooooooooooooooool0000Jooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool0??ooool01Ooo003oooooooooooooooooo`0001;ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`03ool00?ooooooo`0001oooooo00?o
o`00oooooooo00003Oooool2ool001oooooo00Coo`00ooooooooooooo`003?ooool01?oo003ooooo
oooooooo000Nooooo`03ool00?ooooooo`0000gooooo00?oo`00oooooooo00007oooool00ooo003o
ooooool0000;ooooo`03o`000?oooooooooo00gooooo000Looooo`;o00004Oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo03_ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`0Hooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0??ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool09oooool2o`0000[ooooo
00?oo`00oooooooo00007oooool00ooo003oooooool0000<ooooo`04ool00?ooooooooooool001ko
oooo00Coo`00ooooooooooooo`003?ooool01?oo003ooooooooooooo000Nooooo`04ool00?oooooo
ooooool000cooooo00Coo`00ooooooooooooo`007_ooool00ooo003oooooool0000:ooooo`;o0000
3oooool001cooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo03_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool0>oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`03ool00?oo
ooooo`0001oooooo00?oo`00oooooooo00003?ooool01?oo003ooooooooooooo000Nooooo`04ool0
0?ooooooooooool000cooooo00Coo`00ooooooooooooo`007_ooool01?oo003ooooooooooooo000<
ooooo`04ool00?ooooooooooool001gooooo00Coo`00ooooooooooooo`002oooool00ol0003ooooo
ooooo`0=ooooo`007?ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool0>oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool03oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo00Co
o`00ooooooooooooo`007_ooool01?oo003ooooooooooooo000<ooooo`04ool00?ooooooooooool0
01kooooo00Coo`00ooooooooooooo`003?ooool01?oo003ooooooooooooo000Nooooo`04ool00?oo
ooooooooool000cooooo00Coo`00ooooooooooooo`007Oooool01?oo003ooooooooooooo000;oooo
o`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00oooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool05oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo03_ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool02?ooool01?oo003ooooooooooooo000Nooooo`04ool00?ooooooooooool000cooooo00Coo`00
ooooooooooooo`007_ooool01?oo003ooooooooooooo000<ooooo`04ool00?ooooooooooool001ko
oooo00Coo`00ooooooooooooo`003?ooool01?oo003ooooooooooooo000Mooooo`04ool00?oooooo
ooooool000_ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool03oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo03Wooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0>_ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`08ooooo`04ool00?ooooooooooool001kooooo00Goo`00oooooooooooooooo
ool0000;ooooo`04ool00?ooooooooooool001kooooo00Coo`00ooooooooooooo`003?ooool01?oo
003ooooooooooooo000Nooooo`04ool00?ooooooooooool000cooooo00Coo`00ooooooooooooo`00
7Oooool01Ooo003oooooooooooooooooo`0000[ooooo00?o0000ooooooooool03Oooool001cooooo
00?o0000ooooooooool03oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00oooooo
0ooo000Dooooo`;oo`004Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0?ooooo`;oo`005?ooool3ool0017ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool02?ooool01Ooo003oooooooooooooooooo`0000Sooooo0_oo0009ooooo`;o
o`002?ooool01Ooo003oooooooooooooooooo`0000_ooooo00Coo`00ooooooooooooo`002Oooool2
ool000Wooooo0_oo0008ooooo`04ool00?ooooooooooool000cooooo00Coo`00ooooooooooooo`00
2?ooool2ool000[ooooo00?oo`00ooooooooool01_ooool01Ooo003oooooooooooooooooo`0000co
oooo00Goo`00ooooooooooooooooool00007ooooo`;oo`002Oooool2ool000Sooooo00Goo`00oooo
ooooooooooooool0000:ooooo`03o`000?oooooooooo00gooooo000Looooo`;o00004?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00kooooo0_oo00000oooooooo`00ool0000Boooo
o`04ool00?ooooooooooool0013ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0G
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03_ooool01?oo003ooooooooooooo
000Booooo`;oo`0000?oooooool00?ooool04?ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00kooooo00?o0000ooooooooool09oooool2o`0000Wooooo00Goo`00oooooooooooooooo
ool00007ooooo`?oo`002Oooool2ool000Sooooo00Goo`00ooooooooooooooooool0000;ooooo`04
ool00?ooooooooooool000Sooooo0ooo0008ooooo`03ool00?ooooooo`0000Sooooo00Coo`00oooo
ooooooooo`003?ooool01Ooo003oooooooooooooooooo`0000Oooooo0_oo0009ooooo`03ool00?oo
ooooo`0000Oooooo00Goo`00ooooooooooooooooool0000<ooooo`05ool00?oooooooooooooooooo
00001oooool2ool000Wooooo0ooo0007ooooo`05ool00?oooooooooooooooooo00002Oooool2o`00
00oooooo000Looooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`0>ooooo`05ool00?oooooooooooooooooo00004Oooool01Ooo003ooooooooooooooooo
o`00013ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool03_ooool01Ooo003oooooooooooooooooo`00017ooooo00Go
o`00ooooooooooooooooool0000@ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
3_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo00Goo`00oooooooooooo
ooooool00007ooooo`03ool00?ooooooo`0000Sooooo00Coo`00ooooooooooooo`001oooool01Ooo
003oooooooooooooooooo`0000_ooooo00Coo`00ooooooooooooo`002?ooool00ooo003oooooool0
0008ooooo`03ool00?ooooooo`0000Sooooo00Goo`00ooooooooooooooooool0000;ooooo`05ool0
0?oooooooooooooooooo00001oooool00ooo003oooooool00008ooooo`03ool00?ooooooo`0000Oo
oooo00Goo`00ooooooooooooooooool0000<ooooo`05ool00?oooooooooooooooooo00001_ooool0
1?oo003ooooooooooooo0008ooooo`03ool00?ooooooo`0000Oooooo00Goo`00oooooooooooooooo
ool0000:ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00oooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`0>ooooo`05ool00?oooooooooooooooooo0000
4Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
3Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
3_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo00Goo`00oooooooooooo
ooooool00007ooooo`04ool00?ooooooooooool000Oooooo00Coo`00ooooooooooooo`001_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Wooooo00Goo`00ooooooooooooooooool0
0007ooooo`03ool00?ooooooo`0000Sooooo00?oo`00oooooooo00002?ooool01Ooo003ooooooooo
ooooooooo`0000_ooooo00Goo`00ooooooooooooooooool00006ooooo`04ool00?ooooooooooool0
00Sooooo00?oo`00oooooooo00001oooool01Ooo003oooooooooooooooooo`0000_ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooool000Sooooo00?o
o`00oooooooo00001oooool01Ooo003oooooooooooooooooo`0000[ooooo00?o0000ooooooooool0
3Oooool001cooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0>ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo01Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0=ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0>ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool02?ooool01Ooo003oooooooooooooooooo`0000Oooooo
00Coo`00ooooooooooooo`001oooool01?oo003ooooooooooooo0006ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool02Oooool01Ooo003oooooooooooooooooo`0000Oooooo00Coo`00
ooooooooooooo`001oooool01?oo003ooooooooooooo0007ooooo`05ool00?oooooooooooooooooo
00002_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooooooo
ooooo`002?ooool00ooo003oooooool00007ooooo`05ool00?oooooooooooooooooo00002oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`001ooo
ool01?oo003ooooooooooooo0007ooooo`05ool00?oooooooooooooooooo00002_ooool00ol0003o
ooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool03?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00gooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool05Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00cooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool03?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00kooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`08ooooo`05ool00?oooooooooooooooooo
00001oooool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Kooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`09ooooo`05ool00?oooooooooooooooooo00001ooo
ool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Kooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool01?ooool01?oo003ooooooooooooo0007ooooo`05ool00?oooooooooooooooooo00001_ooool0
1Ooo003oooooooooooooooooo`0000_ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`04ooooo`04ool00?ooooooooooool000Oooooo00Coo`00ooooooooooooo`001oooool01Ooo003o
ooooooooooooooooo`0000[ooooo00?o0000ooooooooool03Oooool001cooooo0_l0000@ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0;ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00_ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0<ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`07ooooo`03
ool00?oooooooooo00gooooo00?o0000ooooooooool09oooool2o`0000Wooooo00Goo`00oooooooo
ooooooooool00006ooooo`05ool00?oooooooooooooooooo00001oooool01?oo003ooooooooooooo
0006ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02Oooool01Ooo003ooooooooo
ooooooooo`0000Oooooo00Coo`00ooooooooooooo`001oooool01?oo003ooooooooooooo0006oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool00006ooooo`05ool00?oooooo
oooooooooooo00001_ooool01Ooo003oooooooooooooooooo`0000_ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooool000Oooooo00Goo`00oooooooo
ooooooooool00006ooooo`05ool00?oooooooooooooooooo00002Oooool2o`0000oooooo000Loooo
o`03o`000?oooooooooo00kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0;oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0:oooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00Sooooo00Goo`00ooooooooooooooooool00006ooooo`05ool00?oooooo
oooooooooooo00001oooool01?oo003ooooooooooooo0006ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool02Oooool01Ooo003oooooooooooooooooo`0000Kooooo00Goo`00oooooooo
ooooooooool00007ooooo`04ool00?ooooooooooool000Kooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`08ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool0
1Ooo003oooooooooooooooooo`0000Kooooo00Goo`00ooooooooooooooooool00006ooooo`05ool0
0?oooooooooooooooooo00002oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Co
oooo00Coo`00ooooooooooooo`001oooool01Ooo003oooooooooooooooooo`0000Kooooo00Goo`00
ooooooooooooooooool0000:ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooo
oooo00kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00[ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00_ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooo
oooo00Oooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00Sooooo00Goo`00ooooooooooooooooool00006ooooo`05ool00?oooooooooooooooooo0000
1oooool01Ooo003oooooooooooooooooo`0000Gooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`08ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool01Ooo003o
ooooooooooooooooo`0000Oooooo00Coo`00ooooooooooooo`001_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04
ooooo`05ool00?oooooooooooooooooo00001_ooool01Ooo003oooooooooooooooooo`0000Kooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0000Kooooo00Goo`00oooooooo
ooooooooool00006ooooo`05ool00?oooooooooooooooooo00002_ooool00ol0003oooooooooo`0=
ooooo`005_ooool2o`0000Cooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`07oooo
o`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0;oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0:oooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`07oooo
o`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0=oooo
o`03o`000?oooooooooo023ooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00Goo`00oooo
ooooooooooooool00006ooooo`05ool00?oooooooooooooooooo00001_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`08ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool00005ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00Sooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`05ool0
0?oooooooooooooooooo00001_ooool01Ooo003oooooooooooooooooo`0000Gooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Eooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`07oooo
o`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0:oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`08oooo
o`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`09oooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`07oooo
o`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0=oooo
o`03o`000?oooooooooo01oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`08
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`08
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool00005ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`005Oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool01ooo
ool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02Ooo
ool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02?oo
ool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02Ooo
ool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02?oo
ool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool03Ooo
ool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
2?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
2?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool001Gooooo00Co0000oooooooooooo00000oooool3o`0000kooooo00?oo`00ooooooooool0
2?ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0
2?ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0
2?ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0
3?ooool2o`00027ooooo00Co0000oooooooooooo00001?ooool2o`0000Wooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool02?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`07ooooo`;o00003oooool001Gooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool01oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool02Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool04oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool02Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooooooo
ool01oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00gooooo00?o0000oooooooo
ool07oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Sooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool02?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Eooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`08oooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`07oooo
o`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`08oooo
o`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`08oooo
o`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`09oooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0<oooo
o`03o`000?oooooooooo01oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`08
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`05ool00?oooooooooooooooooo00001Oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00Sooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`08ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`0=ooooo`005_ooool2
o`0000Cooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`08ooooo`03ool00?oooooo
oooo00Oooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooo
oooo00Wooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`09ooooo`03ool00?oooooo
oooo01?ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooo
oooo00Wooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooo
oooo023ooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool0
0006ooooo`05ool00?oooooooooooooooooo00001Oooool00ooo003oooooooooo`08ooooo`03ool0
0?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00007ooooo`05ool00?oooooooooooooo
oooo00001Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool02?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00oooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool00oooool0
1Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`07ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00gooooo00?oo`00
ooooooooool02_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00[ooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00Wooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool02_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00[ooooo00?oo`00
ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00Goo`00
ooooooooooooooooool00006ooooo`05ool00?oooooooooooooooooo00001Oooool00ooo003ooooo
ooooo`08ooooo`03ool00?oooooooooo00?ooooo00Goo`00ooooooooooooooooool00007ooooo`05
ool00?oooooooooooooooooo00001_ooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00oooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool00ooo
ool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`07ooooo`03o`000?oooooooooo00gooooo000Looooo`;o00003_ooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool02_ooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`09ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool02Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`0;ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02_ooool00ooo003ooooooooo
o`0<ooooo`03o`000?oooooooooo02Oooooo0_l00008ooooo`03ool00?oooooooooo00Cooooo00Go
o`00ooooooooooooooooool00006ooooo`05ool00?oooooooooooooooooo00001_ooool01Ooo003o
ooooooooooooooooo`0000Gooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`03oooo
o`05ool00?oooooooooooooooooo00001oooool01Ooo003oooooooooooooooooo`0000Kooooo00Co
o`00ooooooooooooo`001oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00?ooooo
00Goo`00ooooooooooooooooool00006ooooo`05ool00?oooooooooooooooooo00001oooool01Ooo
003oooooooooooooooooo`0000Gooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`04
ooooo`05ool00?oooooooooooooooooo00001_ooool01Ooo003oooooooooooooooooo`0000Kooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Kooooo
0_l0000?ooooo`007?ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo00[ooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool03?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Wooooo00?o
o`00ooooooooool04oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool02oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00_ooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00cooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo00Cooooo00Go
o`00ooooooooooooooooool00006ooooo`04ool00?ooooooooooool000Oooooo00Goo`00oooooooo
ooooooooool00005ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool00oooool01Ooo
003oooooooooooooooooo`0000Oooooo00Goo`00ooooooooooooooooool00006ooooo`04ool00?oo
ooooooooool000Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`03ooooo`05ool0
0?oooooooooooooooooo00001oooool01?oo003ooooooooooooo0007ooooo`05ool00?oooooooooo
oooooooo00001Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Cooooo00Goo`00
ooooooooooooooooool00006ooooo`05ool00?oooooooooooooooooo00001oooool01Ooo003ooooo
ooooooooooooo`0000Gooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`0=ooooo`00
7?ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
3?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
3?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo00Cooooo00Goo`00oooooooooooo
ooooool00006ooooo`04ool00?ooooooooooool000Oooooo00Goo`00ooooooooooooooooool00005
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool00oooool01Ooo003ooooooooooooo
ooooo`0000Oooooo00Coo`00ooooooooooooo`001oooool01?oo003ooooooooooooo0007ooooo`03
ool00?oooooooooo00Oooooo00?oo`00ooooooooool01?ooool01?oo003ooooooooooooo0007oooo
o`04ool00?ooooooooooool000Oooooo00Coo`00ooooooooooooo`001_ooool00ooo003ooooooooo
o`07ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool00006ooooo`05ool0
0?oooooooooooooooooo00001oooool01?oo003ooooooooooooo0006ooooo`03ool00?oooooooooo
00Oooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool03Oooool00ooo003o
ooooooooo`0;ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03Oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`0:ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool02oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0=ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02oooool00ooo003o
ooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ooo003o
ooooooooo`04ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003oooooool00007oooo
o`05ool00?oooooooooooooooooo00001Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooo
oooo00Cooooo00Coo`00ooooooooooooo`001oooool01?oo003ooooooooooooo0007ooooo`04ool0
0?ooooooooooool000Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`04ooooo`04
ool00?ooooooooooool000Oooooo00Coo`00ooooooooooooo`001oooool01?oo003ooooooooooooo
0006ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01?ooool01Ooo003ooooooooo
ooooooooo`0000Oooooo00Coo`00ooooooooooooo`001oooool01?oo003ooooooooooooo0006oooo
o`03ool00?oooooooooo00Oooooo00?o0000ooooooooool03Oooool001cooooo00?o0000oooooooo
ool03Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool03_ooool01Ooo003oooooooooooooooooo`00013ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0;ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool02oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0=ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02oooool00ooo
003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ooo
003oooooooooo`04ooooo`04ool00?ooooooooooool000Sooooo00?oo`00oooooooo00002?ooool0
1?oo003ooooooooooooo0005ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool01?oo
ool01?oo003ooooooooooooo0008ooooo`03ool00?ooooooo`0000Oooooo00Coo`00oooooooooooo
o`001oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooooooo
ooooo`001oooool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Kooooo00?o
o`00ooooooooool01oooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo0000
1oooool00ooo003oooooool00008ooooo`04ool00?ooooooooooool000Kooooo00?oo`00oooooooo
ool01oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0=ooooo`03ool0
0?oooooooooo00_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0?ooooo`04ool0
0?ooooooo`00ool0017ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0;ooooo`03
ool00?oooooooooo017ooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00oooooo00?oo`00ooooooooool00_oo000@ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool01oooool00ooo003oooooooooo`04ooooo`04ool00?ooooooooooool0
00Sooooo00?oo`00oooooooo00002?ooool01?oo003ooooooooooooo0006ooooo`03ool00?oooooo
oooo00Oooooo00?oo`00ooooooooool01?ooool01?oo003ooooooooooooo0008ooooo`?oo`002?oo
ool00ooo003oooooool00007ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01?oo
ool01?oo003ooooooooooooo0008ooooo`;oo`002?ooool01?oo003ooooooooooooo0006ooooo`03
ool00?oooooooooo00Oooooo00?oo`00ooooooooool01Oooool01?oo003ooooooooooooo0007oooo
o`?oo`002?ooool01?oo003ooooooooooooo0006ooooo`03ool00?oooooooooo00Oooooo00?o0000
ooooooooool03Oooool001cooooo0_l0000>ooooo`03ool00?oooooooooo00cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0?ooooo`?oo`004_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00cooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0<oooo
o`05ool00?oooooooooooooooooo00004oooool3ool001;ooooo00Goo`00ooooooooooooooooool0
000>ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool09oooool2o`0000Sooooo00?o
o`00ooooooooool01?ooool01?oo003ooooooooooooo0008ooooo`;oo`002Oooool00ooo003ooooo
ool00007ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01?ooool01?oo003ooooo
oooooooo0008ooooo`;oo`002Oooool00ooo003oooooool00007ooooo`03ool00?oooooooooo00Oo
oooo00?oo`00ooooooooool01?ooool01?oo003ooooooooooooo0008ooooo`;oo`002?ooool01?oo
003ooooooooooooo0006ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooool00009ooooo`;oo`002?ooool01?oo003ooooooooooooo0006ooooo`03ool00?oo
oooooooo00Kooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooo
oooo00cooooo00Goo`00ooooooooooooooooool0000Wooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool03?ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00cooooo00Go
o`00ooooooooooooooooool0000Xooooo`05ool00?oooooooooooooooooo00003oooool00ooo003o
ooooooooo`0;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ooo003o
ooooooooo`05ooooo`03ool00?ooooooo`0001?ooooo00?oo`00oooooooo00001oooool00ooo003o
ooooooooo`07ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo00005?ooool00ooo003o
ooooool00007ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01?ooool01?oo003o
oooooooooooo000Booooo`04ool00?ooooooooooool000Kooooo00?oo`00ooooooooool01oooool0
0ooo003oooooooooo`05ooooo`03ool00?ooooooo`0001?ooooo00?oo`00oooooooo00001oooool0
0ooo003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo
00gooooo00?oo`00ooooooooool03?ooool01?oo003ooooooooooooo000Yooooo`04ool00?oooooo
ooooool000oooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0=ooooo`04ool00?oo
ooooooooool002Sooooo00?oo`00ooooooooool00_oo000?ooooo`03ool00?oooooooooo00_ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo00Gooooo
00?oo`00oooooooo00004oooool00ooo003oooooool00007ooooo`03ool00?oooooooooo00Oooooo
00?oo`00ooooooooool01Oooool2ool001Cooooo00?oo`00oooooooo00001oooool00ooo003ooooo
ooooo`07ooooo`03ool00?oooooooooo00Cooooo0ooo000Dooooo`;oo`001oooool00ooo003ooooo
ooooo`07ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo00005?ooool2ool000Oooooo
00?oo`00ooooooooool01oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003ooooooooo
o`0=ooooo`03ool00?oooooooooo00gooooo0ooo000Zooooo`?oo`003oooool00ooo003ooooooooo
o`0Aooooo`03ool00?oooooooooo00gooooo0ooo000Zooooo`?oo`004?ooool00ooo003ooooooooo
o`0;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ooo003ooooooooo
o`05ooooo`;oo`005Oooool2ool000Oooooo00?oo`00ooooooooool01oooool00ooo003ooooooooo
o`05ooooo`;oo`005?ooool2ool000Sooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`06ooooo`;oo`005?ooool2ool000Oooooo00?oo`00ooooooooool01oooool00ooo003ooooooooo
o`05ooooo`?oo`005?ooool2ool000Oooooo00?oo`00ooooooooool01oooool00ol0003ooooooooo
o`0=ooooo`007?ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo00kooooo00?oo`00
ooooooooool0:_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo017ooooo00?oo`00
ooooooooool03_ooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00oooooo00?oo`00
ooooooooool02oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo00?oo`00
ooooooooool09Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool05?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01cooooo00?oo`00
ooooooooool01oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0<oooo
o`03ool00?oooooooooo04gooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1=oooo
o`03ool00?oooooooooo00_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`07oooo
o`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0Uoooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`0=oooo
o`007?ooool2o`0000gooooo00?oo`00ooooooooool0COooool00ooo003oooooooooo`0Aooooo`03
ool00?oooooooooo04gooooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0Wooooo`;o
00002?ooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool09Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo02Kooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo00Kooooo0_l0000?ooooo`00
7?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo04gooooo00?oo`00ooooooooool0
4?ooool00ooo003oooooooooo`1>ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool0
1oooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
9_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool0
1oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0<ooooo`03ool00?oo
oooooooo04gooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`1>ooooo`03ool00?oo
oooooooo00_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`07ooooo`03ool00?oo
oooooooo02Gooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0Uooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo02Kooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`005?ooool5
o`0000?ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`1>ooooo`03ool00?oooooo
oooo00oooooo00?oo`00ooooooooool0C_ooool00ooo003oooooooooo`0;ooooo`03o`000?oooooo
oooo01kooooo1Ol00004ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool09Oooool0
0ooo003oooooooooo`07ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool09_ooool0
0ooo003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`1>ooooo`03ool00?oooooo
oooo00oooooo00?oo`00ooooooooool0C_ooool00ooo003oooooooooo`0;ooooo`03o`000?oooooo
oooo01oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`07ooooo`03ool00?oo
oooooooo02Gooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0Uooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo02Kooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`005_ooool0
0ol0003oooooooooo`03ooooo`?o00003?ooool00ooo003oooooooooo`1>ooooo`03ool00?oooooo
oooo00oooooo00?oo`00ooooooooool0C_ooool00ooo003oooooooooo`0:ooooo`;o00008_ooool0
0ol0003oooooooooo`04ooooo`;o00002?ooool00ooo003oooooooooo`0Uooooo`03ool00?oooooo
oooo00Oooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo02Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooo
oooo00Gooooo0_l0000?ooooo`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00cooooo00?oo`00ooooooooool0C_ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo
04oooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo
00Oooooo00?oo`00ooooooooool09Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
02Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo
00Kooooo00?o0000ooooooooool03Oooool001Cooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0C_ooool00ooo003oooooooooo`0?oooo
o`03ool00?oooooooooo04oooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0Noooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`06ooooo`03ool00?oooooo
oooo02Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo02Kooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`005?ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`1>
ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0Coooool00ooo003oooooooooo`0:
ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00Kooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo02Oooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Vooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`06ooooo`03o`000?oo
oooooooo00gooooo000Eooooo`?o00001?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooo
oooo04kooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`1?ooooo`03ool00?oooooo
oooo00[ooooo00?o0000ooooooooool07oooool3o`0000Gooooo00?o0000ooooooooool01_ooool0
0ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool09oooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool03Oooool0
01cooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`1>ooooo`03ool00?oooooooooo
00oooooo00?oo`00ooooooooool0Coooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
02Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo
00Kooooo00?o0000ooooooooool03Oooool001cooooo0_l0000<ooooo`03ool00?oooooooooo04oo
oooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`1?ooooo`03ool00?oooooooooo00[o
oooo00?o0000ooooooooool09oooool2o`0000Oooooo00?oo`00ooooooooool09_ooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`0Vooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool09oooool00ooo003o
ooooooooo`05ooooo`;o00003oooool001cooooo00?o0000ooooooooool02oooool00ooo003ooooo
ooooo`1?ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0D?ooool00ooo003ooooo
ooooo`0:ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ooo003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool09oooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`0Wooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool03Oooool001cooooo00?o
0000ooooooooool02oooool00ooo003oooooooooo`1?ooooo`03ool00?oooooooooo00kooooo00?o
o`00ooooooooool0D?ooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool01_ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool09oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo02Kooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Kooooo00?o
0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`1?
ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0D?ooool00ooo003oooooooooo`0:
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0V
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0W
ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool03Oooool001cooooo00?o0000oooo
ooooool02oooool00ooo003oooooooooo`1?ooooo`03ool00?oooooooooo00kooooo00?oo`00oooo
ooooool0D?ooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool01_ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool09oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo02Kooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Kooooo00?o0000oooo
ooooool03Oooool001cooooo0_l0000<ooooo`03ool00?oooooooooo053ooooo00?oo`00oooooooo
ool03Oooool00ooo003oooooooooo`1@ooooo`03ool00?oooooooooo00[ooooo00?o0000oooooooo
ool09oooool2o`0000Oooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo02Oooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Vooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`05ooooo`;o
00003oooool001cooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`1@ooooo`03ool0
0?oooooooooo00gooooo00?oo`00ooooooooool0D?ooool00ooo003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0Vooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo02Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Wooooo`03ool0
0?oooooooooo00Kooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02ooo
ool00ooo003oooooooooo`1@ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0DOoo
ool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_oo
ool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool09ooo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool03Ooo
ool001cooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`1@ooooo`03ool00?oooooo
oooo00gooooo00?oo`00ooooooooool0DOooool00ooo003oooooooooo`09ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo02Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Wooooo`03ool00?oooooo
oooo00Kooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02oooool00ooo
003oooooooooo`1@ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0DOooool00ooo
003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ooo
003oooooooooo`0Wooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool09oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`0Wooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool03Oooool001co
oooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`1Aooooo`03ool00?oooooooooo00go
oooo00?oo`00ooooooooool0DOooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Oo
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool001cooooo0_l0000;ooooo`03ool00?oooooooooo057ooooo
00?oo`00ooooooooool03Oooool00ooo003oooooooooo`1Aooooo`03ool00?oooooooooo00Wooooo
00?o0000ooooooooool09oooool2o`0000Oooooo00?oo`00ooooooooool09oooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`0Wooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool09oooool00ooo003ooooo
ooooo`05ooooo`;o00003oooool001cooooo00?o0000ooooooooool02_ooool00ooo003ooooooooo
o`1Aooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0DOooool00ooo003ooooooooo
o`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ooo003ooooooooo
o`0Wooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool09oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0Xooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03Oooool001cooooo00?o0000
ooooooooool02_ooool00ooo003oooooooooo`1Aooooo`03ool00?oooooooooo00gooooo00?oo`00
ooooooooool0DOooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool01_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool09oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Sooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00Gooooo00?o0000
ooooooooool03Oooool001Kooooo0ol00003ooooo`03o`000?oooooooooo00[ooooo00?oo`00oooo
ooooool0DOooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo05;ooooo00?oo`00oooo
ooooool02Oooool00ol0003oooooooooo`0Pooooo`?o00001?ooool00ol0003oooooooooo`06oooo
o`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Woooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`0=oooo
o`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?oo`00oooooooo
ool0DOooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo05;ooooo00?oo`00oooooooo
ool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool09oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Sooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00Gooooo00?o0000oooooooo
ool03Oooool001Cooooo1Ol00003ooooo`?o00002_ooool00ooo003oooooooooo`1Aooooo`03ool0
0?oooooooooo00cooooo00?oo`00ooooooooool0D_ooool00ooo003oooooooooo`08ooooo`;o0000
8?ooool5o`0000Cooooo0_l00007ooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
:?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool0
1?ooool2o`0000oooooo000Dooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
2Oooool00ooo003oooooooooo`1Cooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0
D_ooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo02Sooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool0:?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Sooooo00?oo`00oooooooo
ool01Oooool00ol0003oooooooooo`0=ooooo`005Oooool00ol0003oooooo`000004ooooo`03o`00
0?oooooooooo00Wooooo00?oo`00ooooooooool0Doooool00ooo003oooooooooo`0;ooooo`03ool0
0?oooooooooo05;ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Xooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo02Sooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Xooooo`03ool0
0?oooooooooo00Gooooo00?o0000ooooooooool03Oooool001Kooooo0_l00004ooooo`03o`000?oo
oooooooo00Wooooo00?oo`00ooooooooool0Doooool00ooo003oooooooooo`0;ooooo`03ool00?oo
oooooooo05;ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`;o00001Ooo
ool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0:?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool01Ooo
ool00ol0003oooooooooo`0=ooooo`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00?oo`00ooooooooool0Doooool00ooo003oooooooooo`0;ooooo`03ool00?oooooo
oooo05?ooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Xooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo02Sooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooo
oooo00Gooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02Oooool00ooo
003oooooooooo`1Cooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0Doooool00ooo
003oooooooooo`08ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool00ooo
003oooooooooo`0Xooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0:Oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0Xooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03Oooool001co
oooo0_l0000:ooooo`03ool00?oooooooooo05?ooooo00?oo`00ooooooooool02oooool00ooo003o
ooooooooo`1Cooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool09oooool2o`0000Ko
oooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Wo
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`04ooooo`;o00003oooool001cooooo
00?o0000ooooooooool02Oooool00ooo003oooooooooo`1Cooooo`03ool00?oooooooooo00_ooooo
00?oo`00ooooooooool0Doooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Sooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00Gooooo
00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02Oooool00ooo003ooooooooo
o`1Cooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0Doooool00ooo003ooooooooo
o`08ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool00ooo003ooooooooo
o`0Xooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0:Oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0Xooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03Oooool001cooooo00?o0000
ooooooooool02?ooool00ooo003oooooooooo`1Dooooo`03ool00?oooooooooo00_ooooo00?oo`00
ooooooooool0Doooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool01Oooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool0:Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Sooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00Gooooo00?o0000
ooooooooool03Oooool001cooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`1Doooo
o`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0E?ooool00ooo003oooooooooo`08oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Xoooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Yoooo
o`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03Oooool001cooooo00?o0000oooooooo
ool02?ooool00ooo003oooooooooo`1Dooooo`03ool00?oooooooooo00[ooooo00?oo`00oooooooo
ool0E?ooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool01Oooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool0:Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Sooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00Gooooo00?o0000oooooooo
ool03Oooool001cooooo0_l00009ooooo`03ool00?oooooooooo05Cooooo00?oo`00ooooooooool0
2_ooool00ooo003oooooooooo`1Dooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool0
9oooool2o`0000Kooooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo02Wooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Xooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`04ooooo`;o0000
3oooool001cooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`1Dooooo`03ool00?oo
oooooooo00[ooooo00?oo`00ooooooooool0E?ooool00ooo003oooooooooo`08ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Yooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo02Sooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Zooooo`03ool00?oo
oooooooo00Cooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02?ooool0
0ooo003oooooooooo`1Eooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0E?ooool0
0ooo003oooooooooo`08ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool0
0ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0:Oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool03Oooool0
01cooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`1Eooooo`03ool00?oooooooooo
00Wooooo00?oo`00ooooooooool0E?ooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
02Sooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo
00Cooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01oooool00ooo003o
ooooooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0EOooool00ooo003o
ooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`0Yooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0:Oooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo02Sooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0Zooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool03Oooool001cooooo
0_l00008ooooo`03ool00?oooooooooo05Kooooo00?oo`00ooooooooool02Oooool00ooo003ooooo
ooooo`1Eooooo`03ool00?oooooooooo00Oooooo00?o0000ooooooooool09oooool2o`0000Gooooo
00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Wooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`03ooooo`;o00003oooool001cooooo00?o
0000ooooooooool01oooool00ooo003oooooooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?o
o`00ooooooooool0EOooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool01?ooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool0:Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02Wooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00Cooooo00?o
0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`1F
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0EOooool00ooo003oooooooooo`07
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0Z
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo02Wooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Z
ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool03Oooool001Gooooo0ol00004oooo
o`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0E_ooool00ooo003oooooooooo`09oooo
o`03ool00?oooooooooo05Gooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`0Ooooo
o`?o00001Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02[ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0:_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00oooo
ooooool01?ooool00ol0003oooooooooo`0=ooooo`005?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`1Fooooo`03ool00?oooooooooo
00Wooooo00?oo`00ooooooooool0EOooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo
01kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?oo`00
ooooooooool0:_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Wooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool0:_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo000Doooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`07ooooo`03ool00?oooooo
oooo05Kooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1Eooooo`03ool00?oooooo
oooo00Oooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool01?ooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool0:Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00Cooooo00?o
0000ooooooooool03Oooool001Cooooo1?l00004ooooo`?o00001_ooool00ooo003oooooooooo`1G
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0E_ooool00ooo003oooooooooo`06
ooooo`;o00008?ooool4o`0000Gooooo0_l00005ooooo`03ool00?oooooooooo02[ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool0:_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00
ooooooooool00oooool2o`0000oooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ooo003oooooooooo`1Gooooo`03ool00?oooooooooo00Sooooo00?oo`00oooo
ooooool0E_ooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02[ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0:_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00oooo
ooooool01?ooool00ol0003oooooooooo`0=ooooo`005Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Kooooo00?oo`00ooooooooool0Eoooool00ooo003oooooooooo`08ooooo`03
ool00?oooooooooo05Kooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0Zooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo02[ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Zooooo`03
ool00?oooooooooo00Cooooo00?o0000ooooooooool03Oooool001Kooooo0_l00004ooooo`03o`00
0?oooooooooo00Kooooo00?oo`00ooooooooool0F?ooool00ooo003oooooooooo`07ooooo`03ool0
0?oooooooooo05Kooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`0Pooooo`;o0000
1Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00Goo`00oooooooooooo
ooooool0000/ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool01?ooool00ol0003o
ooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo05Sooooo
00?oo`00ooooooooool01oooool00ooo003oooooooooo`1Fooooo`03ool00?oooooooooo00Oooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo
00Goo`00ooooooooooooooooool0000/ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool0:_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00oooooooo
ool01?ooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0000Oooooo00?oo`00ooooooooool0
F?ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo05Oooooo00?oo`00ooooooooool0
1_ooool00ol0003oooooooooo`0Wooooo`;o00001Oooool00ooo003oooooooooo`0[ooooo`05ool0
0?oooooooooooooooooo0000;?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00?o
oooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo05Sooooo
00?oo`00ooooooooool01oooool00ooo003oooooooooo`1Gooooo`03ool00?oooooooooo00Kooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo
00Goo`00ooooooooooooooooool0000/ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool0:_ooool01Ooo003oooooooooooooooooo`0002gooooo00?oo`00ooooooooool01?ooool00ol0
003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo05So
oooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`1Gooooo`03ool00?oooooooooo00Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_o
oooo00Goo`00ooooooooooooooooool0000/ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0:_ooool01Ooo003oooooooooooooooooo`0002gooooo00?oo`00ooooooooool01?ooool0
0ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo
05Wooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`1Gooooo`03ool00?oooooooooo
00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
02_ooooo00Goo`00ooooooooooooooooool0000/ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool0:_ooool01Ooo003oooooooooooooooooo`0002kooooo00?oo`00ooooooooool00ooo
ool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`05ooooo`03ool00?oooooo
oooo05Wooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`1Gooooo`03ool00?oooooo
oooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooo
oooo02_ooooo00Goo`00ooooooooooooooooool0000/ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool0:_ooool01Ooo003oooooooooooooooooo`0002kooooo00?oo`00ooooooooool0
0oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`05ooooo`03ool00?oo
oooooooo05Wooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`1Gooooo`03ool00?oo
oooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03ool00?oo
oooooooo02cooooo00Goo`00ooooooooooooooooool0000/ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool0:_ooool01Ooo003oooooooooooooooooo`0002kooooo00?oo`00oooooooo
ool00oooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0000Kooooo00?oo`00ooooooooool0
FOooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo05Oooooo00?oo`00ooooooooool0
1_ooool00ol0003oooooooooo`0Wooooo`;o00001?ooool00ooo003oooooooooo`0/ooooo`05ool0
0?oooooooooooooooooo0000;?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[o
oooo00Goo`00ooooooooooooooooool0000^ooooo`03ool00?oooooooooo00;ooooo0_l0000?oooo
o`007?ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo05Wooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`1Hooooo`03ool00?oooooooooo00Kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo02cooooo00Goo`00oooooooo
ooooooooool0000]ooooo`04ool00?ooooooooooool002gooooo00Goo`00ooooooooooooooooool0
000^ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000
ooooooooool01Oooool00ooo003oooooooooo`1Iooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool0F?ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool00oooool00ooo003oooooooooo`0/ooooo`05ool00?oooooooooooooooooo0000;Ooo
ool01?oo003ooooooooooooo000^ooooo`04ool00?ooooooooooool002kooooo00?oo`00oooooooo
ool00oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`05ooooo`03ool0
0?oooooooooo05[ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`1Hooooo`03ool0
0?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03ool0
0?oooooooooo02cooooo00Goo`00ooooooooooooooooool0000]ooooo`04ool00?ooooooooooool0
02kooooo00Coo`00ooooooooooooo`00;_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooo
oooo00gooooo000Looooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0Foooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo05Wooooo00?oo`00ooooooooool01Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0;?ooool01Ooo
003oooooooooooooooooo`0002gooooo00Coo`00ooooooooooooo`00;_ooool01?oo003ooooooooo
oooo000^ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool03Oooool001cooooo0_l0
0005ooooo`03ool00?oooooooooo05_ooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool09oooool2o`0000Cooooo00?o
o`00ooooooooool0;?ooool01Ooo003oooooooooooooooooo`0002gooooo00Coo`00oooooooooooo
o`00;_ooool01?oo003ooooooooooooo000^ooooo`03ool00?oooooooooo00;ooooo0_l0000?oooo
o`007?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05_ooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo02cooooo00Goo`00oooooooo
ooooooooool0000]ooooo`04ool00?ooooooooooool002kooooo00Coo`00ooooooooooooo`00;_oo
ool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooo
oooo00Cooooo00?oo`00ooooooooool0Foooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo05Wooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00?ooooo00?oo`00ooooooooool0;?ooool01?oo003ooooooooooooo000^ooooo`04ool00?oo
ooooooooool002kooooo00Coo`00ooooooooooooo`00;_ooool00ooo003oooooooooo`03ooooo`03
o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0
Foooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo05Wooooo00?oo`00ooooooooool0
1Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
;?ooool01?oo003ooooooooooooo000^ooooo`04ool00?ooooooooooool002kooooo00Coo`00oooo
ooooooooo`00;_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo000Eoooo
o`?o00001?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05_ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`1Jooooo`03ool00?oooooooooo00Gooooo00?o0000oooo
ooooool07oooool3o`0000Gooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0/oooo
o`04ool00?ooooooooooool002kooooo00Coo`00ooooooooooooo`00;_ooool01?oo003ooooooooo
oooo000^ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool03Oooool001Cooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0
Foooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo05[ooooo00?oo`00ooooooooool0
1Oooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo02cooooo00Coo`00ooooooooooooo`00;_ooool01?oo
003ooooooooooooo000^ooooo`04ool00?ooooooooooool002kooooo00?oo`00ooooooooool00ooo
ool00ol0003oooooooooo`0=ooooo`005?ooool01Ol0003ooooooooooooooooo000000?ooooo0ol0
0004ooooo`03ool00?oooooooooo05cooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`1Kooooo`03ool00?oooooooooo00?ooooo0_l0000Pooooo`05o`000?ooooooooooooooool00000
1?ooool2o`0000Cooooo00?oo`00ooooooooool0;Oooool00ooo003oooooool0000^ooooo`04ool0
0?ooooooooooool002kooooo00Coo`00ooooooooooooo`00;_ooool00ooo003oooooooooo`02oooo
o`;o00003oooool001Gooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo00?oo`00oooooooo
ool0GOooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05_ooooo00?oo`00oooooooo
ool01?ooool00ol0003oooooooooo`0Oooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo02gooooo00?oo`00oooooooo0000;_ooool01?oo003ooooooooooooo000^oooo
o`04ool00?ooooooooooool002kooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0=
ooooo`005?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool0
0ooo003oooooooooo`1Mooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0G?ooool0
0ooo003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0;Oooool00ooo003oooooool0
000^ooooo`04ool00?ooooooooooool002kooooo00?oo`00oooooooo0000;oooool00ooo003ooooo
ooooo`03ooooo`03o`000?oooooooooo00gooooo000Dooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`1Looooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool0
7_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ooo003o
ooooooooo`0]ooooo`03ool00?ooooooo`0002kooooo00Coo`00ooooooooooooo`00;_ooool00ooo
003oooooool0000`ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool03Oooool001Go
oooo0ol00004ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0G_ooool01Ooo003o
ooooooooooooooooo`0005kooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0Ooooo
o`?o00001Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo02kooooo00?oo`00oooo
oooo0000;_ooool01?oo003ooooooooooooo000^ooooo`03ool00?ooooooo`00033ooooo00?oo`00
ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo05kooooo00Goo`00ooooooooooooooooool0001Nooooo`03ool00?oooooo
oooo00Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03ool00?oooooo
oooo02kooooo00?oo`00oooooooo0000;oooool2ool002oooooo00?oo`00oooooooo0000<?ooool0
0ooo003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Looooo`;o00001?ooool00ooo
003oooooooooo`1Nooooo`05ool00?oooooooooooooooooo0000G_ooool00ooo003oooooooooo`04
ooooo`03o`000?oooooooooo02Oooooo0_l00003ooooo`03ool00?oooooooooo02kooooo00?oo`00
oooooooo0000;oooool2ool002oooooo00?oo`00oooooooo0000<?ooool01?oo003ooooooooooooo
ool2o`0000oooooo000Looooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0G_ooool0
1Ooo003oooooooooooooooooo`0005oooooo00?oo`00ooooooooool00oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0;_ooool00ooo003oooooool0
000_ooooo`;oo`00;oooool00ooo003oooooool0000`ooooo`03ool00?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool001cooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`1O
ooooo`04ool00?ooooooooooool0063ooooo00?oo`00ooooooooool00oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0;_ooool00ooo003oooooool0
000_ooooo`;oo`00;oooool00ooo003oooooool0000`ooooo`03ool00?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool001cooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`1P
ooooo`03ool00?ooooooo`00063ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0;_ooool2ool0033ooooo0_oo000`
ooooo`;oo`00<?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Loooo
o`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0H?ooool00ooo003oooooool0001Poooo
o`;oo`001?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?oo`00oooo
ooooool0;_ooool2ool0033ooooo0_oo000`ooooo`;oo`00<?ooool00ooo003oooooooooo`02oooo
o`03o`000?oooooooooo00gooooo000Looooo`;o00000oooool00ooo003oooooooooo`1Pooooo`?o
o`00HOooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo02Oooooo0_l00003ooooo`03
ool00?oooooooooo02oooooo00?oo`00ooooooooool0;_ooool2ool0033ooooo0_oo000`ooooo`04
ool00?ooooooooooooooo`;o00003oooool001cooooo00?o0000ooooooooool0c_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo0<kooooo00?o0000ooooooooool03Oooool001cooooo
00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o0000:Oooool00ol0003ooooo
o`000007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000003oooool001coooood_l0
000Yooooom;o00003oooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooo
nOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooo
nOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooo
nOooool00?oooooo8oooool3o`0001_ooooo1Ol0000Looooo`?o00006oooool2o`0001cooooo0ol0
000Looooo`Go00007?ooool3o`0001Sooooo000Rooooo`Go00000oooool2o`0002Sooooo0ol00004
ooooo`;o0000:Oooool2o`0002_ooooo0ol00004ooooo`;o0000:?ooool5o`0000?ooooo0_l0000c
ooooo`05o`000?ooooooooooooooool000006oooool01?l0003oooooooooool0000Mooooo`03o`00
0?oooooooooo01Wooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Looooo`04
o`000?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`00000Gooooo`008oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`0002_ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Xooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo0000;?ooool5o`0000Gooooo00?o0000ooooooooool04_ooool5o`0000?ooooo00?o
0000ooooooooool05Oooool5o`0000?ooooo00?o0000ooooooooool06Oooool01?l0003ooooooooo
ool0000Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Eooooo`007?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Pooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Oo
oooo00Co0000oooooooooooo0000:oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000dooooo`;o00007_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo0000
7?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo0_l0000Hooooo`009Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0002Oooooo00Co0000oooooooooooo0000:oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0002[ooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000001gooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool0000Looooo`03
o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo
01Gooooo000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000X
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo0000<_ooool01Ol0003ooooooooooooo
oooo000001[ooooo00Go0000ooooooooooooooooo`00000Looooo`;o00006oooool01?l0003ooooo
ooooool0000Kooooo`;o00007Oooool01Ol0003ooooooooooooooooo000001_ooooo00Go0000oooo
ooooooooooooo`00000Gooooo`008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00009oooool2o`0000Cooooo00Co0000oooooooooooo00009oooool01?l0003ooooo
ooooool0000Zooooo`;o00001?ooool01?l0003oooooooooool0000Wooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool0000cooooo`?o00007?ooool3o`0001kooooo00?o
0000ooooooooool06_ooool2o`0001gooooo00?o0000ooooooooool07?ooool3o`0001gooooo0ol0
000Hooooo`008oooool3o`0000Cooooo0_l0000Yooooo`03o`000?oooooooooo00?ooooo0_l0000Y
ooooo`;o0000;?ooool00ol0003oooooooooo`03ooooo`;o0000:Oooool3o`0000Cooooo0_l0003o
ooooo`_ooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo000Poooooloo0000:?oo
oooBo`0000oooooo000Jooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000001oooooo1Ol0
0004ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool0000?ooooo`006Oooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooooooo
o`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`?o003o0_ooool3o`00o`;ooooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003o0_ooool3
o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l^ooooo`?o003o0_ooool3
o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`04ooooool00?oo003oo`00o`;ooooo0ol0
0?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol0
0?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`03o`000?oooooooooo01kooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo00gooooo
000Iooooo`04o`000?ooooooooooo`0000?ooooo1?l00003o`00o`;o00000ol00?l2o`0000?o003o
0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o
00Co0000o`00ool00?oo003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o
00000ol00?l2o`0000?o003o0ol000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o
000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00Co000000?o003oo`00
0?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000Co003oo`00
0?l0003o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o00Co0000
o`00ool00?oo003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol0
0?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`?o00006Ooo
ool5o`0000?ooooo00?o0000ooooooooool01?ooool2o`0004Kooooo0ooo000looooo`?oo`00A_oo
ool2o`0000oooooo000Iooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`04ooooool00?oo003oo`00o`;ooooo0ol00?l2ooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2
ooooo`?o003o0_ooool3o`00o`04ooooool00?oo003oo`00o`;ooooo0ol00?l2ooooo`?o003o0_oo
ool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_oo
ool3o`00o`;ooooo0ol00?l2ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`14ooooo`05ool00?oooooooooooooooooo0000>_ooool2ool000;ooooo
0_oo0015ooooo`03o`000?oooooooooo00gooooo000Iooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool0DOooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0D?ooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`13ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0=oooool2ool0
00Cooooo00?oo`00ooooooooool0@oooool00ol0003oooooooooo`0=ooooo`006Oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0@oooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo03Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`12ooooo`03o`000?oo
oooooooo00gooooo000Jooooo`;o00001?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo01kooooo0ol0
0005ooooo`03o`000?oooooooooo04;ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0fooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0@Oooool00ol0003ooooooooo
o`0=ooooo`008?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0@Ooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo03Cooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`11ooooo`03o`000?oooooooooo00gooooo000Pooooo`;o0000D_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0003ooooooooo
o`0Vooooo`;o0000@_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo03Cooooo00?o
o`00ooooooooool01oooool00ooo003oooooooooo`0oooooo`;o00003oooool0023ooooo00?o0000
ooooooooool0DOooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo043ooooo00?oo`00ooooooooool02?oo
ool00ooo003oooooooooo`0booooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0@?oo
ool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0?oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo03;ooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`0oooooo`03o`000?oooooooooo00gooooo000P
ooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0oooooo`03ool00?oo
oooooooo00Wooooo00?oo`00ooooooooool0<_ooool00ooo003oooooooooo`09ooooo`03ool00?oo
oooooooo03oooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0DOooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo03kooooo00?oo`00ooooooooool02oooool00ooo003ooooooooo
o`0`ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0?oooool00ol0003ooooooooo
o`0=ooooo`008?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05_oo
ool5ool002?ooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0`ooooo`03ool00?oo
oooooooo00_ooooo00?oo`00ooooooooool08Oooool5ool001Sooooo00?o0000ooooooooool03Ooo
ool0023ooooo0_l0001Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`1@ooooo`03o`000?oooooooooo02Kooooo0_l0000Fooooo`;oo`001?ooool00ooo003ooooooooo
o`0Oooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0<?ooool00ooo003ooooooooo
o`0;ooooo`03ool00?oooooooooo01oooooo0_oo0004ooooo`;oo`005_ooool2o`0000oooooo000P
ooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Dooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`0=ooooo`03ool00?oo
oooooooo02kooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Nooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`008?ooool0
0ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04oooool00ooo003ooooooooo
o`07ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool03Oooool00ooo003ooooooooo
o`0^ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool07Oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000
ooooooooool0DOooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool02?oo
ool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0;_oo
ool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool02?oo
ool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooo
oooo057ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo00[ooooo00?o
o`00ooooooooool06_ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo02gooooo00?o
o`00ooooooooool03_ooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo00Wooooo00?o
o`00ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`1A
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03o`000?oo
oooooooo02Kooooo0_l0000Booooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool06?oo
ool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo02cooooo00?oo`00ooooooooool03ooo
ool00ooo003oooooooooo`0Jooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool04?oo
ool2o`0000oooooo000Pooooo`;o0000D_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo017ooooo00?o
o`00ooooooooool03?ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo013ooooo00?o
o`00ooooooooool0;?ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01Sooooo00?o
o`00ooooooooool03Oooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo00gooooo000P
ooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03ool00?oo
oooooooo00kooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Aooooo`03ool00?oo
oooooooo02_ooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0Hooooo`03ool00?oo
oooooooo00gooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`008?ooool0
0ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`1@ooooo`03o`000?oooooooooo01oooooo0_l00005ooooo`03o`000?oooooooooo00oooooo00?o
o`00ooooooooool03oooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01;ooooo00?o
o`00ooooooooool0:_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo01Oooooo00?o
o`00ooooooooool03oooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000P
ooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo053ooooo00?o0000ooooooooool07_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00kooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Eooooo`03ool0
0?oooooooooo01;ooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`0Booooo`03ool0
0?oooooooooo01Gooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool07_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool04Oooool00ooo003o
ooooooooo`0Eooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool0:Oooool00ooo003o
ooooooooo`0Booooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool04oooool00ooo003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo057ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000oooooooo
ool07_ooool01?l0003oooooooooool00004ooooo`;o00003_ooool00ooo003oooooooooo`0Coooo
o`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Yoooo
o`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Coooo
o`03ool00?oooooooooo00cooooo0_l0000?ooooo`008?ooool2o`0005;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool07_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool05?ooool0
0ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0:Oooool0
0ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool05Oooool0
0ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo
057ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000
ooooooooool07_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00cooooo00?o
o`00ooooooooool05Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01Cooooo00?o
o`00ooooooooool0:?ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo017ooooo00?o
o`00ooooooooool05oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000P
ooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo053ooooo00?o0000ooooooooool07oooool2o`0000Gooooo00?o0000ooooooooool02ooo
ool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool05Ooo
ool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool04?oo
ool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool03Ooo
ool0023ooooo00?o0000ooooooooool0DOooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[ooooo00?o
o`00ooooooooool06?ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01Kooooo00?o
o`00ooooooooool09oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00oooooo00?o
o`00ooooooooool06Oooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo000>
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`1A
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03o`000?oo
oooooooo02Kooooo0_l0000;ooooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool03_oo
ool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo02Oooooo00?oo`00ooooooooool05Ooo
ool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool02Ooo
ool2o`0000oooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03
ool00?oooooooooo01[ooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Gooooo`03
ool00?oooooooooo02Oooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0=ooooo`03
ool00?oooooooooo01[ooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`00
3Oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooooooo`?o0000DOooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Coooool2o`0002Sooooo00?o0000
ooooooooool02?ooool00ooo003oooooooooo`0Looooo`03ool00?oooooooooo00cooooo00?oo`00
ooooooooool06?ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo01Oooooo00?oo`00
ooooooooool03Oooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo00Wooooo00?o0000
ooooooooool03Oooool000gooooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooooooo
oooo000005?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo01kooooo
00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo02Kooooo
00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01cooooo
0_oo0009ooooo`03o`000?oooooooooo00gooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo
1?l00004ooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03
ool00?oooooooooo01oooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Jooooo`03
ool00?oooooooooo02Gooooo00?oo`00ooooooooool06Oooool00ooo003oooooooooo`0:ooooo`03
ool00?oooooooooo01oooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`00
3Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0DOooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo0_oo000Sooooo`03ool00?oooooooooo
00Wooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo
01Wooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Pooooo`;oo`001_ooool00ol0
003oooooooooo`0=ooooo`003_ooool2o`0000Sooooo1Ol00003ooooo`03o`000?oooooooooo057o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000oooo
ooooool09_ooool2o`0000?ooooo0ooo000Uooooo`03ool00?oooooooooo00Oooooo00?oo`00oooo
ooooool06oooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo01[ooooo00?oo`00oooo
ooooool02?ooool00ooo003oooooooooo`0Rooooo`?oo`000oooool2o`0000oooooo000Pooooo`03
o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool07?ooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo
01_ooooo00?oo`00ooooooooool01Oooool2ool002cooooo00?o0000ooooooooool03Oooool0023o
oooo00?o0000ooooooooool0DOooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02cooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo02Cooooo00?oo`00oooo
ooooool07Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02cooooo00?o0000oooo
ooooool03Oooool0023ooooo0_l0001Booooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0;Oooool5ool0
023ooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`0Nooooo`Goo`00;oooool00ol0
003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0Doooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo05;ooooo00?o0000oooo
ooooool03Oooool0023ooooo00?o0000ooooooooool0DOooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`;o0000E?ooool00ooo
003oooooooooo`0Sooooo`03ool00?oooooooooo057ooooo0_l0000?ooooo`008?ooool00ol0003o
ooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1@oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Doooool00ooo003oooooooooo`0Soooo
o`03ool00?oooooooooo05;ooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000oooooooo
ool0DOooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo05?ooooo00?oo`00ooooooooool08oooool00ooo
003oooooooooo`1Booooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo057o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1Cooooo`03ool00?oooooooooo02;ooooo00?oo`00oooo
ooooool0Doooool00ol0003oooooooooo`0=ooooo`008?ooool2o`0005;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool07Oooool5o`00
00Cooooo00?o0000ooooooooool0Doooool00ooo003oooooooooo`0Rooooo`03ool00?oooooooooo
05?ooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0DOooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Noooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Doooool00ooo003oooooooooo`0R
ooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000oooo
ooooool0DOooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo0_l0001Eooooo`03ool00?oooooo
oooo027ooooo00?oo`00ooooooooool0D_ooool2o`0000oooooo000Pooooo`03o`000?oooooooooo
057ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Cooooo00?oo`00
ooooooooool08Oooool00ooo003oooooooooo`1Cooooo`03o`000?oooooooooo00gooooo000Poooo
o`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo053ooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0E?ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo05?ooooo00?o
0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0DOooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Mooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`1Dooooo`03ool00?oooooooooo023ooooo
00?oo`00ooooooooool0E?ooool00ol0003oooooooooo`0=ooooo`008?ooool2o`0005;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool0
7_ooool3o`0000Gooooo00?o0000ooooooooool0E?ooool00ooo003oooooooooo`0Pooooo`03ool0
0?oooooooooo05Cooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0DOoo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo05Cooooo00?oo`00ooooooooool08?ooool00ooo003ooooo
ooooo`1Dooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo057ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool0
9_ooool2o`0005Kooooo00?oo`00ooooooooool07oooool00ooo003oooooooooo`1Cooooo`;o0000
3oooool0023ooooo00?o0000ooooooooool0DOooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Gooooo
00?oo`00ooooooooool07oooool00ooo003oooooooooo`1Dooooo`03o`000?oooooooooo00gooooo
000Pooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Eooooo`03ool0
0?oooooooooo01oooooo00?oo`00ooooooooool0E?ooool00ol0003oooooooooo`0=ooooo`008?oo
ool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0EOooool00ooo003ooooo
ooooo`0Nooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool03Oooool0023ooooo0_l0
001Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0EOooool00ooo003oooooooooo`0Nooooo`03ool0
0?oooooooooo05Gooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0DOoo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0003ooooo
ooooo`0Vooooo`;o0000E_ooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo05Cooooo
0_l0000?ooooo`008?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
E_ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool0
3Oooool001Wooooo0ol00004ooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`1Fooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0EOooool00ol0003ooooo
ooooo`0=ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo057ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`1Fooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0
EOooool00ol0003oooooooooo`0=ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo053ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l01?oooooo003oo`00
ool00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003oDOooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool07?ooool00ooo003ooooo
ooooo`1Fooooo`03o`000?oooooooooo00gooooo000Jooooo`03o`000?oooooooooo00?ooooo0ol0
001@ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o00Coooooo`00ool00?oo003o
0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00oe3ooooo0_l0000Xooooo`03o`00
0?oooooooooo05Kooooo00?oo`00ooooooooool07?ooool00ooo003oooooooooo`1Fooooo`03o`00
0?oooooooooo00gooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0D?oo
ool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`04ooooool00?oo003oo`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?mAooooo`03o`000?oooooooooo02Kooooo
0_l0001Gooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool0EOooool2o`0000oooooo
000Iooooo`;o00001Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0E_ooool00ooo003oooooooooo`0Looooo`03ool00?oooooooooo05Kooooo00?o
0000ooooooooool03Oooool001[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Eoooool00ooo003oooooooooo`0K
ooooo`03ool00?oooooooooo05Kooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000oooo
ooooool0boooool00ol0003oooooooooo`0Oooooo`?o00001?ooool00ol0003oooooooooo`1Goooo
o`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool0Eoooool00ol0003oooooooooo`0=oooo
o`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo01[ooooo00?oo`00oooooooo
ool0Eoooool00ol0003oooooooooo`0=ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool0
7Oooool5o`0000Cooooo0_l0001Hooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool0
E_ooool2o`0000oooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool07Ooo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo05Oooooo00?oo`00ooooooooool0
6_ooool00ooo003oooooooooo`1Gooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oo
oooooooo0<_ooooo00?o0000ooooooooool07_ooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo05Oooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`1Gooooo`03o`000?oo
oooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool07oooool2
o`0000Gooooo00?o0000ooooooooool0F?ooool00ooo003oooooooooo`0Iooooo`03ool00?oooooo
oooo05Oooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F?ooool00ooo
003oooooooooo`0Hooooo`03ool00?oooooooooo05Sooooo00?o0000ooooooooool03Oooool0023o
oooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05So
oooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`1Hooooo`03o`000?oooooooooo00go
oooo000Pooooo`;o0000c?ooool00ol0003oooooooooo`0Vooooo`;o0000FOooool00ooo003ooooo
ooooo`0Hooooo`03ool00?oooooooooo05Oooooo0_l0000?ooooo`008?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0F?ooool00ooo003ooooooooo
o`0Hooooo`03ool00?oooooooooo05Sooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Sooooo00?oo`00
ooooooooool06?ooool00ooo003oooooooooo`1Hooooo`03o`000?oooooooooo00gooooo000Poooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Hoooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool0FOooool00ol0003oooooooooo`0=oooo
o`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0FOooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo05Wooooo00?o0000oooooooo
ool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`;o0000
F_ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo05Sooooo0_l0000?ooooo`008?oo
ool2o`000<cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Iooooo`03ool00?oo
oooooooo01Kooooo00?oo`00ooooooooool0FOooool00ol0003oooooooooo`0=ooooo`008?ooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0FOooool0
0ooo003oooooooooo`0Fooooo`03ool00?oooooooooo05Wooooo00?o0000ooooooooool03Oooool0
023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
05Wooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`1Jooooo`03o`000?oooooooooo
00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`1Iooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool0F_ooool00ol0003o
ooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0F_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo05[ooooo
00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003ooooooooo
o`0Vooooo`;o0000Foooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo05Wooooo0_l0
000?ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1J
ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0F_ooool00ol0003oooooooooo`0=
ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0F_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo05[ooooo00?o0000oooo
ooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Nooooo`?o
00001Oooool00ol0003oooooooooo`1Jooooo`03ool00?oooooooooo01?ooooo00?oo`00oooooooo
ool0Foooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`00
0?oooooooooo01gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05_o
oooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`1Kooooo`03o`000?oooooooooo00go
oooo000=ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003ooooo
ooooo`3;ooooo`03o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo05_ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`1Kooooo`03
o`000?oooooooooo00gooooo000>ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool07Oooool4o`0000Go
oooo0_l0001Looooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0F_ooool2o`0000oo
oooo000>ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0ol0003:ooooo`;o
00007oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05_ooooo00?oo`00oooooooo
ool04_ooool00ooo003oooooooooo`1Kooooo`03o`000?oooooooooo00gooooo000>ooooo`03o`00
0?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00003=ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool0G?ooool00ol0003oooooooooo`0=ooooo`003_ooool00ol0003ooooo
ooooo`07ooooo`Co00001?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01oooooo
0_l00005ooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool04Oooool00ooo003ooooo
ooooo`1Looooo`03o`000?oooooooooo00gooooo000=ooooo`;o00002Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`1Looooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0G?ooool00ol0003ooooooooo
o`0=ooooo`003_ooool00ol0003oooooooooo`07ooooo`Go00000oooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo02Kooooo0_l0001Mooooo`03ool00?oooooooooo013ooooo00?oo`00
ooooooooool0Foooool2o`0000oooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo013ooooo00?oo`00oooo
ooooool0G?ooool00ol0003oooooooooo`0=ooooo`008?ooool2o`000<cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo013ooooo00?oo`00oooooooo
ool0G?ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0G?ooool00ooo003oooooooooo`0?ooooo`03ool0
0?oooooooooo05gooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0booo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05gooooo00?oo`00ooooooooool03_oo
ool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooo
oooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Mooooo`03ool00?oooooo
oooo00kooooo00?oo`00ooooooooool0GOooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0
003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo0_l0001Nooooo`03ool00?oooooooooo
00kooooo00?oo`00ooooooooool0G?ooool2o`0000oooooo000Pooooo`03o`000?oooooooooo0<_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Mooooo`03ool00?oooooooooo00ko
oooo00?oo`00ooooooooool0GOooool00ol0003oooooooooo`0=ooooo`008?ooool2o`000<cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Mooooo`03ool00?oooooooooo00gooooo
00?oo`00ooooooooool0G_ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0G_ooool00ooo003ooooooooo
o`0<ooooo`03ool00?oooooooooo05kooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05kooooo00?oo`00
ooooooooool03?ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooooooo00gooooo000Poooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool2o`0005oooooo00?oo`00oooo
ooooool03?ooool00ooo003oooooooooo`1Mooooo`;o00003oooool0023ooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05kooooo00?oo`00oooooooo
ool03?ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`00
0?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Nooooo`03ool0
0?oooooooooo00_ooooo00?oo`00ooooooooool0Goooool00ol0003oooooooooo`0=ooooo`008?oo
ool2o`000<cooooo00?o0000ooooooooool07_ooool3o`0000Gooooo00?o0000ooooooooool0Gooo
ool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo05oooooo00?o0000ooooooooool03Ooo
ool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Mooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`1Oooooo`03ool00?oooooooooo00[ooooo00?o
o`00ooooooooool0Goooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo05oooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`1Oooooo`03o`000?oo
oooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool07_ooool3
o`0000Gooooo0_l0001Qooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0Goooool2
o`0000oooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool07Oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0H?ooool00ooo003oooooooooo`08
ooooo`03ool00?oooooooooo063ooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000oooo
ooooool0boooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`1Pooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0H?ooool0
0ol0003oooooooooo`0=ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool07_ooool3o`00
00Gooooo00?o0000ooooooooool0HOooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
067ooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo067ooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`1Qooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool09_ooool2o`0006;ooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`1Pooooo`;o00003oooool0023ooooo00?o0000ooooooooool0boooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`1Rooooo`03o`000?oooooooooo00gooooo000Hooooo`Go00000oooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo06;ooooo00?o0000ooooooooool03Oooool001Wooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0Hoooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo06?ooooo00?o0000
ooooooooool03Oooool001[ooooo00?o0000ooooooooool00oooool3o`000<[ooooo0_l0000Xoooo
o`03o`000?oooooooooo06?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1Soooo
o`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06Cooooo00?oo`00oooooooo
ool00_oo001Uooooo`03o`000?oooooooooo00gooooo000Hooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00Go0000oooooooo
ooooooooo`00000Xooooo`;o0000IOooool4ool006Gooooo0_l0000?ooooo`006?ooool01Ol0003o
oooooooooooooooo000000?ooooocol0000Xooooo`03o`000?oooooooooo0<kooooo00?o0000oooo
ooooool03Oooool001Wooooo0ol0003kooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool0000?ooooo`00oooooolHooooom;o00003oooool00?oo
oooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oo
oooonOooool00?oooooonOooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-8.42587, \
-4.02496, 0.0631478, 0.0897574}, {{262.875, 490.688}, {303, 162.25}} -> \
{-48.5007, -4.02488, 0.126296, 0.0897569}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-27.7031, -2.91994, 0.203806, 0.0164882}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-12.1252, -17.9261, 0.031574, 0.0897572}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["M = 8", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = 8;\)\), "\[IndentingNewLine]", 
    \(\(g1d\  = \ 
        DiscreteListPlot[Table[{n, \ pulse[n, \ m]}, {n, \(-20\), 20}], Blue, 
          Frame \[Rule] True, \ Axes \[Rule] {True, False}, \ 
          PlotRange \[Rule] {\(- .05\), 2.05}, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g2d\  = \ 
        Plot[Evaluate[
            dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-\[Pi]\), \ \[Pi]}, 
          PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g3d\  = \ 
        Plot[Evaluate[dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-2\) \[Pi], \ 
            2  \[Pi]}, PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, \ 
          Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g4d\  = \ 
        Plot[Evaluate[dtft2\  /. \ M \[Rule] m], {\[Theta], \ \(-4\) \[Pi], \ 
            4  \[Pi]}, PlotStyle \[Rule] Red, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ Axes \[Rule] False, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1d, g2d}, {g3d, g4d}}], \ 
        ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.120768 0.0283853 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12077 -6 -4.5 ]
[-0.0125 .12077 0 4.5 ]
[-0.0125 .26269 -6 -4.5 ]
[-0.0125 .26269 0 4.5 ]
[-0.0125 .40462 -12 -4.5 ]
[-0.0125 .40462 0 4.5 ]
[-0.0125 .54655 -12 -4.5 ]
[-0.0125 .54655 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-6)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-4)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-2)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(2)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(4)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(6)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.08317 0 m
.08317 .00375 L
s
.12106 0 m
.12106 .00375 L
s
.15895 0 m
.15895 .00375 L
s
.23474 0 m
.23474 .00375 L
s
.27264 0 m
.27264 .00375 L
s
.31053 0 m
.31053 .00375 L
s
.38632 0 m
.38632 .00375 L
s
.42421 0 m
.42421 .00375 L
s
.46211 0 m
.46211 .00375 L
s
.53789 0 m
.53789 .00375 L
s
.57579 0 m
.57579 .00375 L
s
.61368 0 m
.61368 .00375 L
s
.68947 0 m
.68947 .00375 L
s
.72736 0 m
.72736 .00375 L
s
.76526 0 m
.76526 .00375 L
s
.84105 0 m
.84105 .00375 L
s
.87894 0 m
.87894 .00375 L
s
.91683 0 m
.91683 .00375 L
s
.00738 0 m
.00738 .00375 L
s
.99262 0 m
.99262 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12077 m
.00625 .12077 L
s
[(0)] -0.0125 .12077 1 0 Mshowa
0 .26269 m
.00625 .26269 L
s
[(5)] -0.0125 .26269 1 0 Mshowa
0 .40462 m
.00625 .40462 L
s
[(10)] -0.0125 .40462 1 0 Mshowa
0 .54655 m
.00625 .54655 L
s
[(15)] -0.0125 .54655 1 0 Mshowa
.125 Mabswid
0 .14915 m
.00375 .14915 L
s
0 .17754 m
.00375 .17754 L
s
0 .20592 m
.00375 .20592 L
s
0 .23431 m
.00375 .23431 L
s
0 .29108 m
.00375 .29108 L
s
0 .31947 m
.00375 .31947 L
s
0 .34785 m
.00375 .34785 L
s
0 .37624 m
.00375 .37624 L
s
0 .43301 m
.00375 .43301 L
s
0 .46139 m
.00375 .46139 L
s
0 .48978 m
.00375 .48978 L
s
0 .51816 m
.00375 .51816 L
s
0 .09238 m
.00375 .09238 L
s
0 .064 m
.00375 .064 L
s
0 .03561 m
.00375 .03561 L
s
0 .00723 m
.00375 .00723 L
s
0 .57493 m
.00375 .57493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.08317 .61428 m
.08317 .61803 L
s
.12106 .61428 m
.12106 .61803 L
s
.15895 .61428 m
.15895 .61803 L
s
.23474 .61428 m
.23474 .61803 L
s
.27264 .61428 m
.27264 .61803 L
s
.31053 .61428 m
.31053 .61803 L
s
.38632 .61428 m
.38632 .61803 L
s
.42421 .61428 m
.42421 .61803 L
s
.46211 .61428 m
.46211 .61803 L
s
.53789 .61428 m
.53789 .61803 L
s
.57579 .61428 m
.57579 .61803 L
s
.61368 .61428 m
.61368 .61803 L
s
.68947 .61428 m
.68947 .61803 L
s
.72736 .61428 m
.72736 .61803 L
s
.76526 .61428 m
.76526 .61803 L
s
.84105 .61428 m
.84105 .61803 L
s
.87894 .61428 m
.87894 .61803 L
s
.91683 .61428 m
.91683 .61803 L
s
.00738 .61428 m
.00738 .61803 L
s
.99262 .61428 m
.99262 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .12077 m
1 .12077 L
s
.99375 .26269 m
1 .26269 L
s
.99375 .40462 m
1 .40462 L
s
.99375 .54655 m
1 .54655 L
s
.125 Mabswid
.99625 .14915 m
1 .14915 L
s
.99625 .17754 m
1 .17754 L
s
.99625 .20592 m
1 .20592 L
s
.99625 .23431 m
1 .23431 L
s
.99625 .29108 m
1 .29108 L
s
.99625 .31947 m
1 .31947 L
s
.99625 .34785 m
1 .34785 L
s
.99625 .37624 m
1 .37624 L
s
.99625 .43301 m
1 .43301 L
s
.99625 .46139 m
1 .46139 L
s
.99625 .48978 m
1 .48978 L
s
.99625 .51816 m
1 .51816 L
s
.99625 .09238 m
1 .09238 L
s
.99625 .064 m
1 .064 L
s
.99625 .03561 m
1 .03561 L
s
.99625 .00723 m
1 .00723 L
s
.99625 .57493 m
1 .57493 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.04262 .31765 L
.04754 .20481 L
.0522 .11434 L
.05477 .07532 L
.05613 .05848 L
.05756 .0436 L
.05877 .03349 L
.0601 .02491 L
.06131 .01941 L
.06244 .01619 L
.06309 .01518 L
.06379 .01472 L
.06506 .01556 L
.06631 .01833 L
.06746 .0225 L
.06883 .02923 L
.07007 .03681 L
.07286 .05783 L
.07791 .10336 L
.08255 .14334 L
.0852 .16159 L
.08655 .16907 L
.088 .17557 L
.08876 .17831 L
.08946 .1804 L
.09016 .18212 L
.09081 .18334 L
.09157 .18432 L
.0924 .18485 L
.09312 .18485 L
.0939 .1844 L
.09516 .18268 L
.09586 .18119 L
.09651 .17953 L
.09897 .1708 L
.1017 .15745 L
.10458 .14077 L
.10949 .11104 L
.1119 .09804 L
.11412 .08801 L
.11535 .0835 L
.11669 .07945 L
.11804 .07641 L
.11878 .0752 L
.11947 .07437 L
.12069 .07358 L
.12181 .07365 L
.1231 .07463 L
.12432 .07642 L
Mistroke
.12548 .07884 L
.12653 .08159 L
.12888 .08946 L
.13311 .10774 L
.13768 .12922 L
.14027 .14018 L
.14269 .14864 L
.1439 .15206 L
.14505 .15472 L
.14568 .15594 L
.14637 .15705 L
.14758 .15845 L
.14888 .15917 L
.14954 .15923 L
.15026 .15905 L
.15154 .15812 L
.15274 .15658 L
.15387 .15456 L
.15506 .15187 L
.15719 .14585 L
.16197 .12833 L
.16679 .10947 L
.16944 .10051 L
.17193 .09385 L
.17335 .09102 L
.1741 .08984 L
.17489 .08884 L
.17555 .08819 L
.17628 .08769 L
.17757 .08736 L
.17887 .08773 L
.17961 .08824 L
.18028 .0889 L
.18158 .09067 L
.18281 .09292 L
.18517 .09859 L
.18739 .10523 L
.19244 .12278 L
.19505 .13169 L
.19779 .13993 L
.20013 .14547 L
.20146 .14785 L
.20269 .14952 L
.20384 .15058 L
.20493 .15111 L
.20591 .15121 L
.20697 .1509 L
.20813 .15008 L
.20935 .14869 L
.2104 .1471 L
Mistroke
.21155 .14493 L
.21648 .13184 L
.2211 .11676 L
.22607 .1021 L
.22743 .09895 L
.22889 .09616 L
.22959 .09504 L
.23025 .09414 L
.23149 .09284 L
.2327 .09211 L
.23397 .09189 L
.23505 .09217 L
.23624 .09296 L
.23752 .09436 L
.23889 .09645 L
.24137 .10161 L
.24604 .11485 L
.25099 .13045 L
.25303 .13625 L
.25523 .14158 L
.25648 .14408 L
.25764 .14597 L
.25874 .14739 L
.2599 .14844 L
.26112 .14904 L
.26242 .14911 L
.26365 .14862 L
.26476 .14771 L
.26607 .14612 L
.2675 .14377 L
.27008 .13806 L
.27546 .12221 L
.2784 .1129 L
.28115 .1049 L
.28376 .09866 L
.2849 .09648 L
.28614 .09456 L
.28684 .09368 L
.2875 .09303 L
.28879 .09216 L
.28951 .09194 L
.29016 .09189 L
.29092 .09204 L
.29163 .09236 L
.2928 .09329 L
.29404 .09479 L
.2951 .09647 L
.29627 .09872 L
.30128 .11218 L
.3061 .12793 L
Mistroke
.30864 .1358 L
.31133 .1429 L
.31246 .14535 L
.31368 .14755 L
.31438 .14859 L
.31502 .1494 L
.31627 .15056 L
.31739 .15111 L
.31861 .15117 L
.31977 .15071 L
.32084 .14982 L
.32153 .14903 L
.32227 .14798 L
.32362 .14559 L
.32614 .1396 L
.3318 .12124 L
.33696 .10354 L
.33948 .0964 L
.34177 .09145 L
.3429 .08968 L
.34413 .08831 L
.34529 .08756 L
.34636 .08736 L
.34749 .08767 L
.34874 .08864 L
.35005 .09034 L
.35127 .09255 L
.35389 .09907 L
.35629 .10685 L
.3617 .1278 L
.36427 .13773 L
.36702 .14707 L
.36835 .15085 L
.36961 .15386 L
.37074 .15604 L
.37196 .15779 L
.37326 .15891 L
.37392 .15917 L
.37464 .15922 L
.37592 .15869 L
.37712 .15748 L
.37785 .15641 L
.37854 .15516 L
.37984 .15223 L
.38276 .14311 L
.39237 .10008 L
.39514 .08869 L
.39649 .08399 L
.39774 .08033 L
.39885 .07766 L
Mistroke
.40007 .07546 L
.4013 .07406 L
.4026 .07352 L
.40384 .07393 L
.40501 .07516 L
.40606 .07696 L
.4072 .07965 L
.40844 .08341 L
.40975 .08829 L
.41212 .0991 L
.421 .15125 L
.42339 .16411 L
.42469 .17016 L
.4259 .17501 L
.42702 .17874 L
.42804 .18142 L
.42918 .18354 L
.43039 .18473 L
.43169 .18473 L
.43288 .18351 L
.4342 .18081 L
.43486 .17891 L
.43559 .1764 L
.43813 .16439 L
.4405 .14899 L
.44925 .07258 L
.45165 .05213 L
.4542 .03382 L
.45525 .02776 L
.45638 .02237 L
.45762 .01799 L
.45879 .0155 L
.46005 .01473 L
.46077 .01523 L
.46143 .01634 L
.46214 .01819 L
.46278 .02051 L
.46352 .02393 L
.46422 .02793 L
.46662 .04715 L
.46797 .0618 L
.46922 .0777 L
.47402 .15829 L
.47911 .26869 L
.48407 .38511 L
.48879 .48623 L
.49084 .52309 L
.49303 .55578 L
.49429 .57106 L
.49543 .5825 L
Mistroke
.49657 .59156 L
.49765 .59778 L
.4988 .60186 L
.50001 .60332 L
.50104 .60223 L
.50217 .59857 L
.5034 .59178 L
.5047 .58131 L
.50707 .55452 L
.50979 .51237 L
.51236 .46327 L
.51719 .35572 L
.52589 .16007 L
.52828 .11622 L
.53085 .07687 L
.53327 .04825 L
.53435 .03836 L
.53549 .02973 L
.53666 .02301 L
.53774 .01857 L
.53903 .0155 L
.5402 .01472 L
.54142 .01583 L
.54211 .01728 L
.54275 .01911 L
.54392 .02365 L
.54515 .02997 L
.54768 .04688 L
.55004 .0663 L
.55541 .11531 L
.55759 .13415 L
.55997 .1523 L
.56206 .16545 L
.56321 .17134 L
.56429 .17595 L
.56494 .17828 L
.56565 .18041 L
.56688 .18313 L
.56813 .18462 L
.56928 .18486 L
.57033 .18415 L
.57149 .1824 L
.5727 .17953 L
.57383 .17598 L
.57644 .16495 L
.57886 .15209 L
.58431 .11908 L
.58903 .09354 L
.59032 .08798 L
.59171 .0829 L
Mistroke
.59292 .07935 L
.59423 .07641 L
.59548 .07455 L
.59664 .07367 L
.59775 .07357 L
.59893 .07427 L
.6001 .07572 L
.60119 .07776 L
.60324 .08314 L
.60563 .09163 L
.60783 .10098 L
.6128 .12431 L
.61749 .14403 L
.61884 .14853 L
.62012 .15214 L
.62129 .15482 L
.62252 .15699 L
.6236 .15829 L
.62478 .15908 L
.62586 .15921 L
.62687 .15883 L
.62806 .15776 L
.62915 .15623 L
.63035 .15396 L
.63161 .15097 L
.64159 .11472 L
.64446 .10424 L
.64718 .09612 L
.64836 .09331 L
.64962 .09089 L
.65027 .08986 L
.65099 .08893 L
.65226 .08781 L
.65358 .08737 L
.65483 .08761 L
.65595 .08837 L
.65717 .08978 L
.6585 .09194 L
.65991 .09491 L
.66245 .10172 L
.67199 .13409 L
.67437 .14096 L
.67562 .14399 L
.67695 .14667 L
.67811 .14854 L
.67938 .15004 L
.68054 .15088 L
.68162 .15121 L
.68275 .15107 L
.68382 .15049 L
Mistroke
.68479 .14962 L
.68583 .14829 L
.68697 .14642 L
.68818 .144 L
.69035 .13867 L
.69973 .10909 L
.7023 .10201 L
.7037 .09879 L
.70501 .09628 L
.70612 .09456 L
.70731 .09317 L
.70799 .09261 L
.70864 .09222 L
.70984 .09189 L
.7109 .09204 L
.71206 .09266 L
.71327 .09382 L
.71441 .09534 L
.71644 .09907 L
.71862 .10428 L
.72812 .13321 L
.73068 .1399 L
.73208 .14294 L
.73339 .1453 L
.73462 .14703 L
.73532 .14779 L
.73595 .14834 L
.73708 .14897 L
.73827 .14915 L
.73959 .14876 L
.74033 .14827 L
.741 .14767 L
.74231 .14605 L
.74354 .14403 L
.74631 .13795 L
.74932 .1295 L
.7544 .1135 L
.75717 .10536 L
.75978 .09902 L
.76091 .0968 L
.76199 .09504 L
.76323 .09347 L
.76437 .0925 L
.76562 .09195 L
.76679 .09195 L
.76807 .09252 L
.76878 .09308 L
.76943 .09376 L
.77063 .09538 L
.77175 .09731 L
Mistroke
.7743 .10305 L
.77945 .11858 L
.78419 .13389 L
.78652 .14044 L
.78867 .14538 L
.78989 .14758 L
.79119 .14937 L
.79249 .15058 L
.79323 .15099 L
.79393 .15119 L
.79513 .15109 L
.79623 .15052 L
.79744 .14937 L
.79872 .14757 L
.80001 .14519 L
.80138 .14207 L
.80386 .13515 L
.80949 .1159 L
.81446 .09961 L
.81697 .09337 L
.8184 .09071 L
.81973 .08889 L
.82048 .08817 L
.82119 .0877 L
.82182 .08744 L
.82252 .08736 L
.82327 .0875 L
.82407 .08791 L
.82482 .08853 L
.82551 .08931 L
.82683 .09133 L
.82825 .09426 L
.83083 .10134 L
.84045 .13767 L
.84308 .14668 L
.84453 .15082 L
.8459 .15408 L
.84717 .15644 L
.84789 .15747 L
.84856 .15822 L
.84974 .15905 L
.85098 .1592 L
.85222 .15862 L
.85334 .15744 L
.85458 .15545 L
.85589 .1526 L
.85808 .14616 L
.86048 .13716 L
.86597 .11207 L
.87096 .09008 L
Mistroke
.87226 .08536 L
.87368 .08101 L
.87501 .07772 L
.87624 .07549 L
.87755 .07402 L
.87829 .07361 L
.87898 .07353 L
.87971 .07374 L
.88038 .07422 L
.88115 .0751 L
.88188 .07627 L
.88311 .07892 L
.88441 .08267 L
.88674 .09166 L
.89203 .12003 L
.89659 .14776 L
.89907 .16157 L
.90139 .1723 L
.9027 .17714 L
.9039 .18062 L
.90458 .18217 L
.90523 .18333 L
.90591 .18421 L
.90665 .18477 L
.90787 .18474 L
.90916 .18338 L
.91026 .18113 L
.91148 .1775 L
.9127 .17265 L
.91385 .16696 L
.91602 .15368 L
.92091 .11413 L
.92546 .07241 L
.92975 .03802 L
.93092 .03063 L
.93217 .02415 L
.93282 .02137 L
.93353 .01884 L
.93478 .01581 L
.93592 .01473 L
.93714 .01547 L
.93829 .01807 L
.93934 .02211 L
.94065 .02942 L
.94186 .03847 L
.94459 .06707 L
.947 .10128 L
.94957 .14591 L
.95905 .35699 L
.96334 .45314 L
Mistroke
.96559 .49768 L
.96796 .5378 L
.97001 .5657 L
.97109 .57755 L
.97225 .58784 L
.97332 .59506 L
.97429 .5997 L
.97527 .60246 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.037894 0.120772 0.0283851 [
[.12106 -0.0125 -9 -9 ]
[.12106 -0.0125 9 0 ]
[.31053 -0.0125 -6 -9 ]
[.31053 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.68947 -0.0125 -3 -9 ]
[.68947 -0.0125 3 0 ]
[.87894 -0.0125 -6 -9 ]
[.87894 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12077 -6 -4.5 ]
[-0.0125 .12077 0 4.5 ]
[-0.0125 .2627 -6 -4.5 ]
[-0.0125 .2627 0 4.5 ]
[-0.0125 .40462 -12 -4.5 ]
[-0.0125 .40462 0 4.5 ]
[-0.0125 .54655 -12 -4.5 ]
[-0.0125 .54655 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12106 0 m
.12106 .00625 L
s
[(-10)] .12106 -0.0125 0 1 Mshowa
.31053 0 m
.31053 .00625 L
s
[(-5)] .31053 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.68947 0 m
.68947 .00625 L
s
[(5)] .68947 -0.0125 0 1 Mshowa
.87894 0 m
.87894 .00625 L
s
[(10)] .87894 -0.0125 0 1 Mshowa
.125 Mabswid
.15895 0 m
.15895 .00375 L
s
.19685 0 m
.19685 .00375 L
s
.23474 0 m
.23474 .00375 L
s
.27264 0 m
.27264 .00375 L
s
.34842 0 m
.34842 .00375 L
s
.38632 0 m
.38632 .00375 L
s
.42421 0 m
.42421 .00375 L
s
.46211 0 m
.46211 .00375 L
s
.53789 0 m
.53789 .00375 L
s
.57579 0 m
.57579 .00375 L
s
.61368 0 m
.61368 .00375 L
s
.65158 0 m
.65158 .00375 L
s
.72736 0 m
.72736 .00375 L
s
.76526 0 m
.76526 .00375 L
s
.80315 0 m
.80315 .00375 L
s
.84105 0 m
.84105 .00375 L
s
.08317 0 m
.08317 .00375 L
s
.04527 0 m
.04527 .00375 L
s
.00738 0 m
.00738 .00375 L
s
.91683 0 m
.91683 .00375 L
s
.95473 0 m
.95473 .00375 L
s
.99262 0 m
.99262 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12077 m
.00625 .12077 L
s
[(0)] -0.0125 .12077 1 0 Mshowa
0 .2627 m
.00625 .2627 L
s
[(5)] -0.0125 .2627 1 0 Mshowa
0 .40462 m
.00625 .40462 L
s
[(10)] -0.0125 .40462 1 0 Mshowa
0 .54655 m
.00625 .54655 L
s
[(15)] -0.0125 .54655 1 0 Mshowa
.125 Mabswid
0 .14916 m
.00375 .14916 L
s
0 .17754 m
.00375 .17754 L
s
0 .20593 m
.00375 .20593 L
s
0 .23431 m
.00375 .23431 L
s
0 .29108 m
.00375 .29108 L
s
0 .31947 m
.00375 .31947 L
s
0 .34785 m
.00375 .34785 L
s
0 .37624 m
.00375 .37624 L
s
0 .43301 m
.00375 .43301 L
s
0 .46139 m
.00375 .46139 L
s
0 .48978 m
.00375 .48978 L
s
0 .51816 m
.00375 .51816 L
s
0 .09239 m
.00375 .09239 L
s
0 .064 m
.00375 .064 L
s
0 .03562 m
.00375 .03562 L
s
0 .00723 m
.00375 .00723 L
s
0 .57493 m
.00375 .57493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.12106 .61178 m
.12106 .61803 L
s
.31053 .61178 m
.31053 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.68947 .61178 m
.68947 .61803 L
s
.87894 .61178 m
.87894 .61803 L
s
.125 Mabswid
.15895 .61428 m
.15895 .61803 L
s
.19685 .61428 m
.19685 .61803 L
s
.23474 .61428 m
.23474 .61803 L
s
.27264 .61428 m
.27264 .61803 L
s
.34842 .61428 m
.34842 .61803 L
s
.38632 .61428 m
.38632 .61803 L
s
.42421 .61428 m
.42421 .61803 L
s
.46211 .61428 m
.46211 .61803 L
s
.53789 .61428 m
.53789 .61803 L
s
.57579 .61428 m
.57579 .61803 L
s
.61368 .61428 m
.61368 .61803 L
s
.65158 .61428 m
.65158 .61803 L
s
.72736 .61428 m
.72736 .61803 L
s
.76526 .61428 m
.76526 .61803 L
s
.80315 .61428 m
.80315 .61803 L
s
.84105 .61428 m
.84105 .61803 L
s
.08317 .61428 m
.08317 .61803 L
s
.04527 .61428 m
.04527 .61803 L
s
.00738 .61428 m
.00738 .61803 L
s
.91683 .61428 m
.91683 .61803 L
s
.95473 .61428 m
.95473 .61803 L
s
.99262 .61428 m
.99262 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .12077 m
1 .12077 L
s
.99375 .2627 m
1 .2627 L
s
.99375 .40462 m
1 .40462 L
s
.99375 .54655 m
1 .54655 L
s
.125 Mabswid
.99625 .14916 m
1 .14916 L
s
.99625 .17754 m
1 .17754 L
s
.99625 .20593 m
1 .20593 L
s
.99625 .23431 m
1 .23431 L
s
.99625 .29108 m
1 .29108 L
s
.99625 .31947 m
1 .31947 L
s
.99625 .34785 m
1 .34785 L
s
.99625 .37624 m
1 .37624 L
s
.99625 .43301 m
1 .43301 L
s
.99625 .46139 m
1 .46139 L
s
.99625 .48978 m
1 .48978 L
s
.99625 .51816 m
1 .51816 L
s
.99625 .09239 m
1 .09239 L
s
.99625 .064 m
1 .064 L
s
.99625 .03562 m
1 .03562 L
s
.99625 .00723 m
1 .00723 L
s
.99625 .57493 m
1 .57493 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02395 .60324 L
.02408 .60302 L
.02423 .60261 L
.02437 .60205 L
.02462 .60067 L
.02489 .59861 L
.02519 .59566 L
.02551 .59176 L
.02608 .58284 L
.02722 .55787 L
.02847 .52039 L
.03109 .41601 L
.03355 .30175 L
.03579 .20005 L
.03823 .10693 L
.03955 .06858 L
.04019 .05351 L
.04078 .04197 L
.04134 .03278 L
.04195 .02499 L
.04228 .02166 L
.04259 .01918 L
.04289 .01733 L
.04304 .01659 L
.0432 .01592 L
.04336 .01541 L
.04351 .01506 L
.04365 .01484 L
.0438 .01473 L
.04393 .01473 L
.04406 .01481 L
.04419 .015 L
.04434 .01531 L
.04449 .01573 L
.04465 .01632 L
.04498 .01789 L
.04528 .0198 L
.04557 .02194 L
.04664 .03293 L
.04778 .04889 L
.05018 .09081 L
.05278 .13706 L
.054 .15515 L
.05467 .1635 L
.05529 .17017 L
.05587 .17527 L
.05639 .179 L
.05698 .18209 L
.0573 .1833 L
Mistroke
.0576 .18414 L
.05776 .18444 L
.05783 .18457 L
.05792 .18468 L
.05807 .18483 L
.05821 .1849 L
.05835 .1849 L
.05848 .18485 L
.05861 .18474 L
.05876 .18455 L
.05892 .18427 L
.0591 .18388 L
.05941 .18294 L
.05972 .18175 L
.06 .18041 L
.06107 .17339 L
.06222 .16311 L
.06678 .10959 L
.06792 .09744 L
.06911 .08686 L
.06974 .08242 L
.07043 .07855 L
.07073 .07718 L
.07105 .07596 L
.07133 .07511 L
.07163 .07438 L
.07179 .07409 L
.07194 .07387 L
.0721 .07369 L
.07219 .07362 L
.07228 .07358 L
.07242 .07353 L
.07258 .07354 L
.07273 .0736 L
.07287 .07371 L
.07303 .07388 L
.07318 .0741 L
.07352 .07479 L
.07385 .07571 L
.07421 .07696 L
.07483 .07974 L
.07548 .08345 L
.07664 .09177 L
.08123 .13355 L
.08245 .14327 L
.0836 .15068 L
.08423 .15387 L
.08457 .15527 L
.08492 .15653 L
.08522 .1574 L
Mistroke
.08554 .15817 L
.08569 .15844 L
.08584 .15869 L
.08599 .15888 L
.08612 .15902 L
.0862 .15909 L
.08628 .15914 L
.08643 .15921 L
.08651 .15923 L
.0866 .15924 L
.08675 .15921 L
.0869 .15915 L
.08703 .15905 L
.08718 .15891 L
.08734 .1587 L
.0877 .15808 L
.08804 .15727 L
.08867 .15521 L
.08928 .15265 L
.08983 .14979 L
.0911 .14188 L
.09354 .12314 L
.09583 .10566 L
.0969 .09885 L
.09803 .09316 L
.09862 .0909 L
.09893 .08992 L
.09926 .08905 L
.09957 .0884 L
.09985 .08794 L
.09998 .08777 L
.10013 .08762 L
.10026 .08751 L
.10039 .08743 L
.10054 .08738 L
.10068 .08736 L
.10081 .08738 L
.10095 .08743 L
.10111 .08752 L
.10119 .08758 L
.10127 .08766 L
.10156 .08801 L
.10183 .08847 L
.10212 .08909 L
.10265 .09055 L
.10329 .09283 L
.10395 .09581 L
.10514 .10239 L
.10973 .13366 L
.11095 .14071 L
Mistroke
.11209 .14596 L
.11273 .14814 L
.11306 .14907 L
.11341 .14987 L
.11371 .15041 L
.11387 .15064 L
.11404 .15084 L
.11419 .15099 L
.11434 .15109 L
.11448 .15117 L
.11462 .15121 L
.11477 .15122 L
.11485 .15121 L
.11493 .15119 L
.11507 .15114 L
.11522 .15105 L
.11536 .15093 L
.11548 .1508 L
.11577 .15042 L
.11608 .14987 L
.11637 .14924 L
.117 .14743 L
.11814 .14291 L
.11922 .13735 L
.12384 .1081 L
.12507 .10146 L
.12623 .09659 L
.12681 .09474 L
.12743 .09325 L
.12777 .09267 L
.12795 .09242 L
.12812 .09223 L
.12827 .0921 L
.12843 .092 L
.12852 .09195 L
.1286 .09192 L
.12876 .09189 L
.1289 .0919 L
.12905 .09194 L
.12919 .092 L
.12932 .09209 L
.12947 .09221 L
.12963 .09239 L
.12993 .09281 L
.13024 .09338 L
.13057 .09413 L
.13117 .09585 L
.13234 .10044 L
.1334 .10579 L
.13592 .12117 L
Mistroke
.13823 .13524 L
.13941 .14109 L
.1405 .14529 L
.14105 .14686 L
.14133 .14752 L
.14164 .14811 L
.14181 .14838 L
.14197 .1486 L
.14213 .14878 L
.14229 .14893 L
.14244 .14903 L
.14258 .1491 L
.14273 .14915 L
.14289 .14916 L
.14304 .14913 L
.14318 .14908 L
.14334 .14899 L
.14349 .14887 L
.14375 .14859 L
.14404 .14816 L
.14436 .14756 L
.1447 .14677 L
.14531 .14499 L
.14652 .14012 L
.14785 .13314 L
.1504 .11732 L
.15272 .10362 L
.15388 .09829 L
.15448 .09604 L
.15513 .09416 L
.15569 .09296 L
.15601 .09248 L
.15616 .0923 L
.15631 .09215 L
.15645 .09205 L
.15659 .09197 L
.15672 .09192 L
.15684 .0919 L
.15699 .0919 L
.15712 .09192 L
.15727 .09199 L
.15741 .09207 L
.15755 .09219 L
.1577 .09234 L
.15797 .0927 L
.15829 .09326 L
.15858 .09389 L
.15922 .09567 L
.15982 .09784 L
.16205 .10913 L
Mistroke
.16446 .12472 L
.16665 .13824 L
.16787 .14426 L
.16843 .14648 L
.16903 .1484 L
.16933 .14919 L
.16966 .14992 L
.16996 .15045 L
.17024 .15082 L
.17041 .15098 L
.1705 .15105 L
.17057 .1511 L
.17072 .15117 L
.17088 .15121 L
.17103 .15122 L
.17112 .1512 L
.1712 .15118 L
.17129 .15114 L
.17137 .1511 L
.17156 .15096 L
.17171 .1508 L
.17185 .15062 L
.17213 .1502 L
.17242 .14962 L
.17274 .14885 L
.17384 .14509 L
.17447 .14223 L
.17514 .13871 L
.17633 .13138 L
.17872 .11471 L
.18091 .1004 L
.18211 .09419 L
.18266 .09192 L
.18325 .08997 L
.18358 .08911 L
.18388 .08848 L
.18418 .08798 L
.18431 .0878 L
.18446 .08764 L
.18462 .08751 L
.1847 .08746 L
.18479 .08742 L
.18493 .08737 L
.18509 .08737 L
.18518 .08738 L
.18527 .08741 L
.18536 .08745 L
.18545 .0875 L
.1856 .08763 L
.18577 .08782 L
Mistroke
.18607 .08827 L
.18636 .08884 L
.1869 .09027 L
.18749 .09234 L
.18812 .09517 L
.19033 .10887 L
.1929 .12895 L
.19523 .14594 L
.1964 .15245 L
.19705 .15526 L
.19737 .15635 L
.19766 .15722 L
.19794 .1579 L
.19819 .15841 L
.19847 .15883 L
.19862 .159 L
.19877 .15912 L
.19891 .1592 L
.19906 .15923 L
.19919 .15923 L
.19933 .15919 L
.19949 .15911 L
.19957 .15904 L
.19965 .15897 L
.19995 .15858 L
.2001 .15831 L
.20025 .15801 L
.20052 .15735 L
.20113 .15535 L
.20165 .15308 L
.20223 .15006 L
.20472 .13144 L
.20707 .10948 L
.20832 .09809 L
.20965 .08736 L
.21031 .08298 L
.21094 .0795 L
.2115 .07699 L
.21182 .07585 L
.21211 .07501 L
.2124 .07433 L
.21254 .07409 L
.21268 .07388 L
.21284 .07371 L
.21298 .0736 L
.21313 .07354 L
.21322 .07353 L
.2133 .07353 L
.21344 .07358 L
.21358 .07367 L
Mistroke
.2137 .07378 L
.21383 .07395 L
.21413 .07448 L
.2144 .07516 L
.21496 .07709 L
.21557 .08 L
.21666 .0873 L
.21795 .099 L
.21914 .11194 L
.22162 .14199 L
.22283 .15604 L
.22392 .16725 L
.22447 .17206 L
.22507 .17653 L
.22558 .1797 L
.22615 .18237 L
.22646 .18344 L
.22675 .18418 L
.22691 .18448 L
.22706 .18469 L
.22714 .18477 L
.22722 .18484 L
.22731 .18488 L
.22738 .1849 L
.22753 .18489 L
.22767 .1848 L
.2278 .18468 L
.22794 .18448 L
.22809 .1842 L
.22824 .18382 L
.22852 .18293 L
.22883 .18166 L
.22912 .18017 L
.22967 .17661 L
.23026 .17171 L
.2309 .16517 L
.23311 .13411 L
.23546 .09224 L
.2367 .06955 L
.23804 .04728 L
.2387 .03784 L
.23932 .03007 L
.23993 .02384 L
.24022 .02133 L
.24049 .01938 L
.24075 .01783 L
.24102 .01648 L
.24117 .0159 L
.24131 .01546 L
.24145 .01514 L
Mistroke
.24159 .01489 L
.24173 .01475 L
.24188 .01472 L
.24203 .0148 L
.24216 .01497 L
.24231 .0153 L
.2424 .01554 L
.24248 .0158 L
.24279 .01711 L
.24308 .01887 L
.24334 .02091 L
.24395 .02707 L
.24448 .0343 L
.24504 .04376 L
.24622 .07005 L
.24752 .10803 L
.24989 .19825 L
.25241 .31348 L
.25481 .42452 L
.25608 .47755 L
.25742 .52608 L
.25861 .56074 L
.25924 .57528 L
.25992 .58767 L
.26025 .59229 L
.26055 .59594 L
.26085 .59881 L
.26112 .60084 L
.26125 .60161 L
.26138 .6022 L
.26152 .60273 L
.26165 .60307 L
.2618 .60328 L
.26194 .60332 L
.26208 .60319 L
.26224 .60287 L
.26239 .60239 L
.26255 .60166 L
.26284 .59982 L
.26312 .59737 L
.26338 .59455 L
.26398 .58615 L
.26461 .57433 L
.26566 .54833 L
.26682 .51149 L
.27168 .30025 L
.27391 .19883 L
.27517 .14755 L
.27635 .10605 L
.27762 .06923 L
Mistroke
.27877 .04381 L
.2794 .03322 L
.28 .02545 L
.28031 .0223 L
.28063 .01958 L
.2808 .0184 L
.28099 .0173 L
.28116 .01646 L
.28132 .01584 L
.28146 .01538 L
.28162 .01503 L
.28177 .01481 L
.28186 .01474 L
.28195 .01472 L
.2821 .01476 L
.28223 .01491 L
.28239 .01519 L
.28254 .01561 L
.28282 .01663 L
.28308 .01792 L
.28367 .02197 L
.2843 .02802 L
.28488 .03485 L
.28619 .05388 L
.28869 .09855 L
.291 .13909 L
.29217 .15609 L
.29325 .16885 L
.29385 .17433 L
.29439 .17837 L
.29499 .18173 L
.29532 .18307 L
.29548 .18356 L
.29564 .184 L
.2958 .18435 L
.29595 .1846 L
.2961 .18477 L
.29625 .18487 L
.29638 .18491 L
.29651 .18488 L
.29665 .1848 L
.2968 .18464 L
.29696 .18439 L
.29713 .18403 L
.29744 .18315 L
.29775 .18202 L
.29803 .18073 L
.29911 .17389 L
.30025 .16376 L
.3048 .11039 L
Mistroke
.30594 .09815 L
.30714 .08742 L
.30776 .0829 L
.30845 .07891 L
.30875 .0775 L
.30907 .07622 L
.30935 .07532 L
.30965 .07454 L
.3098 .07424 L
.30997 .07397 L
.31005 .07385 L
.31014 .07375 L
.31022 .07368 L
.3103 .07362 L
.31044 .07355 L
.3106 .07353 L
.31074 .07356 L
.31089 .07364 L
.31098 .07372 L
.31106 .07381 L
.31125 .07406 L
.31142 .07436 L
.31159 .07473 L
.3119 .07556 L
.31223 .07667 L
.31283 .07927 L
.31339 .08232 L
.31466 .09115 L
.31705 .11247 L
.31966 .13632 L
.32087 .14557 L
.32153 .14979 L
.32216 .15309 L
.32273 .15554 L
.32326 .15725 L
.32356 .15799 L
.32384 .15854 L
.32399 .15876 L
.32414 .15895 L
.32423 .15903 L
.32431 .1591 L
.32447 .15919 L
.32461 .15923 L
.32475 .15923 L
.3249 .1592 L
.32506 .15911 L
.32514 .15905 L
.32522 .15896 L
.32538 .15878 L
.32568 .15831 L
Mistroke
.32596 .15771 L
.32625 .15693 L
.32679 .15513 L
.32798 .1495 L
.3293 .14113 L
.33183 .12162 L
.33415 .10419 L
.33532 .09704 L
.33642 .09196 L
.33697 .09008 L
.33725 .0893 L
.33756 .0886 L
.33773 .08827 L
.3379 .08801 L
.33805 .0878 L
.33821 .08763 L
.33836 .0875 L
.3385 .08742 L
.33865 .08738 L
.33881 .08737 L
.33889 .08738 L
.33897 .0874 L
.33912 .08746 L
.33927 .08757 L
.33944 .08774 L
.33975 .08816 L
.34003 .08867 L
.34068 .09033 L
.34136 .09275 L
.34252 .09823 L
.34379 .10583 L
.34634 .12361 L
.34867 .13867 L
.34982 .14446 L
.35047 .14702 L
.35108 .14887 L
.3516 .15006 L
.3519 .15055 L
.35219 .15089 L
.35233 .15102 L
.35248 .15112 L
.35261 .15118 L
.35275 .15121 L
.3529 .15122 L
.35299 .1512 L
.35307 .15118 L
.35322 .15111 L
.35336 .15101 L
.3535 .15089 L
.35365 .15072 L
Mistroke
.35392 .15033 L
.35424 .14974 L
.35454 .14906 L
.35517 .14718 L
.35578 .14492 L
.35801 .1333 L
.3602 .11909 L
.36145 .11106 L
.36262 .10425 L
.36386 .09834 L
.36441 .09629 L
.365 .09446 L
.3656 .09312 L
.36592 .09259 L
.36622 .09223 L
.36639 .09208 L
.36648 .09202 L
.36655 .09198 L
.3667 .09192 L
.36686 .09189 L
.36701 .0919 L
.3671 .09192 L
.36718 .09195 L
.36727 .092 L
.36735 .09204 L
.36753 .09219 L
.36769 .09235 L
.36784 .09253 L
.36811 .09295 L
.36872 .09426 L
.36925 .0958 L
.36982 .09785 L
.37232 .11058 L
.37468 .12543 L
.37593 .133 L
.37727 .14003 L
.37793 .1429 L
.37856 .14517 L
.37912 .1468 L
.37941 .14748 L
.37973 .1481 L
.38003 .14856 L
.38031 .14887 L
.38047 .14899 L
.38061 .14907 L
.38076 .14913 L
.38084 .14915 L
.38093 .14916 L
.38107 .14915 L
.3812 .14911 L
Mistroke
.38136 .14904 L
.3815 .14894 L
.38175 .1487 L
.38203 .14833 L
.38232 .14784 L
.38262 .1472 L
.38317 .14572 L
.38443 .14097 L
.38576 .13424 L
.38697 .12703 L
.38946 .11134 L
.39067 .10442 L
.39176 .09915 L
.39232 .09696 L
.39291 .095 L
.39348 .09356 L
.39373 .09307 L
.394 .09263 L
.39415 .09243 L
.39428 .09227 L
.39442 .09214 L
.39455 .09205 L
.3947 .09196 L
.39478 .09193 L
.39486 .09191 L
.395 .09189 L
.39515 .09191 L
.39531 .09196 L
.39546 .09204 L
.39562 .09216 L
.39578 .09233 L
.39607 .0927 L
.39638 .09324 L
.39702 .09477 L
.39762 .09671 L
.39875 .1015 L
.40127 .11626 L
.40349 .13074 L
.40475 .13822 L
.40592 .14405 L
.40651 .14643 L
.40708 .14828 L
.40739 .14911 L
.40773 .14987 L
.40804 .15042 L
.40832 .1508 L
.40847 .15095 L
.40862 .15107 L
.40877 .15115 L
.40891 .1512 L
Mistroke
.40906 .15122 L
.40914 .15122 L
.40922 .1512 L
.40931 .15118 L
.40938 .15114 L
.40947 .1511 L
.40955 .15104 L
.40971 .1509 L
.40988 .15072 L
.41018 .15027 L
.4105 .14965 L
.41086 .14878 L
.41149 .14681 L
.41209 .14445 L
.4132 .13887 L
.41572 .1225 L
.41814 .10569 L
.41919 .0993 L
.42033 .09363 L
.42097 .09116 L
.42156 .08941 L
.42184 .08873 L
.42212 .08822 L
.4224 .08781 L
.42255 .08765 L
.42271 .08752 L
.42279 .08746 L
.42288 .08742 L
.42303 .08737 L
.42312 .08736 L
.4232 .08737 L
.42329 .08739 L
.42339 .08742 L
.42346 .08746 L
.42355 .08751 L
.42372 .08766 L
.42388 .08784 L
.42403 .08804 L
.42434 .08858 L
.42461 .0892 L
.42524 .09105 L
.42582 .09333 L
.42644 .09629 L
.42755 .10282 L
.43006 .12149 L
.43245 .14003 L
.4335 .147 L
.43463 .15311 L
.43526 .15566 L
.43556 .15667 L
Mistroke
.43584 .15744 L
.4361 .15806 L
.43639 .15859 L
.43655 .15881 L
.4367 .15898 L
.43683 .1591 L
.43698 .15918 L
.43714 .15923 L
.43728 .15923 L
.43736 .15922 L
.43745 .15919 L
.4376 .15909 L
.43775 .15896 L
.43791 .15878 L
.43818 .15833 L
.43851 .15762 L
.43881 .15678 L
.4395 .15421 L
.4401 .1513 L
.44075 .14744 L
.44194 .13882 L
.44418 .11889 L
.44675 .09521 L
.44796 .08589 L
.44908 .07927 L
.44964 .07679 L
.44993 .07578 L
.45024 .0749 L
.45041 .07452 L
.45055 .07423 L
.45071 .07398 L
.45085 .0738 L
.45092 .07372 L
.45101 .07365 L
.45109 .07359 L
.45118 .07355 L
.45126 .07353 L
.45135 .07353 L
.45151 .07356 L
.45165 .07365 L
.45178 .07377 L
.45193 .07396 L
.45209 .07421 L
.45241 .07491 L
.4527 .07577 L
.45326 .07799 L
.4538 .08076 L
.45497 .08903 L
.45621 .10062 L
.45843 .12626 L
Mistroke
.46082 .1549 L
.46186 .16578 L
.463 .17539 L
.46363 .1794 L
.46393 .18099 L
.4642 .18221 L
.46447 .18317 L
.46476 .18399 L
.46491 .18433 L
.46506 .18457 L
.4652 .18474 L
.46535 .18486 L
.4655 .18491 L
.46565 .18488 L
.46573 .18484 L
.46581 .18477 L
.46597 .18458 L
.46611 .18433 L
.46627 .18399 L
.46655 .18318 L
.46687 .18192 L
.46717 .18042 L
.46787 .17587 L
.46843 .17098 L
.46905 .16451 L
.4703 .14821 L
.47254 .11097 L
.4751 .06419 L
.47632 .04458 L
.47743 .02987 L
.478 .02405 L
.4786 .0193 L
.47891 .01746 L
.4792 .01616 L
.47937 .01559 L
.47952 .01519 L
.4796 .01502 L
.47969 .01488 L
.47978 .01479 L
.47986 .01473 L
.47999 .01472 L
.48013 .01481 L
.48026 .01499 L
.48039 .01524 L
.48052 .01561 L
.48067 .01614 L
.48097 .01758 L
.48126 .01951 L
.48158 .02214 L
.48215 .02837 L
Mistroke
.48279 .03772 L
.48338 .04856 L
.48472 .08074 L
.48715 .16377 L
.49189 .37857 L
.49428 .48166 L
.49532 .51972 L
.49646 .5543 L
.49708 .56968 L
.49766 .58152 L
.49821 .59052 L
.49852 .59451 L
.4988 .59753 L
.49913 .60025 L
.4993 .60134 L
.49948 .60223 L
.49964 .60279 L
.49979 .60313 L
.49987 .60325 L
.49995 .60331 L
.50004 .60331 L
.50012 .60326 L
.50027 .60303 L
.50042 .60261 L
.50055 .6021 L
.50069 .60138 L
.50102 .59916 L
.50132 .59634 L
.50189 .58912 L
.5025 .57841 L
.50375 .54847 L
.50491 .51179 L
.50599 .47123 L
.5107 .25721 L
.5131 .15414 L
.51436 .1087 L
.5157 .06953 L
.5169 .04323 L
.51758 .0321 L
.51821 .02421 L
.51851 .02134 L
.51879 .0191 L
.51905 .01749 L
.51933 .01616 L
.51949 .01559 L
.51963 .01521 L
.51971 .01504 L
.51979 .0149 L
.51995 .01475 L
.52009 .01472 L
Mistroke
.52025 .01481 L
.52038 .01499 L
.52053 .01529 L
.52068 .01574 L
.52083 .01626 L
.52116 .01783 L
.52145 .01963 L
.52176 .02196 L
.52288 .03364 L
.52408 .05071 L
.52541 .07321 L
.52794 .11957 L
.53026 .15612 L
.53141 .16944 L
.53206 .17526 L
.53266 .17946 L
.53296 .1811 L
.53324 .18238 L
.53349 .18331 L
.53376 .18407 L
.5339 .18436 L
.53406 .18461 L
.5342 .18477 L
.53433 .18487 L
.53448 .18491 L
.53462 .18487 L
.5347 .18483 L
.53478 .18476 L
.53494 .18457 L
.53508 .18433 L
.53522 .18404 L
.53552 .1832 L
.53579 .18224 L
.53607 .181 L
.53667 .17765 L
.53732 .17296 L
.53985 .14715 L
.54241 .11601 L
.54474 .0915 L
.5459 .08261 L
.54656 .07884 L
.54687 .07739 L
.54716 .07624 L
.54744 .07534 L
.54769 .07467 L
.54797 .07411 L
.54813 .07388 L
.54827 .07371 L
.54841 .0736 L
.54856 .07354 L
Mistroke
.54871 .07353 L
.54884 .07356 L
.54899 .07364 L
.54907 .07372 L
.54915 .0738 L
.5493 .074 L
.54945 .07424 L
.54975 .07487 L
.55002 .07563 L
.55062 .07788 L
.55115 .08043 L
.55172 .08378 L
.55421 .1037 L
.55656 .12576 L
.5578 .13671 L
.55914 .14672 L
.55976 .15052 L
.56041 .15383 L
.56097 .15606 L
.56129 .15708 L
.56158 .15784 L
.56188 .15844 L
.56216 .15886 L
.56231 .15902 L
.56245 .15913 L
.56261 .15921 L
.56269 .15923 L
.56277 .15924 L
.56291 .15922 L
.56305 .15917 L
.5632 .15907 L
.56334 .15894 L
.5636 .15861 L
.56388 .1581 L
.56419 .15738 L
.56452 .15641 L
.56513 .15417 L
.56626 .14848 L
.56879 .13066 L
.57115 .11199 L
.5724 .10311 L
.57309 .09885 L
.57374 .09535 L
.57436 .09255 L
.57504 .09016 L
.57533 .08933 L
.57565 .08861 L
.57592 .08812 L
.57621 .08772 L
.57637 .08757 L
Mistroke
.57651 .08747 L
.57664 .08741 L
.57679 .08737 L
.57694 .08737 L
.57703 .08739 L
.57711 .08741 L
.57726 .08749 L
.5774 .0876 L
.57754 .08774 L
.57768 .08791 L
.57794 .08831 L
.57821 .08886 L
.57852 .08959 L
.57915 .09157 L
.57975 .09397 L
.58087 .09964 L
.58339 .11619 L
.58559 .1315 L
.58684 .13911 L
.58801 .14487 L
.58857 .14702 L
.58916 .14884 L
.58947 .14959 L
.58981 .15025 L
.58995 .15049 L
.59011 .1507 L
.59025 .15086 L
.5904 .151 L
.59048 .15106 L
.59057 .15112 L
.59073 .15119 L
.59081 .15121 L
.59091 .15122 L
.591 .15122 L
.59108 .1512 L
.59124 .15115 L
.59133 .1511 L
.59141 .15105 L
.59156 .15092 L
.59173 .15075 L
.59205 .15028 L
.59236 .14969 L
.59293 .14825 L
.59349 .14639 L
.59411 .14391 L
.59536 .13765 L
.59759 .12377 L
.60014 .10747 L
.60135 .10104 L
.60247 .09641 L
Mistroke
.60303 .09465 L
.60363 .09324 L
.60393 .0927 L
.60422 .09232 L
.60439 .09216 L
.60454 .09204 L
.60462 .09199 L
.60471 .09195 L
.6048 .09192 L
.60488 .0919 L
.60503 .09189 L
.60518 .09192 L
.60533 .09197 L
.60546 .09205 L
.60558 .09215 L
.60572 .09227 L
.60599 .09261 L
.60628 .09309 L
.6066 .09373 L
.60717 .09524 L
.60839 .09982 L
.60972 .10655 L
.61215 .12145 L
.61449 .13557 L
.61582 .14204 L
.61642 .1444 L
.61707 .14641 L
.61763 .14774 L
.61795 .14831 L
.61811 .14853 L
.61825 .14871 L
.61838 .14884 L
.61853 .14896 L
.61866 .14905 L
.61878 .14911 L
.61891 .14914 L
.61905 .14916 L
.6192 .14914 L
.61934 .1491 L
.61949 .14902 L
.61958 .14896 L
.61966 .14889 L
.61996 .14857 L
.62023 .14816 L
.62052 .14762 L
.62119 .14595 L
.6218 .14394 L
.62301 .13871 L
.62412 .13271 L
.62663 .11707 L
Mistroke
.62782 .10972 L
.6291 .1027 L
.62971 .09978 L
.6303 .09738 L
.63082 .09557 L
.6314 .09397 L
.63195 .09285 L
.63225 .09242 L
.63239 .09226 L
.63254 .09213 L
.63266 .09203 L
.6328 .09196 L
.63293 .09192 L
.63304 .0919 L
.63318 .0919 L
.63331 .09192 L
.63345 .09198 L
.63359 .09207 L
.63373 .09218 L
.63388 .09233 L
.63419 .09274 L
.63447 .09324 L
.63474 .09381 L
.63533 .09544 L
.63598 .0977 L
.6372 .10331 L
.63853 .11094 L
.64096 .12672 L
.64229 .13505 L
.64353 .14183 L
.64466 .1466 L
.64529 .1486 L
.64557 .14931 L
.64587 .14996 L
.64617 .15047 L
.64644 .15082 L
.64657 .15095 L
.64671 .15106 L
.64684 .15114 L
.64697 .15119 L
.64711 .15122 L
.64724 .15122 L
.64739 .15118 L
.64755 .15111 L
.64763 .15105 L
.64772 .15099 L
.64787 .15083 L
.64817 .15045 L
.64849 .14988 L
.64878 .14924 L
Mistroke
.64943 .14735 L
.6506 .14254 L
.6518 .13594 L
.65292 .12878 L
.65543 .11113 L
.65769 .0971 L
.65832 .09411 L
.65898 .09145 L
.65931 .09038 L
.65961 .08951 L
.65991 .0888 L
.66019 .08826 L
.66045 .08786 L
.6606 .08769 L
.66074 .08756 L
.66088 .08746 L
.66104 .08739 L
.66112 .08737 L
.6612 .08736 L
.66135 .08738 L
.66143 .0874 L
.66151 .08743 L
.66159 .08748 L
.66168 .08754 L
.66183 .08767 L
.662 .08786 L
.6623 .08833 L
.66259 .08891 L
.66315 .09043 L
.66366 .09225 L
.66481 .09775 L
.6671 .11319 L
.6696 .13296 L
.67083 .142 L
.67198 .14927 L
.67262 .15258 L
.6733 .15548 L
.67361 .15652 L
.67393 .15744 L
.67421 .15808 L
.67451 .15862 L
.67467 .15884 L
.67482 .159 L
.67496 .15912 L
.67511 .1592 L
.67524 .15923 L
.67537 .15923 L
.6755 .1592 L
.67565 .15912 L
.6758 .159 L
Mistroke
.67596 .15882 L
.67613 .15858 L
.67629 .1583 L
.67659 .15764 L
.67688 .15686 L
.67744 .15487 L
.67795 .15257 L
.67909 .14583 L
.68151 .12604 L
.68374 .10504 L
.686 .08626 L
.68662 .08225 L
.68729 .0787 L
.68761 .07729 L
.68792 .07615 L
.68821 .07523 L
.68849 .07454 L
.68876 .07405 L
.68891 .07384 L
.68904 .0737 L
.68919 .07359 L
.68934 .07353 L
.68942 .07353 L
.6895 .07353 L
.68965 .07359 L
.68981 .0737 L
.6899 .0738 L
.68999 .0739 L
.6903 .07444 L
.69059 .07514 L
.69089 .07609 L
.69143 .07834 L
.69195 .08108 L
.69311 .08942 L
.69436 .10123 L
.69555 .11449 L
.69779 .14169 L
.69903 .15617 L
.7002 .16806 L
.70125 .1765 L
.70185 .1801 L
.70239 .18257 L
.70268 .18352 L
.70294 .18419 L
.7031 .18448 L
.70323 .18468 L
.70331 .18476 L
.70339 .18483 L
.70355 .1849 L
.70369 .1849 L
Mistroke
.70378 .18486 L
.70385 .18481 L
.70401 .18465 L
.7041 .18453 L
.70418 .18439 L
.70447 .18373 L
.70477 .18274 L
.70507 .18145 L
.70539 .17973 L
.70597 .17576 L
.70667 .16964 L
.7073 .16282 L
.70961 .12898 L
.71212 .08356 L
.71447 .04373 L
.71511 .03489 L
.7158 .02688 L
.71614 .02364 L
.71646 .02099 L
.71677 .01881 L
.71705 .01721 L
.7172 .01656 L
.71735 .01596 L
.71748 .01553 L
.71763 .01516 L
.71778 .01489 L
.71786 .0148 L
.71794 .01474 L
.71808 .01472 L
.71823 .01482 L
.71837 .01502 L
.71853 .01536 L
.71867 .0158 L
.71881 .01631 L
.71906 .01756 L
.71933 .01929 L
.71994 .02478 L
.72051 .03193 L
.72113 .04203 L
.72181 .05555 L
.72296 .08502 L
.72423 .12564 L
.72678 .22885 L
.72934 .34842 L
.73167 .45334 L
.73284 .49937 L
.7341 .54151 L
.73468 .55765 L
.73529 .57227 L
.73586 .58335 L
Mistroke
.73639 .59168 L
.73668 .59523 L
.73699 .59838 L
.73727 .60057 L
.73753 .60204 L
.73768 .60261 L
.73781 .603 L
.73796 .60325 L
.73805 .60331 L
.73812 .60332 L
.73827 .60319 L
.73835 .60305 L
.73843 .60286 L
.73859 .60234 L
.73876 .60156 L
.73904 .59972 L
.73935 .59698 L
.73991 .5901 L
.74046 .58106 L
.74097 .57076 L
.74213 .54018 L
.74323 .50389 L
.74572 .40086 L
.75039 .18639 L
.75161 .13819 L
.75295 .09331 L
.7542 .05965 L
.75537 .03671 L
.75598 .02794 L
.7563 .02423 L
.75665 .021 L
.75694 .01872 L
.7571 .01773 L
.75727 .01683 L
.75743 .01614 L
.75757 .01563 L
.75771 .01523 L
.75785 .01496 L
.75798 .0148 L
.75812 .01472 L
.75827 .01475 L
.75841 .01489 L
.75854 .0151 L
.75865 .01538 L
.75892 .01626 L
.75919 .01751 L
.75949 .01927 L
.76009 .02401 L
.76073 .03065 L
.76133 .03823 L
Mistroke
.76246 .0552 L
.76499 .10046 L
.7672 .13913 L
.76845 .15736 L
.76907 .16481 L
.76963 .17066 L
.77018 .1755 L
.77079 .17965 L
.77112 .18142 L
.77142 .18274 L
.77172 .1837 L
.77188 .18412 L
.77203 .18442 L
.77219 .18466 L
.77227 .18475 L
.77236 .18483 L
.77251 .1849 L
.77266 .1849 L
.77275 .18486 L
.77283 .1848 L
.77299 .18464 L
.77307 .18451 L
.77315 .18438 L
.77334 .18399 L
.77362 .18319 L
.77393 .18203 L
.77457 .17885 L
.77519 .17467 L
.77579 .16984 L
.77691 .15892 L
.77942 .12918 L
.78184 .10111 L
.78289 .09103 L
.78403 .0824 L
.78467 .07878 L
.78495 .07748 L
.78525 .07626 L
.78552 .07537 L
.78581 .07461 L
.78597 .07428 L
.78612 .07403 L
.78626 .07383 L
.7864 .07368 L
.78655 .07358 L
.78663 .07355 L
.78671 .07353 L
.78686 .07354 L
.78695 .07357 L
.78703 .07361 L
.78717 .07372 L
Mistroke
.78731 .07388 L
.78747 .07411 L
.78761 .07437 L
.78795 .07515 L
.78825 .07607 L
.78893 .07884 L
.78952 .08195 L
.79013 .08588 L
.79124 .09434 L
.79375 .11731 L
.79614 .13871 L
.79718 .1464 L
.79832 .15296 L
.79894 .15562 L
.79925 .15666 L
.79952 .15746 L
.79979 .15809 L
.80008 .15861 L
.80023 .15883 L
.80038 .159 L
.80052 .15911 L
.80067 .15919 L
.80082 .15923 L
.80097 .15923 L
.80105 .15921 L
.80113 .15918 L
.80129 .15908 L
.80143 .15894 L
.80159 .15876 L
.80187 .15831 L
.80219 .15761 L
.80249 .15678 L
.80319 .15431 L
.80437 .14835 L
.80562 .14018 L
.80786 .1229 L
.81027 .10465 L
.81132 .0981 L
.81246 .09256 L
.81309 .09028 L
.81337 .08948 L
.81368 .08875 L
.81397 .0882 L
.81424 .08781 L
.81439 .08764 L
.81452 .08753 L
.81468 .08743 L
.81483 .08738 L
.81497 .08736 L
.81505 .08737 L
Mistroke
.81513 .08739 L
.81529 .08745 L
.81538 .08751 L
.81546 .08757 L
.81574 .08786 L
.81588 .08806 L
.81604 .08832 L
.81637 .08899 L
.81672 .08989 L
.81736 .09199 L
.81859 .09759 L
.81993 .10551 L
.82236 .12238 L
.8247 .1378 L
.82534 .1413 L
.82604 .14456 L
.82668 .14708 L
.82729 .14891 L
.8276 .14968 L
.82789 .15024 L
.82821 .15071 L
.82839 .15091 L
.82856 .15105 L
.8287 .15114 L
.82886 .1512 L
.82899 .15122 L
.82914 .15121 L
.82929 .15117 L
.82938 .15113 L
.82946 .15108 L
.82962 .15096 L
.82977 .15081 L
.83004 .15045 L
.83033 .14995 L
.83085 .14874 L
.83141 .14702 L
.83203 .14465 L
.83437 .13224 L
.83688 .11585 L
.83925 .10197 L
.8399 .09897 L
.8406 .09629 L
.84125 .09431 L
.84185 .093 L
.84214 .09254 L
.84231 .09233 L
.84246 .09218 L
.84259 .09207 L
.84273 .09199 L
.84289 .09192 L
Mistroke
.84303 .0919 L
.84311 .09189 L
.84319 .0919 L
.84334 .09194 L
.84343 .09198 L
.84352 .09203 L
.84368 .09215 L
.84384 .0923 L
.84398 .09247 L
.84431 .09296 L
.84484 .09409 L
.84544 .09578 L
.84663 .10045 L
.84899 .11346 L
.85151 .12938 L
.85274 .13644 L
.85339 .1397 L
.85408 .14273 L
.85468 .14494 L
.85534 .14688 L
.85563 .14754 L
.85594 .14814 L
.85624 .14857 L
.85651 .14887 L
.85666 .14899 L
.85681 .14908 L
.85694 .14913 L
.85708 .14915 L
.85724 .14915 L
.85731 .14914 L
.8574 .14911 L
.85755 .14904 L
.85769 .14894 L
.85784 .14882 L
.85797 .14867 L
.85822 .14833 L
.85879 .14724 L
.85942 .14556 L
.85999 .14358 L
.86129 .13775 L
.86373 .1234 L
.86603 .10907 L
.86709 .10319 L
.86822 .09807 L
.8688 .09593 L
.86945 .09408 L
.86973 .09344 L
.87003 .09287 L
.87032 .09245 L
.87058 .09217 L
Mistroke
.87072 .09206 L
.87086 .09198 L
.871 .09192 L
.87116 .09189 L
.87124 .09189 L
.87133 .09191 L
.87148 .09195 L
.87164 .09203 L
.87178 .09214 L
.87206 .09243 L
.87232 .0928 L
.87289 .09395 L
.87351 .09569 L
.87418 .09813 L
.8754 .10384 L
.87776 .11817 L
.88035 .13484 L
.88154 .14137 L
.88219 .1444 L
.88281 .14681 L
.88339 .14861 L
.88369 .14938 L
.88402 .15006 L
.88429 .15051 L
.88443 .1507 L
.88459 .15088 L
.88473 .15101 L
.88486 .1511 L
.88498 .15116 L
.88511 .1512 L
.88526 .15122 L
.88535 .15121 L
.88542 .1512 L
.88557 .15115 L
.88572 .15106 L
.88585 .15095 L
.88598 .15082 L
.88627 .15044 L
.88658 .1499 L
.88686 .14927 L
.8875 .14744 L
.88863 .14282 L
.88971 .13705 L
.89433 .10571 L
.89556 .09835 L
.89671 .09285 L
.89729 .09074 L
.89791 .08901 L
.89825 .08832 L
.89843 .08802 L
Mistroke
.8986 .08779 L
.89876 .08762 L
.89891 .08751 L
.89899 .08746 L
.89907 .08742 L
.89915 .08739 L
.89924 .08737 L
.89939 .08737 L
.89952 .0874 L
.89968 .08747 L
.89983 .08758 L
.89997 .08771 L
.90009 .08786 L
.90038 .0883 L
.9007 .08895 L
.90099 .08968 L
.90163 .09179 L
.90226 .09445 L
.90294 .09795 L
.90417 .10569 L
.90653 .12369 L
.90778 .13358 L
.90911 .14332 L
.9104 .15106 L
.91101 .15395 L
.91158 .15611 L
.91214 .15773 L
.91244 .15835 L
.91259 .15861 L
.91276 .15884 L
.9129 .15899 L
.91303 .1591 L
.91316 .15918 L
.91329 .15922 L
.91344 .15924 L
.91357 .15921 L
.91372 .15914 L
.91388 .15902 L
.91403 .15886 L
.91419 .15864 L
.91452 .15803 L
.91483 .15728 L
.91511 .15642 L
.91576 .15392 L
.91645 .15041 L
.91772 .14201 L
.91888 .13254 L
.92137 .10934 L
.92258 .09826 L
.92368 .08929 L
Mistroke
.92483 .08161 L
.92536 .07884 L
.92591 .0765 L
.9262 .07556 L
.92651 .07472 L
.92664 .07442 L
.92679 .07415 L
.92693 .07394 L
.92706 .07378 L
.92721 .07364 L
.9273 .07358 L
.92739 .07355 L
.92754 .07353 L
.92762 .07354 L
.9277 .07356 L
.92785 .07365 L
.92799 .07378 L
.92813 .07397 L
.92829 .07423 L
.9286 .07492 L
.9289 .07578 L
.92944 .07794 L
.93004 .08105 L
.93068 .08528 L
.93289 .1059 L
.93525 .13394 L
.9365 .14901 L
.93783 .16363 L
.93849 .16982 L
.93912 .17487 L
.93973 .17891 L
.94 .18039 L
.94029 .18179 L
.94055 .1828 L
.94083 .18368 L
.94098 .18406 L
.94112 .18435 L
.94125 .18457 L
.94139 .18475 L
.94154 .18486 L
.94169 .18491 L
.94184 .18488 L
.94197 .1848 L
.94212 .18463 L
.94221 .1845 L
.94229 .18436 L
.94259 .18364 L
.94289 .18264 L
.94316 .18149 L
.94376 .17801 L
Mistroke
.94432 .17372 L
.94485 .16873 L
.94604 .15456 L
.94734 .13505 L
.94991 .08908 L
.95225 .04853 L
.95341 .03233 L
.95407 .02516 L
.95439 .02233 L
.95468 .02007 L
.95496 .01826 L
.95521 .01692 L
.95549 .0158 L
.95564 .01534 L
.95579 .01503 L
.95593 .01482 L
.95608 .01472 L
.95621 .01473 L
.95635 .01484 L
.95651 .01509 L
.95659 .01528 L
.95667 .01549 L
.95697 .0166 L
.95712 .01738 L
.95727 .01824 L
.95754 .02017 L
.95815 .02611 L
.95868 .03304 L
.95925 .04246 L
.96055 .07113 L
.96175 .10613 L
.96401 .19152 L
.9665 .30428 L
.96905 .42224 L
.97137 .51493 L
.97252 .55082 L
.97313 .56639 L
.97377 .58013 L
.9744 .59044 L
.97496 .59722 L
.97523 .59961 L
.97537 .60063 L
.97552 .60153 L
.97566 .60217 L
.9758 .60271 L
.97593 .60305 L
.97606 .60325 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.0147151 0.294302 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.04762 .01472 m
.04762 .01472 L
s
.07143 .01472 m
.07143 .01472 L
s
.09524 .01472 m
.09524 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.14286 .01472 m
.14286 .01472 L
s
.16667 .01472 m
.16667 .01472 L
s
.19048 .01472 m
.19048 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.2381 .01472 m
.2381 .01472 L
s
.2619 .01472 m
.2619 .01472 L
s
.28571 .01472 m
.28571 .01472 L
s
.30952 .01472 m
.30952 .30902 L
s
.33333 .01472 m
.33333 .30902 L
s
.35714 .01472 m
.35714 .30902 L
s
.38095 .01472 m
.38095 .30902 L
s
.40476 .01472 m
.40476 .30902 L
s
.42857 .01472 m
.42857 .30902 L
s
.45238 .01472 m
.45238 .30902 L
s
.47619 .01472 m
.47619 .30902 L
s
.5 .01472 m
.5 .30902 L
s
.52381 .01472 m
.52381 .30902 L
s
.54762 .01472 m
.54762 .30902 L
s
.57143 .01472 m
.57143 .30902 L
s
.59524 .01472 m
.59524 .30902 L
s
.61905 .01472 m
.61905 .30902 L
s
.64286 .01472 m
.64286 .30902 L
s
.66667 .01472 m
.66667 .30902 L
s
.69048 .01472 m
.69048 .30902 L
s
.71429 .01472 m
.71429 .01472 L
s
.7381 .01472 m
.7381 .01472 L
s
.7619 .01472 m
.7619 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.80952 .01472 m
.80952 .01472 L
s
.83333 .01472 m
.83333 .01472 L
s
.85714 .01472 m
.85714 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.90476 .01472 m
.90476 .01472 L
s
.92857 .01472 m
.92857 .01472 L
s
.95238 .01472 m
.95238 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.04762 .01472 Mdot
.07143 .01472 Mdot
.09524 .01472 Mdot
.11905 .01472 Mdot
.14286 .01472 Mdot
.16667 .01472 Mdot
.19048 .01472 Mdot
.21429 .01472 Mdot
.2381 .01472 Mdot
.2619 .01472 Mdot
.28571 .01472 Mdot
.30952 .30902 Mdot
.33333 .30902 Mdot
.35714 .30902 Mdot
.38095 .30902 Mdot
.40476 .30902 Mdot
.42857 .30902 Mdot
.45238 .30902 Mdot
.47619 .30902 Mdot
.5 .30902 Mdot
.52381 .30902 Mdot
.54762 .30902 Mdot
.57143 .30902 Mdot
.59524 .30902 Mdot
.61905 .30902 Mdot
.64286 .30902 Mdot
.66667 .30902 Mdot
.69048 .30902 Mdot
.71429 .01472 Mdot
.7381 .01472 Mdot
.7619 .01472 Mdot
.78571 .01472 Mdot
.80952 .01472 Mdot
.83333 .01472 Mdot
.85714 .01472 Mdot
.88095 .01472 Mdot
.90476 .01472 Mdot
.92857 .01472 Mdot
.95238 .01472 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.120774 0.0283859 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12077 -6 -4.5 ]
[-0.0125 .12077 0 4.5 ]
[-0.0125 .2627 -6 -4.5 ]
[-0.0125 .2627 0 4.5 ]
[-0.0125 .40463 -12 -4.5 ]
[-0.0125 .40463 0 4.5 ]
[-0.0125 .54656 -12 -4.5 ]
[-0.0125 .54656 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12077 m
.00625 .12077 L
s
[(0)] -0.0125 .12077 1 0 Mshowa
0 .2627 m
.00625 .2627 L
s
[(5)] -0.0125 .2627 1 0 Mshowa
0 .40463 m
.00625 .40463 L
s
[(10)] -0.0125 .40463 1 0 Mshowa
0 .54656 m
.00625 .54656 L
s
[(15)] -0.0125 .54656 1 0 Mshowa
.125 Mabswid
0 .14916 m
.00375 .14916 L
s
0 .17755 m
.00375 .17755 L
s
0 .20593 m
.00375 .20593 L
s
0 .23432 m
.00375 .23432 L
s
0 .29109 m
.00375 .29109 L
s
0 .31948 m
.00375 .31948 L
s
0 .34786 m
.00375 .34786 L
s
0 .37625 m
.00375 .37625 L
s
0 .43302 m
.00375 .43302 L
s
0 .46141 m
.00375 .46141 L
s
0 .48979 m
.00375 .48979 L
s
0 .51818 m
.00375 .51818 L
s
0 .09239 m
.00375 .09239 L
s
0 .064 m
.00375 .064 L
s
0 .03562 m
.00375 .03562 L
s
0 .00723 m
.00375 .00723 L
s
0 .57495 m
.00375 .57495 L
s
0 .60333 m
.00375 .60333 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .12077 m
1 .12077 L
s
.99375 .2627 m
1 .2627 L
s
.99375 .40463 m
1 .40463 L
s
.99375 .54656 m
1 .54656 L
s
.125 Mabswid
.99625 .14916 m
1 .14916 L
s
.99625 .17755 m
1 .17755 L
s
.99625 .20593 m
1 .20593 L
s
.99625 .23432 m
1 .23432 L
s
.99625 .29109 m
1 .29109 L
s
.99625 .31948 m
1 .31948 L
s
.99625 .34786 m
1 .34786 L
s
.99625 .37625 m
1 .37625 L
s
.99625 .43302 m
1 .43302 L
s
.99625 .46141 m
1 .46141 L
s
.99625 .48979 m
1 .48979 L
s
.99625 .51818 m
1 .51818 L
s
.99625 .09239 m
1 .09239 L
s
.99625 .064 m
1 .064 L
s
.99625 .03562 m
1 .03562 L
s
.99625 .00723 m
1 .00723 L
s
.99625 .57495 m
1 .57495 L
s
.99625 .60333 m
1 .60333 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .14916 m
.02499 .1491 L
.02605 .14894 L
.02729 .14862 L
.02846 .14821 L
.03053 .14717 L
.03279 .14565 L
.0379 .14077 L
.04262 .13481 L
.05285 .11912 L
.06244 .10472 L
.06713 .09906 L
.06955 .09671 L
.07218 .09463 L
.07367 .0937 L
.07505 .09301 L
.07637 .0925 L
.07711 .09228 L
.07778 .09212 L
.07904 .09194 L
.07976 .0919 L
.08041 .0919 L
.08162 .09201 L
.0829 .09227 L
.08359 .09247 L
.08425 .0927 L
.08548 .09323 L
.08824 .09491 L
.09063 .09686 L
.09323 .09948 L
.10458 .11542 L
.11478 .13204 L
.11977 .1393 L
.12435 .14477 L
.12665 .14695 L
.12916 .14886 L
.13038 .1496 L
.13168 .15023 L
.1324 .15052 L
.13306 .15074 L
.13434 .15105 L
.13503 .15115 L
.13576 .15121 L
.13706 .15119 L
.13779 .15111 L
.13846 .15099 L
.13921 .15081 L
.14001 .15055 L
.14144 .14995 L
.14281 .14919 L
Mistroke
.14536 .14733 L
.14796 .14486 L
.15041 .14205 L
.15497 .13573 L
.16521 .11839 L
.17398 .10343 L
.17863 .09681 L
.18119 .09378 L
.18361 .0914 L
.18488 .09035 L
.18626 .08939 L
.18741 .08872 L
.18867 .08814 L
.18986 .08774 L
.19113 .08747 L
.1923 .08737 L
.1934 .0874 L
.19466 .0876 L
.1953 .08777 L
.19599 .08799 L
.19723 .08852 L
.19837 .08915 L
.20096 .09106 L
.20372 .09382 L
.20871 .10047 L
.21342 .10834 L
.22221 .12542 L
.23196 .14376 L
.23687 .15108 L
.23966 .15434 L
.2409 .15555 L
.24226 .15668 L
.2435 .15754 L
.24465 .15819 L
.24575 .15866 L
.24692 .15902 L
.24796 .15919 L
.24894 .15924 L
.25001 .15916 L
.25117 .15892 L
.25233 .15851 L
.2536 .15788 L
.25492 .15702 L
.25616 .15603 L
.26073 .15085 L
.26335 .1469 L
.26577 .14268 L
.27123 .13152 L
.28116 .10831 L
.29011 .08898 L
Mistroke
.29269 .08446 L
.29514 .08078 L
.29737 .07803 L
.29974 .07578 L
.301 .07489 L
.30214 .07427 L
.30329 .07383 L
.30437 .07359 L
.30563 .07353 L
.3068 .07369 L
.30807 .07409 L
.30871 .07439 L
.30942 .07478 L
.31168 .07655 L
.31295 .07787 L
.31411 .07928 L
.31848 .08629 L
.32356 .09741 L
.32908 .11231 L
.33911 .14275 L
.34852 .16827 L
.3511 .1737 L
.35388 .1785 L
.35515 .18029 L
.3565 .18188 L
.35773 .18306 L
.3589 .18391 L
.36022 .18457 L
.36142 .18487 L
.36271 .18487 L
.36343 .18472 L
.3641 .18449 L
.36522 .18391 L
.36645 .18296 L
.36774 .18163 L
.36894 .18009 L
.37171 .1754 L
.37423 .16978 L
.37991 .15283 L
.38992 .112 L
.40056 .06355 L
.40574 .04285 L
.40827 .03424 L
.4106 .02749 L
.41269 .02252 L
.41498 .01838 L
.41616 .01682 L
.41727 .01574 L
.41844 .01501 L
.41969 .01472 L
Mistroke
.42094 .01494 L
.42226 .01576 L
.42339 .01694 L
.42463 .01877 L
.42596 .02135 L
.4274 .02487 L
.42999 .03318 L
.4326 .04409 L
.43508 .05683 L
.43973 .08685 L
.44844 .16234 L
.45796 .26579 L
.46893 .39415 L
.47927 .50204 L
.48378 .5397 L
.48855 .57096 L
.49104 .58336 L
.49236 .58877 L
.49378 .59364 L
.49508 .59726 L
.49627 .59983 L
.49746 .60171 L
.49859 .60284 L
.49975 .60332 L
.50083 .60316 L
.50203 .6023 L
.50331 .60058 L
.50458 .59806 L
.50592 .59454 L
.50832 .58607 L
.51055 .57577 L
.51262 .56417 L
.51733 .53114 L
.52718 .43746 L
.53771 .31654 L
.54795 .19963 L
.55334 .1451 L
.55905 .09602 L
.56404 .06195 L
.56668 .04755 L
.56953 .03499 L
.57214 .02617 L
.57452 .02033 L
.57567 .01827 L
.57692 .01657 L
.5781 .01547 L
.5792 .01489 L
.58049 .01473 L
.58114 .01485 L
.58185 .01515 L
Mistroke
.58311 .01606 L
.58428 .01736 L
.58567 .01941 L
.58694 .02176 L
.58978 .02853 L
.5949 .0452 L
.59975 .06489 L
.6086 .10524 L
.61364 .1277 L
.61837 .14666 L
.62341 .16345 L
.62804 .17489 L
.63045 .17918 L
.63167 .18091 L
.63298 .18242 L
.6343 .18357 L
.63553 .18433 L
.63628 .18464 L
.63698 .18482 L
.63831 .1849 L
.63937 .1847 L
.64054 .18423 L
.64177 .18345 L
.64291 .18248 L
.64496 .18015 L
.64715 .17686 L
.65216 .16669 L
.65673 .15486 L
.66675 .12479 L
.67224 .10855 L
.6774 .0951 L
.68177 .08581 L
.68402 .08196 L
.68649 .07853 L
.68904 .0759 L
.69043 .07487 L
.69173 .07418 L
.69294 .07375 L
.69405 .07356 L
.69533 .07356 L
.69654 .07378 L
.69767 .07418 L
.69874 .07473 L
.69991 .07551 L
.70117 .07656 L
.70374 .07932 L
.70608 .08254 L
.7149 .09927 L
.72523 .12345 L
.73026 .13476 L
Mistroke
.73482 .14375 L
.73709 .14761 L
.73955 .15124 L
.74168 .15387 L
.74401 .15618 L
.74521 .15712 L
.7465 .15794 L
.7472 .1583 L
.74785 .15859 L
.74912 .15899 L
.75027 .1592 L
.75153 .15923 L
.75271 .15909 L
.75381 .15881 L
.755 .15835 L
.75628 .15768 L
.75859 .15599 L
.76134 .15326 L
.76386 .15011 L
.77454 .13187 L
.78369 .11375 L
.78872 .1046 L
.79347 .09731 L
.79616 .09394 L
.79909 .09102 L
.80038 .08999 L
.80174 .08908 L
.80302 .0884 L
.80419 .08793 L
.80538 .0876 L
.80665 .0874 L
.80782 .08737 L
.80894 .08748 L
.81024 .08776 L
.81144 .08818 L
.81276 .08881 L
.81417 .08967 L
.81679 .09175 L
.81955 .0946 L
.82448 .10111 L
.83563 .11987 L
.84538 .13625 L
.85084 .14353 L
.85342 .14624 L
.85581 .14825 L
.85816 .14975 L
.85935 .15031 L
.86066 .15077 L
.86197 .15107 L
.8627 .15117 L
Mistroke
.86338 .15122 L
.86468 .15118 L
.86593 .151 L
.86707 .1507 L
.8683 .15024 L
.8705 .14908 L
.87312 .14715 L
.87549 .14492 L
.88494 .13248 L
.89384 .11799 L
.90359 .10329 L
.90851 .09767 L
.9113 .09525 L
.91254 .09436 L
.9139 .09355 L
.91514 .09295 L
.91629 .09251 L
.91739 .0922 L
.91856 .09199 L
.9196 .0919 L
.92058 .09191 L
.92165 .09202 L
.92281 .09226 L
.92397 .09261 L
.92524 .09314 L
.9278 .09461 L
.93016 .09645 L
.93237 .09854 L
.95243 .1275 L
.96153 .14011 L
.96402 .14282 L
.96666 .14521 L
.96891 .14683 L
.9702 .14758 L
.97139 .14814 L
.97258 .14858 L
.97387 .14892 L
.97506 .1491 L
.97619 .14916 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`009oooool3o`0001kooooo0ol0000Jooooo`Go0000
6_ooool2o`0001cooooo1Ol0000Looooo`?o00007?ooool3o`0004Wooooo0ol00004ooooo`;o0000
8_ooool3o`0002?ooooo0_l0000Tooooo`?o00008_ooool3o`0000Cooooo0_l0000Uooooo`009_oo
ool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool06_ooool01?l0003ooooo
ooooool0000Iooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00007Oooool0
0ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000BOooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`00023ooooo00Go0000ooooooooooooooooo`00000Qooooo`04
o`000?ooooooooooo`0002;ooooo00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00009?ooool0023ooooo1Ol000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo01?ooooo1Ol000000ooooooo0000o`000003o`0001Cooooo1Ol00003
ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00007Oooool00ol0003ooooooooo
o`0Jooooo`Go00006oooool01Ol0003ooooooooooooooooo0000047ooooo1Ol00003ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool5o`0000Gooooo00?o0000oooooooo
ool07oooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Tooooo`009_ooool4o`0001cooooo00Co0000oooo
oooooooo00007_ooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0001kooooo00?o
0000ooooooooool06Oooool01?l0003oooooooooool0000Looooo`Co0000B_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool07oooool01?l0003o
ooooooooool0000Vooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Tooooo`009_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo0000
01_ooooo00Go0000ooooooooooooooooo`00000Iooooo`04o`000?ooooooooooo`0001_ooooo00Go
0000ooooooooooooooooo`00000Kooooo`03o`000?oooooo000001cooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00023ooooo1?l0000Rooooo`04
o`000?ooooooooooo`0002;ooooo1?l0000Sooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00009?ooool002Oooooo00?o0000ooooooooool07_ooool2o`0001_ooooo00Go0000oooo
ooooooooooooo`00000Iooooo`04o`000?ooooooooooo`0001_ooooo00Go0000oooooooooooooooo
o`00000Looooo`;o00007Oooool00ol0003oooooooooo`19ooooo`;o00001?ooool01?l0003ooooo
ooooool0000Pooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00008_ooool00ol0
003oooooooooo`0Sooooo`;o00001?ooool01?l0003oooooooooool0000Tooooo`00:?ooool2o`00
01oooooo00?o0000ooooooooool06_ooool3o`0001_ooooo0_l0000Mooooo`?o00007_ooool00ol0
003oooooooooo`0Looooo`;o0000B_ooool00ol0003oooooooooo`03ooooo`;o00008Oooool5o`00
02;ooooo0_l0000Sooooo`Go00008_ooool00ol0003oooooooooo`03ooooo`;o00009Oooool00?oo
oooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool001coooood_l0000Yoooo
om;o00003oooool001cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`;o
0000:Oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool0
00003oooool001cooooo0_l0003?ooooo`03o`000?oooooooooo02Oooooo0_l0003>ooooo`;o0000
3oooool001cooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`1?ooooo`;oo`003ooo
ool2ool0057ooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Kooooo0_oo000Wooooo`;oo`001oooool00ooo003oooooooooo`0Vooooo`;oo`001ooo
ool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00Gooooo0_oo000Xooooo`03ool00?oo
oooooooo00Kooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02_ooool2
ool0057ooooo0_oo000?ooooo`;oo`00DOooool2ool000_ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`06ooooo`;oo`009oooool2ool000Oooooo00?oo`00ooooooooool09_ooool2
ool000Kooooo0_oo000Xooooo`03ool00?oooooooooo00Gooooo0_oo000Xooooo`03ool00?oooooo
oooo00Kooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02_ooool00ooo
003oooooool0001@ooooo`;oo`003oooool2ool0053ooooo00?oo`00oooooooo00002oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo0_oo000Wooooo`;oo`001oooool00ooo
003oooooooooo`0Vooooo`;oo`001_ooool2ool002Sooooo00?oo`00ooooooooool01Oooool2ool0
02Oooooo0_oo0008ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00[o
oooo00?oo`00oooooooo0000D?ooool2ool000kooooo00?oo`00oooooooo0000D?ooool00ooo003o
ooooool0000;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool2ool002Oo
oooo0_oo0007ooooo`03ool00?oooooooooo02Kooooo0_oo0006ooooo`;oo`00:?ooool00ooo003o
ooooooooo`05ooooo`;oo`009oooool2ool000Sooooo00?o0000ooooooooool03Oooool001cooooo
00?o0000ooooooooool02_ooool00ooo003oooooool0001?ooooo`03ool00?ooooooo`0000kooooo
00?oo`00oooooooo0000D?ooool00ooo003oooooool0000;ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool01_ooool2ool002Oooooo0_oo0006ooooo`03ool00?ooooooo`0002Oooooo
0_oo0006ooooo`;oo`009oooool00ooo003oooooool00006ooooo`;oo`009oooool2ool000Sooooo
00?o0000ooooooooool03Oooool001cooooo0_l0000;ooooo`03ool00?ooooooo`0004oooooo00?o
o`00oooooooo00003_ooool00ooo003oooooool0001@ooooo`03ool00?ooooooo`0000_ooooo00?o
0000ooooooooool09oooool2o`0000Oooooo0_oo000Wooooo`;oo`001_ooool00ooo003oooooool0
000Wooooo`;oo`001_ooool2ool002Oooooo00?oo`00oooooooo00001_ooool2ool002Oooooo0_oo
0007ooooo`;o00003oooool001cooooo00?o0000ooooooooool02Oooool01?oo003ooooooooooooo
001?ooooo`04ool00?ooooooooooool000gooooo00Coo`00ooooooooooooo`00Coooool00ooo003o
ooooool0000;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool2ool002Oo
oooo0_oo0006ooooo`03ool00?ooooooo`0002Oooooo0_oo0006ooooo`;oo`009oooool00ooo003o
ooooool00006ooooo`;oo`009oooool2ool000Sooooo00?o0000ooooooooool03Oooool001cooooo
00?o0000ooooooooool02Oooool01?oo003ooooooooooooo001?ooooo`04ool00?ooooooooooool0
00gooooo00Coo`00ooooooooooooo`00Coooool00ooo003oooooool0000;ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool01_ooool2ool002Oooooo0_oo0006ooooo`03ool00?oooooo
o`0002Oooooo0_oo0006ooooo`03ool00?ooooooo`0002Kooooo00?oo`00oooooooo00001_ooool2
ool002Oooooo0_oo0008ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo
00Wooooo00Goo`00ooooooooooooooooool0001>ooooo`04ool00?ooooooooooool000gooooo00Co
o`00ooooooooooooo`00Coooool00ooo003oooooool0000;ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool01Oooool00ooo003oooooool0000Wooooo`;oo`001_ooool00ooo003ooooo
ool0000Wooooo`;oo`001_ooool00ooo003oooooool0000Vooooo`03ool00?ooooooo`0000Kooooo
0_oo000Wooooo`;oo`002?ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003ooooooooo
o`09ooooo`05ool00?oooooooooooooooooo0000C_ooool01?oo003ooooooooooooo000=ooooo`04
ool00?ooooooooooool004kooooo00Goo`00ooooooooooooooooool0000:ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool01Oooool00ooo003oooooool0000Wooooo`;oo`001_ooool0
0ooo003oooooool0000Vooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00009_ooool0
0ooo003oooooool00006ooooo`;oo`009oooool2ool000Sooooo00?o0000ooooooooool03Oooool0
01cooooo0_l0000:ooooo`05ool00?oooooooooooooooooo0000C_ooool01?oo003ooooooooooooo
000=ooooo`04ool00?ooooooooooool004kooooo00Goo`00ooooooooooooooooool0000:ooooo`03
o`000?oooooooooo02Oooooo0_l00006ooooo`03ool00?ooooooo`0002Oooooo0_oo0006ooooo`03
ool00?ooooooo`0002Kooooo00?oo`00oooooooo00001_ooool00ooo003oooooool0000Vooooo`03
ool00?ooooooo`0000Kooooo0_oo000Wooooo`03ool00?ooooooo`0000Kooooo0_l0000?ooooo`00
7?ooool00ol0003oooooooooo`09ooooo`05ool00?oooooooooooooooooo0000COooool01Ooo003o
ooooooooooooooooo`0000cooooo00Goo`00ooooooooooooooooool0001>ooooo`05ool00?oooooo
oooooooooooo00002_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o
o`00oooooooo00009oooool2ool000Kooooo00?oo`00oooooooo00009_ooool00ooo003oooooool0
0006ooooo`03ool00?ooooooo`0002Kooooo00?oo`00oooooooo00001_ooool2ool002Oooooo00?o
o`00oooooooo00001oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`09
ooooo`05ool00?oooooooooooooooooo00002Oooool00ooo003oooooooooo`0hooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`09ooooo`05ool00?oo
oooooooooooooooo00002Oooool00ooo003oooooooooo`0hooooo`03ool00?oooooooooo00Oooooo
00Goo`00ooooooooooooooooool0000:ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool01Oooool01?oo003ooooooooooooo0003ooooo`;oo`007?ooool00ooo003oooooooooo`02oooo
o`;oo`001_ooool00ooo003oooooool00004ooooo`03ool00?oooooooooo01[ooooo0_oo0003oooo
o`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001?ooool00ooo003oooooooooo`0Joooo
o`03ool00?oooooooooo00;ooooo00?oo`00oooooooo00001_ooool2ool000Cooooo0_oo000Loooo
o`03ool00?oooooooooo00;ooooo00?oo`00oooooooo00001oooool00ol0003oooooooooo`0=oooo
o`007?ooool00ol0003oooooooooo`09ooooo`05ool00?oooooooooooooooooo00002?ooool2ool0
03Wooooo0_oo0008ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02Oooool01Ooo
003oooooooooooooooooo`0000Wooooo0_oo000hooooo`?oo`002?ooool01Ooo003ooooooooooooo
ooooo`0000[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05ooooo`04ool00?oo
ooooooooool000?ooooo0_oo000Kooooo`;oo`001?ooool2ool000Kooooo00?oo`00oooooooo0000
1?ooool00ooo003oooooooooo`0Jooooo`;oo`000oooool00ooo003oooooool00006ooooo`03ool0
0?ooooooo`0000?ooooo0_oo000Looooo`;oo`000oooool00ooo003oooooool00006ooooo`;oo`00
1?ooool2ool001cooooo00?oo`00ooooooooool00_ooool00ooo003oooooool00007ooooo`03o`00
0?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Wooooo00Goo`00oooooooooooooooo
ool00008ooooo`03ool00?ooooooo`0003Sooooo00?oo`00oooooooo00001oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`05ooooo`04ool00?ooooooooooool003Oooooo00?oo`00oooooooo00002?ooool01Ooo003o
ooooooooooooooooo`0000[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05oooo
o`04ool00?ooooooooooool000?ooooo0_oo000Kooooo`;oo`001?ooool2ool000Kooooo00?oo`00
oooooooo00000oooool3ool001_ooooo0_oo0003ooooo`03ool00?ooooooo`0000Kooooo00?oo`00
oooooooo00000oooool2ool001cooooo0_oo0003ooooo`03ool00?ooooooo`0000Gooooo00Coo`00
ooooooooooooo`000oooool2ool001_ooooo0_oo0004ooooo`03ool00?ooooooo`0000Oooooo00?o
0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo00002Oooool2ool002;ooooo00?oo`00
ooooooooool01oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Co
o`00ooooooooooooo`002Oooool00ooo003oooooooooo`0Pooooo`;oo`002Oooool00ooo003ooooo
ool00008ooooo`05ool00?oooooooooooooooooo00002_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Gooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooool00004oooo
o`03ool00?oooooooooo00oooooo00?oo`00ooooooooool00_ooool2ool000?ooooo00?oo`00oooo
oooo00001_ooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000Cooooo00?oo`00oooo
ooooool03_ooool2ool000Cooooo0_oo0003ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooo
oooo00000oooool2ool000Cooooo0_oo000@ooooo`;oo`000oooool00ooo003oooooool00003oooo
o`03ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`000oooool2ool000Cooooo0_oo000@
ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo00000oooool00ooo003oooooool00007
ooooo`03o`000?oooooooooo00gooooo000Looooo`;o00002_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`002Oooool2ool000[ooooo0_oo000:
ooooo`03ool00?oooooooooo00Sooooo0ooo0008ooooo`04ool00?ooooooooooool000Oooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool01Oooool01?oo003ooooooooooooo0008ooooo`03ool00?ooooooo`0000Wooooo
0_oo000:ooooo`;oo`002Oooool3ool000Sooooo00Goo`00ooooooooooooooooool00007ooooo`05
ool00?oooooooooooooooooo00002_ooool00ol0003oooooooooo`0Wooooo`;o00001_ooool01?oo
003ooooooooooooo0002ooooo`03ool00?ooooooo`0000Cooooo0_oo0004ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool00_ooool2ool000Cooooo0_oo0003ooooo`03ool00?oooooo
o`0000Kooooo00?oo`00oooooooo00000oooool00ooo003oooooool00003ooooo`;oo`001Oooool0
0ooo003oooooooooo`02ooooo`;oo`001?ooool2ool000Cooooo0_oo0003ooooo`03ool00?oooooo
o`0000Kooooo00?oo`00oooooooo00000oooool2ool000Cooooo0_oo0004ooooo`;oo`001?ooool2
ool000Cooooo0_oo0003ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00001Oooool0
1?oo003ooooooooooooo0003ooooo`;oo`001?ooool2ool000Cooooo0_oo0004ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooool00003ooooo`03ool00?oo
ooooo`0000Kooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`09ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool01?ooool01?oo003ooooooooooooo0008ooooo`04ool00?oo
ooooooooool000Sooooo0ooo0009ooooo`?oo`002?ooool01?oo003ooooooooooooo0008ooooo`04
ool00?ooooooooooool000Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`09oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01?oo003ooooooooooooo0008
ooooo`03ool00?ooooooo`0000Wooooo0ooo0008ooooo`Coo`002?ooool01?oo003ooooooooooooo
0007ooooo`05ool00?oooooooooooooooooo00001_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05ooooo`04ool0
0?ooooooooooool000;ooooo00?oo`00oooooooo00001?ooool2ool000?ooooo0_oo0004ooooo`;o
o`001?ooool2ool000Cooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0005oooo
o`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000oooool2ool000Cooooo0_oo0004oooo
o`;oo`001?ooool2ool000?ooooo00?oo`00oooooooo00000oooool00ooo003oooooool00006oooo
o`03ool00?ooooooo`0000?ooooo0_oo0004ooooo`;oo`001?ooool2ool000Cooooo0_oo0003oooo
o`?oo`000oooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000Gooooo00Coo`00oooo
ooooooooo`000oooool2ool000Cooooo0_oo0004ooooo`;oo`001?ooool2ool000?ooooo00?oo`00
oooooooo00000oooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000Oooooo00?o0000
ooooooooool03Oooool001cooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`002?ooool01?oo003ooooooooooooo
0008ooooo`04ool00?ooooooooooool000Sooooo00?oo`00oooooooo00002?ooool01?oo003ooooo
oooooooo0007ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`05ooooo`04ool00?ooooooooooool000Sooooo00Coo`00ooooooooooooo`001oooool0
1?oo003ooooooooooooo0008ooooo`04ool00?ooooooooooool000Sooooo00Coo`00oooooooooooo
o`001oooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`08ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool01?oo
003ooooooooooooo0002ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000oooool0
0ooo003oooooool00003ooooo`;oo`001?ooool2ool000Cooooo00?oo`00oooooooo00000_ooool0
1?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000ooo
ool00ooo003oooooool00003ooooo`;oo`001?ooool2ool000Cooooo0_oo0003ooooo`03ool00?oo
ooooo`0000?ooooo00?oo`00oooooooo00001_ooool00ooo003oooooool00003ooooo`03ool00?oo
ooooo`0000?ooooo0_oo0004ooooo`;oo`001?ooool2ool000?ooooo00?oo`00oooooooo00000ooo
ool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`00
0_ooool00ooo003oooooool00004ooooo`;oo`000oooool3ool000?ooooo00?oo`00oooooooo0000
0oooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo0000
1oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`08ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0000Oooooo
00Goo`00ooooooooooooooooool00007ooooo`04ool00?ooooooooooool000Oooooo00Coo`00oooo
ooooooooo`002?ooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02Ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`00
1oooool01Ooo003oooooooooooooooooo`0000Oooooo00Goo`00ooooooooooooooooool00007oooo
o`04ool00?ooooooooooool000Sooooo00Coo`00ooooooooooooo`001_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`08ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool01?oo003ooooooooo
oooo0002ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000oooool00ooo003ooooo
ool00003ooooo`;oo`001?ooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000;ooooo
00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000?o
oooo00?oo`00oooooooo00000oooool2ool000Cooooo0_oo0003ooooo`03ool00?ooooooo`0000?o
oooo00?oo`00oooooooo00000oooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000;o
oooo00Coo`00ooooooooooooo`000oooool2ool000Cooooo0_oo0004ooooo`;oo`000oooool00ooo
003oooooool00003ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00001Oooool01?oo
003ooooooooooooo0002ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000oooool0
0ooo003oooooool00003ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000oooool0
0ooo003oooooool00003ooooo`03ool00?ooooooo`0000Oooooo00?o0000ooooooooool03Oooool0
01Kooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00006
ooooo`05ool00?oooooooooooooooooo00001oooool01Ooo003oooooooooooooooooo`0000Kooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool02Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo
00001oooool01Ooo003oooooooooooooooooo`0000Oooooo00Coo`00ooooooooooooo`001oooool0
1Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02?ooool00ol0003ooooooooo
o`0Pooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`04ool00?ooooooooooool000;ooooo
00?oo`00oooooooo00000oooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000?ooooo
00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
00;ooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00003ooooo`03ool00?oooooo
o`0000?ooooo00?oo`00oooooooo00000oooool00ooo003oooooool00002ooooo`04ool00?oooooo
ooooool000;ooooo00?oo`00oooooooo00000oooool00ooo003oooooool00003ooooo`03ool00?oo
ooooo`0000Kooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0003ooooo`03ool0
0?ooooooo`0000;ooooo00?oo`00oooooooo00000oooool00ooo003oooooool00003ooooo`03ool0
0?ooooooo`0000?ooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0005ooooo`04
ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooool00003
ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000oooool00ooo003oooooool00003
ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00001oooool00ol0003oooooooooo`0=
ooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00001_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02Ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`05ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
ooooo`000_ooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000;ooooo00Coo`00oooo
ooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo
00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000?o
oooo00?oo`00oooooooo00000oooool00ooo003oooooool00002ooooo`04ool00?ooooooooooool0
00;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oo
ooooo`0000Kooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooool00003oooo
o`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0005
ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooo
ool00003ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000oooool00ooo003ooooo
ool00003ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`001oooool00ol0003o
ooooooooo`0=ooooo`005Oooool01?l0003oooooooooool00003ooooo`?o00002?ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool00006oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`08oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Oooooo0_l0000Qooooo`04o`000?ooooooooooo`0000Cooooo0_l00006
ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooo
ool00003ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`001Ooo
ool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000Kooooo00?o
o`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooool00003ooooo`03ool00?ooooooo`00
00;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0005ooooo`04ool00?oo
ooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002oooo
o`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000oooool00ooo003oooooool00003oooo
o`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`001_ooool2o`0000oooooo000Eoooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`08
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool07oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Gooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooo
oooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo00000_ooool01?oo
003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0005ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
oooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Co
o`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
00;ooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00002ooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`06
ool00?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oo
ooooooooool000;ooooo00?oo`00ooooooooool00oooool01?oo003ooooooooooooo0002ooooo`04
ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo
0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooo
oooooooo0002ooooo`04ool00?ooooooooooool000Oooooo00?o0000ooooooooool03Oooool001Go
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo
00Cooooo00Goo`00ooooooooooooooooool00006ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Sooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool01?ooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01ooo
ool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1Oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Koo`00oooo
ooooooooo`00oooooooo0003ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
ooooool00oooool01?oo003ooooooooooooo0002ooooo`06ool00?ooooooooooool00?ooooooo`00
0_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo
00?oo`00ooooooooool00oooool00ooo003oooooool00002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003oooooool000?ooooo00?o
o`00oooooooo00000oooool00ooo003oooooool00002ooooo`04ool00?ooooooooooool000;ooooo
00?oo`00ooooooooool00oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
00;ooooo00Koo`00ooooooooooooo`00oooooooo0003ooooo`04ool00?ooooooooooool000;ooooo
00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
00;ooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`005Oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool01?ooool01Ooo
003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool01Ooo003ooooooooooooo
ooooo`0000Oooooo00Goo`00ooooooooooooooooool00006ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool02?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo
00Goo`00ooooooooooooooooool00007ooooo`05ool00?oooooooooooooooooo00001_ooool01Ooo
003oooooooooooooooooo`0000Oooooo00Goo`00ooooooooooooooooool00006ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`07ooooo`03o`000?oo
oooooooo01oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003o
ooooool000?ooooo00?oo`00oooooooo00000oooool00ooo003oooooool00002ooooo`04ool00?oo
ooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03ooooo`04
ool00?ooooooooooool000;ooooo00Koo`00ooooooooooooo`00oooooooo0003ooooo`03ool00?oo
ooooo`0000?ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00003ooooo`03ool00?oo
ooooo`0000?ooooo00?oo`00oooooooo00000oooool00ooo003oooooooooo`02ooooo`04ool00?oo
ooooooooool000;ooooo00Ooo`00ooooooooooooooooool00?ooooooo`0000;ooooo00?oo`00oooo
oooo00000oooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooo
oooo00000oooool00ooo003oooooool00002ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooo
ooooooooo`000_ooool01_oo003ooooooooooooo003oooooool000?ooooo00?oo`00oooooooo0000
0oooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo0000
0_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Gooooo00?o0000oooooooo
ool03Oooool001Kooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0
1?ooool01Ooo003oooooooooooooooooo`0000Oooooo00Goo`00ooooooooooooooooool00007oooo
o`05ool00?oooooooooooooooooo00001_ooool01Ooo003oooooooooooooooooo`0000Oooooo00Go
o`00ooooooooooooooooool00007ooooo`04ool00?ooooooooooool000Oooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00Goo`00oooooooo
ooooooooool00007ooooo`05ool00?oooooooooooooooooo00001oooool01?oo003ooooooooooooo
0008ooooo`04ool00?ooooooooooool000Oooooo00Goo`00ooooooooooooooooool00007ooooo`05
ool00?oooooooooooooooooo00001_ooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo
023ooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo00Koo`00ooooooooooooo`00oooooooo
0003ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000oooool00ooo003oooooool0
0003ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooo
oooooooo0002ooooo`03ool00?oooooooooo00?ooooo00Koo`00ooooooooooooo`00oooooooo0003
ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000oooool00ooo003oooooool00003
ooooo`;oo`000oooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000?ooooo00?oo`00
ooooooooool00_ooool01?oo003ooooooooooooo0002ooooo`07ool00?oooooooooooooooooo003o
ooooool00003ooooo`;oo`000oooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000?o
oooo00?oo`00oooooooo00000oooool00ooo003oooooool00002ooooo`03ool00?oooooooooo00?o
oooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003oooooool000?ooooo00?o
o`00oooooooo00000oooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000?ooooo00?o
o`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Gooooo
00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02?ooool00ooo003ooooooooo
o`04ooooo`05ool00?oooooooooooooooooo00001oooool01?oo003ooooooooooooo0008ooooo`04
ool00?ooooooooooool000Sooooo00?oo`00oooooooo00002Oooool01?oo003ooooooooooooo0007
ooooo`04ool00?ooooooooooool000Oooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool00007ooooo`;oo`00
00?oooooool00?ooool01oooool2ool00003oooooooo003ooooo00Oooooo00Coo`00oooooooooooo
o`001oooool01Ooo003oooooooooooooooooo`0000Oooooo00Goo`00ooooooooooooooooool00006
ooooo`03ool00?oooooooooo00Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05
ooooo`06ool00?ooooooooooool00?ooooooo`000oooool00ooo003oooooool00003ooooo`03ool0
0?ooooooo`0000?ooooo0_oo0004ooooo`?oo`000oooool2ool000?ooooo00Coo`00oooooooooooo
o`000_ooool00ooo003oooooooooo`03ooooo`06ool00?ooooooooooool00?ooooooo`000oooool0
0ooo003oooooool00003ooooo`;oo`001?ooool2ool000Cooooo0_oo0003ooooo`03ool00?oooooo
o`0000?ooooo00?oo`00oooooooo00000oooool00ooo003oooooooooo`02ooooo`07ool00?oooooo
oooooooooooo003oooooool00003ooooo`;oo`001?ooool2ool000Cooooo0_oo0004ooooo`;oo`00
0oooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool0
0oooool01?oo003ooooooooooooo0002ooooo`06ool00?ooooooooooool00?ooooooo`001?ooool2
ool000Cooooo0_oo0003ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000oooool0
0ooo003oooooool00002ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03Oooool0
01cooooo0_l00009ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool00007
ooooo`04ool00?ooooooooooool000Sooooo0ooo0009ooooo`?oo`002Oooool3ool000Sooooo00Co
o`00ooooooooooooo`001oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01oooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo
00002?ooool01?oo003ooooooooooooo0008ooooo`03ool00?ooooooo`0000Wooooo0ooo0009oooo
o`;oo`002Oooool01?oo003ooooooooooooo0007ooooo`05ool00?oooooooooooooooooo00001_oo
ool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo0_l00006ooooo`06ool00?oo
ooooooooool00?ooooooo`000oooool00ooo003oooooool00003ooooo`;oo`001Oooool00ooo003o
ooooooooo`02ooooo`;oo`001?ooool2ool000?ooooo00Coo`00ooooooooooooo`000_ooool00ooo
003oooooooooo`03ooooo`06ool00?ooooooooooool00?ooooooo`000oooool00ooo003oooooool0
0003ooooo`;oo`001?ooool2ool000Cooooo0_oo0004ooooo`;oo`000oooool00ooo003oooooool0
0003ooooo`03ool00?oooooooooo00;ooooo00Ooo`00ooooooooooooooooool00?ooooooo`0000?o
oooo0_oo0004ooooo`;oo`001?ooool2ool000Cooooo0_oo0003ooooo`03ool00?ooooooo`0000?o
oooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`03ooooo`06ool00?ooooooooooool0
0?ooooooo`001?ooool2ool000Cooooo0_oo0004ooooo`;oo`001?ooool00ooo003oooooooooo`02
ooooo`03ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`04
ooooo`;o00003oooool001cooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`04oooo
o`05ool00?oooooooooooooooooo00002?ooool00ooo003oooooool00009ooooo`;oo`005_ooool0
0ooo003oooooooooo`07ooooo`;oo`0000?oooooool00?ooool01_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`04
ooooo`05ool00?oooooooooooooooooo00002?ooool00ooo003oooooool0000:ooooo`03ool00?oo
oooooooo01Cooooo0_oo0009ooooo`03ool00?ooooooo`0000Sooooo00Goo`00oooooooooooooooo
ool00006ooooo`03ool00?oooooooooo00Oooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`05ooooo`06ool00?ooooooooooool00?ooooooo`001?ooool2ool000Cooooo00?oo`00oooo
ooooool02Oooool00ooo003oooooooooo`02ooooo`;oo`001?ooool2ool000?ooooo00?oo`00oooo
ooooool00oooool01_oo003ooooooooooooo003oooooool000?ooooo00?oo`00oooooooo00001?oo
ool00ooo003oooooooooo`08ooooo`;oo`001?ooool2ool000?ooooo00?oo`00oooooooo00000ooo
ool00ooo003oooooooooo`02ooooo`07ool00?oooooooooooooooooo003oooooool00003ooooo`;o
o`001?ooool2ool000[ooooo00?oo`00ooooooooool00oooool2ool000?ooooo00?oo`00oooooooo
00000_ooool00ooo003oooooooooo`03ooooo`04ool00?ooooooooooooooo`;oo`001?ooool2ool0
00Cooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`02ooooo`?oo`000oooool00ooo
003oooooool00002ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03Oooool001co
oooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooo
oooo00002?ooool2ool002gooooo0ooo0007ooooo`05ool00?oooooooooooooooooo00001oooool0
0ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool0
0009ooooo`;oo`00;?ooool3ool000Sooooo00Goo`00ooooooooooooooooool00006ooooo`03ool0
0?oooooooooo00Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05ooooo`06ool0
0?ooooooooooool00?ooooooo`001?ooool2ool001Gooooo0_oo0004ooooo`;oo`000oooool00ooo
003oooooooooo`03ooooo`06ool00?ooooooooooool00?ooooooo`000oooool2ool001Kooooo0_oo
0003ooooo`03ool00?ooooooo`0000?ooooo00?oo`00ooooooooool00_ooool01ooo003ooooooooo
ooooooooo`00oooooooo00000oooool2ool001Kooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooool00002ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooooooooooooooo0_oo0004oooo
o`;oo`005_ooool00ooo003oooooooooo`02ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooo
ooooool01Oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`07ooooo`03
ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00012ooooo`04ool00?oooooooooo
ool000Oooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`05ooooo`04ool00?oooooo
ooooool004;ooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`07ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool01Oooool01_oo003ooooooooooooo003oooooool0
027ooooo0_oo0003ooooo`03ool00?oooooooooo00?ooooo00Koo`00ooooooooooooo`00oooooooo
000Qooooo`;oo`000oooool00ooo003oooooooooo`02ooooo`04ool00?ooooooooooooooo`;oo`00
8Oooool00ooo003oooooool00002ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooooooooooo
oooo0_oo000Qooooo`;oo`000oooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo00go
oooo000Looooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ool00013ooooo`04ool00?ooooooooooool000Oooooo00?oo`00ooooooooool01oooool00ooo003o
ooooooooo`05ooooo`04ool00?ooooooooooool004;ooooo00Coo`00ooooooooooooo`001oooool0
0ooo003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool0
1_oo003ooooooooooooo003oooooool0027ooooo0_oo0003ooooo`03ool00?oooooooooo00?ooooo
00Koo`00ooooooooooooo`00oooooooo000Qooooo`;oo`000oooool00ooo003oooooooooo`02oooo
o`04ool00?ooooooooooooooo`;oo`008Oooool00ooo003oooooool00002ooooo`03ool00?oooooo
oooo00?ooooo00Coo`00oooooooooooooooo0_oo000Qooooo`;oo`000oooool00ooo003ooooooooo
o`05ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Oooooo00?oo`00
ooooooooool01_ooool00ooo003oooooool00013ooooo`03ool00?ooooooo`0000Sooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooool004?ooooo00?o
o`00oooooooo00001oooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool01Oooool01?oo003oooooooooooooool2ool0027ooooo0_oo0003ooooo`03ool0
0?oooooooooo00?ooooo00Koo`00ooooooooooooo`00oooooooo000Qooooo`;oo`000oooool00ooo
003oooooooooo`02ooooo`04ool00?ooooooooooooooo`;oo`008Oooool00ooo003oooooool00002
ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooooooooooooooo0_oo000Qooooo`;oo`000ooo
ool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo000Looooo`;o00002?ooool0
0ooo003oooooooooo`06ooooo`03ool00?ooooooo`0004?ooooo0ooo0008ooooo`03ool00?oooooo
oooo00Oooooo00?oo`00ooooooooool01Oooool3ool004Cooooo00?oo`00oooooooo00001oooool0
0ooo003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo0_l00006ooooo`04ool00?oooooo
ooooooooo`;oo`008Oooool2ool000?ooooo00?oo`00ooooooooool00_ooool01?oo003ooooooooo
ooooool3ool0027ooooo0_oo0003ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooo
oooo0_oo000Rooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`04ool00?oooooooooooooo
o`;oo`008Oooool2ool000?ooooo00?oo`00ooooooooool01?ooool2o`0000oooooo000Looooo`03
o`000?oooooooooo00Oooooo00?oo`00ooooooooool01_ooool3ool004Cooooo0_oo0008ooooo`03
ool00?oooooooooo00Oooooo00?oo`00ooooooooool01_ooool2ool004Cooooo0ooo0007ooooo`03
ool00?oooooooooo00Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05ooooo`04
ool00?ooooooooooooooo`;oo`008Oooool2ool000?ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo023ooooo0_oo0003ooooo`03ool00?oooooooooo
00;ooooo00Coo`00oooooooooooooooo0_oo000Rooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool01?oo003oooooooooooooool2ool0027ooooo0_oo0003ooooo`03ool00?oo
oooooooo00Gooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01oooool0
0ooo003oooooooooo`07ooooo`03ool00?oooooooooo04?ooooo0_oo0008ooooo`03ool00?oooooo
oooo00Oooooo00?oo`00ooooooooool01_ooool2ool004Gooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool0
1Ooo003oooooooooooooooooo`0002;ooooo0_oo0003ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo023ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`04ool00?ooooooooooooooo`;oo`00
8_ooool01Ooo003oooooooooooooooooo`0000Oooooo00?o0000ooooooooool03Oooool001cooooo
00?o0000ooooooooool01oooool00ooo003oooooooooo`1Gooooo`03ool00?oooooooooo00Oooooo
00?oo`00ooooooooool0E_ooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00Gooooo
00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01oooool00ooo003ooooooooo
o`1Gooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0E_ooool00ooo003ooooooooo
o`07ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool00ooo003ooooooooo
o`0Yooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0Yooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03Oooool001cooooo00?o0000
ooooooooool01oooool00ooo003oooooooooo`1Gooooo`03ool00?oooooooooo00Oooooo00?oo`00
ooooooooool0E_ooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool01Oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool0:_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00Gooooo00?o0000
ooooooooool03Oooool001cooooo0_l00008ooooo`03ool00?oooooooooo05Oooooo00?oo`00oooo
ooooool01oooool00ooo003oooooooooo`1Gooooo`03ool00?oooooooooo00Kooooo00?o0000oooo
ooooool09oooool2o`0000Kooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Zoooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`04oooo
o`;o00003oooool001cooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`1Gooooo`03
ool00?oooooooooo00Oooooo00?oo`00ooooooooool0Eoooool00ooo003oooooooooo`06ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Yooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo02[ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Yooooo`03
ool00?oooooooooo00Gooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0
1oooool00ooo003oooooooooo`1Hooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
Eoooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
1Oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
:_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool0
3Oooool001cooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`1Hooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool0Eoooool00ooo003oooooooooo`06ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Yooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo02[ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Yooooo`03ool00?oo
oooooooo00Gooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01oooool0
0ooo003oooooooooo`1Hooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0Eoooool0
0ooo003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool0
0ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03Oooool0
01cooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`1Hooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool0Eoooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
02[ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo
00Gooooo00?o0000ooooooooool03Oooool001cooooo0_l00008ooooo`03ool00?oooooooooo05So
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1Gooooo`03ool00?oooooooooo00Ko
oooo00?o0000ooooooooool09oooool2o`0000Kooooo00?oo`00ooooooooool0:Oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0Zooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:Oooool00ooo003o
ooooooooo`04ooooo`;o00003oooool001cooooo00?o0000ooooooooool01oooool00ooo003ooooo
ooooo`1Hooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0Eoooool00ooo003ooooo
ooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool00ooo003ooooo
ooooo`0Yooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`0Yooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool03Oooool001cooooo00?o
0000ooooooooool01oooool00ooo003oooooooooo`1Hooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool0Eoooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool01Oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool0:_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00Gooooo00?o
0000ooooooooool03Oooool001Gooooo0ol00004ooooo`03o`000?oooooooooo00Oooooo00?oo`00
ooooooooool0F?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo05Oooooo00?oo`00
ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?oo`00
ooooooooool0:Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool0:Oooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo000Doooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`07ooooo`03ool00?oooooo
oooo05Sooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1Gooooo`03ool00?oooooo
oooo00Kooooo00?o0000ooooooooool07oooool3o`0000Gooooo00?o0000ooooooooool01?ooool0
0ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool03Oooool0
01Sooooo00Go0000ooooooooooooooooo`000009ooooo`03ool00?oooooooooo05Sooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`1Gooooo`03ool00?oooooooooo00Kooooo00?o0000
ooooooooool07_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?oo
ool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool03Ooo
ool001Sooooo00Co0000oooooooooooooooo0ol00006ooooo`03ool00?oooooooooo05Wooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`1Hooooo`03ool00?oooooooooo00Gooooo0_l0
000Tooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03ool00?oooooooooo02_ooooo00Go
o`00ooooooooooooooooool0000/ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
:_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool0
0oooool2o`0000oooooo000Dooooo`Co00001?ooool00ol0003oooooooooo`06ooooo`03ool00?oo
oooooooo05Wooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`1Hooooo`03ool00?oo
oooooooo00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?oo`00ooooooooool0:oooool01Ooo003oooooooooooooooooo`0002cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo
000Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ooo003ooooooooo
o`1Iooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0F?ooool00ooo003ooooooooo
o`06ooooo`03o`000?oooooooooo01kooooo1?l00005ooooo`03o`000?oooooooooo00Cooooo00?o
o`00ooooooooool0:oooool01Ooo003oooooooooooooooooo`0002gooooo00Goo`00oooooooooooo
ooooool0000/ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0:_ooool00ooo003o
ooooooooo`04ooooo`03o`000?oooooooooo00gooooo000Dooooo`Go00000oooool00ol0003ooooo
ooooo`06ooooo`03ool00?oooooooooo05Wooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`1Hooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0:oooool01Ooo003ooooo
ooooooooooooo`0002gooooo00Goo`00ooooooooooooooooool0000/ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo
00gooooo000Looooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0FOooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo05Sooooo00?oo`00ooooooooool01_ooool00ol0003o
ooooooooo`0Nooooo`Go00001?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_o
oooo00Goo`00ooooooooooooooooool0000]ooooo`05ool00?oooooooooooooooooo0000;?ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool01?ooool0
0ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo
05Wooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`1Hooooo`03ool00?oooooooooo
00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
02_ooooo00Goo`00ooooooooooooooooool0000]ooooo`05ool00?oooooooooooooooooo0000;?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool01?oo
ool00ol0003oooooooooo`0=ooooo`007?ooool2o`0000Oooooo00?oo`00ooooooooool0FOooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo05Sooooo00?oo`00ooooooooool01_ooool0
0ol0003oooooooooo`0Wooooo`;o00001Oooool00ooo003oooooooooo`0[ooooo`05ool00?oooooo
oooooooooooo0000;Oooool01Ooo003oooooooooooooooooo`0002cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0Zooooo`03ool00?oooooooooo00?ooooo0_l0000?ooooo`007?oo
ool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo05Wooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`1Hooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00Goo`00oooooooooooooooo
ool0000]ooooo`05ool00?oooooooooooooooooo0000;?ooool01Ooo003oooooooooooooooooo`00
02gooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003o
ooooooooo`06ooooo`03ool00?oooooooooo05Wooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`1Hooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00Goo`00ooooooooooooooooool0000]oooo
o`05ool00?oooooooooooooooooo0000;?ooool01Ooo003oooooooooooooooooo`0002gooooo00?o
o`00ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`06
ooooo`03ool00?oooooooooo05Wooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`1H
ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04
ooooo`03ool00?oooooooooo02_ooooo00Goo`00ooooooooooooooooool0000]ooooo`05ool00?oo
oooooooooooooooo0000;?ooool01Ooo003oooooooooooooooooo`0002gooooo00?oo`00oooooooo
ool01?ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`06ooooo`03ool0
0?oooooooooo05Wooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`1Iooooo`03ool0
0?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool0
0?oooooooooo02_ooooo00Goo`00ooooooooooooooooool0000]ooooo`05ool00?oooooooooooooo
oooo0000;?ooool01Ooo003oooooooooooooooooo`0002gooooo00?oo`00ooooooooool01?ooool0
0ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo
05Wooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`1Iooooo`03ool00?oooooooooo
00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo
02_ooooo00Goo`00ooooooooooooooooool0000]ooooo`05ool00?oooooooooooooooooo0000;?oo
ool01Ooo003oooooooooooooooooo`0002gooooo00?oo`00ooooooooool01?ooool00ol0003ooooo
ooooo`0=ooooo`007?ooool2o`0000Oooooo00?oo`00ooooooooool0FOooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo05Wooooo00?oo`00ooooooooool01Oooool00ol0003ooooooooo
o`0Wooooo`;o00001Oooool00ooo003oooooooooo`0[ooooo`05ool00?oooooooooooooooooo0000
;Oooool01Ooo003oooooooooooooooooo`0002cooooo00Goo`00ooooooooooooooooool0000]oooo
o`03ool00?oooooooooo00?ooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`06ooooo`03
ool00?oooooooooo05Wooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`1Iooooo`03
ool00?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03
ool00?oooooooooo02_ooooo00Goo`00ooooooooooooooooool0000]ooooo`05ool00?oooooooooo
oooooooo0000;?ooool01Ooo003oooooooooooooooooo`0002gooooo00?oo`00ooooooooool01?oo
ool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`06ooooo`03ool00?oooooo
oooo05[ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1Iooooo`03ool00?oooooo
oooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooo
oooo02_ooooo00Goo`00ooooooooooooooooool0000]ooooo`05ool00?oooooooooooooooooo0000
;?ooool01Ooo003oooooooooooooooooo`0002gooooo00?oo`00ooooooooool01?ooool00ol0003o
ooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo05[ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo
00Goo`00ooooooooooooooooool0000]ooooo`05ool00?oooooooooooooooooo0000;?ooool01Ooo
003oooooooooooooooooo`0002gooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0=
ooooo`007?ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo05[ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00Goo`00oooo
ooooooooooooool0000]ooooo`05ool00?oooooooooooooooooo0000;?ooool01Ooo003ooooooooo
ooooooooo`0002gooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`007?oo
ool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo05[ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00Goo`00oooooooooooooooo
ool0000]ooooo`05ool00?oooooooooooooooooo0000;?ooool01Ooo003oooooooooooooooooo`00
02gooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0000Oo
oooo00?oo`00ooooooooool0F_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo05Wo
oooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`;o00001Oooool00ooo003o
ooooooooo`0[ooooo`05ool00?oooooooooooooooooo0000;Oooool01Ooo003ooooooooooooooooo
o`0002cooooo00Goo`00ooooooooooooooooool0000]ooooo`03ool00?oooooooooo00?ooooo0_l0
000?ooooo`007?ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo05_ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00Goo`00
ooooooooooooooooool0000]ooooo`05ool00?oooooooooooooooooo0000;?ooool01Ooo003ooooo
ooooooooooooo`0002gooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`00
7?ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo05_ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00Goo`00oooooooooooo
ooooool0000]ooooo`05ool00?oooooooooooooooooo0000;?ooool01Ooo003ooooooooooooooooo
o`0002gooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0
003oooooooooo`05ooooo`03ool00?oooooooooo05_ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00Goo`00ooooooooooooooooool0000]
ooooo`05ool00?oooooooooooooooooo0000;?ooool01Ooo003oooooooooooooooooo`0002gooooo
00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003ooooooooo
o`05ooooo`03ool00?oooooooooo05_ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`04ooooo`03ool00?oooooooooo02_ooooo00Goo`00ooooooooooooooooool0000]ooooo`04ool0
0?ooooooooooool002gooooo00Goo`00ooooooooooooooooool0000^ooooo`03ool00?oooooooooo
00?ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`1Kooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0FOooool00ooo003o
ooooooooo`05ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01?ooool00ooo003o
ooooooooo`0[ooooo`05ool00?oooooooooooooooooo0000;Oooool01?oo003ooooooooooooo000]
ooooo`05ool00?oooooooooooooooooo0000;_ooool00ooo003oooooooooo`03ooooo`03o`000?oo
oooooooo00gooooo000Looooo`;o00001_ooool00ooo003oooooooooo`1Kooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool0FOooool00ooo003oooooooooo`05ooooo`03o`000?oooooo
oooo02Oooooo0_l00005ooooo`03ool00?oooooooooo02_ooooo00Goo`00ooooooooooooooooool0
000]ooooo`04ool00?ooooooooooool002gooooo00Goo`00ooooooooooooooooool0000^ooooo`03
ool00?oooooooooo00;ooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`05ooooo`03ool0
0?oooooooooo05_ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1Iooooo`03ool0
0?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool0
0?oooooooooo02_ooooo00Goo`00ooooooooooooooooool0000]ooooo`04ool00?ooooooooooool0
02gooooo00Goo`00ooooooooooooooooool0000^ooooo`03ool00?oooooooooo00?ooooo00?o0000
ooooooooool03Oooool001cooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1Koooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0FOooool00ooo003oooooooooo`05oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0[oooo
o`05ool00?oooooooooooooooooo0000;Oooool01?oo003ooooooooooooo000]ooooo`05ool00?oo
oooooooooooooooo0000;_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo
000?ooooo`?o00001?ooool2o`0000Cooooo00?o0000ooooooooool01Oooool00ooo003ooooooooo
o`1Kooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0FOooool00ooo003ooooooooo
o`05ooooo`03o`000?oooooooooo01Wooooo0ol00004ooooo`;o00001Oooool00ol0003ooooooooo
o`04ooooo`03ool00?oooooooooo02_ooooo00Goo`00ooooooooooooooooool0000]ooooo`04ool0
0?ooooooooooool002gooooo00Goo`00ooooooooooooooooool0000^ooooo`03ool00?oooooooooo
00?ooooo00?o0000ooooooooool03Oooool0013ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0Foooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo05Wooooo00?oo`00ooooooooool01Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00Goo`00ooooooooooooooooool0
000]ooooo`04ool00?ooooooooooool002gooooo00Goo`00ooooooooooooooooool0000^ooooo`03
ool00?oooooooooo00?ooooo00?o0000ooooooooool03Oooool0013ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?oo`00oooooooo
ool0Foooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo05Wooooo00?oo`00oooooooo
ool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00Goo`00oooo
ooooooooooooool0000]ooooo`04ool00?ooooooooooool002gooooo00Goo`00oooooooooooooooo
ool0000^ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool03Oooool0013ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`?o00001Oooool00ooo003ooooo
ooooo`1Kooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0FOooool00ooo003ooooo
ooooo`04ooooo`;o00007?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Co
oooo0_l00005ooooo`03ool00?oooooooooo02_ooooo00Goo`00ooooooooooooooooool0000]oooo
o`04ool00?ooooooooooool002kooooo00Coo`00ooooooooooooo`00;_ooool00ooo003ooooooooo
o`02ooooo`;o00003oooool0013ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0Foooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo05_ooooo00?oo`00ooooooooool01?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo02_ooooo00Coo`00ooooooooooooo`00;_ooool01?oo003o
oooooooooooo000^ooooo`04ool00?ooooooooooool002kooooo00?oo`00ooooooooool00oooool0
0ol0003oooooooooo`0=ooooo`003oooool2o`0000Cooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo05_ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`1Kooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool06Oooool2
o`0000Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03ool00?oo
oooooooo02_ooooo00Coo`00ooooooooooooo`00;_ooool01?oo003ooooooooooooo000^ooooo`04
ool00?ooooooooooool002kooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0=oooo
o`004?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo05_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Kooooo`03
ool00?oooooooooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`03ooooo`;o
00001Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00Coo`00oooooooo
ooooo`00;_ooool01?oo003ooooooooooooo000^ooooo`04ool00?ooooooooooool002kooooo00?o
o`00ooooooooool00oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`04
ooooo`03ool00?oooooooooo05cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1K
ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04
ooooo`03ool00?oooooooooo02_ooooo00Coo`00ooooooooooooo`00;_ooool01?oo003ooooooooo
oooo000^ooooo`04ool00?ooooooooooool002kooooo00?oo`00ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05cooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Kooooo`03ool00?oooooooooo00Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo
00Coo`00ooooooooooooo`00;_ooool01?oo003ooooooooooooo000^ooooo`04ool00?oooooooooo
ool002kooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0=ooooo`007?ooool2o`00
00Gooooo00?oo`00ooooooooool0G?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
05_ooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`;o00001Oooool00ooo
003oooooooooo`0[ooooo`04ool00?ooooooooooool002kooooo00Coo`00ooooooooooooo`00;_oo
ool01?oo003ooooooooooooo000^ooooo`03ool00?oooooooooo00;ooooo0_l0000?ooooo`007?oo
ool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`1Kooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00Coo`00ooooooooooooo`00
;_ooool01?oo003ooooooooooooo000^ooooo`04ool00?ooooooooooool002kooooo00?oo`00oooo
ooooool00oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`04ooooo`03
ool00?oooooooooo05gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1Kooooo`03
ool00?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03
ool00?oooooooooo02_ooooo00Coo`00ooooooooooooo`00;_ooool01?oo003ooooooooooooo000^
ooooo`04ool00?ooooooooooool002kooooo00?oo`00ooooooooool00oooool00ol0003ooooooooo
o`0=ooooo`007?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05gooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`1Kooooo`03ool00?oooooooooo00Cooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00Coo`00
ooooooooooooo`00;_ooool01?oo003ooooooooooooo000^ooooo`04ool00?ooooooooooool002ko
oooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`1Kooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo02cooooo00?oo`00oooooooo0000;_ooool01?oo003ooooo
oooooooo000^ooooo`03ool00?ooooooo`0002oooooo00?oo`00ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05gooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1Kooooo`03ool00?oooooooooo00Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo02cooooo
00?oo`00oooooooo0000;_ooool01?oo003ooooooooooooo000^ooooo`03ool00?ooooooo`0002oo
oooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0000Gooooo
00?oo`00ooooooooool0GOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo05_ooooo
00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`;o00001Oooool00ooo003ooooo
ooooo`0/ooooo`03ool00?ooooooo`0002kooooo00Coo`00ooooooooooooo`00;_ooool00ooo003o
ooooool0000_ooooo`03ool00?oooooooooo00;ooooo0_l0000?ooooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`1Kooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo02cooooo00?oo`00oooooooo0000;_ooool01?oo003ooooo
oooooooo000^ooooo`03ool00?ooooooo`0002oooooo00?oo`00ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05gooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1Kooooo`03ool00?oooooooooo00Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo02gooooo
00?oo`00oooooooo0000;_ooool01?oo003ooooooooooooo000^ooooo`03ool00?ooooooo`0002oo
oooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo05gooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`1Kooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`03ool00?oooooooooo02gooooo00?oo`00oooooooo0000;_ooool01?oo003ooooo
oooooooo000^ooooo`03ool00?ooooooo`0002oooooo00?oo`00ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05gooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1Kooooo`03ool00?oooooooooo00Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo02gooooo
00?oo`00oooooooo0000;_ooool01?oo003ooooooooooooo000^ooooo`03ool00?ooooooo`0002oo
oooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0000Gooooo
00?oo`00ooooooooool0GOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo05_ooooo
00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`;o00001?ooool00ooo003ooooo
ooooo`0]ooooo`03ool00?ooooooo`0002kooooo00Coo`00ooooooooooooo`00;_ooool00ooo003o
ooooool0000_ooooo`03ool00?oooooooooo00;ooooo0_l0000?ooooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo05gooooo00Goo`00ooooooooooooooooool0001Nooooo`03
ool00?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo02gooooo00?oo`00oooooooo0000;_ooool01?oo003ooooooooooooo000^oooo
o`03ool00?ooooooo`0002oooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0=oooo
o`007?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05kooooo00Goo`00oooooooo
ooooooooool0001Nooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`03ooooo`03ool00?oooooooooo02gooooo00?oo`00oooooooo0000;_ooool01?oo
003ooooooooooooo000^ooooo`03ool00?ooooooo`0002oooooo00?oo`00ooooooooool00oooool0
0ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo
05kooooo00Goo`00ooooooooooooooooool0001Nooooo`03ool00?oooooooooo00Cooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo02gooooo00?oo`00
oooooooo0000;_ooool01?oo003ooooooooooooo000^ooooo`03ool00?ooooooo`0002oooooo00?o
o`00ooooooooool00oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo05kooooo00Goo`00ooooooooooooooooool0001Nooooo`03ool00?oo
oooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03ool00?oo
oooooooo02gooooo00?oo`00oooooooo0000;oooool00ooo003oooooool0000^ooooo`03ool00?oo
ooooo`0002oooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0=ooooo`007?ooool0
0ol0003oooooooooo`03ooooo`03ool00?oooooooooo05kooooo00Goo`00ooooooooooooooooool0
001Nooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo02gooooo00?oo`00oooooooo0000;oooool00ooo003oooooool0
000^ooooo`03ool00?ooooooo`0002oooooo00?oo`00ooooooooool00oooool00ol0003ooooooooo
o`0=ooooo`007?ooool2o`0000Cooooo00?oo`00ooooooooool0G_ooool01Ooo003ooooooooooooo
ooooo`0005kooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`;o00001?oo
ool00ooo003oooooooooo`0]ooooo`03ool00?ooooooo`0002oooooo00?oo`00oooooooo0000;_oo
ool00ooo003oooooool0000_ooooo`03ool00?oooooooooo00;ooooo0_l0000?ooooo`007?ooool0
0ol0003oooooooooo`03ooooo`03ool00?oooooooooo05kooooo00Goo`00ooooooooooooooooool0
001Oooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo02gooooo00?oo`00oooooooo0000;oooool00ooo003oooooool0
000^ooooo`03ool00?ooooooo`0002oooooo00?oo`00ooooooooool00oooool00ol0003ooooooooo
o`0=ooooo`007?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05kooooo00Goo`00
ooooooooooooooooool0001Oooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo02gooooo00?oo`00oooooooo0000;ooo
ool00ooo003oooooool0000^ooooo`03ool00?ooooooo`0002oooooo00?oo`00ooooooooool00ooo
ool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooo
oooo05kooooo00Goo`00ooooooooooooooooool0001Oooooo`03ool00?oooooooooo00?ooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo02gooooo00?o
o`00oooooooo0000;oooool00ooo003oooooool0000^ooooo`03ool00?ooooooo`0002oooooo00?o
o`00ooooooooool00oooool00ol0003oooooooooo`0=ooooo`003oooool3o`0000?ooooo0ol00004
ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0G_ooool01?oo003ooooooooooooo
001Pooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool06Oooool3o`0000?ooooo0ol0
0005ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0;Oooool00ooo003oooooool0
000_ooooo`;oo`00;oooool00ooo003oooooool0000_ooooo`03ool00?oooooooooo00?ooooo00?o
0000ooooooooool03Oooool0013ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001Oooool00ooo003oooooooooo`1Nooooo`04ool00?ooooooooooool0063o
oooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?oo`00oooo
ooooool0;Oooool00ooo003oooooool0000_ooooo`;oo`00;oooool00ooo003oooooool0000_oooo
o`03ool00?oooooooooo00?ooooo00?o0000ooooooooool03Oooool0013ooooo00?o0000oooooooo
ool01Oooool01?l0003oooooooooooooool3o`0000?ooooo00?oo`00ooooooooool0G_ooool01?oo
003ooooooooooooo001Pooooo`03ool00?oooooooooo00;ooooo0_l0000Looooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?oo`00ooooooooool0;Oooool0
0ooo003oooooool0000_ooooo`;oo`00;oooool00ooo003oooooool0000_ooooo`03ool00?oooooo
oooo00;ooooo0_l0000?ooooo`004?ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000001Oooool00ooo003oooooooooo`1Nooooo`04ool00?ooooooooooool0063ooooo00?o
o`00ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo02gooooo00?o
o`00oooooooo0000;oooool2ool002oooooo00?oo`00oooooooo0000;oooool00ooo003ooooooooo
o`03ooooo`03o`000?oooooooooo00gooooo000@ooooo`04o`000?ooooooooooooooo`Co00001?oo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05kooooo00Coo`00ooooooooooooo`00
H?ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo
oooo1?l00005ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0;Oooool00ooo003o
ooooool0000_ooooo`;oo`00<?ooool2ool002oooooo00?oo`00ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`003oooool2o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03ool00?oooooooooo05kooooo00Coo`00ooooooooooooo`00H?ooool00ooo003o
ooooooooo`03ooooo`03o`000?oooooooooo01Wooooo0_l00003ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0]ooooo`03ool00?ooooooo`0002oo
oooo0_oo000`ooooo`;oo`00;oooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00go
oooo000@ooooo`04o`000?ooooooooooooooo`Go00000oooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo05oooooo00?oo`00oooooooo0000H?ooool00ooo003oooooooooo`03ooooo`03
o`000?oooooooooo01[ooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo
00?ooooo00?oo`00ooooooooool0;Oooool2ool0033ooooo0_oo000`ooooo`;oo`00;oooool00ooo
003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00;o
oooo00?oo`00ooooooooool0H?ooool00ooo003oooooool0001Pooooo`03ool00?oooooooooo00?o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo02go
oooo0_oo000`ooooo`;oo`00<?ooool2ool002oooooo00?oo`00ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`007?ooool2o`0000?ooooo00?oo`00ooooooooool0H?ooool00ooo003ooooo
ool0001Pooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool09oooool2o`0000Cooooo
00?oo`00ooooooooool0;Oooool2ool0033ooooo0_oo000`ooooo`;oo`00<?ooool01?oo003ooooo
ooooooooool2o`0000oooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0
H?ooool00ooo003oooooool0001Pooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo02gooooo0_oo000`ooooo`;oo`00
<?ooool2ool0033ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`007?oo
ool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo063ooooo00?oo`00oooooooo0000H?oo
ool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00ooo
ool00ooo003oooooooooo`0]ooooo`;oo`00<?ooool2ool0033ooooo0_oo000`ooooo`03ool00?oo
oooooooo00;ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool00_ooool0
0ooo003oooooooooo`1Pooooo`03ool00?ooooooo`00067ooooo00?oo`00ooooooooool00_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0;Oooool2
ool0033ooooo0_oo000`ooooo`;oo`00<?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooo
oooo00gooooo000Looooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0H?ooool00ooo
003oooooool0001Qooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`02ooooo`03ool00?oooooooooo02kooooo0_oo000`ooooo`;oo`00<?ooool2ool0
033ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003o
ooooooooo`02ooooo`03ool00?oooooooooo063ooooo0_oo001Rooooo`03ool00?oooooooooo00;o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo02ko
oooo0_oo000`ooooo`;oo`00<?ooool2ool0033ooooo00?oo`00ooooooooool00_ooool00ol0003o
ooooooooo`0=ooooo`007?ooool2o`0000?ooooo00?oo`00ooooooooool0HOooool00ooo003ooooo
ooooo`1Pooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool09oooool2o`0000?ooooo
00?oo`00ooooooooool0;oooool00ooo003oooooooooo`0^ooooo`;oo`00<?ooool2ool0033ooooo
00Coo`00oooooooooooooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`3>ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0c_ooool00ol0003oooooooooo`0=ooooo`007?oo
ool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0000Yooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00000?ooooo`007?oooooB
o`0002Woooood_l0000?ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooolSooooo`?o00006oooool5o`0001cooooo0ol0000Kooooo`;o00007?ooool3
o`0001cooooo1Ol0000Looooo`?o00006?ooool002;ooooo1Ol00003ooooo`;o0000:?ooool3o`00
00Cooooo0_l0000Yooooo`;o0000:oooool3o`0000Cooooo0_l0000Xooooo`Go00000oooool2o`00
03?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04o`000?ooooooooooo`0001gooooo00?o
0000ooooooooool06Oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo01cooooo
00Co0000oooooooooooo00006oooool01Ol0003ooooooooooooooooo000001Oooooo000Sooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0002Oooooo00Co0000oooooooooooo0000:oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0002Sooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000/ooooo`Go00001Oooool00ol0003oooooooooo`0Booooo`Go00000oooool0
0ol0003oooooooooo`0Eooooo`Go00000oooool00ol0003oooooooooo`0Iooooo`04o`000?oooooo
ooooo`0001cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo01Gooooo000Looooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`00023ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
9oooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000:Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003Cooooo0_l0000N
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool0
000Looooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07?ooool2o`0001Sooooo000U
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00009oooool01?l0003oooooooooool0000[ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:_ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooo
ooooooooool000007Oooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0001cooooo
00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000001oooooo00?o0000oooooooo
ool05Oooool002;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
02Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`04o`000?oooooo
ooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool0000booooo`05o`000?oooooooooo
ooooool000006_ooool01Ol0003ooooooooooooooooo000001cooooo0_l0000Kooooo`04o`000?oo
ooooooooo`0001_ooooo0_l0000Mooooo`05o`000?ooooooooooooooool000006oooool01Ol0003o
oooooooooooooooo000001Oooooo000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Wooooo`;o00001?ooool01?l0003oooooooooool0000Wooooo`04o`000?oo
ooooooooo`0002[ooooo0_l00004ooooo`04o`000?ooooooooooo`0002Oooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0003?ooooo0ol0000Looooo`?o00007_ooool0
0ol0003oooooooooo`0Jooooo`;o00007Oooool00ol0003oooooooooo`0Looooo`?o00007Oooool3
o`0001Sooooo000Sooooo`?o00001?ooool2o`0002Wooooo00?o0000ooooooooool00oooool2o`00
02Wooooo0_l0000/ooooo`03o`000?oooooooooo00?ooooo0_l0000Yooooo`?o00001?ooool2o`00
0?oooooo2oooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0023ooooocol0000X
ooooom;o00003oooool001[ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000:?ooool2
o`000003ooooool0003ooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?l0
000?ooooo`006Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`?o003o
0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o
0_ooool3o`00o`;ooooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003o0_ooool3o`00oeKo
oooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`?o003o0_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0<kooooo00?o0000oooo
ooooool03Oooool001Wooooo00Co0000oooooooooooo00000oooool4o`0000?o003o0_l00003o`00
o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00
o`;o00000ol00?l01?l0003o003oo`00ool00?l2o`0000?o003o0_l00003o`00o`?o000000?o003o
o`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000?o003o
o`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000?o003o
o`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00Co000000?o003oo`000?l000000_l0
00000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000?o003oo`000?l000000_l0
00000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000?o003oo`000?l000000_l0
00001?l00?oo0000o`000?l00003o`00o`04o`000?l00?oo003oo`00o`;o00000ol00?l2o`0000?o
003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o
003o0_l00003o`00o`;o00000ol00?l3o`0002Sooooo00?o0000ooooooooool0E?ooool2ool0023o
oooo0_oo001Fooooo`03o`000?oooooooooo00gooooo000Iooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`04ooooool00?oo003o
o`00o`;ooooo0ol00?l2ooooo`?o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooooooo`?o003o
00Coooooo`00ool00?oo003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;o
oooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Dooooo`03ool00?ooooooo`0001ko
oooo00?oo`00oooooooo0000E_ooool00ol0003oooooooooo`0=ooooo`006Oooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo03gooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0loooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Doooool01?oo003ooooooooooooo000N
ooooo`04ool00?ooooooooooool005Gooooo00?o0000ooooooooool03Oooool001Wooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05?ooooo00Coo`00oooooooooooo
o`007_ooool01?oo003ooooooooooooo001Eooooo`03o`000?oooooooooo00gooooo000Jooooo`;o
00001?ooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0
003oooooooooo`0Vooooo`;o0000Doooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
01[ooooo00Goo`00ooooooooooooooooool0001Dooooo`;o00003oooool0023ooooo00?o0000oooo
ooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1Booooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool06_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo05;ooooo00?o0000ooooooooool03Oooool0
023ooooo0_l0000nooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo05;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0I
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0D_ooool00ol0003oooooooooo`0=
ooooo`008?ooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`0Iooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0D_ooool0
0ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05;ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool0D_ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`0moooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo057ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool0DOooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0
003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0V
ooooo`;o0000D_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Sooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`1@ooooo`;o00003oooool0023ooooo00?o0000oooo
ooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1Aooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool06?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo057ooooo00?o0000ooooooooool03Oooool0
023ooooo0_l0000nooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo03cooooo0_oo000Cooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool06?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo017ooooo0_oo000n
ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo03gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>oooool2
ool00003oooooooo003ooooo013ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0G
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03oooool2ool00003oooooooo003o
o`0003gooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0k
ooooo`05ool00?oooooooooooooooooo00004?ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo01Kooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`04ool00?oo
ooooooooooooo`;oo`00??ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003ooooooooo
o`0mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Cooooo0ooo000Cooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
3Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
4Oooool3ool002Kooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0?Ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool2o`0000kooooo
0ooo000Cooooo`;oo`000_ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool03Oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Kooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool04?ooool2ool00003oooooooo003oo`0001?ooooo0ooo000>ooooo`;o0000
3oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00;oo`00
4Oooool2ool000Cooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Fooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0@ooooo`;oo`00
0_ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo000Pooooo`;o0000?_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03_ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`0;ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool05_ooool00ooo003ooooo
ooooo`07ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`0>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool03Oooool0023ooooo00?o
0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
3Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0
5_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
3_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool0
3Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo
00?o0000ooooooooool07oooool2o`0000Gooooo00?o0000ooooooooool02_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0;ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02_ooool00ooo003ooooo
ooooo`08ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool01oooool00ooo003ooooo
ooooo`0;ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03?ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo03gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool02_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00_ooooo00?oo`00oooooooo
ool01oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool05Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00_ooooo00?oo`00oooooooo
ool01oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool02oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Wooooo00?o0000oooooooo
ool03Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03co
oooo00?o0000ooooooooool07_ooool01?l0003oooooooooool00004ooooo`;o00002Oooool00ooo
003oooooooooo`08ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02?ooool00ooo
003oooooooooo`09ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`09ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool02?ooool00ooo
003oooooooooo`09ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02_ooool00ooo
003oooooooooo`08ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01oooool00ooo
003oooooooooo`08ooooo`;o00003oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo03cooooo00?o0000ooooooooool07_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`08
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0D
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0:
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0=
ooooo`008?ooool2o`0003kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooo
oooo01kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`07ooooo`03ool00?oo
oooooooo00[ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0:ooooo`03ool00?oo
oooooooo00Sooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`08ooooo`03ool00?oo
oooooooo00Wooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`09ooooo`03ool00?oo
oooooooo00Sooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`08ooooo`03ool00?oo
oooooooo00[ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0:ooooo`03ool00?oo
oooooooo00Oooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0?Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool07_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool03?ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool01oooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02_ooool00ooo003ooooo
ooooo`0Dooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01oooool00ooo003ooooo
ooooo`0<ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03?ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool01_ooool00ol0003ooooo
ooooo`0=ooooo`008?ooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
??ooool00ol0003oooooooooo`0Oooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03ool0
0?oooooooooo00kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0=ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00[ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo00Oooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0>ooooo`03ool0
0?oooooooooo00Gooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0?Ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`0?ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03?ooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool05?ooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool03Oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`0?ooooo`;oo`001_ooool00ol0003oooooooooo`0=ooooo`003_ooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0?Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo03cooooo00?o0000ooooooooool09_ooool2o`0000?ooooo0_oo000Dooooo`Coo`00
4_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool0
2_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`0?ooooo`Goo`005?ooool2ool000?ooooo0_l0000?ooooo`003Ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01Wooooo0_oo000Dooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool03_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00cooooo00?oo`00oooo
ooooool04oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool03oooool01Ooo003oooooooooooooooooo`0001Cooooo0_oo000Kooooo`03o`000?oooooo
oooo00gooooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooooooo0ol0
000mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0>oooool2o`0002Sooooo00?o0000ooooooooool0
<?ooool4ool0017ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0<ooooo`03ool0
0?oooooooooo01?ooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo013ooooo1?oo000aooooo`03o`000?oooooooooo00gooooo000=ooooo`04o`000?oo
ooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000oooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04Gooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01?ooooo00?oo`00oooo
ooooool02oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04Kooooo00?o0000oooo
ooooool03Oooool000gooooo00Co0000oooooooooooo00001oooool4o`0000Cooooo00?o0000oooo
ooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`16ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03Oooool0
0ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`16ooooo`03o`000?oooooooooo00gooooo000=ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04Kooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01?ooooo00?o
o`00ooooooooool03?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04Kooooo00?o
0000ooooooooool03Oooool000kooooo0_l00008ooooo`Go00000oooool00ol0003oooooooooo`0m
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Vooooo`;o0000B?oo
ool01Ooo003oooooooooooooooooo`0000oooooo00?oo`00ooooooooool04_ooool00ooo003ooooo
ooooo`0=ooooo`;oo`000_ooool00ooo003oooooooooo`16ooooo`;o00003oooool0023ooooo00?o
0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`17ooooo`Coo`004?ooool00ooo003oooooooooo`0Booooo`03ool0
0?oooooooooo00kooooo1?oo0019ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oo
oooooooo03gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0B?ooool2ool0017ooooo00?oo`00ooooooooool04_ooool00ooo003ooooo
ooooo`0?ooooo`;oo`00B_ooool00ol0003oooooooooo`0=ooooo`008?ooool2o`0003kooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
G?ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool0
3Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo017ooooo
00?oo`00ooooooooool0Foooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003ooooooooo
o`0mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo05cooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1Kooooo`03o`00
0?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo03gooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0looooo`03o`000?oooooooooo02Kooooo0_l0001Mooooo`03ool00?oooooooooo017ooooo
00?oo`00ooooooooool0F_ooool2o`0000oooooo000Pooooo`03o`000?oooooooooo03gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
G?ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool0
3Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo017ooooo
00?oo`00ooooooooool0Foooool00ol0003oooooooooo`0=ooooo`008?ooool2o`0003kooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
G?ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool0
3Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo013ooooo
00?oo`00ooooooooool0G?ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003ooooooooo
o`0mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo05cooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`1Looooo`03o`00
0?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo03gooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0looooo`03o`000?oooooooooo02Kooooo0_l0001Mooooo`03ool00?oooooooooo013ooooo
00?oo`00ooooooooool0Foooool2o`0000oooooo000Pooooo`03o`000?oooooooooo03gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
G?ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo05cooooo00?o0000ooooooooool0
3Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Mooooo`03ool00?oooooooooo00oooooo
00?oo`00ooooooooool0G?ooool00ol0003oooooooooo`0=ooooo`008?ooool2o`0003kooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo01kooooo0ol00005ooooo`03o`00
0?oooooooooo05gooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`1Looooo`03o`00
0?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo03gooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0looooo`03o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo05gooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`1Looooo`03
o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo03gooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Mooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0G?ooool00ol0003o
ooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo0_l0001Nooooo`03
ool00?oooooooooo00kooooo00?oo`00ooooooooool0G?ooool2o`0000oooooo000Pooooo`03o`00
0?oooooooooo03gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo01go
oooo1?l00005ooooo`03o`000?oooooooooo05gooooo00?oo`00ooooooooool03_ooool00ooo003o
ooooooooo`1Mooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo03gooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1Mooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo
ool0GOooool00ol0003oooooooooo`0=ooooo`008?ooool2o`0003kooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0looooo`03o`000?oooooooooo01gooooo1Ol00004ooooo`03o`000?oooooooooo05go
oooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00go
oooo000Pooooo`03o`000?oooooooooo03gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0looooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`0>ooooo`03
ool00?oooooooooo05gooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0
?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`1Mooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0GOooool00ol0003o
ooooooooo`0=ooooo`006Oooool3o`0000Cooooo00?o0000ooooooooool0?Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool2o`0005kooooo00?oo`00oooooooo
ool03_ooool00ooo003oooooooooo`1Looooo`;o00003oooool001[ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo05gooooo00?oo`00ooooooooool03_ooool00ooo003o
ooooooooo`1Mooooo`03o`000?oooooooooo00gooooo000Jooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0??ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o
003o0_ooool3o`00ocgooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Nooooo`03
ool00?oooooooooo00cooooo00?oo`00ooooooooool0G_ooool00ol0003oooooooooo`0=ooooo`00
6_ooool00ol0003oooooooooo`03ooooo`?o0000??ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o
0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l01?oooooo003o
o`00ool00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;o
oooo0ol00?l2ooooo`?o003o0_ooool3o`00occooooo0_l0000Xooooo`03o`000?oooooooooo05ko
oooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooooooo00go
oooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0??ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00ocgooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1Nooooo`03ool00?oooooooooo00cooooo00?oo`00oooooooo
ool0G_ooool00ol0003oooooooooo`0=ooooo`006Oooool2o`0000Gooooo00?o0000ooooooooool0
boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05kooooo00?oo`00ooooooooool0
3?ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooooooo00gooooo000Jooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`;o0000Gooo
ool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo05gooooo0_l0000?ooooo`008?ooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0G_ooool0
0ooo003oooooooooo`0<ooooo`03ool00?oooooooooo05kooooo00?o0000ooooooooool03Oooool0
023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
05kooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooooooo
00gooooo000Pooooo`;o0000c?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05ko
oooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooooooo00go
oooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`1Nooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0G_ooool00ol0003ooooo
ooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0G_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo05kooooo00?o
0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0V
ooooo`;o0000Goooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo05kooooo0_l0000?
ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0G_ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo05oooooo00?o0000oooo
ooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo05kooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`1Oooooo`03
o`000?oooooooooo00gooooo000Pooooo`;o0000c?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo05oooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`1Oooooo`03o`00
0?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`1Oooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0Gooo
ool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0Goooool00ooo003oooooooooo`0:ooooo`03ool00?oooooo
oooo05oooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0
003oooooooooo`0Vooooo`;o0000H?ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo
05kooooo0_l0000?ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0Goooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo05oo
oooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo05oooooo00?oo`00ooooooooool02_ooool00ooo003ooooo
ooooo`1Oooooo`03o`000?oooooooooo00gooooo000Pooooo`;o0000c?ooool00ol0003ooooooooo
o`0Hooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0Goooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo05oooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1Oooooo`03ool00?oooooooooo00[ooooo00?o
o`00ooooooooool0Goooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo05oooooo00?oo`00ooooooooool02_ooool00ooo003ooooooooo
o`1Oooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo0_l0
001Pooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0G_ooool2o`0000oooooo000P
ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Goooool00ooo003ooooooooo
o`09ooooo`03ool00?oooooooooo063ooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`0Hooooo`;o00001?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo05oooooo00?oo`00ooooooooool02Oooool00ooo003ooooooooo
o`1Pooooo`03o`000?oooooooooo00gooooo000Pooooo`;o0000c?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo05oooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`1Pooooo`03o`000?oooooooooo00gooooo000Poooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Poooo
o`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0H?ooool00ol0003oooooooooo`0=oooo
o`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo0_l0001Qooooo`03
ool00?oooooooooo00Sooooo00?oo`00ooooooooool0Goooool2o`0000oooooo000Pooooo`03o`00
0?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Pooooo`03ool0
0?oooooooooo00Sooooo00?oo`00ooooooooool0H?ooool00ol0003oooooooooo`0=ooooo`003Ooo
ool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0booo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo063ooooo00?oo`00ooooooooool02?oo
ool00ooo003oooooooooo`1Pooooo`03o`000?oooooooooo00gooooo000>ooooo`03o`000?oooooo
oooo00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0<_ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo00Sooooo00?o
o`00ooooooooool0H?ooool00ol0003oooooooooo`0=ooooo`003_ooool00ol0003oooooooooo`0;
ooooo`04o`000?ooooooooooooooo`?o0000b_ooool2o`0002Sooooo00?o0000ooooooooool0H?oo
ool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo063ooooo00?o0000ooooooooool03Ooo
ool000kooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo00000<gooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo00Sooooo00?o
o`00ooooooooool0H?ooool00ol0003oooooooooo`0=ooooo`003_ooool00ol0003oooooooooo`07
ooooo`Co00001?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo0_l0001Q
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool0Goooool2o`0000oooooo000=oooo
o`;o00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo00Oooooo00?oo`00oooo
ooooool0HOooool00ol0003oooooooooo`0=ooooo`003_ooool00ol0003oooooooooo`07ooooo`Go
00000oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0H?ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo067ooooo00?o0000oooooooo
ool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo063ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`1Qooooo`03o`00
0?oooooooooo00gooooo000Pooooo`;o0000c?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo067ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1Qooooo`03o`000?oo
oooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1Qooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0HOooool0
0ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo
02Kooooo0_l0001Rooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0H?ooool2o`00
00oooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`1Qooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0HOooool00ol0003o
ooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0HOooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo067ooooo
00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo067ooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`1Qooooo`03o`000?oooooooooo00gooooo000Pooooo`;o0000c?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo067ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1Q
ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1Qooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool0H_ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo02Kooooo0_l0001Rooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool0HOooool2o`0000oooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`1Qooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
H_ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo06;ooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`1Rooooo`03o`000?oooooooooo00gooooo000Pooooo`;o0000c?ooool00ol0
003oooooooooo`0Hooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool0H_ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo06;ooooo00?o0000ooooooooool03Oooool0023o
oooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Iooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06;ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`1Rooooo`03o`000?oooooooooo00gooooo000Pooooo`03
o`000?oooooooooo0<_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo0_l0001Sooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool0HOooool2o`0000oooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
H_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo06?ooooo00?o0000ooooooooool0
3Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Iooooo`04o`000?oo
ooooooooooooo`Co00001Oooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool0Hoooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo01Sooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0Hoooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo06?ooooo00?o
0000ooooooooool03Oooool0023ooooo0_l0003<ooooo`03o`000?oooooooooo01Wooooo00Co0000
oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo06?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`1Sooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooo
oooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Sooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool0Hoooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0
003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo0_l0001Tooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0H_ooool2o`0000oooooo000Pooooo`03o`000?oooooooooo0<_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Tooooo`05ool00?oooooooooooooo
oooo0000IOooool00ol0003oooooooooo`0=ooooo`006?ooool5o`0000?ooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06Cooooo00Coo`00oooooooo
ooooo`00I_ooool00ol0003oooooooooo`0=ooooo`006Oooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Toooo
o`04ool00?ooooooooooool006Kooooo00?o0000ooooooooool03Oooool001[ooooo00?o0000oooo
ooooool00oooool3o`000<[ooooo0_l0000Xooooo`03o`000?oooooooooo06Cooooo00Coo`00oooo
ooooooooo`00I_ooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Toooo
o`?oo`00Ioooool00ol0003oooooooooo`0=ooooo`006?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`05o`000?oooooooooo
ooooool00000:?ooool2o`0006Kooooo0_oo001Vooooo`;o00003oooool001Sooooo00Go0000oooo
ooooooooooooo`000003oooooloo0000:?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooo
oooo00gooooo000Iooooo`?o0000noooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00003oooool00?oooooo6?oooooBo`0000oooooo003ooooo
ooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003ooooo
ooWooooo003oooooooWooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-8.42587, \
-7.46649, 0.0631478, 0.168603}, {{262.875, 490.688}, {303, 162.25}} -> \
{-48.5007, -7.46669, 0.126296, 0.168604}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-27.7031, -2.91994, 0.203806, 0.0164882}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-12.1252, -33.5784, 0.031574, 0.1686}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Summary of results", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{{g10, g20}, {g1a, g2a}, {g1b, g2b}, {g1c, g2c}, {g1d, 
              g2d}}], ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.58923 
%%ImageSize: 504 800.972 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0378388 0.47619 [
[ 0 0 0 0 ]
[ 1 1.58923 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.58923 L
0 1.58923 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0378388 0.477324 0.318126 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.0147151 0.294302 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.04762 .01472 m
.04762 .01472 L
s
.07143 .01472 m
.07143 .01472 L
s
.09524 .01472 m
.09524 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.14286 .01472 m
.14286 .01472 L
s
.16667 .01472 m
.16667 .01472 L
s
.19048 .01472 m
.19048 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.2381 .01472 m
.2381 .01472 L
s
.2619 .01472 m
.2619 .01472 L
s
.28571 .01472 m
.28571 .01472 L
s
.30952 .01472 m
.30952 .30902 L
s
.33333 .01472 m
.33333 .30902 L
s
.35714 .01472 m
.35714 .30902 L
s
.38095 .01472 m
.38095 .30902 L
s
.40476 .01472 m
.40476 .30902 L
s
.42857 .01472 m
.42857 .30902 L
s
.45238 .01472 m
.45238 .30902 L
s
.47619 .01472 m
.47619 .30902 L
s
.5 .01472 m
.5 .30902 L
s
.52381 .01472 m
.52381 .30902 L
s
.54762 .01472 m
.54762 .30902 L
s
.57143 .01472 m
.57143 .30902 L
s
.59524 .01472 m
.59524 .30902 L
s
.61905 .01472 m
.61905 .30902 L
s
.64286 .01472 m
.64286 .30902 L
s
.66667 .01472 m
.66667 .30902 L
s
.69048 .01472 m
.69048 .30902 L
s
.71429 .01472 m
.71429 .01472 L
s
.7381 .01472 m
.7381 .01472 L
s
.7619 .01472 m
.7619 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.80952 .01472 m
.80952 .01472 L
s
.83333 .01472 m
.83333 .01472 L
s
.85714 .01472 m
.85714 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.90476 .01472 m
.90476 .01472 L
s
.92857 .01472 m
.92857 .01472 L
s
.95238 .01472 m
.95238 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.04762 .01472 Mdot
.07143 .01472 Mdot
.09524 .01472 Mdot
.11905 .01472 Mdot
.14286 .01472 Mdot
.16667 .01472 Mdot
.19048 .01472 Mdot
.21429 .01472 Mdot
.2381 .01472 Mdot
.2619 .01472 Mdot
.28571 .01472 Mdot
.30952 .30902 Mdot
.33333 .30902 Mdot
.35714 .30902 Mdot
.38095 .30902 Mdot
.40476 .30902 Mdot
.42857 .30902 Mdot
.45238 .30902 Mdot
.47619 .30902 Mdot
.5 .30902 Mdot
.52381 .30902 Mdot
.54762 .30902 Mdot
.57143 .30902 Mdot
.59524 .30902 Mdot
.61905 .30902 Mdot
.64286 .30902 Mdot
.66667 .30902 Mdot
.69048 .30902 Mdot
.71429 .01472 Mdot
.7381 .01472 Mdot
.7619 .01472 Mdot
.78571 .01472 Mdot
.80952 .01472 Mdot
.83333 .01472 Mdot
.85714 .01472 Mdot
.88095 .01472 Mdot
.90476 .01472 Mdot
.92857 .01472 Mdot
.95238 .01472 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0378388 0.97619 0.318126 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.120774 0.0283859 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12077 -6 -4.5 ]
[-0.0125 .12077 0 4.5 ]
[-0.0125 .2627 -6 -4.5 ]
[-0.0125 .2627 0 4.5 ]
[-0.0125 .40463 -12 -4.5 ]
[-0.0125 .40463 0 4.5 ]
[-0.0125 .54656 -12 -4.5 ]
[-0.0125 .54656 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12077 m
.00625 .12077 L
s
[(0)] -0.0125 .12077 1 0 Mshowa
0 .2627 m
.00625 .2627 L
s
[(5)] -0.0125 .2627 1 0 Mshowa
0 .40463 m
.00625 .40463 L
s
[(10)] -0.0125 .40463 1 0 Mshowa
0 .54656 m
.00625 .54656 L
s
[(15)] -0.0125 .54656 1 0 Mshowa
.125 Mabswid
0 .14916 m
.00375 .14916 L
s
0 .17755 m
.00375 .17755 L
s
0 .20593 m
.00375 .20593 L
s
0 .23432 m
.00375 .23432 L
s
0 .29109 m
.00375 .29109 L
s
0 .31948 m
.00375 .31948 L
s
0 .34786 m
.00375 .34786 L
s
0 .37625 m
.00375 .37625 L
s
0 .43302 m
.00375 .43302 L
s
0 .46141 m
.00375 .46141 L
s
0 .48979 m
.00375 .48979 L
s
0 .51818 m
.00375 .51818 L
s
0 .09239 m
.00375 .09239 L
s
0 .064 m
.00375 .064 L
s
0 .03562 m
.00375 .03562 L
s
0 .00723 m
.00375 .00723 L
s
0 .57495 m
.00375 .57495 L
s
0 .60333 m
.00375 .60333 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .12077 m
1 .12077 L
s
.99375 .2627 m
1 .2627 L
s
.99375 .40463 m
1 .40463 L
s
.99375 .54656 m
1 .54656 L
s
.125 Mabswid
.99625 .14916 m
1 .14916 L
s
.99625 .17755 m
1 .17755 L
s
.99625 .20593 m
1 .20593 L
s
.99625 .23432 m
1 .23432 L
s
.99625 .29109 m
1 .29109 L
s
.99625 .31948 m
1 .31948 L
s
.99625 .34786 m
1 .34786 L
s
.99625 .37625 m
1 .37625 L
s
.99625 .43302 m
1 .43302 L
s
.99625 .46141 m
1 .46141 L
s
.99625 .48979 m
1 .48979 L
s
.99625 .51818 m
1 .51818 L
s
.99625 .09239 m
1 .09239 L
s
.99625 .064 m
1 .064 L
s
.99625 .03562 m
1 .03562 L
s
.99625 .00723 m
1 .00723 L
s
.99625 .57495 m
1 .57495 L
s
.99625 .60333 m
1 .60333 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .14916 m
.02499 .1491 L
.02605 .14894 L
.02729 .14862 L
.02846 .14821 L
.03053 .14717 L
.03279 .14565 L
.0379 .14077 L
.04262 .13481 L
.05285 .11912 L
.06244 .10472 L
.06713 .09906 L
.06955 .09671 L
.07218 .09463 L
.07367 .0937 L
.07505 .09301 L
.07637 .0925 L
.07711 .09228 L
.07778 .09212 L
.07904 .09194 L
.07976 .0919 L
.08041 .0919 L
.08162 .09201 L
.0829 .09227 L
.08359 .09247 L
.08425 .0927 L
.08548 .09323 L
.08824 .09491 L
.09063 .09686 L
.09323 .09948 L
.10458 .11542 L
.11478 .13204 L
.11977 .1393 L
.12435 .14477 L
.12665 .14695 L
.12916 .14886 L
.13038 .1496 L
.13168 .15023 L
.1324 .15052 L
.13306 .15074 L
.13434 .15105 L
.13503 .15115 L
.13576 .15121 L
.13706 .15119 L
.13779 .15111 L
.13846 .15099 L
.13921 .15081 L
.14001 .15055 L
.14144 .14995 L
.14281 .14919 L
Mistroke
.14536 .14733 L
.14796 .14486 L
.15041 .14205 L
.15497 .13573 L
.16521 .11839 L
.17398 .10343 L
.17863 .09681 L
.18119 .09378 L
.18361 .0914 L
.18488 .09035 L
.18626 .08939 L
.18741 .08872 L
.18867 .08814 L
.18986 .08774 L
.19113 .08747 L
.1923 .08737 L
.1934 .0874 L
.19466 .0876 L
.1953 .08777 L
.19599 .08799 L
.19723 .08852 L
.19837 .08915 L
.20096 .09106 L
.20372 .09382 L
.20871 .10047 L
.21342 .10834 L
.22221 .12542 L
.23196 .14376 L
.23687 .15108 L
.23966 .15434 L
.2409 .15555 L
.24226 .15668 L
.2435 .15754 L
.24465 .15819 L
.24575 .15866 L
.24692 .15902 L
.24796 .15919 L
.24894 .15924 L
.25001 .15916 L
.25117 .15892 L
.25233 .15851 L
.2536 .15788 L
.25492 .15702 L
.25616 .15603 L
.26073 .15085 L
.26335 .1469 L
.26577 .14268 L
.27123 .13152 L
.28116 .10831 L
.29011 .08898 L
Mistroke
.29269 .08446 L
.29514 .08078 L
.29737 .07803 L
.29974 .07578 L
.301 .07489 L
.30214 .07427 L
.30329 .07383 L
.30437 .07359 L
.30563 .07353 L
.3068 .07369 L
.30807 .07409 L
.30871 .07439 L
.30942 .07478 L
.31168 .07655 L
.31295 .07787 L
.31411 .07928 L
.31848 .08629 L
.32356 .09741 L
.32908 .11231 L
.33911 .14275 L
.34852 .16827 L
.3511 .1737 L
.35388 .1785 L
.35515 .18029 L
.3565 .18188 L
.35773 .18306 L
.3589 .18391 L
.36022 .18457 L
.36142 .18487 L
.36271 .18487 L
.36343 .18472 L
.3641 .18449 L
.36522 .18391 L
.36645 .18296 L
.36774 .18163 L
.36894 .18009 L
.37171 .1754 L
.37423 .16978 L
.37991 .15283 L
.38992 .112 L
.40056 .06355 L
.40574 .04285 L
.40827 .03424 L
.4106 .02749 L
.41269 .02252 L
.41498 .01838 L
.41616 .01682 L
.41727 .01574 L
.41844 .01501 L
.41969 .01472 L
Mistroke
.42094 .01494 L
.42226 .01576 L
.42339 .01694 L
.42463 .01877 L
.42596 .02135 L
.4274 .02487 L
.42999 .03318 L
.4326 .04409 L
.43508 .05683 L
.43973 .08685 L
.44844 .16234 L
.45796 .26579 L
.46893 .39415 L
.47927 .50204 L
.48378 .5397 L
.48855 .57096 L
.49104 .58336 L
.49236 .58877 L
.49378 .59364 L
.49508 .59726 L
.49627 .59983 L
.49746 .60171 L
.49859 .60284 L
.49975 .60332 L
.50083 .60316 L
.50203 .6023 L
.50331 .60058 L
.50458 .59806 L
.50592 .59454 L
.50832 .58607 L
.51055 .57577 L
.51262 .56417 L
.51733 .53114 L
.52718 .43746 L
.53771 .31654 L
.54795 .19963 L
.55334 .1451 L
.55905 .09602 L
.56404 .06195 L
.56668 .04755 L
.56953 .03499 L
.57214 .02617 L
.57452 .02033 L
.57567 .01827 L
.57692 .01657 L
.5781 .01547 L
.5792 .01489 L
.58049 .01473 L
.58114 .01485 L
.58185 .01515 L
Mistroke
.58311 .01606 L
.58428 .01736 L
.58567 .01941 L
.58694 .02176 L
.58978 .02853 L
.5949 .0452 L
.59975 .06489 L
.6086 .10524 L
.61364 .1277 L
.61837 .14666 L
.62341 .16345 L
.62804 .17489 L
.63045 .17918 L
.63167 .18091 L
.63298 .18242 L
.6343 .18357 L
.63553 .18433 L
.63628 .18464 L
.63698 .18482 L
.63831 .1849 L
.63937 .1847 L
.64054 .18423 L
.64177 .18345 L
.64291 .18248 L
.64496 .18015 L
.64715 .17686 L
.65216 .16669 L
.65673 .15486 L
.66675 .12479 L
.67224 .10855 L
.6774 .0951 L
.68177 .08581 L
.68402 .08196 L
.68649 .07853 L
.68904 .0759 L
.69043 .07487 L
.69173 .07418 L
.69294 .07375 L
.69405 .07356 L
.69533 .07356 L
.69654 .07378 L
.69767 .07418 L
.69874 .07473 L
.69991 .07551 L
.70117 .07656 L
.70374 .07932 L
.70608 .08254 L
.7149 .09927 L
.72523 .12345 L
.73026 .13476 L
Mistroke
.73482 .14375 L
.73709 .14761 L
.73955 .15124 L
.74168 .15387 L
.74401 .15618 L
.74521 .15712 L
.7465 .15794 L
.7472 .1583 L
.74785 .15859 L
.74912 .15899 L
.75027 .1592 L
.75153 .15923 L
.75271 .15909 L
.75381 .15881 L
.755 .15835 L
.75628 .15768 L
.75859 .15599 L
.76134 .15326 L
.76386 .15011 L
.77454 .13187 L
.78369 .11375 L
.78872 .1046 L
.79347 .09731 L
.79616 .09394 L
.79909 .09102 L
.80038 .08999 L
.80174 .08908 L
.80302 .0884 L
.80419 .08793 L
.80538 .0876 L
.80665 .0874 L
.80782 .08737 L
.80894 .08748 L
.81024 .08776 L
.81144 .08818 L
.81276 .08881 L
.81417 .08967 L
.81679 .09175 L
.81955 .0946 L
.82448 .10111 L
.83563 .11987 L
.84538 .13625 L
.85084 .14353 L
.85342 .14624 L
.85581 .14825 L
.85816 .14975 L
.85935 .15031 L
.86066 .15077 L
.86197 .15107 L
.8627 .15117 L
Mistroke
.86338 .15122 L
.86468 .15118 L
.86593 .151 L
.86707 .1507 L
.8683 .15024 L
.8705 .14908 L
.87312 .14715 L
.87549 .14492 L
.88494 .13248 L
.89384 .11799 L
.90359 .10329 L
.90851 .09767 L
.9113 .09525 L
.91254 .09436 L
.9139 .09355 L
.91514 .09295 L
.91629 .09251 L
.91739 .0922 L
.91856 .09199 L
.9196 .0919 L
.92058 .09191 L
.92165 .09202 L
.92281 .09226 L
.92397 .09261 L
.92524 .09314 L
.9278 .09461 L
.93016 .09645 L
.93237 .09854 L
.95243 .1275 L
.96153 .14011 L
.96402 .14282 L
.96666 .14521 L
.96891 .14683 L
.9702 .14758 L
.97139 .14814 L
.97258 .14858 L
.97387 .14892 L
.97506 .1491 L
.97619 .14916 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.346155 0.477324 0.626443 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.0147151 0.294302 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.04762 .01472 m
.04762 .01472 L
s
.07143 .01472 m
.07143 .01472 L
s
.09524 .01472 m
.09524 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.14286 .01472 m
.14286 .01472 L
s
.16667 .01472 m
.16667 .01472 L
s
.19048 .01472 m
.19048 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.2381 .01472 m
.2381 .01472 L
s
.2619 .01472 m
.2619 .01472 L
s
.28571 .01472 m
.28571 .01472 L
s
.30952 .01472 m
.30952 .01472 L
s
.33333 .01472 m
.33333 .01472 L
s
.35714 .01472 m
.35714 .01472 L
s
.38095 .01472 m
.38095 .01472 L
s
.40476 .01472 m
.40476 .30902 L
s
.42857 .01472 m
.42857 .30902 L
s
.45238 .01472 m
.45238 .30902 L
s
.47619 .01472 m
.47619 .30902 L
s
.5 .01472 m
.5 .30902 L
s
.52381 .01472 m
.52381 .30902 L
s
.54762 .01472 m
.54762 .30902 L
s
.57143 .01472 m
.57143 .30902 L
s
.59524 .01472 m
.59524 .30902 L
s
.61905 .01472 m
.61905 .01472 L
s
.64286 .01472 m
.64286 .01472 L
s
.66667 .01472 m
.66667 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.71429 .01472 m
.71429 .01472 L
s
.7381 .01472 m
.7381 .01472 L
s
.7619 .01472 m
.7619 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.80952 .01472 m
.80952 .01472 L
s
.83333 .01472 m
.83333 .01472 L
s
.85714 .01472 m
.85714 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.90476 .01472 m
.90476 .01472 L
s
.92857 .01472 m
.92857 .01472 L
s
.95238 .01472 m
.95238 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.04762 .01472 Mdot
.07143 .01472 Mdot
.09524 .01472 Mdot
.11905 .01472 Mdot
.14286 .01472 Mdot
.16667 .01472 Mdot
.19048 .01472 Mdot
.21429 .01472 Mdot
.2381 .01472 Mdot
.2619 .01472 Mdot
.28571 .01472 Mdot
.30952 .01472 Mdot
.33333 .01472 Mdot
.35714 .01472 Mdot
.38095 .01472 Mdot
.40476 .30902 Mdot
.42857 .30902 Mdot
.45238 .30902 Mdot
.47619 .30902 Mdot
.5 .30902 Mdot
.52381 .30902 Mdot
.54762 .30902 Mdot
.57143 .30902 Mdot
.59524 .30902 Mdot
.61905 .01472 Mdot
.64286 .01472 Mdot
.66667 .01472 Mdot
.69048 .01472 Mdot
.71429 .01472 Mdot
.7381 .01472 Mdot
.7619 .01472 Mdot
.78571 .01472 Mdot
.80952 .01472 Mdot
.83333 .01472 Mdot
.85714 .01472 Mdot
.88095 .01472 Mdot
.90476 .01472 Mdot
.92857 .01472 Mdot
.95238 .01472 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.346155 0.97619 0.626443 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.123439 0.05332 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0168 -12 -4.5 ]
[-0.0125 .0168 0 4.5 ]
[-0.0125 .12344 -6 -4.5 ]
[-0.0125 .12344 0 4.5 ]
[-0.0125 .23008 -6 -4.5 ]
[-0.0125 .23008 0 4.5 ]
[-0.0125 .33672 -6 -4.5 ]
[-0.0125 .33672 0 4.5 ]
[-0.0125 .44336 -6 -4.5 ]
[-0.0125 .44336 0 4.5 ]
[-0.0125 .55 -6 -4.5 ]
[-0.0125 .55 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0168 m
.00625 .0168 L
s
[(-2)] -0.0125 .0168 1 0 Mshowa
0 .12344 m
.00625 .12344 L
s
[(0)] -0.0125 .12344 1 0 Mshowa
0 .23008 m
.00625 .23008 L
s
[(2)] -0.0125 .23008 1 0 Mshowa
0 .33672 m
.00625 .33672 L
s
[(4)] -0.0125 .33672 1 0 Mshowa
0 .44336 m
.00625 .44336 L
s
[(6)] -0.0125 .44336 1 0 Mshowa
0 .55 m
.00625 .55 L
s
[(8)] -0.0125 .55 1 0 Mshowa
.125 Mabswid
0 .04346 m
.00375 .04346 L
s
0 .07012 m
.00375 .07012 L
s
0 .09678 m
.00375 .09678 L
s
0 .1501 m
.00375 .1501 L
s
0 .17676 m
.00375 .17676 L
s
0 .20342 m
.00375 .20342 L
s
0 .25674 m
.00375 .25674 L
s
0 .2834 m
.00375 .2834 L
s
0 .31006 m
.00375 .31006 L
s
0 .36338 m
.00375 .36338 L
s
0 .39004 m
.00375 .39004 L
s
0 .4167 m
.00375 .4167 L
s
0 .47002 m
.00375 .47002 L
s
0 .49668 m
.00375 .49668 L
s
0 .52334 m
.00375 .52334 L
s
0 .57666 m
.00375 .57666 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0168 m
1 .0168 L
s
.99375 .12344 m
1 .12344 L
s
.99375 .23008 m
1 .23008 L
s
.99375 .33672 m
1 .33672 L
s
.99375 .44336 m
1 .44336 L
s
.99375 .55 m
1 .55 L
s
.125 Mabswid
.99625 .04346 m
1 .04346 L
s
.99625 .07012 m
1 .07012 L
s
.99625 .09678 m
1 .09678 L
s
.99625 .1501 m
1 .1501 L
s
.99625 .17676 m
1 .17676 L
s
.99625 .20342 m
1 .20342 L
s
.99625 .25674 m
1 .25674 L
s
.99625 .2834 m
1 .2834 L
s
.99625 .31006 m
1 .31006 L
s
.99625 .36338 m
1 .36338 L
s
.99625 .39004 m
1 .39004 L
s
.99625 .4167 m
1 .4167 L
s
.99625 .47002 m
1 .47002 L
s
.99625 .49668 m
1 .49668 L
s
.99625 .52334 m
1 .52334 L
s
.99625 .57666 m
1 .57666 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .17676 m
.02499 .17673 L
.02605 .17664 L
.02729 .17648 L
.02846 .17626 L
.03053 .17571 L
.03279 .1749 L
.03527 .17374 L
.0379 .17222 L
.04262 .16875 L
.05205 .15924 L
.06244 .14554 L
.08274 .11377 L
.09394 .09664 L
.10458 .08276 L
.10945 .07759 L
.11464 .07307 L
.11762 .07098 L
.12033 .06942 L
.12305 .0682 L
.12428 .06776 L
.12562 .06736 L
.12683 .06708 L
.12796 .06688 L
.12915 .06673 L
.13043 .06666 L
.13162 .06666 L
.13275 .06673 L
.13376 .06684 L
.13487 .06702 L
.13606 .06728 L
.13738 .06766 L
.14006 .06868 L
.14254 .06994 L
.14487 .07139 L
.14956 .07509 L
.1547 .08025 L
.16505 .09382 L
.18355 .1253 L
.20481 .16302 L
.21485 .17748 L
.21926 .1826 L
.22412 .18719 L
.2288 .19047 L
.23136 .19176 L
.2325 .19222 L
.23375 .19263 L
.23445 .19282 L
.2351 .19297 L
.23638 .1932 L
Mistroke
.23755 .19332 L
.23879 .19335 L
.23949 .19333 L
.24025 .19327 L
.24097 .19319 L
.24163 .19308 L
.24288 .1928 L
.2442 .19241 L
.24646 .19148 L
.24888 .19013 L
.25325 .18678 L
.25844 .1813 L
.26316 .17495 L
.2731 .15773 L
.28228 .13798 L
.30306 .08618 L
.31283 .06226 L
.32335 .03993 L
.32819 .03152 L
.33328 .02427 L
.33763 .01957 L
.34009 .01758 L
.34238 .01618 L
.34361 .01561 L
.34475 .01521 L
.34599 .0149 L
.34731 .01474 L
.34846 .01472 L
.34953 .01482 L
.3507 .01506 L
.35197 .01547 L
.35308 .01596 L
.3543 .01663 L
.35652 .01824 L
.35867 .0203 L
.36067 .02263 L
.36516 .0294 L
.37012 .03937 L
.38018 .06752 L
.39026 .10594 L
.3995 .14922 L
.42035 .26737 L
.44085 .39376 L
.45994 .49903 L
.4694 .54071 L
.47834 .57132 L
.48329 .5841 L
.48589 .58958 L
.48865 .5944 L
.49097 .59766 L
Mistroke
.4922 .59909 L
.49352 .6004 L
.49473 .60139 L
.49584 .60212 L
.49696 .60268 L
.49802 .60305 L
.49926 .60328 L
.49997 .60332 L
.50061 .60329 L
.5018 .60309 L
.50305 .60267 L
.50418 .6021 L
.50523 .60142 L
.50761 .59929 L
.5102 .59611 L
.51255 .59243 L
.51784 .58146 L
.52237 .56923 L
.52729 .55311 L
.53623 .51693 L
.57703 .28343 L
.5973 .16573 L
.60723 .11702 L
.61632 .07976 L
.62518 .05121 L
.62969 .0398 L
.6345 .03 L
.63704 .02581 L
.63935 .0226 L
.6417 .01991 L
.64386 .01794 L
.64639 .01623 L
.64772 .01559 L
.64839 .01533 L
.64912 .01511 L
.65035 .01484 L
.65149 .01473 L
.65219 .01472 L
.65285 .01475 L
.65409 .01492 L
.65534 .01524 L
.65605 .01548 L
.65669 .01574 L
.65914 .01706 L
.66137 .0187 L
.66371 .02087 L
.6686 .02674 L
.67395 .03507 L
.69236 .07471 L
.71356 .12812 L
Mistroke
.72359 .15098 L
.73285 .16864 L
.74246 .18236 L
.74752 .18745 L
.75007 .18943 L
.75289 .19115 L
.75415 .19176 L
.75535 .19225 L
.75644 .19261 L
.7576 .19292 L
.75885 .19316 L
.76002 .1933 L
.76074 .19334 L
.76141 .19335 L
.76267 .1933 L
.76378 .19317 L
.76496 .19296 L
.76597 .19271 L
.76707 .19237 L
.76953 .19136 L
.77183 .1901 L
.77683 .18638 L
.78228 .1809 L
.79218 .16772 L
.81073 .13582 L
.8301 .10138 L
.8404 .0862 L
.8458 .0797 L
.8515 .07416 L
.85654 .07048 L
.8594 .06893 L
.86077 .06832 L
.86206 .06784 L
.86323 .06747 L
.86451 .06715 L
.86567 .06692 L
.86674 .06678 L
.8679 .06668 L
.86917 .06665 L
.86981 .06667 L
.8705 .06671 L
.87174 .06684 L
.87301 .06705 L
.87418 .06731 L
.87684 .06816 L
.87918 .06918 L
.88167 .07054 L
.88644 .07392 L
.89075 .07779 L
.9008 .08939 L
Mistroke
.91003 .1025 L
.93086 .13547 L
.93996 .14896 L
.94971 .16126 L
.95531 .16694 L
.96041 .17108 L
.96287 .17269 L
.96554 .17414 L
.96806 .17523 L
.97039 .17598 L
.97181 .17631 L
.97315 .17654 L
.97391 .17664 L
.97461 .1767 L
.97538 .17674 L
.97619 .17676 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.654471 0.477324 0.934759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.0147151 0.294302 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.04762 .01472 m
.04762 .01472 L
s
.07143 .01472 m
.07143 .01472 L
s
.09524 .01472 m
.09524 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.14286 .01472 m
.14286 .01472 L
s
.16667 .01472 m
.16667 .01472 L
s
.19048 .01472 m
.19048 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.2381 .01472 m
.2381 .01472 L
s
.2619 .01472 m
.2619 .01472 L
s
.28571 .01472 m
.28571 .01472 L
s
.30952 .01472 m
.30952 .01472 L
s
.33333 .01472 m
.33333 .01472 L
s
.35714 .01472 m
.35714 .01472 L
s
.38095 .01472 m
.38095 .01472 L
s
.40476 .01472 m
.40476 .01472 L
s
.42857 .01472 m
.42857 .01472 L
s
.45238 .01472 m
.45238 .30902 L
s
.47619 .01472 m
.47619 .30902 L
s
.5 .01472 m
.5 .30902 L
s
.52381 .01472 m
.52381 .30902 L
s
.54762 .01472 m
.54762 .30902 L
s
.57143 .01472 m
.57143 .01472 L
s
.59524 .01472 m
.59524 .01472 L
s
.61905 .01472 m
.61905 .01472 L
s
.64286 .01472 m
.64286 .01472 L
s
.66667 .01472 m
.66667 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.71429 .01472 m
.71429 .01472 L
s
.7381 .01472 m
.7381 .01472 L
s
.7619 .01472 m
.7619 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.80952 .01472 m
.80952 .01472 L
s
.83333 .01472 m
.83333 .01472 L
s
.85714 .01472 m
.85714 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.90476 .01472 m
.90476 .01472 L
s
.92857 .01472 m
.92857 .01472 L
s
.95238 .01472 m
.95238 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.04762 .01472 Mdot
.07143 .01472 Mdot
.09524 .01472 Mdot
.11905 .01472 Mdot
.14286 .01472 Mdot
.16667 .01472 Mdot
.19048 .01472 Mdot
.21429 .01472 Mdot
.2381 .01472 Mdot
.2619 .01472 Mdot
.28571 .01472 Mdot
.30952 .01472 Mdot
.33333 .01472 Mdot
.35714 .01472 Mdot
.38095 .01472 Mdot
.40476 .01472 Mdot
.42857 .01472 Mdot
.45238 .30902 Mdot
.47619 .30902 Mdot
.5 .30902 Mdot
.52381 .30902 Mdot
.54762 .30902 Mdot
.57143 .01472 Mdot
.59524 .01472 Mdot
.61905 .01472 Mdot
.64286 .01472 Mdot
.66667 .01472 Mdot
.69048 .01472 Mdot
.71429 .01472 Mdot
.7381 .01472 Mdot
.7619 .01472 Mdot
.78571 .01472 Mdot
.80952 .01472 Mdot
.83333 .01472 Mdot
.85714 .01472 Mdot
.88095 .01472 Mdot
.90476 .01472 Mdot
.92857 .01472 Mdot
.95238 .01472 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.654471 0.97619 0.934759 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.132436 0.0941768 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03826 -12 -4.5 ]
[-0.0125 .03826 0 4.5 ]
[-0.0125 .13244 -6 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .22661 -6 -4.5 ]
[-0.0125 .22661 0 4.5 ]
[-0.0125 .32079 -6 -4.5 ]
[-0.0125 .32079 0 4.5 ]
[-0.0125 .41497 -6 -4.5 ]
[-0.0125 .41497 0 4.5 ]
[-0.0125 .50914 -6 -4.5 ]
[-0.0125 .50914 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03826 m
.00625 .03826 L
s
[(-1)] -0.0125 .03826 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(0)] -0.0125 .13244 1 0 Mshowa
0 .22661 m
.00625 .22661 L
s
[(1)] -0.0125 .22661 1 0 Mshowa
0 .32079 m
.00625 .32079 L
s
[(2)] -0.0125 .32079 1 0 Mshowa
0 .41497 m
.00625 .41497 L
s
[(3)] -0.0125 .41497 1 0 Mshowa
0 .50914 m
.00625 .50914 L
s
[(4)] -0.0125 .50914 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(5)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .05709 m
.00375 .05709 L
s
0 .07593 m
.00375 .07593 L
s
0 .09477 m
.00375 .09477 L
s
0 .1136 m
.00375 .1136 L
s
0 .15127 m
.00375 .15127 L
s
0 .17011 m
.00375 .17011 L
s
0 .18894 m
.00375 .18894 L
s
0 .20778 m
.00375 .20778 L
s
0 .24545 m
.00375 .24545 L
s
0 .26428 m
.00375 .26428 L
s
0 .28312 m
.00375 .28312 L
s
0 .30195 m
.00375 .30195 L
s
0 .33963 m
.00375 .33963 L
s
0 .35846 m
.00375 .35846 L
s
0 .3773 m
.00375 .3773 L
s
0 .39613 m
.00375 .39613 L
s
0 .4338 m
.00375 .4338 L
s
0 .45264 m
.00375 .45264 L
s
0 .47147 m
.00375 .47147 L
s
0 .49031 m
.00375 .49031 L
s
0 .52798 m
.00375 .52798 L
s
0 .54681 m
.00375 .54681 L
s
0 .56565 m
.00375 .56565 L
s
0 .58448 m
.00375 .58448 L
s
0 .01942 m
.00375 .01942 L
s
0 .00059 m
.00375 .00059 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03826 m
1 .03826 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .22661 m
1 .22661 L
s
.99375 .32079 m
1 .32079 L
s
.99375 .41497 m
1 .41497 L
s
.99375 .50914 m
1 .50914 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .05709 m
1 .05709 L
s
.99625 .07593 m
1 .07593 L
s
.99625 .09477 m
1 .09477 L
s
.99625 .1136 m
1 .1136 L
s
.99625 .15127 m
1 .15127 L
s
.99625 .17011 m
1 .17011 L
s
.99625 .18894 m
1 .18894 L
s
.99625 .20778 m
1 .20778 L
s
.99625 .24545 m
1 .24545 L
s
.99625 .26428 m
1 .26428 L
s
.99625 .28312 m
1 .28312 L
s
.99625 .30195 m
1 .30195 L
s
.99625 .33963 m
1 .33963 L
s
.99625 .35846 m
1 .35846 L
s
.99625 .3773 m
1 .3773 L
s
.99625 .39613 m
1 .39613 L
s
.99625 .4338 m
1 .4338 L
s
.99625 .45264 m
1 .45264 L
s
.99625 .47147 m
1 .47147 L
s
.99625 .49031 m
1 .49031 L
s
.99625 .52798 m
1 .52798 L
s
.99625 .54681 m
1 .54681 L
s
.99625 .56565 m
1 .56565 L
s
.99625 .58448 m
1 .58448 L
s
.99625 .01942 m
1 .01942 L
s
.99625 .00059 m
1 .00059 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .22661 m
.02499 .2266 L
.02605 .22655 L
.02729 .22646 L
.02846 .22635 L
.03053 .22606 L
.03279 .22562 L
.03527 .225 L
.0379 .22418 L
.04262 .22229 L
.05205 .21695 L
.06244 .20875 L
.0842 .18467 L
.10458 .15551 L
.14335 .09263 L
.16306 .06269 L
.17347 .04881 L
.18458 .03611 L
.19538 .02625 L
.20517 .01975 L
.2099 .01753 L
.21238 .01661 L
.21501 .01583 L
.21731 .01532 L
.21862 .01509 L
.21984 .01493 L
.22096 .01482 L
.22199 .01476 L
.22317 .01472 L
.22428 .01472 L
.22542 .01477 L
.22665 .01486 L
.22781 .01499 L
.22887 .01515 L
.23134 .01565 L
.23394 .01638 L
.23648 .01731 L
.23884 .01836 L
.24419 .02142 L
.2531 .02859 L
.26261 .03915 L
.27286 .05382 L
.28396 .07349 L
.30411 .11849 L
.34503 .23884 L
.38443 .37147 L
.42232 .48855 L
.44177 .53667 L
.45261 .55855 L
.46266 .57523 L
Mistroke
.47279 .58829 L
.47814 .59358 L
.48384 .59798 L
.48645 .59956 L
.48927 .60096 L
.49194 .60199 L
.4932 .60237 L
.49438 .60267 L
.49555 .60291 L
.4966 .60308 L
.49778 .60322 L
.49903 .6033 L
.50024 .60332 L
.50155 .60327 L
.50279 .60316 L
.50394 .603 L
.50512 .60278 L
.50636 .60249 L
.50859 .60181 L
.51098 .60085 L
.51359 .59954 L
.51828 .5965 L
.52264 .59288 L
.53261 .5818 L
.54326 .56585 L
.56464 .52199 L
.58481 .46848 L
.62332 .34537 L
.6643 .20885 L
.68469 .14811 L
.70375 .09958 L
.72205 .06236 L
.73225 .04608 L
.74169 .034 L
.75185 .02429 L
.75721 .02053 L
.75995 .01897 L
.76291 .01757 L
.76547 .01658 L
.76783 .01586 L
.77009 .01533 L
.77122 .01513 L
.77246 .01495 L
.77317 .01488 L
.77385 .01482 L
.7751 .01474 L
.77581 .01472 L
.77646 .01472 L
.77717 .01472 L
.77793 .01475 L
Mistroke
.77918 .01483 L
.78035 .01495 L
.78164 .01513 L
.78302 .01538 L
.78556 .01598 L
.78827 .01683 L
.79313 .01888 L
.79892 .02216 L
.80417 .02589 L
.82426 .04604 L
.84352 .07225 L
.86435 .10513 L
.90537 .17038 L
.92581 .19682 L
.93579 .20713 L
.94488 .21477 L
.95264 .21986 L
.96 .2234 L
.96403 .2248 L
.96775 .22574 L
.9697 .2261 L
.97082 .22626 L
.97185 .22638 L
.97292 .22648 L
.97409 .22656 L
.97511 .2266 L
.97619 .22661 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.962788 0.477324 1.24308 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.0147151 0.294302 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.04762 .01472 m
.04762 .01472 L
s
.07143 .01472 m
.07143 .01472 L
s
.09524 .01472 m
.09524 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.14286 .01472 m
.14286 .01472 L
s
.16667 .01472 m
.16667 .01472 L
s
.19048 .01472 m
.19048 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.2381 .01472 m
.2381 .01472 L
s
.2619 .01472 m
.2619 .01472 L
s
.28571 .01472 m
.28571 .01472 L
s
.30952 .01472 m
.30952 .01472 L
s
.33333 .01472 m
.33333 .01472 L
s
.35714 .01472 m
.35714 .01472 L
s
.38095 .01472 m
.38095 .01472 L
s
.40476 .01472 m
.40476 .01472 L
s
.42857 .01472 m
.42857 .01472 L
s
.45238 .01472 m
.45238 .01472 L
s
.47619 .01472 m
.47619 .30902 L
s
.5 .01472 m
.5 .30902 L
s
.52381 .01472 m
.52381 .30902 L
s
.54762 .01472 m
.54762 .01472 L
s
.57143 .01472 m
.57143 .01472 L
s
.59524 .01472 m
.59524 .01472 L
s
.61905 .01472 m
.61905 .01472 L
s
.64286 .01472 m
.64286 .01472 L
s
.66667 .01472 m
.66667 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.71429 .01472 m
.71429 .01472 L
s
.7381 .01472 m
.7381 .01472 L
s
.7619 .01472 m
.7619 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.80952 .01472 m
.80952 .01472 L
s
.83333 .01472 m
.83333 .01472 L
s
.85714 .01472 m
.85714 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.90476 .01472 m
.90476 .01472 L
s
.92857 .01472 m
.92857 .01472 L
s
.95238 .01472 m
.95238 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.04762 .01472 Mdot
.07143 .01472 Mdot
.09524 .01472 Mdot
.11905 .01472 Mdot
.14286 .01472 Mdot
.16667 .01472 Mdot
.19048 .01472 Mdot
.21429 .01472 Mdot
.2381 .01472 Mdot
.2619 .01472 Mdot
.28571 .01472 Mdot
.30952 .01472 Mdot
.33333 .01472 Mdot
.35714 .01472 Mdot
.38095 .01472 Mdot
.40476 .01472 Mdot
.42857 .01472 Mdot
.45238 .01472 Mdot
.47619 .30902 Mdot
.5 .30902 Mdot
.52381 .30902 Mdot
.54762 .01472 Mdot
.57143 .01472 Mdot
.59524 .01472 Mdot
.61905 .01472 Mdot
.64286 .01472 Mdot
.66667 .01472 Mdot
.69048 .01472 Mdot
.71429 .01472 Mdot
.7381 .01472 Mdot
.7619 .01472 Mdot
.78571 .01472 Mdot
.80952 .01472 Mdot
.83333 .01472 Mdot
.85714 .01472 Mdot
.88095 .01472 Mdot
.90476 .01472 Mdot
.92857 .01472 Mdot
.95238 .01472 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.962788 0.97619 1.24308 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.161866 0.147151 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -6 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -6 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(2)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01475 L
.02729 .01479 L
.02846 .01485 L
.03053 .015 L
.03279 .01523 L
.03527 .01556 L
.0379 .01599 L
.04262 .01698 L
.04749 .0183 L
.05205 .01981 L
.06244 .02422 L
.07305 .03011 L
.08274 .03668 L
.10458 .05552 L
.14429 .10289 L
.18248 .16177 L
.22313 .23454 L
.26226 .3097 L
.30384 .3894 L
.34391 .46058 L
.38246 .51918 L
.402 .54393 L
.42346 .56659 L
.44388 .58338 L
.45301 .58929 L
.46295 .59457 L
.46838 .59694 L
.4734 .5988 L
.4781 .60026 L
.4833 .60154 L
.48553 .60198 L
.48794 .60239 L
.49002 .60268 L
.4923 .60294 L
.49473 .60314 L
.49605 .60322 L
.49728 .60327 L
.49844 .6033 L
.49949 .60332 L
.50071 .60332 L
.50186 .6033 L
.50301 .60326 L
.50425 .60321 L
.50542 .60313 L
.50648 .60305 L
.5091 .60279 L
.51158 .60246 L
.5165 .60158 L
Mistroke
.52187 .60026 L
.53144 .59701 L
.54032 .59297 L
.56088 .5799 L
.5795 .56376 L
.61962 .51633 L
.65822 .45702 L
.69928 .38356 L
.73882 .30761 L
.77684 .2346 L
.81732 .1621 L
.85628 .1021 L
.87613 .07654 L
.89769 .0533 L
.91843 .03582 L
.92832 .02927 L
.93759 .02421 L
.94643 .02037 L
.95595 .01733 L
.9611 .01617 L
.96369 .01572 L
.96652 .01531 L
.96894 .01505 L
.9703 .01494 L
.97153 .01485 L
.97268 .01479 L
.97393 .01475 L
.97511 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.2711 0.477324 1.55139 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.0147151 0.294302 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.04762 .01472 m
.04762 .01472 L
s
.07143 .01472 m
.07143 .01472 L
s
.09524 .01472 m
.09524 .01472 L
s
.11905 .01472 m
.11905 .01472 L
s
.14286 .01472 m
.14286 .01472 L
s
.16667 .01472 m
.16667 .01472 L
s
.19048 .01472 m
.19048 .01472 L
s
.21429 .01472 m
.21429 .01472 L
s
.2381 .01472 m
.2381 .01472 L
s
.2619 .01472 m
.2619 .01472 L
s
.28571 .01472 m
.28571 .01472 L
s
.30952 .01472 m
.30952 .01472 L
s
.33333 .01472 m
.33333 .01472 L
s
.35714 .01472 m
.35714 .01472 L
s
.38095 .01472 m
.38095 .01472 L
s
.40476 .01472 m
.40476 .01472 L
s
.42857 .01472 m
.42857 .01472 L
s
.45238 .01472 m
.45238 .01472 L
s
.47619 .01472 m
.47619 .01472 L
s
.5 .01472 m
.5 .30902 L
s
.52381 .01472 m
.52381 .01472 L
s
.54762 .01472 m
.54762 .01472 L
s
.57143 .01472 m
.57143 .01472 L
s
.59524 .01472 m
.59524 .01472 L
s
.61905 .01472 m
.61905 .01472 L
s
.64286 .01472 m
.64286 .01472 L
s
.66667 .01472 m
.66667 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.71429 .01472 m
.71429 .01472 L
s
.7381 .01472 m
.7381 .01472 L
s
.7619 .01472 m
.7619 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.80952 .01472 m
.80952 .01472 L
s
.83333 .01472 m
.83333 .01472 L
s
.85714 .01472 m
.85714 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.90476 .01472 m
.90476 .01472 L
s
.92857 .01472 m
.92857 .01472 L
s
.95238 .01472 m
.95238 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.04762 .01472 Mdot
.07143 .01472 Mdot
.09524 .01472 Mdot
.11905 .01472 Mdot
.14286 .01472 Mdot
.16667 .01472 Mdot
.19048 .01472 Mdot
.21429 .01472 Mdot
.2381 .01472 Mdot
.2619 .01472 Mdot
.28571 .01472 Mdot
.30952 .01472 Mdot
.33333 .01472 Mdot
.35714 .01472 Mdot
.38095 .01472 Mdot
.40476 .01472 Mdot
.42857 .01472 Mdot
.45238 .01472 Mdot
.47619 .01472 Mdot
.5 .30902 Mdot
.52381 .01472 Mdot
.54762 .01472 Mdot
.57143 .01472 Mdot
.59524 .01472 Mdot
.61905 .01472 Mdot
.64286 .01472 Mdot
.66667 .01472 Mdot
.69048 .01472 Mdot
.71429 .01472 Mdot
.7381 .01472 Mdot
.7619 .01472 Mdot
.78571 .01472 Mdot
.80952 .01472 Mdot
.83333 .01472 Mdot
.85714 .01472 Mdot
.88095 .01472 Mdot
.90476 .01472 Mdot
.92857 .01472 Mdot
.95238 .01472 Mdot
.97619 .01472 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 1.2711 0.97619 1.55139 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.0147151 0.294302 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 800.938},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h000382000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`008_ooool5
o`0000?ooooo0_l0000Xooooo`?o00001?ooool2o`0002Wooooo0_l0000[ooooo`?o00001?ooool2
o`0002Sooooo1Ol00003ooooo`;o0000<oooool3o`0001cooooo1Ol0000Looooo`?o00006oooool2
o`0001cooooo0ol0000Looooo`Go00007?ooool3o`0001Sooooo000Sooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0002Oooooo00Co0000oooooooooooo0000:oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0002Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000aooooo`05o`000?ooooooooooooooool000007?ooool01?l0003oooooooooool0000Mooooo`03
o`000?oooooooooo01Wooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Loooo
o`04o`000?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`00000Gooooo`007?ooool5
o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Pooooo`Go00000ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Oooooo00Co0000oooooooooooo
0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Wooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000[ooooo`Go00001Oooool00ol0003oooooooooo`0C
ooooo`Go00000oooool00ol0003oooooooooo`0Eooooo`Go00000oooool00ol0003oooooooooo`0I
ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01Gooooo000Uooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
9oooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000:_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0<Oooool2
o`0001oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`04o`000?oooooo
ooooo`0001cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Looooo`;o00006?oo
ool002;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`00
02_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000eooooo`03o`000?oooooooooo01Wooooo
00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooo
oooo00007?ooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000007oooool0
0ol0003oooooooooo`0Eooooo`008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00009oooool2o`0000Cooooo00Co0000oooooooooooo00009oooool01?l0003ooooo
ooooool0000Zooooo`;o00001?ooool01?l0003oooooooooool0000Wooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool0000aooooo`05o`000?ooooooooooooooool00000
6oooool01Ol0003ooooooooooooooooo000001cooooo0_l0000Kooooo`04o`000?ooooooooooo`00
01_ooooo0_l0000Mooooo`05o`000?ooooooooooooooool000006oooool01Ol0003ooooooooooooo
oooo000001Oooooo000Sooooo`?o00001?ooool2o`0002Wooooo00?o0000ooooooooool00oooool2
o`0002Wooooo0_l0000/ooooo`03o`000?oooooooooo00?ooooo0_l0000Yooooo`?o00001?ooool2
o`0003?ooooo0ol0000Mooooo`?o00007_ooool00ol0003oooooooooo`0Jooooo`;o00007Oooool0
0ol0003oooooooooo`0Looooo`?o00007Oooool3o`0001Sooooo003oooooooWooooo003oooooooWo
oooo003oooooooWooooo003ooooooaSoooood_l0000?ooooo`006Oooool2o`0000Gooooocol0000X
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool0000?ooooo`006?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0;oooool01Ol0003ooooooooooooooooo000002Sooooo0_l00007ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool001Sooooo00Co0000oooooooooooo
00001?ooool01?l0003oooooooooooooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00
o`;ooooo0ol00?l2ooooo`?o003o00Coooooo`00ool00?oo003o0_ooool3o`00o`;ooooo0ol00?l2
ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?mEooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2
ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2
ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0c_ooool00ol0003oooooooooo`0=ooooo`006?ooool01?l0003oooooooooool00004
ooooo`Co00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003
o`00o`04o`000?l00?oo003oo`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol0
0?l2o`0000?o003o0ol000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000?o
003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000Go
003oo`000?l0003o0000o`00o`04o`000003o`00ool0003o000000;o000000?o003oo`000?l00000
0_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000?o003oo`000?l00000
0_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000?o003oo`000?l00000
0_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000?o003o0_l00003o`00o`;o0000
0ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o0000
0ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l3o`0002Sooooo00?o0000ooooooooool0
E?ooool3ool001oooooo0_oo001Fooooo`03o`000?oooooooooo00gooooo000Hooooo`04o`000?oo
ooooooooo`0000Cooooo00Co0000oooooooooooooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;o
oooo0ol00?l2ooooo`?o003o0_ooool3o`00o`04ooooool00?oo003oo`00o`;ooooo0ol00?l2oooo
o`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2
ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Doooool01?oo003ooooooooooooo
000Nooooo`04ool00?ooooooooooool005Gooooo00?o0000ooooooooool03Oooool001Sooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05?ooooo00Coo`00oooooooo
ooooo`007_ooool01?oo003ooooooooooooo001Eooooo`03o`000?oooooooooo00gooooo000Ioooo
o`;o00001Oooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05?ooooo00Goo`00ooooooooooooooooool0
000Mooooo`04ool00?ooooooooooool005Gooooo00?o0000ooooooooool03Oooool0023ooooo00?o
0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool0
9_ooool2o`0005?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Jooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool0D_ooool00ol0003oooooooooo`0=ooooo`008?oo
ool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo05;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0Iooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0D_ooool00ol0003ooooo
ooooo`0=ooooo`008?ooool2o`0003kooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0looooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0D_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo01Wooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Aooooo`03o`00
0?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo03gooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0D_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`1Aooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo03gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
DOooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`1Aooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oo
oooooooo03gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0DOooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Sooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo
000Pooooo`03o`000?oooooooooo03gooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0looooo`03o`00
0?oooooooooo02Kooooo0_l0001Booooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
6?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool0
3Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Aooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool06?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo053ooooo
00?o0000ooooooooool03Oooool0023ooooo0_l0000nooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03cooooo0ooo000Booooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00oooooo1?oo000mooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oo
oooooooo03gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0>oooool00ooo003oooooooooo`02ool0013ooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
3oooool01?oo003ooooooooooooo000mooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`00
0?oooooooooo03gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00ko
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03[o
oooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Tooooo`Co
o`004_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00gooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool03Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo0ooo000Vooooo`03
o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo03gooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0looooo`03o`000?oooooooooo02Kooooo0_l0000=ooooo`Coo`004oooool01?oo003o
ooooooooooooool2ool0017ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0=oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`07oooo
o`03ool00?oooooooooo00cooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0?oooo
o`04ool00?ooooooooooooooo`;oo`004_ooool4ool000kooooo00?o0000ooooooooool03Oooool0
023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0;ooooo`;oo`000oooool2ool0013ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool03?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo01Kooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool03Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00oooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000Poooo
o`;o0000?_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03Oooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool05_ooool0
0ooo003oooooooooo`07ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool03Oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool03Oooool0
023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000
ooooooooool07oooool2o`0000Gooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0;
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0;
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0:
ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo03gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0looooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool02ooo
ool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01ooo
ool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool05Ooo
ool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01ooo
ool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02ooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool03Ooo
ool0023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o
0000ooooooooool07_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Sooooo
00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Sooooo
00?oo`00ooooooooool02Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00[ooooo
00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00Oooooo
00?oo`00ooooooooool02oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00[ooooo
00?oo`00ooooooooool01oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Oooooo
00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003ooooooooo
o`0mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Nooooo`04o`00
0?ooooooooooo`0000Cooooo0_l00009ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool02_ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooooooo
ool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool05Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooooooo
ool02Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooooooo
ool02Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Oooooo0_l0000?ooooo`00
8?ooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003o
ooooooooo`0Nooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01oooool00ooo
003oooooooooo`0:ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02_ooool00ooo
003oooooooooo`08ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02?ooool00ooo
003oooooooooo`09ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02?ooool00ooo
003oooooooooo`09ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02_ooool00ooo
003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo000Pooooo`;o0000?_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo03cooooo00?o0000ooooooooool07_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0:
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0D
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0:
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`0=
ooooo`008?ooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool0
0ol0003oooooooooo`0Oooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooo
oooo00cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`07ooooo`03ool00?oooooo
oooo00Wooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`09ooooo`03ool00?oooooo
oooo00Sooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooo
oooo00Kooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05
ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0=
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0:
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0>
ooooo`;oo`001_ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`0moooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00?ooooo0_oo000Booooo`;oo`000_ooool2ool0017ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool02oooool0
0ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03_ooool2
ool000?ooooo00?oo`00ooooooooool04?ooool2ool000Gooooo00?o0000ooooooooool03Oooool0
00gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo
03gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo02Kooooo0_l00003
ooooo`;oo`005?ooool4ool001?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0C
ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0>
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04?ooool4ool001Cooooo0_oo0004
ooooo`03o`000?oooooooooo00gooooo000<ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03gooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0;oooool2ool00003oooo
oooo003oo`00017ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0;ooooo`03ool0
0?oooooooooo01?ooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00oooooo0_oo0002ooooo`03ool00?oooooooooo02oooooo00?o0000ooooooooool0
3Oooool000cooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`;o0000
?_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo03_ooooo0_l0000Xooooo`03o`000?oooooooooo033o
oooo0ooo000Booooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool03?ooool00ooo003o
ooooooooo`0Cooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`0@ooooo`?oo`00<_ooool00ol0003oooooooooo`0=ooooo`003?ooool01?l0003ooooo
ooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`16oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Coooo
o`03ool00?oooooooooo00cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`15oooo
o`03o`000?oooooooooo00gooooo000<ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005oooo
o`03o`000?oooooooooo03gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0A_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00gooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool0AOooool00ol0003oooooooooo`0=ooooo`003?ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`17ooooo`05ool00?oooooooooooooooooo00003oooool00ooo003oooooooooo`0Booooo`03ool0
0?oooooooooo00gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`16ooooo`03o`00
0?oooooooooo00gooooo000=ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool0?Ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool2o`0004Sooooo
00Coo`00ooooooooooooo`004?ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00ko
oooo00Coo`00ooooooooooooo`00BOooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003o
ooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo04Sooooo0ooo000@ooooo`03ool00?oooooooooo01;ooooo00?oo`00oooo
ooooool03oooool3ool004Wooooo00?o0000ooooooooool03Oooool0023ooooo0_l0000nooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
05cooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`1Kooooo`03o`000?oooooooooo
00gooooo000Pooooo`03o`000?oooooooooo03gooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0loooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0G?ooool00ooo003oooooooooo`0Aoooo
o`03ool00?oooooooooo05_ooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000oooooooo
ool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`1Looooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Foooool00ol0
003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05cooooo00?oo`00oooo
ooooool04Oooool00ooo003oooooooooo`1Kooooo`03o`000?oooooooooo00gooooo000Pooooo`03
o`000?oooooooooo03gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo
02Kooooo0_l0001Mooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Foooool00ol0
003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05cooooo00?oo`00oooo
ooooool04Oooool00ooo003oooooooooo`1Kooooo`03o`000?oooooooooo00gooooo000Pooooo`;o
0000?_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`1Looooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0Foooool00ol0
003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05cooooo00?oo`00oooo
ooooool04Oooool00ooo003oooooooooo`1Kooooo`03o`000?oooooooooo00gooooo000Pooooo`03
o`000?oooooooooo03gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0G?ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo
05_ooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Loooo
o`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0G?ooool00ol0003oooooooooo`0=oooo
o`008?ooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0
003oooooooooo`0Vooooo`;o0000GOooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo
05cooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo03cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Moooo
o`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0G?ooool00ol0003oooooooooo`0=oooo
o`008?ooool2o`0003kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0looooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo
05cooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo03cooooo00?o0000ooooooooool07_ooool3o`0000Gooooo00?o0000oooo
ooooool0GOooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo05cooooo00?o0000oooo
ooooool03Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
03cooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0GOooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo05cooooo00?o0000
ooooooooool03Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`;o0000G_ooool0
0ooo003oooooooooo`0?ooooo`03ool00?oooooooooo05_ooooo0_l0000?ooooo`008?ooool00ol0
003oooooooooo`0mooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`0?
ooooo`03ool00?oooooooooo05cooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000oooo
ooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000ooooooooool07Oooool4
o`0000Gooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`0?ooooo`03ool00?oooooo
oooo05cooooo00?o0000ooooooooool03Oooool0023ooooo0_l0000nooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0??ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0GOooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo05cooooo00?o0000
ooooooooool03Oooool0023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo03cooooo00?o0000ooooooooool07Oooool5o`0000Cooooo00?o0000ooooooooool0GOooool0
0ooo003oooooooooo`0?ooooo`03ool00?oooooooooo05cooooo00?o0000ooooooooool03Oooool0
023ooooo00?o0000ooooooooool0?Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo03cooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`1Mooooo`03ool00?oooooooooo00oooooo00?oo`00
ooooooooool0G?ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`0moooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0Vooooo`;o0000G_ooool0
0ooo003oooooooooo`0?ooooo`03ool00?oooooooooo05cooooo00?o0000ooooooooool03Oooool0
01Sooooo0ol00005ooooo`03o`000?oooooooooo03gooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0l
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`0>
ooooo`03ool00?oooooooooo05gooooo00?o0000ooooooooool03Oooool001Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0looooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`?o003o0_ooool3o`00o`;ooooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003o0_ooool3
o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3
o`00o`;ooooo0ol00?l2ooooo`?o003o?Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo05gooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`1Mooooo`03o`000?oooooo
oooo00gooooo000Iooooo`03o`000?oooooooooo00Cooooo0_l0000mooooo`?o003o0_ooool3o`00
o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l01?oooooo003oo`00ool00?l2
ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2
ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o??ooool2o`0002Sooooo00?o0000
ooooooooool0G_ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo05gooooo00?o0000
ooooooooool03Oooool001Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0loooo
o`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l01?oo
oooo003oo`00ool00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3
o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o?Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05kooooo00?oo`00ooooooooool03Oooool0
0ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00gooooo000Iooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
05kooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo
00gooooo000Hooooo`;o00001_ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Ko
oooo0_l0001Oooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0GOooool00ol0003o
ooooooooo`0=ooooo`006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Nooooo`03ool00?oooooooooo00gooooo
00?oo`00ooooooooool0GOooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0G_ooool00ooo003ooooooooo
o`0=ooooo`03ool00?oooooooooo05gooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05kooooo00?oo`00
ooooooooool03Oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00gooooo000Poooo
o`;o0000c?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05kooooo00?oo`00oooo
ooooool03Oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00gooooo000Pooooo`03
o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Nooooo`03
ool00?oooooooooo00cooooo00?oo`00ooooooooool0G_ooool00ol0003oooooooooo`0=ooooo`00
8?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo0_l0001Oooooo`03ool0
0?oooooooooo00cooooo00?oo`00ooooooooool0G_ooool00ol0003oooooooooo`0=ooooo`008?oo
ool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0G_oo
ool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo05kooooo00?o0000ooooooooool03Ooo
ool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo05kooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooo
oooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`1Nooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0G_ooool00ol0
003oooooooooo`0=ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`1Oooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0G_ooool00ol0003o
ooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0Goooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo05kooooo
00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003ooooooooo
o`0Vooooo`;o0000H?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo05kooooo00?o
0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo05oooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`1O
ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1Oooooo`03ool00?oooooooooo00[ooooo00?oo`00oooo
ooooool0Goooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0Goooool00ooo003oooooooooo`0:ooooo`03
ool00?oooooooooo05oooooo00?o0000ooooooooool03Oooool0023ooooo0_l0003<ooooo`03o`00
0?oooooooooo01Sooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`1Oooooo`03ool0
0?oooooooooo00[ooooo00?oo`00ooooooooool0Goooool00ol0003oooooooooo`0=ooooo`008?oo
ool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05oooooo00?oo`00ooooooooool0
2_ooool00ooo003oooooooooo`1Oooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oo
oooooooo0<_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Cooooo0_l0001Pooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0
G_ooool2o`0000oooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
Goooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo05oooooo00?o0000ooooooooool0
3Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Oooooo`03ool0
0?oooooooooo00[ooooo00?oo`00ooooooooool0Goooool00ol0003oooooooooo`0=ooooo`008?oo
ool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01Sooooo0_l00004ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0Goooool00ooo003oooooooooo`0:ooooo`03ool0
0?oooooooooo05oooooo00?o0000ooooooooool03Oooool0023ooooo0_l0003<ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool0Gooo
ool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo063ooooo00?o0000ooooooooool03Ooo
ool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo063ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`1Pooooo`03o`000?oooooo
oooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool2o`00
067ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`1Pooooo`03o`000?oooooooooo
00gooooo000<ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0H?ooool00ooo003o
ooooooooo`08ooooo`03ool00?oooooooooo063ooooo00?o0000ooooooooool03Oooool000gooooo
00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo063ooooo00?oo`00oooooooo
ool02?ooool00ooo003oooooooooo`1Pooooo`03o`000?oooooooooo00gooooo000=ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3;ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0H?ooool00ooo003oooooooooo`08ooooo`03ool0
0?oooooooooo063ooooo00?o0000ooooooooool03Oooool000gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`;o0000boooool2o`0002Sooooo00?o0000ooooooooool0H?oo
ool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo063ooooo00?o0000ooooooooool03Ooo
ool000gooooo00?o0000ooooooooool01oooool4o`0000Gooooo00?o0000ooooooooool0boooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo063ooooo00?oo`00ooooooooool02?ooool0
0ooo003oooooooooo`1Pooooo`03o`000?oooooooooo00gooooo000<ooooo`;o00002Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool2o`00
067ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`1Pooooo`03o`000?oooooooooo
00gooooo000=ooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo0<_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Pooooo`03ool00?oooooooooo00Oo
oooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003ooooo
ooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0H?ooool00ooo003ooooo
ooooo`07ooooo`03ool00?oooooooooo067ooooo00?o0000ooooooooool03Oooool0023ooooo00?o
0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo063ooooo00?o
o`00ooooooooool01oooool00ooo003oooooooooo`1Qooooo`03o`000?oooooooooo00gooooo000P
ooooo`;o0000c?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo067ooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`1Qooooo`03o`000?oooooooooo00gooooo000Poooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Qoooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0=oooo
o`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo0_l0001Rooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0=ooooo`00
8?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
HOooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo067ooooo00?o0000ooooooooool0
3Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo067ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`1Qooooo`03o`000?oo
oooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1Qooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0HOooool0
0ol0003oooooooooo`0=ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`1Qooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0HOooool00ol0
003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0HOooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo06;o
oooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003ooooo
ooooo`0Vooooo`;o0000H_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo06;ooooo
00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`1Rooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool0H_ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo01Sooooo0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`1Roooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0H_ooool00ol0003oooooooooo`0=oooo
o`008?ooool2o`000<cooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool0H_ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`1Rooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
0_l0001Sooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0HOooool2o`0000oooooo
000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool06Oooool01?l0003ooooooooo
ooooool4o`0000Gooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo06?ooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0booo
ool00ol0003oooooooooo`0Hooooo`;o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo06?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1Sooooo`03o`000?oo
oooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool06Oooool0
1?l0003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool0Hoooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo06?ooooo00?o0000ooooooooool03Oooool0023ooooo0_l0003<
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Hoooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo06?ooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000oooo
ooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06?ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`1Sooooo`03o`000?oooooooooo00gooooo000Pooooo`03
o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool2o`0006Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`1Sooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`00
0?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Tooooo`05ool0
0?oooooooooooooooooo0000IOooool00ol0003oooooooooo`0=ooooo`005oooool5o`0000Cooooo
00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06Cooooo
00Coo`00ooooooooooooo`00I_ooool00ol0003oooooooooo`0=ooooo`006?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`1Tooooo`04ool00?ooooooooooool006Kooooo00?o0000ooooooooool03Oooool001Wo
oooo00?o0000ooooooooool01?ooool2o`000<_ooooo0_l0000Xooooo`03o`000?oooooooooo06Co
oooo00Coo`00ooooooooooooo`00I_ooool00ol0003oooooooooo`0=ooooo`006_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`1Uooooo`?oo`00I_ooool00ol0003oooooooooo`0=ooooo`005oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Xooooo`;o0000I_ooool2ool0
06Oooooo00?o0000ooooooooool03Oooool001Oooooo00Go0000ooooooooooooooooo`000004oooo
oloo0000:?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo00gooooo000Hooooo`?o
0000o?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00003oooool00?oooooo6?oooooBo`0000oooooo003oooooooWooooo003oooooooWooooo
003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo
003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo
003oooooooWooooo003oooooooWooooo000Rooooo`Go00000oooool2o`0002Sooooo0ol00004oooo
o`;o0000:Oooool2o`0002_ooooo0ol00004ooooo`;o0000:?ooool5o`0000?ooooo0_l0000coooo
o`?o00007?ooool5o`0001cooooo0ol0000Kooooo`;o00007?ooool3o`0001cooooo1Ol0000Loooo
o`?o00006?ooool002?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000X
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`00037ooooo00Go0000ooooooooooooooooo`00
000Looooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool06Oooool01?l0003ooooo
ooooool0000Looooo`03o`000?oooooooooo01cooooo00Co0000oooooooooooo00006oooool01Ol0
003ooooooooooooooooo000001Oooooo000Looooo`Go00000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`00023ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00009oooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02_ooooo1Ol00005ooooo`03o`000?oooooooooo01?ooooo1Ol00003ooooo`03o`000?oooooooooo
01Gooooo1Ol00003ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00007?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05Oooool0
02Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`0002_ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Zooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`0aooooo`;o00007oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01cooooo0_l0000Hooooo`008_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0002Oooooo00Co0000oooooooooooo0000:oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0003Gooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000001gooooo
00?o0000ooooooooool06Oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo01_o
oooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo01Gooooo000Rooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Wooooo`;o00001?ooool0
1?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`0002[ooooo0_l00004ooooo`04o`00
0?ooooooooooo`0002Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`00037ooooo00Go0000ooooooooooooooooo`00000Kooooo`05o`000?ooooooooooooooool00000
7?ooool2o`0001_ooooo00Co0000oooooooooooo00006oooool2o`0001gooooo00Go0000oooooooo
ooooooooo`00000Kooooo`05o`000?ooooooooooooooool000005oooool002?ooooo0ol00004oooo
o`;o0000:Oooool00ol0003oooooooooo`03ooooo`;o0000:Oooool2o`0002cooooo00?o0000oooo
ooooool00oooool2o`0002Wooooo0ol00004ooooo`;o0000<oooool3o`0001gooooo0ol0000Noooo
o`03o`000?oooooooooo01[ooooo0_l0000Mooooo`03o`000?oooooooooo01cooooo0ol0000Moooo
o`?o00006?ooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
01Wooooo0_l00005oooooloo0000:?oooooBo`0000oooooo000Hooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`00000Oooooo`Go00001?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool001Sooooo00Co0000oooo
oooooooo00001?ooool01?l0003oooooooooooooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_oo
ool3o`00o`;ooooo0ol00?l2ooooo`?o003o00Coooooo`00ool00?oo003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o;_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`04oooo
ool00?oo003oo`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o
003o0_ooool00ol0003oooooooooo`0Nooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0c_ooool00ol0003oooooooooo`0=ooooo`006?ooool01?l0003oooooooooool00004oooo
o`Co00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00
o`04o`000?l00?oo003oo`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2
o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`?o000000?o003o
o`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00Co000000?o003oo`000?l000000_l0
00000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000?o003oo`000?l000000_l0
00000ol00?oo0000o`000002o`000004o`00ool0003o0000o`0000?o003o0_l00003o`00o`;o0000
0ol00?l2o`0000?o003o00Co0000o`00ool00?oo003o0_l00003o`00o`;o00000ol00?l2o`0000?o
003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o
003o0_l00003o`00o`;o00000ol00?l3o`0001Wooooo1Ol00003ooooo`03o`000?oooooooooo00Co
oooo0_l00015ooooo`Goo`00>oooool4ool004Gooooo0_l0000?ooooo`006?ooool01?l0003ooooo
ooooool00004ooooo`04o`000?ooooooooooooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`?o003o0_ooool3o`00o`;ooooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003o0_ooool3
o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3
o`00o`;ooooo0ol00?l3ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ooooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`04ooooool00?oo003oo`00o`;o
oooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;o
oooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A?ooool01?oo003o
ooooooooooooool2ool003Wooooo00Coo`00oooooooooooooooo0_oo0015ooooo`03o`000?oooooo
oooo00gooooo000Hooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0DOooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0003ooooooooo
o`0Mooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`13ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool0=_ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo04;ooooo00?o0000ooooooooool03Oooool001Wooooo0_l00005ooooo`03o`000?oo
oooooooo057ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo
00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0@_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo03Kooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`12ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`00
0?oooooooooo057ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053o
oooo00?o0000ooooooooool07_ooool3o`0000Gooooo00?o0000ooooooooool0@_ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo03Kooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`11ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo057ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`11ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool0=?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo047ooooo00?o0000oooooooo
ool03Oooool0023ooooo0_l0001Booooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo0_l00012ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool0=?ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo043o
oooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0DOooool00ol00?oooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo043ooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0booooo`03
ool00?oooooooooo00Sooooo00?oo`00ooooooooool0@?ooool00ol0003oooooooooo`0=ooooo`00
8?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0@?ooool00ooo003o
ooooooooo`08ooooo`03ool00?oooooooooo03;ooooo00?oo`00ooooooooool02Oooool00ooo003o
ooooooooo`0oooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo057ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`10ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooooooo
ool0<?ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo03oooooo00?o0000oooooooo
ool03Oooool0023ooooo00?o0000ooooooooool0DOooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03oo
oooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0`ooooo`03ool00?oooooooooo00_o
oooo00?oo`00ooooooooool0?_ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003ooooo
ooooo`1Aooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03
o`000?oooooooooo02Kooooo0_l0000Gooooo`Koo`008oooool00ooo003oooooooooo`0;ooooo`03
ool00?oooooooooo02oooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Pooooo`Oo
o`005oooool00ol0003oooooooooo`0=ooooo`008?ooool2o`0005;ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo0_oo000Qooooo`03ool00?oooooooooo00co
oooo00?oo`00ooooooooool0;_ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo01ko
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00go
oooo000Pooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Dooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0=ooooo`03
ool00?oooooooooo02kooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Mooooo`03
ool00?oooooooooo00Kooooo0_oo000Eooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`00
0?oooooooooo057ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo00So
oooo00?oo`00ooooooooool07?ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo02go
oooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Looooo`03ool00?oooooooooo00So
oooo00?oo`00ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003ooooo
ooooo`1Aooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`09ooooo`03
ool00?oooooooooo01[ooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0]ooooo`03
ool00?oooooooooo00kooooo00?oo`00ooooooooool06oooool00ooo003oooooooooo`0:ooooo`03
ool00?oooooooooo017ooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0
DOooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool02oooool00ooo003o
ooooooooo`0Iooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0;?ooool00ooo003o
ooooooooo`0?ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool02_ooool00ooo003o
ooooooooo`0Aooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo057ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000oooooooo
ool09_ooool2o`0001;ooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Hooooo`03
ool00?oooooooooo013ooooo00?oo`00ooooooooool0;?ooool00ooo003oooooooooo`0@ooooo`03
ool00?oooooooooo01Wooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0@ooooo`03
o`000?oooooooooo00gooooo000Pooooo`;o0000D_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013o
oooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool0:oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01So
oooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo00go
oooo000Pooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03
ool00?oooooooooo00oooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Aooooo`03
ool00?oooooooooo02_ooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0Hooooo`03
ool00?oooooooooo00kooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0=ooooo`00
8?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1@ooooo`03o`000?oooooooooo01oooooo0_l00005ooooo`03o`000?oooooooooo00ko
oooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo01;o
oooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01Ko
oooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo000Pooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo053ooooo00?o0000ooooooooool07_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00kooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`0Boooo
o`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0>oooo
o`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo057ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool07_ooool01?l0
003oooooooooool00004ooooo`;o00003_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooo
oooo01Gooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooo
oooo01;ooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooo
oooo00cooooo0_l0000?ooooo`008?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo01kooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo01?ooooo00?o
o`00ooooooooool04oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo02Wooooo00?o
o`00ooooooooool04oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Cooooo00?o
o`00ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`008?ooool2o`0005;ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool07_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0
5?ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0
:?ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool0
5?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oo
oooooooo057ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo
00?o0000ooooooooool07_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00_o
oooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo01Co
oooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00go
oooo000Pooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo053ooooo00?o0000ooooooooool07oooool2o`0000Gooooo00?o0000oooooooo
ool02oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo013ooooo00?oo`00oooooooo
ool05Oooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo01Gooooo00?oo`00oooooooo
ool04Oooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo00_ooooo00?o0000oooooooo
ool03Oooool0023ooooo00?o0000ooooooooool0DOooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00[o
oooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01Ko
oooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo013o
oooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00go
oooo000=ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooo
ooooo`1Aooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03
o`000?oooooooooo02Kooooo0_l0000;ooooo`03ool00?oooooooooo01Wooooo00?oo`00oooooooo
ool03_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo02Oooooo00?oo`00oooooooo
ool05_ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo01Wooooo00?oo`00oooooooo
ool02Oooool00ol0003oooooooooo`0=ooooo`003?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool02Oooool00ooo003oooooooooo`0Jooooo`03ool00?oooooooooo00kooooo00?oo`00
ooooooooool05oooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo01Oooooo00?oo`00
ooooooooool03_ooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo00Sooooo00?o0000
ooooooooool03Oooool000cooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02
ooooo`;o0000D_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Cooo
ool2o`0002Sooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`0Looooo`03ool00?oo
oooooooo00cooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Vooooo`03ool00?oo
oooooooo01Sooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Mooooo`03ool00?oo
oooooooo00Oooooo00?o0000ooooooooool03Oooool000cooooo00Co0000oooooooooooo00002ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`07ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool02oooool00ooo003ooooo
ooooo`0Hooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool06?ooool00ooo003ooooo
ooooo`0<ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool01oooool00ol0003ooooo
ooooo`0=ooooo`003?ooool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0003ooooo
ooooo`1Aooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0Oooooo`03
ool00?oooooooooo00[ooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`0Uooooo`03
ool00?oooooooooo01Wooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Oooooo`;o
o`001oooool00ol0003oooooooooo`0=ooooo`003?ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0DOooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00?ooooo0ooo000Sooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool06oooool00ooo
003oooooooooo`0Uooooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`0Rooooo`;oo`001Oooool00ol0003oooooooooo`0=ooooo`003Oooool2o`0000So
oooo1Ol00004ooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo053ooooo00?o0000ooooooooool09_ooool2o`0000?ooooo0_oo000Voooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool06oooool00ooo003oooooooooo`0Uoooo
o`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0Toooo
o`;oo`001?ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`1Aooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0:oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
01cooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`0Looooo`;oo`001oooool00ooo
003oooooooooo`0Zooooo`03o`000?oooooooooo00gooooo000Pooooo`;o0000D_ooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo02cooooo0_oo0003ooooo`;oo`007oooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo01kooooo00?oo`00ooooooooool00_ooool2ool002gooooo00?o0000oooo
ooooool03Oooool0023ooooo00?o0000ooooooooool0DOooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02gooooo1Ooo000Pooooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool07oooool4ool0
02oooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0DOooool00ol00?oo
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo05?ooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`1Boooo
o`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo057ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool09_ooool2o`00
05Cooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`1Booooo`03o`000?oooooooooo
00gooooo000Pooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool01Ol00?oo
oooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Coooo
o`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool0D_ooool00ol0003oooooooooo`0=oooo
o`008?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Doooool00ooo
003oooooooooo`0Rooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool03Oooool0023o
oooo0_l0001Booooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1@oooo
o`03o`000?oooooooooo01gooooo1Ol00004ooooo`03o`000?oooooooooo05?ooooo00?oo`00oooo
ooooool08_ooool00ooo003oooooooooo`1Cooooo`03o`000?oooooooooo00gooooo000Pooooo`03
o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
053ooooo00?o0000ooooooooool07_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo05?ooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`1Cooooo`03o`000?oooooo
oooo00gooooo000Pooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05?ooooo00?oo`00ooooooooool08_ooool00ooo003oooooooooo`1C
ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo057ooooo00?o003ooooo
ooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`03ooooo`;o0000EOooool00ooo003oooooooooo`0Qooooo`03ool00?oooooo
oooo05;ooooo0_l0000?ooooo`008?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo
00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05Cooooo00?oo`00ooooooooool08Ooo
ool00ooo003oooooooooo`1Cooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooo
oooo057ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o
0000ooooooooool07Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
E?ooool00ooo003oooooooooo`0Qooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool0
3Oooool0023ooooo0_l0001Booooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1@ooooo`03o`000?oooooooooo01kooooo0ol00005ooooo`03o`000?oooooooooo05Cooooo
00?oo`00ooooooooool08?ooool00ooo003oooooooooo`1Dooooo`03o`000?oooooooooo00gooooo
000Pooooo`03o`000?oooooooooo057ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Dooooo`03ool0
0?oooooooooo023ooooo00?oo`00ooooooooool0E?ooool00ol0003oooooooooo`0=ooooo`008?oo
ool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1@ooooo`03o`000?oooooooooo02Kooooo0_l0001Eooooo`03ool00?oooooooooo023ooooo
00?oo`00ooooooooool0E?ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003ooooooooo
o`1Aooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1@ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0EOooool00ooo003oooooooooo`0Oooooo`03ool0
0?oooooooooo05Cooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0DOoo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0D?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo05Gooooo00?oo`00ooooooooool07oooool00ooo003ooooo
ooooo`1Dooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo057ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`1Eooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool0
E?ooool00ol0003oooooooooo`0=ooooo`008?ooool2o`0005;ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`1Eooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool0EOooool00ol0003ooooo
ooooo`0=ooooo`008?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
EOooool00ooo003oooooooooo`0Nooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool0
3Oooool0023ooooo00?o0000ooooooooool0DOooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`;o0000E_ooool00ooo003ooooo
ooooo`0Nooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool03Oooool0023ooooo00?o
0000ooooooooool0DOooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool0
7Oooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo00gooooo000Hooooo`?o00001Ooo
ool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool00ooo003ooooo
ooooo`0Mooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool03Oooool001Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo00;ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
E_ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool0
3Oooool001Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1@ooooo`?o003o0_oo
ool3o`00o`04ooooool00?oo003oo`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00oe7ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`1Fooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool0E_ooool00ol0003ooooo
ooooo`0=ooooo`006Oooool00ol0003oooooooooo`04ooooo`;o0000DOooool3o`00o`;ooooo0ol0
0?l01?oooooo003oo`00ool00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o
0_ooool3o`00o`;ooooo0ol00?m@ooooo`;o0000:?ooool00ol0003oooooooooo`1Fooooo`03ool0
0?oooooooooo01cooooo00?oo`00ooooooooool0E_ooool00ol0003oooooooooo`0=ooooo`006Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo053ooooo0ol00?l2ooooo`?o003o00Co
ooooo`00ool00?oo003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003oDOooool00ol0003oooooooooo`0Vooooo`;o0000Eoooool00ooo003ooooo
ooooo`0Looooo`03ool00?oooooooooo05Kooooo00?o0000ooooooooool03Oooool001Sooooo0_l0
0006ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`1Fooooo`03ool00?oooooooooo01cooooo00?oo`00ooooooooool0E_ooool00ol0003ooooooooo
o`0=ooooo`006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<_ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`1Gooooo`03ool00?oooooooooo01_ooooo00?oo`00
ooooooooool0E_ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo01oooooo0ol00004ooooo`03o`000?oooooooooo05Oooooo00?oo`00oooo
ooooool06_ooool00ooo003oooooooooo`1Gooooo`03o`000?oooooooooo00gooooo000Pooooo`03
o`000?oooooooooo0<_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05Oooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`1Gooooo`03
o`000?oooooooooo00gooooo000Pooooo`;o0000c?ooool00ol0003oooooooooo`0Mooooo`Go0000
1?ooool2o`0005Sooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`1Fooooo`;o0000
3oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Mooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool0Eoooool00ooo003oooooooooo`0Jooooo`03ool0
0?oooooooooo05Oooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0booo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0Eooo
ool00ooo003oooooooooo`0Jooooo`03ool00?oooooooooo05Oooooo00?o0000ooooooooool03Ooo
ool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Oooooo`;o00001Oooool0
0ol0003oooooooooo`1Hooooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool0Eoooool0
0ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Hooooo`03ool00?oooooooooo
01Sooooo00?oo`00ooooooooool0F?ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0F?ooool00ooo003o
ooooooooo`0Hooooo`03ool00?oooooooooo05Sooooo00?o0000ooooooooool03Oooool0023ooooo
0_l0003<ooooo`03o`000?oooooooooo02Kooooo0_l0001Iooooo`03ool00?oooooooooo01Sooooo
00?oo`00ooooooooool0F?ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0F?ooool00ooo003ooooooooo
o`0Hooooo`03ool00?oooooooooo05Sooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Sooooo00?oo`00
ooooooooool06?ooool00ooo003oooooooooo`1Hooooo`03o`000?oooooooooo00gooooo000Poooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Hoooo
o`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool0FOooool00ol0003oooooooooo`0=oooo
o`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0FOooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo05Wooooo00?o0000oooooooo
ool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`;o0000
F_ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo05Wooooo00?o0000ooooooooool0
3Oooool0023ooooo0_l0003<ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0FOoo
ool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo05Wooooo00?o0000ooooooooool03Ooo
ool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo05Wooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`1Iooooo`03o`000?oooooo
oooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`1Iooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool0F_ooool00ol0
003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0FOooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo05[o
oooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo05[ooooo00?oo`00ooooooooool05?ooool00ooo003ooooo
ooooo`1Jooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o
0000ooooooooool09_ooool2o`0005_ooooo00?oo`00ooooooooool05?ooool00ooo003ooooooooo
o`1Jooooo`03o`000?oooooooooo00gooooo000Pooooo`;o0000c?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo05[ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`1J
ooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`1Jooooo`03ool00?oooooooooo01Cooooo00?oo`00oooo
ooooool0F_ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo01kooooo0ol00005ooooo`03o`000?oooooooooo05[ooooo00?oo`00oooooooo
ool04oooool00ooo003oooooooooo`1Kooooo`03o`000?oooooooooo00gooooo000<ooooo`?o0000
1?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`3;ooooo`03o`00
0?oooooooooo01gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05_o
oooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`1Kooooo`03o`000?oooooooooo00go
oooo000=ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo0<_ooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo0000
00Cooooo0_l0001Looooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0F_ooool2o`00
00oooooo000=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo01gooooo1?l00005ooooo`03o`000?oooooooooo05_o
oooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`1Kooooo`03o`000?oooooooooo00go
oooo000=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool2o`000<_ooooo
0_l0000Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Foooool00ooo003ooooo
ooooo`0Booooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool03Oooool000gooooo00?o
0000ooooooooool01oooool4o`0000Gooooo00?o0000ooooooooool0boooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Foooool00ooo003ooooooooo
o`0Aooooo`03ool00?oooooooooo05cooooo00?o0000ooooooooool03Oooool000cooooo0_l00009
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0O
ooooo`;o00001Oooool00ol0003oooooooooo`1Kooooo`03ool00?oooooooooo017ooooo00?oo`00
ooooooooool0G?ooool00ol0003oooooooooo`0=ooooo`003Oooool00ol0003oooooooooo`07oooo
o`Go00001?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0G?ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo05cooooo00?o0000oooo
ooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`;o
0000GOooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo05cooooo00?o0000oooooooo
ool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo05cooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`1Looooo`03o`00
0?oooooooooo00gooooo000Pooooo`;o0000c?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo05cooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`1Looooo`03o`000?oo
oooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1Looooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0GOooool0
0ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo
05gooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool0boooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo05gooooo00?oo`00ooooooooool03_ooool00ooo003o
ooooooooo`1Mooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool09_ooool2o`0005kooooo00?oo`00ooooooooool03_ooool00ooo003ooooo
ooooo`1Mooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`1Mooooo`03ool00?oooooooooo00kooooo00?o
o`00ooooooooool0GOooool00ol0003oooooooooo`0=ooooo`008?ooool2o`000<cooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`1Mooooo`03ool00?oooooooooo00gooooo00?oo`00
ooooooooool0G_ooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0G_ooool00ooo003oooooooooo`0<oooo
o`03ool00?oooooooooo05kooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05kooooo00?oo`00oooooooo
ool03?ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`00
0?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool2o`0005oooooo00?oo`00ooooooooool0
3?ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oo
oooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Nooooo`03ool00?oo
oooooooo00cooooo00?oo`00ooooooooool0G_ooool00ol0003oooooooooo`0=ooooo`008?ooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0G_ooool0
0ooo003oooooooooo`0;ooooo`03ool00?oooooooooo05oooooo00?o0000ooooooooool03Oooool0
023ooooo0_l0003<ooooo`03o`000?oooooooooo01kooooo0ol00005ooooo`03o`000?oooooooooo
05oooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`1Oooooo`03o`000?oooooooooo
00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool07Oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0Goooool00ooo003oooooooooo`0:oooo
o`03ool00?oooooooooo05oooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`1Oooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0H?ooool00ol0
003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01ko
oooo0ol00005ooooo`;o0000HOooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo05oo
oooo0_l0000?ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01gooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo063ooooo00?oo`00oooooooo
ool02?ooool00ooo003oooooooooo`1Pooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`00
0?oooooooooo0<_ooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool0H?ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo063o
oooo00?o0000ooooooooool03Oooool0023ooooo0_l0003<ooooo`03o`000?oooooooooo01kooooo
0ol00005ooooo`03o`000?oooooooooo067ooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`1Qooooo`03o`000?oooooooooo00gooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`1Qooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool0HOooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo02Kooooo0_l0001Rooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool0HOooool00ol0003oooooooooo`0=ooooo`008?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo06;ooooo00?o0000ooooooooool03Oooool001Oooooo1Ol00004ooooo`03
o`000?oooooooooo0<_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Rooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool0H_ooool00ol0003oooooooooo`0=ooooo`00
6?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1Sooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool0Hoooool00ol0003oooooooooo`0=ooooo`006Oooool00ol0003oooooooooo`04ooooo`;o0000
boooool2o`0002Sooooo00?o0000ooooooooool0Hoooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo06?ooooo00?o0000ooooooooool03Oooool001[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0I?oo
ool01?oo003ooooooooooooo001Vooooo`03o`000?oooooooooo00gooooo000Gooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo
00Go0000ooooooooooooooooo`00000Xooooo`;o0000I_ooool3ool006Kooooo00?o0000oooooooo
ool03Oooool001Oooooo00Go0000ooooooooooooooooo`000004oooooloo0000:?ooool00ol0003o
ooooooooo`3>ooooo`03o`000?oooooooooo00gooooo000Hooooo`?o0000o?ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00003oooool00?oo
oooo6?oooooBo`0000oooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003ooooo
ooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003ooooo
ooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003ooooo
ooWooooo000Rooooo`Go00000oooool2o`0002Sooooo0ol00004ooooo`;o0000:Oooool2o`0002_o
oooo0ol00004ooooo`;o0000:?ooool5o`0000?ooooo0_l0000eooooo`?o00006oooool5o`0001_o
oooo0ol0000Kooooo`;o00007?ooool3o`0001_ooooo1Ol0000Looooo`?o00006Oooool002?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00009oooool01?l0003oooooooooool0000[ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000:?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0003?ooooo00Go0000ooooooooooooooooo`00000Kooooo`04o`000?oooooo
ooooo`0001cooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool0000Looooo`03o`00
0?oooooooooo01_ooooo00Co0000oooooooooooo00006oooool01Ol0003ooooooooooooooooo0000
01Sooooo000Looooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
023ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009oooool0
1?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
:Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002gooooo1Ol00005ooooo`03
o`000?oooooooooo01;ooooo1Ol00003ooooo`03o`000?oooooooooo01Cooooo1Ol00003ooooo`03
o`000?oooooooooo01Wooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool05_ooool002Gooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Wooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000Zooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`0cooooo`;o00007_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Wo
oooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01cooooo0_l0000Iooooo`008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo0000:?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Oooooo00Co
0000oooooooooooo0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Oo
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0003Oooooo00?o0000
ooooooooool06?ooool01Ol0003ooooooooooooooooo000001cooooo00?o0000ooooooooool06Ooo
ool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo01[ooooo00Go0000oooooooooooo
ooooo`00000Oooooo`03o`000?oooooooooo01Kooooo000Rooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool0000Wooooo`;o00001?ooool01?l0003oooooooooool0000W
ooooo`04o`000?ooooooooooo`0002[ooooo0_l00004ooooo`04o`000?ooooooooooo`0002Oooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0003?ooooo00Go0000oooo
ooooooooooooo`00000Jooooo`05o`000?ooooooooooooooool000006oooool2o`0001_ooooo00Co
0000oooooooooooo00006oooool2o`0001cooooo00Go0000ooooooooooooooooo`00000Kooooo`05
o`000?ooooooooooooooool000006?ooool002?ooooo0ol00004ooooo`;o0000:Oooool00ol0003o
ooooooooo`03ooooo`;o0000:Oooool2o`0002cooooo00?o0000ooooooooool00oooool2o`0002Wo
oooo0ol00004ooooo`;o0000=Oooool3o`0001cooooo0ol0000Mooooo`03o`000?oooooooooo01[o
oooo0_l0000Mooooo`03o`000?oooooooooo01_ooooo0ol0000Mooooo`?o00006Oooool00?oooooo
nOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool001Wooooo0_l00005oooooloo
0000:Oooooo@o`00013ooooo000Hooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooo
ooooooooo`00000Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0>ooooo`006?ooool01?l0003oooooooooool00004ooooo`04o`000?oooooooooo
ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l0
1?oooooo003oo`00ool00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_oo
ool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_oo
ool3o`00oa[ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_oo
ool3o`00o`04ooooool00?oo003oo`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool03_ooool001Sooooo00Co0000oooooooooooo00001?ooool4o`0000?o003o
0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l01?l0003o003o
o`00ool00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o
00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o
000000?o003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o
000000?o003oo`000?l000000_l000001?l00?oo0000o`000?l00003o`00o`;o00000ol00?l2o`00
00?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o00Co0000o`00ool00?oo003o0_l00003
o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003
o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l3o`0002Wooooo00?o0000
ooooooooool0:Oooool7ool006_ooooo1_oo000[ooooo`03o`000?oooooooooo00kooooo000Hoooo
o`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooooooo0ol00?l2ooooo`?o003o0_oo
ool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`04ooooool00?oo003oo`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`?o003o0_ooool3o`00
o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00
o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo00?o0000ooooooooool09oooool2o`00
02Sooooo0_oo0007ooooo`03ool00?oooooooooo06Oooooo00?oo`00ooooooooool01?ooool3ool0
02Oooooo0_l0000@ooooo`006?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
05[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo
023ooooo0ol00004ooooo`03o`000?oooooooooo02Gooooo0_oo000:ooooo`03ool00?oooooooooo
06Gooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Uooooo`03o`000?oooooooooo
00kooooo000Iooooo`;o00001Oooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool09?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo06?o
oooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo00ko
oooo000Pooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1Jooooo`03o`000?oooooooooo01Wooooo1Ol00003ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool08oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo067ooooo
00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0Sooooo`03o`000?oooooooooo00kooooo
000Pooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`1Jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool2o`0002Cooooo00?o
o`00ooooooooool03_ooool00ooo003oooooooooo`1Oooooo`03ool00?oooooooooo00kooooo00?o
o`00ooooooooool08Oooool2o`00013ooooo000Pooooo`;o0000Foooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`1N
ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool08Oooool00ol0003oooooooooo`0>
ooooo`008?ooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0F_ooool00ol0003oooooooooo`0Pooooo`;o00001Oooool00ol0003oooooooooo`0Qoooo
o`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0GOooool00ooo003oooooooooo`0@oooo
o`03ool00?oooooooooo027ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooooooo
ool0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`03ooooo`;o00008_ooool00ooo003oooooooooo`0Booooo`03
ool00?oooooooooo05_ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Oooooo`;o
00004?ooool0023ooooo00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo05[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Pooooo`03ool0
0?oooooooooo01?ooooo00?oo`00ooooooooool0Foooool00ooo003oooooooooo`0Cooooo`03ool0
0?oooooooooo01oooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0F_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Oooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool0FOoo
ool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo01oooooo00?o0000ooooooooool03_oo
ool0023ooooo00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo05[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Oooooo`03ool00?oooooo
oooo01Gooooo00?oo`00ooooooooool0FOooool00ooo003oooooooooo`0Eooooo`03ool00?oooooo
oooo01kooooo00?o0000ooooooooool03_ooool0023ooooo0_l0001Kooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Wooooo`;o00007oooool00ooo
003oooooooooo`0Gooooo`03ool00?oooooooooo05Oooooo00?oo`00ooooooooool05oooool00ooo
003oooooooooo`0Looooo`;o00004?ooool0023ooooo00?o0000ooooooooool0F_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Mooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0Eoooool00ooo003o
ooooooooo`0Gooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool03_ooool0023ooooo
00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo01Wooooo
00?oo`00ooooooooool0EOooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo01cooooo
00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0F_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Looooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool0E?ooool00ooo003ooooooooo
o`0Kooooo`03ool00?oooooooooo01_ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000
ooooooooool0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000
ooooooooool09oooool2o`0001cooooo00?oo`00ooooooooool07?ooool00ooo003oooooooooo`1C
ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool06_ooool2o`00013ooooo000Poooo
o`03o`000?oooooooooo05[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Joooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06oooool00ooo003oooooooooo`0Loooo
o`03ool00?oooooooooo05;ooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0Joooo
o`03o`000?oooooooooo00kooooo000Pooooo`;o0000Foooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo05[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Jooooo`03
ool00?oooooooooo01gooooo00?oo`00ooooooooool0D_ooool00ooo003oooooooooo`0Nooooo`03
ool00?oooooooooo01Wooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0
F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool0
D?ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool0
3_ooool0023ooooo00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo05[ooooo00?o0000ooooooooool09oooool2o`0001[ooooo00?oo`00ooooooooool07ooo
ool00ooo003oooooooooo`1@ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool05ooo
ool2o`00013ooooo000Pooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06?ooool0
0ooo003oooooooooo`0Qooooo`03ool00?oooooooooo04oooooo00?oo`00ooooooooool08Oooool0
0ooo003oooooooooo`0Gooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo
05[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo
027ooooo0_l00004ooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool08Oooool00ooo
003oooooooooo`1>ooooo`03ool00?oooooooooo02;ooooo00?oo`00ooooooooool05oooool00ol0
003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo
04gooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo
00kooooo000Pooooo`;o0000Foooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[o
oooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00003ooooo`;o00005oooool00ooo
003oooooooooo`0Tooooo`03ool00?oooooooooo04cooooo00?oo`00ooooooooool09Oooool00ooo
003oooooooooo`0Dooooo`;o00004?ooool0023ooooo00?o0000ooooooooool0F_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool08?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool09?ooool00ooo
003oooooooooo`1<ooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool05Oooool00ol0
003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo
04_ooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo
00kooooo000Pooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1Jooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`0Eooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool0B_ooool00ooo
003oooooooooo`0Wooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool03_ooool000go
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo05[o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo027o
oooo0_l00004ooooo`;o00005Oooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo04[o
oooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`0Booooo`;o00004?ooool000cooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo02Wooooo00?oo`00oooo
ooooool0BOooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo01;ooooo00?o0000oooo
ooooool03_ooool000cooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02oooo
o`;o0000Foooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05Wooooo0_l0000Yoooo
o`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`18oooo
o`03ool00?oooooooooo02[ooooo00?oo`00ooooooooool04_ooool00ol0003oooooooooo`0>oooo
o`003?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo02[ooooo00?oo`00oooo
ooooool0B?ooool00ooo003oooooooooo`0[ooooo`03ool00?oooooooooo017ooooo00?o0000oooo
ooooool03_ooool000cooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo00?o0000oooo
ooooool0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000oooo
ooooool09oooool2o`0001;ooooo00?oo`00ooooooooool0;?ooool00ooo003oooooooooo`17oooo
o`03ool00?oooooooooo02cooooo00?oo`00ooooooooool03oooool2o`00013ooooo000<ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Joooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0;?ooool00ooo003oooooooooo`16oooo
o`03ool00?oooooooooo02gooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0>oooo
o`003Oooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo05[ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool04?ooool00ooo003oooooooooo`0^ooooo`03ool00?oooooooooo04Gooooo00?oo`00oooooooo
ool0;_ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`00
0?oooooooooo05[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0_ooooo`03ool0
0?oooooooooo04Gooooo00?oo`00ooooooooool0;oooool00ooo003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo000Pooooo`;o0000Foooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo05[ooooo00?o0000ooooooooool09oooool2o`0000oooooo00?oo`00ooooooooool0<?oo
ool00ooo003oooooooooo`14ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool03?oo
ool2o`00013ooooo000Pooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03Oooool0
0ooo003oooooooooo`0booooo`03ool00?oooooooooo04?ooooo00?oo`00ooooooooool0<_ooool0
0ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo
05[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0cooooo`03ool00?oooooooooo
04?ooooo00?oo`00ooooooooool0<_ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo000Pooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1Jooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool00ooo003o
ooooooooo`0dooooo`03ool00?oooooooooo04;ooooo00?oo`00ooooooooool0=?ooool00ooo003o
ooooooooo`0;ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo05[ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02Oooooo
0_l0000;ooooo`03ool00?oooooooooo03Kooooo00?oo`00ooooooooool0@Oooool00ooo003ooooo
ooooo`0eooooo`;oo`002_ooool2o`00013ooooo000Pooooo`03o`000?oooooooooo05[ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo023ooooo0ol0
0004ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0=oooool00ooo003ooooooooo
o`11ooooo`03ool00?oooooooooo03Oooooo00?oo`00ooooooooool02?ooool00ol0003ooooooooo
o`0>ooooo`008?ooool2o`0005_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1J
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`;oo`00>_ooool00ooo003oooooooooo`11ooooo`03ool00?oooooooooo03Sooooo0_oo0008
ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo05[ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`Coo`00?Oooool00ooo003oooooooooo`0ooooo
o`03ool00?oooooooooo03_ooooo0ooo0005ooooo`03o`000?oooooooooo00kooooo000Pooooo`03
o`000?oooooooooo05[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool2o`0000?ooooo0_oo0010ooooo`03
ool00?oooooooooo03oooooo00?oo`00ooooooooool0?Oooool2ool000?ooooo0_l0000@ooooo`00
8?ooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
F_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
A?ooool00ooo003oooooooooo`0oooooo`03ool00?oooooooooo04?ooooo00?o0000ooooooooool0
3_ooool0023ooooo00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo05[ooooo00?o0000ooooooooool08?ooool2o`0000Gooooo00?o0000ooooooooool0AOoo
ool00ooo003oooooooooo`0mooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool03_oo
ool0023ooooo00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo05[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`;o0000A_ooool0
0ooo003oooooooooo`0mooooo`03ool00?oooooooooo04?ooooo0_l0000@ooooo`008?ooool2o`00
05_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0AOooool00ooo003oooooooooo`0mooooo`03ool00?oooooooooo
04Cooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0F_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`16ooooo`03ool00?oooooooooo03_ooooo00?oo`00ooooooooool0AOooool00ol0003o
ooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Kooooo
00?oo`00ooooooooool0>oooool00ooo003oooooooooo`15ooooo`03o`000?oooooooooo00kooooo
000Pooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`1Jooooo`03o`000?oooooooooo02Oooooo0_l00017ooooo`03ool00?oooooooooo03_ooooo00?o
o`00ooooooooool0A?ooool2o`00013ooooo000Pooooo`03o`000?oooooooooo05[ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0Aoooool00ooo003oooooooooo`0iooooo`03ool00?oooooooooo04Kooooo00?o0000
ooooooooool03_ooool0023ooooo00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo05[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`17oooo
o`03ool00?oooooooooo03Wooooo00?oo`00ooooooooool0A_ooool00ol0003oooooooooo`0>oooo
o`008?ooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0F_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Oooooo00?oo`00oooooooo
ool0>Oooool00ooo003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo000Pooooo`;o0000
Foooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool0
9oooool2o`0004Sooooo00?oo`00ooooooooool0>?ooool00ooo003oooooooooo`16ooooo`;o0000
4?ooool0023ooooo00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo05[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`18ooooo`03ool00?oo
oooooooo03Oooooo00?oo`00ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`008?ooool0
0ol0003oooooooooo`1Jooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04Sooooo00?oo`00ooooooooool0=oooool0
0ooo003oooooooooo`17ooooo`03o`000?oooooooooo00kooooo000Hooooo`?o00001Oooool00ol0
003oooooooooo`1Jooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo04Sooooo00?oo`00ooooooooool0=_ooool00ooo
003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo000Iooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[o
oooo00?o0000ooooooooool09oooool2o`0004[ooooo00?oo`00ooooooooool0=Oooool00ooo003o
ooooooooo`17ooooo`;o00004?ooool001Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Iooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00oe_ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`19ooooo`03ool00?oooooooooo03Gooooo
00?oo`00ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`006Oooool00ol0003ooooooooo
o`04ooooo`;o0000F_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol0
0?mJooooo`;o00008Oooool5o`0000?ooooo00?o0000ooooooooool0BOooool00ooo003ooooooooo
o`0dooooo`03ool00?oooooooooo04Wooooo00?o0000ooooooooool03_ooool001Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2
ooooo`?o003o0_ooool3o`00oe_ooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo04Wooooo00?oo`00ooooooooool0=?ooool00ooo003ooooooooo
o`19ooooo`03o`000?oooooooooo00kooooo000Hooooo`;o00001_ooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool2o`0004_ooooo00?oo`00
ooooooooool0<oooool00ooo003oooooooooo`18ooooo`;o00004?ooool001Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1:ooooo`03ool00?oooooooooo03;ooooo00?oo`00oooo
ooooool0B_ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
04[ooooo00?oo`00ooooooooool0<_ooool00ooo003oooooooooo`1:ooooo`03o`000?oooooooooo
00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool07oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`0aoooo
o`03ool00?oooooooooo04[ooooo00?o0000ooooooooool03_ooool0023ooooo0_l0003<ooooo`03
o`000?oooooooooo023ooooo0ol00004ooooo`;o0000C?ooool00ooo003oooooooooo`0`ooooo`03
ool00?oooooooooo04[ooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`0`ooooo`03ool0
0?oooooooooo04_ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0booo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0<?oo
ool00ooo003oooooooooo`1;ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooo
oooo0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1<ooooo`03ool00?oooooo
oooo02oooooo00?oo`00ooooooooool0Boooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0
003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo0_l0001=ooooo`03ool00?oooooooooo
02kooooo00?oo`00ooooooooool0Boooool2o`00013ooooo000Pooooo`03o`000?oooooooooo0<_o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo02ko
oooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0>ooooo`008?ooool2o`000<cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`1=ooooo`03ool00?oooooooooo02gooooo
00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0COooool00ooo003ooooooooo
o`0/ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`0Wooooo`;o0000C_ooool00ooo003oooooooooo`0/
ooooo`03ool00?oooooooooo04cooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`0[oooo
o`03ool00?oooooooooo04gooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04kooooo00?oo`00oooooooo
ool0:_ooool00ooo003oooooooooo`1>ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`00
0?oooooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1>ooooo`03ool0
0?oooooooooo02[ooooo00?oo`00ooooooooool0C_ooool00ol0003oooooooooo`0>ooooo`008?oo
ool2o`000<cooooo00?o0000ooooooooool09oooool2o`00053ooooo00?oo`00ooooooooool0:Ooo
ool00ooo003oooooooooo`1=ooooo`;o00004?ooool0023ooooo00?o0000ooooooooool0boooool0
0ol0003oooooooooo`0Pooooo`?o00001?ooool00ol0003oooooooooo`1?ooooo`03ool00?oooooo
oooo02Sooooo00?oo`00ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0
003oooooooooo`3;ooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo04oooooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`1?
ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool08oooool01Ol0003ooooooooooooooooo000005;ooooo00?oo`00ooooooooool09oooool0
0ooo003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo
0<_ooooo00?o0000ooooooooool08Oooool2o`0000Cooooo0_l0001Aooooo`03ool00?oooooooooo
02Oooooo00?oo`00ooooooooool0C_ooool2o`00013ooooo000Pooooo`03o`000?oooooooooo0<_o
oooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000005;ooooo00?oo`00oooo
ooooool09_ooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo00kooooo000Pooooo`;o
0000c?ooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`1Aooooo`03ool00?oooooooooo02Gooooo00?oo`00ooooooooool0D?ooool00ol0
003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo023o
oooo0ol00004ooooo`;o0000D_ooool00ooo003oooooooooo`0Uooooo`03ool00?oooooooooo04oo
oooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0DOooool00ooo003oooooooooo`0Tooooo`03ool00?oooooooooo057ooooo
00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo05;ooooo00?oo`00ooooooooool08oooool00ooo003ooooooooo
o`1Aooooo`03o`000?oooooooooo00kooooo000<ooooo`?o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0D_ooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo057ooooo00?o0000
ooooooooool03_ooool000gooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Wooooo`;o0000Doooool0
0ooo003oooooooooo`0Rooooo`03ool00?oooooooooo057ooooo0_l0000@ooooo`003Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l0003;ooooo`;o0000:Oooool00ol0
003oooooooooo`1Cooooo`03ool00?oooooooooo027ooooo00?oo`00ooooooooool0D_ooool00ol0
003oooooooooo`0>ooooo`003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo05?o
oooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`1Booooo`03o`000?oooooooooo00ko
oooo000=ooooo`03o`000?oooooooooo00Oooooo1?l00005ooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`1Cooooo`03ool00?oooooooooo023ooooo
00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0>ooooo`003?ooool2o`0000Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo0_l0
001Eooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool0D_ooool2o`00013ooooo000=
ooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo0<_ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`1Dooooo`03ool00?oooooooooo01oooooo00?oo`00
ooooooooool0Doooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0E?ooool00ooo003oooooooooo`0Noooo
o`03ool00?oooooooooo05Cooooo00?o0000ooooooooool03_ooool0023ooooo0_l0003<ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool00ooo003oooooooooo`0Mooooo`03
ool00?oooooooooo05Cooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0
boooool00ol0003oooooooooo`0Wooooo`;o0000E_ooool00ooo003oooooooooo`0Mooooo`03ool0
0?oooooooooo05?ooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0EOooool00ooo003oooooooooo`0Looooo`03ool00?oo
oooooooo05Gooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool0
0ol0003oooooooooo`0Qooooo`?o00000oooool00ol0003oooooooooo`1Fooooo`03ool00?oooooo
oooo01_ooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0
003oooooooooo`3;ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Fooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool0EOooool00ol0
003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01oo
oooo1Ol00003ooooo`;o0000Eoooool00ooo003oooooooooo`0Jooooo`03ool00?oooooooooo05Go
oooo0_l0000@ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool07oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo05Oooooo00?oo`00ooooooooool06Oooool00ooo003o
ooooooooo`1Fooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool08?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo05Oooooo
00?oo`00ooooooooool06Oooool00ooo003oooooooooo`1Fooooo`03o`000?oooooooooo00kooooo
000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool08Oooool2o`0000Cooooo00?o
0000ooooooooool0F?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo05Oooooo00?o
0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00;ooooo0_l0001Iooooo`03ool00?oooooooooo01Oooooo00?oo`00
ooooooooool0E_ooool2o`00013ooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1Hooooo`03ool00?oooooooooo01Kooooo00?oo`00oooo
ooooool0F?ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0FOooool00ooo003oooooooooo`0Eooooo`03
ool00?oooooooooo05Sooooo00?o0000ooooooooool03_ooool0023ooooo0_l0003<ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0FOooool00ooo003oooooooooo`0Dooooo`03ool0
0?oooooooooo05Wooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0booo
ool00ol0003oooooooooo`0Wooooo`;o0000Foooool00ooo003oooooooooo`0Cooooo`03ool00?oo
oooooooo05Sooooo0_l0000@ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0F_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooo
oooo05Wooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool04Oooool00ooo
003oooooooooo`1Jooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Kooooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool0F_ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003ooooo
ooooo`3;ooooo`03o`000?oooooooooo02Oooooo0_l0001Mooooo`03ool00?oooooooooo00oooooo
00?oo`00ooooooooool0F_ooool2o`00013ooooo000Pooooo`;o0000c?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo05cooooo00?oo`00ooooooooool03_ooool00ooo003ooooooooo
o`1Looooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`1Mooooo`03ool00?oooooooooo00cooooo00?oo`00
ooooooooool0GOooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0G_ooool00ooo003oooooooooo`0:oooo
o`03ool00?oooooooooo05kooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Wooooo`;o0000H?ooool00ooo003oooooooooo`08ooooo`03
ool00?oooooooooo05kooooo0_l0000@ooooo`005oooool5o`0000Cooooo00?o0000ooooooooool0
boooool00ol0003oooooooooo`0Pooooo`?o00001?ooool00ol0003oooooooooo`1Oooooo`03ool0
0?oooooooooo00Oooooo00?oo`00ooooooooool0H?ooool00ol0003oooooooooo`0>ooooo`006?oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0
7oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0H?ooool2ool000Ko
oooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0>ooooo`006Oooool00ol0003ooooo
ooooo`04ooooo`;o0000boooool2o`0002Gooooo00Go0000ooooooooooooooooo`00001Tooooo`Ko
o`00I?ooool00ol0003oooooooooo`0>ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0<_ooooo00?o0000ooooooooool08oooool01?l0003oooooooooooooool2o`0006Go
oooo0_oo001Uooooo`;o00004?ooool001Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool01Ol0003ooooooooooooooooo0000
027ooooo1?l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0>ooooo`005oooool01Ol0003ooooooooooooooooo000000Cooooocol0000Qoooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`00013ooooo000Hooooo`?o0000mOooool5o`0000?oooood?l0000@
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`008_ooool5o`0000?ooooo0_l0000Xooooo`?o00001?ooool2o`0002Wooooo0_l0000[oooo
o`?o00001?ooool2o`0002Sooooo1Ol00003ooooo`;o0000=Oooool3o`0001_ooooo1Ol0000Koooo
o`?o00006oooool2o`0001cooooo0ol0000Kooooo`Go00007?ooool3o`0001Wooooo000Sooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0002Oooooo00Co0000oooooooooooo0000:oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0002Sooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000cooooo`05o`000?ooooooooooooooool000006oooool01?l0003ooooooooo
ool0000Looooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00007?ooool00ol0003o
ooooooooo`0Kooooo`04o`000?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`00000H
ooooo`007?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000P
ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Oooooo00Co
0000oooooooooooo0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Wo
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000]ooooo`Go00001Oooool00ol0
003oooooooooo`0Booooo`Go00000oooool00ol0003oooooooooo`0Dooooo`Go00000oooool00ol0
003oooooooooo`0Iooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Kooooo000Uooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00009oooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000:_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool0<oooool2o`0001kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Ioooo
o`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0L
ooooo`;o00006Oooool002;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0002Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`04o`00
0?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Woooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000gooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`00000Looooo`03o`000?oooooooooo01Wooooo
00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooooooo
ool000007oooool00ol0003oooooooooo`0Fooooo`008_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00009oooool2o`0000Cooooo00Co0000oooooooooooo00009ooo
ool01?l0003oooooooooool0000Zooooo`;o00001?ooool01?l0003oooooooooool0000Wooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000cooooo`05o`000?oooooo
ooooooooool000006_ooool01Ol0003ooooooooooooooooo000001_ooooo0_l0000Kooooo`04o`00
0?ooooooooooo`0001_ooooo0_l0000Looooo`05o`000?ooooooooooooooool000006oooool01Ol0
003ooooooooooooooooo000001Sooooo000Sooooo`?o00001?ooool2o`0002Wooooo00?o0000oooo
ooooool00oooool2o`0002Wooooo0_l0000/ooooo`03o`000?oooooooooo00?ooooo0_l0000Yoooo
o`?o00001?ooool2o`0003Gooooo0ol0000Looooo`?o00007Oooool00ol0003oooooooooo`0Joooo
o`;o00007Oooool00ol0003oooooooooo`0Kooooo`?o00007Oooool3o`0001Wooooo003oooooooWo
oooo003oooooooWooooo003oooooooWooooo003oooooooWooooo000Iooooo`;o00001Oooooo?o`00
02;ooooo0ol00004ooooom3o00004?ooool001Sooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000002?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool001Sooooo00Co0000oooo
oooooooo00001?ooool01?l0003oooooooooooooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_oo
ool3o`00o`;ooooo0ol00?l2ooooo`?o003o00Coooooo`00ool00?oo003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l01?oooooo003oo`00ool00?lAooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o
003o00Coooooo`00ool00?oo003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00
o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00
o`;ooooo0ol00?l2ooooo`03o`000?oooooooooo01Wooooo1Ol00003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0>ooooo`006?ooool01?l0003o
ooooooooool00004ooooo`Co00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`00
00?o003o0_l00003o`00o`04o`000?l00?oo003oo`00o`;o00000ol00?l2o`0000?o003o0_l00003
o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003
o`00o`;o00000ol00?l2o`0000?o003o00Co0000o`00ool00?oo003o0ol000000ol00?oo0000o`00
0002o`000003o`00ool0003o000000;o000000Co003oo`000?l0003o00000ol00?l2o`0000?o003o
0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l01?l0003o003o
o`00ool00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o
00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`?o
00008oooool00ol0003oooooooooo`03ooooo`;o00000oooool5ool00;_ooooo1_oo0003ooooo`;o
00004?ooool001Sooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooooooool3o`00
o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o00Coooooo`00
ool00?oo003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2
ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l0
1?oooooo003oo`00ool00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooooooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo
0ol00?l2ooooo`?o003o0_ooool3o`00o`04ooooool00?oo003oo`00o`;ooooo0ol00?l2ooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o
003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool3ool00;Kooooo0_oo000:ooooo`03
o`000?oooooooooo00kooooo000Hooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0Goooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0Goooool00ol0003oooooooooo`0Pooooo`;o00001Oooool00ol0003oooooooooo`0:ooooo`;o
o`00/_ooool2ool000cooooo00?o0000ooooooooool03_ooool001Wooooo0_l00005ooooo`03o`00
0?oooooooooo05oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo05oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00cooooo0_oo002^ooooo`;oo`003_ooool00ol0003oooooooooo`0>ooooo`008?oo
ool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03_oo
ool2ool00:_ooooo00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`008?ooool0
0ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04?ooool0
0ooo003oooooooooo`2Wooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool03_ooool0
023ooooo0_l0001Pooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo0_l0000Booooo`03ool00?oooooooooo
0:Gooooo00?oo`00ooooooooool03oooool2o`00013ooooo000Pooooo`03o`000?oooooooooo05oo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05oo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo0:?o
oooo00?oo`00ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003ooooo
ooooo`1Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04oooool00ooo003ooooo
ooooo`2Qooooo`03ool00?oooooooooo01;ooooo00?o0000ooooooooool03_ooool0023ooooo00?o
0000ooooooooool0Goooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0Goooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01?ooooo00?o
o`00ooooooooool0XOooool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo000P
ooooo`03o`000?oooooooooo05oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0D
ooooo`03ool00?oooooooooo09oooooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`0>
ooooo`008?ooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool05Oooool00ooo003oooooooooo`2Mooooo`03ool00?oooooooooo01Cooooo00?o0000oooo
ooooool03_ooool0023ooooo0_l0001Pooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo0_l0000Gooooo`03
ool00?oooooooooo09_ooooo00?oo`00ooooooooool05?ooool2o`00013ooooo000Pooooo`03o`00
0?oooooooooo05oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Gooooo`03ool0
0?oooooooooo09Wooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0>ooooo`008?oo
ool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05ooo
ool00ooo003oooooooooo`2Hooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool03_oo
ool0023ooooo00?o0000ooooooooool0Goooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo01Sooooo00?oo`00ooooooooool0U_ooool00ooo003oooooooooo`0Hooooo`03o`000?oooooo
oooo00kooooo000Pooooo`03o`000?oooooooooo05oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Iooooo`03ool00?oooooooooo09Cooooo00?oo`00ooooooooool06Oooool00ol0
003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`2Booooo`03ool00?oooooooooo01[o
oooo00?o0000ooooooooool03_ooool0023ooooo0_l0001Pooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo
0_l0000Looooo`03ool00?oooooooooo093ooooo00?oo`00ooooooooool06_ooool2o`00013ooooo
000Pooooo`03o`000?oooooooooo05oooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo093ooooo00?oo`00ooooooooool06oooool00ol0003ooooooooo
o`0>ooooo`008?ooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool07?ooool00ooo003oooooooooo`2>ooooo`03ool00?oooooooooo01cooooo00?o0000
ooooooooool03_ooool0023ooooo00?o0000ooooooooool0Goooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo01gooooo00?oo`00ooooooooool0S?ooool00ooo003oooooooooo`0Moooo
o`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo05oooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05oooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo08cooooo00?oo`00oooooooo
ool07Oooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Oooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ooo003oooooooooo`2:ooooo`03ool0
0?oooooooooo01kooooo00?o0000ooooooooool03_ooool0023ooooo0_l0001Pooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oo
oooooooo02Oooooo0_l0000Pooooo`03ool00?oooooooooo08Sooooo00?oo`00ooooooooool07_oo
ool2o`00013ooooo000Pooooo`03o`000?oooooooooo05oooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Oooooo`03ool00?oooooooooo08Sooooo00?oo`00ooooooooool07oooool0
0ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool08?ooool00ooo003oooooooooo`26ooooo`03ool00?oooooooooo
023ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0Goooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Goooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool0Q?ooool00ooo003o
ooooooooo`0Qooooo`03o`000?oooooooooo00kooooo000=ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo027ooooo
0_l00004ooooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool0Q?ooool00ooo003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00kooooo000<ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05oooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05oooooo00?o0000oooooooo
ool08?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo02;ooooo00?oo`00oooo
ooooool0P_ooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00kooooo000<ooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2o`00063ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05kooooo0_l0000Roooo
o`04o`000?ooooooooooo`0000?ooooo0_l0000Tooooo`03ool00?oooooooooo083ooooo00?oo`00
ooooooooool08_ooool2o`00013ooooo000<ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo023ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`0Sooooo`03ool00?oooooooooo083ooooo00?o
o`00ooooooooool08oooool00ol0003oooooooooo`0>ooooo`003?ooool01?l0003oooooooooool0
0007ooooo`Co00001Oooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo023ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo07kooooo
00?oo`00ooooooooool09?ooool00ol0003oooooooooo`0>ooooo`003?ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Goooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Goooool00ol0003ooooo
ooooo`0Pooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool09?ooool00ooo003o
ooooooooo`1nooooo`03ool00?oooooooooo02Cooooo00?o0000ooooooooool03_ooool000gooooo
0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo027ooooo
0_l00004ooooo`03o`000?oooooooooo02Gooooo00?oo`00ooooooooool0O?ooool00ooo003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo05oooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo07cooooo00?o
o`00ooooooooool09Oooool00ol0003oooooooooo`0>ooooo`008?ooool2o`00063ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05oooooo00?o0000
ooooooooool09oooool2o`0002Oooooo00?oo`00ooooooooool0N_ooool00ooo003oooooooooo`0U
ooooo`;o00004?ooool0023ooooo00?o0000ooooooooool0Goooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0N_ooool00ooo003oooooooooo`0Voooo
o`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo05oooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05oooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Wooooo`03ool00?oooooooooo07Sooooo00?oo`00oooooooo
ool09oooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Oooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ooo003oooooooooo`1fooooo`03ool0
0?oooooooooo02Sooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0Gooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Gooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Sooooo00?oo`00ooooooooool0M_oo
ool00ooo003oooooooooo`0Xooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooo
oooo05oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo05oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Yooooo`03ool00?oooooo
oooo07Cooooo00?oo`00ooooooooool0:Oooool00ol0003oooooooooo`0>ooooo`008?ooool2o`00
063ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
05oooooo00?o0000ooooooooool09oooool2o`0002[ooooo00?oo`00ooooooooool0M?ooool00ooo
003oooooooooo`0Xooooo`;o00004?ooool0023ooooo00?o0000ooooooooool0Goooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Goooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool0L_ooool00ooo003o
ooooooooo`0Zooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo05oooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05oooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Zooooo`03ool00?oooooooooo07;ooooo
00?oo`00ooooooooool0:_ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003ooooooooo
o`1Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:oooool00ooo003ooooooooo
o`1`ooooo`03ool00?oooooooooo02_ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000
ooooooooool0Goooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0Goooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02_ooooo00?oo`00
ooooooooool0L?ooool00ooo003oooooooooo`0[ooooo`03o`000?oooooooooo00kooooo000Poooo
o`03o`000?oooooooooo05oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0/oooo
o`03ool00?oooooooooo06kooooo00?oo`00ooooooooool0;?ooool00ol0003oooooooooo`0>oooo
o`008?ooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0;?ooool00ooo003oooooooooo`1^ooooo`03ool00?oooooooooo02cooooo00?o0000oooooooo
ool03_ooool0023ooooo0_l0001Pooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo0_l0000^ooooo`03ool0
0?oooooooooo06cooooo00?oo`00ooooooooool0;?ooool2o`00013ooooo000Pooooo`03o`000?oo
oooooooo05oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo05oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0]ooooo`03ool00?oo
oooooooo06cooooo00?oo`00ooooooooool0;Oooool00ol0003oooooooooo`0>ooooo`008?ooool0
0ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0;_ooool0
0ooo003oooooooooo`1Zooooo`03ool00?oooooooooo02kooooo00?o0000ooooooooool03_ooool0
023ooooo00?o0000ooooooooool0Goooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
02kooooo00?oo`00ooooooooool0J_ooool00ooo003oooooooooo`0^ooooo`03o`000?oooooooooo
00kooooo000Pooooo`03o`000?oooooooooo05oooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0_ooooo`03ool00?oooooooooo06Sooooo00?oo`00ooooooooool0;oooool00ol0003o
ooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0;oooool00ooo003oooooooooo`1Wooooo`03ool00?oooooooooo033ooooo
00?o0000ooooooooool03_ooool0023ooooo0_l0001Pooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo0_l0
000aooooo`03ool00?oooooooooo06Kooooo00?oo`00ooooooooool0;oooool2o`00013ooooo000P
ooooo`03o`000?oooooooooo05oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo05oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0`
ooooo`03ool00?oooooooooo06Gooooo00?oo`00ooooooooool0<Oooool00ol0003oooooooooo`0>
ooooo`008?ooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0<Oooool00ooo003oooooooooo`1Tooooo`03ool00?oooooooooo037ooooo00?o0000oooo
ooooool03_ooool001Sooooo0ol00005ooooo`03o`000?oooooooooo05oooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05oooooo00?o0000oooooooo
ool08?ooool3o`0000Cooooo00?o0000ooooooooool0<Oooool00ooo003oooooooooo`1Sooooo`03
ool00?oooooooooo03;ooooo00?o0000ooooooooool03_ooool001Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`1Oooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0booooo`03ool00?oooooooooo06;ooooo00?oo`00ooooooooool0
<_ooool00ol0003oooooooooo`0>ooooo`006Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo05kooooo0ol00?l2ooooo`?o003o0_ooool3o`00of3ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo00?oo`00ooooooooool0HOoo
ool00ooo003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo000Iooooo`03o`000?oooooo
oooo00Cooooo0_l0001Oooooo`?o003o0_ooool3o`00o`;ooooo0ol00?mOooooo`;o00008oooool0
0ol0003oooooooooo`03ooooo`;o0000=?ooool00ooo003oooooooooo`1Pooooo`03ool00?oooooo
oooo03;ooooo0_l0000@ooooo`006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
05kooooo0ol00?l2ooooo`?o003o0_ooool3o`00of3ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo03?ooooo00?oo`00ooooooooool0Goooool00ooo
003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo000Hooooo`;o00001_ooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo023ooooo0_l00005ooooo`03o`000?oooooooooo03Co
oooo00?oo`00ooooooooool0G_ooool00ooo003oooooooooo`0dooooo`03o`000?oooooooooo00ko
oooo000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0boooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool00ooo003ooooo
ooooo`1Mooooo`03ool00?oooooooooo03Gooooo00?o0000ooooooooool03_ooool0023ooooo00?o
0000ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Gooooo00?o
o`00ooooooooool0G?ooool00ooo003oooooooooo`0eooooo`03o`000?oooooooooo00kooooo000P
ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0f
ooooo`03ool00?oooooooooo05[ooooo00?oo`00ooooooooool0=_ooool00ol0003oooooooooo`0>
ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool09oooool2o`0003Oooooo00?oo`00oooo
ooooool0F_ooool00ooo003oooooooooo`0eooooo`;o00004?ooool0023ooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?oo`00oooooooo
ool0F?ooool00ooo003oooooooooo`0gooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`00
0?oooooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0gooooo`03ool0
0?oooooooooo05Sooooo00?oo`00ooooooooool0=oooool00ol0003oooooooooo`0>ooooo`008?oo
ool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>?oo
ool00ooo003oooooooooo`1Fooooo`03ool00?oooooooooo03Sooooo00?o0000ooooooooool03_oo
ool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Sooooo00?oo`00ooooooooool0E_ooool00ooo003oooooooooo`0hooooo`03o`000?oooooo
oooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0iooooo`03ool00?oooooooooo05Cooooo00?oo`00ooooooooool0>Oooool00ol0
003oooooooooo`0>ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool09oooool2o`0003[o
oooo00?oo`00ooooooooool0E?ooool00ooo003oooooooooo`0hooooo`;o00004?ooool0023ooooo
00?o0000ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03[ooooo
00?oo`00ooooooooool0D_ooool00ooo003oooooooooo`0jooooo`03o`000?oooooooooo00kooooo
000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0kooooo`03ool00?oooooooooo057ooooo00?oo`00ooooooooool0>_ooool00ol0003ooooooooo
o`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0>oooool00ooo003oooooooooo`1@ooooo`03ool00?oooooooooo03_ooooo00?o0000
ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo03cooooo00?oo`00ooooooooool0Coooool00ooo003oooooooooo`0koooo
o`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0looooo`03ool00?oooooooooo04kooooo00?oo`00oooooooo
ool0??ooool00ol0003oooooooooo`0>ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool0
9oooool2o`0003kooooo00?oo`00ooooooooool0C?ooool00ooo003oooooooooo`0looooo`;o0000
4?ooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03gooooo00?oo`00ooooooooool0C?ooool00ooo003oooooooooo`0mooooo`03o`000?oo
oooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0nooooo`03ool00?oooooooooo04[ooooo00?oo`00ooooooooool0?_ooool0
0ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0?_ooool00ooo003oooooooooo`1:ooooo`03ool00?oooooooooo
03kooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo03oooooo00?oo`00ooooooooool0B?ooool00ooo003o
ooooooooo`0oooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0oooooo`03ool00?oooooooooo04Oooooo
00?oo`00ooooooooool0@?ooool00ol0003oooooooooo`0>ooooo`008?ooool2o`000<cooooo00?o
0000ooooooooool09oooool2o`00047ooooo00?oo`00ooooooooool0A_ooool00ooo003ooooooooo
o`0oooooo`;o00004?ooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo047ooooo00?oo`00ooooooooool0A?ooool00ooo003oooooooooo`11
ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`11ooooo`03ool00?oooooooooo04Cooooo00?oo`00oooo
ooooool0@Oooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0@_ooool00ooo003oooooooooo`12ooooo`03
ool00?oooooooooo04;ooooo00?o0000ooooooooool03_ooool000cooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0
7oooool5o`0000?ooooo00?o0000ooooooooool0@_ooool00ooo003oooooooooo`11ooooo`03ool0
0?oooooooooo04?ooooo00?o0000ooooooooool03_ooool000gooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0boooool00ol0003ooooo
ooooo`0Pooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0@oooool00ooo003o
ooooooooo`10ooooo`03ool00?oooooooooo04?ooooo00?o0000ooooooooool03_ooool000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`;o0000boooool2o`0002?ooooo
00?o0000ooooooooool00oooool2o`0004Cooooo00?oo`00ooooooooool0?oooool00ooo003ooooo
ooooo`13ooooo`;o00004?ooool000gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04Cooooo00?oo`00ooooooooool0?_ooool00ooo003ooooooooo
o`14ooooo`03o`000?oooooooooo00kooooo000=ooooo`03o`000?oooooooooo00Oooooo1?l00005
ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0A?ooool00ooo003oooooooooo`0mooooo`03ool00?oo
oooooooo04Gooooo00?o0000ooooooooool03_ooool000cooooo0_l00009ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Oooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`15ooooo`03ool00?oooooooooo03_ooooo00?o
o`00ooooooooool0A_ooool00ol0003oooooooooo`0>ooooo`003Oooool00ol0003oooooooooo`07
ooooo`Go00001?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo023ooooo0ol00004
ooooo`03o`000?oooooooooo04Kooooo00?oo`00ooooooooool0>_ooool00ooo003oooooooooo`16
ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`16ooooo`03ool00?oooooooooo03Wooooo00?oo`00oooo
ooooool0Aoooool00ol0003oooooooooo`0>ooooo`008?ooool2o`000<cooooo00?o0000oooooooo
ool09oooool2o`0004Sooooo00?oo`00ooooooooool0>?ooool00ooo003oooooooooo`16ooooo`;o
00004?ooool0023ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo04Sooooo00?oo`00ooooooooool0=_ooool00ooo003oooooooooo`18ooooo`03o`00
0?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`18ooooo`03ool00?oooooooooo03Gooooo00?oo`00ooooooooool0BOoo
ool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0BOooool00ooo003oooooooooo`0dooooo`03ool00?oooooo
oooo04Wooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0boooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo04[ooooo00?oo`00ooooooooool0<_ooool00ooo
003oooooooooo`1:ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1:ooooo`03ool00?oooooooooo03;o
oooo00?oo`00ooooooooool0B_ooool00ol0003oooooooooo`0>ooooo`008?ooool2o`000<cooooo
00?o0000ooooooooool09oooool2o`0004cooooo00?oo`00ooooooooool0<?ooool00ooo003ooooo
ooooo`1:ooooo`;o00004?ooool0023ooooo00?o0000ooooooooool0boooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool0;_ooool00ooo003ooooooooo
o`1<ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo02kooooo00?oo`00
ooooooooool0C?ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0COooool00ooo003oooooooooo`0/oooo
o`03ool00?oooooooooo04gooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo04kooooo00?oo`00oooooooo
ool0:_ooool00ooo003oooooooooo`1>ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`00
0?oooooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1?ooooo`03ool0
0?oooooooooo02Sooooo00?oo`00ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`008?oo
ool2o`000<cooooo00?o0000ooooooooool09oooool2o`00057ooooo00?oo`00ooooooooool09_oo
ool00ooo003oooooooooo`1?ooooo`;o00004?ooool0023ooooo00?o0000ooooooooool0boooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo057ooooo00?oo`00ooooooooool09?ooool0
0ooo003oooooooooo`1Aooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo
0<_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Booooo`03ool00?oooooooooo
02;ooooo00?oo`00ooooooooool0D_ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Doooool00ooo003o
ooooooooo`0Pooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool03_ooool0023ooooo
00?o0000ooooooooool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo05Cooooo
00?oo`00ooooooooool07_ooool00ooo003oooooooooo`1Dooooo`03o`000?oooooooooo00kooooo
000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`1Eooooo`;oo`007Oooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo00kooooo000P
ooooo`;o0000c?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo05Oooooo00?oo`00
ooooooooool06Oooool00ooo003oooooooooo`1Fooooo`03o`000?oooooooooo00kooooo000Poooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool09oooool2o`0005Wooooo00?oo`00oooo
ooooool05oooool00ooo003oooooooooo`1Fooooo`;o00004?ooool0023ooooo00?o0000oooooooo
ool0boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo05Wooooo00?oo`00oooooooo
ool05?ooool2ool005[ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0
boooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo05[ooooo00?oo`00ooooooooool0
4Oooool2ool005cooooo00?o0000ooooooooool03_ooool001Oooooo1Ol00004ooooo`03o`000?oo
oooooooo0<_ooooo00?o0000ooooooooool08?ooool3o`0000Cooooo00?o0000ooooooooool0Fooo
ool2ool000oooooo0_oo001Nooooo`03o`000?oooooooooo00kooooo000Hooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`0Oooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`1Mooooo`;oo`002oooool2ool0063ooooo
00?o0000ooooooooool03_ooool001Wooooo00?o0000ooooooooool01?ooool2o`000<_ooooo0_l0
000Uooooo`05o`000?ooooooooooooooool00000HOooool5ool000?ooooo0ooo001Rooooo`03o`00
0?oooooooooo00kooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0booo
ool00ol0003oooooooooo`0Qooooo`;o00001?ooool2o`0006Cooooo1Ooo001Sooooo`;o00004?oo
ool001Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0;oooool01Ol0003ooooooooooooooooo000002Gooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool001Oooooo
00Go0000ooooooooooooooooo`000004oooooloo00008Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`00013ooooo000Hooooo`?o0000m_ooool3o`0000Coooood?l0000@ooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`008_ooool5o`00
00?ooooo0_l0000Xooooo`?o00001?ooool2o`0002Wooooo0_l0000[ooooo`?o00001?ooool2o`00
02Sooooo1Ol00003ooooo`;o0000>?ooool3o`0001_ooooo1Ol0000Kooooo`?o00006oooool2o`00
01cooooo0ol0000Kooooo`Go00007?ooool3o`0001Kooooo000Sooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0002Oooooo00Co0000oooooooooooo0000:oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0002Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000f
ooooo`05o`000?ooooooooooooooool000006oooool01?l0003oooooooooool0000Looooo`03o`00
0?oooooooooo01Wooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Kooooo`04
o`000?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`00000Eooooo`007?ooool5o`00
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Pooooo`Go00000oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Oooooo00Co0000oooooooooooo0000
:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Wooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000`ooooo`Go00001Oooool00ol0003oooooooooo`0Boooo
o`Go00000oooool00ol0003oooooooooo`0Dooooo`Go00000oooool00ol0003oooooooooo`0Ioooo
o`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01?ooooo000Uooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009ooo
ool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000:_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0=_ooool2o`00
01kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`04o`000?oooooooooo
o`0001cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Looooo`;o00005_ooool0
02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002Sooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`0002_o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool0000jooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`00000Looooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo
00007?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000007oooool00ol0
003oooooooooo`0Cooooo`008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00009oooool2o`0000Cooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool0000Zooooo`;o00001?ooool01?l0003oooooooooool0000Wooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000fooooo`05o`000?ooooooooooooooool000006_oo
ool01Ol0003ooooooooooooooooo000001_ooooo0_l0000Kooooo`04o`000?ooooooooooo`0001_o
oooo0_l0000Looooo`05o`000?ooooooooooooooool000006oooool01Ol0003ooooooooooooooooo
000001Gooooo000Sooooo`?o00001?ooool2o`0002Wooooo00?o0000ooooooooool00oooool2o`00
02Wooooo0_l0000/ooooo`03o`000?oooooooooo00?ooooo0_l0000Yooooo`?o00001?ooool2o`00
03Sooooo0ol0000Looooo`?o00007Oooool00ol0003oooooooooo`0Jooooo`;o00007Oooool00ol0
003oooooooooo`0Kooooo`?o00007Oooool3o`0001Kooooo003oooooooWooooo003oooooooWooooo
003oooooooWooooo003oooooooWooooo000Poooooloo00009_ooool2o`0000Coooood?l0000=oooo
o`006Oooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Uooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000gooooo000Hooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo
oooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`04
ooooool00?oo003oo`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`?o003o00Coooooo`00ool00?oo003o0_ooool3o`00o`Oooooo0ol00?l2ooooo`?o003o0_ooool3
o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o00Cooooo
o`00ool00?oo003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol0
0?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol0
0?l2ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Hooooo`04o`000?ooooooooooo`0000Cooooo
1?l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o
00Co0000o`00ool00?oo003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o
00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o
00000ol00?l01?l0003o003oo`00ool00?l2o`0000?o003o0ol000001?l00?oo0000o`000?l00003
o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003
o`00o`;o00000ol00?l01?l0003o003oo`00ool00?l2o`0000?o003o0_l00003o`00o`;o00000ol0
0?l2o`0000?o003o0_l00003o`00o`;o00000ol00?l2o`0000?o003o0_l00003o`00o`;o00000ol0
0?l2o`0000?o003o0_l00003o`00o`?o00009Oooool01?l0003oooooooooool00003ooooo`;o0000
c?ooool2o`0000gooooo000Hooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo
oooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`04
ooooool00?oo003oo`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2oooo
o`?o003o00Coooooo`00ool00?oo003o0_ooool3o`00o`?ooooo00Co003ooooooooooooooooo0ol0
0?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol0
0?l2ooooo`?o003o00Coooooo`00ool00?oo003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o
0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o0_ooool3o`00o`;ooooo0ol00?l2ooooo`?o003o
0_ooool3o`00o`;ooooo0ol00?l2ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Hooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03
o`000?oooooooooo02?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo00_ooooo000Hooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02Cooooo0_l00004oooo
o`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool001Wooooo0_l00005ooooo`03
o`000?oooooooooo06Cooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0
I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0;ooooo`008?ooool2o`0006Gooooo00?o003oooooooooool0I?oo
ool00ol0003oooooooooo`0Zooooo`;o0000c?ooool2o`0000gooooo000Pooooo`03o`000?oooooo
oooo06Cooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0I?ooool00ol0
0?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo06Co
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_o
oooo000Pooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool0I?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o
0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool2o`0006Gooooo00?o003o
ooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`;o0000c?ooool2o`0000gooooo000Poooo
o`03o`000?oooooooooo06Cooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000oooooooo
ool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`00
oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool0I?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02ooo
ool0023ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool2o`00
06Gooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`;o0000c?ooool2o`00
00gooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool0I?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo
00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003ooooooooo
o`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o003o
ooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000
ooooooooool02oooool0023ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Toooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;oooo
o`008?ooool2o`0006Gooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`;o
0000c?ooool2o`0000gooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool0
I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool0
2oooool0023ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool0
0ol0003oooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000=ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo
06Cooooo00?o0000ooooooooool06?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Cooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`003?ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1T
ooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3<ooooo`03o`00
0?oooooooooo00_ooooo000<ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
0_ooool2o`0006Gooooo00?o003oooooooooool0Hoooool2o`0001Wooooo00Co0000oooooooooooo
00002oooool01?l0003oooooooooooooool2o`000<cooooo0_l0000=ooooo`003?ooool01?l0003o
ooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I?ooool00ol0
0?ooooooooooo`1Tooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00002oooool0
1Ol0003ooooooooooooooooo00000<kooooo00?o0000ooooooooool02oooool000cooooo00Co0000
oooooooooooo00001oooool4o`0000Gooooo00?o0000ooooooooool0I?ooool00ol00?oooooooooo
o`1Tooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00001oooool4o`0000Cooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`003?ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0I?ooool00ol00?oooooo
ooooo`1Tooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool000gooooo
0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo
00?o0000ooooooooool06?ooool2o`0000Sooooo1Ol00003ooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0I?ooool00ol00?oooooooooo
o`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0;ooooo`008?ooool2o`0006Gooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`0Z
ooooo`;o0000c?ooool2o`0000gooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o003ooooo
ooooool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000oooo
ooooool02oooool0023ooooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`00
8?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oo
oooooooo06Cooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0I?ooool0
0ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool0
0ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo
06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo
00_ooooo000Pooooo`;o0000IOooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[o
oooo0_l0003<ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0I?ooool00ol00?oooooo
ooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000P
ooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000oooo
ooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03
o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03
o`000?oooooooooo00_ooooo000Pooooo`;o0000IOooool00ol00?ooooooooooo`1Tooooo`03o`00
0?oooooooooo02[ooooo0_l0003<ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0I?oo
ool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooo
oooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooo
oooo00_ooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o003oooooooooool0I?ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool02oooool0023o
oooo00?o0000ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003ooooo
ooooo`1Tooooo`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`3<ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000IOooool00ol00?oooooooooo
o`1Tooooo`03o`000?oooooooooo02[ooooo0_l0003<ooooo`;o00003Oooool0023ooooo00?o0000
ooooooooool0I?ooool00ol00?ooooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1Toooo
o`03o`00oooooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3<oooo
o`03o`000?oooooooooo00_ooooo000Hooooo`?o00001Oooool00ol0003oooooooooo`1Tooooo`03
o`00oooooooooooo06Cooooo00?o0000ooooooooool08oooool3o`0000Cooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo06Cooooo00?o003oooooooooool0I?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`006Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06?ooooo0ol00?mUooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3<ooooo`03o`000?oo
oooooooo00_ooooo000Iooooo`03o`000?oooooooooo00Cooooo0_l0001Tooooo`?o003oI?ooool2
o`0002Kooooo00?o0000ooooooooool00oooool2o`0000?oooooa_oo0003ooooo`;o00003Oooool0
01Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Sooooo`?o003oIOooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0;ooooo`006?ooool2o`0000Kooooo00?o0000ooooooooool0boooool00ol0003o
ooooooooo`0Sooooo`;o00001Oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_o
oooo000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0boooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;
ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool0:_ooool2o`000<cooooo0_l0000=oooo
o`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?oo
ool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0
003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0;ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool0:_ooool2o`000<co
oooo0_l0000=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;oooo
o`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool0
:_ooool2o`000<cooooo0_l0000=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool0
0ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003o
ooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool2o`000<cooooo00?o
0000ooooooooool0:_ooool2o`000<cooooo0_l0000=ooooo`008?ooool00ol0003oooooooooo`3;
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;
ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`00
3?ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0
boooool00ol0003oooooooooo`0Gooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000=ooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000=ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00_ooool2o`000<_ooooo0_l0000Jooooo`03o`00
0?oooooooooo00_ooooo00Co0000oooooooooooooooo0_l0003<ooooo`;o00003Oooool000gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool0
0000c_ooool00ol0003oooooooooo`0;ooooo`003Oooool00ol0003oooooooooo`07ooooo`Co0000
1Oooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1oooool4o`0000Cooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`003?oo
ool2o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3;ooooo`03o`000?oo
oooooooo01Oooooo0_l00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0c?oo
ool00ol0003oooooooooo`0;ooooo`003Oooool00ol0003oooooooooo`07ooooo`Go00001?ooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool5
o`0000?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0
003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0
003oooooooooo`0;ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool0:_ooool2o`000<co
oooo0_l0000=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003ooooooooo
o`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;oooo
o`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool2o`000<cooooo00?o0000ooooooooool0
:_ooool2o`000<cooooo0_l0000=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool0
0ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool0
0ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003o
ooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003o
ooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool2o`000<cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000P
ooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:_ooool2o`000<cooooo0_l0000=
ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`00
8?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool2
o`000<cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooo
oooo00_ooooo000Pooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0:_ooool2o`00
0<cooooo0_l0000=ooooo`008?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003ooooo
ooooo`3;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0;ooooo`005oooool5o`0000Cooooo00?o0000ooooooooool0boooool00ol0003ooooooooo
o`0Rooooo`Go00000oooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00_ooooo000H
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0boooool00ol0003ooooooooo
o`0Sooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0c?ooool00ol0003ooooo
ooooo`0;ooooo`006Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<_ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<cooooo00?o
0000ooooooooool02oooool001[ooooo00?o0000ooooooooool00oooool2o`000<_ooooo0_l0000W
ooooo`03o`000?oooooooooo00;ooooo0_l0003<ooooo`;o00003Oooool001Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool0
1Ol0003ooooooooooooooooo000002Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`005ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Tooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00003Oooool001Sooooo0ol00005oooooloo00009Oooool3
o`0000Coooood?l0000=ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {799.938, 0}} -> {-0.0500105, -0.0806364, \
0.004175, 0.004175}, {{11.9375, 240.062}, {780.625, 639.625}} -> {-27.6155, \
-0.561393, 0.203431, 0.0164579}, {{262.875, 491}, {780.625, 639.625}} -> \
{-12.1072, -9.45963, 0.0315142, 0.16828}, {{11.9375, 240.062}, {625.5, \
484.5}} -> {-27.6155, -3.11443, 0.203431, 0.0164579}, {{262.875, 491}, \
{625.5, 484.5}} -> {-12.1072, -18.9832, 0.0315142, 0.0895872}, {{11.9375, \
240.062}, {470.438, 329.438}} -> {-27.6155, -5.66644, 0.203431, 0.0164579}, \
{{262.875, 491}, {470.438, 329.438}} -> {-12.2416, -18.8995, 0.0318653, \
0.0512866}, {{11.9375, 240.062}, {315.375, 174.375}} -> {-27.6155, -8.21844, \
0.203431, 0.0164579}, {{262.875, 491}, {315.375, 174.375}} -> {-12.2416, \
-17.3854, 0.0318653, 0.0328235}, {{11.9375, 240.062}, {160.25, 19.3125}} -> \
{-27.6155, -10.771, 0.203431, 0.0164579}, {{262.875, 491}, {160.25, 19.3125}} -> \
{-12.3433, -10.7438, 0.0318809, 0.0164198}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comparison to continuous-time Fourier transform (CTFT)", "Subsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .94177 
%%ImageSize: 504 474.65 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.022423 0.47619 [
[ 0 0 0 0 ]
[ 1 .94177 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .94177 L
0 .94177 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.022423 0.477324 0.302711 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0280925 0.280925 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .16855 -18 -4.5 ]
[-0.0125 .16855 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .44948 -18 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .16855 m
.00625 .16855 L
s
[(0.5)] -0.0125 .16855 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(1.5)] -0.0125 .44948 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(2)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .33711 m
.00375 .33711 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .16855 m
1 .16855 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .44948 m
1 .44948 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.01 w
.02381 .02809 m
.02567 .02809 L
.02769 .02809 L
.0296 .02809 L
.03143 .02809 L
.03338 .02809 L
.03525 .02809 L
.03724 .02809 L
.03917 .02809 L
.04101 .02809 L
.04298 .02809 L
.04487 .02809 L
.04669 .02809 L
.04863 .02809 L
.05049 .02809 L
.05248 .02809 L
.05439 .02809 L
.05622 .02809 L
.05818 .02809 L
.06006 .02809 L
.06206 .02809 L
.06399 .02809 L
.06584 .02809 L
.06781 .02809 L
.06971 .02809 L
.07154 .02809 L
.07348 .02809 L
.07535 .02809 L
.07734 .02809 L
.07926 .02809 L
.0811 .02809 L
.08306 .02809 L
.08495 .02809 L
.08677 .02809 L
.0887 .02809 L
.09056 .02809 L
.09254 .02809 L
.09445 .02809 L
.09628 .02809 L
.09823 .02809 L
.10011 .02809 L
.10211 .02809 L
.10403 .02809 L
.10588 .02809 L
.10785 .02809 L
.10974 .02809 L
.11156 .02809 L
.1135 .02809 L
.11537 .02809 L
.11736 .02809 L
Mistroke
.11927 .02809 L
.12111 .02809 L
.12307 .02809 L
.12495 .02809 L
.12695 .02809 L
.12888 .02809 L
.13074 .02809 L
.13271 .02809 L
.13462 .02809 L
.13644 .02809 L
.13839 .02809 L
.14026 .02809 L
.14226 .02809 L
.14418 .02809 L
.14602 .02809 L
.14799 .02809 L
.14988 .02809 L
.15169 .02809 L
.15363 .02809 L
.15549 .02809 L
.15748 .02809 L
.15938 .02809 L
.16122 .02809 L
.16317 .02809 L
.16505 .02809 L
.16705 .02809 L
.16898 .02809 L
.17083 .02809 L
.1728 .02809 L
.1747 .02809 L
.17652 .02809 L
.17846 .02809 L
.18033 .02809 L
.18232 .02809 L
.18424 .02809 L
.18608 .02809 L
.18804 .02809 L
.18993 .02809 L
.19174 .02809 L
.19367 .02809 L
.19553 .02809 L
.19751 .02809 L
.19941 .02809 L
.20124 .02809 L
.20319 .02809 L
.20507 .02809 L
.20706 .02809 L
.20899 .02809 L
.21083 .02809 L
.2128 .02809 L
Mistroke
.21469 .02809 L
.21651 .02809 L
.21845 .02809 L
.22032 .02809 L
.2223 .02809 L
.22421 .02809 L
.22605 .02809 L
.22801 .02809 L
.22989 .02809 L
.23189 .02809 L
.23382 .02809 L
.23567 .02809 L
.23765 .02809 L
.23955 .02809 L
.24137 .02809 L
.24332 .02809 L
.24519 .02809 L
.24718 .02809 L
.2491 .02809 L
.25094 .02809 L
.25291 .02809 L
.2548 .02809 L
.25661 .02809 L
.25855 .02809 L
.26041 .02809 L
.26239 .02809 L
.2643 .02809 L
.26613 .02809 L
.26808 .02809 L
.26996 .02809 L
.27196 .02809 L
.27388 .02809 L
.27573 .02809 L
.2777 .02809 L
.2796 .02809 L
.28142 .02809 L
.28336 .02809 L
.28523 .02809 L
.28722 .02809 L
.28913 .02809 L
.29097 .02809 L
.29293 .02809 L
.29481 .02809 L
.29682 .02809 L
.29875 .02809 L
.3006 .02809 L
.30258 .02809 L
.30448 .02809 L
.30631 .02809 L
.30826 .02809 L
Mistroke
.31014 .02809 L
.31213 .02809 L
.31405 .02809 L
.31589 .02809 L
.31786 .02809 L
.31975 .02809 L
.32157 .02809 L
.32351 .02809 L
.32537 .02809 L
.32735 .02809 L
.32926 .02809 L
.3311 .02809 L
.33305 .02809 L
.33494 .02809 L
.33694 .02809 L
.33886 .02809 L
.34072 .02809 L
.34269 .02809 L
.34459 .02809 L
.34641 .02809 L
.34835 .02809 L
.35023 .02809 L
.35221 .02809 L
.35413 .02809 L
.35597 .02809 L
.35793 .02809 L
.35982 .02809 L
.36164 .02809 L
.36357 .02809 L
.36543 .02809 L
.36741 .02809 L
.36931 .02809 L
.37115 .02809 L
.3731 .02809 L
.37497 .02809 L
.37697 .02809 L
.37889 .02809 L
.38074 .02809 L
.38271 .02809 L
.3846 .02809 L
.38642 .02809 L
.38836 .02809 L
.39023 .02809 L
.39221 .02809 L
.39413 .02809 L
.39597 .02809 L
.39792 .02809 L
.39981 .02809 L
.40181 .02809 L
.40374 .02809 L
Mistroke
.40559 .02809 L
.40757 .02809 L
.40947 .02809 L
.4113 .02809 L
.41324 .02809 L
.41512 .02809 L
.41711 .02809 L
.41903 .02809 L
.42087 .02809 L
.42283 .02809 L
.42472 .02809 L
.42654 .02809 L
.42848 .02809 L
.43034 .02809 L
.43232 .02809 L
.43423 .02809 L
.43606 .02809 L
.43802 .02809 L
.4399 .02809 L
.44189 .02809 L
.44382 .02809 L
.44567 .02809 L
.44764 .02809 L
.44954 .02809 L
.45136 .02809 L
.4533 .02809 L
.45517 .02809 L
.45716 .02809 L
.45907 .02809 L
.46092 .02809 L
.46288 .02809 L
.46476 .02809 L
.46658 .02809 L
.46851 .02809 L
.47037 .02809 L
.47234 .02809 L
.47425 .02809 L
.4752 .02809 L
.47562 .02809 L
.47584 .02809 L
.47596 .02809 L
.47608 .02809 L
.47613 .02809 L
.4762 .30902 L
.47623 .30902 L
.47626 .30902 L
.47633 .30902 L
.47656 .30902 L
.47702 .30902 L
.47802 .30902 L
Mistroke
.47986 .30902 L
.48182 .30902 L
.4837 .30902 L
.4857 .30902 L
.48763 .30902 L
.48948 .30902 L
.49145 .30902 L
.49335 .30902 L
.49518 .30902 L
.49713 .30902 L
.499 .30902 L
.50099 .30902 L
.5029 .30902 L
.50475 .30902 L
.50671 .30902 L
.5086 .30902 L
.51041 .30902 L
.51235 .30902 L
.51421 .30902 L
.51619 .30902 L
.51809 .30902 L
.51993 .30902 L
.52188 .30902 L
.52278 .30902 L
.52325 .30902 L
.52351 .30902 L
.52364 .30902 L
.5237 .30902 L
.52376 .30902 L
.52382 .02809 L
.52388 .02809 L
.52401 .02809 L
.52429 .02809 L
.52478 .02809 L
.52575 .02809 L
.52771 .02809 L
.5296 .02809 L
.5316 .02809 L
.53353 .02809 L
.53539 .02809 L
.53736 .02809 L
.53926 .02809 L
.54109 .02809 L
.54304 .02809 L
.54491 .02809 L
.54691 .02809 L
.54882 .02809 L
.55067 .02809 L
.55264 .02809 L
.55453 .02809 L
Mistroke
.55635 .02809 L
.55828 .02809 L
.56015 .02809 L
.56213 .02809 L
.56404 .02809 L
.56587 .02809 L
.56783 .02809 L
.56971 .02809 L
.5717 .02809 L
.57363 .02809 L
.57548 .02809 L
.57745 .02809 L
.57935 .02809 L
.58118 .02809 L
.58312 .02809 L
.58499 .02809 L
.58698 .02809 L
.58889 .02809 L
.59074 .02809 L
.5927 .02809 L
.59458 .02809 L
.5964 .02809 L
.59833 .02809 L
.60019 .02809 L
.60217 .02809 L
.60407 .02809 L
.6059 .02809 L
.60785 .02809 L
.60973 .02809 L
.61173 .02809 L
.61365 .02809 L
.6155 .02809 L
.61746 .02809 L
.61936 .02809 L
.62118 .02809 L
.62312 .02809 L
.62498 .02809 L
.62697 .02809 L
.62888 .02809 L
.63072 .02809 L
.63267 .02809 L
.63456 .02809 L
.63656 .02809 L
.63849 .02809 L
.64034 .02809 L
.64231 .02809 L
.64422 .02809 L
.64604 .02809 L
.64799 .02809 L
.64986 .02809 L
Mistroke
.65185 .02809 L
.65377 .02809 L
.65561 .02809 L
.65758 .02809 L
.65947 .02809 L
.66128 .02809 L
.66322 .02809 L
.66508 .02809 L
.66706 .02809 L
.66897 .02809 L
.6708 .02809 L
.67275 .02809 L
.67463 .02809 L
.67663 .02809 L
.67856 .02809 L
.68041 .02809 L
.68238 .02809 L
.68427 .02809 L
.6861 .02809 L
.68804 .02809 L
.68991 .02809 L
.69189 .02809 L
.69381 .02809 L
.69565 .02809 L
.69761 .02809 L
.69949 .02809 L
.7015 .02809 L
.70343 .02809 L
.70528 .02809 L
.70726 .02809 L
.70916 .02809 L
.71099 .02809 L
.71294 .02809 L
.71482 .02809 L
.71681 .02809 L
.71873 .02809 L
.72058 .02809 L
.72254 .02809 L
.72444 .02809 L
.72625 .02809 L
.72819 .02809 L
.73006 .02809 L
.73204 .02809 L
.73395 .02809 L
.73579 .02809 L
.73774 .02809 L
.73962 .02809 L
.74162 .02809 L
.74355 .02809 L
.7454 .02809 L
Mistroke
.74737 .02809 L
.74927 .02809 L
.7511 .02809 L
.75304 .02809 L
.75491 .02809 L
.7569 .02809 L
.75882 .02809 L
.76066 .02809 L
.76262 .02809 L
.76451 .02809 L
.76633 .02809 L
.76826 .02809 L
.77012 .02809 L
.7721 .02809 L
.77401 .02809 L
.77584 .02809 L
.77779 .02809 L
.77967 .02809 L
.78166 .02809 L
.78359 .02809 L
.78543 .02809 L
.7874 .02809 L
.7893 .02809 L
.79112 .02809 L
.79306 .02809 L
.79493 .02809 L
.79691 .02809 L
.79882 .02809 L
.80066 .02809 L
.80262 .02809 L
.8045 .02809 L
.80651 .02809 L
.80844 .02809 L
.81029 .02809 L
.81227 .02809 L
.81417 .02809 L
.816 .02809 L
.81794 .02809 L
.81982 .02809 L
.82181 .02809 L
.82373 .02809 L
.82557 .02809 L
.82754 .02809 L
.82943 .02809 L
.83125 .02809 L
.83318 .02809 L
.83504 .02809 L
.83703 .02809 L
.83893 .02809 L
.84077 .02809 L
Mistroke
.84272 .02809 L
.8446 .02809 L
.8466 .02809 L
.84853 .02809 L
.85038 .02809 L
.85235 .02809 L
.85425 .02809 L
.85607 .02809 L
.85801 .02809 L
.85988 .02809 L
.86187 .02809 L
.86378 .02809 L
.86563 .02809 L
.86759 .02809 L
.86947 .02809 L
.87129 .02809 L
.87322 .02809 L
.87508 .02809 L
.87705 .02809 L
.87896 .02809 L
.88079 .02809 L
.88274 .02809 L
.88461 .02809 L
.88661 .02809 L
.88853 .02809 L
.89038 .02809 L
.89234 .02809 L
.89424 .02809 L
.89606 .02809 L
.898 .02809 L
.89986 .02809 L
.90185 .02809 L
.90376 .02809 L
.90559 .02809 L
.90755 .02809 L
.90943 .02809 L
.91143 .02809 L
.91336 .02809 L
.91522 .02809 L
.91719 .02809 L
.91909 .02809 L
.92092 .02809 L
.92286 .02809 L
.92473 .02809 L
.92672 .02809 L
.92864 .02809 L
.93048 .02809 L
.93245 .02809 L
.93434 .02809 L
.93615 .02809 L
Mistroke
.93809 .02809 L
.93995 .02809 L
.94193 .02809 L
.94383 .02809 L
.94567 .02809 L
.94762 .02809 L
.9495 .02809 L
.95149 .02809 L
.95342 .02809 L
.95527 .02809 L
.95724 .02809 L
.95913 .02809 L
.96096 .02809 L
.9629 .02809 L
.96476 .02809 L
.96675 .02809 L
.96866 .02809 L
.9705 .02809 L
.97246 .02809 L
.97435 .02809 L
.97619 .02809 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.022423 0.97619 0.302711 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.11976 2.41779 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11976 -6 -4.5 ]
[-0.0125 .11976 0 4.5 ]
[-0.0125 .24065 -24 -4.5 ]
[-0.0125 .24065 0 4.5 ]
[-0.0125 .36154 -18 -4.5 ]
[-0.0125 .36154 0 4.5 ]
[-0.0125 .48243 -24 -4.5 ]
[-0.0125 .48243 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11976 m
.00625 .11976 L
s
[(0)] -0.0125 .11976 1 0 Mshowa
0 .24065 m
.00625 .24065 L
s
[(0.05)] -0.0125 .24065 1 0 Mshowa
0 .36154 m
.00625 .36154 L
s
[(0.1)] -0.0125 .36154 1 0 Mshowa
0 .48243 m
.00625 .48243 L
s
[(0.15)] -0.0125 .48243 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0.2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .02305 m
.00375 .02305 L
s
0 .04723 m
.00375 .04723 L
s
0 .0714 m
.00375 .0714 L
s
0 .09558 m
.00375 .09558 L
s
0 .14394 m
.00375 .14394 L
s
0 .16812 m
.00375 .16812 L
s
0 .19229 m
.00375 .19229 L
s
0 .21647 m
.00375 .21647 L
s
0 .26483 m
.00375 .26483 L
s
0 .28901 m
.00375 .28901 L
s
0 .31318 m
.00375 .31318 L
s
0 .33736 m
.00375 .33736 L
s
0 .38572 m
.00375 .38572 L
s
0 .4099 m
.00375 .4099 L
s
0 .43407 m
.00375 .43407 L
s
0 .45825 m
.00375 .45825 L
s
0 .50661 m
.00375 .50661 L
s
0 .53079 m
.00375 .53079 L
s
0 .55496 m
.00375 .55496 L
s
0 .57914 m
.00375 .57914 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .11976 m
1 .11976 L
s
.99375 .24065 m
1 .24065 L
s
.99375 .36154 m
1 .36154 L
s
.99375 .48243 m
1 .48243 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .02305 m
1 .02305 L
s
.99625 .04723 m
1 .04723 L
s
.99625 .0714 m
1 .0714 L
s
.99625 .09558 m
1 .09558 L
s
.99625 .14394 m
1 .14394 L
s
.99625 .16812 m
1 .16812 L
s
.99625 .19229 m
1 .19229 L
s
.99625 .21647 m
1 .21647 L
s
.99625 .26483 m
1 .26483 L
s
.99625 .28901 m
1 .28901 L
s
.99625 .31318 m
1 .31318 L
s
.99625 .33736 m
1 .33736 L
s
.99625 .38572 m
1 .38572 L
s
.99625 .4099 m
1 .4099 L
s
.99625 .43407 m
1 .43407 L
s
.99625 .45825 m
1 .45825 L
s
.99625 .50661 m
1 .50661 L
s
.99625 .53079 m
1 .53079 L
s
.99625 .55496 m
1 .55496 L
s
.99625 .57914 m
1 .57914 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11976 m
1 .11976 L
s
.5 0 m
.5 .61803 L
s
1 0 1 r
.01 w
.02381 .11976 m
.02567 .11787 L
.02769 .11578 L
.0296 .11382 L
.03143 .11191 L
.03338 .10987 L
.03525 .1079 L
.03724 .10579 L
.03917 .10376 L
.04101 .10179 L
.04298 .09969 L
.04487 .09767 L
.04669 .09572 L
.04863 .09364 L
.05049 .09164 L
.05248 .08952 L
.05439 .08747 L
.05622 .08551 L
.05818 .08342 L
.06006 .08142 L
.06206 .0793 L
.06399 .07726 L
.06584 .07531 L
.06781 .07325 L
.06971 .07127 L
.07154 .06938 L
.07348 .06739 L
.07535 .06549 L
.07734 .06348 L
.07926 .06157 L
.0811 .05974 L
.08306 .05783 L
.08495 .056 L
.08677 .05427 L
.0887 .05245 L
.09056 .05073 L
.09254 .04892 L
.09445 .04721 L
.09628 .04559 L
.09823 .0439 L
.10011 .04231 L
.10211 .04065 L
.10403 .03909 L
.10588 .03762 L
.10785 .0361 L
.10974 .03468 L
.11156 .03334 L
.1135 .03196 L
.11537 .03068 L
.11736 .02936 L
Mistroke
.11927 .02813 L
.12111 .02699 L
.12307 .02583 L
.12495 .02476 L
.12695 .02368 L
.12888 .02268 L
.13074 .02178 L
.13271 .02087 L
.13462 .02005 L
.13644 .01932 L
.13839 .01859 L
.14026 .01795 L
.14226 .01732 L
.14418 .01678 L
.14602 .01632 L
.14799 .01589 L
.14988 .01554 L
.15169 .01526 L
.15363 .01502 L
.15549 .01486 L
.15646 .0148 L
.15695 .01477 L
.15748 .01475 L
.15797 .01474 L
.15843 .01472 L
.15864 .01472 L
.15876 .01472 L
.15888 .01472 L
.15899 .01472 L
.1591 .01472 L
.15916 .01472 L
.15921 .01472 L
.15926 .01472 L
.15931 .01472 L
.15937 .01472 L
.1594 .01472 L
.15943 .01472 L
.15947 .01472 L
.1595 .01472 L
.15956 .01472 L
.15962 .01472 L
.15968 .01472 L
.15974 .01472 L
.1598 .01472 L
.15994 .01472 L
.16008 .01472 L
.16033 .01472 L
.16057 .01473 L
.16079 .01473 L
.1613 .01475 L
Mistroke
.16176 .01476 L
.1622 .01478 L
.16319 .01484 L
.16417 .01492 L
.16506 .01501 L
.16697 .01524 L
.16881 .01553 L
.17076 .01591 L
.17265 .01635 L
.17465 .01688 L
.17657 .01748 L
.17843 .01812 L
.1804 .01888 L
.1823 .01968 L
.18413 .02052 L
.18607 .02149 L
.18795 .0225 L
.18994 .02365 L
.19185 .02483 L
.1937 .02604 L
.19566 .02741 L
.19755 .0288 L
.19937 .0302 L
.2013 .03178 L
.20316 .03337 L
.20514 .03513 L
.20705 .03692 L
.20888 .0387 L
.21084 .04068 L
.21271 .04266 L
.21471 .04484 L
.21664 .04702 L
.21849 .04919 L
.22046 .05158 L
.22235 .05396 L
.22417 .05631 L
.22612 .0589 L
.22798 .06145 L
.22997 .06425 L
.23188 .06702 L
.23372 .06976 L
.23568 .07274 L
.23757 .07568 L
.23957 .07889 L
.2415 .08205 L
.24336 .08517 L
.24534 .08855 L
.24724 .09188 L
.24907 .09514 L
.25102 .09868 L
Mistroke
.25289 .10216 L
.25488 .10593 L
.2568 .10962 L
.25865 .11324 L
.26061 .11715 L
.26251 .12099 L
.26433 .12473 L
.26626 .12877 L
.26813 .13272 L
.27011 .13698 L
.27202 .14115 L
.27385 .14521 L
.27581 .14958 L
.27769 .15385 L
.27969 .15844 L
.28162 .16292 L
.28347 .16727 L
.28544 .17196 L
.28734 .17652 L
.28917 .18095 L
.29111 .18571 L
.29298 .19033 L
.29497 .19529 L
.29688 .20011 L
.29873 .20479 L
.30069 .2098 L
.30258 .21467 L
.30439 .21938 L
.30632 .22442 L
.30818 .22931 L
.31016 .23454 L
.31207 .23961 L
.3139 .24451 L
.31585 .24975 L
.31773 .25482 L
.31972 .26024 L
.32165 .26547 L
.32349 .27053 L
.32546 .27592 L
.32736 .28113 L
.32918 .28616 L
.33112 .29152 L
.33298 .29669 L
.33497 .30219 L
.33688 .3075 L
.33872 .31262 L
.34068 .31806 L
.34256 .3233 L
.34456 .32887 L
.34649 .33424 L
Mistroke
.34835 .3394 L
.35032 .34488 L
.35222 .35015 L
.35405 .35521 L
.356 .36058 L
.35787 .36574 L
.35986 .37121 L
.36178 .37646 L
.36363 .3815 L
.36559 .38683 L
.36748 .39195 L
.3693 .39684 L
.37123 .40203 L
.3731 .40699 L
.37508 .41224 L
.37698 .41726 L
.37882 .42206 L
.38077 .42713 L
.38265 .43198 L
.38465 .43709 L
.38657 .44197 L
.38843 .44663 L
.3904 .45153 L
.39229 .45621 L
.39412 .46067 L
.39606 .46536 L
.39793 .46983 L
.39992 .47453 L
.40183 .479 L
.40367 .48324 L
.40563 .4877 L
.40752 .49193 L
.40933 .49595 L
.41126 .50016 L
.41312 .50415 L
.4151 .50833 L
.417 .51229 L
.41883 .51603 L
.42078 .51995 L
.42266 .52365 L
.42465 .5275 L
.42657 .53114 L
.42842 .53456 L
.43038 .53813 L
.43228 .54149 L
.4341 .54464 L
.43603 .54792 L
.4379 .551 L
.43988 .55418 L
.44179 .55716 L
Mistroke
.44363 .55995 L
.44559 .56283 L
.44747 .56552 L
.44947 .56828 L
.4514 .57085 L
.45325 .57323 L
.45522 .57567 L
.45712 .57793 L
.45895 .58002 L
.46089 .58214 L
.46277 .5841 L
.46476 .58608 L
.46667 .58788 L
.46852 .58953 L
.47048 .59118 L
.47237 .59268 L
.47418 .59402 L
.47612 .59535 L
.47798 .59654 L
.47996 .5977 L
.48186 .59872 L
.4837 .5996 L
.48565 .60043 L
.48753 .60114 L
.48952 .60178 L
.49145 .60229 L
.4933 .60269 L
.49423 .60285 L
.49526 .603 L
.49625 .60312 L
.49716 .60321 L
.49761 .60324 L
.4981 .60327 L
.49836 .60328 L
.49861 .60329 L
.49887 .6033 L
.4991 .60331 L
.49935 .60331 L
.49947 .60332 L
.49961 .60332 L
.49967 .60332 L
.49973 .60332 L
.49978 .60332 L
.49984 .60332 L
.49987 .60332 L
.49991 .60332 L
.49994 .60332 L
.49997 .60332 L
.50003 .60332 L
.50009 .60332 L
Mistroke
.50015 .60332 L
.50021 .60332 L
.50026 .60332 L
.50031 .60332 L
.50044 .60332 L
.50055 .60331 L
.50076 .60331 L
.50098 .60331 L
.50148 .60329 L
.50201 .60326 L
.50252 .60323 L
.50298 .60319 L
.50389 .60311 L
.50488 .60298 L
.50682 .60267 L
.50869 .60226 L
.51068 .60172 L
.5126 .60109 L
.51444 .6004 L
.5164 .59955 L
.51829 .59864 L
.5201 .59767 L
.52204 .59653 L
.52389 .59535 L
.52587 .59398 L
.52778 .59257 L
.52961 .59111 L
.53156 .58947 L
.53343 .58779 L
.53543 .5859 L
.53735 .58398 L
.5392 .58204 L
.54117 .57989 L
.54306 .57772 L
.54488 .57555 L
.54682 .57314 L
.54869 .57074 L
.55067 .56809 L
.55258 .56545 L
.55442 .56282 L
.55638 .55994 L
.55826 .55708 L
.56026 .55395 L
.56219 .55085 L
.56405 .54779 L
.56602 .54444 L
.56792 .54114 L
.56975 .53789 L
.57169 .53436 L
.57357 .53088 L
Mistroke
.57556 .52711 L
.57747 .52339 L
.57932 .51975 L
.58128 .51581 L
.58317 .51194 L
.58499 .50816 L
.58692 .50406 L
.58879 .50006 L
.59077 .49574 L
.59267 .49151 L
.59451 .48739 L
.59646 .48294 L
.59834 .47861 L
.60033 .47394 L
.60226 .46939 L
.60411 .46496 L
.60608 .46019 L
.60798 .45555 L
.6098 .45105 L
.61174 .44621 L
.61361 .44151 L
.6156 .43646 L
.61751 .43157 L
.61935 .42682 L
.62131 .42173 L
.6232 .41679 L
.6252 .41151 L
.62713 .40639 L
.62899 .40144 L
.63096 .39614 L
.63287 .39101 L
.6347 .38606 L
.63665 .38076 L
.63852 .37564 L
.64051 .37018 L
.64243 .3649 L
.64428 .35981 L
.64625 .35438 L
.64814 .34915 L
.64996 .3441 L
.6519 .33872 L
.65376 .33354 L
.65574 .32802 L
.65765 .32271 L
.65949 .3176 L
.66144 .31216 L
.66333 .30693 L
.66533 .30137 L
.66725 .29603 L
.66911 .2909 L
Mistroke
.67108 .28545 L
.67298 .28021 L
.6748 .27519 L
.67675 .26986 L
.67862 .26475 L
.68061 .25934 L
.68252 .25414 L
.68437 .24917 L
.68633 .2439 L
.68822 .23885 L
.69003 .23403 L
.69197 .22892 L
.69383 .22403 L
.6958 .21887 L
.69771 .21393 L
.69954 .20921 L
.70149 .20423 L
.70337 .19947 L
.70537 .19445 L
.70729 .18966 L
.70914 .18509 L
.71111 .18028 L
.713 .17569 L
.71482 .17132 L
.71676 .16672 L
.71863 .16234 L
.72062 .15773 L
.72253 .15335 L
.72437 .14919 L
.72632 .14481 L
.72821 .14065 L
.73021 .13629 L
.73214 .13215 L
.734 .12823 L
.73597 .12411 L
.73787 .12021 L
.7397 .11652 L
.74165 .11265 L
.74352 .109 L
.74551 .10517 L
.74743 .10156 L
.74928 .09815 L
.75124 .09459 L
.75313 .09122 L
.75495 .08806 L
.75689 .08475 L
.75875 .08164 L
.76073 .0784 L
.76264 .07536 L
.76447 .0725 L
Mistroke
.76643 .06953 L
.76831 .06674 L
.7703 .06386 L
.77223 .06116 L
.77408 .05863 L
.77605 .05602 L
.77795 .05358 L
.77977 .0513 L
.78172 .04895 L
.78359 .04677 L
.78557 .04452 L
.78749 .04244 L
.78933 .04051 L
.79129 .03853 L
.79318 .0367 L
.79499 .03501 L
.79692 .03329 L
.79878 .03171 L
.80076 .0301 L
.80266 .02864 L
.80449 .0273 L
.80644 .02595 L
.80832 .02472 L
.81031 .0235 L
.81223 .0224 L
.81408 .02141 L
.81605 .02044 L
.81794 .01957 L
.81976 .01881 L
.8217 .01807 L
.82357 .01743 L
.82555 .01683 L
.82746 .01632 L
.8293 .0159 L
.83125 .01552 L
.83314 .01522 L
.8341 .0151 L
.83514 .01499 L
.83606 .0149 L
.83706 .01483 L
.83802 .01477 L
.83855 .01475 L
.83904 .01474 L
.83928 .01473 L
.83954 .01472 L
.83979 .01472 L
.83991 .01472 L
.84002 .01472 L
.84012 .01472 L
.84022 .01472 L
Mistroke
.84027 .01472 L
.84033 .01472 L
.84039 .01472 L
.84045 .01472 L
.84051 .01472 L
.84057 .01472 L
.84063 .01472 L
.84069 .01472 L
.84074 .01472 L
.84079 .01472 L
.84091 .01472 L
.84103 .01472 L
.84113 .01472 L
.84138 .01472 L
.8416 .01473 L
.84181 .01473 L
.84229 .01474 L
.84281 .01476 L
.84375 .01481 L
.84476 .01488 L
.84677 .01506 L
.8487 .01531 L
.85055 .01561 L
.85253 .016 L
.85443 .01643 L
.85626 .0169 L
.85821 .01746 L
.86008 .01806 L
.86208 .01876 L
.864 .01949 L
.86584 .02025 L
.86781 .02111 L
.8697 .02199 L
.87152 .02289 L
.87346 .02389 L
.87532 .02491 L
.8773 .02604 L
.87921 .02719 L
.88105 .02833 L
.883 .02959 L
.88488 .03085 L
.88688 .03223 L
.88881 .03361 L
.89066 .03498 L
.89263 .03647 L
.89453 .03795 L
.89636 .0394 L
.8983 .04099 L
.90017 .04255 L
.90216 .04424 L
Mistroke
.90407 .0459 L
.90592 .04753 L
.90788 .0493 L
.90976 .05103 L
.91158 .05272 L
.91351 .05454 L
.91537 .05632 L
.91735 .05823 L
.91925 .0601 L
.92109 .06191 L
.92304 .06386 L
.92491 .06576 L
.92691 .06779 L
.92883 .06977 L
.93068 .07168 L
.93265 .07373 L
.93454 .07571 L
.93636 .07763 L
.9383 .07968 L
.94017 .08166 L
.94215 .08377 L
.94407 .08582 L
.9459 .08778 L
.94786 .08988 L
.94974 .0919 L
.95175 .09405 L
.95367 .09611 L
.95553 .0981 L
.9575 .10021 L
.9594 .10224 L
.96123 .10418 L
.96318 .10624 L
.96505 .10822 L
.96704 .11031 L
.96896 .11232 L
.97081 .11423 L
.97277 .11626 L
.97466 .1182 L
.97619 .11976 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.330739 0.477324 0.611027 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0280925 0.280925 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .16855 -18 -4.5 ]
[-0.0125 .16855 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .44948 -18 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .16855 m
.00625 .16855 L
s
[(0.5)] -0.0125 .16855 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(1.5)] -0.0125 .44948 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(2)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .33711 m
.00375 .33711 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .16855 m
1 .16855 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .44948 m
1 .44948 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .02809 m
.02567 .02809 L
.02769 .02809 L
.0296 .02809 L
.03143 .02809 L
.03338 .02809 L
.03525 .02809 L
.03724 .02809 L
.03917 .02809 L
.04101 .02809 L
.04298 .02809 L
.04487 .02809 L
.04669 .02809 L
.04863 .02809 L
.05049 .02809 L
.05248 .02809 L
.05439 .02809 L
.05622 .02809 L
.05818 .02809 L
.06006 .02809 L
.06206 .02809 L
.06399 .02809 L
.06584 .02809 L
.06781 .02809 L
.06971 .02809 L
.07154 .02809 L
.07348 .02809 L
.07535 .02809 L
.07734 .02809 L
.07926 .02809 L
.0811 .02809 L
.08306 .02809 L
.08495 .02809 L
.08677 .02809 L
.0887 .02809 L
.09056 .02809 L
.09254 .02809 L
.09445 .02809 L
.09628 .02809 L
.09823 .02809 L
.10011 .02809 L
.10211 .02809 L
.10403 .02809 L
.10588 .02809 L
.10785 .02809 L
.10974 .02809 L
.11156 .02809 L
.1135 .02809 L
.11537 .02809 L
.11736 .02809 L
Mistroke
.11927 .02809 L
.12111 .02809 L
.12307 .02809 L
.12495 .02809 L
.12695 .02809 L
.12888 .02809 L
.13074 .02809 L
.13271 .02809 L
.13462 .02809 L
.13644 .02809 L
.13839 .02809 L
.14026 .02809 L
.14226 .02809 L
.14418 .02809 L
.14602 .02809 L
.14799 .02809 L
.14988 .02809 L
.15169 .02809 L
.15363 .02809 L
.15549 .02809 L
.15748 .02809 L
.15938 .02809 L
.16122 .02809 L
.16317 .02809 L
.16505 .02809 L
.16705 .02809 L
.16898 .02809 L
.17083 .02809 L
.1728 .02809 L
.1747 .02809 L
.17652 .02809 L
.17846 .02809 L
.18033 .02809 L
.18232 .02809 L
.18424 .02809 L
.18608 .02809 L
.18804 .02809 L
.18993 .02809 L
.19174 .02809 L
.19367 .02809 L
.19553 .02809 L
.19751 .02809 L
.19941 .02809 L
.20124 .02809 L
.20319 .02809 L
.20507 .02809 L
.20706 .02809 L
.20899 .02809 L
.21083 .02809 L
.2128 .02809 L
Mistroke
.21469 .02809 L
.21651 .02809 L
.21845 .02809 L
.22032 .02809 L
.2223 .02809 L
.22421 .02809 L
.22605 .02809 L
.22801 .02809 L
.22989 .02809 L
.23189 .02809 L
.23382 .02809 L
.23567 .02809 L
.23765 .02809 L
.23955 .02809 L
.24137 .02809 L
.24332 .02809 L
.24519 .02809 L
.24718 .02809 L
.2491 .02809 L
.25094 .02809 L
.25291 .02809 L
.2548 .02809 L
.25661 .02809 L
.25855 .02809 L
.26041 .02809 L
.26239 .02809 L
.2643 .02809 L
.26613 .02809 L
.26808 .02809 L
.26996 .02809 L
.27196 .02809 L
.27388 .02809 L
.27573 .02809 L
.2777 .02809 L
.2796 .02809 L
.28142 .02809 L
.28336 .02809 L
.28523 .02809 L
.28722 .02809 L
.28913 .02809 L
.29097 .02809 L
.29293 .02809 L
.29481 .02809 L
.29682 .02809 L
.29875 .02809 L
.3006 .02809 L
.30258 .02809 L
.30448 .02809 L
.30631 .02809 L
.30826 .02809 L
Mistroke
.31014 .02809 L
.31213 .02809 L
.31405 .02809 L
.31589 .02809 L
.31786 .02809 L
.31975 .02809 L
.32157 .02809 L
.32351 .02809 L
.32537 .02809 L
.32735 .02809 L
.32926 .02809 L
.3311 .02809 L
.33305 .02809 L
.33494 .02809 L
.33694 .02809 L
.33886 .02809 L
.34072 .02809 L
.34269 .02809 L
.34459 .02809 L
.34641 .02809 L
.34835 .02809 L
.35023 .02809 L
.35221 .02809 L
.35413 .02809 L
.35597 .02809 L
.35793 .02809 L
.35982 .02809 L
.36164 .02809 L
.36357 .02809 L
.36543 .02809 L
.36741 .02809 L
.36931 .02809 L
.37115 .02809 L
.3731 .02809 L
.37497 .02809 L
.37697 .02809 L
.37889 .02809 L
.37977 .02809 L
.38027 .02809 L
.38052 .02809 L
.38074 .02809 L
.38085 .02809 L
.38088 .02809 L
.38092 .02809 L
.38098 .30902 L
.38104 .30902 L
.38109 .30902 L
.3812 .30902 L
.3817 .30902 L
.38271 .30902 L
Mistroke
.38456 .30902 L
.38654 .30902 L
.38844 .30902 L
.39027 .30902 L
.39221 .30902 L
.39409 .30902 L
.39608 .30902 L
.398 .30902 L
.39984 .30902 L
.4018 .30902 L
.4037 .30902 L
.40551 .30902 L
.40745 .30902 L
.40931 .30902 L
.41129 .30902 L
.4132 .30902 L
.41503 .30902 L
.41699 .30902 L
.41887 .30902 L
.42086 .30902 L
.42279 .30902 L
.42464 .30902 L
.42661 .30902 L
.42851 .30902 L
.43033 .30902 L
.43227 .30902 L
.43414 .30902 L
.43613 .30902 L
.43805 .30902 L
.43989 .30902 L
.44185 .30902 L
.44373 .30902 L
.44555 .30902 L
.44748 .30902 L
.44934 .30902 L
.45131 .30902 L
.45322 .30902 L
.45505 .30902 L
.457 .30902 L
.45887 .30902 L
.46086 .30902 L
.46279 .30902 L
.46463 .30902 L
.4666 .30902 L
.46849 .30902 L
.47031 .30902 L
.47225 .30902 L
.47412 .30902 L
.4761 .30902 L
.47801 .30902 L
Mistroke
.47985 .30902 L
.4818 .30902 L
.48368 .30902 L
.48568 .30902 L
.48761 .30902 L
.48947 .30902 L
.49144 .30902 L
.49334 .30902 L
.49517 .30902 L
.49711 .30902 L
.49898 .30902 L
.50097 .30902 L
.50289 .30902 L
.50473 .30902 L
.50669 .30902 L
.50858 .30902 L
.5104 .30902 L
.51233 .30902 L
.51419 .30902 L
.51617 .30902 L
.51808 .30902 L
.51991 .30902 L
.52186 .30902 L
.52374 .30902 L
.52574 .30902 L
.52766 .30902 L
.52951 .30902 L
.53148 .30902 L
.53338 .30902 L
.5352 .30902 L
.53714 .30902 L
.53901 .30902 L
.54099 .30902 L
.5429 .30902 L
.54474 .30902 L
.5467 .30902 L
.54859 .30902 L
.55059 .30902 L
.55252 .30902 L
.55438 .30902 L
.55635 .30902 L
.55825 .30902 L
.56008 .30902 L
.56203 .30902 L
.5639 .30902 L
.5659 .30902 L
.56782 .30902 L
.56966 .30902 L
.57163 .30902 L
.57352 .30902 L
Mistroke
.57534 .30902 L
.57727 .30902 L
.57914 .30902 L
.58112 .30902 L
.58303 .30902 L
.58486 .30902 L
.58682 .30902 L
.5887 .30902 L
.5907 .30902 L
.59262 .30902 L
.59447 .30902 L
.59645 .30902 L
.59834 .30902 L
.60017 .30902 L
.60211 .30902 L
.60398 .30902 L
.60597 .30902 L
.60789 .30902 L
.60973 .30902 L
.61169 .30902 L
.61358 .30902 L
.61539 .30902 L
.6164 .30902 L
.61732 .30902 L
.61823 .30902 L
.61868 .30902 L
.61881 .30902 L
.61888 .30902 L
.61894 .30902 L
.619 .30902 L
.61904 .30902 L
.61907 .02809 L
.61912 .02809 L
.61918 .02809 L
.621 .02809 L
.62294 .02809 L
.62481 .02809 L
.62679 .02809 L
.6287 .02809 L
.63054 .02809 L
.6325 .02809 L
.63438 .02809 L
.63638 .02809 L
.63831 .02809 L
.64017 .02809 L
.64214 .02809 L
.64404 .02809 L
.64587 .02809 L
.64781 .02809 L
.64969 .02809 L
Mistroke
.65168 .02809 L
.65359 .02809 L
.65544 .02809 L
.6574 .02809 L
.65929 .02809 L
.66111 .02809 L
.66304 .02809 L
.66491 .02809 L
.66689 .02809 L
.66879 .02809 L
.67063 .02809 L
.67258 .02809 L
.67446 .02809 L
.67646 .02809 L
.67838 .02809 L
.68023 .02809 L
.6822 .02809 L
.6841 .02809 L
.68592 .02809 L
.68786 .02809 L
.68973 .02809 L
.69172 .02809 L
.69363 .02809 L
.69547 .02809 L
.69743 .02809 L
.69932 .02809 L
.70132 .02809 L
.70325 .02809 L
.70511 .02809 L
.70708 .02809 L
.70899 .02809 L
.71082 .02809 L
.71277 .02809 L
.71464 .02809 L
.71663 .02809 L
.71855 .02809 L
.7204 .02809 L
.72237 .02809 L
.72426 .02809 L
.72608 .02809 L
.72802 .02809 L
.72988 .02809 L
.73186 .02809 L
.73377 .02809 L
.73561 .02809 L
.73756 .02809 L
.73945 .02809 L
.74145 .02809 L
.74337 .02809 L
.74523 .02809 L
Mistroke
.7472 .02809 L
.7491 .02809 L
.75092 .02809 L
.75287 .02809 L
.75474 .02809 L
.75673 .02809 L
.75864 .02809 L
.76049 .02809 L
.76245 .02809 L
.76434 .02809 L
.76615 .02809 L
.76809 .02809 L
.76995 .02809 L
.77192 .02809 L
.77383 .02809 L
.77566 .02809 L
.77761 .02809 L
.77949 .02809 L
.78149 .02809 L
.78341 .02809 L
.78526 .02809 L
.78723 .02809 L
.78912 .02809 L
.79094 .02809 L
.79288 .02809 L
.79475 .02809 L
.79674 .02809 L
.79865 .02809 L
.80049 .02809 L
.80245 .02809 L
.80433 .02809 L
.80633 .02809 L
.80826 .02809 L
.81012 .02809 L
.81209 .02809 L
.81399 .02809 L
.81582 .02809 L
.81777 .02809 L
.81964 .02809 L
.82163 .02809 L
.82355 .02809 L
.8254 .02809 L
.82736 .02809 L
.82925 .02809 L
.83107 .02809 L
.83301 .02809 L
.83487 .02809 L
.83685 .02809 L
.83876 .02809 L
.84059 .02809 L
Mistroke
.84255 .02809 L
.84443 .02809 L
.84643 .02809 L
.84835 .02809 L
.8502 .02809 L
.85217 .02809 L
.85407 .02809 L
.85589 .02809 L
.85784 .02809 L
.85971 .02809 L
.86169 .02809 L
.86361 .02809 L
.86545 .02809 L
.86741 .02809 L
.8693 .02809 L
.87111 .02809 L
.87304 .02809 L
.8749 .02809 L
.87688 .02809 L
.87878 .02809 L
.88061 .02809 L
.88256 .02809 L
.88444 .02809 L
.88643 .02809 L
.88835 .02809 L
.8902 .02809 L
.89217 .02809 L
.89406 .02809 L
.89588 .02809 L
.89782 .02809 L
.89969 .02809 L
.90167 .02809 L
.90358 .02809 L
.90542 .02809 L
.90737 .02809 L
.90926 .02809 L
.91126 .02809 L
.91319 .02809 L
.91504 .02809 L
.91701 .02809 L
.91891 .02809 L
.92074 .02809 L
.92268 .02809 L
.92456 .02809 L
.92655 .02809 L
.92846 .02809 L
.93031 .02809 L
.93227 .02809 L
.93416 .02809 L
.93598 .02809 L
Mistroke
.93791 .02809 L
.93977 .02809 L
.94175 .02809 L
.94366 .02809 L
.94549 .02809 L
.94744 .02809 L
.94932 .02809 L
.95132 .02809 L
.95324 .02809 L
.95509 .02809 L
.95706 .02809 L
.95896 .02809 L
.96078 .02809 L
.96272 .02809 L
.96459 .02809 L
.96658 .02809 L
.96849 .02809 L
.97033 .02809 L
.97229 .02809 L
.97417 .02809 L
.97618 .02809 L
.97619 .02809 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.330739 0.97619 0.611027 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.11976 0.483559 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02305 -24 -4.5 ]
[-0.0125 .02305 0 4.5 ]
[-0.0125 .11976 -6 -4.5 ]
[-0.0125 .11976 0 4.5 ]
[-0.0125 .21647 -18 -4.5 ]
[-0.0125 .21647 0 4.5 ]
[-0.0125 .31318 -18 -4.5 ]
[-0.0125 .31318 0 4.5 ]
[-0.0125 .4099 -18 -4.5 ]
[-0.0125 .4099 0 4.5 ]
[-0.0125 .50661 -18 -4.5 ]
[-0.0125 .50661 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02305 m
.00625 .02305 L
s
[(-0.2)] -0.0125 .02305 1 0 Mshowa
0 .11976 m
.00625 .11976 L
s
[(0)] -0.0125 .11976 1 0 Mshowa
0 .21647 m
.00625 .21647 L
s
[(0.2)] -0.0125 .21647 1 0 Mshowa
0 .31318 m
.00625 .31318 L
s
[(0.4)] -0.0125 .31318 1 0 Mshowa
0 .4099 m
.00625 .4099 L
s
[(0.6)] -0.0125 .4099 1 0 Mshowa
0 .50661 m
.00625 .50661 L
s
[(0.8)] -0.0125 .50661 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04723 m
.00375 .04723 L
s
0 .0714 m
.00375 .0714 L
s
0 .09558 m
.00375 .09558 L
s
0 .14394 m
.00375 .14394 L
s
0 .16812 m
.00375 .16812 L
s
0 .19229 m
.00375 .19229 L
s
0 .24065 m
.00375 .24065 L
s
0 .26483 m
.00375 .26483 L
s
0 .28901 m
.00375 .28901 L
s
0 .33736 m
.00375 .33736 L
s
0 .36154 m
.00375 .36154 L
s
0 .38572 m
.00375 .38572 L
s
0 .43407 m
.00375 .43407 L
s
0 .45825 m
.00375 .45825 L
s
0 .48243 m
.00375 .48243 L
s
0 .53079 m
.00375 .53079 L
s
0 .55496 m
.00375 .55496 L
s
0 .57914 m
.00375 .57914 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02305 m
1 .02305 L
s
.99375 .11976 m
1 .11976 L
s
.99375 .21647 m
1 .21647 L
s
.99375 .31318 m
1 .31318 L
s
.99375 .4099 m
1 .4099 L
s
.99375 .50661 m
1 .50661 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04723 m
1 .04723 L
s
.99625 .0714 m
1 .0714 L
s
.99625 .09558 m
1 .09558 L
s
.99625 .14394 m
1 .14394 L
s
.99625 .16812 m
1 .16812 L
s
.99625 .19229 m
1 .19229 L
s
.99625 .24065 m
1 .24065 L
s
.99625 .26483 m
1 .26483 L
s
.99625 .28901 m
1 .28901 L
s
.99625 .33736 m
1 .33736 L
s
.99625 .36154 m
1 .36154 L
s
.99625 .38572 m
1 .38572 L
s
.99625 .43407 m
1 .43407 L
s
.99625 .45825 m
1 .45825 L
s
.99625 .48243 m
1 .48243 L
s
.99625 .53079 m
1 .53079 L
s
.99625 .55496 m
1 .55496 L
s
.99625 .57914 m
1 .57914 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11976 m
1 .11976 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .11976 m
.02567 .11787 L
.02769 .11583 L
.0296 .11395 L
.03143 .11223 L
.03338 .11049 L
.03525 .10895 L
.03724 .10749 L
.03917 .10627 L
.04101 .10528 L
.04195 .10487 L
.04298 .10447 L
.04397 .10415 L
.04487 .10392 L
.0458 .10374 L
.04632 .10366 L
.04658 .10363 L
.04681 .10361 L
.04703 .10359 L
.04727 .10357 L
.0474 .10357 L
.04752 .10356 L
.04765 .10356 L
.04776 .10355 L
.04786 .10355 L
.04792 .10355 L
.04797 .10355 L
.04802 .10355 L
.04808 .10355 L
.04814 .10355 L
.04819 .10355 L
.04825 .10355 L
.0483 .10355 L
.04835 .10355 L
.04841 .10355 L
.04853 .10355 L
.04865 .10356 L
.04887 .10357 L
.04912 .10358 L
.04956 .10362 L
.05008 .10368 L
.05055 .10376 L
.05147 .10394 L
.05247 .10422 L
.05444 .10495 L
.05634 .1059 L
.05816 .10702 L
.0601 .10843 L
.06197 .10998 L
.06395 .1118 L
Mistroke
.06587 .1137 L
.0677 .11564 L
.06966 .11778 L
.07155 .11989 L
.07355 .12216 L
.07548 .12432 L
.07734 .12635 L
.07931 .12842 L
.08121 .13029 L
.08304 .13195 L
.08499 .13353 L
.08686 .13486 L
.08885 .13603 L
.08985 .13651 L
.09077 .1369 L
.09172 .13723 L
.09262 .13748 L
.09352 .13768 L
.09399 .13775 L
.09426 .13779 L
.09451 .13782 L
.09475 .13784 L
.09497 .13785 L
.09521 .13787 L
.09535 .13787 L
.09541 .13788 L
.09547 .13788 L
.09553 .13788 L
.0956 .13788 L
.09563 .13788 L
.09567 .13788 L
.09573 .13788 L
.09579 .13788 L
.09585 .13788 L
.09591 .13788 L
.09596 .13788 L
.09602 .13788 L
.09608 .13788 L
.09622 .13787 L
.09635 .13787 L
.09649 .13786 L
.09673 .13785 L
.09695 .13783 L
.09745 .13777 L
.09794 .1377 L
.09847 .1376 L
.09949 .13734 L
.10046 .13703 L
.10231 .13622 L
.10428 .13509 L
Mistroke
.10617 .13374 L
.10799 .13222 L
.10993 .13039 L
.11179 .12845 L
.11378 .12623 L
.11569 .12395 L
.11753 .12168 L
.11948 .11921 L
.12137 .11681 L
.12337 .11429 L
.1253 .11192 L
.12715 .10975 L
.12912 .10757 L
.13102 .10565 L
.13285 .10399 L
.1348 .10246 L
.13667 .10125 L
.13762 .10073 L
.13866 .10025 L
.13957 .0999 L
.14058 .0996 L
.14103 .09949 L
.14153 .09939 L
.14205 .09931 L
.1423 .09928 L
.14254 .09926 L
.14276 .09924 L
.14288 .09924 L
.143 .09923 L
.14307 .09923 L
.14313 .09922 L
.1432 .09922 L
.14326 .09922 L
.14332 .09922 L
.14338 .09922 L
.14344 .09922 L
.14347 .09922 L
.1435 .09922 L
.14357 .09922 L
.1436 .09922 L
.14363 .09922 L
.14369 .09922 L
.14375 .09922 L
.14382 .09922 L
.14388 .09923 L
.14402 .09923 L
.14414 .09924 L
.14426 .09924 L
.14452 .09927 L
.14501 .09932 L
Mistroke
.14546 .09939 L
.14647 .09961 L
.14739 .09989 L
.14839 .10029 L
.15035 .10131 L
.15224 .1026 L
.15406 .1041 L
.156 .10597 L
.15786 .10801 L
.15984 .11039 L
.16175 .11286 L
.16359 .11537 L
.16554 .11814 L
.16743 .12086 L
.16943 .12377 L
.17135 .12654 L
.17321 .12914 L
.17518 .13177 L
.17708 .13415 L
.1789 .13625 L
.18085 .13824 L
.18272 .1399 L
.1847 .14134 L
.1857 .14193 L
.18662 .1424 L
.18757 .14279 L
.18846 .14308 L
.18936 .14329 L
.18984 .14337 L
.19011 .14341 L
.19035 .14343 L
.19058 .14345 L
.19071 .14346 L
.19082 .14346 L
.19093 .14346 L
.19099 .14347 L
.19105 .14347 L
.1911 .14347 L
.19115 .14347 L
.19121 .14347 L
.19126 .14347 L
.19132 .14347 L
.19136 .14347 L
.19139 .14347 L
.19145 .14347 L
.19151 .14346 L
.19163 .14346 L
.19174 .14345 L
.19201 .14344 L
.19226 .14341 L
Mistroke
.19273 .14335 L
.19322 .14326 L
.19411 .14304 L
.19506 .14271 L
.19594 .14232 L
.19781 .14123 L
.19981 .1397 L
.20172 .13787 L
.20357 .13582 L
.20553 .13335 L
.20742 .13072 L
.20924 .128 L
.21118 .12493 L
.21304 .12186 L
.21502 .11852 L
.21693 .11527 L
.21876 .11218 L
.22071 .10896 L
.22259 .10599 L
.22459 .10303 L
.22652 .10041 L
.22837 .09814 L
.23034 .09606 L
.23224 .09441 L
.23406 .09317 L
.235 .09268 L
.236 .09226 L
.23649 .0921 L
.23702 .09196 L
.23752 .09186 L
.23775 .09182 L
.23799 .09179 L
.23823 .09176 L
.23834 .09175 L
.23845 .09174 L
.23855 .09174 L
.23866 .09173 L
.23872 .09173 L
.23878 .09173 L
.23883 .09173 L
.23889 .09173 L
.23894 .09173 L
.23901 .09173 L
.23904 .09173 L
.23907 .09173 L
.23913 .09173 L
.23919 .09173 L
.23925 .09173 L
.23936 .09174 L
.23949 .09174 L
Mistroke
.23961 .09175 L
.23988 .09178 L
.24012 .09181 L
.24038 .09185 L
.24086 .09195 L
.24176 .0922 L
.24272 .09259 L
.24373 .09311 L
.24556 .09437 L
.2475 .09614 L
.24937 .09824 L
.25136 .10087 L
.25328 .10375 L
.25512 .10681 L
.25709 .11033 L
.25897 .11392 L
.26079 .11751 L
.26272 .12143 L
.26459 .12524 L
.26656 .12926 L
.26847 .13305 L
.2703 .13655 L
.27226 .14007 L
.27413 .14319 L
.27613 .14617 L
.27805 .14866 L
.2799 .15064 L
.28084 .15149 L
.28187 .15229 L
.28286 .15292 L
.28377 .15338 L
.2847 .15373 L
.28522 .15387 L
.28548 .15392 L
.28571 .15396 L
.28593 .154 L
.28617 .15402 L
.2863 .15403 L
.28642 .15404 L
.28654 .15405 L
.2866 .15405 L
.28663 .15405 L
.28666 .15405 L
.28672 .15405 L
.28678 .15405 L
.28683 .15405 L
.28688 .15405 L
.28694 .15405 L
.287 .15405 L
.28706 .15405 L
Mistroke
.28712 .15404 L
.28723 .15404 L
.28733 .15403 L
.28755 .15401 L
.28778 .15398 L
.28802 .15394 L
.28846 .15384 L
.28898 .15369 L
.28946 .15352 L
.29038 .15308 L
.29138 .15247 L
.29335 .15082 L
.29525 .1487 L
.29708 .1462 L
.29902 .14306 L
.30089 .13961 L
.30288 .13555 L
.30479 .13129 L
.30664 .12694 L
.3086 .1221 L
.31048 .11731 L
.3123 .11265 L
.31423 .10771 L
.31609 .10303 L
.31807 .09824 L
.31997 .09387 L
.3218 .08997 L
.32375 .08621 L
.32563 .08304 L
.32762 .08022 L
.32955 .0781 L
.33043 .07733 L
.3314 .07664 L
.33235 .07613 L
.33287 .07592 L
.33336 .07578 L
.3336 .07572 L
.33386 .07567 L
.33398 .07565 L
.33411 .07564 L
.33423 .07562 L
.33434 .07561 L
.33445 .07561 L
.33451 .0756 L
.33454 .0756 L
.33458 .0756 L
.33463 .0756 L
.33469 .0756 L
.33475 .0756 L
.3348 .0756 L
Mistroke
.33486 .0756 L
.33491 .0756 L
.33496 .0756 L
.33502 .07561 L
.33512 .07561 L
.33523 .07562 L
.33546 .07565 L
.33571 .07569 L
.33616 .0758 L
.33664 .07596 L
.33716 .07618 L
.33811 .07671 L
.33912 .07748 L
.34111 .07957 L
.34304 .08231 L
.34489 .08558 L
.34686 .08972 L
.34875 .09429 L
.35058 .09917 L
.35252 .10483 L
.35439 .11066 L
.35637 .11717 L
.35829 .12366 L
.36013 .13002 L
.36209 .13679 L
.36397 .14323 L
.36598 .14986 L
.36791 .15594 L
.36977 .1614 L
.37174 .16668 L
.37364 .17116 L
.37547 .17482 L
.37742 .17794 L
.37832 .17909 L
.3793 .18012 L
.37983 .18059 L
.38032 .18095 L
.38082 .18126 L
.38129 .18149 L
.38173 .18165 L
.38197 .18172 L
.38219 .18177 L
.38231 .18179 L
.38243 .18181 L
.38251 .18182 L
.38257 .18182 L
.38264 .18183 L
.3827 .18183 L
.38276 .18183 L
.38282 .18184 L
Mistroke
.38288 .18184 L
.38292 .18184 L
.38295 .18184 L
.38301 .18184 L
.38306 .18183 L
.38312 .18183 L
.38318 .18183 L
.3833 .18182 L
.3834 .1818 L
.38365 .18176 L
.38389 .18171 L
.38414 .18163 L
.3846 .18144 L
.38503 .18122 L
.38594 .18058 L
.38693 .17961 L
.38788 .17843 L
.38888 .1769 L
.39088 .17303 L
.3928 .16829 L
.39465 .1628 L
.39662 .15604 L
.39851 .14869 L
.40034 .14093 L
.40228 .13201 L
.40414 .12288 L
.40613 .11273 L
.40804 .10266 L
.40988 .09282 L
.41184 .08235 L
.41372 .07242 L
.41572 .06221 L
.41765 .05286 L
.41951 .0445 L
.42148 .03643 L
.42338 .02964 L
.42521 .02415 L
.42623 .02158 L
.42716 .01957 L
.42813 .01781 L
.42903 .01653 L
.42995 .01556 L
.43044 .01519 L
.43071 .01503 L
.43095 .01491 L
.43117 .01483 L
.4314 .01477 L
.43152 .01475 L
.43164 .01473 L
.4317 .01472 L
Mistroke
.43176 .01472 L
.43179 .01472 L
.43183 .01472 L
.43186 .01472 L
.43189 .01472 L
.43194 .01472 L
.432 .01472 L
.43205 .01472 L
.43209 .01472 L
.43215 .01473 L
.43221 .01474 L
.43232 .01476 L
.43243 .01478 L
.43255 .01482 L
.43277 .01489 L
.433 .015 L
.43322 .01512 L
.43371 .01548 L
.43413 .01589 L
.43458 .01641 L
.43553 .01785 L
.43642 .01958 L
.43829 .02458 L
.44029 .03188 L
.44221 .04088 L
.44405 .05136 L
.44602 .06444 L
.44791 .07889 L
.44973 .09443 L
.45167 .11268 L
.45354 .1318 L
.45552 .15367 L
.45743 .17609 L
.45927 .19877 L
.46123 .22392 L
.46311 .24893 L
.46511 .27616 L
.46704 .3028 L
.46889 .32859 L
.47087 .35597 L
.47276 .38204 L
.47459 .40663 L
.47654 .43207 L
.47841 .45561 L
.4804 .47938 L
.48232 .50085 L
.48416 .51999 L
.48612 .53854 L
.48801 .55446 L
.48983 .56784 L
Mistroke
.49176 .57987 L
.49362 .58919 L
.49457 .59304 L
.4956 .59657 L
.4966 .59928 L
.49751 .60115 L
.498 .60191 L
.49845 .60248 L
.49894 .60292 L
.49921 .6031 L
.49934 .60317 L
.49946 .60322 L
.49957 .60325 L
.49969 .60328 L
.49975 .6033 L
.49981 .60331 L
.49987 .60331 L
.49993 .60332 L
.49999 .60332 L
.50005 .60332 L
.5001 .60332 L
.50016 .60331 L
.50021 .6033 L
.50026 .6033 L
.50036 .60327 L
.50049 .60323 L
.50061 .60319 L
.50088 .60305 L
.50112 .60288 L
.50136 .60267 L
.50182 .60215 L
.50232 .60144 L
.5032 .59973 L
.50414 .59732 L
.50502 .59452 L
.50689 .58685 L
.50887 .57619 L
.51078 .56359 L
.51261 .5494 L
.51457 .53224 L
.51645 .51384 L
.51845 .49247 L
.52037 .4703 L
.52223 .44771 L
.5242 .42254 L
.5261 .39742 L
.52792 .37264 L
.52987 .34584 L
.53174 .31983 L
.53373 .29222 L
Mistroke
.53564 .26587 L
.53748 .24098 L
.53944 .21518 L
.54133 .19122 L
.54315 .16915 L
.54508 .14687 L
.54694 .12675 L
.54892 .10694 L
.55082 .08951 L
.55265 .07436 L
.5546 .06006 L
.55648 .04813 L
.55848 .03746 L
.5604 .02914 L
.56225 .02296 L
.56318 .0205 L
.56422 .0183 L
.56519 .01671 L
.56611 .01565 L
.56661 .01524 L
.56686 .01508 L
.56709 .01496 L
.56731 .01486 L
.56751 .0148 L
.56763 .01477 L
.56774 .01475 L
.56785 .01473 L
.56792 .01472 L
.56798 .01472 L
.56804 .01472 L
.56809 .01472 L
.56815 .01472 L
.5682 .01472 L
.56826 .01472 L
.56829 .01472 L
.56833 .01473 L
.56845 .01474 L
.56855 .01476 L
.56867 .01479 L
.56888 .01485 L
.56914 .01495 L
.5694 .01509 L
.56988 .01542 L
.57034 .01582 L
.57083 .01636 L
.57171 .01757 L
.57371 .02144 L
.57563 .02656 L
.57749 .03262 L
.57946 .04015 L
Mistroke
.58135 .04829 L
.58318 .05681 L
.58512 .06645 L
.58699 .07613 L
.58897 .08668 L
.59089 .09693 L
.59273 .10674 L
.59469 .11695 L
.59657 .12644 L
.59839 .13513 L
.60032 .1438 L
.60218 .15147 L
.60415 .15881 L
.60606 .16501 L
.60789 .1701 L
.60984 .17454 L
.61171 .17784 L
.61274 .17922 L
.61371 .18026 L
.61417 .18067 L
.61467 .18103 L
.61513 .18131 L
.61555 .18151 L
.61601 .18168 L
.61626 .18174 L
.61637 .18177 L
.61649 .18179 L
.61661 .1818 L
.61671 .18182 L
.61676 .18182 L
.61682 .18183 L
.61687 .18183 L
.61691 .18183 L
.61697 .18183 L
.61703 .18184 L
.61709 .18184 L
.61715 .18184 L
.61721 .18184 L
.61727 .18183 L
.61732 .18183 L
.61737 .18183 L
.61749 .18182 L
.61761 .1818 L
.61782 .18177 L
.61809 .18171 L
.61832 .18163 L
.61882 .18144 L
.61933 .18117 L
.62028 .18049 L
.62117 .17966 L
Mistroke
.62305 .17727 L
.62504 .17385 L
.62696 .16979 L
.62881 .16525 L
.63078 .15983 L
.63268 .15413 L
.6345 .1483 L
.63644 .14183 L
.63831 .13543 L
.64029 .12855 L
.64221 .12197 L
.64405 .11577 L
.646 .10941 L
.64789 .10361 L
.64989 .09788 L
.65182 .09285 L
.65368 .08853 L
.65565 .08457 L
.65755 .0814 L
.65938 .07898 L
.6604 .07791 L
.66133 .07712 L
.66229 .07646 L
.6632 .07602 L
.66367 .07585 L
.66392 .07578 L
.66416 .07572 L
.66438 .07568 L
.66458 .07565 L
.66481 .07562 L
.66493 .07561 L
.66499 .07561 L
.66505 .0756 L
.66511 .0756 L
.66514 .0756 L
.66517 .0756 L
.66523 .0756 L
.66529 .0756 L
.66535 .0756 L
.6654 .0756 L
.66546 .0756 L
.66551 .0756 L
.66563 .07561 L
.6657 .07562 L
.66576 .07562 L
.666 .07565 L
.6662 .07568 L
.66643 .07573 L
.66689 .07584 L
.66737 .07601 L
Mistroke
.66781 .07621 L
.66882 .07678 L
.66973 .07745 L
.67072 .07835 L
.67267 .0806 L
.67455 .08332 L
.67654 .08675 L
.67846 .09051 L
.68031 .0945 L
.68228 .09906 L
.68417 .10368 L
.68599 .10828 L
.68793 .11325 L
.6898 .11803 L
.69178 .12305 L
.69369 .12773 L
.69553 .13203 L
.69749 .13632 L
.69937 .14012 L
.70137 .14373 L
.7033 .14675 L
.70515 .1492 L
.70713 .15127 L
.70811 .1521 L
.70903 .15274 L
.70997 .15326 L
.71086 .15364 L
.71132 .15378 L
.71157 .15385 L
.71184 .15391 L
.71206 .15395 L
.7123 .15399 L
.71252 .15402 L
.71273 .15403 L
.71285 .15404 L
.71295 .15405 L
.71302 .15405 L
.71307 .15405 L
.71311 .15405 L
.71314 .15405 L
.7132 .15405 L
.71326 .15405 L
.7133 .15405 L
.71333 .15405 L
.71336 .15405 L
.71339 .15405 L
.71346 .15405 L
.71352 .15404 L
.71358 .15404 L
.7137 .15403 L
Mistroke
.71392 .15401 L
.71416 .15398 L
.71459 .15391 L
.71509 .15379 L
.71562 .15362 L
.71659 .15321 L
.71755 .15267 L
.71857 .15196 L
.7204 .15035 L
.72235 .14817 L
.72422 .14567 L
.72621 .14263 L
.72813 .13939 L
.72998 .13602 L
.73195 .13223 L
.73384 .12845 L
.73566 .12474 L
.7376 .12078 L
.73946 .11701 L
.74144 .11311 L
.74335 .10952 L
.74519 .10628 L
.74714 .10309 L
.74902 .10033 L
.75102 .09777 L
.75295 .0957 L
.7548 .09409 L
.75574 .09344 L
.75678 .09283 L
.75776 .09238 L
.75867 .09207 L
.75918 .09194 L
.75965 .09184 L
.76008 .09178 L
.76032 .09176 L
.76044 .09175 L
.76055 .09174 L
.76065 .09174 L
.76077 .09173 L
.76083 .09173 L
.76088 .09173 L
.76094 .09173 L
.76098 .09173 L
.76101 .09173 L
.76106 .09173 L
.76112 .09173 L
.76117 .09173 L
.76123 .09173 L
.76128 .09173 L
.76133 .09173 L
Mistroke
.76144 .09174 L
.76157 .09175 L
.76169 .09175 L
.76192 .09178 L
.76217 .09181 L
.76243 .09185 L
.76293 .09195 L
.76338 .09206 L
.76439 .09241 L
.76532 .09283 L
.76632 .0934 L
.76829 .09483 L
.77019 .09659 L
.77202 .0986 L
.77397 .10104 L
.77584 .10365 L
.77783 .10665 L
.77975 .10972 L
.7816 .11278 L
.78356 .1161 L
.78545 .11932 L
.78727 .12237 L
.78921 .12555 L
.79107 .12847 L
.79305 .1314 L
.79496 .13399 L
.79679 .13624 L
.79874 .13835 L
.80062 .14006 L
.80262 .14151 L
.80362 .1421 L
.80455 .14254 L
.80551 .14291 L
.8064 .14318 L
.80684 .14327 L
.8073 .14336 L
.80757 .14339 L
.80782 .14342 L
.80805 .14344 L
.80817 .14345 L
.8083 .14346 L
.80842 .14346 L
.80847 .14346 L
.80853 .14347 L
.80858 .14347 L
.80864 .14347 L
.80869 .14347 L
.80875 .14347 L
.80878 .14347 L
.80881 .14347 L
Mistroke
.80885 .14347 L
.80888 .14347 L
.80894 .14347 L
.80898 .14347 L
.80901 .14347 L
.80912 .14346 L
.80925 .14346 L
.80938 .14345 L
.80952 .14344 L
.80977 .14342 L
.81002 .14339 L
.81026 .14336 L
.81077 .14327 L
.81124 .14316 L
.81214 .14289 L
.81311 .14252 L
.81399 .1421 L
.81589 .14094 L
.81772 .13954 L
.81966 .13775 L
.82154 .13576 L
.82353 .13342 L
.82544 .13096 L
.82729 .12846 L
.82925 .12569 L
.83114 .12295 L
.83295 .12031 L
.83489 .11752 L
.83675 .1149 L
.83873 .11222 L
.84064 .10979 L
.84247 .10763 L
.84442 .10555 L
.8463 .10378 L
.8483 .1022 L
.85022 .10098 L
.85207 .1001 L
.85303 .09976 L
.85351 .09962 L
.85404 .09949 L
.85453 .09939 L
.85498 .09932 L
.8552 .09929 L
.85543 .09927 L
.85564 .09925 L
.85586 .09924 L
.85599 .09923 L
.85612 .09923 L
.85623 .09922 L
.85629 .09922 L
Mistroke
.85633 .09922 L
.85636 .09922 L
.85642 .09922 L
.85647 .09922 L
.85653 .09922 L
.85659 .09922 L
.85665 .09922 L
.8567 .09922 L
.85675 .09922 L
.85681 .09922 L
.85694 .09923 L
.85706 .09923 L
.85733 .09925 L
.85758 .09927 L
.85782 .0993 L
.85828 .09936 L
.85877 .09945 L
.85965 .09966 L
.86068 .09999 L
.86165 .10038 L
.86351 .10135 L
.86548 .10266 L
.86738 .10419 L
.8692 .10586 L
.87114 .10785 L
.87301 .10993 L
.875 .11228 L
.87692 .11465 L
.87876 .11697 L
.88072 .11947 L
.88261 .12185 L
.88442 .12409 L
.88636 .12638 L
.88822 .12846 L
.89019 .13052 L
.8921 .1323 L
.89393 .13381 L
.89588 .13519 L
.89776 .13625 L
.89871 .1367 L
.89975 .1371 L
.90067 .13739 L
.90119 .13752 L
.90167 .13763 L
.90217 .13772 L
.90263 .13778 L
.90312 .13784 L
.90338 .13786 L
.90352 .13786 L
.90364 .13787 L
Mistroke
.90376 .13787 L
.90382 .13788 L
.90388 .13788 L
.90394 .13788 L
.904 .13788 L
.90405 .13788 L
.9041 .13788 L
.90413 .13788 L
.90417 .13788 L
.90423 .13788 L
.90428 .13788 L
.90434 .13788 L
.9044 .13788 L
.90446 .13788 L
.90459 .13788 L
.90471 .13787 L
.90481 .13787 L
.90505 .13785 L
.90526 .13784 L
.90548 .13782 L
.90594 .13776 L
.90643 .13769 L
.90731 .1375 L
.90834 .13721 L
.90931 .13687 L
.91116 .13602 L
.91313 .13487 L
.91503 .13352 L
.91685 .13204 L
.91879 .13028 L
.92066 .12845 L
.92265 .12637 L
.92456 .12427 L
.9264 .12221 L
.92836 .12 L
.93025 .11788 L
.93225 .11568 L
.93418 .11365 L
.93604 .11181 L
.93802 .10999 L
.93992 .10842 L
.94175 .10708 L
.9437 .10588 L
.94557 .10494 L
.94653 .10455 L
.94757 .1042 L
.94857 .10394 L
.94904 .10383 L
.94949 .10375 L
.94996 .10368 L
Mistroke
.95039 .10363 L
.95062 .1036 L
.95087 .10358 L
.95113 .10357 L
.95126 .10356 L
.95138 .10356 L
.9515 .10355 L
.95157 .10355 L
.95164 .10355 L
.9517 .10355 L
.95175 .10355 L
.95181 .10355 L
.95185 .10355 L
.95188 .10355 L
.95193 .10355 L
.95199 .10355 L
.95205 .10355 L
.95211 .10355 L
.95221 .10355 L
.95233 .10356 L
.95246 .10356 L
.95258 .10357 L
.95285 .10358 L
.95308 .1036 L
.95333 .10362 L
.95379 .10368 L
.95428 .10375 L
.95517 .10393 L
.95619 .1042 L
.95716 .10452 L
.95901 .1053 L
.96098 .10635 L
.96288 .10757 L
.9647 .10892 L
.96664 .1105 L
.96851 .11216 L
.97049 .11404 L
.9724 .11592 L
.97424 .11778 L
.97619 .11976 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.639056 0.477324 0.919343 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0280925 0.280925 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .16855 -18 -4.5 ]
[-0.0125 .16855 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .44948 -18 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .16855 m
.00625 .16855 L
s
[(0.5)] -0.0125 .16855 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(1.5)] -0.0125 .44948 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(2)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .33711 m
.00375 .33711 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .16855 m
1 .16855 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .44948 m
1 .44948 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .02809 m
.02567 .02809 L
.02769 .02809 L
.0296 .02809 L
.03143 .02809 L
.03338 .02809 L
.03525 .02809 L
.03724 .02809 L
.03917 .02809 L
.04101 .02809 L
.04298 .02809 L
.04487 .02809 L
.04669 .02809 L
.04863 .02809 L
.05049 .02809 L
.05248 .02809 L
.05439 .02809 L
.05622 .02809 L
.05818 .02809 L
.06006 .02809 L
.06206 .02809 L
.06399 .02809 L
.06584 .02809 L
.06781 .02809 L
.06971 .02809 L
.07154 .02809 L
.07348 .02809 L
.07535 .02809 L
.07734 .02809 L
.07926 .02809 L
.0811 .02809 L
.08306 .02809 L
.08495 .02809 L
.08677 .02809 L
.0887 .02809 L
.09056 .02809 L
.09254 .02809 L
.09445 .02809 L
.09628 .02809 L
.09823 .02809 L
.10011 .02809 L
.10211 .02809 L
.10403 .02809 L
.10588 .02809 L
.10785 .02809 L
.10974 .02809 L
.11156 .02809 L
.1135 .02809 L
.11537 .02809 L
.11736 .02809 L
Mistroke
.11927 .02809 L
.12111 .02809 L
.12307 .02809 L
.12495 .02809 L
.12695 .02809 L
.12888 .02809 L
.13074 .02809 L
.13271 .02809 L
.13462 .02809 L
.13644 .02809 L
.13839 .02809 L
.14026 .02809 L
.14226 .02809 L
.14418 .02809 L
.14602 .02809 L
.14799 .02809 L
.14988 .02809 L
.15169 .02809 L
.15363 .02809 L
.15549 .02809 L
.15748 .02809 L
.15938 .02809 L
.16122 .02809 L
.16317 .02809 L
.16505 .02809 L
.16705 .02809 L
.16898 .02809 L
.17083 .02809 L
.1728 .02809 L
.1747 .02809 L
.17652 .02809 L
.17846 .02809 L
.18033 .02809 L
.18232 .02809 L
.18424 .02809 L
.18608 .02809 L
.18804 .02809 L
.18993 .02809 L
.19174 .02809 L
.19367 .02809 L
.19553 .02809 L
.19751 .02809 L
.19941 .02809 L
.20124 .02809 L
.20319 .02809 L
.20507 .02809 L
.20706 .02809 L
.20899 .02809 L
.21083 .02809 L
.2128 .02809 L
Mistroke
.21469 .02809 L
.21651 .02809 L
.21845 .02809 L
.22032 .02809 L
.2223 .02809 L
.22421 .02809 L
.22605 .02809 L
.22801 .02809 L
.22989 .02809 L
.23189 .02809 L
.23382 .02809 L
.23567 .02809 L
.23765 .02809 L
.23955 .02809 L
.24137 .02809 L
.24332 .02809 L
.24519 .02809 L
.24718 .02809 L
.2491 .02809 L
.25094 .02809 L
.25291 .02809 L
.2548 .02809 L
.25661 .02809 L
.25855 .02809 L
.26041 .02809 L
.26137 .02809 L
.26161 .02809 L
.26174 .02809 L
.2618 .02809 L
.26186 .02809 L
.26189 .02809 L
.26193 .30902 L
.26196 .30902 L
.262 .30902 L
.26213 .30902 L
.26239 .30902 L
.26433 .30902 L
.2662 .30902 L
.26818 .30902 L
.2701 .30902 L
.27194 .30902 L
.2739 .30902 L
.27578 .30902 L
.27779 .30902 L
.27972 .30902 L
.28157 .30902 L
.28355 .30902 L
.28545 .30902 L
.28728 .30902 L
.28923 .30902 L
Mistroke
.2911 .30902 L
.2931 .30902 L
.29502 .30902 L
.29686 .30902 L
.29883 .30902 L
.30072 .30902 L
.30254 .30902 L
.30448 .30902 L
.30634 .30902 L
.30832 .30902 L
.31023 .30902 L
.31207 .30902 L
.31402 .30902 L
.3159 .30902 L
.3179 .30902 L
.31983 .30902 L
.32168 .30902 L
.32366 .30902 L
.32555 .30902 L
.32738 .30902 L
.32932 .30902 L
.33119 .30902 L
.33318 .30902 L
.3351 .30902 L
.33694 .30902 L
.3389 .30902 L
.34079 .30902 L
.34261 .30902 L
.34454 .30902 L
.3464 .30902 L
.34838 .30902 L
.35028 .30902 L
.35211 .30902 L
.35406 .30902 L
.35594 .30902 L
.35794 .30902 L
.35986 .30902 L
.36171 .30902 L
.36368 .30902 L
.36557 .30902 L
.36739 .30902 L
.36933 .30902 L
.3712 .30902 L
.37318 .30902 L
.3751 .30902 L
.37693 .30902 L
.37889 .30902 L
.38077 .30902 L
.38278 .30902 L
.38471 .30902 L
Mistroke
.38656 .30902 L
.38854 .30902 L
.39044 .30902 L
.39226 .30902 L
.39421 .30902 L
.39608 .30902 L
.39808 .30902 L
.39999 .30902 L
.40184 .30902 L
.4038 .30902 L
.40569 .30902 L
.40751 .30902 L
.40945 .30902 L
.41131 .30902 L
.41329 .30902 L
.4152 .30902 L
.41703 .30902 L
.41898 .30902 L
.42086 .30902 L
.42286 .30902 L
.42479 .30902 L
.42664 .30902 L
.42861 .30902 L
.43051 .30902 L
.43233 .30902 L
.43427 .30902 L
.43614 .30902 L
.43813 .30902 L
.44004 .30902 L
.44188 .30902 L
.44384 .30902 L
.44573 .30902 L
.44754 .30902 L
.44948 .30902 L
.45133 .30902 L
.45331 .30902 L
.45521 .30902 L
.45704 .30902 L
.45899 .30902 L
.46087 .30902 L
.46286 .30902 L
.46478 .30902 L
.46663 .30902 L
.4686 .30902 L
.47049 .30902 L
.47231 .30902 L
.47425 .30902 L
.47611 .30902 L
.4781 .30902 L
.48001 .30902 L
Mistroke
.48184 .30902 L
.4838 .30902 L
.48568 .30902 L
.48768 .30902 L
.48961 .30902 L
.49146 .30902 L
.49344 .30902 L
.49534 .30902 L
.49716 .30902 L
.49911 .30902 L
.50098 .30902 L
.50297 .30902 L
.50489 .30902 L
.50673 .30902 L
.50869 .30902 L
.51058 .30902 L
.5124 .30902 L
.51433 .30902 L
.51619 .30902 L
.51817 .30902 L
.52008 .30902 L
.52191 .30902 L
.52386 .30902 L
.52574 .30902 L
.52774 .30902 L
.52966 .30902 L
.53151 .30902 L
.53348 .30902 L
.53537 .30902 L
.5372 .30902 L
.53914 .30902 L
.541 .30902 L
.54299 .30902 L
.5449 .30902 L
.54674 .30902 L
.5487 .30902 L
.55058 .30902 L
.55259 .30902 L
.55452 .30902 L
.55637 .30902 L
.55835 .30902 L
.56025 .30902 L
.56208 .30902 L
.56403 .30902 L
.5659 .30902 L
.56789 .30902 L
.56981 .30902 L
.57166 .30902 L
.57362 .30902 L
.57552 .30902 L
Mistroke
.57733 .30902 L
.57927 .30902 L
.58113 .30902 L
.58312 .30902 L
.58502 .30902 L
.58686 .30902 L
.58881 .30902 L
.5907 .30902 L
.59269 .30902 L
.59462 .30902 L
.59647 .30902 L
.59844 .30902 L
.60034 .30902 L
.60217 .30902 L
.60411 .30902 L
.60598 .30902 L
.60797 .30902 L
.60988 .30902 L
.61173 .30902 L
.61369 .30902 L
.61557 .30902 L
.61739 .30902 L
.61932 .30902 L
.62118 .30902 L
.62316 .30902 L
.62506 .30902 L
.62689 .30902 L
.62884 .30902 L
.63072 .30902 L
.63271 .30902 L
.63464 .30902 L
.63649 .30902 L
.63845 .30902 L
.64035 .30902 L
.64217 .30902 L
.64411 .30902 L
.64597 .30902 L
.64796 .30902 L
.64987 .30902 L
.65171 .30902 L
.65366 .30902 L
.65555 .30902 L
.65755 .30902 L
.65947 .30902 L
.66133 .30902 L
.6633 .30902 L
.6652 .30902 L
.66703 .30902 L
.66898 .30902 L
.67085 .30902 L
Mistroke
.67284 .30902 L
.67476 .30902 L
.6766 .30902 L
.67857 .30902 L
.68046 .30902 L
.68227 .30902 L
.68421 .30902 L
.68607 .30902 L
.68805 .30902 L
.68996 .30902 L
.69179 .30902 L
.69374 .30902 L
.69562 .30902 L
.69762 .30902 L
.69954 .30902 L
.7014 .30902 L
.70336 .30902 L
.70526 .30902 L
.70708 .30902 L
.70903 .30902 L
.7109 .30902 L
.71288 .30902 L
.7148 .30902 L
.71664 .30902 L
.71859 .30902 L
.72048 .30902 L
.72248 .30902 L
.72442 .30902 L
.72627 .30902 L
.72825 .30902 L
.73015 .30902 L
.73198 .30902 L
.73393 .30902 L
.73581 .30902 L
.73676 .30902 L
.73726 .30902 L
.73754 .30902 L
.7378 .30902 L
.73792 .30902 L
.73803 .30902 L
.73809 .30902 L
.73812 .02809 L
.73816 .02809 L
.73827 .02809 L
.7388 .02809 L
.73972 .02809 L
.7416 .02809 L
.7436 .02809 L
.74553 .02809 L
.74738 .02809 L
Mistroke
.74935 .02809 L
.75125 .02809 L
.75308 .02809 L
.75502 .02809 L
.75689 .02809 L
.75888 .02809 L
.7608 .02809 L
.76264 .02809 L
.7646 .02809 L
.76649 .02809 L
.76831 .02809 L
.77024 .02809 L
.7721 .02809 L
.77408 .02809 L
.77598 .02809 L
.77782 .02809 L
.77977 .02809 L
.78165 .02809 L
.78364 .02809 L
.78556 .02809 L
.78741 .02809 L
.78938 .02809 L
.79128 .02809 L
.7931 .02809 L
.79504 .02809 L
.79691 .02809 L
.79889 .02809 L
.8008 .02809 L
.80264 .02809 L
.8046 .02809 L
.80648 .02809 L
.80849 .02809 L
.81042 .02809 L
.81227 .02809 L
.81425 .02809 L
.81615 .02809 L
.81798 .02809 L
.81992 .02809 L
.8218 .02809 L
.82379 .02809 L
.82571 .02809 L
.82755 .02809 L
.82952 .02809 L
.83141 .02809 L
.83322 .02809 L
.83516 .02809 L
.83702 .02809 L
.839 .02809 L
.84091 .02809 L
.84275 .02809 L
Mistroke
.8447 .02809 L
.84658 .02809 L
.84858 .02809 L
.8505 .02809 L
.85236 .02809 L
.85433 .02809 L
.85622 .02809 L
.85805 .02809 L
.85999 .02809 L
.86186 .02809 L
.86385 .02809 L
.86576 .02809 L
.86761 .02809 L
.86956 .02809 L
.87145 .02809 L
.87327 .02809 L
.8752 .02809 L
.87706 .02809 L
.87903 .02809 L
.88094 .02809 L
.88277 .02809 L
.88472 .02809 L
.88659 .02809 L
.88859 .02809 L
.89051 .02809 L
.89236 .02809 L
.89432 .02809 L
.89622 .02809 L
.89804 .02809 L
.89998 .02809 L
.90184 .02809 L
.90382 .02809 L
.90574 .02809 L
.90757 .02809 L
.90953 .02809 L
.91141 .02809 L
.91341 .02809 L
.91534 .02809 L
.91719 .02809 L
.91917 .02809 L
.92107 .02809 L
.92289 .02809 L
.92484 .02809 L
.92671 .02809 L
.9287 .02809 L
.93062 .02809 L
.93246 .02809 L
.93442 .02809 L
.93631 .02809 L
.93813 .02809 L
Mistroke
.94006 .02809 L
.94193 .02809 L
.94391 .02809 L
.94581 .02809 L
.94765 .02809 L
.9496 .02809 L
.95148 .02809 L
.95347 .02809 L
.9554 .02809 L
.95725 .02809 L
.95922 .02809 L
.96111 .02809 L
.96293 .02809 L
.96488 .02809 L
.96674 .02809 L
.96873 .02809 L
.97064 .02809 L
.97248 .02809 L
.97444 .02809 L
.97619 .02809 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.639056 0.97619 0.919343 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.11976 0.24178 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11976 -6 -4.5 ]
[-0.0125 .11976 0 4.5 ]
[-0.0125 .24065 -18 -4.5 ]
[-0.0125 .24065 0 4.5 ]
[-0.0125 .36154 -6 -4.5 ]
[-0.0125 .36154 0 4.5 ]
[-0.0125 .48243 -18 -4.5 ]
[-0.0125 .48243 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11976 m
.00625 .11976 L
s
[(0)] -0.0125 .11976 1 0 Mshowa
0 .24065 m
.00625 .24065 L
s
[(0.5)] -0.0125 .24065 1 0 Mshowa
0 .36154 m
.00625 .36154 L
s
[(1)] -0.0125 .36154 1 0 Mshowa
0 .48243 m
.00625 .48243 L
s
[(1.5)] -0.0125 .48243 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .02305 m
.00375 .02305 L
s
0 .04723 m
.00375 .04723 L
s
0 .0714 m
.00375 .0714 L
s
0 .09558 m
.00375 .09558 L
s
0 .14394 m
.00375 .14394 L
s
0 .16812 m
.00375 .16812 L
s
0 .19229 m
.00375 .19229 L
s
0 .21647 m
.00375 .21647 L
s
0 .26483 m
.00375 .26483 L
s
0 .28901 m
.00375 .28901 L
s
0 .31318 m
.00375 .31318 L
s
0 .33736 m
.00375 .33736 L
s
0 .38572 m
.00375 .38572 L
s
0 .4099 m
.00375 .4099 L
s
0 .43407 m
.00375 .43407 L
s
0 .45825 m
.00375 .45825 L
s
0 .50661 m
.00375 .50661 L
s
0 .53079 m
.00375 .53079 L
s
0 .55496 m
.00375 .55496 L
s
0 .57914 m
.00375 .57914 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .11976 m
1 .11976 L
s
.99375 .24065 m
1 .24065 L
s
.99375 .36154 m
1 .36154 L
s
.99375 .48243 m
1 .48243 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .02305 m
1 .02305 L
s
.99625 .04723 m
1 .04723 L
s
.99625 .0714 m
1 .0714 L
s
.99625 .09558 m
1 .09558 L
s
.99625 .14394 m
1 .14394 L
s
.99625 .16812 m
1 .16812 L
s
.99625 .19229 m
1 .19229 L
s
.99625 .21647 m
1 .21647 L
s
.99625 .26483 m
1 .26483 L
s
.99625 .28901 m
1 .28901 L
s
.99625 .31318 m
1 .31318 L
s
.99625 .33736 m
1 .33736 L
s
.99625 .38572 m
1 .38572 L
s
.99625 .4099 m
1 .4099 L
s
.99625 .43407 m
1 .43407 L
s
.99625 .45825 m
1 .45825 L
s
.99625 .50661 m
1 .50661 L
s
.99625 .53079 m
1 .53079 L
s
.99625 .55496 m
1 .55496 L
s
.99625 .57914 m
1 .57914 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11976 m
1 .11976 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
.02381 .11976 m
.02567 .11788 L
.02769 .11595 L
.0296 .11437 L
.03143 .11316 L
.03237 .11267 L
.03338 .11228 L
.03387 .11213 L
.03413 .11207 L
.0344 .11201 L
.03464 .11196 L
.0349 .11193 L
.03514 .1119 L
.03525 .11189 L
.03537 .11188 L
.03549 .11187 L
.03555 .11187 L
.03561 .11187 L
.03564 .11187 L
.03568 .11187 L
.03571 .11187 L
.03574 .11187 L
.03581 .11187 L
.03584 .11187 L
.03587 .11187 L
.03593 .11187 L
.03599 .11187 L
.03604 .11187 L
.0361 .11187 L
.03623 .11188 L
.03634 .11188 L
.03655 .1119 L
.03678 .11193 L
.03723 .112 L
.03772 .11211 L
.03816 .11224 L
.03917 .11262 L
.04008 .11308 L
.04107 .11369 L
.04302 .11519 L
.0449 .11694 L
.0469 .11899 L
.04882 .12104 L
.05067 .12296 L
.05264 .1248 L
.05453 .12627 L
.05549 .12686 L
.05636 .12731 L
.05729 .12768 L
.05781 .12784 L
Mistroke
.0583 .12795 L
.05854 .12799 L
.05876 .12802 L
.05888 .12804 L
.05902 .12805 L
.05913 .12806 L
.05925 .12807 L
.05931 .12807 L
.05937 .12808 L
.05942 .12808 L
.05948 .12808 L
.05951 .12808 L
.05954 .12808 L
.0596 .12808 L
.05965 .12808 L
.05971 .12808 L
.05976 .12808 L
.05982 .12808 L
.05987 .12808 L
.05991 .12808 L
.06002 .12807 L
.06014 .12806 L
.06038 .12804 L
.0606 .12802 L
.06085 .12798 L
.06109 .12793 L
.06197 .12769 L
.06244 .12752 L
.06294 .12731 L
.06382 .12685 L
.06565 .12559 L
.06759 .12387 L
.06946 .12194 L
.07145 .11974 L
.07336 .11759 L
.07521 .11564 L
.07717 .11381 L
.07814 .11303 L
.07905 .11241 L
.07994 .1119 L
.08087 .11148 L
.08133 .11131 L
.08184 .11117 L
.08206 .11112 L
.0823 .11107 L
.08251 .11103 L
.08273 .11101 L
.08285 .11099 L
.08298 .11098 L
.0831 .11097 L
Mistroke
.08322 .11097 L
.08325 .11097 L
.08329 .11097 L
.08332 .11097 L
.08335 .11096 L
.08339 .11096 L
.08342 .11096 L
.08348 .11096 L
.08351 .11096 L
.08354 .11096 L
.08358 .11096 L
.08362 .11096 L
.08368 .11097 L
.08375 .11097 L
.08388 .11098 L
.08399 .11098 L
.08425 .11101 L
.08449 .11104 L
.08472 .11108 L
.08519 .11119 L
.08568 .11134 L
.08657 .11169 L
.0875 .11219 L
.08838 .11276 L
.09024 .11428 L
.09222 .11628 L
.09413 .11844 L
.09596 .12063 L
.09792 .12291 L
.09979 .12494 L
.10179 .12676 L
.10279 .12751 L
.10372 .12808 L
.10461 .12852 L
.10507 .1287 L
.10557 .12885 L
.10582 .12892 L
.10606 .12897 L
.10629 .12901 L
.10651 .12904 L
.10671 .12906 L
.10683 .12907 L
.10693 .12908 L
.10704 .12909 L
.10711 .12909 L
.10717 .12909 L
.10722 .12909 L
.10728 .12909 L
.10733 .12909 L
.10739 .12909 L
Mistroke
.10745 .12909 L
.10748 .12909 L
.10752 .12909 L
.10763 .12908 L
.1077 .12908 L
.10777 .12907 L
.10789 .12906 L
.10814 .12903 L
.10837 .129 L
.10883 .1289 L
.10926 .12877 L
.11022 .1284 L
.1111 .12793 L
.11298 .12656 L
.11498 .12463 L
.11691 .12243 L
.11876 .12012 L
.12073 .11763 L
.12263 .11534 L
.12446 .11337 L
.1264 .11167 L
.1273 .11105 L
.12827 .11051 L
.1288 .11028 L
.12929 .11011 L
.12976 .10998 L
.13 .10993 L
.13026 .10989 L
.1305 .10986 L
.13062 .10985 L
.13075 .10984 L
.13086 .10983 L
.13092 .10983 L
.13098 .10983 L
.13103 .10983 L
.13109 .10983 L
.13114 .10983 L
.13119 .10983 L
.13125 .10983 L
.13131 .10983 L
.13137 .10983 L
.13142 .10984 L
.13155 .10984 L
.13168 .10986 L
.13192 .10989 L
.13219 .10993 L
.13269 .11004 L
.13314 .11018 L
.13415 .11062 L
.13508 .11117 L
Mistroke
.13608 .11191 L
.13805 .11376 L
.13995 .11596 L
.14178 .11831 L
.14373 .12094 L
.1456 .12342 L
.14759 .12584 L
.14951 .12781 L
.15136 .12923 L
.15231 .12975 L
.15279 .12996 L
.15332 .13014 L
.15356 .13021 L
.15381 .13026 L
.15402 .1303 L
.15425 .13034 L
.15438 .13035 L
.1545 .13036 L
.15456 .13037 L
.15462 .13037 L
.15468 .13037 L
.15473 .13037 L
.15479 .13038 L
.15483 .13038 L
.15486 .13038 L
.1549 .13038 L
.15494 .13038 L
.15497 .13038 L
.155 .13038 L
.15507 .13038 L
.1551 .13038 L
.15513 .13037 L
.1552 .13037 L
.15526 .13037 L
.15537 .13036 L
.15549 .13035 L
.15574 .13032 L
.15595 .13028 L
.15618 .13023 L
.15671 .13009 L
.15719 .12991 L
.15811 .12945 L
.15911 .12879 L
.16107 .12703 L
.16297 .12486 L
.16479 .12244 L
.16673 .11968 L
.16859 .11698 L
.17057 .11428 L
.17248 .11199 L
Mistroke
.17432 .11023 L
.17527 .10953 L
.17628 .10895 L
.17677 .10874 L
.17703 .10865 L
.17731 .10856 L
.17755 .1085 L
.17781 .10844 L
.17805 .1084 L
.17816 .10839 L
.17828 .10838 L
.1784 .10837 L
.17846 .10836 L
.17852 .10836 L
.17855 .10836 L
.17858 .10836 L
.17864 .10836 L
.17867 .10836 L
.17871 .10836 L
.17875 .10836 L
.17878 .10836 L
.17884 .10836 L
.1789 .10836 L
.17895 .10836 L
.17901 .10836 L
.17914 .10837 L
.17926 .10838 L
.17946 .10841 L
.17969 .10844 L
.18015 .10855 L
.18064 .10871 L
.18108 .10889 L
.18209 .10945 L
.183 .11012 L
.184 .11101 L
.18596 .11321 L
.18784 .11576 L
.18985 .11878 L
.19178 .12179 L
.19363 .1246 L
.19561 .1273 L
.19751 .12946 L
.19847 .13033 L
.19934 .13098 L
.20028 .13152 L
.2008 .13174 L
.20103 .13182 L
.20129 .1319 L
.20151 .13196 L
.20175 .13201 L
Mistroke
.20189 .13203 L
.20201 .13204 L
.20213 .13206 L
.20225 .13207 L
.2023 .13207 L
.20235 .13207 L
.20241 .13208 L
.20246 .13208 L
.20252 .13208 L
.20258 .13208 L
.20264 .13208 L
.2027 .13208 L
.20275 .13207 L
.20281 .13207 L
.20291 .13207 L
.20303 .13206 L
.20313 .13204 L
.20336 .13201 L
.20361 .13196 L
.20405 .13184 L
.20452 .13167 L
.20505 .13142 L
.20598 .13085 L
.20698 .13003 L
.20896 .1279 L
.21086 .12529 L
.21269 .12242 L
.21464 .11915 L
.21652 .116 L
.21852 .11286 L
.22044 .11025 L
.22229 .10828 L
.22324 .10751 L
.22373 .10719 L
.22425 .1069 L
.22474 .10669 L
.22519 .10654 L
.22541 .10648 L
.22565 .10644 L
.22575 .10642 L
.22587 .1064 L
.22597 .10639 L
.22607 .10638 L
.22614 .10638 L
.2262 .10638 L
.22623 .10637 L
.22626 .10637 L
.2263 .10637 L
.22633 .10637 L
.22639 .10637 L
Mistroke
.22645 .10637 L
.22651 .10637 L
.22654 .10637 L
.22657 .10637 L
.22664 .10638 L
.2267 .10638 L
.22685 .10639 L
.22697 .10641 L
.22711 .10643 L
.22735 .10647 L
.22757 .10653 L
.22808 .1067 L
.22858 .10692 L
.22906 .10719 L
.22996 .10783 L
.23181 .10968 L
.23378 .11233 L
.23567 .1154 L
.2375 .11866 L
.23944 .12224 L
.24131 .12558 L
.24329 .1288 L
.24521 .13136 L
.24617 .1324 L
.24705 .13316 L
.248 .1338 L
.24852 .13405 L
.24875 .13415 L
.24901 .13424 L
.24923 .1343 L
.24948 .13435 L
.24961 .13438 L
.24973 .13439 L
.24986 .13441 L
.24991 .13441 L
.24997 .13442 L
.25003 .13442 L
.25008 .13442 L
.25014 .13443 L
.2502 .13443 L
.25025 .13443 L
.2503 .13443 L
.25035 .13442 L
.2504 .13442 L
.25046 .13442 L
.25052 .13442 L
.25064 .1344 L
.25076 .13439 L
.25086 .13437 L
.25109 .13433 L
Mistroke
.25133 .13427 L
.25183 .1341 L
.25229 .13389 L
.25272 .13364 L
.2537 .1329 L
.25459 .13204 L
.25651 .1296 L
.25835 .12662 L
.26031 .12295 L
.2622 .11916 L
.26401 .1155 L
.26595 .1118 L
.26781 .10867 L
.26875 .10731 L
.26979 .10603 L
.27078 .10503 L
.27169 .10433 L
.27218 .10405 L
.27263 .10384 L
.27287 .10375 L
.27312 .10367 L
.27325 .10364 L
.27339 .10361 L
.27351 .10359 L
.27364 .10357 L
.2737 .10357 L
.27377 .10356 L
.27383 .10356 L
.27389 .10355 L
.27393 .10355 L
.27396 .10355 L
.27402 .10355 L
.27407 .10355 L
.27413 .10355 L
.27418 .10355 L
.27424 .10355 L
.27429 .10356 L
.27434 .10356 L
.27446 .10357 L
.27458 .10359 L
.27483 .10363 L
.27506 .10369 L
.27531 .10377 L
.27558 .10387 L
.27603 .1041 L
.27652 .1044 L
.2774 .10511 L
.27837 .10612 L
.27938 .10744 L
.28122 .11039 L
Mistroke
.28317 .11419 L
.28505 .11827 L
.28705 .12277 L
.28897 .127 L
.29082 .1307 L
.2928 .13398 L
.29378 .1353 L
.29469 .1363 L
.29557 .13704 L
.29607 .13736 L
.29652 .13758 L
.29675 .13767 L
.29699 .13775 L
.2972 .1378 L
.29732 .13783 L
.29743 .13785 L
.2975 .13786 L
.29756 .13786 L
.29762 .13787 L
.29768 .13787 L
.29775 .13788 L
.29778 .13788 L
.29782 .13788 L
.29788 .13788 L
.29792 .13788 L
.29795 .13788 L
.29801 .13788 L
.29806 .13788 L
.29812 .13787 L
.29818 .13787 L
.29831 .13785 L
.29843 .13784 L
.29866 .13779 L
.29891 .13772 L
.29935 .13755 L
.29987 .13727 L
.30034 .13694 L
.30127 .1361 L
.30227 .13491 L
.30424 .13177 L
.30614 .12792 L
.30797 .12365 L
.30991 .11877 L
.31179 .11403 L
.31378 .10929 L
.31569 .1053 L
.31754 .10226 L
.31849 .10107 L
.31898 .10057 L
.3195 .10011 L
Mistroke
.31999 .09977 L
.32044 .09952 L
.32087 .09936 L
.32108 .0993 L
.3212 .09927 L
.32132 .09925 L
.32144 .09924 L
.3215 .09923 L
.32154 .09923 L
.32157 .09922 L
.32163 .09922 L
.32169 .09922 L
.32172 .09922 L
.32175 .09922 L
.32181 .09922 L
.32187 .09922 L
.32192 .09922 L
.32198 .09923 L
.32203 .09923 L
.32215 .09925 L
.32226 .09927 L
.32251 .09932 L
.32275 .0994 L
.323 .0995 L
.32327 .09963 L
.32373 .09992 L
.32422 .10031 L
.3251 .10122 L
.32612 .1026 L
.32709 .10421 L
.32894 .10802 L
.3309 .11293 L
.33279 .1182 L
.33461 .12348 L
.33655 .12899 L
.33841 .13385 L
.3404 .13819 L
.34139 .13994 L
.3423 .14128 L
.34319 .14229 L
.34369 .14272 L
.34414 .14303 L
.34437 .14316 L
.34462 .14327 L
.34483 .14335 L
.34507 .14341 L
.3452 .14343 L
.34532 .14345 L
.34538 .14346 L
.34542 .14346 L
Mistroke
.34545 .14346 L
.34549 .14347 L
.34552 .14347 L
.34558 .14347 L
.34565 .14347 L
.3457 .14347 L
.34577 .14346 L
.3458 .14346 L
.34583 .14346 L
.34595 .14344 L
.34607 .14343 L
.34619 .1434 L
.34631 .14337 L
.34657 .14328 L
.3468 .14317 L
.34705 .14304 L
.34748 .14275 L
.34794 .14234 L
.34888 .14127 L
.34988 .13973 L
.35187 .13562 L
.35378 .13052 L
.35562 .12483 L
.35757 .1183 L
.35946 .11192 L
.36146 .10549 L
.36339 .10007 L
.36524 .09592 L
.3662 .09427 L
.36669 .09358 L
.36722 .09296 L
.36771 .09249 L
.36816 .09215 L
.36838 .09202 L
.36862 .09191 L
.36884 .09183 L
.36905 .09177 L
.36916 .09175 L
.36922 .09175 L
.36927 .09174 L
.36933 .09173 L
.36939 .09173 L
.36945 .09173 L
.36948 .09173 L
.36951 .09173 L
.36957 .09173 L
.36962 .09173 L
.36967 .09174 L
.36973 .09174 L
.36983 .09176 L
Mistroke
.36995 .09178 L
.37007 .09181 L
.37019 .09185 L
.37046 .09196 L
.3707 .09209 L
.37094 .09224 L
.3714 .09262 L
.37189 .09314 L
.37278 .09437 L
.37371 .09607 L
.37459 .09801 L
.37645 .10315 L
.37843 .1099 L
.38033 .11724 L
.38216 .12469 L
.38411 .13255 L
.38598 .13956 L
.38798 .14592 L
.38898 .14853 L
.3899 .15054 L
.39079 .15208 L
.39125 .15271 L
.39175 .15325 L
.392 .15347 L
.39224 .15365 L
.39247 .1538 L
.39268 .1539 L
.39289 .15397 L
.393 .15401 L
.39311 .15403 L
.39317 .15404 L
.39322 .15404 L
.39328 .15405 L
.39334 .15405 L
.3934 .15405 L
.39345 .15405 L
.3935 .15405 L
.39357 .15404 L
.39362 .15404 L
.39369 .15403 L
.39382 .154 L
.39394 .15396 L
.39405 .15392 L
.39431 .1538 L
.39459 .15362 L
.39509 .15319 L
.39555 .15265 L
.39646 .15122 L
.39746 .14911 L
.39941 .1434 L
Mistroke
.40129 .13618 L
.40329 .12709 L
.40521 .11748 L
.40706 .10799 L
.40903 .09827 L
.41092 .08988 L
.41274 .08326 L
.41376 .08036 L
.41469 .07826 L
.41514 .07744 L
.41564 .07671 L
.41587 .07644 L
.41612 .07619 L
.41633 .076 L
.41655 .07585 L
.41668 .07578 L
.41681 .07571 L
.41693 .07567 L
.41705 .07564 L
.41712 .07562 L
.41715 .07562 L
.41718 .07561 L
.41724 .0756 L
.41727 .0756 L
.41731 .0756 L
.41734 .0756 L
.41738 .0756 L
.41741 .0756 L
.41744 .0756 L
.41747 .0756 L
.41751 .07561 L
.41755 .07561 L
.41758 .07562 L
.41765 .07563 L
.41771 .07565 L
.41783 .07568 L
.41805 .07579 L
.41831 .07595 L
.41856 .07615 L
.41902 .07667 L
.41946 .07731 L
.42045 .07932 L
.42143 .08203 L
.42232 .08512 L
.42424 .09358 L
.42608 .10375 L
.42804 .11619 L
.42993 .12907 L
.43174 .14157 L
.43367 .15421 L
Mistroke
.43553 .16494 L
.43648 .1696 L
.43751 .17397 L
.43851 .17736 L
.43941 .17966 L
.4399 .18056 L
.44036 .1812 L
.44061 .18146 L
.44084 .18164 L
.44096 .18171 L
.44109 .18177 L
.44116 .18179 L
.44123 .18181 L
.44127 .18182 L
.4413 .18182 L
.44136 .18183 L
.44142 .18184 L
.44146 .18184 L
.44149 .18184 L
.44155 .18183 L
.44161 .18182 L
.44166 .18181 L
.44171 .1818 L
.44183 .18176 L
.44195 .1817 L
.44206 .18163 L
.44232 .18143 L
.44254 .1812 L
.44277 .18088 L
.4432 .18016 L
.44365 .17917 L
.44415 .17781 L
.44516 .17421 L
.4461 .1699 L
.4471 .16423 L
.44908 .15013 L
.45099 .13345 L
.45282 .11526 L
.45477 .09462 L
.45665 .07461 L
.45865 .05455 L
.46057 .03775 L
.46242 .02516 L
.46338 .0204 L
.46386 .01851 L
.46439 .01685 L
.46464 .01622 L
.46488 .01573 L
.4651 .01536 L
.46533 .01506 L
Mistroke
.46546 .01493 L
.46558 .01484 L
.46564 .0148 L
.4657 .01477 L
.46576 .01475 L
.46581 .01473 L
.46587 .01472 L
.46593 .01472 L
.46596 .01472 L
.466 .01472 L
.46603 .01472 L
.46606 .01473 L
.4661 .01474 L
.46613 .01475 L
.46619 .01477 L
.46626 .01481 L
.46633 .01485 L
.46645 .01495 L
.46658 .01509 L
.46682 .01543 L
.46705 .01586 L
.46727 .01635 L
.46775 .0178 L
.46827 .01986 L
.4693 .02558 L
.47027 .03297 L
.47212 .05256 L
.4741 .08115 L
.47599 .11581 L
.47782 .15502 L
.47976 .20202 L
.48163 .2511 L
.48362 .30571 L
.48554 .35893 L
.48738 .40894 L
.48934 .45901 L
.49123 .50244 L
.49305 .53829 L
.49498 .56873 L
.49587 .57972 L
.49684 .58943 L
.4978 .59658 L
.49833 .59941 L
.49882 .60136 L
.49906 .60208 L
.49919 .6024 L
.49932 .60268 L
.49944 .60288 L
.49957 .60306 L
.49963 .60313 L
Mistroke
.49969 .60319 L
.49975 .60323 L
.4998 .60326 L
.49986 .60329 L
.49992 .60331 L
.49995 .60332 L
.49998 .60332 L
.50004 .60332 L
.5001 .60331 L
.50015 .60329 L
.50021 .60326 L
.50027 .60322 L
.50037 .60312 L
.50047 .60301 L
.5007 .60264 L
.50094 .60209 L
.5012 .6013 L
.50168 .59938 L
.50214 .59692 L
.50257 .59411 L
.50347 .58661 L
.50446 .57589 L
.5064 .54793 L
.50826 .51314 L
.51024 .46907 L
.51215 .4213 L
.51398 .37208 L
.51594 .31798 L
.51782 .26603 L
.51981 .21284 L
.52174 .16527 L
.52359 .12426 L
.52556 .08693 L
.52746 .05797 L
.52928 .03704 L
.53022 .029 L
.53122 .02239 L
.53171 .01994 L
.53224 .01781 L
.53249 .01703 L
.53275 .01632 L
.53299 .01577 L
.53321 .01538 L
.53343 .01508 L
.53354 .01496 L
.53366 .01486 L
.53378 .01478 L
.53385 .01475 L
.53391 .01473 L
.53397 .01472 L
Mistroke
.53403 .01472 L
.53409 .01472 L
.53415 .01472 L
.5342 .01473 L
.53425 .01475 L
.5343 .01477 L
.53435 .01479 L
.53446 .01487 L
.53457 .01496 L
.53479 .0152 L
.53502 .01556 L
.53552 .01662 L
.53597 .01794 L
.53698 .02204 L
.53791 .0271 L
.53891 .03381 L
.54088 .05015 L
.54278 .06871 L
.54461 .08796 L
.54655 .10871 L
.54842 .12778 L
.55041 .14596 L
.55233 .16054 L
.55417 .17124 L
.55513 .17536 L
.55561 .17708 L
.55614 .17863 L
.55663 .1798 L
.55707 .18064 L
.5575 .18124 L
.55772 .18146 L
.55795 .18164 L
.55807 .18172 L
.55814 .18175 L
.55821 .18177 L
.55827 .18179 L
.55833 .18181 L
.55839 .18182 L
.55845 .18183 L
.5585 .18184 L
.55856 .18184 L
.55861 .18183 L
.55866 .18183 L
.55872 .18182 L
.55878 .18181 L
.55884 .18179 L
.5589 .18177 L
.55903 .18171 L
.55915 .18165 L
.55942 .18143 L
Mistroke
.55965 .18119 L
.5599 .18086 L
.56036 .1801 L
.56085 .17907 L
.56173 .17662 L
.56276 .17292 L
.56373 .16866 L
.56557 .15878 L
.56754 .14642 L
.56943 .13353 L
.57125 .12099 L
.57318 .10827 L
.57505 .09732 L
.57703 .08772 L
.57802 .08387 L
.57894 .08093 L
.57983 .07868 L
.58032 .07769 L
.58077 .07695 L
.58127 .07633 L
.58153 .07608 L
.5818 .07587 L
.58192 .0758 L
.58204 .07574 L
.58215 .07569 L
.58226 .07565 L
.58234 .07563 L
.5824 .07562 L
.58246 .07561 L
.5825 .07561 L
.58253 .0756 L
.58259 .0756 L
.58262 .0756 L
.58266 .0756 L
.58271 .0756 L
.58277 .07561 L
.58283 .07561 L
.5829 .07562 L
.58301 .07565 L
.58313 .07569 L
.58323 .07573 L
.58347 .07586 L
.58372 .07604 L
.58414 .07645 L
.5846 .07705 L
.58554 .07872 L
.58654 .08116 L
.58853 .08771 L
.59044 .09578 L
.59228 .10464 L
Mistroke
.59423 .11462 L
.59612 .12417 L
.59812 .13362 L
.60005 .14147 L
.6019 .14746 L
.60286 .14986 L
.60335 .15088 L
.60388 .15181 L
.60437 .15255 L
.60482 .1531 L
.60527 .15352 L
.6057 .15381 L
.60593 .15391 L
.60605 .15396 L
.60617 .15399 L
.60629 .15402 L
.60636 .15403 L
.60642 .15404 L
.60648 .15405 L
.60654 .15405 L
.6066 .15405 L
.60663 .15405 L
.60666 .15405 L
.60672 .15405 L
.60678 .15404 L
.60683 .15404 L
.60688 .15403 L
.607 .154 L
.60712 .15397 L
.60733 .1539 L
.60755 .15379 L
.60804 .15345 L
.60857 .15292 L
.60954 .15156 L
.61048 .14976 L
.61149 .14736 L
.6135 .14135 L
.61543 .13435 L
.61729 .12695 L
.61926 .11888 L
.62117 .11141 L
.623 .10493 L
.62495 .09917 L
.62584 .09701 L
.62682 .09505 L
.62735 .09417 L
.62785 .09347 L
.62835 .09288 L
.62881 .09243 L
.62925 .09212 L
Mistroke
.62949 .09198 L
.62971 .09188 L
.62996 .0918 L
.6301 .09177 L
.63016 .09176 L
.63022 .09175 L
.63028 .09174 L
.63031 .09174 L
.63035 .09173 L
.6304 .09173 L
.63046 .09173 L
.63052 .09173 L
.63058 .09173 L
.63064 .09173 L
.63067 .09173 L
.63071 .09174 L
.63082 .09175 L
.63088 .09176 L
.63094 .09177 L
.63118 .09184 L
.6314 .09192 L
.63162 .09203 L
.63215 .09237 L
.63262 .0928 L
.63353 .09389 L
.63453 .0955 L
.63648 .09974 L
.63836 .10494 L
.64035 .11129 L
.64228 .11779 L
.64413 .124 L
.64609 .13015 L
.64799 .13528 L
.64981 .13919 L
.65075 .14074 L
.65175 .14203 L
.65224 .14251 L
.65277 .14292 L
.65301 .14308 L
.65327 .14321 L
.6535 .1433 L
.65374 .14338 L
.65386 .14341 L
.65399 .14344 L
.65405 .14345 L
.65412 .14345 L
.65418 .14346 L
.65423 .14346 L
.65427 .14347 L
.6543 .14347 L
Mistroke
.65434 .14347 L
.65438 .14347 L
.65441 .14347 L
.65445 .14347 L
.65448 .14347 L
.65451 .14347 L
.65457 .14346 L
.65464 .14346 L
.6547 .14345 L
.65477 .14344 L
.65489 .14342 L
.65501 .14339 L
.65524 .14332 L
.65548 .14323 L
.65574 .1431 L
.65619 .14281 L
.6567 .14239 L
.65771 .14126 L
.65865 .13989 L
.65965 .1381 L
.66164 .13372 L
.66355 .12871 L
.6654 .12346 L
.66736 .11777 L
.66924 .11254 L
.67106 .10803 L
.67299 .10407 L
.67388 .1026 L
.67485 .10128 L
.67581 .10028 L
.67634 .09987 L
.67682 .09958 L
.67707 .09947 L
.67733 .09937 L
.67745 .09933 L
.67758 .0993 L
.67769 .09928 L
.67781 .09925 L
.67792 .09924 L
.67803 .09923 L
.67808 .09922 L
.67813 .09922 L
.67818 .09922 L
.67823 .09922 L
.67829 .09922 L
.67835 .09922 L
.6784 .09922 L
.67846 .09923 L
.67852 .09923 L
.67859 .09924 L
Mistroke
.6787 .09926 L
.67882 .09928 L
.67894 .0993 L
.67916 .09937 L
.67939 .09945 L
.67965 .09956 L
.6801 .09983 L
.68053 .10013 L
.68143 .10098 L
.68242 .1022 L
.68435 .10539 L
.68621 .10927 L
.68819 .11398 L
.6901 .1188 L
.69193 .12341 L
.69389 .12798 L
.69576 .13179 L
.69672 .13343 L
.69776 .13495 L
.69868 .13605 L
.6992 .13656 L
.69968 .13696 L
.70018 .1373 L
.70064 .13755 L
.70087 .13765 L
.70113 .13773 L
.70127 .13777 L
.7014 .1378 L
.70153 .13783 L
.70165 .13785 L
.70177 .13786 L
.70183 .13787 L
.7019 .13788 L
.70193 .13788 L
.70197 .13788 L
.702 .13788 L
.70204 .13788 L
.7021 .13788 L
.70213 .13788 L
.70216 .13788 L
.70222 .13788 L
.70227 .13788 L
.70233 .13787 L
.7024 .13787 L
.70253 .13785 L
.70264 .13783 L
.70286 .13779 L
.7031 .13772 L
.70354 .13756 L
.70403 .1373 L
Mistroke
.70448 .137 L
.70549 .13611 L
.70642 .13505 L
.70742 .13367 L
.70939 .13029 L
.71129 .12644 L
.71312 .12241 L
.71506 .11803 L
.71693 .11399 L
.71892 .11015 L
.72083 .10714 L
.72171 .10604 L
.72268 .10504 L
.72363 .1043 L
.72415 .104 L
.72438 .10389 L
.72464 .10379 L
.72487 .10371 L
.72511 .10365 L
.72524 .10362 L
.72537 .10359 L
.72549 .10358 L
.72561 .10356 L
.72571 .10356 L
.72577 .10355 L
.72583 .10355 L
.72589 .10355 L
.72592 .10355 L
.72595 .10355 L
.72601 .10355 L
.72607 .10355 L
.72612 .10355 L
.72617 .10356 L
.72627 .10356 L
.72639 .10358 L
.7265 .10359 L
.72673 .10364 L
.72698 .1037 L
.72742 .10386 L
.7279 .10409 L
.72843 .10441 L
.72937 .10516 L
.73037 .10621 L
.73236 .10894 L
.73428 .11222 L
.73613 .11577 L
.73809 .11975 L
.73998 .12352 L
.7418 .12687 L
.74373 .12994 L
Mistroke
.7456 .13223 L
.74656 .13312 L
.74705 .13349 L
.74758 .13381 L
.74808 .13406 L
.74853 .13423 L
.74875 .13429 L
.74898 .13435 L
.74909 .13437 L
.74921 .13439 L
.7493 .1344 L
.74941 .13441 L
.74947 .13442 L
.74953 .13442 L
.74959 .13442 L
.74965 .13442 L
.7497 .13443 L
.74975 .13443 L
.74981 .13443 L
.74987 .13442 L
.74993 .13442 L
.74996 .13442 L
.74999 .13442 L
.75006 .13442 L
.75012 .13441 L
.75023 .1344 L
.75035 .13438 L
.75057 .13434 L
.75081 .13429 L
.75124 .13415 L
.75169 .13396 L
.75219 .13369 L
.7532 .13296 L
.75414 .13209 L
.75514 .13095 L
.75712 .12817 L
.75903 .12499 L
.76087 .12167 L
.76282 .11807 L
.76471 .11476 L
.76671 .11162 L
.76863 .10918 L
.76952 .10828 L
.77049 .10749 L
.77145 .10691 L
.77197 .10668 L
.77246 .10652 L
.7727 .10646 L
.77283 .10644 L
.77296 .10642 L
Mistroke
.77308 .1064 L
.77321 .10639 L
.77327 .10638 L
.77333 .10638 L
.77339 .10638 L
.77344 .10637 L
.77349 .10637 L
.77355 .10637 L
.77361 .10637 L
.77367 .10637 L
.77373 .10637 L
.77376 .10637 L
.77379 .10637 L
.77385 .10638 L
.77391 .10638 L
.774 .10639 L
.77411 .1064 L
.77433 .10643 L
.77457 .10648 L
.77483 .10655 L
.77531 .10671 L
.77577 .10691 L
.7762 .10715 L
.77719 .10783 L
.77809 .10862 L
.78002 .11082 L
.78187 .11345 L
.78385 .11661 L
.78575 .11982 L
.78758 .12286 L
.78953 .12586 L
.7914 .12833 L
.79235 .12939 L
.79339 .13036 L
.79439 .1311 L
.79486 .13138 L
.79531 .1316 L
.79578 .13179 L
.79621 .13192 L
.79644 .13197 L
.79669 .13202 L
.79681 .13204 L
.79693 .13205 L
.79701 .13206 L
.79707 .13206 L
.79714 .13207 L
.7972 .13207 L
.79726 .13207 L
.79731 .13208 L
.79735 .13208 L
Mistroke
.79738 .13208 L
.79744 .13208 L
.7975 .13208 L
.79755 .13208 L
.79762 .13207 L
.79768 .13207 L
.79779 .13206 L
.79789 .13205 L
.79813 .13203 L
.79838 .13198 L
.79861 .13193 L
.79913 .13177 L
.7996 .13158 L
.80004 .13136 L
.80103 .13072 L
.80291 .12903 L
.8049 .12664 L
.80683 .12392 L
.80867 .12109 L
.81064 .11803 L
.81253 .11522 L
.81436 .11282 L
.81629 .11073 L
.81719 .10997 L
.81816 .1093 L
.81869 .109 L
.81918 .10878 L
.81965 .10861 L
.81991 .10853 L
.82014 .10848 L
.82039 .10843 L
.82064 .10839 L
.82077 .10838 L
.8209 .10837 L
.82097 .10836 L
.82103 .10836 L
.82107 .10836 L
.8211 .10836 L
.82114 .10836 L
.82118 .10836 L
.82123 .10836 L
.82129 .10836 L
.82135 .10836 L
.8214 .10836 L
.82146 .10836 L
.82152 .10836 L
.82165 .10837 L
.82177 .10838 L
.8219 .1084 L
.82215 .10843 L
Mistroke
.8224 .10849 L
.82264 .10855 L
.82317 .10872 L
.82364 .10892 L
.82414 .10917 L
.82597 .11047 L
.82791 .11243 L
.82978 .11473 L
.83176 .11749 L
.83368 .12026 L
.83552 .12286 L
.83748 .1254 L
.83936 .12747 L
.84032 .12834 L
.84137 .12912 L
.84237 .12971 L
.84285 .12992 L
.8433 .13009 L
.84373 .13021 L
.84396 .13026 L
.8442 .13031 L
.84434 .13033 L
.84447 .13034 L
.84459 .13036 L
.84466 .13036 L
.84472 .13037 L
.84479 .13037 L
.84484 .13037 L
.8449 .13038 L
.84495 .13038 L
.84502 .13038 L
.84507 .13038 L
.84513 .13038 L
.84517 .13038 L
.8452 .13038 L
.84526 .13037 L
.84531 .13037 L
.84543 .13037 L
.84555 .13036 L
.84568 .13034 L
.84591 .13031 L
.84612 .13028 L
.84664 .13015 L
.84713 .12999 L
.84808 .12956 L
.84897 .12902 L
.85086 .12746 L
.85267 .12554 L
.85461 .12316 L
.85647 .12068 L
Mistroke
.85844 .11801 L
.86035 .11558 L
.86218 .11352 L
.8632 .11252 L
.86413 .11174 L
.86511 .11105 L
.86601 .11054 L
.86693 .11016 L
.86742 .11002 L
.86769 .10995 L
.86793 .10991 L
.86817 .10987 L
.86839 .10985 L
.86851 .10984 L
.86862 .10983 L
.86868 .10983 L
.86874 .10983 L
.86878 .10983 L
.86881 .10983 L
.86887 .10983 L
.86893 .10983 L
.86898 .10983 L
.86904 .10983 L
.8691 .10983 L
.86916 .10983 L
.86922 .10984 L
.86933 .10984 L
.86954 .10986 L
.86976 .10989 L
.86999 .10993 L
.87021 .10998 L
.87071 .11011 L
.87119 .11028 L
.87172 .11051 L
.87268 .11104 L
.8737 .11174 L
.87553 .11336 L
.87749 .11548 L
.87937 .11776 L
.88137 .12028 L
.88329 .12266 L
.88514 .12476 L
.88711 .12664 L
.88809 .1274 L
.88901 .12799 L
.88989 .12845 L
.89038 .12865 L
.89084 .12881 L
.89132 .12893 L
.89158 .12899 L
Mistroke
.89186 .12903 L
.89197 .12905 L
.89209 .12906 L
.8922 .12907 L
.89232 .12908 L
.89238 .12908 L
.89244 .12908 L
.89251 .12909 L
.89255 .12909 L
.89258 .12909 L
.89261 .12909 L
.89265 .12909 L
.89271 .12909 L
.89276 .12909 L
.89282 .12909 L
.89288 .12909 L
.89294 .12909 L
.893 .12908 L
.89306 .12908 L
.89328 .12906 L
.8934 .12905 L
.89351 .12904 L
.89376 .129 L
.89422 .12891 L
.89464 .12879 L
.89561 .12842 L
.8965 .12796 L
.8984 .12661 L
.90022 .12492 L
.90217 .12282 L
.90404 .12062 L
.90603 .11826 L
.90795 .11609 L
.90979 .11425 L
.91073 .11344 L
.91176 .11266 L
.91274 .11205 L
.91364 .1116 L
.91458 .11125 L
.91506 .11113 L
.91533 .11107 L
.91558 .11103 L
.91581 .111 L
.91604 .11098 L
.91616 .11097 L
.91627 .11097 L
.91633 .11097 L
.91637 .11097 L
.9164 .11096 L
.91643 .11096 L
Mistroke
.91647 .11096 L
.91653 .11096 L
.91658 .11096 L
.91664 .11096 L
.9167 .11097 L
.91675 .11097 L
.9168 .11097 L
.91687 .11097 L
.91698 .11098 L
.91709 .11099 L
.91721 .111 L
.91741 .11102 L
.91787 .1111 L
.91836 .11122 L
.91924 .11152 L
.92027 .112 L
.92123 .11259 L
.92308 .11402 L
.92505 .11589 L
.92694 .11792 L
.92876 .11997 L
.93069 .12211 L
.93256 .12401 L
.93454 .12574 L
.93553 .12644 L
.93645 .127 L
.93734 .12743 L
.93828 .12777 L
.93878 .1279 L
.93904 .12796 L
.93931 .128 L
.93955 .12804 L
.93968 .12805 L
.93982 .12806 L
.93994 .12807 L
.94006 .12808 L
.94011 .12808 L
.94017 .12808 L
.94023 .12808 L
.94028 .12808 L
.94034 .12808 L
.9404 .12808 L
.94045 .12808 L
.9405 .12808 L
.94056 .12808 L
.94063 .12808 L
.94074 .12807 L
.94086 .12806 L
.94097 .12805 L
.94118 .12803 L
Mistroke
.94143 .128 L
.94165 .12796 L
.94217 .12784 L
.94264 .12771 L
.94307 .12755 L
.94406 .12711 L
.94593 .12594 L
.94791 .12431 L
.94983 .12245 L
.95166 .12053 L
.95362 .11844 L
.9555 .11654 L
.95751 .11475 L
.95851 .11398 L
.95944 .11336 L
.9604 .11283 L
.96129 .11243 L
.9622 .11213 L
.96268 .11202 L
.96294 .11197 L
.96319 .11193 L
.96343 .1119 L
.96355 .11189 L
.96368 .11188 L
.96375 .11188 L
.96381 .11187 L
.96388 .11187 L
.96394 .11187 L
.964 .11187 L
.96403 .11187 L
.96407 .11187 L
.96411 .11187 L
.96415 .11187 L
.96418 .11187 L
.96421 .11187 L
.96427 .11187 L
.96433 .11187 L
.96439 .11187 L
.96446 .11187 L
.96459 .11188 L
.96472 .11189 L
.96496 .11191 L
.96518 .11194 L
.96565 .11202 L
.96614 .11213 L
.96702 .11242 L
.96796 .11283 L
.96884 .11331 L
.9707 .1146 L
.97267 .11629 L
Mistroke
.97457 .11813 L
.97619 .11976 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 474.625},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001fR000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`009Oooool5o`0002gooooo0ol0000]ooooo`;o0000
;_ooool3o`0002kooooo1Ol0003oooooo`cooooo000Vooooo`04o`000?ooooooooooo`0002kooooo
00?o0000ooooooooool0:oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo02ko
oooo00Co0000oooooooooooo0000=oooool3o`0000Cooooo0_l0000Yooooo`?o0000:oooool2o`00
02gooooo0ol0000Yooooo`?o00001?ooool2o`00013ooooo000Oooooo`Go00000oooool00ol0003o
ooooooooo`0Vooooo`Go00000oooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`00
02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00009oooool01Ol0003ooooooooooooooooo000002Wooooo00Co
0000oooooooooooo0000:oooool01Ol0003ooooooooooooooooo000002Wooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000?ooooo`00:?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02_ooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo02oooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00008Oooool5o`0000Gooooo00?o0000ooooooooool09oooool01?l0003oooooooooool0
000_ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000?ooooo`009Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooooooool0
:oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo02gooooo00Go0000oooooooo
ooooooooo`00000hooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:oooool0
0ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000oooooo000Uooooo`05o`000?oo
ooooooooooooool00000;Oooool2o`0002gooooo00Co0000oooooooooooo0000;Oooool2o`0002oo
oooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00009oooool4o`0002[ooooo00Co0000oooooooooooo0000:oooool4o`0002[ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000?ooooo`009_ooool3o`0002oooooo00?o
0000ooooooooool0;?ooool2o`0002oooooo00?o0000ooooooooool0;_ooool3o`0003Sooooo0_l0
0004ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool0:oooool01?l0003ooooo
ooooool0000[ooooo`03o`000?oooooooooo02[ooooo0_l00004ooooo`04o`000?ooooooooooo`00
00oooooo003oooooobKooooo00?o0000ooooooooool00oooool2o`0002Sooooo1Ol0000Zooooo`;o
0000;?ooool5o`0002Wooooo00?o0000ooooooooool00oooool2o`00013ooooo003oooooooWooooo
003oooooooWooooo000Pooooom3o0000ooooool9ooooo`008?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
00000?oooooo2Oooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_oooo
o`05o`000?ooooooooooooooool00000<Oooooo9o`0000kooooo000Pooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00cooooo000Jooooo`;o00001?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Looooo`?oo`3o@_ooool00ol0003o
ooooooooo`11ooooo`;oo`3o7_ooool00ol0003oooooooooo`0<ooooo`006Oooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo01Sooooo2_oo0?loooooo`03o`000?oooooooooo03co
oooo2ooo0?lJooooo`03o`000?oooooooooo00cooooo000Iooooo`04o`000?ooooooooooo`0000?o
oooo0_l00002ooooof3oo`3o1?ooool01?l0003ooooooooooooooomPool0o`;ooooo0_l0000aoooo
o`;o00005_ooool?ool0ocgooooo00?o0000ooooooooool0>_ooool>ool0oaSooooo0_l0000>oooo
o`006Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooof3oo`3o1?ooool0
1?l0003ooooooooooooooomPool0o`?ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0Dooooo`Goo`3o1oooool5ool0occooooo00?o0000ooooooooool0>Oooool5ool0o`Oooooo1Ooo
0?lGooooo`03o`000?oooooooooo00cooooo000Iooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool0Goooool2ool0o`Cooooo00Co0000oooooooooooooooo0_oo0?mQooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool04_ooool5ool0o`_ooooo1Ooo0?ljooooo`03o`00
0?oooooooooo03Sooooo1?oo0?l;ooooo`Goo`3o5Oooool00ol0003oooooooooo`0<ooooo`006Ooo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo017o
oooo1?oo0?l?ooooo`Coo`3o>Oooool00ol0003oooooooooo`0fooooo`Coo`3o3oooool4ool0oaCo
oooo00?o0000ooooooooool03?ooool001[ooooo0_l00004ooooo`03o`000?oooooooooo05oooooo
0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo013ooooo1?oo0?lAooooo`?oo`3o>Oooool00ol0003oooooooooo`0fooooo`?o
o`3o4Oooool4ool0oa?ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0
Goooool2ool0o`Cooooo00Co0000oooooooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02oo
oooo0_l0000@ooooo`Coo`3o4oooool3ool0ocSooooo00?o0000ooooooooool0=Oooool3ool0oa?o
oooo1?oo0?lAooooo`;o00003_ooool0023ooooo0_l0001Pooooo`;oo`3o1?ooool01?l0003ooooo
ooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0>ooooo`Co
o`3o5Oooool3ool0ocOooooo00?o0000ooooooooool0=?ooool3ool0oaKooooo0ooo0?lAooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00go
oooo0ooo0?lHooooo`?oo`3o=_ooool00ol0003oooooooooo`0cooooo`?oo`3o6?ooool4ool0o`oo
oooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Goooool2ool0o`Cooooo
00Co0000oooooooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool02oooool4ool0oaWooooo1?oo0?leooooo`03o`000?oooooooooo03?ooooo0_oo0?lJooooo`?o
o`3o3oooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Oooooo`;oo`3o
1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0;ooooo`?oo`3o6oooool3ool0ocGooooo00?o0000ooooooooool0<_ooool3ool0oa_o
oooo1?oo0?l=ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo
0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`;o
00002_ooool4ool0oagooooo0ooo0?ldooooo`03o`000?oooooooooo037ooooo0ooo0?lMooooo`Co
o`3o2oooool2o`0000kooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wo
oooo0ooo0?lOooooo`;oo`3o=?ooool00ol0003oooooooooo`0`ooooo`?oo`3o7oooool3ool0o`co
oooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Pooooo`;oo`3o1?ooool01?l0003ooooo
ooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`08ooooo`?o
o`3o8?ooool3ool0oc?ooooo00?o0000ooooooooool0<?ooool3ool0ob3ooooo0ooo0?l;ooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oo
oooo0ooo0?lRooooo`?oo`3o<_ooool00ol0003oooooooooo`0_ooooo`?oo`3o8_ooool3ool0o`[o
oooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Goooool2ool0o`Cooooo
00Co0000oooooooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool01_ooool3ool0obCooooo0_oo0?lbooooo`03o`000?oooooooooo02oooooo0ooo0?lSooooo`?o
o`3o2Oooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Oooooo`;oo`3o
1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool2o`0000Ko
oooo0ooo0?lUooooo`?oo`3o<Oooool00ol0003oooooooooo`0^ooooo`?oo`3o9Oooool3ool0o`Oo
oooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003ooooo
ooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`04ooooo`?o
o`3o9oooool3ool0oc3ooooo00?o0000ooooooooool0;_ooool2ool0obOooooo0ooo0?l7ooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0Xooooo`;o00001Oooool00ol0003o
ooooooooo`03ooooo`?oo`3o:Oooool2ool0oc3ooooo00?o0000ooooooooool0;Oooool3ool0obSo
oooo0ooo0?l6ooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000H?ooool2ool0o`Cooooo
00Co0000oooooooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`02ooooo`Coo`3o:Oooool3ool0oboooooo00?o0000oooo
ooooool0;?ooool3ool0obWooooo1?oo0?l5ooooo`03o`000?oooooooooo00cooooo000Pooooo`03
o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0
003oooooooooo`0Wooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooooooo1?oo
0?lZooooo`?oo`3o;oooool00ol0003oooooooooo`0/ooooo`?oo`3o:oooool3ool0o`Cooooo00?o
0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Goooool2ool0o`Cooooo00Co0000
oooooooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo0000
1?ooool4o`0000?oo`3o;?l00002ool0oeko00000_oo0?l/o`0000?oo`3o1Ol0000>ooooo`008?oo
ool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo
00?o0000ooooooooool09oooool01?l0003oooooooooool00004ooooo`04o`000?oooooooooooooo
o`;oo`3o;Oooool3ool0obkooooo00?o0000ooooooooool0:oooool3ool0obgooooo0_oo0?l4oooo
o`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04
o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0Wooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0<Oooool3ool0obgooooo00?o0000ooooooooool0:oooool2
ool0ocCooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Goooool2ool0
o`Cooooo00Co0000oooooooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02Sooooo0_l00005
ooooo`03o`000?oooooooooo037ooooo0ooo0?l]ooooo`03o`000?oooooooooo02[ooooo0ooo0?ld
ooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000H?ooool2ool0o`Cooooo00Co0000oooo
oooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<_ooool2
ool0obgooooo00?o0000ooooooooool0:_ooool2ool0ocGooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool0Goooool2ool0o`Cooooo00Co0000oooooooooooooooo0_oo0?mQ
ooooo`03o`000?oooooooooo02oooooo0_l0000cooooo`?oo`3o;?ooool00ol0003oooooooooo`0Y
ooooo`?oo`3o=?ooool2o`0000kooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4oooo
o`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo03?ooooo0_oo0?l/ooooo`03o`000?oooooooooo02Wooooo0_oo0?lfooooo`03o`000?oooooo
oooo00cooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0
003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0cooooo`?oo`3o:oooool00ol0003oooooooooo`0X
ooooo`?oo`3o=_ooool00ol0003oooooooooo`0<ooooo`003Oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Oooooo`;oo`3o1?oo
ool01?l0003oooooooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0dooooo`;oo`3o:oooool00ol0003oooooooooo`0Xooooo`;oo`3o=oooool00ol0003ooooo
ooooo`0<ooooo`003Oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooooooo`;o
0000H?ooool2ool0o`Cooooo00Co0000oooooooooooooooo0_oo0?mPooooo`;o0000<Oooool2o`00
03Gooooo0ooo0?lZooooo`03o`000?oooooooooo02Oooooo0ooo0?lfooooo`;o00003_ooool000go
oooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooooooooooo0000067ooooo0_oo0?l4
ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo03Gooooo0_oo0?lZooooo`03o`000?oooooooooo02Oooooo0_oo0?lhooooo`03o`000?oo
oooooooo00cooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo1?l00004ooooo`03o`000?oo
oooooooo05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo03Gooooo0_oo0?lZooooo`03o`000?oooooooooo02Oooooo
0_oo0?lhooooo`03o`000?oooooooooo00cooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003ooooo
ooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0eooooo`?o
o`3o:Oooool00ol0003oooooooooo`0Vooooo`?oo`3o>?ooool00ol0003oooooooooo`0<ooooo`00
3_ooool2o`0000Sooooo1Ol00003ooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Ko
oooo0_oo0?lYooooo`03o`000?oooooooooo02Kooooo0_oo0?liooooo`03o`000?oooooooooo00co
oooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;o
o`3oHOooool00ol0003oooooooooo`0_ooooo`;o0000=oooool3ool0obSooooo00?o0000oooooooo
ool09_ooool2ool0ocSooooo0_l0000>ooooo`008?ooool2o`00063ooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Oo
oooo0_oo0?lXooooo`03o`000?oooooooooo02Gooooo0ooo0?liooooo`03o`000?oooooooooo00co
oooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;o
o`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Oooooo0_oo0?lXooooo`03
o`000?oooooooooo02Gooooo0_oo0?ljooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`00
0?oooooooooo05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo03Oooooo0ooo0?lWooooo`03o`000?oooooooooo02Co
oooo0ooo0?ljooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo
0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo03Sooooo0_oo0?lWooooo`03o`000?oooooooooo02Cooooo0_oo0?lkooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`;o0000>Oooool2ool0obOo
oooo00?o0000ooooooooool09?ooool2ool0oc[ooooo0_l0000>ooooo`008?ooool00ol0003ooooo
ooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0hooooo`?oo`3o9_ooool00ol0003oooooooooo`0Sooooo`?o
o`3o>oooool00ol0003oooooooooo`0<ooooo`008?ooool2o`00063ooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0Fooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0>Oooool2ool0obKo
oooo00?o0000ooooooooool08oooool2ool0occooooo00?o0000ooooooooool03?ooool0023ooooo
00?o0000ooooooooool0Goooool2ool0o`Cooooo00Co0000oooooooooooooooo0_oo0?mQooooo`03
o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0iooooo`?oo`3o9Ooo
ool00ol0003oooooooooo`0Sooooo`;oo`3o??ooool00ol0003oooooooooo`0<ooooo`008?ooool0
0ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o
0000ooooooooool05Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0jooooo`;oo`3o9Oooool00ol0003o
ooooooooo`0Rooooo`?oo`3o??ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003ooooo
ooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000oooooooo
ool05Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool00_ooool2o`0003_ooooo0_oo0?lUooooo`03o`000?oooooooooo02;ooooo0_oo0?ll
ooooo`;o00003_ooool0023ooooo00?o0000ooooooooool0Goooool2ool0o`Cooooo00Co0000oooo
oooooooooooo0_oo0?mQooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002?oo
ool01Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`0jooooo`?oo`3o
9?ooool00ol0003oooooooooo`0Qooooo`?oo`3o?Oooool00ol0003oooooooooo`0<ooooo`008?oo
ool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo
00?o0000ooooooooool05Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`00
0?oooooo00002?ooool00ol0003oooooooooo`0kooooo`;oo`3o9?ooool00ol0003oooooooooo`0Q
ooooo`;oo`3o?_ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`00063ooooo0_oo0?l4oooo
o`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0Fooooo`;o00002_ooool2
o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo03_ooooo0ooo0?lSooooo`03o`000?oooooo
oooo027ooooo0_oo0?lnooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo03cooooo0_oo0?lSooooo`03o`000?oooooooooo023ooooo0ooo0?ln
ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4oooo
o`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`;o0000?Oooool2
ool0ob?ooooo00?o0000ooooooooool08?ooool2ool0ockooooo0_l0000>ooooo`008?ooool00ol0
003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0looooo`?oo`3o8_ooool00ol0003oooooooooo`0O
ooooo`?oo`3o?oooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Ooooo
o`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0mooooo`;oo`3o8_ooool00ol0003oooooooooo`0Oooooo`;oo`3o@?ooool0
0ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0
003oooooooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0m
ooooo`;oo`3o8_ooool00ol0003oooooooooo`0Oooooo`;oo`3o@?ooool00ol0003oooooooooo`0<
ooooo`008?ooool2o`00063ooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03gooooo0ooo0?lQooooo`03o`000?oooooo
oooo01kooooo0ooo0?m0ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_
ooooo`;o0000?oooool2ool0ob7ooooo00?o0000ooooooooool07_ooool2ool0od3ooooo0_l0000>
ooooo`008?ooool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2
ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0nooooo`?oo`3o8?ooool0
0ol0003oooooooooo`0Nooooo`;oo`3o@Oooool00ol0003oooooooooo`0<ooooo`006Oooool3o`00
00Cooooo00?o0000ooooooooool0Goooool2ool0o`Cooooo00Co0000oooooooooooooooo0_oo0?mQ
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0?oooool2ool0ob3ooooo00?o0000
ooooooooool07Oooool3ool0od7ooooo00?o0000ooooooooool03?ooool001[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2
ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0oooooo`;oo`3o8?ooool0
0ol0003oooooooooo`0Mooooo`;oo`3o@_ooool00ol0003oooooooooo`0<ooooo`006_ooool00ol0
003oooooooooo`03ooooo`;o0000H?ooool<ool0of3ooooo0_l0000aooooo`;o0000@?ooool3ool0
oaoooooo00?o0000ooooooooool07?ooool3ool0od7ooooo0_l0000>ooooo`006_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo05oooooo3?oo0?mQooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0@?ooool2ool0oaoooooo00?o0000ooooooooool07?ooool2ool0od?o
oooo00?o0000ooooooooool03?ooool001[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`10ooooo`?oo`3o7_ooool00ol0003oooooooooo`0Looooo`;oo`3o@oooool00ol0003ooooo
ooooo`0<ooooo`006Oooool2o`0000Gooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0@Oooool2ool0oakooooo00?o
0000ooooooooool06oooool3ool0od?ooooo00?o0000ooooooooool03?ooool001[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`11ooooo`;oo`3o7_ooool00ol0003oooooooooo`0K
ooooo`;oo`3oA?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool2o`0004;ooooo0_oo0?lNoooo
o`03o`000?oooooooooo01_ooooo0_oo0?m3ooooo`;o00003_ooool0023ooooo0_l0001Vooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`11ooooo`?o
o`3o7Oooool00ol0003oooooooooo`0Jooooo`?oo`3oA?ooool00ol0003oooooooooo`0<ooooo`00
8?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`12ooooo`;oo`3o7Oooool00ol0003oooooooooo`0Jooooo`;oo`3o
AOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool07?ooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Gooooo00?o0000ooooooooool0@_ooool2ool0oagooooo00?o0000ooooooooool06_oo
ool2ool0odGooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo0ooo0?lLooooo`03o`000?oo
oooooooo01Wooooo0ooo0?m5ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`0004Cooooo0_oo0?lLooooo`03o`000?oo
oooooooo01Wooooo0_oo0?m5ooooo`;o00003_ooool0023ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04?ooooo0ooo0?lKooooo`03o`000?oo
oooooooo01Wooooo0_oo0?m6ooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000I_ooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Cooooo0_oo0?lKooooo`03o`000?oo
oooooooo01Sooooo0ooo0?m6ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo04Cooooo0_oo0?lKooooo`03o`000?oo
oooooooo01Sooooo0_oo0?m7ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Looooo`;o00002_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Cooooo0ooo0?lJooooo`03o`000?oooooo
oooo01Oooooo0ooo0?m7ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o0000A_ooool2ool0
oa[ooooo00?o0000ooooooooool05oooool2ool0odOooooo0_l0000>ooooo`008?ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`15ooooo`;oo`3o6_ooool00ol0003oooooooooo`0Gooooo`;oo`3oB?ooool00ol0003o
ooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`15ooooo`?oo`3o6Oooool00ol0003ooooo
ooooo`0Fooooo`?oo`3oB?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0006Kooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04Kooooo0_oo
0?lIooooo`03o`000?oooooooooo01Kooooo0_oo0?m9ooooo`03o`000?oooooooooo00cooooo000P
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo04Kooooo0ooo0?lHooooo`03o`000?oooooooooo01Kooooo0_oo0?m9
ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o0000B?ooool2ool0oaSooooo00?o0000oooo
ooooool05Oooool3ool0odSooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`17ooooo`;o
o`3o6?ooool00ol0003oooooooooo`0Eooooo`;oo`3oB_ooool00ol0003oooooooooo`0<ooooo`00
8?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`17ooooo`?oo`3o5oooool00ol0003oooooooooo`0Dooooo`?oo`3o
B_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`18ooooo`;oo`3o5ooo
ool00ol0003oooooooooo`0Dooooo`;oo`3oBoooool00ol0003oooooooooo`0<ooooo`008?ooool2
o`0006Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo04Sooooo0ooo0?lFooooo`03o`000?oooooooooo01Cooooo0_oo0?m;ooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0_ooooo`;o0000B_ooool2ool0oaKooooo00?o0000ooooooooool04oooool3ool0
od[ooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`19ooooo`;oo`3o5_ooool00ol0003o
ooooooooo`0Cooooo`;oo`3oC?ooool00ol0003oooooooooo`0<ooooo`003Oooool3o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0BOooool3ool0oaGooooo
00?o0000ooooooooool04_ooool3ool0odcooooo00?o0000ooooooooool03?ooool000kooooo00?o
0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
B_ooool2ool0oaGooooo00?o0000ooooooooool04_ooool2ool0odgooooo00?o0000ooooooooool0
3?ooool000kooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000006Oooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04[ooooo
0_oo0?lEooooo`03o`000?oooooooooo01;ooooo0_oo0?m=ooooo`03o`000?oooooooooo00cooooo
000>ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0_l0001Vooooo`03o`00
0?oooooooooo06?ooooo0_l0000aooooo`;o0000Boooool3ool0oaCooooo00?o0000ooooooooool0
4Oooool3ool0odcooooo0_l0000>ooooo`003_ooool00ol0003oooooooooo`07ooooo`Co00001?oo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`1;ooooo`;oo`3o5?ooool00ol0003oooooooooo`0Aooooo`;oo`3oC_oo
ool00ol0003oooooooooo`0<ooooo`003Oooool2o`0000Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool05_ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooo
oooo04_ooooo0ooo0?lCooooo`03o`000?oooooooooo017ooooo0_oo0?m>ooooo`03o`000?oooooo
oooo00cooooo000>ooooo`03o`000?oooooooooo00Oooooo1Ol00003ooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Eooooo`04o`000?oooooooooo
o`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0C?ooool2ool0oa?ooooo00?o0000ooooooooool04?ooool3ool0odkooooo00?o
0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo0_l0001=ooooo`;oo`3o4oooool00ol0003ooooooooo
o`0?ooooo`?oo`3oC_ooool2o`0000kooooo000Pooooo`;o0000I_ooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C?ooool3ool0oa;ooooo00?o
0000ooooooooool03oooool3ool0odoooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Gooooo00Co0000
oooooooooooo00002Oooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000ooooooooool0
COooool3ool0oa7ooooo00?o0000ooooooooool03oooool2ool0oe3ooooo00?o0000ooooooooool0
3?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo01Gooooo00Co0000oooooooooooo00002?ooool2o`0000?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1>ooooo`;oo`3o4Oooool00ol0003oooooooooo`0>ooooo`?oo`3o
D?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool05_ooool2o`0000[ooooo00Co0000oooooooooooooooo
1Ol00004ooooo`03o`000?oooooooooo04kooooo0_oo0?lAooooo`03o`000?oooooooooo00kooooo
0_oo0?mAooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o0000Coooool3ool0oa3ooooo00?o
0000ooooooooool03Oooool3ool0oe3ooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1?
ooooo`;oo`3o4?ooool00ol0003oooooooooo`0=ooooo`;oo`3oD_ooool00ol0003oooooooooo`0<
ooooo`008?ooool2o`0006Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo04oooooo0ooo0?l?ooooo`03o`000?oooooooooo00cooooo0ooo0?mBoooo
o`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo053ooooo0_oo0?l?ooooo`03
o`000?oooooooooo00cooooo0_oo0?mCooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo053ooooo0ooo0?l>ooooo`03o`000?oooooooooo00_ooooo0ooo0?mCooooo`03o`00
0?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`0_ooooo`;o0000D_ooool2ool0o`kooooo00?o0000ooooooooool02ooo
ool3ool0oe;ooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Aooooo`?oo`3o3Oooool0
0ol0003oooooooooo`0:ooooo`?oo`3oE?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`1Booooo`;oo`3o3Oooool00ol0003oooooooooo`0:ooooo`;oo`3oEOooool00ol0
003oooooooooo`0<ooooo`008?ooool2o`0006Kooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo05;ooooo0ooo0?l<ooooo`03o`000?oooooooooo00Wo
oooo0ooo0?mEooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05?ooooo
0ooo0?l;ooooo`03o`000?oooooooooo00Wooooo0_oo0?mFooooo`03o`000?oooooooooo00cooooo
000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0_ooooo`;o0000EOooool2ool0o`_ooooo00?o0000ooooooooool02?ooool3ool0oeGooooo0_l0
000>ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`1Dooooo`?oo`3o2_ooool00ol0003oooooooooo`07
ooooo`?oo`3oEoooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Eoooo
o`?oo`3o2Oooool00ol0003oooooooooo`07ooooo`;oo`3oF?ooool00ol0003oooooooooo`0<oooo
o`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`1Fooooo`;oo`3o2Oooool00ol0003oooooooooo`06ooooo`?o
o`3oF?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0006Kooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05Kooooo0ooo0?l8ooooo`03o`00
0?oooooooooo00Gooooo0ooo0?mIooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o0000F?oo
ool3ool0o`Oooooo00?o0000ooooooooool01?ooool3ool0oeWooooo0_l0000>ooooo`008?ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`1Gooooo`Coo`3o1_ooool00ol0003oooooooooo`03ooooo`?oo`3oFoooool0
0ol0003oooooooooo`0<ooooo`006?ooool5o`0000?ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo01cooooo0_l00004ooooo`04o`000?oooooooooo
ooooo`Go00001?ooool00ol0003oooooooooo`1Iooooo`Coo`3o1?ooool00ol0003oooooooooo`02
ooooo`Coo`3oFoooool00ol0003oooooooooo`0<ooooo`006Oooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0K
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1Jooooo`Coo`3o0oooool00ol0003oooooooooo`04ool0oegooooo00?o0000ooooooooool0
3?ooool001[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Foooool<ool0oekooooo00?o0000ooooooooool0
3?ooool001_ooooo00?o0000ooooooooool00_ooool2o`0006Kooooo00?o0000ooooooooool0Hooo
ool2o`0001gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`;o0000
GOooool:ool0oekooooo0_l0000>ooooo`006?ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02_ooooo1?oo0?l^oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<oooo
o`006?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0<ooooo`006Oooool3o`0000Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo01cooooo0_l00009ooooo`?o00001Oooooo9o`0000kooooo000Poooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool01Ol0003ooooooooooooooooo
00000?oooooo2Oooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00003oooooo`Wooooo000Poooo
om3o0000ooooool9ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`009Oooool5o`0002gooooo0ol0000]ooooo`;o0000;_ooool3o`0002ko
oooo1Ol0003oooooo`cooooo000Vooooo`04o`000?ooooooooooo`0002kooooo00?o0000oooooooo
ool0:oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo02kooooo00Co0000oooo
oooooooo0000=oooool3o`0000Cooooo0_l0000Yooooo`?o0000:oooool2o`0002gooooo0ol0000Y
ooooo`?o00001?ooool2o`00013ooooo000Oooooo`Go00000oooool00ol0003oooooooooo`0Voooo
o`Go00000oooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0002kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00009oooool01Ol0003ooooooooooooooooo000002Wooooo00Co0000oooooooooooo
0000:oooool01Ol0003ooooooooooooooooo000002Wooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000?ooooo`00:?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02_ooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo02oooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008Ooo
ool5o`0000Gooooo00?o0000ooooooooool09oooool01?l0003oooooooooool0000_ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000?ooooo`00
9Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooooooool0:oooool01?l0003o
ooooooooool0000^ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000h
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:oooool00ol0003ooooooooo
o`0Wooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000oooooo000Uooooo`05o`000?ooooooooooooooool0
0000;Oooool2o`0002gooooo00Co0000oooooooooooo0000;Oooool2o`0002oooooo00Go0000oooo
ooooooooooooo`00000hooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009ooo
ool4o`0002[ooooo00Co0000oooooooooooo0000:oooool4o`0002[ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000?ooooo`009_ooool3o`0002oooooo00?o0000ooooooooool0
;?ooool2o`0002oooooo00?o0000ooooooooool0;_ooool3o`0003Sooooo0_l00004ooooo`04o`00
0?ooooooooooo`0002Oooooo00?o0000ooooooooool0:oooool01?l0003oooooooooool0000[oooo
o`03o`000?oooooooooo02[ooooo0_l00004ooooo`04o`000?ooooooooooo`0000oooooo003ooooo
obKooooo00?o0000ooooooooool00oooool2o`0002Sooooo1Ol0000Zooooo`;o0000;?ooool5o`00
02Wooooo00?o0000ooooooooool00oooool2o`00013ooooo003oooooooWooooo003oooooooWooooo
000Pooooom3o0000ooooool9ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo00000?oooooo2Ooo
ool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`05o`000?oooooo
ooooooooool00000<Oooooo9o`0000kooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03?ooool001[ooooo0_l00004ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`0Looooo`;o00001?ooool01?l0003oooooooooooooool5
o`0000Cooooo00?o0000ooooooooool0E?ooool00ooo003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0<ooooo`006Oooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`1Cooooo`;oo`003?ooool00ol0003oooooooooo`0:ooooo`;oo`00
EOooool00ol0003oooooooooo`0<ooooo`006Oooool01?l0003oooooooooool00003ooooo`;o0000
0ooooom;ool001Sooooo00?o0000ooooooooool05Ooooom<ool000;ooooo0_l0000Fooooo`Go0000
0_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0001Cooooo`03
ool00?ooooooo`0000cooooo00?o0000ooooooooool02_ooool00ooo003oooooool0001Cooooo`;o
00003_ooool001Wooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1<ooooo`03
ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<ooooo`03
o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05;ooooo00Coo`00ooooooooooooo`002oooool00ol0003oooooooooo`0:
ooooo`03ool00?ooooooo`0005Cooooo00?o0000ooooooooool03?ooool001Wooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo01Kooooo00?o0000
ooooooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo01_ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
D_ooool01?oo003ooooooooooooo000;ooooo`03o`000?oooooooooo00Wooooo00Goo`00oooooooo
ooooooooool0001Cooooo`03o`000?oooooooooo00cooooo000Iooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo
01Gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo057ooooo00Go
o`00ooooooooooooooooool0000;ooooo`03o`000?oooooooooo00Wooooo00Goo`00oooooooooooo
ooooool0001Cooooo`03o`000?oooooooooo00cooooo000Jooooo`;o00001?ooool00ol0003ooooo
ooooo`1<ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003ooooo
ooooo`1<ooooo`03o`000?oooooooooo01cooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`1Aooooo`05ool00?oooooooooooooooooo00002oooool00ol0003oooooooooo`09ooooo`05
ool00?oooooooooooooooooo0000Doooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003o
ooooooooo`1<ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003o
ooooooooo`1<ooooo`03o`000?oooooooooo02oooooo0_l0001Booooo`05ool00?oooooooooooooo
oooo00002oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0D?ooool2o`0000kooooo000Pooooo`;o0000COooool00ooo003oooooooooo`0Fooooo`03
o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo057ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1Aooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool0
5_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`1Aooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
D?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1<ooooo`03ool00?oo
oooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0D?ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo053ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0C?ooool0
0ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo053ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`1@ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
04cooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo
04cooooo00?o0000ooooooooool0;oooool2o`00057ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`1?ooooo`;o00003_ooool0023ooooo00?o0000ooooooooool0C?ooool00ooo003o
ooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo03oooooo0ooo000>ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool03?ooool3ool0047ooooo00?o0000ooooooooool03?ooool0023ooooo
0_l0001=ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003ooooo
ooooo`1<ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0?_ooool2ool00003oooo
oooo003oo`0000cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0<ooooo`04ool0
0?ooooooooooool0043ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0
C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0
C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03kooooo00Goo`00oooooooooooo
ooooool0000<ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02_ooool01Ooo003o
ooooooooooooooooo`00043ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooooooo
ool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooooooo
ool0C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02cooooo0ooo000>ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Wooooo0_oo0004ooooo`03ool00?oooooooooo00cooooo0ooo000^ooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool0
5_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0
;oooool2o`0001_ooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`02ool000gooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool02Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00_ooooo
0_oo0002ooooo`03ool00?oooooooooo00kooooo0_oo000Jooooo`;o00003_ooool0023ooooo00?o
0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o
o`00ooooooooool0C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00?o
o`00ooooooooool03_ooool4ool000kooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02Oooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03?ooool4ool0017ooooo00?o
o`00ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1<
ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<
ooooo`03o`000?oooooooooo02Sooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo1_oo000=
ooooo`03ool00?oooooooooo00;ooooo0_oo000;ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Sooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`03ooooo`;oo`003?ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00cooooo1Ooo0006ooooo`03o`000?oooooooooo00cooooo000Poooo
o`;o0000COooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooo
ooooool0C?ooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00oooool2ool000Cooooo0_oo000;ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Sooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Oooooo0_oo0006
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`09
ooooo`;oo`001?ooool2ool000Gooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooo
ooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooo
ooooool0C?ooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00_ooool2ool000Kooooo0_oo0009ooooo`;oo`001oooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Oooooo0_oo0007ooooo`03ool00?oooooooooo00Oooooo0_oo0006
ooooo`;oo`001?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1<oooo
o`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<oooo
o`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo00001?ooool5o`000003ool00?l0003o
000000Ko00000_oo0007o`0000;oo`002?l000000ooo003o0000o`000007o`000003ool00?l0003o
000000Oo000000?oo`00o`000?l000001_l000000ooo003o0000o`000006o`000003ool00?l0003o
000000Oo000000?oo`00o`000?l000001_l000000ooo003o0000o`00000@o`000003ool00?l0003o
000000Oo000000?oo`00o`000?l000001ol000000ooo003o0000o`000006o`000003ool00?l0003o
000000Oo000000?oo`00o`000?l000001_l00002ool000Oo00000_oo0008o`0000;oo`001ol00002
ool000So000000?oo`00o`000?l000000ol0000>ooooo`008?ooool00ol0003oooooooooo`1<oooo
o`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<oooo
o`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0<
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`08
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`08
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooo
ooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooo
ooooool0C?ooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool03Oooool2ool000Cooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00Wooooo0_oo0006ooooo`03ool00?oooooooooo00Sooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool02?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Sooooo0_oo0005
ooooo`;oo`002oooool2ool000Cooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`008?ooool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo01Kooooo00?o0000oooo
ooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo02Sooooo0_l00005oooo
o`03o`000?oooooooooo00kooooo1Ooo000=ooooo`;oo`000oooool2ool000cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool02?ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?oo`00oooo
ooooool02?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00;ooooo0_oo000=oooo
o`Goo`004?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0004gooooo00?oo`00oooooooo
ool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0Qooooo`Goo`003Oooool2ool000Cooooo00?oo`00oooooooo
ool02_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00;ooooo0_oo000=ooooo`Go
o`008oooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1<ooooo`03ool0
0?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`00
0?oooooooooo02oooooo0_l0000Tooooo`03ool00?oooooooooo00kooooo00Goo`00oooooooooooo
ooooool0000=ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02?ooool00ooo003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool02?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00[ooooo0_oo0003ooooo`03ool00?oooooooooo00ko
oooo00?oo`00ooooooooool08_ooool2o`0000kooooo000Pooooo`03o`000?oooooooooo04cooooo
00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0eooooo`Coo`003Oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0;ooooo`Coo`00=oooool00ol0003oooooooooo`0<ooooo`003_ooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0C?ooool00ooo003ooooooooo
o`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo03Kooooo0_oo000?ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00cooooo0_oo
000hooooo`03o`000?oooooooooo00cooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool0
5_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`17ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04Oooooo00?o0000ooooooooool0
3?ooool000gooooo00Co0000oooooooooooo00002oooool01?l0003oooooooooooooool2o`0004go
oooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04_o
oooo0_l0000aooooo`;o0000B?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`16ooooo`;o00003_ooool000gooooo
00Co0000oooooooooooo00002oooool01Ol0003ooooooooooooooooo000004kooooo00?oo`00oooo
ooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`18ooooo`03ool00?oooooooooo00;oo`003?ooool00ooo
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool02_ooool01?oo
003ooooooooooooo001:ooooo`03o`000?oooooooooo00cooooo000=ooooo`04o`000?oooooooooo
o`0000Oooooo1?l00004ooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool05_ooool0
0ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`18ooooo`04ool00?ooooooooooool000gooooo00?oo`00ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo00[ooooo00Coo`00ooooooooooooo`00
B_ooool00ol0003oooooooooo`0<ooooo`003Oooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo04Wooooo0ooo000=ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ooo003oooooooooo`0;ooooo`;oo`00Boooool00ol0003oooooooooo`0<ooooo`003_oo
ool2o`0000Sooooo1Ol00003ooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool05_oo
ool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo04cooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooo
oooo04cooooo00?o0000ooooooooool0;oooool2o`0005[ooooo00?oo`00ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo05Sooooo0_l0000>ooooo`008?ooool2o`00
04gooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo
04cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo
00cooooo000Pooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool05_ooool00ol0003o
ooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`1Iooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo04cooooo
00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo
00?o0000ooooooooool07?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`03
o`000?oooooooooo05Wooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo05Wooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0
C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0
C?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00cooooo000Pooooo`03
o`000?oooooooooo04cooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03
ool00?oooooooooo04cooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00Cooooo0_l0001Jooooo`03ool00?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ooo003oooooooooo`1Hooooo`;o00003_ooool0023ooooo00?o0000oooooooo
ool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooooooo
ool0C?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00cooooo000Pooooo`;o
0000COooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooooooo
ool0C?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo05Wooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo
01Gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05Wooooo00?o
o`00ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo05Wooooo00?o
0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`0F
ooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0L
ooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool0FOooool00ooo003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0FOooool00ol0003oooooooooo`0<
ooooo`008?ooool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo01Kooooo00?o0000oooo
ooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo02oooooo0_l0001Koooo
o`03ool00?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1Hoooo
o`;o00003_ooool0023ooooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03
o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo05[ooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo05Wooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0
C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0
C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05[ooooo00?oo`00ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo05Wooooo00?o0000ooooooooool0
3?ooool0023ooooo0_l0001=ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Ooo
ool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0F_oo
ool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0F_oo
ool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1<ooooo`03ool00?oooooo
oooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0F_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?oo`00ooooooooool0F_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0
003oooooooooo`1<ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo
003oooooooooo`1<ooooo`03o`000?oooooooooo02oooooo0_l0001Kooooo`03ool00?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`1Iooooo`;o00003_ooool0023o
oooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05[o
oooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05[o
oooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0C?ooool00ooo003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo05[ooooo00?oo`00ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo05[ooooo00?o0000ooooooooool03?ooool0023ooooo00?o
0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o
o`00ooooooooool0C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05[ooooo00?o
o`00ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05[ooooo00?o
0000ooooooooool03?ooool0023ooooo0_l0001=ooooo`03ool00?oooooooooo01Kooooo00?o0000
ooooooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0F_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oo`00
ooooooooool0F_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1<oooo
o`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<oooo
o`03o`000?oooooooooo02oooooo0_l0001Kooooo`03ool00?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ooo003oooooooooo`1Iooooo`;o00003_ooool0023ooooo00?o0000oooooooo
ool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooooooo
ool0C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05[ooooo00?oo`00oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05[ooooo00?o0000oooooooo
ool03?ooool001Wooooo0ol00004ooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool0
5_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0
7?ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0
F_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0
F_ooool00ol0003oooooooooo`0<ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo04cooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oo
oooooooo04cooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0F_ooool00ooo003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?oo`00ooooooooool0F_ooool00ol0003oooooooooo`0<ooooo`006_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool05_oo
ool00ol0003oooooooooo`0Eooooo`;oo`00COooool00ol0003oooooooooo`0Kooooo`04o`000?oo
ooooooooo`0000Oooooo1Ol00004ooooo`03o`000?oooooooooo05[ooooo00?oo`00ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool0
3?ooool001[ooooo00?o0000ooooooooool00oooool2o`0004gooooo<_oo001=ooooo`;o00007Ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo0_l0001Kooooo`03
ool00?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1Jooooo`;o
00003_ooool001[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Uooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool0Foooool00ooo003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?oo`00ooooooooool0Foooool00ol0003oooooooooo`0<ooooo`00
6Oooool2o`0000Gooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo01_ooooo00Co0000oooooooooooo00002Oooool2o`0000Gooooo00?o0000oooooooo
ool0Foooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?oo`00oooooooo
ool0Foooool00ol0003oooooooooo`0<ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Looooo`;o0000
2oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool0
3?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo02oooooo0_l0001Looooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ooo003oooooooooo`1Jooooo`;o00003_ooool0023ooooo0_l0001Vooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Kooooo`03ool00?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1Kooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool03?ooool0023o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0Foooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?oo`00ooooooooool0Foooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`1Kooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ooo003ooooo
ooooo`1Kooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o0000G?ooool00ooo003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0F_ooool2o`0000kooooo000P
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Voooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Loooo
o`03ool00?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1Koooo
o`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05cooooo00?oo`00oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05_ooooo00?o0000oooooooo
ool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0G?ooool00ooo003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool0Foooool00ol0003oooooooooo`0<ooooo`008?oo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;ooo
ool2o`0005gooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03ool00?oo
oooooooo05_ooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Looooo`03ool00?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`1Looooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Looooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0
003oooooooooo`1Looooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ooo
003oooooooooo`1Looooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000I_ooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0G?ooool00ooo003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0G?ooool00ol0003oooooooooo`0<
ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool06oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ooo003oooooooooo`1Looooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooo`0000Oooooo1?l00005ooooo`;o0000GOooool00ooo003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?oo`00ooooooooool0Foooool2o`0000kooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Looooo`03ool00?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`1Looooo`03o`000?oo
oooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ooo003oooooooooo`1Looooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Looooo`;o00002_ooool2
o`0000Gooooo00?o0000ooooooooool0G?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?oo`00ooooooooool0G?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`00
06Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
05cooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo
05cooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo02oooooo0_l0001Mooooo`03ool00?oooooooooo00;o
oooo00Go0000ooooooooooooooooool0001Nooooo`;o00003_ooool0023ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0G?ooool00ooo003oooooooooo`02ooooo`05o`000?oooooooooooooooooo0000Goooool00ol0
003oooooooooo`0<ooooo`003Oooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Co
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0GOooool01Ooo003ooooooooooooooooo000000?ooooo00?oo`00oooo
ooooool0GOooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`07ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Mooooo`05ool00?oooooooooo
ooooool000000oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00001Wooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Mooooo`05ool00?oooooo
ooooooooool000000oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00cooooo000>
ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0_l0001Vooooo`03o`000?oo
oooooooo06?ooooo0_l0000aooooo`;o0000G_ooool01Ooo003ooooooooooooooooo000000?ooooo
00?oo`00ooooooooool0G?ooool2o`0000kooooo000>ooooo`03o`000?oooooooooo00Oooooo1?l0
0004ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo05gooooo00Goo`00ooooooooooooooooo`000003ooooo`03ool0
0?oooooooooo05gooooo00?o0000ooooooooool03?ooool000gooooo0_l00009ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0GOooool01Ooo003ooooooooooooooooo000000?ooooo
00?oo`00ooooooooool0GOooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003ooooooooo
o`07ooooo`Go00000oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`1Mooooo`05ool00?ooooooooooooooool00000
0oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o0000G_oo
ool01Ooo003ooooooooooooooooo000000?ooooo00?oo`00ooooooooool0G?ooool2o`0000kooooo
000Pooooo`;o0000I_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0GOooool01Ooo003ooooooooooooooooo000000?ooooo00?oo`00ooooooooool0
GOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Mooooo`05ool00?oo
ooooooooooooool000000oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00cooooo
000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0Looooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooooooo
o`1Nooooo`04ool00?ooooooooooo`0000?ooooo00?oo`00ooooooooool0GOooool00ol0003ooooo
ooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool06oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`1Nooooo`04ool00?ooooooooooo`0000?ooooo00?oo`00oooo
ooooool0GOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001?ooool2o`0005oooooo00Coo`00oooooooooooo00000_oo
ool00ooo003oooooooooo`1Mooooo`;o00003_ooool0023ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002?oo
ool3o`0000Gooooo00?o0000ooooooooool0G_ooool01?oo003oooooooooool00002ooooo`03ool0
0?oooooooooo05kooooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Vooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Nooooo`04ool00?ooooooooooo`00
00;ooooo00?oo`00ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool06oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1N
ooooo`04ool00?ooooooooooo`0000;ooooo00?oo`00ooooooooool0G_ooool00ol0003ooooooooo
o`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool07?ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo05kooooo00Coo`00
oooooooooooo00000_ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000P
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_
ooooo`;o0000Goooool01?oo003oooooooooool00002ooooo`03ool00?oooooooooo05gooooo0_l0
000>ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`1Nooooo`04ool00?ooooooooooo`0000;ooooo00?o
o`00ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1N
ooooo`04ool00?ooooooooooo`0000;ooooo00?oo`00ooooooooool0G_ooool00ol0003ooooooooo
o`0<ooooo`008?ooool2o`0006Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo05kooooo00Coo`00oooooooooooo00000_ooool00ooo003ooooooooo
o`1Nooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05oooooo00?oo`00
ooooool000000_ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Poooo
o`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_oooo
o`;o0000H?ooool00ooo003oooooo`000002ooooo`03ool00?oooooooooo05gooooo0_l0000>oooo
o`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`1Oooooo`05ool00?oooooo0000oooooooo0000HOooool00ol0
003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Oooooo`05ool00?oooooo0000oooo
oooo0000HOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Oooooo`05
ool00?oooooo0000oooooooo0000HOooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0006Ko
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05oo
oooo00Goo`00ooooool0003oooooool0001Qooooo`03o`000?oooooooooo00cooooo000Pooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o
0000H?ooool01Ooo003oooooo`000?ooooooo`00063ooooo0_l0000>ooooo`008?ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1Oooooo`04ool00?oooooo0000ool006;ooooo00?o0000ooooooooool03?ooool001So
oooo1Ol00003ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`0Wooooo`?o00001Oooool00ol0003oooooooooo`1Pooooo`03ool00?l0003oo`0006;o
oooo00?o0000ooooooooool03?ooool001Wooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?oo`00o`000?oo0000H_ooool00ol0003o
ooooooooo`0<ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0H?ooool3ool006;ooooo00?o0000ooooooooool03?ooool001_ooooo00?o
0000ooooooooool00_ooool2o`0006Kooooo00?o0000ooooooooool0Hoooool2o`0002[ooooo00?o
0000ooooooooool01?ooool2o`0006;ooooo00?oo`00ooooooooool0H?ooool2o`0000kooooo000H
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00cooooo000Hooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool09oooool2o`0000Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`006Oooool3o`0000Cooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool01?ooooo9o`0000kooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;oooool01Ol0003ooooooooooooooooo00000?oooooo2Oooool0023ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`00003oooooo`Wooooo000Pooooom3o0000ooooool9ooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooolOooooo`?o00001?ooool2o`00
02_ooooo0ol0000/ooooo`;o0000;_ooool3o`0002_ooooo0ol00004ooooo`;o00004?ooool002Go
oooo1Ol0000]ooooo`?o0000;Oooool2o`0002kooooo0ol0000^ooooo`Go0000<_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0002Wooooo00Go0000ooooooooooooooooo`00000Z
ooooo`04o`000?ooooooooooo`0002cooooo00Go0000ooooooooooooooooo`00000[ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00003oooool002Kooooo00Co0000oooooooooooo
0000;_ooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0002kooooo00?o0000oooo
ooooool0;_ooool01?l0003oooooooooool0000Zooooo`Go00000oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0002?ooooo1Ol00005ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo0000<?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00003oooool001oooooo1Ol00003ooooo`03o`000?oooooooooo02Kooooo
1Ol00003ooooo`03o`000?oooooooooo02_ooooo00Co0000oooooooooooo0000;_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000]ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000<?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00003ooo
ool002Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0[ooooo`04o`000?oooooo
ooooo`0002kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000:Oooool4o`0002_ooooo00Co0000oooooooooooo
0000;?ooool4o`0002cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000?oooo
o`009Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooooooool0:oooool01?l0
003oooooooooool0000^ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00
000aooooo`;o00001?ooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo02cooooo
00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0/ooooo`;o00001?ooool01?l0003o
ooooooooool0000?ooooo`009Oooool01Ol0003ooooooooooooooooo000002gooooo0_l0000]oooo
o`04o`000?ooooooooooo`0002gooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000<_oo
ool00ol0003oooooooooo`03ooooo`;o0000:_ooool5o`0002_ooooo0_l0000]ooooo`Go0000:ooo
ool00ol0003oooooooooo`03ooooo`;o00004?ooool002Kooooo0ol0000_ooooo`03o`000?oooooo
oooo02cooooo0_l0000_ooooo`03o`000?oooooooooo02kooooo0ol0003oooooo`gooooo003ooooo
ooWooooo003oooooooWooooo003oooooooWooooo003ooooooacooooocol0000>ooooo`008?ooooo@
o`0002_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0<
ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1Mooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool01?ooool2o`00oekooooo00?o0000ooooooooool03?ooool001[ooooo0_l00004ooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo05gooooo0_l00?l5ooooo`03o`000?oooooooooo00Cooooo0_l00?mNooooo`03
o`000?oooooooooo00cooooo000Iooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo0_l0001Mooooo`03
o`00oooooooo003o00Gooooo00?o0000ooooooooool01?ooool2o`00oekooooo00?o0000oooooooo
ool03?ooool001Wooooo00Co0000oooooooooooo00000oooool2o`0000?ooooo<ol00?l`ooooo`03
o`000?oooooooooo02kooooo<ol00?l2ooooo`;o0000:oooool00ol0003oooooooooo`1Looooo`03
o`00oooooooo003o00Gooooo00?o0000ooooooooool00oooool00ol00?ooooooo`00o`1Nooooo`03
o`000?oooooooooo00cooooo000Iooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003ooooooooo
ool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05cooooo00?o003oooooool0
0?l01Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooo003o05kooooo00?o0000oooooooo
ool03?ooool001Wooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0cooooo`03
o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0G?ooool00ol00?ooooooo`00o`05ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooool00?l0G_ooool00ol0003oooooooooo`0<ooooo`00
6Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo03?ooooo00?o003ooooooooo
ool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1Looooo`03o`00oooooooo003o00Gooooo00?o0000oooooooo
ool00oooool01?l00?ooooooooooool00?mMooooo`03o`000?oooooooooo00cooooo000Jooooo`;o
00001?ooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000oooooooo
ool0;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo02Wooooo0_l0001Mooooo`03
o`00oooooooo003o00Gooooo00?o0000ooooooooool00oooool01?l00?ooooooooooool00?mMoooo
o`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo03?ooooo00?o003ooooooooo
ool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1Looooo`03o`00oooooooo003o00Gooooo00?o0000oooooooo
ool00oooool01?l00?ooooooooooool00?mMooooo`03o`000?oooooooooo00cooooo000Pooooo`;o
0000=?ooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003ooooooooo
ool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05cooooo00?o003oooooool0
0?l01Oooool00ol0003oooooooooo`03ooooo`04o`00ooooooooooooo`00oegooooo00?o0000oooo
ooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03
o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo05cooooo00?o003oooooool00?l01Oooool00ol0003oooooooooo`03ooooo`04
o`00ooooooooooooo`00oegooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooooooo
ool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003ooooooooo
ool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05_ooooo00Co003ooooooooo
oooo003o1Oooool00ol0003oooooooooo`03ooooo`04o`00ooooooooooooo`00oegooooo00?o0000
ooooooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_oooo
o`03o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yoooo
o`;o0000E?ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol0003oooooooooo`03ooooo`04o`00ooooooooooooo`00o`Oooooo0_l00?mDooooo`03o`000?oo
oooooooo00cooooo000Pooooo`03o`000?oooooooooo03?ooooo00?o003oooooooooool0;oooool0
0ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`1Cooooo`;o003o1_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
0000ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Oooooo0_l00?mDooooo`03o`00
0?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo03?ooooo00?o003oooooooooool0;ooo
ool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`1Booooo`03o`00oooooooo003o00Kooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`000?oooooooooo00;ooooo00Go003oooooooooooooooooo`00o`06ooooo`03
o`00oooooooo003o05Cooooo00?o0000ooooooooool03?ooool0023ooooo0_l0000dooooo`03o`00
oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0D_ooool00ol00?ooooooo`00o`06ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol0003oooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l01_ooool00ol00?ooooooo`00o`1Dooooo`03o`000?oooooooooo00cooooo000Pooooo`03
o`000?oooooooooo03?ooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03
o`00oooooooooooo03?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`19ooooo`;o
003o1oooool01?l00?ooooooooooool00?l5ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol0003oooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooo`00
o`07ooooo`?o003oB_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`0c
ooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0c
ooooo`03o`000?oooooooooo02Wooooo0_l00011ooooo`03o`00oooooooooooo00Gooooo0ol00?l6
ooooo`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o0000ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Kooooo00Co003ooooooooo
oooo003o1_ooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo03oooooo00?o0000oooo
ooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03
o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo03Gooooo0_l00?l7ooooo`?o003o1oooool01?l00?ooooooooooool00?l5oooo
o`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
0000ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00Co
003ooooooooooooo003o1_ooool00ol00?ooooooo`00o`07ooooo`?o003o2?ooool00ol00?oooooo
ooooo`0eooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo03?ooooo00?o
003oooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o
0000ooooooooool08_ooool2o`0000Gooooo00?o0000ooooooooool06?ooool00ol00?oooooooooo
o`06ooooo`;o003o2?ooool2o`00o`Oooooo1?l00?l6ooooo`04o`00oooooooo003oo`00o`Kooooo
00Co003ooooooooooooo003o1Oooool01Ol00?oooooooooooooooooo003o00Gooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01_ooool01?l00?oooooooooo
ool00?l5ooooo`;o003o00?oooooo`00ooooool01_ooool3o`00o`Oooooo0ol00?l7ooooo`;o003o
2?ooool2o`00oaWooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0<ooo
ool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool0<ooo
ool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0oooool3o`00o`Oooooo0ol00?l7ooooo`?o003o1oooool3o`00o`Kooooo00Co003ooooooooooooo
003o1_ooool01?l00?ooooooooooool00?l6ooooo`04o`00ooooooooooooo`00o`Gooooo00Go003o
ooooooooooooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`05ooooo`05
o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003o
ooooooooool00_l00?l5ooooo`;o003o00?oooooo`00ooooool01Oooool4o`00o`Kooooo1?l00?l6
ooooo`?o003o1oooool3o`00o`Gooooo00?o0000ooooooooool03?ooool0023ooooo0_l0000doooo
o`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0coooo
o`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02
ooooo`;o003o00?oooooo`00ool00?l01Oooool2o`00o`;ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`02o`00o`Gooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01?l00?ooooooooooooooool2o`00o`Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01Oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00oooo
ooooooooooooool00?l01?ooool2o`00o`?ooooo00?o003oooooooooool00_ooool2o`00o`;ooooo
0_l00?l4ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`;o003o00?oooooo`00ool00?l0
1Oooool2o`00o`03ooooool00?oo003o00Cooooo00?o0000ooooooooool03?ooool0023ooooo00?o
0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o
003oooooooooool0<oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Cooooo
1Ol000000ol00?oo0000o`000002o`000004o`00ool0003o0000o`0000;o003o0ol00002o`00o`?o
000000?o003oo`000?l000000ol000001Ol00?oo0000o`000?l0003o003o00Co00000_l00?l3o`00
0003o`00ool0003o000000;o000000?o003oo`000?l000000_l000000ol00?oo0000o`000002o`00
0003o`00ool0003o000000;o000000?o003oo`000?l000000_l000000ol00?oo0000o`000002o`00
0005o`00ool0003o0000o`000?l00?l01Ol000001Ol00?oo0000o`000?l0003o003o00Co000000?o
003oo`000?l000000_l000000ol00?oo0000o`000007o`000003o`00ool0003o000000;o000000?o
003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000?o
003oo`000?l000000_l000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l0
1?l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000?o003oo`000?l00000
0_l00002o`00o`?o000000?o003oo`000?l000000_l000001?l00?oo0000o`000?l00002o`00o`Co
000000Co003oo`000?l0003o00000_l00?l4o`000004o`00ool0003o0000o`0000;o003o0ol00000
0ol00?oo0000o`000003o`0000kooooo000Pooooo`03o`000?oooooooooo03?ooooo00?o003ooooo
ooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000oooo
ooooool08Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Sooooo1?l00?l6
ooooo`Co003o1Oooool2o`00o`03ooooool00?oo003o00Gooooo00Co003ooooooooooooo003o1_oo
ool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00;o003o1?ooool01Ol00?oooooo
oooooooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooo
oooooooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`Kooooo00Co003ooooooooooooo003o1_ooool4o`00o`Gooooo1Ol00?l9ooooo`03o`000?oo
oooooooo00cooooo000Pooooo`03o`000?oooooooooo03?ooooo00?o003oooooooooool0;oooool0
0ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000ooooooooool08Oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo01?ooooo0_l00?l7ooooo`?o003o1ooo
ool3o`00o`Kooooo1?l00?l6ooooo`04o`00ooooooooooooo`00o`Gooooo00Go003ooooooooooooo
ooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo
003o00Cooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l0
1Oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003oooooool00?l01_ooool2o`00o`03
ooooool00?oooooo00Gooooo1?l00?l6ooooo`?o003o2?ooool2o`00oaCooooo00?o0000oooooooo
ool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`00
0?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Rooooo`;o0000
1Oooool00ol0003oooooooooo`0`ooooo`;o003o1oooool3o`00o`Oooooo00Co003ooooooooooooo
003o1Oooool01Ol00?oooooooooooooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00Kooooo
00Co003ooooooooooooo003o1_ooool3o`00o`Oooooo0_l00?lbooooo`03o`000?oooooooooo00co
oooo000Pooooo`03o`000?oooooooooo03?ooooo00?o003oooooooooool0;oooool00ol0003ooooo
ooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0jooooo`;o003o1oooool3o`00o`Oooooo00Co003ooooooooooooo003o1Oooool01Ol00?oo
oooooooooooooooo003o00Gooooo00Go003oooooooooooooooooo`000004ooooo`03o`00oooooooo
oooo00?ooooo00Co003ooooooooooooo003o1_ooool01?l00?ooooooooooool00?l6ooooo`?o003o
2?ooool00ol00?ooooooooooo`0jooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000=?oo
ool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool0<ooo
ool00ol0003oooooooooo`0Yooooo`;o0000AOooool2o`00o`Oooooo00?o003oooooool00?l01_oo
ool01Ol00?oooooooooooooooooo003o00Gooooo00Go003oooooooooooooooooo`000004ooooo`03
o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooo`00o`08oooo
o`03o`00oooooooooooo04Cooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooooooo
ool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003ooooooooo
ool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04gooooo0ol00?l6ooooo`05
o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo000000Cooooo00?o003o
ooooooooool00oooool01?l00?ooooooooooool00?l6ooooo`?o003oCoooool00ol0003ooooooooo
o`0<ooooo`008?ooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000
ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0C_ooool2o`00o`Kooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00oooo
ooooooooooooool000001?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Oo
oooo0_l00?m?ooooo`03o`000?oooooooooo00cooooo000>ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oooooo
00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0E_ooool01?l00?ooooooooooool00?l6ooooo`05o`00oooooooooooooooo
ool000001?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00oeSooooo00?o0000
ooooooooool03?ooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oo
oooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo05Oooooo00?o003oooooool00?l01_ooool01Ol00?oooooooooooooooooo000000Cooooo
00?o003oooooooooool00oooool01?l00?ooooooooooool00?mHooooo`03o`000?oooooooooo00co
oooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooooooo0_l0000doooo
o`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0boooo
o`;o0000:oooool2o`0005Sooooo00?o003oooooool00?l01_ooool01Ol00?oooooooooooooooooo
000000Cooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`1Iooooo`03o`000?oooooo
oooo00cooooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00
000eooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?oooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Eoooool00ol00?ooooooo`00
o`06ooooo`05o`00ooooooooooooooooool000001?ooool00ol00?ooooooooooo`04ooooo`;o003o
FOooool00ol0003oooooooooo`0<ooooo`003Oooool01?l0003oooooooooool00007ooooo`Co0000
1?ooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0
;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
Eoooool3o`00o`Kooooo00Go003oooooooooooooooooo`000004ooooo`03o`00oooooooooooo00Co
oooo0_l00?mIooooo`03o`000?oooooooooo00cooooo000=ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oo
oooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0F?ooool00ol00?ooooooooooo`05ooooo`05o`00oooooooooooooooo
ool000001?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Sooooo00?o0000oooo
ooooool03?ooool000kooooo0_l00008ooooo`Go00000oooool00ol0003oooooooooo`0cooooo`03
o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0H?ooool01Ol00?oooooooooooooooooo0000
00Cooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003o
ooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?oo
ooooooooo`0cooooo`03o`000?oooooooooo02Wooooo0_l0001Qooooo`05o`00oooooooooooooooo
ool000000oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Pooooo`;o
0000=?ooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003ooooooooo
ool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo063ooooo00Go003ooooooooo
ooooooooo`000003ooooo`03o`00oooooooooooo063ooooo00?o0000ooooooooool03?ooool0023o
oooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02ko
oooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo063o
oooo00Go003oooooooooooooooooo`000003ooooo`03o`00oooooooooooo063ooooo00?o0000oooo
ooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03
o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo063ooooo00Go003oooooooooooooooooo`000003ooooo`03o`00oooooooooooo
063ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?oo
ooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo063ooooo00Go003oooooooooooooooooo`000003oooo
o`03o`00oooooooooooo063ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooooooo
ool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003ooooooooo
ool0<oooool00ol0003oooooooooo`0Yooooo`;o0000HOooool01Ol00?oooooooooooooooooo0000
00?ooooo00?o003oooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003o
ooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?oo
ooooooooo`0cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0H?ooool01Ol00?oo
oooooooooooooooo000000?ooooo00?o003oooooooooool0H?ooool00ol0003oooooooooo`0<oooo
o`008?ooool2o`0003Cooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03
o`00oooooooooooo03?ooooo00?o0000ooooooooool05_ooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool0H?ooool01Ol00?oooooooooooooooooo0000
00?ooooo00?o003oooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003o
ooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?oo
ooooooooo`0cooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0H?ooool01Ol00?oooooooooooooo
oooo000000?ooooo00?o003oooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008?ooool0
0ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool0
0ol00?ooooooooooo`0cooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo063ooooo00Go003ooooooooooooooooo
o`000003ooooo`03o`00oooooooooooo063ooooo00?o0000ooooooooool03?ooool0023ooooo00?o
0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o
003oooooooooool0<oooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool00_ooool2o`00067ooooo00Go003oooooooooooooooooo`000003ooooo`03
o`00oooooooooooo05oooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`0cooooo`03o`00
oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`00
0?oooooooooo01Gooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo00?o0000oooooooo
ool0H?ooool01Ol00?oooooooooooooooooo000000?ooooo00?o003oooooooooool0H?ooool00ol0
003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oo
oooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo01Go
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
063ooooo00Go003oooooooooooooooooo`000003ooooo`03o`00oooooooooooo063ooooo00?o0000
ooooooooool03?ooool0023ooooo0_l0000dooooo`03o`00oooooooooooo02oooooo00?o0000oooo
ooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo01Kooooo0_l00008oooo
o`Go00001?ooool00ol0003oooooooooo`1Pooooo`05o`00ooooooooooooooooool000000oooool0
0ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
03?ooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo
03?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Pooooo`05o`00oooooooooooo
ooooool000000oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Poooo
o`03o`000?oooooooooo03?ooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`03o`00oooooooooooo03?ooooo00?o0000ooooooooool0:Oooool2o`00067ooooo00Go003ooooo
ooooooooooooo`000003ooooo`03o`00oooooooooooo063ooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo
02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
063ooooo00Go003oooooooooooooooooo`000003ooooo`03o`00oooooooooooo063ooooo00?o0000
ooooooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_oooo
o`03o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo063ooooo00Go003oooooooooooooooooo`000003ooooo`03o`00oooooooo
oooo063ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol0
0?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo067ooooo00Co003ooooooooooooo00000oooool0
0ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000=?ooool00ol0
0?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo067ooooo00Co003ooooooooooooo00000oooool0
0ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
03?ooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo
03?ooooo00?o0000ooooooooool0:Oooool2o`0006;ooooo00Co003ooooooooooooo00000oooool0
0ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
03?ooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo
03?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Qooooo`04o`00oooooooooooo
o`0000;ooooo00?o003oooooooooool0HOooool00ol0003oooooooooo`0<ooooo`006Oooool3o`00
00Cooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo
02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
067ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool00ol0
0?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo067ooooo00Co003ooooooooooooo00000_ooool0
0ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0<oooool2o`00oc3ooooo00?o0000ooooooooool0;_ooool00ol0
0?ooooooooooo`0cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0HOooool01?l0
0?ooooooooooool00002ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool0
01[ooooo00?o0000ooooooooool00oooool2o`0003CoooooI?l00?ldooooo`;o0000:oooool2o`00
06;ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0HOooool01?l0
0?ooooooooooool00002ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool0
01Wooooo0_l00005ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo067ooooo00Co003ooooooooooooo00000_ooool0
0ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0HOooool01?l00?ooooooooooool00002ooooo`03o`00oooooooo
oooo067ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0HOooool01?l0
0?ooooooooooool00002ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool0
023ooooo0_l0001Vooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool2o`00
06;ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo067ooooo00Co003ooooooooooooo00000_ooool0
0ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Qooooo`?o00001Oooool00ol0
003oooooooooo`1Qooooo`04o`00ooooooooooooo`0000;ooooo00?o003oooooooooool0HOooool0
0ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
067ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0HOooool01?l0
0?ooooooooooool00002ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01?ooool2o`0006;ooooo00Co003ooooooooooooo00000_ooool0
0ol00?ooooooooooo`1Pooooo`;o00003_ooool0023ooooo0_l0001Vooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
067ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Qooooo`;o00001_ooool00ol0003oooooooooo`1Qooooo`04o`00oooooooooooo
o`0000;ooooo00?o003oooooooooool0HOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo067ooooo00Co003ooooooooooooo00000_ooool0
0ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
067ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Yooooo`;o0000Hoooool00ol00?ooooooo`000002ooooo`03o`00oooooooooooo
067ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0H_ooool00ol00?oo
ooooo`000002ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool0023ooooo
0_l0001Vooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1Rooooo`03o`00oooooooo000000;ooooo00?o003oooooooooool0HOooool00ol0003ooooo
ooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1Rooooo`03o`00oooooooo000000;ooooo00?o
003oooooooooool0HOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1R
ooooo`03o`00oooooooo000000;ooooo00?o003oooooooooool0HOooool00ol0003oooooooooo`0<
ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool0:Oooool2o`0006?ooooo00?o003oooooool000000_ooool00ol00?ooooooooooo`1Qoooo
o`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06;ooooo00?o003oooooool0
00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo06;ooooo00?o003oooooool000000_ooool00ol00?ooooooooooo`1Qooooo`03o`00
0?oooooooooo00cooooo000Pooooo`;o0000I_ooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0H_ooool00ol00?ooooooo`000002ooooo`03o`00oooo
oooooooo067ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0H_ooool0
0ol00?ooooooo`000002ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
02Wooooo0_l0001Sooooo`03o`00oooooooo000000;ooooo00?o003oooooooooool0HOooool00ol0
003oooooooooo`0<ooooo`003Oooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Co
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0H_ooool00ol00?ooooooo`000002ooooo`03o`00oooooooooooo067o
oooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool01oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0H_ooool00ol00?ooooooo`000002ooooo`03
o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0
2oooool01Ol0003ooooooooooooooooo000006Oooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo06;ooooo00Go003oooooool0003oooooo`00o`1Toooo
o`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooo
oooooooo0_l0001Vooooo`03o`000?oooooooooo06?ooooo0_l0000[ooooo`03o`000?oooooooooo
06;ooooo00Go003oooooool0003oooooo`00o`1Tooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo00Oooooo1?l00004ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`0Yooooo`;o0000Hoooool01Ol00?ooooooo`000?oooooo
003o06Cooooo00?o0000ooooooooool03?ooool000gooooo0_l00009ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0H_ooool01Ol00?ooooooo`000?oooooo003o06Cooooo00?o0000
ooooooooool03?ooool000kooooo00?o0000ooooooooool01oooool5o`0000?ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Gooooo0ol00004oooo
o`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo06;ooooo00Go003ooooo
ool0003oooooo`00o`1Tooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06;ooooo00Go003o
ooooool0003oooooo`00o`1Tooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`05o`00oooooooo
0000ooooool00?l0I?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0006Kooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00_ooool2o`0006?ooooo00Go003oooooool0003oooooo`00o`1Sooooo`;o00003_oo
ool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool01oooool4o`0000Gooooo00?o0000ooooooooool0H_ooool0
1Ol00?ooooooo`000?oooooo003o06Cooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Gooooo0_l00009
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H_ooool01Ol00?ooooooo`000?oo
oooo003o06Cooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool5
o`0000Cooooo00?o0000ooooooooool0H_ooool01Ol00?ooooooo`000?oooooo003o06Cooooo00?o
0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0H_ooool01Ol00?ooooooo`000?oo
oooo003o06Cooooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Vooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0:Oooool2o`0006?ooooo00Go003oooooool0003oooooo`00
o`1Tooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06;ooooo00Go003o
ooooool0003oooooo`00o`1Tooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo06;ooooo00Go003oooooool0003oooooo`00o`1Tooooo`03o`000?oooooooooo00cooooo000P
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo06?ooooo00Co003oo`000?oooooo003oI?ooool00ol0003ooooooooo
o`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`1Sooooo`04o`00ool0003oooooo`00ofCooooo00?o
0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo02Wooooo0_l0001Tooooo`03o`00ool0003o003o06Gooooo00?o0000
ooooooooool03?ooool0023ooooo0_l0001Vooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1Sooooo`03o`00ool0003o003o06Gooooo00?o0000oooo
ooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0Hoooool00ol00?oo0000o`00o`1Uooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06?ooooo00?o003oo`000?l00?l0
IOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Sooooo`03o`00ool0
003o003o06Gooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo0_l0001Tooooo`03o`00ool0003o
003o06Gooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Hoooool00ol0
0?oo0000o`00o`1Uooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000I_ooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Hoooool00ol00?oo
0000o`00o`1Uooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06?ooooo
00?o003oo`000?l00?l0IOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`1Sooooo`03o`00ool0003o003o06Gooooo00?o0000ooooooooool03?ooool001Sooooo1Ol00003
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Y
ooooo`;o0000I?ooool00ol00?oo0000o`00o`1Uooooo`03o`000?oooooooooo00cooooo000Ioooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Hoooool00ol00?oo0000o`00o`1U
ooooo`03o`000?oooooooooo00cooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo023ooooo1Ol00004oooo
o`03o`000?oooooooooo06Cooooo0_l00?mUooooo`03o`000?oooooooooo00cooooo000Kooooo`03
o`000?oooooooooo00;ooooo0_l0001Vooooo`03o`000?oooooooooo06?ooooo0_l0000Sooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0I?ooool2o`00ofGooooo00?o0000oooo
ooooool03?ooool001Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0I?ooool2o`00ofGooooo00?o0000ooooooooool03?ooool001So
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo0_l0001Uoooo
o`03o`00oooooooooooo06?ooooo0_l0000>ooooo`006Oooool3o`0000Cooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo023ooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;oooool01Ol0003ooooooooooooooooo000002;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`00000Sooooo`?o00001Oooooo?o`0000kooooo000Poooo
om3o0000ooooool9ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {473.625, 0}} -> {-0.0501996, -0.0470982, \
0.00417575, 0.00417575}, {{12, 240.062}, {462.312, 321.375}} -> {-2.76021, \
-0.503531, 0.0202563, 0.017168}, {{262.875, 490.938}, {462.312, 321.375}} -> \
{-40.8355, -0.100845, 0.104829, 0.00206464}, {{12, 240.062}, {307.25, \
166.312}} -> {-2.76021, -3.16564, 0.0202563, 0.017168}, {{262.875, 490.938}, \
{307.25, 166.312}} -> {-40.8355, -2.10496, 0.104829, 0.0103232}, {{12, \
240.062}, {152.188, 11.25}} -> {-2.76021, -5.82775, 0.0202563, 0.017168}, \
{{262.875, 490.938}, {152.188, 11.25}} -> {-39.3408, -7.1721, 0.101747, \
0.0200392}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Discrete-time Fourier transform (DTFT): additional \
illustrations\
\>", "Section"],

Cell[CellGroupData[{

Cell["Example #1a: 1Hz cosine (finite length, discrete-time)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := Cos[2  \[Pi]\ t];\)\), "\n", 
    \(xd = \ sampler[x, fs = 10]; \ 
    If[OddQ[Length[xd]], \ xd\  = \ Drop[xd, \(-1\)]];\), "\n", 
    \(\(DiscreteListPlot2[xd, \ Blue, \ Frame \[Rule] True, 
        Axes \[Rule] {True, False}, \ AspectRatio \[Rule] 1/3, 
        ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0194363 0.166667 0.15873 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21817 -0.0125 -6 -9 ]
[.21817 -0.0125 6 0 ]
[.41254 -0.0125 -6 -9 ]
[.41254 -0.0125 6 0 ]
[.6069 -0.0125 -6 -9 ]
[.6069 -0.0125 6 0 ]
[.80126 -0.0125 -6 -9 ]
[.80126 -0.0125 6 0 ]
[.99563 -0.0125 -6 -9 ]
[.99563 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -12 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .0873 -24 -4.5 ]
[-0.0125 .0873 0 4.5 ]
[-0.0125 .16667 -6 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .24603 -18 -4.5 ]
[-0.0125 .24603 0 4.5 ]
[-0.0125 .3254 -6 -4.5 ]
[-0.0125 .3254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21817 0 m
.21817 .00625 L
s
[(10)] .21817 -0.0125 0 1 Mshowa
.41254 0 m
.41254 .00625 L
s
[(20)] .41254 -0.0125 0 1 Mshowa
.6069 0 m
.6069 .00625 L
s
[(30)] .6069 -0.0125 0 1 Mshowa
.80126 0 m
.80126 .00625 L
s
[(40)] .80126 -0.0125 0 1 Mshowa
.99563 0 m
.99563 .00625 L
s
[(50)] .99563 -0.0125 0 1 Mshowa
.125 Mabswid
.06268 0 m
.06268 .00375 L
s
.10155 0 m
.10155 .00375 L
s
.14043 0 m
.14043 .00375 L
s
.1793 0 m
.1793 .00375 L
s
.25705 0 m
.25705 .00375 L
s
.29592 0 m
.29592 .00375 L
s
.33479 0 m
.33479 .00375 L
s
.37366 0 m
.37366 .00375 L
s
.45141 0 m
.45141 .00375 L
s
.49028 0 m
.49028 .00375 L
s
.52915 0 m
.52915 .00375 L
s
.56803 0 m
.56803 .00375 L
s
.64577 0 m
.64577 .00375 L
s
.68465 0 m
.68465 .00375 L
s
.72352 0 m
.72352 .00375 L
s
.76239 0 m
.76239 .00375 L
s
.84014 0 m
.84014 .00375 L
s
.87901 0 m
.87901 .00375 L
s
.91788 0 m
.91788 .00375 L
s
.95675 0 m
.95675 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(-1)] -0.0125 .00794 1 0 Mshowa
0 .0873 m
.00625 .0873 L
s
[(-0.5)] -0.0125 .0873 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(0)] -0.0125 .16667 1 0 Mshowa
0 .24603 m
.00625 .24603 L
s
[(0.5)] -0.0125 .24603 1 0 Mshowa
0 .3254 m
.00625 .3254 L
s
[(1)] -0.0125 .3254 1 0 Mshowa
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .07143 m
.00375 .07143 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .13492 m
.00375 .13492 L
s
0 .15079 m
.00375 .15079 L
s
0 .18254 m
.00375 .18254 L
s
0 .19841 m
.00375 .19841 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .2619 m
.00375 .2619 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21817 .32708 m
.21817 .33333 L
s
.41254 .32708 m
.41254 .33333 L
s
.6069 .32708 m
.6069 .33333 L
s
.80126 .32708 m
.80126 .33333 L
s
.99563 .32708 m
.99563 .33333 L
s
.125 Mabswid
.06268 .32958 m
.06268 .33333 L
s
.10155 .32958 m
.10155 .33333 L
s
.14043 .32958 m
.14043 .33333 L
s
.1793 .32958 m
.1793 .33333 L
s
.25705 .32958 m
.25705 .33333 L
s
.29592 .32958 m
.29592 .33333 L
s
.33479 .32958 m
.33479 .33333 L
s
.37366 .32958 m
.37366 .33333 L
s
.45141 .32958 m
.45141 .33333 L
s
.49028 .32958 m
.49028 .33333 L
s
.52915 .32958 m
.52915 .33333 L
s
.56803 .32958 m
.56803 .33333 L
s
.64577 .32958 m
.64577 .33333 L
s
.68465 .32958 m
.68465 .33333 L
s
.72352 .32958 m
.72352 .33333 L
s
.76239 .32958 m
.76239 .33333 L
s
.84014 .32958 m
.84014 .33333 L
s
.87901 .32958 m
.87901 .33333 L
s
.91788 .32958 m
.91788 .33333 L
s
.95675 .32958 m
.95675 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .07143 m
1 .07143 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .13492 m
1 .13492 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .19841 m
1 .19841 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .16667 m
1 .16667 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .16667 m
.02381 .3254 L
s
.04325 .16667 m
.04325 .29508 L
s
.06268 .16667 m
.06268 .21572 L
s
.08212 .16667 m
.08212 .11762 L
s
.10155 .16667 m
.10155 .03825 L
s
.12099 .16667 m
.12099 .00794 L
s
.14043 .16667 m
.14043 .03825 L
s
.15986 .16667 m
.15986 .11762 L
s
.1793 .16667 m
.1793 .21572 L
s
.19874 .16667 m
.19874 .29508 L
s
.21817 .16667 m
.21817 .3254 L
s
.23761 .16667 m
.23761 .29508 L
s
.25705 .16667 m
.25705 .21572 L
s
.27648 .16667 m
.27648 .11762 L
s
.29592 .16667 m
.29592 .03825 L
s
.31535 .16667 m
.31535 .00794 L
s
.33479 .16667 m
.33479 .03825 L
s
.35423 .16667 m
.35423 .11762 L
s
.37366 .16667 m
.37366 .21572 L
s
.3931 .16667 m
.3931 .29508 L
s
.41254 .16667 m
.41254 .3254 L
s
.43197 .16667 m
.43197 .29508 L
s
.45141 .16667 m
.45141 .21572 L
s
.47085 .16667 m
.47085 .11762 L
s
.49028 .16667 m
.49028 .03825 L
s
.50972 .16667 m
.50972 .00794 L
s
.52915 .16667 m
.52915 .03825 L
s
.54859 .16667 m
.54859 .11762 L
s
.56803 .16667 m
.56803 .21572 L
s
.58746 .16667 m
.58746 .29508 L
s
.6069 .16667 m
.6069 .3254 L
s
.62634 .16667 m
.62634 .29508 L
s
.64577 .16667 m
.64577 .21572 L
s
.66521 .16667 m
.66521 .11762 L
s
.68465 .16667 m
.68465 .03825 L
s
.70408 .16667 m
.70408 .00794 L
s
.72352 .16667 m
.72352 .03825 L
s
.74295 .16667 m
.74295 .11762 L
s
.76239 .16667 m
.76239 .21572 L
s
.78183 .16667 m
.78183 .29508 L
s
.80126 .16667 m
.80126 .3254 L
s
.8207 .16667 m
.8207 .29508 L
s
.84014 .16667 m
.84014 .21572 L
s
.85957 .16667 m
.85957 .11762 L
s
.87901 .16667 m
.87901 .03825 L
s
.89845 .16667 m
.89845 .00794 L
s
.91788 .16667 m
.91788 .03825 L
s
.93732 .16667 m
.93732 .11762 L
s
.95675 .16667 m
.95675 .21572 L
s
.97619 .16667 m
.97619 .29508 L
s
.005 w
.02381 .3254 Mdot
.04325 .29508 Mdot
.06268 .21572 Mdot
.08212 .11762 Mdot
.10155 .03825 Mdot
.12099 .00794 Mdot
.14043 .03825 Mdot
.15986 .11762 Mdot
.1793 .21572 Mdot
.19874 .29508 Mdot
.21817 .3254 Mdot
.23761 .29508 Mdot
.25705 .21572 Mdot
.27648 .11762 Mdot
.29592 .03825 Mdot
.31535 .00794 Mdot
.33479 .03825 Mdot
.35423 .11762 Mdot
.37366 .21572 Mdot
.3931 .29508 Mdot
.41254 .3254 Mdot
.43197 .29508 Mdot
.45141 .21572 Mdot
.47085 .11762 Mdot
.49028 .03825 Mdot
.50972 .00794 Mdot
.52915 .03825 Mdot
.54859 .11762 Mdot
.56803 .21572 Mdot
.58746 .29508 Mdot
.6069 .3254 Mdot
.62634 .29508 Mdot
.64577 .21572 Mdot
.66521 .11762 Mdot
.68465 .03825 Mdot
.70408 .00794 Mdot
.72352 .03825 Mdot
.74295 .11762 Mdot
.76239 .21572 Mdot
.78183 .29508 Mdot
.80126 .3254 Mdot
.8207 .29508 Mdot
.84014 .21572 Mdot
.85957 .11762 Mdot
.87901 .03825 Mdot
.89845 .00794 Mdot
.91788 .03825 Mdot
.93732 .11762 Mdot
.95675 .21572 Mdot
.97619 .29508 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00;oooool2o`0005;ooooo0ol00004ooooo`;o0000C_ooool5o`0000?ooooo0_l0001?oooo
o`?o00001?ooool2o`00057ooooo0ol00003ooooo`;o0000Coooool3o`0000Cooooo0_l0000;oooo
o`00;_ooool01?l0003oooooooooool0001Booooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo0000C_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004gooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00057ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo04_ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000[ooooo000^ooooo`04o`000?ooooooooooo`0005;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0001?ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo0000DOooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo04cooooo1Ol00002ooooo`04o`000?ooooooooooo`00057ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`08ooooo`00;_ooool01?l0003oooooooooool0001Booooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo0000D?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool0COooool2o`0000?ooooo00Co0000oooooooooooo0000C_ooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00057ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`08ooooo`00;_ooool01?l0003oooooooooool0001Booooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000COooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo0000DOooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooool000000oooool01?l0003oooooooooool0001=ooooo`Co
00000oooool01?l0003oooooooooool0000:ooooo`00;_ooool01?l0003oooooooooool0001Aoooo
o`;o00001?ooool01?l0003oooooooooool0001=ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool0001=ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0001@ooooo`;o00000oooool01?l0003oooooooooool0001=ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00002_ooool002oooooo0_l0001Cooooo`03o`000?oooooo
oooo00?ooooo0_l0001?ooooo`?o00001?ooool2o`0004oooooo0ol00004ooooo`;o0000D_ooool0
0ol0003oooooooooo`02ooooo`;o0000C_ooool5o`0000?ooooo0_l0000;ooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00oooooooiooooo`009Oooooooo`000<So00003?ooool001[ooooo0ol00008ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooo`00000<ooooo`006oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooo`00000<ooooo`004oooool5o`0000?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02Sooooo0_l00?l[ooooo`03o`000?oooooooooo
02Sooooo0_l00?l[ooooo`03o`000?oooooooooo02Wooooo0_l00?lZooooo`03o`000?oooooooooo
02Wooooo0_l00?l[ooooo`03o`000?oooooooooo02Sooooo0_l00?l[ooooo`03o`000?oooooo0000
00cooooo000Kooooo`03o`000?oooooooooo00Oooooo1?l0000booooo`;o003oE_ooool2o`00oeOo
oooo0_l00?mFooooo`;o003oE_ooool2o`00ob[ooooo1?l0000<ooooo`006oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03Cooooo00?o003oooooooooool0EOooool00ol00?oooooo
ooooo`1Eooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0EOooool00ol00?oooooo
ooooo`0[ooooo`03o`000?oooooooooo00[ooooo000Jooooo`;o00002Oooool00ol0003ooooooooo
o`0dooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0EOooool00ol00?oooooooooo
o`1Fooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0:oooool00ol0003ooooooooo
o`0:ooooo`006oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo00?o003o
ooooooooool0EOooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Kooooo00?o003o
ooooooooool0EOooool00ol00?ooooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo000Uoooo
o`03o`000?oooooooooo03Cooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1Eoooo
o`03o`00oooooooooooo05Kooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`0[oooo
o`03o`000?oooooooooo00[ooooo000Uooooo`03o`000?oooooooooo03Cooooo00?o003ooooooooo
ool0EOooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Kooooo00?o003ooooooooo
ool0EOooool00ol00?ooooooooooo`0[ooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`00
0?oooooooooo03Cooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1Eooooo`03o`00
oooooooooooo05Kooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`0[ooooo`03o`00
0?oooooooooo00[ooooo000Uooooo`;o0000=Oooool00ol00?ooooooooooo`1Eooooo`03o`00oooo
oooooooo05Gooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Eooooo`03o`00oooo
oooooooo02Wooooo0ol0000<ooooo`009Oooool00ol0003oooooooooo`0dooooo`03o`00oooooooo
oooo05Gooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooo
oooo05Gooooo00?o003oooooooooool0:oooool00ol0003oooooooooo`0:ooooo`009Oooool00ol0
003oooooooooo`0dooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0EOooool00ol0
0?ooooooooooo`1Fooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0:oooool00ol0
003oooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo05Go
oooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Go
oooo00?o003oooooooooool0:oooool00ol0003oooooooooo`0:ooooo`009Oooool00ol0003ooooo
ooooo`0dooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0EOooool00ol00?oooooo
ooooo`1Fooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0:oooool00ol0003ooooo
ooooo`0:ooooo`009Oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo05Gooooo00?o
003oooooooooool0EOooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Gooooo00?o
003oooooooooool0:oooool00ol0003oooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`0Z
ooooo`;o003o2?ooool00ol00?ooooooooooo`05ooooo`;o003oAOooool2o`00o`Oooooo00?o003o
ooooooooool01Oooool2o`00odGooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo0_l00?m5
ooooo`;o003o2?ooool00ol00?ooooooooooo`05ooooo`;o003oA?ooool2o`00o`Sooooo00?o003o
ooooooooool01Oooool2o`00obCooooo00?o0000ooooooooool02_ooool002Gooooo0_l0000[oooo
o`;o003o2?ooool00ol00?ooooooooooo`05ooooo`;o003oAOooool2o`00o`Oooooo00?o003ooooo
ooooool01Oooool2o`00odGooooo0_l00?l7ooooo`03o`00oooooooooooo00Gooooo0_l00?m5oooo
o`;o003o2?ooool00ol00?ooooooooooo`05ooooo`;o003oA?ooool2o`00o`Sooooo00?o003ooooo
ooooool01Oooool2o`00ob;ooooo0ol0000<ooooo`009Oooool00ol0003oooooooooo`0[ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Rooooo`03
o`000?oooooooooo00[ooooo000Uooooo`03o`000?oooooooooo02_ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02;ooooo00?o0000ooooooooool0
2_ooool002Gooooo00?o0000ooooooooool0:oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool08_ooool00ol0003oooooooooo`0:ooooo`009Oooool0
0ol0003oooooooooo`0[ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`000?oooooooooo
02_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
04?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
02;ooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool0:oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08_ooool00ol0003o
ooooooooo`0:ooooo`009Oooool2o`0002cooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo023ooooo0ol0000<ooooo`009Oooool00ol0003ooooooooo
o`0[ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`13ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0Rooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`000?oooooooooo02_ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02;ooooo00?o0000
ooooooooool02_ooool002Gooooo00?o0000ooooooooool0:oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool08_ooool00ol0003oooooooooo`0:oooo
o`009Oooool00ol0003oooooooooo`0[ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`00
0?oooooooooo02_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo04?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo02;ooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool0:ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08_oo
ool00ol0003oooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`0[ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Rooooo`03o`000?oooooo
oooo00[ooooo000Uooooo`;o0000;?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool08?ooool3o`0000cooooo000Uooooo`03o`000?oooooooooo02_o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Co
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Co
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Co
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02;o
oooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool0:oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08_ooool00ol0003ooooo
ooooo`0:ooooo`009Oooool00ol0003oooooooooo`0[ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000?
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00002?ooool00ol0003oooooooooo`0[
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0R
ooooo`03o`000?oooooooooo00[ooooo000>ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo02_ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02;ooooo00?o0000ooooooooool02_oo
ool000Oooooo1Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0[ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000>ooooo`04o`000?oooooo
ooooo`0000_ooooo00?o0000ooooooooool01Oooool4o`0002[ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01oooooo1?l0000<ooooo`003_ooool0
1?l0003oooooooooool00007ooooo`Co00002?ooool00ol0003oooooooooo`0[ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Rooooo`03o`000?oo
oooooooo00[ooooo000>ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0[ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000?ooooo`;o00002?ooool5
o`0000Oooooo00?o0000ooooooooool0:oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool08_ooool00ol0003oooooooooo`0:ooooo`009Oooool00ol0
003oooooooooo`0[ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`13ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`000?oooooooooo02_o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Co
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Co
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Co
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02;o
oooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool0:oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08_ooool00ol0003ooooo
ooooo`0:ooooo`009Oooool2o`0002cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo023ooooo0ol0000<ooooo`009Oooool00ol0003oooooooooo`0[
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0R
ooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`000?oooooooooo02_ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02;ooooo00?o0000oooo
ooooool02_ooool002Gooooo00?o0000ooooooooool0:oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool08_ooool00ol0003oooooooooo`0:ooooo`00
9Oooool00ol0003oooooooooo`0[ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`000?oo
oooooooo02_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo04?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo02;ooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool08Oooool2
o`00o`Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo0_l00?lcooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool2o`00oc?ooooo0_l00?l7ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o<oooool2
o`00o`Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo0_l00?lcooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool2o`00oa_ooooo00?o0000ooooooooool02_ooool0
02Gooooo0_l0000Rooooo`;o003o2?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01_ooool2o`00oc?ooooo0_l00?l7ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o<oooool2o`00
o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo0_l00?lcooooo`;o003o2?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01_ooool2o`00oc?ooooo0_l00?l7ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o6Oooool3o`00
00cooooo000Uooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool06_ooool00ol0003o
ooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01[ooooo
00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool08_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0booooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0Jooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`000?oooooooooo02;ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool0<_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`0Roooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo03;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0boooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo01[ooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000oooooooo
ool08_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo000Uooooo`;o0000
8oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Hooooo`?o00003?ooool002Gooooo00?o0000ooooooooool08_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`000?oooooo
oooo02;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0:ooooo`009Oooool00ol0
003oooooooooo`0Rooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool02_ooool002Go
oooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo00[o
oooo000Uooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool06_ooool00ol0003ooooo
ooooo`0:ooooo`009Oooool00ol0003oooooooooo`0Rooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01[ooooo00?o
0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0b
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0J
ooooo`03o`000?oooooooooo00[ooooo000Uooooo`;o00008oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0boooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Hoooo
o`?o00003?ooool002Gooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Jooooo`03
o`000?oooooooooo00[ooooo000Uooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
<_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
6_ooool00ol0003oooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`0Rooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo03;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01[ooooo00?o0000ooooooooool02_ooool001_ooooo0_l00008ooooo`03o`000?oooooo
oooo02;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0:ooooo`006_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo02;ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool06_ooool0
0ol0003oooooooooo`0:ooooo`006_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo02;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool06_ooool00ol0003oooooooooo`0:ooooo`006_ooool01?l0
003oooooooooool00007ooooo`_o000000?o003oo`000?l000001Ol000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Go000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Go000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Go000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Go000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Go000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Go000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Go000000?o003oo`000?l000001_l000000ol00?oo0000o`000006
o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000o`000005
o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000o`000009
o`0000cooooo000Jooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000Jooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo000Kooooo`;o00002?ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Sooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool02?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool02?ooool00ol0003oooooooooo`0:ooooo`009Oooool00ol0003ooooooooo
o`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0<_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0<_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02_ooool002Gooooo0_l00009
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0b
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0b
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo0ol0000<ooooo`009Oooool00ol0003oooooooooo`08oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0boooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0boooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03;ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03;ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0booooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0booooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0:ooooo`009Ooo
ool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0<_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0<_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02_oo
ool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol0
003oooooooooo`0:ooooo`009Oooool2o`0000Wooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool3o`0000co
oooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`0:ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0b
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03;ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool02?ooool00ol0003oooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`08ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0booooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Sooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool0
2?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`000?oo
oooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0booooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0booooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0:ooooo`009Oooool2
o`0000Wooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`;o003o<oooool2
o`00o`Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo0_l00?lcooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool2o`00oc?ooooo0_l00?l8ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o<oooool2
o`00o`Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo0_l00?lcooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`?o00003?ooool0
02Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Kooooo0_l00?lcooooo`;o003o1oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01Oooool2o`00oc?ooooo0_l00?l7ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`;o003o<oooool2o`00
o`Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo0_l00?lcooooo`;o003o2?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01Oooool2o`00oc?ooooo0_l00?l7ooooo`03o`00oooooooooooo
00Sooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool02?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0@oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0A?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0@oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00[ooooo
000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`13ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`14ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`13ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000
ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`08oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo000Uooooo`;o00002Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo04?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo04Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo04?ooooo00?o003oooooooooool01_ooool3o`0000cooooo000Uooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00
oooooooooooo00Sooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool02?oo
ool00ol0003oooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo000?ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00002?ooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@oooool00ol0
0?ooooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000>ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Sooooo00?o0000
ooooooooool02_ooool000kooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13
ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02_ooool000kooooo00Co0000oooo
oooooooo00002oooool00ol0003oooooooooo`05ooooo`Co00001oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool01Oooool4o`0000cooooo000>oooo
o`04o`000?ooooooooooo`0000Oooooo1?l00008ooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Sooooo00?o0000
ooooooooool02_ooool000kooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13
ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02_ooool000oooooo0_l00008oooo
o`Go00001oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool0@oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool0A?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool0@oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000Uooooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03
o`00oooooooooooo00Sooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool0
2?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool0
2?ooool00ol0003oooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`08ooooo`03o`000?oo
oooooooo00[ooooo000Uooooo`;o00002Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo04?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo04Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo04?ooooo00?o003oooooooooool01_ooool3o`0000cooooo000Uooooo`03o`000?oooooooooo
00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo
00Sooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool02?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0@oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0A?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0@oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00[ooooo
000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`13ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`14ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`13ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000
ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`08oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo000Uooooo`;o00002Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo04?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo04Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo04?ooooo00?o003oooooooooool01_ooool3o`0000cooooo000Uooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00
oooooooooooo00Sooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool02?oo
ool00ol0003oooooooooo`0:ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`13ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`14ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`13ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02_ooool002Go
oooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04Co
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Co
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04?o
oooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0:ooooo`009Oooool00ol0003ooooo
ooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@oooool00ol00?oooooo
ooooo`08ooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool02_ooool002Gooooo0_l00009ooooo`03o`00oooooooooooo00Gooooo0_l00?m4
ooooo`;o003o2?ooool00ol00?ooooooooooo`05ooooo`;o003oAOooool2o`00o`Oooooo00?o003o
ooooooooool01Oooool2o`00odGooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo0_l00?m4
ooooo`;o003o2?ooool00ol00?ooooooooooo`05ooooo`;o003oAOooool2o`00o`Oooooo0ol0000<
ooooo`009Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Gooooo0_l00?m4oooo
o`;o003o2?ooool00ol00?ooooooooooo`05ooooo`;o003oAOooool2o`00o`Oooooo00?o003ooooo
ooooool01Oooool2o`00odGooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo0_l00?m4oooo
o`;o003o2?ooool00ol00?ooooooooooo`05ooooo`;o003oAOooool2o`00o`Wooooo00?o0000oooo
ooooool02_ooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`1Eooooo`03
o`00oooooooooooo05Gooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1Fooooo`03
o`00oooooooooooo05Oooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool0
2?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0
EOooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Oooooo00?o0000ooooooooool0
2_ooool002Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooo
oooooooo05Gooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1Fooooo`03o`00oooo
oooooooo05Oooooo00?o0000ooooooooool02_ooool002Gooooo00?o0000ooooooooool02?ooool0
0ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0EOooool0
0ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Oooooo00?o0000ooooooooool02_ooool0
02Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo
05Gooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo
05Oooooo00?o0000ooooooooool02_ooool002Gooooo0_l00009ooooo`03o`00oooooooooooo05Go
oooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Ko
oooo00?o003oooooooooool0EOooool3o`0000cooooo000Uooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool0EOooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Gooooo
00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Gooooo`03o`000?oooooooooo00[ooooo
000Uooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0EOooool00ol00?oooooooooo
o`1Eooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0E_ooool00ol00?oooooooooo
o`1Gooooo`03o`000?oooooooooo00[ooooo000Uooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooooooool0EOooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Gooooo00?o003o
ooooooooool0E_ooool00ol00?ooooooooooo`1Gooooo`03o`000?oooooooooo00[ooooo000Joooo
o`?o00002?ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo05Gooooo00?o003ooooo
ooooool0EOooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Kooooo00?o003ooooo
ooooool0Eoooool00ol0003oooooooooo`0:ooooo`006oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1Eooooo`03
o`00oooooooooooo05Gooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Gooooo`03
o`000?oooooooooo00[ooooo000Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0
EOooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Oooooo00?o0000ooooooooool0
2_ooool001_ooooo00?o0000ooooooooool01oooool4o`0000Kooooo0_l00?mFooooo`;o003oE_oo
ool2o`00oeOooooo0_l00?mFooooo`;o003oE_ooool4o`0000cooooo000Kooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool2o`00oeKooooo0_l00?mFooooo`;o003oEoooool2
o`00oeKooooo0_l00?mGooooo`03o`000?oooooo000000cooooo000Jooooo`;o00002Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool000003?ooool001_o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooool000003?ooool002Goooooool00038o`0000cooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-5.43775, -1.25358, 0.113258, \
0.0138684}}]
}, Closed]],

Cell[CellGroupData[{

Cell["DTFT", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X\[Theta]\  = DTFT[xd, \[Theta]];\)\), "\[IndentingNewLine]", 
    \(X\[Theta]\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1 + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\) \
+ 1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-2\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-3\)\ \[ImaginaryI]\ \[Theta]\
\) + 1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-4\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-5\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-6\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-7\)\ \[ImaginaryI]\ \[Theta]\
\) + 1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-8\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-9\)\ \[ImaginaryI]\ \[Theta]\
\) + \[ExponentialE]\^\(\(-10\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-11\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-12\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-13\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-14\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-15\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-16\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-17\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-18\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-19\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-20\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-21\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-22\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-23\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-24\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-25\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-26\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-27\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-28\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-29\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-30\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-31\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-32\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-33\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-34\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-35\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-36\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-37\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-38\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-39\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-40\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-41\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-42\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-43\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-44\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-45\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-46\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-47\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-48\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-49\)\ \[ImaginaryI]\ \
\[Theta]\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X\[Theta]\  = \ 
        X\[Theta]\  // \ Simplify;\)\), "\[IndentingNewLine]", 
    \(X\[Theta]\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\/4\ \[ExponentialE]\^\(\(-49\)\ \[ImaginaryI]\ \
\[Theta]\)\ \((\(-1\) - \@5 + 
          2\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) + \((\(-3\) + \
\@5)\)\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \[Theta]\) + 
          4\ \[ExponentialE]\^\(3\ \[ImaginaryI]\ \[Theta]\))\)\ \((\(-1\) - \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(5\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(6\ \[ImaginaryI]\ \[Theta]\) - \
\[ExponentialE]\^\(10\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(11\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(15\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(16\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(20\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(21\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(25\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(26\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(30\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(31\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(35\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(36\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(40\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(41\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(45\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(46\ \[ImaginaryI]\ \[Theta]\))\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plots of DTFT", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g1 = 
        Plot[Abs[X\[Theta]], {\[Theta], \(-\[Pi]\), \[Pi]}, \ 
          PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[Arg[X\[Theta]], {\[Theta], \(-\[Pi]\), \[Pi]}, \ 
          PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.0147151 0.0235176 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1323 -6 -4.5 ]
[-0.0125 .1323 0 4.5 ]
[-0.0125 .24989 -12 -4.5 ]
[-0.0125 .24989 0 4.5 ]
[-0.0125 .36748 -12 -4.5 ]
[-0.0125 .36748 0 4.5 ]
[-0.0125 .48507 -12 -4.5 ]
[-0.0125 .48507 0 4.5 ]
[-0.0125 .60265 -12 -4.5 ]
[-0.0125 .60265 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1323 m
.00625 .1323 L
s
[(5)] -0.0125 .1323 1 0 Mshowa
0 .24989 m
.00625 .24989 L
s
[(10)] -0.0125 .24989 1 0 Mshowa
0 .36748 m
.00625 .36748 L
s
[(15)] -0.0125 .36748 1 0 Mshowa
0 .48507 m
.00625 .48507 L
s
[(20)] -0.0125 .48507 1 0 Mshowa
0 .60265 m
.00625 .60265 L
s
[(25)] -0.0125 .60265 1 0 Mshowa
.125 Mabswid
0 .03823 m
.00375 .03823 L
s
0 .06175 m
.00375 .06175 L
s
0 .08527 m
.00375 .08527 L
s
0 .10879 m
.00375 .10879 L
s
0 .15582 m
.00375 .15582 L
s
0 .17934 m
.00375 .17934 L
s
0 .20286 m
.00375 .20286 L
s
0 .22637 m
.00375 .22637 L
s
0 .27341 m
.00375 .27341 L
s
0 .29693 m
.00375 .29693 L
s
0 .32044 m
.00375 .32044 L
s
0 .34396 m
.00375 .34396 L
s
0 .391 m
.00375 .391 L
s
0 .41451 m
.00375 .41451 L
s
0 .43803 m
.00375 .43803 L
s
0 .46155 m
.00375 .46155 L
s
0 .50858 m
.00375 .50858 L
s
0 .5321 m
.00375 .5321 L
s
0 .55562 m
.00375 .55562 L
s
0 .57914 m
.00375 .57914 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1323 m
1 .1323 L
s
.99375 .24989 m
1 .24989 L
s
.99375 .36748 m
1 .36748 L
s
.99375 .48507 m
1 .48507 L
s
.99375 .60265 m
1 .60265 L
s
.125 Mabswid
.99625 .03823 m
1 .03823 L
s
.99625 .06175 m
1 .06175 L
s
.99625 .08527 m
1 .08527 L
s
.99625 .10879 m
1 .10879 L
s
.99625 .15582 m
1 .15582 L
s
.99625 .17934 m
1 .17934 L
s
.99625 .20286 m
1 .20286 L
s
.99625 .22637 m
1 .22637 L
s
.99625 .27341 m
1 .27341 L
s
.99625 .29693 m
1 .29693 L
s
.99625 .32044 m
1 .32044 L
s
.99625 .34396 m
1 .34396 L
s
.99625 .391 m
1 .391 L
s
.99625 .41451 m
1 .41451 L
s
.99625 .43803 m
1 .43803 L
s
.99625 .46155 m
1 .46155 L
s
.99625 .50858 m
1 .50858 L
s
.99625 .5321 m
1 .5321 L
s
.99625 .55562 m
1 .55562 L
s
.99625 .57914 m
1 .57914 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02608 .02331 L
.02847 .03106 L
.02972 .03419 L
.03089 .03636 L
.03124 .03685 L
.03157 .03725 L
.03186 .03755 L
.03218 .03782 L
.03234 .03793 L
.03252 .03803 L
.03269 .03811 L
.03284 .03817 L
.03292 .03819 L
.03301 .03821 L
.03311 .03823 L
.03321 .03824 L
.03329 .03825 L
.03338 .03825 L
.03347 .03824 L
.03355 .03823 L
.0337 .03821 L
.03383 .03817 L
.03398 .03812 L
.03414 .03804 L
.03446 .03784 L
.03476 .0376 L
.03533 .03699 L
.03587 .03622 L
.03707 .03392 L
.03838 .03056 L
.04072 .02285 L
.04196 .01818 L
.0423 .01687 L
.04249 .01615 L
.04266 .01548 L
.04281 .0149 L
.04297 .01514 L
.04306 .01549 L
.04314 .01582 L
.0433 .01644 L
.04574 .02553 L
.04804 .03252 L
.04921 .03518 L
.04985 .03631 L
.05045 .03716 L
.05096 .0377 L
.05125 .03794 L
.05151 .03811 L
.05165 .03818 L
Mistroke
.0518 .03825 L
.05188 .03828 L
.05196 .0383 L
.05211 .03833 L
.05225 .03835 L
.0524 .03836 L
.05254 .03835 L
.05268 .03834 L
.05283 .0383 L
.05297 .03825 L
.05324 .03813 L
.05354 .03794 L
.05385 .03768 L
.05442 .03705 L
.05495 .03629 L
.05616 .03394 L
.05744 .03062 L
.05982 .0227 L
.06087 .01876 L
.06142 .01662 L
.06157 .01601 L
.06172 .01542 L
.06186 .0149 L
.062 .0151 L
.06215 .01569 L
.06231 .01631 L
.06259 .01741 L
.06314 .01954 L
.06434 .02402 L
.06556 .02819 L
.06686 .03208 L
.0681 .03503 L
.06922 .037 L
.06977 .03768 L
.07005 .03796 L
.07036 .03821 L
.07062 .03837 L
.07077 .03844 L
.07092 .0385 L
.07106 .03854 L
.07118 .03857 L
.07131 .03859 L
.07143 .03859 L
.07158 .03859 L
.07167 .03858 L
.07174 .03856 L
.07189 .03853 L
.07204 .03848 L
.0723 .03836 L
.07258 .03818 L
Mistroke
.07289 .03792 L
.07322 .03759 L
.07381 .03681 L
.07497 .03468 L
.07603 .0321 L
.07832 .02481 L
.07963 .01991 L
.08025 .0175 L
.08052 .01643 L
.08067 .01582 L
.08082 .01525 L
.08096 .01473 L
.0811 .01531 L
.08141 .01651 L
.08204 .01901 L
.08319 .02341 L
.08572 .0318 L
.08695 .0349 L
.0876 .03621 L
.08829 .03734 L
.08889 .03808 L
.08923 .03841 L
.08955 .03864 L
.08969 .03873 L
.08984 .0388 L
.08997 .03885 L
.09011 .03889 L
.09026 .03893 L
.0904 .03894 L
.09048 .03895 L
.09056 .03895 L
.09071 .03893 L
.09085 .03891 L
.091 .03887 L
.09114 .03882 L
.09127 .03876 L
.09159 .03857 L
.09189 .03833 L
.09248 .03768 L
.09313 .03672 L
.09428 .03439 L
.09535 .0316 L
.09763 .02402 L
.09882 .01943 L
.09947 .01683 L
.09964 .01617 L
.09979 .01555 L
.09993 .01499 L
.10008 .01505 L
.10016 .01536 L
Mistroke
.10024 .0157 L
.10039 .0163 L
.10073 .01764 L
.10143 .02045 L
.10267 .02518 L
.10384 .02926 L
.10511 .03306 L
.10634 .03602 L
.10692 .03712 L
.10746 .03796 L
.108 .03862 L
.10829 .03889 L
.10859 .03912 L
.10873 .0392 L
.10888 .03928 L
.10902 .03934 L
.10916 .03938 L
.10928 .03941 L
.10942 .03943 L
.10955 .03944 L
.10967 .03943 L
.10982 .03942 L
.1099 .0394 L
.10998 .03938 L
.11013 .03933 L
.11027 .03927 L
.11059 .03909 L
.11093 .03882 L
.11155 .03813 L
.11212 .03727 L
.11321 .0351 L
.11436 .03209 L
.11677 .02389 L
.11781 .01976 L
.11837 .01751 L
.11867 .01627 L
.11882 .01566 L
.11895 .01511 L
.1191 .01492 L
.11925 .01557 L
.11959 .01693 L
.12017 .01932 L
.12132 .02389 L
.12263 .02871 L
.12384 .03262 L
.12505 .0358 L
.12614 .03797 L
.12676 .03889 L
.12735 .03952 L
.12767 .03976 L
Mistroke
.12797 .03993 L
.12812 .03999 L
.12821 .04002 L
.12829 .04004 L
.12838 .04006 L
.12847 .04007 L
.12856 .04007 L
.12864 .04008 L
.12877 .04007 L
.12892 .04005 L
.12906 .04001 L
.12919 .03997 L
.12933 .0399 L
.12949 .03982 L
.1298 .0396 L
.13011 .03932 L
.13045 .03894 L
.13104 .03809 L
.13221 .03577 L
.13326 .03298 L
.13558 .02504 L
.13678 .02025 L
.13741 .01761 L
.13776 .01614 L
.13793 .01541 L
.13809 .01473 L
.13824 .01534 L
.1384 .01602 L
.13874 .01745 L
.13933 .01994 L
.14049 .02467 L
.14171 .02927 L
.14303 .03359 L
.14425 .03682 L
.14479 .03797 L
.14538 .03901 L
.14593 .0398 L
.14645 .04034 L
.14673 .04056 L
.14699 .04072 L
.14714 .04078 L
.14729 .04083 L
.14744 .04086 L
.14758 .04088 L
.14773 .04089 L
.14787 .04087 L
.148 .04085 L
.14814 .04081 L
.14829 .04075 L
.14845 .04068 L
Mistroke
.14874 .04049 L
.14904 .04023 L
.14932 .03994 L
.14984 .03925 L
.15046 .03819 L
.15103 .03698 L
.15233 .03355 L
.1546 .02553 L
.1559 .02013 L
.15652 .01746 L
.15679 .01627 L
.15694 .01559 L
.15709 .01495 L
.15722 .01507 L
.15737 .01571 L
.15767 .01702 L
.1583 .01977 L
.15944 .02462 L
.16065 .02937 L
.16196 .03393 L
.16313 .03724 L
.16378 .03871 L
.16438 .03986 L
.16471 .04039 L
.16507 .04087 L
.16537 .0412 L
.1657 .04149 L
.16601 .0417 L
.16618 .04178 L
.16634 .04183 L
.16649 .04187 L
.16662 .04189 L
.16678 .04189 L
.16693 .04188 L
.16708 .04185 L
.16716 .04183 L
.16724 .0418 L
.16738 .04175 L
.16754 .04166 L
.1678 .04148 L
.16809 .04123 L
.16873 .04046 L
.16932 .03947 L
.17039 .0371 L
.17154 .03378 L
.17394 .02475 L
.1752 .01923 L
.17583 .01635 L
.17601 .01555 L
.1761 .01511 L
Mistroke
.1762 .01474 L
.17628 .01513 L
.17637 .01555 L
.17654 .0163 L
.17904 .02737 L
.18135 .03585 L
.18259 .03926 L
.18318 .04052 L
.18372 .04148 L
.18434 .04232 L
.18467 .04265 L
.18484 .04278 L
.18502 .0429 L
.18518 .04299 L
.18532 .04305 L
.18547 .0431 L
.18561 .04313 L
.18568 .04314 L
.18577 .04314 L
.18591 .04314 L
.18607 .04312 L
.18616 .0431 L
.18625 .04307 L
.18639 .04301 L
.18654 .04294 L
.18681 .04275 L
.18714 .04246 L
.18743 .04213 L
.18807 .04118 L
.18868 .04 L
.18975 .03731 L
.19091 .03358 L
.19326 .02402 L
.1939 .02107 L
.19459 .01781 L
.19493 .01621 L
.19509 .01541 L
.19525 .01475 L
.19538 .01542 L
.19553 .01612 L
.19584 .01762 L
.19812 .02819 L
.20059 .03759 L
.20125 .03953 L
.20194 .04127 L
.20258 .04258 L
.20318 .04353 L
.20346 .04389 L
.20374 .04417 L
.20389 .04429 L
Mistroke
.20405 .04441 L
.2042 .0445 L
.20434 .04457 L
.20449 .04463 L
.20457 .04465 L
.20466 .04467 L
.20474 .04468 L
.20484 .04469 L
.20491 .04469 L
.205 .04468 L
.20515 .04466 L
.20524 .04463 L
.20532 .04461 L
.20547 .04454 L
.20561 .04447 L
.2059 .04426 L
.20617 .044 L
.20678 .04321 L
.20738 .04214 L
.20803 .0407 L
.20919 .03735 L
.21025 .03353 L
.21146 .02847 L
.21274 .02245 L
.21337 .01936 L
.21367 .01782 L
.21395 .0164 L
.21409 .01572 L
.21421 .01509 L
.21434 .01499 L
.21448 .01571 L
.21505 .01861 L
.21742 .03015 L
.21967 .03909 L
.22085 .04258 L
.22151 .04411 L
.22213 .04521 L
.22265 .04589 L
.22294 .04618 L
.22322 .04638 L
.22336 .04647 L
.22351 .04653 L
.22363 .04657 L
.22377 .0466 L
.22392 .04661 L
.22401 .04661 L
.22408 .0466 L
.22423 .04657 L
.22437 .04653 L
.22451 .04647 L
Mistroke
.22466 .04639 L
.22493 .04619 L
.22525 .04586 L
.22555 .04549 L
.22618 .04444 L
.22679 .04313 L
.22786 .04012 L
.22902 .03594 L
.23136 .02522 L
.232 .02191 L
.23269 .01823 L
.233 .01651 L
.23318 .01557 L
.23326 .01511 L
.23334 .01474 L
.23348 .01549 L
.23362 .0163 L
.23394 .018 L
.2364 .0309 L
.23867 .04071 L
.23979 .04436 L
.24037 .04585 L
.24098 .04714 L
.24131 .04769 L
.2416 .04811 L
.2419 .04846 L
.24218 .04871 L
.24233 .04882 L
.2425 .04891 L
.2426 .04895 L
.24269 .04898 L
.24277 .049 L
.24285 .04902 L
.24293 .04903 L
.24301 .04903 L
.2431 .04902 L
.24319 .04901 L
.24333 .04898 L
.24349 .04892 L
.24364 .04884 L
.2438 .04874 L
.24413 .04844 L
.24444 .04808 L
.24472 .04766 L
.24537 .04646 L
.24606 .04475 L
.24733 .0406 L
.24849 .03577 L
.24969 .0299 L
.25097 .02293 L
Mistroke
.25159 .01936 L
.25189 .01758 L
.25203 .0168 L
.25217 .01593 L
.25231 .01515 L
.25243 .015 L
.25256 .01577 L
.2527 .0166 L
.25327 .01996 L
.25547 .03242 L
.25787 .04357 L
.25852 .0459 L
.2592 .04801 L
.25983 .04959 L
.26043 .05075 L
.2607 .05116 L
.26098 .05151 L
.26113 .05166 L
.2613 .05181 L
.26144 .05191 L
.26158 .05199 L
.26166 .05203 L
.26175 .05207 L
.2619 .05211 L
.26199 .05212 L
.26208 .05212 L
.26216 .05212 L
.26224 .05211 L
.26239 .05207 L
.26248 .05204 L
.26256 .05201 L
.26271 .05192 L
.26286 .05182 L
.26317 .05153 L
.26346 .05116 L
.26401 .05024 L
.26461 .04892 L
.26525 .04711 L
.2664 .04292 L
.26746 .03811 L
.26865 .03181 L
.26993 .02426 L
.27055 .02038 L
.27085 .01844 L
.27113 .01664 L
.27126 .01579 L
.27139 .01499 L
.27151 .01528 L
.27166 .0162 L
.27223 .0199 L
Mistroke
.27446 .03386 L
.27681 .04609 L
.27797 .05063 L
.27859 .05252 L
.27924 .05413 L
.27956 .05474 L
.27985 .05522 L
.28014 .05559 L
.2804 .05586 L
.28065 .05604 L
.28078 .0561 L
.28092 .05615 L
.28106 .05618 L
.28121 .05619 L
.28135 .05617 L
.28148 .05613 L
.28163 .05607 L
.28178 .05598 L
.28205 .05575 L
.28235 .0554 L
.28267 .05492 L
.28324 .05377 L
.28377 .05239 L
.28499 .04811 L
.28627 .04207 L
.28868 .02743 L
.28972 .02013 L
.29001 .01808 L
.29017 .01694 L
.29032 .01588 L
.29044 .01497 L
.29058 .01544 L
.29073 .01652 L
.29086 .01752 L
.29207 .02629 L
.29322 .0343 L
.29453 .04272 L
.29575 .04952 L
.29695 .05496 L
.29803 .05861 L
.29833 .05938 L
.29866 .06009 L
.29894 .0606 L
.29924 .06106 L
.29957 .06142 L
.29975 .06155 L
.29983 .06161 L
.29991 .06165 L
.30007 .0617 L
.30021 .06172 L
Mistroke
.30037 .06172 L
.30045 .0617 L
.30053 .06168 L
.30067 .06162 L
.30082 .06153 L
.30095 .06143 L
.30109 .06129 L
.3014 .0609 L
.30169 .06043 L
.30222 .05929 L
.30278 .0577 L
.30408 .05256 L
.30527 .04628 L
.30648 .03843 L
.30777 .0289 L
.30887 .02009 L
.30918 .01761 L
.30934 .01623 L
.3095 .01491 L
.30965 .01574 L
.30973 .01643 L
.30981 .01707 L
.31009 .01941 L
.31247 .03894 L
.31472 .05464 L
.31591 .0611 L
.31654 .06385 L
.3172 .0662 L
.31776 .06774 L
.31808 .06842 L
.31837 .06892 L
.31864 .06928 L
.31877 .06941 L
.31889 .06951 L
.31903 .06959 L
.31918 .06966 L
.31931 .06968 L
.31945 .06969 L
.31958 .06966 L
.31973 .0696 L
.31989 .0695 L
.32004 .06937 L
.3203 .06907 L
.32058 .06863 L
.32091 .06796 L
.32122 .06718 L
.3218 .06535 L
.32286 .06076 L
.324 .05409 L
.32636 .03577 L
Mistroke
.3276 .0242 L
.32796 .02072 L
.3283 .01737 L
.32845 .0159 L
.32861 .01509 L
.32869 .01591 L
.32878 .01682 L
.32894 .01842 L
.3314 .04269 L
.3337 .06247 L
.33491 .07071 L
.33603 .0765 L
.33661 .07877 L
.33725 .0806 L
.33757 .08126 L
.33775 .08155 L
.33792 .08176 L
.33808 .08192 L
.33816 .08198 L
.33825 .08204 L
.3384 .0821 L
.33854 .08212 L
.33869 .08211 L
.33885 .08205 L
.339 .08194 L
.33913 .08181 L
.3394 .08147 L
.33968 .08096 L
.34001 .08017 L
.34032 .07925 L
.3409 .07705 L
.34196 .07147 L
.3431 .0633 L
.34546 .04051 L
.34671 .02596 L
.34707 .02155 L
.34725 .01936 L
.34741 .01732 L
.34756 .01546 L
.34772 .01596 L
.34788 .01796 L
.34805 .02018 L
.35051 .05138 L
.35281 .07727 L
.35395 .08764 L
.35515 .09617 L
.35577 .09953 L
.3561 .10096 L
.35646 .10223 L
.35679 .10315 L
Mistroke
.35708 .10377 L
.35723 .104 L
.35738 .10419 L
.35753 .10431 L
.35766 .10439 L
.35781 .10441 L
.35796 .10439 L
.35809 .10432 L
.35823 .1042 L
.35838 .10402 L
.35854 .10376 L
.35883 .10314 L
.35913 .10228 L
.35941 .10128 L
.35993 .09889 L
.36055 .09514 L
.36112 .09086 L
.36241 .07837 L
.36361 .06362 L
.36488 .04486 L
.3655 .03484 L
.36609 .02491 L
.36634 .02046 L
.36648 .018 L
.36661 .01568 L
.36675 .01627 L
.36691 .01907 L
.36718 .02404 L
.37177 .10632 L
.37296 .12403 L
.37421 .13931 L
.37528 .149 L
.37557 .15104 L
.37588 .15291 L
.37615 .15425 L
.37644 .15544 L
.37659 .15593 L
.37676 .15636 L
.37685 .15656 L
.37693 .15672 L
.37701 .15685 L
.37709 .15695 L
.37723 .15707 L
.37739 .15712 L
.37753 .15708 L
.37768 .15696 L
.37784 .15673 L
.37793 .15656 L
.37801 .15637 L
.37832 .15543 L
Mistroke
.37848 .15477 L
.37866 .15393 L
.37902 .15183 L
.37963 .14706 L
.38028 .14023 L
.38145 .12336 L
.38385 .07086 L
.38451 .05248 L
.38521 .03127 L
.38549 .02205 L
.38557 .01934 L
.38565 .01675 L
.3858 .0176 L
.38588 .02043 L
.38596 .02308 L
.38614 .02916 L
.38645 .04031 L
.39127 .23682 L
.39599 .43382 L
.39724 .4779 L
.39858 .51948 L
.39974 .54944 L
.40035 .56284 L
.40101 .57517 L
.40166 .58525 L
.40226 .59253 L
.40254 .59538 L
.40285 .59798 L
.40315 .59996 L
.40342 .6014 L
.40358 .60206 L
.40372 .60253 L
.40389 .60293 L
.40397 .60309 L
.40406 .60321 L
.40414 .60328 L
.40423 .60332 L
.40438 .60328 L
.40448 .60319 L
.40457 .60307 L
.40465 .60292 L
.40474 .60271 L
.40489 .60228 L
.40505 .60167 L
.40538 .60002 L
.40568 .59798 L
.40596 .59564 L
.40656 .58929 L
.40722 .58029 L
.40841 .55857 L
Mistroke
.41065 .50103 L
.41302 .42059 L
.41556 .32136 L
.41797 .22237 L
.42058 .12051 L
.42181 .07695 L
.42248 .05478 L
.4231 .03528 L
.42338 .02709 L
.42364 .01956 L
.42378 .01549 L
.42394 .01829 L
.42408 .02216 L
.42421 .02569 L
.42542 .05553 L
.42651 .07787 L
.42768 .09706 L
.42835 .10577 L
.42896 .1123 L
.42958 .11749 L
.43017 .12118 L
.43048 .12266 L
.43077 .12375 L
.43104 .12449 L
.43119 .1248 L
.43132 .12503 L
.43147 .12521 L
.43161 .12531 L
.43176 .12536 L
.43184 .12536 L
.43192 .12533 L
.43208 .12523 L
.43216 .12514 L
.43225 .12503 L
.4324 .12479 L
.43255 .12447 L
.43282 .12377 L
.4331 .12281 L
.43361 .12053 L
.43421 .11697 L
.43477 .11296 L
.43705 .0904 L
.43955 .05857 L
.44077 .04211 L
.44191 .02679 L
.44255 .01859 L
.44272 .0164 L
.44281 .0153 L
.44291 .01533 L
.44299 .01635 L
Mistroke
.44308 .01743 L
.44324 .01938 L
.44444 .0332 L
.44566 .04546 L
.44699 .05638 L
.4476 .06045 L
.44825 .06411 L
.44882 .06674 L
.44942 .06892 L
.44973 .06981 L
.45006 .0706 L
.45037 .07116 L
.45066 .07153 L
.45074 .07162 L
.45083 .07169 L
.45091 .07175 L
.451 .0718 L
.45108 .07184 L
.45116 .07187 L
.45131 .07189 L
.4514 .07188 L
.45148 .07187 L
.45157 .07184 L
.45167 .0718 L
.45175 .07175 L
.45183 .07169 L
.452 .07153 L
.45232 .07112 L
.45262 .0706 L
.45318 .06928 L
.45378 .06739 L
.45444 .06482 L
.45684 .05162 L
.45938 .03354 L
.46052 .02495 L
.46115 .02026 L
.46146 .01798 L
.46159 .01698 L
.46174 .01589 L
.46188 .01489 L
.46201 .01547 L
.46215 .01644 L
.46229 .01749 L
.4629 .02163 L
.46395 .02841 L
.4652 .03546 L
.46636 .04088 L
.46758 .0452 L
.46822 .04691 L
.46855 .04764 L
Mistroke
.46891 .04829 L
.46921 .04875 L
.46955 .04915 L
.4697 .04929 L
.46985 .04942 L
.47 .04951 L
.47014 .04958 L
.47022 .04961 L
.47031 .04964 L
.47041 .04966 L
.4705 .04968 L
.47058 .04968 L
.47067 .04968 L
.47076 .04967 L
.47084 .04965 L
.47099 .04961 L
.47107 .04957 L
.47115 .04954 L
.47131 .04944 L
.47148 .04931 L
.47179 .04901 L
.47209 .04864 L
.47265 .04774 L
.4733 .04637 L
.47391 .04481 L
.47616 .03694 L
.47864 .02577 L
.47978 .0203 L
.4804 .01732 L
.4807 .01589 L
.48084 .01526 L
.48098 .01484 L
.48113 .01557 L
.48128 .01625 L
.48161 .01775 L
.48229 .02081 L
.48349 .02582 L
.48473 .03033 L
.48589 .03383 L
.4871 .03664 L
.48774 .03776 L
.48808 .03824 L
.48843 .03866 L
.48876 .03899 L
.48907 .03922 L
.48921 .03931 L
.48937 .03939 L
.48952 .03945 L
.48965 .03949 L
.48973 .03951 L
Mistroke
.48981 .03953 L
.48991 .03954 L
.48999 .03955 L
.49008 .03955 L
.49017 .03955 L
.49026 .03954 L
.49035 .03952 L
.49049 .03949 L
.49058 .03947 L
.49066 .03944 L
.49099 .03928 L
.4913 .03906 L
.4916 .0388 L
.49215 .03817 L
.49275 .03727 L
.49341 .03607 L
.49578 .02995 L
.49831 .0212 L
.49891 .01892 L
.49955 .01646 L
.49971 .01584 L
.49988 .01518 L
.49998 .01479 L
.50007 .01499 L
.50016 .01534 L
.50025 .01567 L
.50089 .01816 L
.50332 .02705 L
.50448 .03076 L
.50572 .03413 L
.50678 .03644 L
.50733 .03742 L
.50794 .03829 L
.50853 .03892 L
.50886 .03918 L
.50901 .03928 L
.50916 .03936 L
.50929 .03942 L
.50944 .03947 L
.50957 .03951 L
.5097 .03953 L
.50983 .03955 L
.50998 .03955 L
.51013 .03954 L
.51027 .03951 L
.51043 .03947 L
.5106 .0394 L
.51091 .03924 L
.51121 .03901 L
.51149 .03875 L
Mistroke
.51212 .03797 L
.51279 .03685 L
.51403 .03404 L
.51537 .02997 L
.51653 .02571 L
.51781 .02038 L
.51841 .01768 L
.51874 .01616 L
.5189 .0154 L
.51905 .01474 L
.51919 .0154 L
.51934 .01611 L
.51966 .01762 L
.52021 .02028 L
.52276 .03228 L
.52391 .03724 L
.52513 .04182 L
.52626 .04527 L
.52731 .04767 L
.52785 .04856 L
.52813 .04892 L
.52843 .04923 L
.5286 .04938 L
.52876 .04948 L
.52891 .04956 L
.52898 .0496 L
.52907 .04963 L
.52921 .04966 L
.52934 .04968 L
.5295 .04968 L
.52965 .04965 L
.5298 .0496 L
.52989 .04957 L
.52997 .04953 L
.53027 .04932 L
.53043 .04917 L
.53061 .04897 L
.53094 .04853 L
.53158 .04737 L
.53216 .04594 L
.53334 .04204 L
.53444 .03725 L
.53572 .03036 L
.53694 .02275 L
.53751 .01885 L
.53782 .01666 L
.53798 .01557 L
.53812 .01487 L
.53827 .01597 L
.53843 .01717 L
Mistroke
.53878 .01973 L
.5394 .02432 L
.54164 .04106 L
.54284 .04949 L
.54412 .05752 L
.54523 .06332 L
.54643 .0681 L
.54674 .06907 L
.54708 .06994 L
.54738 .07061 L
.54767 .07111 L
.54794 .07147 L
.54809 .07162 L
.54823 .07173 L
.54838 .07182 L
.54847 .07185 L
.54854 .07187 L
.54869 .07189 L
.54884 .07186 L
.54898 .07181 L
.5491 .07174 L
.54924 .07163 L
.54938 .07149 L
.54962 .07117 L
.54988 .07071 L
.55048 .06924 L
.55103 .06734 L
.55164 .06465 L
.5523 .06103 L
.5535 .05265 L
.55574 .03122 L
.55629 .02497 L
.5566 .02139 L
.55688 .01791 L
.55705 .01592 L
.55714 .01478 L
.55722 .01571 L
.55753 .01962 L
.55814 .02748 L
.56068 .06161 L
.56295 .09041 L
.56414 .10331 L
.5654 .11428 L
.56605 .1186 L
.56639 .1205 L
.56675 .1222 L
.56709 .12346 L
.56739 .12434 L
.56754 .12467 L
.5677 .12495 L
Mistroke
.56785 .12515 L
.56799 .12528 L
.56813 .12535 L
.56828 .12536 L
.56842 .1253 L
.56855 .12519 L
.5687 .12501 L
.56885 .12473 L
.56902 .12436 L
.56917 .12393 L
.56949 .1228 L
.56978 .12148 L
.57042 .11746 L
.57101 .11255 L
.57163 .106 L
.57274 .09074 L
.57394 .06922 L
.57461 .05477 L
.57525 .03958 L
.57584 .02436 L
.576 .01998 L
.57609 .01754 L
.57617 .01523 L
.57632 .01832 L
.57648 .02297 L
.5776 .05738 L
.58012 .14692 L
.58478 .3352 L
.58715 .42706 L
.58974 .51241 L
.59094 .54388 L
.59221 .57077 L
.59283 .58107 L
.59342 .58907 L
.59395 .59477 L
.59452 .59934 L
.5948 .60097 L
.59496 .60169 L
.5951 .60225 L
.59524 .60267 L
.59539 .603 L
.59553 .6032 L
.59566 .6033 L
.59573 .60332 L
.59582 .6033 L
.59597 .60317 L
.59612 .60291 L
.59626 .60257 L
.59641 .60209 L
.59658 .60141 L
Mistroke
.59691 .59961 L
.59724 .59723 L
.59754 .59455 L
.59822 .58678 L
.59885 .57745 L
.59945 .56678 L
.60185 .50694 L
.60407 .43131 L
.60881 .2332 L
.61119 .13162 L
.61223 .08973 L
.61282 .06707 L
.61336 .0468 L
.61391 .02732 L
.61407 .02188 L
.61422 .01682 L
.61436 .01709 L
.6145 .02188 L
.6157 .05851 L
.6169 .08981 L
.61822 .11754 L
.61881 .12772 L
.61946 .13695 L
.62001 .14351 L
.62061 .14917 L
.62097 .15176 L
.6213 .1537 L
.62161 .15515 L
.62177 .15573 L
.62194 .15625 L
.62211 .15664 L
.62227 .15689 L
.62242 .15705 L
.62258 .15712 L
.62272 .1571 L
.62285 .15701 L
.623 .15684 L
.62315 .15657 L
.6233 .15622 L
.62346 .15575 L
.62379 .15451 L
.6241 .15303 L
.62438 .15134 L
.62503 .14658 L
.62572 .14005 L
.62815 .10761 L
.63053 .06642 L
.63178 .04314 L
.63247 .03038 L
.63281 .02419 L
Mistroke
.63296 .02149 L
.63312 .01855 L
.63328 .01573 L
.63342 .01632 L
.63358 .01906 L
.63374 .02198 L
.63442 .03355 L
.6356 .0523 L
.6368 .06896 L
.63791 .08183 L
.63913 .09286 L
.63978 .09724 L
.64011 .09908 L
.64047 .10076 L
.64078 .10196 L
.64106 .10285 L
.64133 .10352 L
.64148 .1038 L
.64162 .10402 L
.64177 .1042 L
.64186 .10428 L
.64194 .10433 L
.64208 .1044 L
.64223 .10441 L
.64231 .1044 L
.6424 .10436 L
.64249 .1043 L
.64257 .10423 L
.64273 .10406 L
.64289 .10381 L
.6432 .10319 L
.64353 .10228 L
.64411 .10004 L
.64481 .09642 L
.64545 .09228 L
.64787 .07017 L
.65039 .0401 L
.65149 .02599 L
.6518 .02212 L
.65196 .01999 L
.65212 .01799 L
.65227 .01614 L
.65243 .0153 L
.65257 .01712 L
.65271 .0188 L
.65497 .04521 L
.6562 .05738 L
.65736 .06687 L
.65845 .07383 L
.65906 .07685 L
Mistroke
.65961 .07902 L
.66019 .08067 L
.66052 .08133 L
.66067 .08156 L
.66083 .08177 L
.66091 .08186 L
.66099 .08193 L
.66115 .08204 L
.66129 .0821 L
.66144 .08212 L
.66152 .08212 L
.6616 .0821 L
.66176 .08204 L
.66185 .08198 L
.66194 .08191 L
.6621 .08174 L
.66239 .08133 L
.66265 .08082 L
.66326 .07918 L
.66386 .07699 L
.6645 .074 L
.66566 .06708 L
.66672 .05923 L
.66919 .03702 L
.67039 .02506 L
.67096 .01935 L
.67122 .01684 L
.67136 .01542 L
.67149 .01533 L
.67162 .0166 L
.67176 .01796 L
.67204 .02072 L
.67263 .02645 L
.67371 .03635 L
.67608 .05464 L
.6773 .06153 L
.67799 .06455 L
.67863 .06675 L
.67895 .06761 L
.67925 .06829 L
.67952 .06879 L
.6798 .0692 L
.67995 .06936 L
.68012 .06951 L
.68027 .0696 L
.6804 .06966 L
.68049 .06968 L
.68057 .06969 L
.68072 .06968 L
.6808 .06966 L
Mistroke
.68088 .06964 L
.68096 .0696 L
.68105 .06954 L
.68119 .06944 L
.68134 .0693 L
.68164 .0689 L
.68192 .06842 L
.68218 .06787 L
.68277 .06628 L
.6834 .06407 L
.68456 .05873 L
.68561 .0526 L
.68812 .03427 L
.68922 .02523 L
.6898 .02035 L
.69012 .01765 L
.69028 .01633 L
.69043 .0151 L
.69057 .01551 L
.69072 .01675 L
.69104 .01937 L
.69159 .0239 L
.69268 .0324 L
.69507 .0482 L
.69631 .05434 L
.69701 .05702 L
.69766 .05898 L
.69822 .06027 L
.69854 .06082 L
.69884 .06122 L
.699 .06139 L
.69916 .06152 L
.6993 .0616 L
.69945 .06167 L
.69952 .0617 L
.69961 .06172 L
.6997 .06173 L
.69978 .06172 L
.69993 .0617 L
.70001 .06167 L
.70009 .06164 L
.70025 .06156 L
.70039 .06145 L
.70067 .06117 L
.70096 .06077 L
.70128 .06022 L
.70185 .05892 L
.70238 .05738 L
.70359 .05268 L
.70488 .04618 L
Mistroke
.70727 .03093 L
.70832 .02349 L
.70887 .01949 L
.70917 .01729 L
.70932 .01621 L
.70945 .01522 L
.7096 .01525 L
.70975 .01636 L
.71008 .01873 L
.71066 .02285 L
.7118 .03063 L
.71311 .03868 L
.71433 .04507 L
.71543 .04975 L
.71599 .05168 L
.71661 .05341 L
.71696 .05421 L
.71728 .05483 L
.71758 .05531 L
.71791 .05571 L
.71806 .05585 L
.71821 .05597 L
.71836 .05606 L
.71849 .05612 L
.71864 .05617 L
.71873 .05618 L
.7188 .05619 L
.71895 .05618 L
.7191 .05615 L
.71925 .05609 L
.71934 .05604 L
.71942 .05599 L
.71975 .05571 L
.72004 .05537 L
.72034 .05491 L
.72105 .05347 L
.72169 .05172 L
.72294 .04718 L
.72412 .04168 L
.72632 .02915 L
.72757 .0212 L
.72787 .01927 L
.72818 .01723 L
.72831 .01639 L
.72845 .01549 L
.7286 .01493 L
.72875 .01584 L
.72989 .02316 L
.73113 .0306 L
.73367 .0432 L
Mistroke
.7349 .04757 L
.7356 .04942 L
.73593 .05013 L
.73624 .05071 L
.73654 .05116 L
.73681 .0515 L
.7371 .05179 L
.73727 .05191 L
.73743 .052 L
.73758 .05206 L
.73766 .05209 L
.73774 .05211 L
.73788 .05212 L
.73802 .05212 L
.7381 .0521 L
.73819 .05209 L
.73834 .05203 L
.73842 .05199 L
.7385 .05195 L
.73867 .05183 L
.73899 .05154 L
.73928 .05118 L
.73994 .05007 L
.74052 .04875 L
.74114 .04702 L
.74338 .03819 L
.74576 .0256 L
.7468 .01954 L
.74709 .01786 L
.74724 .01693 L
.74739 .01606 L
.74753 .01525 L
.74768 .01507 L
.74781 .01586 L
.74794 .0166 L
.74914 .02352 L
.75028 .02972 L
.75158 .03607 L
.7528 .04106 L
.75389 .04461 L
.75445 .04605 L
.75507 .04731 L
.75541 .04787 L
.75574 .04829 L
.75604 .04861 L
.7562 .04874 L
.75637 .04885 L
.75652 .04893 L
.75666 .04898 L
.75679 .04901 L
Mistroke
.75693 .04903 L
.75709 .04902 L
.75723 .049 L
.75739 .04895 L
.75748 .04892 L
.75756 .04888 L
.75784 .0487 L
.75814 .04841 L
.75846 .04803 L
.75876 .04758 L
.75987 .04526 L
.7605 .04348 L
.76108 .0416 L
.76238 .03653 L
.76358 .03098 L
.76487 .02444 L
.76549 .02111 L
.76608 .01792 L
.76633 .01653 L
.76647 .01576 L
.7666 .01505 L
.76675 .01515 L
.7669 .01599 L
.76717 .01747 L
.76954 .02964 L
.77179 .03893 L
.77296 .04251 L
.77363 .04407 L
.77424 .04519 L
.77476 .04588 L
.77506 .04617 L
.77533 .04638 L
.77547 .04646 L
.77562 .04653 L
.77575 .04657 L
.77589 .0466 L
.77604 .04661 L
.77612 .04661 L
.7762 .0466 L
.77634 .04658 L
.77648 .04653 L
.77662 .04647 L
.77677 .04639 L
.77704 .04619 L
.77737 .04588 L
.77766 .04551 L
.7783 .04448 L
.7789 .0432 L
.77997 .04028 L
.78113 .03623 L
Mistroke
.78346 .026 L
.7847 .01986 L
.78504 .01813 L
.7854 .01631 L
.78555 .01556 L
.78571 .01475 L
.7858 .01514 L
.78588 .01556 L
.78604 .01638 L
.78848 .0282 L
.79077 .03722 L
.79197 .0407 L
.79255 .042 L
.79308 .043 L
.79366 .04382 L
.79397 .04414 L
.7943 .04441 L
.79447 .04451 L
.79455 .04455 L
.79465 .04459 L
.79474 .04463 L
.79482 .04465 L
.79497 .04468 L
.79513 .04469 L
.79521 .04469 L
.79529 .04468 L
.79544 .04465 L
.79559 .0446 L
.79574 .04454 L
.7959 .04445 L
.79619 .04423 L
.79647 .04396 L
.79673 .04365 L
.79733 .04274 L
.79796 .0415 L
.79901 .03879 L
.80017 .035 L
.8027 .02449 L
.80381 .01928 L
.80411 .01783 L
.80444 .01627 L
.8046 .01552 L
.80474 .0148 L
.80488 .01527 L
.80502 .01596 L
.8073 .02647 L
.80969 .0356 L
.81083 .03887 L
.81149 .04035 L
.81209 .04144 L
Mistroke
.81272 .04231 L
.81307 .04266 L
.81323 .04279 L
.8134 .0429 L
.81356 .04299 L
.8137 .04305 L
.81385 .0431 L
.81399 .04313 L
.81406 .04314 L
.81415 .04314 L
.81429 .04314 L
.81445 .04312 L
.81454 .0431 L
.81463 .04307 L
.81478 .04301 L
.81494 .04293 L
.81523 .04273 L
.81555 .04244 L
.81589 .04204 L
.81651 .0411 L
.81709 .03998 L
.81817 .0373 L
.81933 .03363 L
.8217 .02422 L
.82296 .01861 L
.82332 .01696 L
.8235 .01615 L
.82366 .0154 L
.82381 .01472 L
.82396 .01543 L
.8243 .01694 L
.82678 .02768 L
.82908 .03568 L
.83022 .03856 L
.83086 .03981 L
.83145 .0407 L
.83199 .04131 L
.8323 .04156 L
.83245 .04165 L
.83258 .04173 L
.83271 .04179 L
.83283 .04183 L
.83296 .04186 L
.83311 .04189 L
.83323 .04189 L
.83338 .04189 L
.83352 .04187 L
.83366 .04183 L
.83381 .04178 L
.83398 .0417 L
Mistroke
.83427 .04152 L
.83458 .04125 L
.83493 .04087 L
.83555 .03998 L
.83613 .03892 L
.83721 .03636 L
.83837 .03286 L
.84075 .02384 L
.842 .01846 L
.84237 .01688 L
.84254 .0161 L
.84271 .01538 L
.84285 .01473 L
.84301 .01539 L
.84334 .01684 L
.84583 .02719 L
.84814 .03488 L
.84928 .03767 L
.84992 .03887 L
.85051 .03973 L
.85105 .04032 L
.85136 .04056 L
.85151 .04065 L
.85164 .04073 L
.85177 .04078 L
.85189 .04082 L
.85202 .04086 L
.85216 .04088 L
.85229 .04089 L
.85243 .04088 L
.85258 .04086 L
.85272 .04083 L
.85287 .04077 L
.85304 .0407 L
.85333 .04052 L
.85364 .04026 L
.85399 .0399 L
.85461 .03904 L
.85519 .03801 L
.85627 .03554 L
.85743 .03216 L
.85982 .02344 L
.86047 .02077 L
.86116 .01785 L
.86145 .01664 L
.8616 .01601 L
.86176 .01534 L
.86184 .01498 L
.86193 .01484 L
.86202 .0152 L
Mistroke
.8621 .01553 L
.86241 .01687 L
.86493 .02696 L
.86721 .03431 L
.86837 .03702 L
.86903 .0382 L
.86963 .03903 L
.87016 .03957 L
.87046 .03979 L
.87074 .03994 L
.87089 .04 L
.87104 .04004 L
.87117 .04006 L
.87131 .04007 L
.87146 .04007 L
.87155 .04007 L
.87162 .04006 L
.87177 .04002 L
.87192 .03998 L
.87206 .03992 L
.87221 .03984 L
.87248 .03966 L
.8728 .03938 L
.87309 .03907 L
.87373 .03819 L
.87434 .03712 L
.8754 .0347 L
.87657 .03138 L
.8789 .02303 L
.87954 .02049 L
.88023 .01767 L
.88055 .01637 L
.88073 .01565 L
.88081 .0153 L
.88089 .01499 L
.88102 .01501 L
.88117 .01562 L
.88148 .0169 L
.88395 .02653 L
.88622 .03369 L
.88734 .03629 L
.88792 .03734 L
.88853 .03823 L
.88886 .03861 L
.88915 .03889 L
.88945 .03911 L
.88973 .03927 L
.88989 .03934 L
.88997 .03937 L
.89005 .03939 L
Mistroke
.89021 .03942 L
.89036 .03944 L
.89044 .03944 L
.89053 .03943 L
.89069 .03942 L
.89077 .0394 L
.89086 .03938 L
.89104 .03931 L
.89119 .03924 L
.89136 .03915 L
.89165 .03894 L
.89196 .03866 L
.89231 .03827 L
.89292 .03739 L
.8935 .03635 L
.89458 .0339 L
.89574 .03059 L
.89812 .02221 L
.89877 .01967 L
.89912 .01824 L
.89946 .01689 L
.89977 .01563 L
.89986 .01528 L
.89995 .01491 L
.90003 .01483 L
.90011 .01518 L
.90071 .01757 L
.90321 .02703 L
.90549 .03386 L
.90607 .03519 L
.9067 .03642 L
.90724 .0373 L
.90784 .03806 L
.90817 .03838 L
.90848 .03861 L
.90864 .03871 L
.9088 .03879 L
.90899 .03886 L
.90907 .03889 L
.90915 .03891 L
.9093 .03894 L
.90945 .03895 L
.9096 .03894 L
.90973 .03893 L
.90989 .0389 L
.91004 .03885 L
.9102 .03878 L
.91037 .0387 L
.91067 .03849 L
.91096 .03824 L
Mistroke
.9115 .03763 L
.91209 .03677 L
.91272 .03559 L
.91493 .02986 L
.91626 .02542 L
.9175 .02078 L
.91805 .01866 L
.91862 .01639 L
.91877 .01582 L
.91893 .0152 L
.91901 .01485 L
.9191 .01491 L
.91926 .01554 L
.91984 .01783 L
.92229 .02693 L
.92456 .0336 L
.92567 .03596 L
.92624 .03688 L
.92656 .03732 L
.92686 .03767 L
.92716 .03797 L
.92748 .03823 L
.92781 .03842 L
.92799 .03849 L
.92807 .03852 L
.92815 .03854 L
.92831 .03857 L
.92846 .03859 L
.92861 .03859 L
.92874 .03858 L
.92888 .03856 L
.92904 .03851 L
.92921 .03845 L
.92937 .03838 L
.92968 .03818 L
.92997 .03794 L
.93062 .03721 L
.9312 .03635 L
.93181 .03522 L
.93405 .02944 L
.93647 .02103 L
.93713 .01849 L
.93749 .01709 L
.93783 .01577 L
.93797 .01519 L
.93811 .01479 L
.93819 .01509 L
.93827 .01542 L
.93842 .01599 L
.93907 .01853 L
Mistroke
.94138 .02693 L
.94269 .03099 L
.94391 .03411 L
.94507 .03632 L
.94571 .03722 L
.94631 .03782 L
.94663 .03806 L
.94693 .03821 L
.9471 .03828 L
.94726 .03832 L
.94734 .03834 L
.94744 .03835 L
.94752 .03836 L
.94761 .03836 L
.94775 .03835 L
.94789 .03833 L
.94804 .0383 L
.94813 .03827 L
.94821 .03824 L
.94853 .03808 L
.94884 .03787 L
.9494 .03734 L
.95001 .03653 L
.95124 .03424 L
.95239 .03139 L
.95346 .02817 L
.95465 .02415 L
.9559 .01953 L
.95641 .01755 L
.95669 .01646 L
.95696 .01542 L
.95711 .01483 L
.9572 .01494 L
.95728 .01524 L
.95757 .01636 L
.95813 .01853 L
.96058 .02737 L
.96178 .03103 L
.96288 .03381 L
.96342 .03496 L
.96401 .03603 L
.96457 .03686 L
.96508 .03745 L
.96537 .03771 L
.96568 .03794 L
.96585 .03803 L
.966 .03811 L
.96615 .03816 L
.96631 .03821 L
.96644 .03823 L
Mistroke
.96659 .03825 L
.96673 .03825 L
.96685 .03824 L
.967 .03821 L
.96716 .03817 L
.96731 .03811 L
.96745 .03805 L
.96774 .03788 L
.96801 .03767 L
.96861 .03704 L
.96914 .03631 L
.9697 .03535 L
.97089 .03276 L
.97219 .02914 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.309097 0.0974746 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01667 -12 -4.5 ]
[-0.0125 .01667 0 4.5 ]
[-0.0125 .11415 -12 -4.5 ]
[-0.0125 .11415 0 4.5 ]
[-0.0125 .21162 -12 -4.5 ]
[-0.0125 .21162 0 4.5 ]
[-0.0125 .3091 -6 -4.5 ]
[-0.0125 .3091 0 4.5 ]
[-0.0125 .40657 -6 -4.5 ]
[-0.0125 .40657 0 4.5 ]
[-0.0125 .50405 -6 -4.5 ]
[-0.0125 .50405 0 4.5 ]
[-0.0125 .60152 -6 -4.5 ]
[-0.0125 .60152 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01667 m
.00625 .01667 L
s
[(-3)] -0.0125 .01667 1 0 Mshowa
0 .11415 m
.00625 .11415 L
s
[(-2)] -0.0125 .11415 1 0 Mshowa
0 .21162 m
.00625 .21162 L
s
[(-1)] -0.0125 .21162 1 0 Mshowa
0 .3091 m
.00625 .3091 L
s
[(0)] -0.0125 .3091 1 0 Mshowa
0 .40657 m
.00625 .40657 L
s
[(1)] -0.0125 .40657 1 0 Mshowa
0 .50405 m
.00625 .50405 L
s
[(2)] -0.0125 .50405 1 0 Mshowa
0 .60152 m
.00625 .60152 L
s
[(3)] -0.0125 .60152 1 0 Mshowa
.125 Mabswid
0 .03617 m
.00375 .03617 L
s
0 .05566 m
.00375 .05566 L
s
0 .07516 m
.00375 .07516 L
s
0 .09465 m
.00375 .09465 L
s
0 .13364 m
.00375 .13364 L
s
0 .15314 m
.00375 .15314 L
s
0 .17263 m
.00375 .17263 L
s
0 .19213 m
.00375 .19213 L
s
0 .23112 m
.00375 .23112 L
s
0 .25061 m
.00375 .25061 L
s
0 .27011 m
.00375 .27011 L
s
0 .2896 m
.00375 .2896 L
s
0 .32859 m
.00375 .32859 L
s
0 .34809 m
.00375 .34809 L
s
0 .36758 m
.00375 .36758 L
s
0 .38708 m
.00375 .38708 L
s
0 .42607 m
.00375 .42607 L
s
0 .44556 m
.00375 .44556 L
s
0 .46506 m
.00375 .46506 L
s
0 .48455 m
.00375 .48455 L
s
0 .52354 m
.00375 .52354 L
s
0 .54304 m
.00375 .54304 L
s
0 .56253 m
.00375 .56253 L
s
0 .58203 m
.00375 .58203 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01667 m
1 .01667 L
s
.99375 .11415 m
1 .11415 L
s
.99375 .21162 m
1 .21162 L
s
.99375 .3091 m
1 .3091 L
s
.99375 .40657 m
1 .40657 L
s
.99375 .50405 m
1 .50405 L
s
.99375 .60152 m
1 .60152 L
s
.125 Mabswid
.99625 .03617 m
1 .03617 L
s
.99625 .05566 m
1 .05566 L
s
.99625 .07516 m
1 .07516 L
s
.99625 .09465 m
1 .09465 L
s
.99625 .13364 m
1 .13364 L
s
.99625 .15314 m
1 .15314 L
s
.99625 .17263 m
1 .17263 L
s
.99625 .19213 m
1 .19213 L
s
.99625 .23112 m
1 .23112 L
s
.99625 .25061 m
1 .25061 L
s
.99625 .27011 m
1 .27011 L
s
.99625 .2896 m
1 .2896 L
s
.99625 .32859 m
1 .32859 L
s
.99625 .34809 m
1 .34809 L
s
.99625 .36758 m
1 .36758 L
s
.99625 .38708 m
1 .38708 L
s
.99625 .42607 m
1 .42607 L
s
.99625 .44556 m
1 .44556 L
s
.99625 .46506 m
1 .46506 L
s
.99625 .48455 m
1 .48455 L
s
.99625 .52354 m
1 .52354 L
s
.99625 .54304 m
1 .54304 L
s
.99625 .56253 m
1 .56253 L
s
.99625 .58203 m
1 .58203 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .3091 m
1 .3091 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .46221 m
.02847 .38896 L
.03355 .30907 L
.03602 .27022 L
.03832 .23404 L
.04054 .19917 L
.04118 .18914 L
.04178 .17965 L
.04232 .17113 L
.04247 .16879 L
.04263 .16632 L
.04276 .16421 L
.04291 .46811 L
.04307 .46566 L
.04321 .4634 L
.04354 .45825 L
.04414 .44889 L
.04525 .43131 L
.04777 .39172 L
.05249 .31753 L
.0549 .27966 L
.05751 .23869 L
.05873 .21945 L
.06002 .19912 L
.06113 .18177 L
.06143 .17702 L
.0616 .1744 L
.06175 .17192 L
.0619 .16962 L
.06206 .47334 L
.0622 .47106 L
.06234 .46895 L
.06707 .3945 L
.07163 .32293 L
.07416 .28316 L
.07647 .24671 L
.07875 .21098 L
.07989 .19301 L
.0802 .18809 L
.08054 .18283 L
.0807 .18028 L
.08085 .17787 L
.08099 .48193 L
.08114 .47958 L
.08608 .40201 L
.09083 .3273 L
.0954 .25548 L
.09774 .21861 L
.09842 .20799 L
.09906 .19791 L
Mistroke
.09963 .18886 L
.09979 .18638 L
.09988 .18503 L
.09996 .18375 L
.10012 .48748 L
.10026 .48523 L
.10492 .41204 L
.10987 .33421 L
.11234 .29543 L
.11464 .25926 L
.11685 .22445 L
.11749 .21443 L
.11809 .20494 L
.11864 .19643 L
.11878 .1941 L
.11894 .19162 L
.11908 .49574 L
.11922 .49341 L
.12408 .4171 L
.12875 .34367 L
.13112 .30635 L
.13372 .26559 L
.13492 .24673 L
.1362 .2266 L
.13682 .21683 L
.13741 .20761 L
.13766 .20359 L
.13793 .19934 L
.13808 .19712 L
.13823 .5009 L
.13837 .49868 L
.1385 .49661 L
.14319 .42292 L
.14818 .34459 L
.15067 .30541 L
.15298 .26914 L
.15522 .23396 L
.15635 .21619 L
.15666 .21132 L
.15682 .20876 L
.15699 .20607 L
.15714 .2037 L
.15723 .50858 L
.15731 .50733 L
.1576 .50278 L
.1623 .42885 L
.1673 .35027 L
.16981 .3109 L
.17212 .27457 L
.17437 .23921 L
Mistroke
.17551 .22137 L
.17582 .21649 L
.17599 .21379 L
.17607 .21247 L
.17615 .21123 L
.1763 .51509 L
.17638 .51384 L
.17647 .5125 L
.17676 .50797 L
.18177 .42914 L
.18661 .35319 L
.19126 .28012 L
.19367 .24231 L
.19425 .23313 L
.19488 .22328 L
.19506 .22038 L
.19515 .21895 L
.19524 .21763 L
.19539 .52139 L
.19548 .52009 L
.19557 .5187 L
.19621 .50862 L
.20076 .43707 L
.20561 .36088 L
.21028 .28757 L
.2127 .24958 L
.21329 .24035 L
.21392 .23049 L
.2141 .22757 L
.21419 .22614 L
.21428 .22482 L
.21443 .52857 L
.21452 .52727 L
.21461 .5259 L
.21525 .51584 L
.21982 .44405 L
.22469 .36762 L
.22937 .29407 L
.23059 .27487 L
.23193 .25395 L
.23254 .24437 L
.23287 .23913 L
.23303 .23655 L
.23318 .23419 L
.23333 .23194 L
.23348 .53579 L
.23363 .53341 L
.2338 .5308 L
.23435 .52211 L
.23923 .44544 L
Mistroke
.24394 .37165 L
.24633 .33405 L
.24893 .29323 L
.25015 .27416 L
.25081 .26373 L
.25144 .25395 L
.25197 .24564 L
.25212 .24324 L
.25226 .24097 L
.25239 .54515 L
.25254 .54292 L
.25375 .52391 L
.25865 .44701 L
.26336 .373 L
.26577 .33523 L
.26838 .29436 L
.2696 .27517 L
.27027 .26469 L
.27089 .2549 L
.27117 .25061 L
.2713 .2485 L
.27143 .24655 L
.27157 .55053 L
.27172 .54809 L
.272 .54382 L
.27321 .52482 L
.27794 .45058 L
.28249 .37922 L
.28502 .33958 L
.28734 .30323 L
.28852 .28479 L
.28961 .26762 L
.29017 .25897 L
.29032 .25647 L
.29047 .25412 L
.29061 .55823 L
.29076 .55594 L
.29201 .53635 L
.29694 .45904 L
.30169 .38461 L
.30626 .31306 L
.30746 .29423 L
.3086 .27635 L
.30891 .27157 L
.30923 .26649 L
.30933 .26498 L
.30942 .26356 L
.3095 .26229 L
.30959 .56714 L
.30967 .56583 L
Mistroke
.30976 .56444 L
.30992 .56196 L
.31112 .54313 L
.31571 .47136 L
.32059 .39498 L
.32528 .32148 L
.32651 .30225 L
.32716 .29211 L
.32785 .28135 L
.32814 .27683 L
.32829 .27446 L
.32845 .27197 L
.32853 .27064 L
.32863 .57541 L
.32871 .57408 L
.32879 .57285 L
.32911 .56785 L
.33028 .54961 L
.33499 .47591 L
.34 .39761 L
.34251 .35836 L
.34483 .32221 L
.34599 .30399 L
.34656 .29509 L
.34708 .28696 L
.34722 .28486 L
.34736 .28256 L
.3475 .2804 L
.34763 .58462 L
.34777 .5825 L
.34792 .58017 L
.34822 .57543 L
.34947 .55592 L
.35431 .48033 L
.35897 .40763 L
.36134 .37075 L
.36393 .33037 L
.36512 .31176 L
.36578 .30153 L
.3661 .29651 L
.36625 .2943 L
.3664 .29187 L
.36655 .28961 L
.36668 .59372 L
.36683 .59149 L
.36698 .58909 L
.36761 .57932 L
.3687 .56224 L
.37368 .48483 L
.37847 .41034 L
Mistroke
.38307 .33875 L
.3843 .31978 L
.3849 .31047 L
.38516 .30638 L
.38545 .3019 L
.38552 .3007 L
.38561 .29942 L
.38576 .60332 L
.38584 .60195 L
.38593 .60066 L
.38608 .59824 L
.38677 .58754 L
.38798 .56888 L
.3926 .49719 L
.39752 .42102 L
.40226 .3478 L
.40681 .27751 L
.41166 .2028 L
.41633 .13106 L
.4187 .09469 L
.42129 .05497 L
.42249 .03664 L
.42314 .02658 L
.42347 .02164 L
.42361 .01947 L
.42376 .01709 L
.42391 .32109 L
.42405 .31901 L
.42434 .31446 L
.42497 .30487 L
.42607 .28813 L
.43075 .21678 L
.43573 .14123 L
.43822 .10361 L
.44053 .06882 L
.44168 .05149 L
.44224 .043 L
.44249 .03928 L
.44262 .03732 L
.44276 .03521 L
.44291 .33917 L
.44305 .33705 L
.44336 .33243 L
.44401 .3227 L
.44514 .30577 L
.45014 .23127 L
.45495 .1601 L
.45715 .12775 L
.4584 .10942 L
.45958 .09228 L
Mistroke
.46073 .07553 L
.46106 .07072 L
.46138 .06614 L
.46166 .06204 L
.46174 .06092 L
.46182 .05972 L
.46197 .36379 L
.46205 .36258 L
.46214 .36131 L
.4623 .35903 L
.46265 .35389 L
.4633 .34457 L
.4645 .3272 L
.46908 .26187 L
.47395 .19344 L
.4762 .16234 L
.47864 .12883 L
.47929 .12005 L
.47997 .11075 L
.48056 .10284 L
.48072 .10067 L
.4808 .09954 L
.48089 .09834 L
.48097 .40351 L
.48105 .40236 L
.4812 .40034 L
.48363 .36781 L
.48852 .30332 L
.49322 .24243 L
.49562 .21172 L
.49688 .19561 L
.49822 .17857 L
.4988 .17125 L
.49942 .1634 L
.4996 .16109 L
.49977 .15889 L
.49993 .15692 L
.50001 .46203 L
.5001 .461 L
.50073 .45293 L
.50304 .42351 L
.50777 .36307 L
.51278 .29786 L
.5153 .26462 L
.51641 .24992 L
.51762 .23372 L
.51818 .22613 L
.5185 .22194 L
.51865 .21988 L
.51879 .21797 L
Mistroke
.51892 .21618 L
.51906 .5205 L
.51921 .51859 L
.51936 .51648 L
.51988 .50943 L
.52227 .47688 L
.52712 .40975 L
.53179 .34394 L
.53416 .3101 L
.53542 .29211 L
.53676 .27283 L
.53743 .26318 L
.53775 .25843 L
.5379 .25635 L
.53806 .25405 L
.5382 .55822 L
.53833 .55629 L
.53862 .55208 L
.53924 .54318 L
.54154 .50961 L
.54623 .44081 L
.55121 .36697 L
.5537 .32981 L
.55491 .31169 L
.55601 .29527 L
.55656 .28695 L
.55671 .28468 L
.55687 .28227 L
.55701 .28022 L
.55716 .5842 L
.5573 .58207 L
.55743 .58013 L
.55772 .57577 L
.55824 .56791 L
.56062 .53209 L
.56544 .45929 L
.57007 .38895 L
.57241 .35323 L
.57366 .33425 L
.57434 .32378 L
.575 .31381 L
.57561 .30447 L
.57578 .30191 L
.57595 .29918 L
.57604 .29785 L
.57612 .2966 L
.57628 .60049 L
.57642 .59831 L
.57657 .59601 L
.57684 .59189 L
Mistroke
.57745 .58259 L
.57974 .54745 L
.58432 .47721 L
.5892 .40225 L
.59389 .32994 L
.59888 .25293 L
.60368 .17861 L
.6083 .10703 L
.61064 .07079 L
.61188 .05153 L
.61253 .04141 L
.61322 .03076 L
.61383 .02132 L
.61399 .01873 L
.61409 .01731 L
.61417 .01597 L
.61425 .01472 L
.61434 .31958 L
.61449 .31721 L
.61566 .29908 L
.61795 .26347 L
.62289 .18678 L
.62764 .11286 L
.63003 .0757 L
.63107 .05945 L
.63221 .04173 L
.63251 .03702 L
.63283 .03201 L
.63299 .02957 L
.63314 .02728 L
.63327 .02522 L
.63341 .32922 L
.63355 .32707 L
.6337 .32471 L
.63401 .31995 L
.63455 .31143 L
.63707 .27217 L
.64196 .19607 L
.64665 .12278 L
.64905 .08542 L
.65031 .06573 L
.651 .05494 L
.65165 .04483 L
.65193 .04047 L
.65222 .03589 L
.65237 .03348 L
.65246 .33835 L
.65254 .33709 L
.65284 .33248 L
.65415 .31201 L
Mistroke
.65646 .27592 L
.66117 .20225 L
.66618 .12394 L
.6687 .08464 L
.6698 .0674 L
.67038 .05826 L
.67071 .05322 L
.67101 .04845 L
.67115 .04623 L
.6713 .04388 L
.67138 .04265 L
.67147 .34752 L
.67162 .34513 L
.67218 .33642 L
.67327 .31936 L
.67566 .28202 L
.6805 .20622 L
.68516 .13326 L
.68753 .09621 L
.68878 .07661 L
.68947 .06583 L
.68981 .06053 L
.69012 .05564 L
.69027 .05321 L
.69042 .05092 L
.69057 .35477 L
.69065 .3535 L
.69074 .35215 L
.69141 .3416 L
.69259 .32316 L
.69489 .2871 L
.69987 .20919 L
.70466 .13413 L
.70707 .09625 L
.70813 .07975 L
.70868 .07107 L
.70898 .06634 L
.70927 .06191 L
.70941 .05961 L
.70957 .36338 L
.70966 .36198 L
.70974 .36065 L
.7099 .35816 L
.71049 .34898 L
.71164 .33093 L
.71417 .29127 L
.71879 .21877 L
.72371 .14162 L
.72616 .1033 L
.72736 .08453 L
Mistroke
.72788 .07631 L
.72816 .07197 L
.72831 .06958 L
.72845 .06733 L
.72859 .37137 L
.72874 .36901 L
.72901 .36487 L
.72952 .3568 L
.73064 .33917 L
.73301 .30211 L
.73794 .22467 L
.7427 .15009 L
.74509 .1126 L
.74613 .09622 L
.74668 .08757 L
.74727 .07836 L
.74744 .07571 L
.7476 .07321 L
.74774 .3772 L
.74789 .37478 L
.74847 .36569 L
.74962 .34776 L
.75214 .30821 L
.75709 .23047 L
.76186 .15559 L
.76426 .11789 L
.76531 .10144 L
.76586 .09277 L
.76616 .08802 L
.76645 .08358 L
.76659 .08131 L
.76675 .38509 L
.76683 .38371 L
.76692 .38239 L
.76708 .37991 L
.76766 .37077 L
.76881 .35277 L
.77133 .31314 L
.77593 .24085 L
.78083 .16391 L
.7831 .12834 L
.78429 .10962 L
.78494 .09939 L
.78526 .09439 L
.78555 .08984 L
.78571 .08735 L
.78586 .39121 L
.78602 .38872 L
.78619 .38601 L
.7869 .37496 L
Mistroke
.78813 .35554 L
.79056 .31734 L
.79548 .24013 L
.79792 .20179 L
.80021 .16578 L
.8024 .13139 L
.803 .12196 L
.80364 .11204 L
.80417 .10357 L
.80432 .10125 L
.80448 .09877 L
.80463 .09642 L
.80476 .40052 L
.80491 .39827 L
.80504 .39615 L
.80535 .39135 L
.80597 .38163 L
.80708 .3642 L
.80958 .32481 L
.81427 .25129 L
.81665 .21389 L
.81924 .17311 L
.82045 .15419 L
.82173 .13404 L
.82235 .12425 L
.82294 .11503 L
.82346 .10675 L
.82361 .10448 L
.82376 .10209 L
.82389 .40627 L
.82403 .40403 L
.82891 .32737 L
.83361 .25357 L
.836 .21598 L
.8386 .17512 L
.83982 .15607 L
.8411 .13585 L
.8422 .11858 L
.8425 .11385 L
.84266 .11137 L
.84275 .11002 L
.84283 .10876 L
.84297 .41269 L
.84305 .41147 L
.84313 .41017 L
.84341 .40577 L
.84842 .32706 L
.85325 .25121 L
.85789 .17824 L
.86029 .14052 L
Mistroke
.86087 .13135 L
.8615 .12151 L
.86169 .11861 L
.86178 .11718 L
.86186 .11586 L
.86202 .41962 L
.8621 .41832 L
.86219 .41694 L
.86283 .40684 L
.86738 .33538 L
.87222 .25927 L
.87688 .18603 L
.87929 .14811 L
.87988 .13889 L
.88051 .12903 L
.88069 .12612 L
.88078 .12469 L
.88087 .12337 L
.88102 .42712 L
.88111 .42582 L
.88119 .42444 L
.88184 .41436 L
.8864 .34264 L
.89126 .26626 L
.89593 .19275 L
.89715 .17359 L
.89848 .15268 L
.89909 .14312 L
.89943 .13787 L
.89959 .1353 L
.89974 .13293 L
.89988 .13068 L
.90003 .43454 L
.90019 .43215 L
.90035 .42954 L
.90091 .42082 L
.90578 .34418 L
.91048 .27041 L
.91286 .23284 L
.91546 .19199 L
.91667 .17296 L
.91734 .16253 L
.91796 .15274 L
.91849 .14444 L
.91863 .14216 L
.91879 .13977 L
.91892 .13772 L
.91906 .44171 L
.91922 .43921 L
.91936 .43694 L
Mistroke
.91969 .43184 L
.92027 .42266 L
.92509 .34686 L
.92973 .27392 L
.93208 .23697 L
.93467 .19634 L
.93585 .17773 L
.9365 .16747 L
.93712 .15774 L
.9377 .14871 L
.93785 .14623 L
.93794 .14488 L
.93802 .1436 L
.93818 .44734 L
.93832 .44509 L
.93942 .42785 L
.94408 .35465 L
.94903 .27681 L
.95149 .23801 L
.9538 .20183 L
.95493 .18394 L
.95601 .16701 L
.95661 .15766 L
.95677 .1551 L
.95694 .15238 L
.95709 .15006 L
.95717 .45496 L
.95725 .45372 L
.95838 .43596 L
.96305 .3625 L
.96802 .28439 L
.97281 .20916 L
.97619 .15598 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000U2000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00:Oooool3
o`0001_ooooo1Ol0000Kooooo`?o00006_ooool2o`0001gooooo0ol0000Kooooo`Go00006oooool3
o`0003kooooo0ol0000Kooooo`Go00007?ooool3o`0001[ooooo0_l0000Looooo`?o00007?ooool5
o`0001_ooooo0ol0000Jooooo`00:?ooool01Ol0003ooooooooooooooooo000001_ooooo00Co0000
oooooooooooo00007?ooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0001gooooo
00?o0000ooooooooool06oooool01?l0003oooooooooool0000Jooooo`05o`000?oooooooooooooo
ool00000??ooool01Ol0003ooooooooooooooooo000001_ooooo00Co0000oooooooooooo00007Ooo
ool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool0
7?ooool01?l0003oooooooooool0000Jooooo`05o`000?ooooooooooooooool000006Oooool002;o
oooo1Ol00005ooooo`03o`000?oooooooooo01;ooooo1Ol00003ooooo`03o`000?oooooooooo01Co
oooo1Ol00003ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00007Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0=?ooool5o`00
00Gooooo00?o0000ooooooooool04_ooool5o`0000?ooooo00?o0000ooooooooool05Oooool5o`00
00?ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Looooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Gooooo`00:_ooool2o`00
01kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`04o`000?oooooooooo
o`0001gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`;o0000?oooool2
o`0001kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Hooooo`04o`000?oooooo
ooooo`0001cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`;o00006_oo
ool002cooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000001cooooo00?o
0000ooooooooool06?ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo01[ooooo
00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool06?ooool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooooooool06?ooool01?l0
003oooooooooool0000Looooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00
000Nooooo`03o`000?oooooooooo01Oooooo000Xooooo`05o`000?ooooooooooooooool000006_oo
ool01Ol0003ooooooooooooooooo000001_ooooo0_l0000Jooooo`04o`000?ooooooooooo`0001co
oooo0_l0000Looooo`05o`000?ooooooooooooooool000006_ooool01Ol0003ooooooooooooooooo
000003cooooo00Go0000ooooooooooooooooo`00000Jooooo`05o`000?ooooooooooooooool00000
7?ooool2o`0001[ooooo00Co0000oooooooooooo00006oooool2o`0001gooooo00Go0000oooooooo
ooooooooo`00000Jooooo`05o`000?ooooooooooooooool000006Oooool002Wooooo0ol0000Loooo
o`?o00007Oooool00ol0003oooooooooo`0Iooooo`;o00007_ooool00ol0003oooooooooo`0Koooo
o`?o00007?ooool3o`0003kooooo0ol0000Looooo`?o00007_ooool00ol0003oooooooooo`0Ioooo
o`;o00007Oooool00ol0003oooooooooo`0Looooo`?o00007?ooool3o`0001[ooooo003oooooooWo
oooo003oooooooWooooo003oooooooWooooo000Noooooloo0000:oooooo?o`00017ooooo000Hoooo
o`;o00001?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00008oooool3o`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`00017ooooo000Gooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo023o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0?ooooo`005oooool01?l0003oooooooooool00003oooo
o`?o00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00002ooooo`;oo`000_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
5oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000?ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool2
o`0001cooooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool03oooool0
01Oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00Gooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00Oooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo0_l0
0005ooooo`;o0000EOooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o
o`00ooooooooool0Boooool2o`00017ooooo000Gooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool00oooool01?oo003ooooooooooooo0003ooooo`;oo`0000?oooooool00?oo0000
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool0
0ooo003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Dooooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool05Oooool0
0ooo003oooooooooo`1<ooooo`03o`000?oooooooooo00oooooo000Gooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02ool000;ooooo0_oo0000
0oooooooo`00ool00002ooooo`?oo`0000Woooooool00?ooooooo`00oooooooo003oooooool00?oo
ool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_oo0002
ooooo`;oo`000_ooool2ool00004oooooooo003o0000ool000;ooooo0_oo0002ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00005
oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo05Cooooo00?oo`00ooooooooool03Oooool0
0ol0003oooooooooo`0Eooooo`03ool00?oooooooooo00;oo`00B_ooool00ol0003oooooooooo`0?
ooooo`006?ooool2o`0000Cooooo00?o0000ooooooooool00oooool07_oo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo00000oooooooo`00o`000003ool0
0005oooooooo003ooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Oooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0001ooooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00Koo`001Ooo
ool00ol0003oooooooooo`0Qooooo`?o00001Oooool00ol0003oooooooooo`1Dooooo`03ool00?oo
oooooooo00gooooo00?o0000ooooooooool05?ooool2ool000;ooooo0_oo0002ooooo`03ool00?oo
oooooooo04Gooooo00?o0000ooooooooool03oooool001kooooo0_l00005ooooo`;oo`0000Gooooo
ool00?oo003oo`00ooooo`03ool00005oooooooo003oo`00ool00?ooool00ooo00001Oooooooo`00
ool00?oo003ooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01?oo003o
ooooool00?oo0002ooooo`;oo`0000coooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00007
ooooo`03ool00?oooooooooo00;oo`000_ooool2ool00004oooooooo003oooooooooo`;oo`0000[o
0000oooooooo003oo`00oooooooo003oooooool00?ooooooo`000_ooool01Ooo003ooooooooooooo
ooooo`0000Oooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool0000Goooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool0
0ooo00000oooooooo`00ool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000Gooooo00?o0000ooooooooool0:Oooool2o`0005Gooooo00Goo`00oooooooooooo
ooooool0000;ooooo`03o`000?oooooooooo01Cooooo0_oo0002ooooo`;oo`000_ooool00ooo003o
ooooooooo`14ooooo`;o00004Oooool001kooooo00?o0000ooooooooool06?ooool00ooo003ooooo
ooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
00koooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000;o
oooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000Oooooo00?oo`00oooo
ooooool00_oo0002ooooo`;oo`0000?oooooool00?ooool00oooool00ol0003oooooooooo`03oooo
o`;oo`0000Goooooool00?ooooooooooool00003ooooo`03ool00?oooooooooo00Gooooo00Goo`00
ooooooooooooooooool00002ooooo`;oo`000_ooool2ool000;ooooo00Coo`00oooooooo003ooooo
0_oo0002ooooo`;oo`0000Koooooool00?ooooooo`00oooooooo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0G
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0E?ooool01Ooo003ooooooooooooo
ooooo`0000_ooooo00?o0000ooooooooool05?ooool2ool000;ooooo0_oo0002ooooo`05ool00?oo
oooooooooooooooo0000@oooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003ooooooooo
o`0Wooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000koooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo0002ooooo`05ool0
0?oooooooooooooooooo00001oooool00ooo003oooooooooo`02ool00004oooooooo003ooooooooo
o`;oo`001?ooool00ol0003oooooooooo`03ooooo`;oo`0000Koooooool00?ooooooo`00oooooooo
0002ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`00
0_ooool2ool000;ooooo00Koo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool09oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo05Cooooo00Goo`00ooooooooooooooooool0000;ooooo`03o`000?oooooo
oooo01Cooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0004?ooooo00?o
0000ooooooooool03oooool001kooooo00?o0000ooooooooool0<oooool2ool000;ooooo0_oo0000
2_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`;oo`000_ooool01Ooo
003oooooooooooooooooo`0000Kooooo0_oo0002ooooo`;oo`0000Goooooool00?ooooooooooool0
0005ooooo`03o`000?oooooooooo00?ooooo0_oo00001_ooooooo`00oooooooo003oooooool000;o
oooo00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002oooo
o`06ool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool003Cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1Dooooo`05ool00?oooooooooooooooooo0000
2oooool00ol0003oooooooooo`0Dooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo03gooooo00?o0000ooooooooool03oooool001kooooo
00?o0000ooooooooool0=oooool2ool000;ooooo0_oo00002oooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003ooooo00;oo`000oooool00ooo003oooooooooo`04ooooo`;oo`000_oo
ool2ool00003oooooooo003ooooo00Oooooo00?o0000ooooooooool01_ooool01Ooo003oooooool0
0?ooooooo`0000;ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ool000;ooooo
00Koo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`00>?ooool00ol0
003oooooooooo`0Yooooo`;o0000EOooool01Ooo003oooooooooooooooooo`0000_ooooo00?o0000
ooooooooool05?ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`0looooo`;o00004Oooool001kooooo0_l0000looooo`;oo`0000_ooooo
ool00?oo003oo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool000?ooooo00?oo`00oooo
ooooool01?ooool2ool000;ooooo00Coo`00oooooooo003oo`002?ooool00ol0003oooooooooo`07
ooooo`;oo`0000Goooooool00?ooooooooooool00007ooooo`03ool00?oooooooooo00;oo`000_oo
ool01_oo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool003cooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1Dooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo0_oo0002ooooo`;oo`000_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000kooooo`03o`000?oo
oooooooo00oooooo000Nooooo`03o`000?oooooooooo03oooooo0_oo00002oooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo00;oo`001_ooool2ool000;ooooo00Coo`00oooo
oooo003oo`002?ooool00ol0003oooooooooo`07ooooo`;oo`0000Goooooool00?ooooooooooool0
0007ooooo`09ool00?ooooooooooool00?ooooooo`00oooooooo003ooooo00;oo`000_ooool2ool0
043ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Dooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo0_oo0002
ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo03Gooooo00?o0000ooooooooool03oooool001kooooo00?o
0000ooooooooool0?oooool03Ooo003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool00_oo0006ooooo`;oo`000_ooool01?oo003oooooool00?oo0008ooooo`03o`00
0?oooooooooo00Oooooo0_oo00001Oooooooo`00ooooooooooooo`0000Oooooo00Woo`00oooooooo
ooooo`00oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`00@?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo05Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00Gooooo00?o0000ooooooooool05?ooool2ool000;ooooo0_oo0002ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool0000cooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo
04?ooooo0_oo00001oooooooo`00oooooooo003oooooool00?ooool00_oo0006ooooo`;oo`0000?o
ooooool00?ooool02oooool00ol0003oooooooooo`0:ooooo`04ool00?ooooooooooool000Oooooo
00Woo`00ooooooooooooo`00oooooooo003oooooool00?ooool00_oo0014ooooo`03o`000?oooooo
oooo02Wooooo0_l0001Eooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`05ooooo`03o`000?oooooooooo01Cooooo0_oo0002ooooo`;oo`000_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo0000<_ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo04?ooooo00Woo`00oooooooo
ooooo`00oooooooo003oooooool00?ooool00_oo0006ooooo`;oo`0000?oooooool00?ooool02ooo
ool00ol0003oooooooooo`0:ooooo`04ool00?ooooooooooool000Kooooo0_oo0002ooooo`06ool0
0?ooooooo`00oooooooo003ooooo0_oo0014ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0Doooool2ool000?ooooo00Goo`00ooooooooooooooooool00007ooooo`03o`000?oooooo
oooo01Cooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooooooo`0]ooooo`03o`000?oooooooooo00oooooo000Nooooo`;o0000Aoooool01_oo003ooooo
ool00?ooooooo`00ooooo`;oo`001_ooool2ool00003oooooooo003ooooo00_ooooo00?o0000oooo
ooooool02_ooool01?oo003oooooool00?oo0006ooooo`;oo`000_ooool01?oo003oooooool00?oo
0018ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Doooool2ool000?ooooo00Go
o`00ooooooooooooooooool00007ooooo`03o`000?oooooooooo01Cooooo0_oo0002ooooo`;oo`00
0_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0002_ooooo00?o
0000ooooooooool03oooool001kooooo00?o0000ooooooooool0A_ooool01_oo003oooooool00?oo
ooooo`00ooooo`;oo`001_ooool2ool00003oooooooo003ooooo00_ooooo00?o0000ooooooooool0
2_ooool01?oo003oooooool00?oo0006ooooo`;oo`000_ooool01?oo003oooooool00?oo0018oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Doooool2ool000;ooooo0_oo0003oooo
o`03ool00?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ooo003oooooool00002oooo
o`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0002_o
oooo00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0Aoooool2ool00003oooo
oooo003ooooo00;oo`001_ooool2ool00003oooooooo003ooooo00_ooooo00?o0000ooooooooool0
2_ooool01?oo003oooooool00?oo0006ooooo`;oo`000_ooool01?oo003oooooool00?oo0018oooo
o`03o`000?oooooooooo02Wooooo0_l0001Dooooo`;oo`000_ooool2ool000?ooooo00?oo`00oooo
ooooool01Oooool00ol0003oooooooooo`0Cooooo`03ool00?ooooooo`0000;ooooo0_oo0002oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooooooo`0Tooooo`;o00004Oooool001kooooo00?o0000ooooooooool0Aoooool01Ooo003ooooo
oooooooo003ooooo00;oo`001_ooool2ool00003oooooooo003ooooo00_ooooo00?o0000oooooooo
ool02oooool3ool000Kooooo0_oo0002ooooo`04ool00?ooooooo`00ool004Sooooo00?o0000oooo
ooooool08?ooool5o`0000Cooooo00?o0000ooooooooool0Doooool2ool000;ooooo0_oo0003oooo
o`05ool00?oooooooooooooooooo00000oooool00ol0003oooooooooo`0Cooooo`07ool00?oooooo
o`00oooooooo003oooooool00002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0002?ooooo00?o0000ooooooooool0
3oooool001kooooo00?o0000ooooooooool0Aoooool01Ooo003ooooooooooooo003ooooo00;oo`00
1_ooool01?oo003oooooool00?oo000<ooooo`03o`000?oooooooooo00_ooooo0_oo00000ooooooo
o`00ooooo`04ooooo`;oo`000_ooool01?oo003oooooool00?oo0018ooooo`03o`000?oooooooooo
027ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Cooooo`;oo`000_ooool2
ool000;ooooo0_oo0003ooooo`05ool00?ooooooooooooooool000005Oooool01ooo003oooooool0
0?ooooooo`00oooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000Sooooo`03o`000?oooooooooo00oo
oooo000Nooooo`;o0000Boooool01?oo003oooooool00?oo0006ooooo`04ool00?ooooooo`00ool0
00cooooo00?o0000ooooooooool02oooool2ool00003oooooooo003ooooo00Cooooo00Goo`00oooo
oooo003oooooool0001;ooooo`03o`000?oooooooooo01[ooooo1Ol00003ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Doooool2ool000;ooooo0_oo0002ooooo`;oo`000oooool0
1Ooo003ooooooooooooooooo000001Gooooo00Soo`00oooooooo003oooooool00?ooooooo`00oooo
o`;oo`000_ooool2ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool03oooool001kooooo
00?o0000ooooooooool0B_ooool01?oo003oooooool00?oo0006ooooo`04ool00?ooooooo`00ool0
00cooooo00?o0000ooooooooool02oooool2ool00003oooooooo003ooooo00Cooooo00Goo`00oooo
oooo003oooooool0001;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool2
o`0005Cooooo0_oo0002ooooo`;oo`000_ooool2ool000?ooooo00Goo`00ooooooooooooooooo`00
000Eooooo`08ool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0003oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0001[ooooo0_l0000Aooooo`005oooool3o`0000Cooooo00?o0000oooooooo
ool0B_ooool01?oo003oooooool00?oo0006ooooo`04ool00?ooooooo`00ool000cooooo00?o0000
ooooooooool02oooool2ool00003oooooooo003ooooo00Cooooo00Goo`00oooooooo003oooooool0
001;ooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo05?ooooo0_oo0002ooooo`;oo`000_ooool2ool000?ooooo00Goo`00oooooooooooo
ooooo`00000Eooooo`08ool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool0000Kooooo`03o`000?oooooooooo00oooooo000Fooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`1:ooooo`04ool00?ooooooo`00ool000Kooooo00Co
o`00oooooooo003oo`003?ooool00ol0003oooooooooo`0;ooooo`;oo`0000?oooooool00?ooool0
1?ooool01?oo003oooooool00?oo001<ooooo`03o`000?oooooooooo023ooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo05?ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00?ooooo00Goo`00ooooooooooooooooo`00000Eooooo`08ool00?ooooooo`00oooooooo003ooooo
ool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000?ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00;oo`000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo01Gooooo00?o
0000ooooooooool03oooool001[ooooo00Go0000ooooooooooooooooo`00001<ooooo`04ool00?oo
ooooo`00ool000Kooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03ool0
0?oooooooooo00?ooooo00Coo`00oooooooo003oo`00C?ooool00ol0003oooooooooo`0Qooooo`?o
00001Oooool00ol0003oooooooooo`1Cooooo`;oo`000_ooool2ool000;ooooo0_oo0003ooooo`05
ool00?ooooooooooooooool000005Oooool02?oo003oooooool00?ooooooo`00oooooooo003ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000oooool01Ooo003ooooo
ooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`02ool000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo017ooooo00?o0000oooo
ooooool03oooool001[ooooo00Co0000oooooooooooooooo0ol0001:ooooo`04ool00?ooooooo`00
ool000Kooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooo
oooo00?ooooo00Coo`00oooooooo003oo`00Boooool2o`0002_ooooo0_l0001Dooooo`;oo`000_oo
ool2ool000;ooooo0_oo0003ooooo`05ool00?ooooooooooooooool000005Oooool02?oo003ooooo
ool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`0@ooooo`;o00004Oooool001Kooooo1?l00004ooooo`03o`000?oooooooooo04[ooooo00Coo`00
oooooooo003oo`001_ooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o
o`00ooooooooool00oooool01?oo003oooooool00?oo001<ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0Doooool2ool000;ooooo0_oo0002ooooo`;oo`000oooool01Ooo003ooooo
oooooooooooo000001Gooooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo000?ooooo`03o`000?oooooooooo00oooooo000Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0B_ooool01Ooo003oooooool00?ooooooo`0000Gooooo00?o
o`00ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo00Co
o`00oooooooo003oo`00C?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo
0_oo0002ooooo`;oo`000_ooool2ool000?ooooo00Goo`00ooooooooooooooooo`00000Dooooo`09
ool00?ooooooooooool00?ooooooo`00oooooooo003ooooo00;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool03oooool001Kooooo1Ol00003
ooooo`03o`000?oooooooooo04_ooooo0_oo00000oooooooo`00ooooo`04ooooo`03ool00?oooooo
oooo00gooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`03ooooo`04ool00?oooooo
o`00ool004cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Cooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000oooool00ol0003oooooooooo`0Booooo`09ool00?oo
ooooooooool00?ooooooo`00oooooooo003ooooo00;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`05ool00?oooooooooooooooooo00002?ooool00ol0003oooooooooo`0?ooooo`007_ooool2o`00
04cooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooo
oooo00kooooo00?oo`00ooooooooool00oooool01?oo003oooooool00?oo001<ooooo`03o`000?oo
oooooooo02Wooooo0_l0001Dooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000ooo
ool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo00;oo`000_ooool01?oo003oooooool0
0?oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00007ooooo`;o
00004Oooool001kooooo00?o0000ooooooooool0Boooool01?oo003ooooooooooooo0005ooooo`03
ool00?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`03ooooo`04
ool00?ooooooo`00ool004cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Coooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`0Boooo
o`03ool00?oooooooooo00;oo`000_ooool01?oo003oooooool00?oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?o
0000ooooooooool03oooool001kooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`06
ooooo`03ool00?oooooooooo04[ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0003
ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`0000Cooooo
ool00?oooooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003ooooooooo
o`1>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03Oooool00ol0003ooooooooo
o`0>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0COooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00Kooooo00Goo`00ooooooooooooooooool00017ooooo`03ool0
0?ooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000?ooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`02ool000;ooooo0_oo00001_ooooooo`00oooooooo003oooooool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02
ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo04kooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo02Wooooo0_l00007oooo
o`05ool00?oooooooooooooooooo0000Aoooool00ooo003oooooool00002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0003ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool00_oo0002
ooooo`;oo`0000[oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooooooo0_l0000Aooooo`007_ooool2
o`0004oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool01Oooool2ool000?ooooo00Goo`00ooooooooooooooooool0
0013ooooo`03ool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000?ooooo00?o
o`00ooooooooool04_ooool00ooo003oooooooooo`02ool000;ooooo0_oo00003_ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`00
0?oooooooooo04kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1=ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool01Oooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool00ooo003oooooooooo`0nooooo`07ool00?ooooooo`00oooooooo003oooooool00002oooo
o`;oo`000_ooool2ool000?ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`02ool0
00;ooooo0_oo00004_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`03
o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
1Oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0nooooo`07ool0
0?ooooooo`00oooooooo003oooooool00002ooooo`;oo`000_ooool2ool000?ooooo00?oo`00oooo
ooooool04_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`0000koooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooo
oooo04kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooo
oooo02Wooooo0_l00006ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooo
oooooooooooo0000??ooool01ooo003oooooool00?ooooooo`00oooooooo00000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`005?ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;o
o`0001;oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oo
oooooooooooooooo00000oooool01?oo003oooooooooooooool2o`00017ooooo000Nooooo`03o`00
0?oooooooooo04kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1=ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool01Oooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0=_ooool02ooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`00
5?ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`0001Koooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`000_ooool2ool000;ooooo0_oo00002?ooooooo`00oooooooo003oooooool0
0?ooooooo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool03ooo
ool001kooooo0_l0001?ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0COooool0
0ol0003oooooooooo`0Qooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0003Cooooo00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0002ooooo`;oo`000_ooool2ool001Cooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_oo
ool2ool0000Foooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo0002ooooo`;oo`0000So
ooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02
ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo04kooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0003Cooooo00_o
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00002ooooo`;oo`000_ooool2
ool001Cooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool0000Joooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`;oo`0000Soooooool00?oooooo
o`00oooooooo003oooooool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ooooo`03o`000?oo
oooooooo00oooooo000Nooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`1=ooooo`03o`000?oooooooooo01[ooooo1Ol00003ooooo`03o`000?oooooo
oooo00Cooooo0_l00006ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
;_ooool02ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo
0002ooooo`;oo`005?ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`0001[o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo00002?oooooo
o`00oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooooooo`;o
00004Oooool001kooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo04gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0002cooooo00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00002oooo
o`;oo`000_ooool2ool000?ooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`02ool0
00;ooooo0_oo0002ooooo`;oo`0001[oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool000;ooooo0_oo00003?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool000;ooooo0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`000_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`00
7_ooool00ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
3_ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
COooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000;?ooool0
2ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo0002oooo
o`;oo`000oooool00ooo003oooooooooo`0=ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2
ool000;ooooo0_oo00006_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
0_ooool2ool0000<oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
0_ooool2ool000;ooooo0_oo00001Oooooooo`00oooooooo003ooooo00;oo`000_ooool2ool000?o
oooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`007_ooool2o`0004oooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo027ooooo
0_l00006ooooo`03o`000?oooooooooo00Gooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool09_ooool02ooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`000oooool00ooo
003oooooooooo`0=ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2ool000;ooooo0_oo0000
;_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo0002ooooo`;oo`0000Goooooool00?ooooooo`00ooooo`02ool000;ooooo0_oo0003ooooo`03
ool00?oooooooooo00;ooooo00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0
C_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`04ooooo`;o00001_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0002Cooooo00oo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000
0_ooool2ool000?ooooo00?oo`00ooooooooool03Oooool01Ooo003oooooooooooooooooo`0000?o
oooo0_oo0002ooooo`;oo`0003Ooooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
00;oo`000_ooool2ool000?ooooo00Coo`00oooooooooooooooo0_l0000Aooooo`004Oooool3o`00
00Cooooo0_l00004ooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`1=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0002Cooooo00ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00000_ooool2ool000?ooooo00?oo`00ooooooooool03Oooool01Ooo
003oooooooooooooooooo`0000?ooooo0_oo0002ooooo`;oo`0003Ooooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003ooooo00;oo`000_ooool2ool000?ooooo00?oo`00ooooooooool00_oo
ool00ol0003oooooooooo`0?ooooo`004_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo04gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`05ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`0Nooooo`0?ool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo0003ooooo`03ool00?oo
oooooooo00gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000_ooool0=_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool0
00?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`004_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0C_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool03oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`05ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo
00;oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0001_o
oooo013oo`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`000_ooool2ool000;ooooo0_oo000?ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000;ooooo03Koo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooool2ool000;ooooo0_oo0003ooooo`03ool00?oooooooooo00;ooooo00?o0000oooooooo
ool03oooool001;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`?o
0000C_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000oooooooo
ool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04cooooo0_l0000[ooooo`;o
00001_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000Kooooo`0@ool0
0?ooooooooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
00;ooooo0_oo0002ooooo`;oo`003oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00002ooooo`;oo`000_ooool0<_oo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002
ooooo`;oo`000_ooool00ooo003oooooooooo`02ooooo`;o00004Oooool001;ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04kooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool01?ooool00ooo003oooooool00002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00
ooooooooool00_oo0003ooooo`03ool00?oooooooooo00;oo`000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00;oo`000_ooool02Ooo003o
ooooool00?ooooooo`00oooooooo003oooooool00002ooooo`;oo`000_ooool2ool000?ooooo00?o
o`00ooooooooool02Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`0Zool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool00ooo003o
ooooooooo`03ooooo`03o`000?oooooooooo00oooooo000Aooooo`;o00001?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`1=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01?ooool00ooo003o
ooooool00002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo017ooooo00?oo`00ooooooooool00_oo0002ooooo`09ool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`09oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo02[oo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?o
0000ooooooooool03oooool001;ooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000
ooooooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000
ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`07ool00?ooooooo`00oooooooo003ooooo
ool00002ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000Cooooo`03ool00?oooooo
oooo00;oo`000_ooool02Ooo003oooooool00?ooooooo`00oooooooo003oooooool00002ooooo`;o
o`000_ooool2ool000?ooooo00?oo`00ooooooooool02Oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`0Zool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002
ooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo000Noooo
o`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>oooo
o`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1=oooo
o`03o`000?oooooooooo02Wooooo0_l00005ooooo`0;ool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo00000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0003ooooo`03ool00?oooooooooo00;oo`000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00gooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool01Ooo003oooooool00?oo
ooooo`0000;ooooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`09ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`0Vool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00;ooooo0_l0000Aooooo`007_ooool2
o`0004oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooo
oooo00oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1=ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool01?ooool02ooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`0000;ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00gooooo00?oo`00
ooooooooool00_oo0002ooooo`;oo`000_ooool02Ooo003oooooool00?ooooooo`00oooooooo003o
ooooool00002ooooo`;oo`000oooool00ooo003oooooooooo`09ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool08_oo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo
0002ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool03oooool001kooooo00?o0000
ooooooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000
ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`0;ool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00Wooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool02Ooo003oooooool00?oo
ooooo`00oooooooo003oooooool00002ooooo`;oo`000oooool01Ooo003oooooooooooooooooo`00
00Oooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool07_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0?
ooooo`007_ooool00ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0COooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Cooooo00_oo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00002ooooo`03ool00?oooooooooo00;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002oooo
o`09ool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo0003ooooo`05ool0
0?oooooooooooooooooo00001oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool06_oo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`03o`00
0?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`0;ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00000_ooool00ooo003oooooooooo`02
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002
ooooo`09ool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo0002ooooo`;o
o`000oooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool05_oo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00;ooooo0_l0000A
ooooo`007_ooool00ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0COooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Cooooo00coo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool02Ooo
003oooooool00?ooooooo`00oooooooo003oooooool00002ooooo`;oo`000_ooool2ool000?ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo00koo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
o`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0?oooo
o`007_ooool2o`0004oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03
o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1=ooooo`03
o`000?oooooooooo02;ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00coo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05
ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002oooo
o`;oo`000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`000oooool0
1Ooo003oooooooooooooooooo`0000;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`0>ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?o0000oooooooo
ool03oooool001kooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo04gooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00coo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo
003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooool00?oooooo
o`0000;ooooo0_oo0002ooooo`;oo`000oooool01Ooo003oooooooooooooooooo`0000;ooooo00?o
o`00ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool02_oo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`03ool00?oo
oooooooo00?ooooo00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0C_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool08Oooool0
1?l0003oooooooooool00004ooooo`Oo000000coo`00o`000?oo003o0000ool00?l0003oo`00o`00
0?oo003o0000ool00?l00002ool000;o00000_oo0002o`0000;oo`000_l00002ool000;o00000_oo
0002o`0000;oo`000_l00002ool000;o00000_oo0002o`0000;oo`000_l00002ool000;o00000_oo
0002o`0000;oo`000_l00002ool000;o00000_oo0002o`000005ool00?l0003o0000o`000?oo0000
1?l000000ooo003o0000o`000002ool000;o00000_oo0002o`0000;oo`000_l000001Ooo003o0000
ool00?l0003oo`0000;o00000_oo0002o`0000;oo`000_l00002ool000?o000000Coo`00o`000?l0
003oo`001?l000001Ooo003o0000o`000?l0003oo`0000?o000000?oo`00o`000?l000000_oo0002
o`0000;oo`000_l00002ool000;o00000_oo0002o`0000;oo`000_l00002ool000;o00000_oo0002
o`0000;oo`000_l00002ool000;o00000_oo0002o`0000;oo`000_l00002ool000;o00000_oo0002
o`000004ool00?l0003oo`00ool000;o00000_oo0002o`000003ool00?l0003o000000Co00004Ooo
ool001kooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo04gooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Cooooo00coo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00001?ooool01?oo003ooooo
oooooooo0003ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooo003oooooool00002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0003ooooo`04ool00?ooooooooooool000Cooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00004oooooooo
003oooooooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo
000Nooooo`;o0000Coooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o
0000ooooooooool08Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo
00coo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?ooooooo`00oooooooo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool01?oo003oooooooooooooool2ool000;ooooo00Goo`00oooooooo003ooooo
ool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0003ooooo`04ool00?ooooooooooool000Co
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
0006oooooooo003oooooool00?ooooooo`000_ooool00ooo003oooooooooo`03ooooo`03o`000?oo
oooooooo00oooooo000Nooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`1=ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`04ooooo`0<ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Co
ooooool00?ooooooo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooooooo0_oo0002
ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00?oo`00ooooooooool01_ooool01Ooo003oooooooooooooooooo`0000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`0000Koooooool00?ooooooo`00oooooooo0002ooooo`03ool00?oooooooooo
00?ooooo00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0C_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool03oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool08_ooool2o`0000Go
oooo0_l00005ooooo`0<ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
oooo0_oo0002ooooo`;oo`0000Soooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo
00002?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00Gooooo00Coo`00oooooooooooooooo0_oo
0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo00?oo`00ooooooooool01_ooool01Ooo003oooooooooooooooooo`0000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`0000Soooooool00?ooooooo`00oooooooo003oooooool000Gooooo0_l0
000Aooooo`007_ooool00ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000D?oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Cooooo00coo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo00002?ooooooo`00oooo
oooo003oooooool00?ooooooo`000_ooool2ool0000<oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool01Oooool01?oo003oooooooooooooool2ool000;ooooo00Woo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo
003oooooooooo`0:ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00008oooooooo003ooooo
ool00?ooooooo`00oooooooo0006ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oo
oooooooo04oooooo00Goo`00ooooooooooooooooool0000@ooooo`03o`000?oooooooooo00oooooo
00Goo`00ooooooooooooooooool0001@ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool01?ooool03?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;o
o`000_ooool2ool0000Hoooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool01Oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo0006ooooo`03o`000?oooooo
oooo00oooooo000Nooooo`;o0000D?ooool01Ooo003oooooooooooooooooo`00013ooooo00?o0000
ooooooooool03oooool01Ooo003oooooooooooooooooo`00053ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`0<ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003ooooo0_oo0002ooooo`;oo`0001Soooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`09ooooo`04
ool00?ooooooooooooooo`;oo`000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool03Oooool2ool000;ooooo0_oo0002
ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo0006ooooo`03o`000?oooooooooo
00oooooo000Nooooo`03o`000?oooooooooo04oooooo00Goo`00ooooooooooooooooool0000@oooo
o`03o`000?oooooooooo00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03o`000?oooooo
oooo02Wooooo0_l00005ooooo`0<ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003ooooo0_oo0002ooooo`;oo`0001Soooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`09ooooo`04ool0
0?ooooooooooooooo`;oo`000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool03Oooool01?oo003oooooooooooooool2
ool000;ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo00002?ooooooo`00oooooooo003oooooool00?ooooooo`001Oooool2
o`00017ooooo000Nooooo`03o`000?oooooooooo04oooooo00Goo`00ooooooooooooooooool0000@
ooooo`03o`000?oooooooooo00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool00oooool03Ooo003ooooooooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`0001Soooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?ooooooo`00
oooooooo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00Wooooo00Coo`00oooooooooooooooo0_oo0002ooooo`05ool00?oooooo
o`00oooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003ooooooooo
o`0Aooooo`05ool00?oooooooooooooooooo00000oooool01?oo003oooooooooooooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool01?oo003oooooooooooooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Soooooool00?ooooooo`00oooooooo
003oooooool000Kooooo00?o0000ooooooooool03oooool0017ooooo0ol00003ooooo`?o00001?oo
ool00ol0003oooooooooo`1?ooooo`05ool00?oooooooooooooooooo00004?ooool00ol0003ooooo
ooooo`0?ooooo`05ool00?oooooooooooooooooo0000D?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`06ool00?ooooooo`00oooo
oooo003ooooo0_oo00009?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo00001?ooooooo`00
oooooooo0002ooooo`;oo`000_ooool2ool00003oooooooo003oo`0000?ooooo00Goo`00oooooooo
ooooooooool0000;ooooo`04ool00?ooooooooooooooo`;oo`000_ooool01Ooo003oooooool00?oo
ooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool04Ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool00008oooooooo003oooooool00?ooooooo`00oooo
oooo0006ooooo`03o`000?oooooooooo00oooooo000Booooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo0000057ooooo00Goo`00ooooooooooooooooool0000@oooo
o`03o`000?oooooooooo00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002
ooooo`0dool00?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo00000oooooooo`00ool00003
ooooo`05ool00?oooooooooooooooooo00002oooool01?oo003oooooooooooooool2ool000;ooooo
00Goo`00oooooooo003oooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03
ool00?oooooooooo01Gooooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?oooooooooo
ooooo`;oo`000_ooool2ool000;ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00008oooooooo003oooooool00?oooooo
o`00oooooooo0006ooooo`03o`000?oooooooooo00oooooo000Booooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooooooo0ol0001?ooooo`05ool00?oooooooooooooooooo00004?ooool0
0ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000Coooool2o`0002_ooooo0_l0
0004ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0000<_ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`000_ooool2ool00003oooooooo003oo`0000?ooooo00Goo`00ooooooooooooooooool0
000?ooooo`;oo`000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool00003oooooooo003ooooo01_ooooo00Goo`00ooooooooooooooooool00003ooooo`04
ool00?ooooooooooooooo`;oo`000_ooool01?oo003oooooooooooooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Soooooool00?ooooooo`00oooo
oooo003oooooool000Gooooo0_l0000Aooooo`004_ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool00000DOooool01Ooo003oooooooooooooooooo`00013ooooo00?o0000oooo
ooooool03oooool01Ooo003oooooooooooooooooo`00053ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0000
<_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`000_ooool2ool00003oooooooo003oo`0000?ooooo00Goo`00oooo
ooooooooooooool0000?ooooo`;oo`000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool00003oooooooo003ooooo01_ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0000
2?ooooooo`00oooooooo003oooooool00?ooooooo`001_ooool00ol0003oooooooooo`0?ooooo`00
4_ooool01?l0003oooooooooooooool4o`0000Cooooo00?o0000ooooooooool0Coooool01?oo003o
oooooooooooo000Aooooo`03o`000?oooooooooo00oooooo00Goo`00ooooooooooooooooool0001@
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02
ool000;ooooo0_oo0002ooooo`;oo`0003;oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo00000ooo
ooooo`00ool00002ooooo`;oo`000oooool00ooo003oooooooooo`0=ooooo`;oo`000_ooool01Ooo
003oooooool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00003oooooooo003o
oooo01oooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooooooo0_oo0002oooo
o`;oo`000_ooool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo0006ooooo`03o`00
0?oooooooooo00oooooo000Aooooo`;o00000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04oooooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0?ooooo`05ool0
0?oooooooooooooooooo0000D?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?o
oooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool00005oooooooo003oooooool0
0?ooool00_oo0002ooooo`0^ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000?ooooo00?oo`00ooooooooool03Ooo
ool2ool000;ooooo00Woo`00oooooooo003oooooool00?ooooooo`00oooooooo00000_ooool2ool0
00;ooooo0_oo00000oooooooo`00ooooo`0Sooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool0
0?ooooooooooooooo`;oo`000_ooool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo
0006ooooo`03o`000?oooooooooo00oooooo000Booooo`04o`000?ooooooooooooooo`Go00000ooo
ool00ol0003oooooooooo`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool0
3oooool01Ooo003oooooooooooooooooo`00053ooooo00?o0000ooooooooool0:Oooool2o`0000Co
oooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool00005oooooooo003oooooool0
0?ooool00_oo0002ooooo`;oo`000_ooool0:_oo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool03_ooool03Ooo
003oooooooooooooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00000_ooool2ool0
00;ooooo0_oo00000oooooooo`00ooooo`0Sooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo
0005ooooo`;o00004Oooool001kooooo0_l0001@ooooo`04ool00?ooooooooooool0017ooooo00?o
0000ooooooooool03oooool01Ooo003oooooooooooooooooo`00053ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo
0_oo00001Oooooooo`00oooooooo003ooooo00;oo`000_ooool2ool000;ooooo02[oo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`03
ool00?oooooooooo00kooooo00goo`00ooooooooooooooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?ooool09oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Ooo`00oooooooo003o
ooooool00?ooooooo`0000Kooooo00?o0000ooooooooool03oooool001kooooo00?o0000oooooooo
ool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo00oooooo00Goo`00oooo
ooooooooooooool0001@ooooo`03o`000?oooooooooo027ooooo0ol00005ooooo`03o`000?oooooo
oooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool00003oooooooo003o
o`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`0Rool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool03_ooool01?oo003ooooooooo
ooooool2ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`;oo`000_ooool2ool00003
oooooooo003ooooo02_ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
0002ooooo`03ool00?ooooooo`0000Kooooo00?o0000ooooooooool03oooool001kooooo00?o0000
ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo00oooooo00Go
o`00ooooooooooooooooool0001@ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo
0_oo00000oooooooo`00ool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool08_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00ko
oooo00Coo`00oooooooooooooooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2
ool000;ooooo0_oo00000oooooooo`00ooooo`0[ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;oo`000_ooool2ool000Oooooo00?o0000ooooooooool03oooool001kooooo
00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo00oo
oooo00Goo`00ooooooooooooooooool0001@ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01?ooool2o`0000Cooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool0
0003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool07_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool03_ooool01?oo003o
ooooooooooooool2ool000;ooooo00Woo`00oooooooo003oooooool00?ooooooo`00oooooooo0000
0_ooool2ool00003oooooooo003ooooo02oooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002
ooooo`;oo`001_ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo04oooooo00Coo`00oooo
ooooooooo`004Oooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000D?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo00000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo01Koo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_oo
ool00ooo003oooooooooo`0Booooo`;oo`000_ooool02Ooo003oooooool00?ooooooo`00oooooooo
003oooooool00002ooooo`;oo`0000?oooooool00?ooool0<oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;oo`000_oo
ool2ool000Oooooo00?o0000ooooooooool03oooool001kooooo0_l0001@ooooo`04ool00?oooooo
ooooool0017ooooo00?o0000ooooooooool03oooool01Ooo003oooooooooooooooooo`00053ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00Coo`00ooooooooooooo`000oooool2ool000;ooooo0_oo00000oooooooo`00ool00002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo01;oo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`03ool00?oo
oooooooo01;ooooo0_oo0002ooooo`09ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
00;ooooo0_oo00000oooooooo`00ooooo`0cooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`001ooo
ool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`1?ooooo`04ool00?oooooo
ooooool0017ooooo00?o0000ooooooooool03oooool01Ooo003oooooooooooooooooo`00053ooooo
00?o0000ooooooooool08Oooool2o`0000Kooooo00?o0000ooooooooool00oooool01?oo003ooooo
oooooooo0003ooooo`;oo`000_ooool2ool00003oooooooo003oo`0000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo00koo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool04_ooool2ool0
00;ooooo00Woo`00oooooooo003oooooool00?ooooooo`00oooooooo00000_ooool2ool00003oooo
oooo003ooooo03Oooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000_ooool2ool000;ooooo0_oo0007ooooo`03o`000?oooooooooo00oooooo000Nooooo`03
o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0?oooo
o`05ool00?oooooooooooooooooo0000D?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Cooooo0_l00004ooooo`04ool00?ooooooooooool000?ooooo0_oo0002ooooo`;oo`0000?o
ooooool00?oo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00[o
o`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool0
0ooo003oooooooooo`0Booooo`;oo`000_ooool02Ooo003oooooool00?ooooooo`00oooooooo003o
ooooool00002ooooo`;oo`0000?oooooool00?ooool0>oooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`001_ooool2o`00017ooooo000Nooooo`03
o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0?oooo
o`05ool00?oooooooooooooooooo0000D?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`;oo`000_ooool2ool00003oooooooo
003oo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`0:ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00
ooooooooool04_ooool2ool000;ooooo00ooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo0000@?ooool01Ooo003oooooooooooooooooo`0000;ooooo
0_oo0002ooooo`;oo`001oooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003ooooooooo
o`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool03oooool01Ooo003ooooo
ooooooooooooo`00053ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool01?oo003oooooooooooooool2ool00003oooooooo003o
o`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`0:ool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00oooo
ooooool04_ooool2ool000;ooooo00ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo0000@?ooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo
0002ooooo`;oo`001oooool00ol0003oooooooooo`0?ooooo`007_ooool2o`00053ooooo00Coo`00
ooooooooooooo`004Oooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000
D?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`04ool00?ooooooooooooooo`;oo`0000?oooooool00?oo00000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01?oo
003oooooool00?oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0Booooo`;oo`000_ooool0
3ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0014ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000Oooooo00?o0000ooooooooool03ooo
ool001kooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oo
oooooooo00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03o`000?oooooooooo02Wooooo
0_l00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool01?oo003oooooool00?oo0002ooooo`03ool00?oooooo
oooo01;ooooo013oo`00ooooooooooooooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003ooooo0_oo0015ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000Kooooo
0_l0000Aooooo`007_ooool00ol0003oooooooooo`1?ooooo`04ool00?ooooooooooool0017ooooo
00?o0000ooooooooool03oooool01Ooo003oooooooooooooooooo`00053ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00005oooooooo003o
oooooooooooo00005?ooool01?oo003oooooooooooooool2ool000;ooooo00Soo`00oooooooo003o
ooooool00?ooooooo`00ooooo`;oo`00B?ooool01Ooo003oooooooooooooooooo`0000Sooooo00?o
0000ooooooooool03oooool001kooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo
000Aooooo`03o`000?oooooooooo00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001Ooo
ooooo`00ooooooooooooo`0001Cooooo00Coo`00oooooooooooooooo0_oo0002ooooo`08ool00?oo
ooooo`00oooooooo003oooooool00?ooool2ool004cooooo00?oo`00ooooooooool01_ooool00ol0
003oooooooooo`0?ooooo`007_ooool2o`00053ooooo00Coo`00ooooooooooooo`004Oooool00ol0
003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000D?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000_ooool2ool000;ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001Ooooooo
o`00ooooooooooooo`0001Cooooo00Coo`00oooooooooooooooo0_oo0002ooooo`08ool00?oooooo
o`00oooooooo003oooooool00?ooool2ool005Gooooo00?o0000ooooooooool03oooool001kooooo
00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo00oo
oooo00Goo`00ooooooooooooooooool0001@ooooo`03o`000?oooooooooo02Wooooo0_l00003oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo
0002ooooo`05ool00?oooooooooooooooooo00000oooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`005Oooool01?oo003o
ooooooooooooool2ool000;ooooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`00
E?ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`00
4Oooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000D?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00
oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Co
ooooool00?ooooooo`005Oooool01?l0003oooooooooooooool2ool000;ooooo00Soo`00oooooooo
003oooooool00?ooooooo`00ooooo`;oo`00EOooool00ol0003oooooooooo`0?ooooo`004?ooool5
o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Ooo
ool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool00004oooooooo003oooooool001Gooooo00Co0000
oooooooooooooooo0_oo0002ooooo`08ool00?ooooooo`00oooooooo003oooooool00?ooool2ool0
05Gooooo00?o0000ooooooooool03oooool0017ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Ooo
ool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00;oo`000_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?oooooooooooooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo00001?ooooooo`00oooooooo000Eooooo`04o`000?oooooo
ooooooooo`;oo`000_ooool2ool000;ooooo00Coo`00oooooooo003ooooo0_oo001Eooooo`03o`00
0?oooooooooo00oooooo000Booooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0oooool3o`0004oooooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0@ooooo`03
ool00?ooooooo`00053ooooo0_l0000[ooooo`;o00003oooool00ooo003oooooooooo`02ool000;o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`00
5Oooool01?l0003oooooooooooooool2ool000;ooooo0_oo0002ooooo`04ool00?ooooooo`00oooo
o`;oo`00E?ooool2o`00017ooooo000Cooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo0000057ooooo00Coo`00ooooooooooooo`004Oooool00ol0003ooooooooo
o`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Aooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool0
1?oo003oooooooooooooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`0000Coooooool00?ooooooo`005Oooool01?l0003oooooooooooooool2ool000;o
oooo0_oo0002ooooo`04ool00?ooooooo`00ooooo`;oo`00EOooool00ol0003oooooooooo`0?oooo
o`004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool04?oo
ool00ooo003oooooool0001Aooooo`03o`000?oooooooooo023ooooo1Ol00004ooooo`03o`000?oo
oooooooo01Gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool00004oooooooo003oooooool001Gooooo00Co0000oooooooooooooooo0_oo0002ooooo`;o
o`000_ooool01?oo003oooooool00?ooool2ool005Gooooo00?o0000ooooooooool03oooool0013o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo00?o
o`00oooooooo0000DOooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool05Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`005Oooool01Ol0003oooooooooooooooooo`00
00?ooooo0_oo0002ooooo`;oo`000_ooool2ool005Gooooo00?o0000ooooooooool03oooool0017o
oooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`04ool00?ooooooooooool0
017ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01?ooool2o`0001[ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`005Oooool01Ol0003ooooooooooooo
ooooo`0000?ooooo0_oo0002ooooo`;oo`000_ooool2ool005Cooooo0_l0000Aooooo`007_ooool2
o`00053ooooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0@ooooo`03ool00?oo
ooooo`00057ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`005Ooo
ool01Ol0003oooooooooooooooooo`0000?ooooo0_oo0002ooooo`;oo`000_ooool2ool005Gooooo
00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0Coooool01?oo003ooooooooo
oooo000Aooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003ooooo
ooooo`0Pooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Qooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool2ool000;ooooo
0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`005Oooool01Ol0003oooooooooooooooooo`00
00?ooooo0_oo0002ooooo`;oo`000_ooool2ool005Gooooo00?o0000ooooooooool03oooool001ko
oooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo
013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Pooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0Qooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool01?oo003oooooooooooooool2ool000;ooooo0_oo0000
1?ooooooo`00oooooooo000Eooooo`05o`000?oooooooooooooooooo00000oooool2ool000;ooooo
0_oo0002ooooo`;oo`00EOooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003ooooooooo
o`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool04?ooool00ooo003ooooo
ool0001Aooooo`03o`000?oooooooooo027ooooo0ol00005ooooo`;o00009_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooooooo
0_oo00001?ooooooo`00oooooooo000Eooooo`05o`000?oooooooooooooooooo00000oooool2ool0
00;ooooo0_oo0002ooooo`;oo`00E?ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo04oo
oooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00
057ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool01_oo003ooooooooooooo003ooooo
ool001Gooooo00?o0000ooooooooool01Oooool2ool000;ooooo0_oo0002ooooo`;oo`00EOooool0
0ol0003oooooooooo`0?ooooo`007_ooool2o`00053ooooo00?oo`00oooooooo00004_ooool00ol0
003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0]ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000_ooool00ooo003oooooool0000Eooooo`03o`000?oooooooooo00Gooooo00Coo`00oooooooo
oooooooo0_oo0002ooooo`;oo`00EOooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003o
ooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0]ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool001Kooooo00?o0000ooooooooool0
1Oooool01?oo003oooooooooooooool2ool000;ooooo0_oo001Eooooo`03o`000?oooooooooo00oo
oooo000Nooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo
00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Yooooo`;o0000<_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ool001Kooooo00?o0000ooooooooool01Oooool0
1?oo003oooooooooooooool2ool000;ooooo0_oo001Dooooo`;o00004Oooool001kooooo00?o0000
ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001A
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<Oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`02ool001Kooooo00?o0000ooooooooool01Oooool01?oo003o
ooooooooooooool2ool000;ooooo0_oo001Eooooo`03o`000?oooooooooo00oooooo000Nooooo`03
o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo
0000DOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000;ooooo0_oo000Fooooo`03o`000?oooooooooo00Gooooo00Coo`00oooooooooooooooo
0_oo0002ooooo`;oo`00EOooool00ol0003oooooooooo`0?ooooo`007_ooool2o`00057ooooo0_oo
000Booooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo03Wooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool001Kooooo00?o0000oooooooo
ool01Oooool01Ooo003oooooooooooooooooo`0000?ooooo0_oo001Eooooo`03o`000?oooooooooo
00oooooo000Nooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013o
oooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Yooooo`;o0000>_ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00;oo`005_ooool00ol0003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00000ooo
ool2ool005Cooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool0
0ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0mooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000;ooooo0_oo000Fooooo`03o`000?oooooooooo00Wooooo00Coo`00oooooooooooo
oooo0_oo001Eooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo053ooooo
0_oo000Booooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo047ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;oo`005_ooool00ol0003oooooooooo`09ooooo`05ool00?oooooooooooooo
oooo0000E_ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`1@ooooo`;o
o`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`11ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`02ool001Kooooo00?o0000ooooooooool02Oooool01Ooo003ooooooooooooooooo
o`0005Kooooo00?o0000ooooooooool03oooool001kooooo0_l0001Aooooo`;oo`004_ooool00ol0
003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0:Oooool2o`00
04Kooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`005_ooool00ol0003oooooooooo`09
ooooo`05ool00?oooooooooooooooooo0000EOooool2o`00017ooooo000Nooooo`03o`000?oooooo
oooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04Gooooo00Goo`00ooooooooooooooooool0
0002ooooo`;oo`005_ooool00ol0003oooooooooo`09ooooo`05ool00?oooooooooooooooooo0000
E_ooool00ol0003oooooooooo`0?ooooo`004?ooool5o`0000;ooooo0ol00004ooooo`03o`000?oo
oooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo017ooooo0_oo001Aooooo`03o`000?oo
oooooooo027ooooo0ol00005ooooo`03o`000?oooooooooo04Wooooo00?oo`00ooooooooool00_oo
000Fooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0E?ooool00ol0003ooooooooo
o`0?ooooo`004Oooool01_l0003oooooooooool0003oooooo`0000?ooooo00Go0000oooooooooooo
ooooo`00001Booooo`;oo`004_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo053o
oooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0BOooool00ooo003oooooooooo`02ool001Kooooo00?o0000ooooooooool03Oooool00ooo
003oooooooooo`1Dooooo`03o`000?oooooooooo00oooooo000Booooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooooooo0ol0001@ooooo`;oo`004_ooool00ol0003oooooooooo`0Aoooo
o`03ool00?oooooooooo04oooooo0_l0000Vooooo`03o`000?oooooooooo00;ooooo0_l0001=oooo
o`;oo`005_ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo05?ooooo0_l0000Aoooo
o`004oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000Doooool00ooo
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0D?ooool00ol0
003oooooooooo`0Rooooo`;o00001Oooool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo
01Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0?ooooo`004?ooool01_l0003o
oooooooooooooooo0000ooooo`Co00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0?ooooo`004?ooool01ol0
003ooooooooooooooooo0000ooooool000001oooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00008_ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`00017ooooo000Aooooo`?o00000_ooool5o`0000?ooooocol0000Sooooo`?o00001Oooooo?
o`00017ooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 503}, {147.312, 0}} -> {-0.0551454, -0.0147182, \
0.00419541, 0.00419541}, {{13.125, 240.125}, {143.75, 3.5}} -> {-4.28574, \
-3.74986, 0.0320189, 0.206369}, {{262.812, 489.812}, {143.75, 3.5}} -> \
{-12.258, -3.92367, 0.0319601, 0.049699}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot DTFT as a function of frequency", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g1 = 
        Plot[Abs[
            X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
              2, fs/2}, \ PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[Arg[
            X\[Theta] /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/2, 
            fs/2}, \ PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.0235176 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1323 -6 -4.5 ]
[-0.0125 .1323 0 4.5 ]
[-0.0125 .24989 -12 -4.5 ]
[-0.0125 .24989 0 4.5 ]
[-0.0125 .36748 -12 -4.5 ]
[-0.0125 .36748 0 4.5 ]
[-0.0125 .48507 -12 -4.5 ]
[-0.0125 .48507 0 4.5 ]
[-0.0125 .60265 -12 -4.5 ]
[-0.0125 .60265 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1323 m
.00625 .1323 L
s
[(5)] -0.0125 .1323 1 0 Mshowa
0 .24989 m
.00625 .24989 L
s
[(10)] -0.0125 .24989 1 0 Mshowa
0 .36748 m
.00625 .36748 L
s
[(15)] -0.0125 .36748 1 0 Mshowa
0 .48507 m
.00625 .48507 L
s
[(20)] -0.0125 .48507 1 0 Mshowa
0 .60265 m
.00625 .60265 L
s
[(25)] -0.0125 .60265 1 0 Mshowa
.125 Mabswid
0 .03823 m
.00375 .03823 L
s
0 .06175 m
.00375 .06175 L
s
0 .08527 m
.00375 .08527 L
s
0 .10879 m
.00375 .10879 L
s
0 .15582 m
.00375 .15582 L
s
0 .17934 m
.00375 .17934 L
s
0 .20286 m
.00375 .20286 L
s
0 .22637 m
.00375 .22637 L
s
0 .27341 m
.00375 .27341 L
s
0 .29693 m
.00375 .29693 L
s
0 .32044 m
.00375 .32044 L
s
0 .34396 m
.00375 .34396 L
s
0 .391 m
.00375 .391 L
s
0 .41451 m
.00375 .41451 L
s
0 .43803 m
.00375 .43803 L
s
0 .46155 m
.00375 .46155 L
s
0 .50858 m
.00375 .50858 L
s
0 .5321 m
.00375 .5321 L
s
0 .55562 m
.00375 .55562 L
s
0 .57914 m
.00375 .57914 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1323 m
1 .1323 L
s
.99375 .24989 m
1 .24989 L
s
.99375 .36748 m
1 .36748 L
s
.99375 .48507 m
1 .48507 L
s
.99375 .60265 m
1 .60265 L
s
.125 Mabswid
.99625 .03823 m
1 .03823 L
s
.99625 .06175 m
1 .06175 L
s
.99625 .08527 m
1 .08527 L
s
.99625 .10879 m
1 .10879 L
s
.99625 .15582 m
1 .15582 L
s
.99625 .17934 m
1 .17934 L
s
.99625 .20286 m
1 .20286 L
s
.99625 .22637 m
1 .22637 L
s
.99625 .27341 m
1 .27341 L
s
.99625 .29693 m
1 .29693 L
s
.99625 .32044 m
1 .32044 L
s
.99625 .34396 m
1 .34396 L
s
.99625 .391 m
1 .391 L
s
.99625 .41451 m
1 .41451 L
s
.99625 .43803 m
1 .43803 L
s
.99625 .46155 m
1 .46155 L
s
.99625 .50858 m
1 .50858 L
s
.99625 .5321 m
1 .5321 L
s
.99625 .55562 m
1 .55562 L
s
.99625 .57914 m
1 .57914 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02608 .02331 L
.02847 .03106 L
.02972 .03419 L
.03089 .03636 L
.03124 .03685 L
.03157 .03725 L
.03186 .03755 L
.03218 .03782 L
.03234 .03793 L
.03252 .03803 L
.03269 .03811 L
.03284 .03817 L
.03292 .03819 L
.03301 .03821 L
.03311 .03823 L
.03321 .03824 L
.03329 .03825 L
.03338 .03825 L
.03347 .03824 L
.03355 .03823 L
.0337 .03821 L
.03383 .03817 L
.03398 .03812 L
.03414 .03804 L
.03446 .03784 L
.03476 .0376 L
.03533 .03699 L
.03587 .03622 L
.03707 .03392 L
.03838 .03056 L
.04072 .02285 L
.04196 .01818 L
.0423 .01687 L
.04249 .01615 L
.04266 .01548 L
.04281 .0149 L
.04297 .01514 L
.04306 .01549 L
.04314 .01582 L
.0433 .01644 L
.04574 .02553 L
.04804 .03252 L
.04921 .03518 L
.04985 .03631 L
.05045 .03716 L
.05096 .0377 L
.05125 .03794 L
.05151 .03811 L
.05165 .03818 L
Mistroke
.0518 .03825 L
.05188 .03828 L
.05196 .0383 L
.05211 .03833 L
.05225 .03835 L
.0524 .03836 L
.05254 .03835 L
.05268 .03834 L
.05283 .0383 L
.05297 .03825 L
.05324 .03813 L
.05354 .03794 L
.05385 .03768 L
.05442 .03705 L
.05495 .03629 L
.05616 .03394 L
.05744 .03062 L
.05982 .0227 L
.06087 .01876 L
.06142 .01662 L
.06157 .01601 L
.06172 .01542 L
.06186 .0149 L
.062 .0151 L
.06215 .01569 L
.06231 .01631 L
.06259 .01741 L
.06314 .01954 L
.06434 .02402 L
.06556 .02819 L
.06686 .03208 L
.0681 .03503 L
.06922 .037 L
.06977 .03768 L
.07005 .03796 L
.07036 .03821 L
.07062 .03837 L
.07077 .03844 L
.07092 .0385 L
.07106 .03854 L
.07118 .03857 L
.07131 .03859 L
.07143 .03859 L
.07158 .03859 L
.07167 .03858 L
.07174 .03856 L
.07189 .03853 L
.07204 .03848 L
.0723 .03836 L
.07258 .03818 L
Mistroke
.07289 .03792 L
.07322 .03759 L
.07381 .03681 L
.07497 .03468 L
.07603 .0321 L
.07832 .02481 L
.07963 .01991 L
.08025 .0175 L
.08052 .01643 L
.08067 .01582 L
.08082 .01525 L
.08096 .01473 L
.0811 .01531 L
.08141 .01651 L
.08204 .01901 L
.08319 .02341 L
.08572 .0318 L
.08695 .0349 L
.0876 .03621 L
.08829 .03734 L
.08889 .03808 L
.08923 .03841 L
.08955 .03864 L
.08969 .03873 L
.08984 .0388 L
.08997 .03885 L
.09011 .03889 L
.09026 .03893 L
.0904 .03894 L
.09048 .03895 L
.09056 .03895 L
.09071 .03893 L
.09085 .03891 L
.091 .03887 L
.09114 .03882 L
.09127 .03876 L
.09159 .03857 L
.09189 .03833 L
.09248 .03768 L
.09313 .03672 L
.09428 .03439 L
.09535 .0316 L
.09763 .02402 L
.09882 .01943 L
.09947 .01683 L
.09964 .01617 L
.09979 .01555 L
.09993 .01499 L
.10008 .01505 L
.10016 .01536 L
Mistroke
.10024 .0157 L
.10039 .0163 L
.10073 .01764 L
.10143 .02045 L
.10267 .02518 L
.10384 .02926 L
.10511 .03306 L
.10634 .03602 L
.10692 .03712 L
.10746 .03796 L
.108 .03862 L
.10829 .03889 L
.10859 .03912 L
.10873 .0392 L
.10888 .03928 L
.10902 .03934 L
.10916 .03938 L
.10928 .03941 L
.10942 .03943 L
.10955 .03944 L
.10967 .03943 L
.10982 .03942 L
.1099 .0394 L
.10998 .03938 L
.11013 .03933 L
.11027 .03927 L
.11059 .03909 L
.11093 .03882 L
.11155 .03813 L
.11212 .03727 L
.11321 .0351 L
.11436 .03209 L
.11677 .02389 L
.11781 .01976 L
.11837 .01751 L
.11867 .01627 L
.11882 .01566 L
.11895 .01511 L
.1191 .01492 L
.11925 .01557 L
.11959 .01693 L
.12017 .01932 L
.12132 .02389 L
.12263 .02871 L
.12384 .03262 L
.12505 .0358 L
.12614 .03797 L
.12676 .03889 L
.12735 .03952 L
.12767 .03976 L
Mistroke
.12797 .03993 L
.12812 .03999 L
.12821 .04002 L
.12829 .04004 L
.12838 .04006 L
.12847 .04007 L
.12856 .04007 L
.12864 .04008 L
.12877 .04007 L
.12892 .04005 L
.12906 .04001 L
.12919 .03997 L
.12933 .0399 L
.12949 .03982 L
.1298 .0396 L
.13011 .03932 L
.13045 .03894 L
.13104 .03809 L
.13221 .03577 L
.13326 .03298 L
.13558 .02504 L
.13678 .02025 L
.13741 .01761 L
.13776 .01614 L
.13793 .01541 L
.13809 .01473 L
.13824 .01534 L
.1384 .01602 L
.13874 .01745 L
.13933 .01994 L
.14049 .02467 L
.14171 .02927 L
.14303 .03359 L
.14425 .03682 L
.14479 .03797 L
.14538 .03901 L
.14593 .0398 L
.14645 .04034 L
.14673 .04056 L
.14699 .04072 L
.14714 .04078 L
.14729 .04083 L
.14744 .04086 L
.14758 .04088 L
.14773 .04089 L
.14787 .04087 L
.148 .04085 L
.14814 .04081 L
.14829 .04075 L
.14845 .04068 L
Mistroke
.14874 .04049 L
.14904 .04023 L
.14932 .03994 L
.14984 .03925 L
.15046 .03819 L
.15103 .03698 L
.15233 .03355 L
.1546 .02553 L
.1559 .02013 L
.15652 .01746 L
.15679 .01627 L
.15694 .01559 L
.15709 .01495 L
.15722 .01507 L
.15737 .01571 L
.15767 .01702 L
.1583 .01977 L
.15944 .02462 L
.16065 .02937 L
.16196 .03393 L
.16313 .03724 L
.16378 .03871 L
.16438 .03986 L
.16471 .04039 L
.16507 .04087 L
.16537 .0412 L
.1657 .04149 L
.16601 .0417 L
.16618 .04178 L
.16634 .04183 L
.16649 .04187 L
.16662 .04189 L
.16678 .04189 L
.16693 .04188 L
.16708 .04185 L
.16716 .04183 L
.16724 .0418 L
.16738 .04175 L
.16754 .04166 L
.1678 .04148 L
.16809 .04123 L
.16873 .04046 L
.16932 .03947 L
.17039 .0371 L
.17154 .03378 L
.17394 .02475 L
.1752 .01923 L
.17583 .01635 L
.17601 .01555 L
.1761 .01511 L
Mistroke
.1762 .01474 L
.17628 .01513 L
.17637 .01555 L
.17654 .0163 L
.17904 .02737 L
.18135 .03585 L
.18259 .03926 L
.18318 .04052 L
.18372 .04148 L
.18434 .04232 L
.18467 .04265 L
.18484 .04278 L
.18502 .0429 L
.18518 .04299 L
.18532 .04305 L
.18547 .0431 L
.18561 .04313 L
.18568 .04314 L
.18577 .04314 L
.18591 .04314 L
.18607 .04312 L
.18616 .0431 L
.18625 .04307 L
.18639 .04301 L
.18654 .04294 L
.18681 .04275 L
.18714 .04246 L
.18743 .04213 L
.18807 .04118 L
.18868 .04 L
.18975 .03731 L
.19091 .03358 L
.19326 .02402 L
.1939 .02107 L
.19459 .01781 L
.19493 .01621 L
.19509 .01541 L
.19525 .01475 L
.19538 .01542 L
.19553 .01612 L
.19584 .01762 L
.19812 .02819 L
.20059 .03759 L
.20125 .03953 L
.20194 .04127 L
.20258 .04258 L
.20318 .04353 L
.20346 .04389 L
.20374 .04417 L
.20389 .04429 L
Mistroke
.20405 .04441 L
.2042 .0445 L
.20434 .04457 L
.20449 .04463 L
.20457 .04465 L
.20466 .04467 L
.20474 .04468 L
.20484 .04469 L
.20491 .04469 L
.205 .04468 L
.20515 .04466 L
.20524 .04463 L
.20532 .04461 L
.20547 .04454 L
.20561 .04447 L
.2059 .04426 L
.20617 .044 L
.20678 .04321 L
.20738 .04214 L
.20803 .0407 L
.20919 .03735 L
.21025 .03353 L
.21146 .02847 L
.21274 .02245 L
.21337 .01936 L
.21367 .01782 L
.21395 .0164 L
.21409 .01572 L
.21421 .01509 L
.21434 .01499 L
.21448 .01571 L
.21505 .01861 L
.21742 .03015 L
.21967 .03909 L
.22085 .04258 L
.22151 .04411 L
.22213 .04521 L
.22265 .04589 L
.22294 .04618 L
.22322 .04638 L
.22336 .04647 L
.22351 .04653 L
.22363 .04657 L
.22377 .0466 L
.22392 .04661 L
.22401 .04661 L
.22408 .0466 L
.22423 .04657 L
.22437 .04653 L
.22451 .04647 L
Mistroke
.22466 .04639 L
.22493 .04619 L
.22525 .04586 L
.22555 .04549 L
.22618 .04444 L
.22679 .04313 L
.22786 .04012 L
.22902 .03594 L
.23136 .02522 L
.232 .02191 L
.23269 .01823 L
.233 .01651 L
.23318 .01557 L
.23326 .01511 L
.23334 .01474 L
.23348 .01549 L
.23362 .0163 L
.23394 .018 L
.2364 .0309 L
.23867 .04071 L
.23979 .04436 L
.24037 .04585 L
.24098 .04714 L
.24131 .04769 L
.2416 .04811 L
.2419 .04846 L
.24218 .04871 L
.24233 .04882 L
.2425 .04891 L
.2426 .04895 L
.24269 .04898 L
.24277 .049 L
.24285 .04902 L
.24293 .04903 L
.24301 .04903 L
.2431 .04902 L
.24319 .04901 L
.24333 .04898 L
.24349 .04892 L
.24364 .04884 L
.2438 .04874 L
.24413 .04844 L
.24444 .04808 L
.24472 .04766 L
.24537 .04646 L
.24606 .04475 L
.24733 .0406 L
.24849 .03577 L
.24969 .0299 L
.25097 .02293 L
Mistroke
.25159 .01936 L
.25189 .01758 L
.25203 .0168 L
.25217 .01593 L
.25231 .01515 L
.25243 .015 L
.25256 .01577 L
.2527 .0166 L
.25327 .01996 L
.25547 .03242 L
.25787 .04357 L
.25852 .0459 L
.2592 .04801 L
.25983 .04959 L
.26043 .05075 L
.2607 .05116 L
.26098 .05151 L
.26113 .05166 L
.2613 .05181 L
.26144 .05191 L
.26158 .05199 L
.26166 .05203 L
.26175 .05207 L
.2619 .05211 L
.26199 .05212 L
.26208 .05212 L
.26216 .05212 L
.26224 .05211 L
.26239 .05207 L
.26248 .05204 L
.26256 .05201 L
.26271 .05192 L
.26286 .05182 L
.26317 .05153 L
.26346 .05116 L
.26401 .05024 L
.26461 .04892 L
.26525 .04711 L
.2664 .04292 L
.26746 .03811 L
.26865 .03181 L
.26993 .02426 L
.27055 .02038 L
.27085 .01844 L
.27113 .01664 L
.27126 .01579 L
.27139 .01499 L
.27151 .01528 L
.27166 .0162 L
.27223 .0199 L
Mistroke
.27446 .03386 L
.27681 .04609 L
.27797 .05063 L
.27859 .05252 L
.27924 .05413 L
.27956 .05474 L
.27985 .05522 L
.28014 .05559 L
.2804 .05586 L
.28065 .05604 L
.28078 .0561 L
.28092 .05615 L
.28106 .05618 L
.28121 .05619 L
.28135 .05617 L
.28148 .05613 L
.28163 .05607 L
.28178 .05598 L
.28205 .05575 L
.28235 .0554 L
.28267 .05492 L
.28324 .05377 L
.28377 .05239 L
.28499 .04811 L
.28627 .04207 L
.28868 .02743 L
.28972 .02013 L
.29001 .01808 L
.29017 .01694 L
.29032 .01588 L
.29044 .01497 L
.29058 .01544 L
.29073 .01652 L
.29086 .01752 L
.29207 .02629 L
.29322 .0343 L
.29453 .04272 L
.29575 .04952 L
.29695 .05496 L
.29803 .05861 L
.29833 .05938 L
.29866 .06009 L
.29894 .0606 L
.29924 .06106 L
.29957 .06142 L
.29975 .06155 L
.29983 .06161 L
.29991 .06165 L
.30007 .0617 L
.30021 .06172 L
Mistroke
.30037 .06172 L
.30045 .0617 L
.30053 .06168 L
.30067 .06162 L
.30082 .06153 L
.30095 .06143 L
.30109 .06129 L
.3014 .0609 L
.30169 .06043 L
.30222 .05929 L
.30278 .0577 L
.30408 .05256 L
.30527 .04628 L
.30648 .03843 L
.30777 .0289 L
.30887 .02009 L
.30918 .01761 L
.30934 .01623 L
.3095 .01491 L
.30965 .01574 L
.30973 .01643 L
.30981 .01707 L
.31009 .01941 L
.31247 .03894 L
.31472 .05464 L
.31591 .0611 L
.31654 .06385 L
.3172 .0662 L
.31776 .06774 L
.31808 .06842 L
.31837 .06892 L
.31864 .06928 L
.31877 .06941 L
.31889 .06951 L
.31903 .06959 L
.31918 .06966 L
.31931 .06968 L
.31945 .06969 L
.31958 .06966 L
.31973 .0696 L
.31989 .0695 L
.32004 .06937 L
.3203 .06907 L
.32058 .06863 L
.32091 .06796 L
.32122 .06718 L
.3218 .06535 L
.32286 .06076 L
.324 .05409 L
.32636 .03577 L
Mistroke
.3276 .0242 L
.32796 .02072 L
.3283 .01737 L
.32845 .0159 L
.32861 .01509 L
.32869 .01591 L
.32878 .01682 L
.32894 .01842 L
.3314 .04269 L
.3337 .06247 L
.33491 .07071 L
.33603 .0765 L
.33661 .07877 L
.33725 .0806 L
.33757 .08126 L
.33775 .08155 L
.33792 .08176 L
.33808 .08192 L
.33816 .08198 L
.33825 .08204 L
.3384 .0821 L
.33854 .08212 L
.33869 .08211 L
.33885 .08205 L
.339 .08194 L
.33913 .08181 L
.3394 .08147 L
.33968 .08096 L
.34001 .08017 L
.34032 .07925 L
.3409 .07705 L
.34196 .07147 L
.3431 .0633 L
.34546 .04051 L
.34671 .02596 L
.34707 .02155 L
.34725 .01936 L
.34741 .01732 L
.34756 .01546 L
.34772 .01596 L
.34788 .01796 L
.34805 .02018 L
.35051 .05138 L
.35281 .07727 L
.35395 .08764 L
.35515 .09617 L
.35577 .09953 L
.3561 .10096 L
.35646 .10223 L
.35679 .10315 L
Mistroke
.35708 .10377 L
.35723 .104 L
.35738 .10419 L
.35753 .10431 L
.35766 .10439 L
.35781 .10441 L
.35796 .10439 L
.35809 .10432 L
.35823 .1042 L
.35838 .10402 L
.35854 .10376 L
.35883 .10314 L
.35913 .10228 L
.35941 .10128 L
.35993 .09889 L
.36055 .09514 L
.36112 .09086 L
.36241 .07837 L
.36361 .06362 L
.36488 .04486 L
.3655 .03484 L
.36609 .02491 L
.36634 .02046 L
.36648 .018 L
.36661 .01568 L
.36675 .01627 L
.36691 .01907 L
.36718 .02404 L
.37177 .10632 L
.37296 .12403 L
.37421 .13931 L
.37528 .149 L
.37557 .15104 L
.37588 .15291 L
.37615 .15425 L
.37644 .15544 L
.37659 .15593 L
.37676 .15636 L
.37685 .15656 L
.37693 .15672 L
.37701 .15685 L
.37709 .15695 L
.37723 .15707 L
.37739 .15712 L
.37753 .15708 L
.37768 .15696 L
.37784 .15673 L
.37793 .15656 L
.37801 .15637 L
.37832 .15543 L
Mistroke
.37848 .15477 L
.37866 .15393 L
.37902 .15183 L
.37963 .14706 L
.38028 .14023 L
.38145 .12336 L
.38385 .07086 L
.38451 .05248 L
.38521 .03127 L
.38549 .02205 L
.38557 .01934 L
.38565 .01675 L
.3858 .0176 L
.38588 .02043 L
.38596 .02308 L
.38614 .02916 L
.38645 .04031 L
.39127 .23682 L
.39599 .43382 L
.39724 .4779 L
.39858 .51948 L
.39974 .54944 L
.40035 .56284 L
.40101 .57517 L
.40166 .58525 L
.40226 .59253 L
.40254 .59538 L
.40285 .59798 L
.40315 .59996 L
.40342 .6014 L
.40358 .60206 L
.40372 .60253 L
.40389 .60293 L
.40397 .60309 L
.40406 .60321 L
.40414 .60328 L
.40423 .60332 L
.40438 .60328 L
.40448 .60319 L
.40457 .60307 L
.40465 .60292 L
.40474 .60271 L
.40489 .60228 L
.40505 .60167 L
.40538 .60002 L
.40568 .59798 L
.40596 .59564 L
.40656 .58929 L
.40722 .58029 L
.40841 .55857 L
Mistroke
.41065 .50103 L
.41302 .42059 L
.41556 .32136 L
.41797 .22237 L
.42058 .12051 L
.42181 .07695 L
.42248 .05478 L
.4231 .03528 L
.42338 .02709 L
.42364 .01956 L
.42378 .01549 L
.42394 .01829 L
.42408 .02216 L
.42421 .02569 L
.42542 .05553 L
.42651 .07787 L
.42768 .09706 L
.42835 .10577 L
.42896 .1123 L
.42958 .11749 L
.43017 .12118 L
.43048 .12266 L
.43077 .12375 L
.43104 .12449 L
.43119 .1248 L
.43132 .12503 L
.43147 .12521 L
.43161 .12531 L
.43176 .12536 L
.43184 .12536 L
.43192 .12533 L
.43208 .12523 L
.43216 .12514 L
.43225 .12503 L
.4324 .12479 L
.43255 .12447 L
.43282 .12377 L
.4331 .12281 L
.43361 .12053 L
.43421 .11697 L
.43477 .11296 L
.43705 .0904 L
.43955 .05857 L
.44077 .04211 L
.44191 .02679 L
.44255 .01859 L
.44272 .0164 L
.44281 .0153 L
.44291 .01533 L
.44299 .01635 L
Mistroke
.44308 .01743 L
.44324 .01938 L
.44444 .0332 L
.44566 .04546 L
.44699 .05638 L
.4476 .06045 L
.44825 .06411 L
.44882 .06674 L
.44942 .06892 L
.44973 .06981 L
.45006 .0706 L
.45037 .07116 L
.45066 .07153 L
.45074 .07162 L
.45083 .07169 L
.45091 .07175 L
.451 .0718 L
.45108 .07184 L
.45116 .07187 L
.45131 .07189 L
.4514 .07188 L
.45148 .07187 L
.45157 .07184 L
.45167 .0718 L
.45175 .07175 L
.45183 .07169 L
.452 .07153 L
.45232 .07112 L
.45262 .0706 L
.45318 .06928 L
.45378 .06739 L
.45444 .06482 L
.45684 .05162 L
.45938 .03354 L
.46052 .02495 L
.46115 .02026 L
.46146 .01798 L
.46159 .01698 L
.46174 .01589 L
.46188 .01489 L
.46201 .01547 L
.46215 .01644 L
.46229 .01749 L
.4629 .02163 L
.46395 .02841 L
.4652 .03546 L
.46636 .04088 L
.46758 .0452 L
.46822 .04691 L
.46855 .04764 L
Mistroke
.46891 .04829 L
.46921 .04875 L
.46955 .04915 L
.4697 .04929 L
.46985 .04942 L
.47 .04951 L
.47014 .04958 L
.47022 .04961 L
.47031 .04964 L
.47041 .04966 L
.4705 .04968 L
.47058 .04968 L
.47067 .04968 L
.47076 .04967 L
.47084 .04965 L
.47099 .04961 L
.47107 .04957 L
.47115 .04954 L
.47131 .04944 L
.47148 .04931 L
.47179 .04901 L
.47209 .04864 L
.47265 .04774 L
.4733 .04637 L
.47391 .04481 L
.47616 .03694 L
.47864 .02577 L
.47978 .0203 L
.4804 .01732 L
.4807 .01589 L
.48084 .01526 L
.48098 .01484 L
.48113 .01557 L
.48128 .01625 L
.48161 .01775 L
.48229 .02081 L
.48349 .02582 L
.48473 .03033 L
.48589 .03383 L
.4871 .03664 L
.48774 .03776 L
.48808 .03824 L
.48843 .03866 L
.48876 .03899 L
.48907 .03922 L
.48921 .03931 L
.48937 .03939 L
.48952 .03945 L
.48965 .03949 L
.48973 .03951 L
Mistroke
.48981 .03953 L
.48991 .03954 L
.48999 .03955 L
.49008 .03955 L
.49017 .03955 L
.49026 .03954 L
.49035 .03952 L
.49049 .03949 L
.49058 .03947 L
.49066 .03944 L
.49099 .03928 L
.4913 .03906 L
.4916 .0388 L
.49215 .03817 L
.49275 .03727 L
.49341 .03607 L
.49578 .02995 L
.49831 .0212 L
.49891 .01892 L
.49955 .01646 L
.49971 .01584 L
.49988 .01518 L
.49998 .01479 L
.50007 .01499 L
.50016 .01534 L
.50025 .01567 L
.50089 .01816 L
.50332 .02705 L
.50448 .03076 L
.50572 .03413 L
.50678 .03644 L
.50733 .03742 L
.50794 .03829 L
.50853 .03892 L
.50886 .03918 L
.50901 .03928 L
.50916 .03936 L
.50929 .03942 L
.50944 .03947 L
.50957 .03951 L
.5097 .03953 L
.50983 .03955 L
.50998 .03955 L
.51013 .03954 L
.51027 .03951 L
.51043 .03947 L
.5106 .0394 L
.51091 .03924 L
.51121 .03901 L
.51149 .03875 L
Mistroke
.51212 .03797 L
.51279 .03685 L
.51403 .03404 L
.51537 .02997 L
.51653 .02571 L
.51781 .02038 L
.51841 .01768 L
.51874 .01616 L
.5189 .0154 L
.51905 .01474 L
.51919 .0154 L
.51934 .01611 L
.51966 .01762 L
.52021 .02028 L
.52276 .03228 L
.52391 .03724 L
.52513 .04182 L
.52626 .04527 L
.52731 .04767 L
.52785 .04856 L
.52813 .04892 L
.52843 .04923 L
.5286 .04938 L
.52876 .04948 L
.52891 .04956 L
.52898 .0496 L
.52907 .04963 L
.52921 .04966 L
.52934 .04968 L
.5295 .04968 L
.52965 .04965 L
.5298 .0496 L
.52989 .04957 L
.52997 .04953 L
.53027 .04932 L
.53043 .04917 L
.53061 .04897 L
.53094 .04853 L
.53158 .04737 L
.53216 .04594 L
.53334 .04204 L
.53444 .03725 L
.53572 .03036 L
.53694 .02275 L
.53751 .01885 L
.53782 .01666 L
.53798 .01557 L
.53812 .01487 L
.53827 .01597 L
.53843 .01717 L
Mistroke
.53878 .01973 L
.5394 .02432 L
.54164 .04106 L
.54284 .04949 L
.54412 .05752 L
.54523 .06332 L
.54643 .0681 L
.54674 .06907 L
.54708 .06994 L
.54738 .07061 L
.54767 .07111 L
.54794 .07147 L
.54809 .07162 L
.54823 .07173 L
.54838 .07182 L
.54847 .07185 L
.54854 .07187 L
.54869 .07189 L
.54884 .07186 L
.54898 .07181 L
.5491 .07174 L
.54924 .07163 L
.54938 .07149 L
.54962 .07117 L
.54988 .07071 L
.55048 .06924 L
.55103 .06734 L
.55164 .06465 L
.5523 .06103 L
.5535 .05265 L
.55574 .03122 L
.55629 .02497 L
.5566 .02139 L
.55688 .01791 L
.55705 .01592 L
.55714 .01478 L
.55722 .01571 L
.55753 .01962 L
.55814 .02748 L
.56068 .06161 L
.56295 .09041 L
.56414 .10331 L
.5654 .11428 L
.56605 .1186 L
.56639 .1205 L
.56675 .1222 L
.56709 .12346 L
.56739 .12434 L
.56754 .12467 L
.5677 .12495 L
Mistroke
.56785 .12515 L
.56799 .12528 L
.56813 .12535 L
.56828 .12536 L
.56842 .1253 L
.56855 .12519 L
.5687 .12501 L
.56885 .12473 L
.56902 .12436 L
.56917 .12393 L
.56949 .1228 L
.56978 .12148 L
.57042 .11746 L
.57101 .11255 L
.57163 .106 L
.57274 .09074 L
.57394 .06922 L
.57461 .05477 L
.57525 .03958 L
.57584 .02436 L
.576 .01998 L
.57609 .01754 L
.57617 .01523 L
.57632 .01832 L
.57648 .02297 L
.5776 .05738 L
.58012 .14692 L
.58478 .3352 L
.58715 .42706 L
.58974 .51241 L
.59094 .54388 L
.59221 .57077 L
.59283 .58107 L
.59342 .58907 L
.59395 .59477 L
.59452 .59934 L
.5948 .60097 L
.59496 .60169 L
.5951 .60225 L
.59524 .60267 L
.59539 .603 L
.59553 .6032 L
.59566 .6033 L
.59573 .60332 L
.59582 .6033 L
.59597 .60317 L
.59612 .60291 L
.59626 .60257 L
.59641 .60209 L
.59658 .60141 L
Mistroke
.59691 .59961 L
.59724 .59723 L
.59754 .59455 L
.59822 .58678 L
.59885 .57745 L
.59945 .56678 L
.60185 .50694 L
.60407 .43131 L
.60881 .2332 L
.61119 .13162 L
.61223 .08973 L
.61282 .06707 L
.61336 .0468 L
.61391 .02732 L
.61407 .02188 L
.61422 .01682 L
.61436 .01709 L
.6145 .02188 L
.6157 .05851 L
.6169 .08981 L
.61822 .11754 L
.61881 .12772 L
.61946 .13695 L
.62001 .14351 L
.62061 .14917 L
.62097 .15176 L
.6213 .1537 L
.62161 .15515 L
.62177 .15573 L
.62194 .15625 L
.62211 .15664 L
.62227 .15689 L
.62242 .15705 L
.62258 .15712 L
.62272 .1571 L
.62285 .15701 L
.623 .15684 L
.62315 .15657 L
.6233 .15622 L
.62346 .15575 L
.62379 .15451 L
.6241 .15303 L
.62438 .15134 L
.62503 .14658 L
.62572 .14005 L
.62815 .10761 L
.63053 .06642 L
.63178 .04314 L
.63247 .03038 L
.63281 .02419 L
Mistroke
.63296 .02149 L
.63312 .01855 L
.63328 .01573 L
.63342 .01632 L
.63358 .01906 L
.63374 .02198 L
.63442 .03355 L
.6356 .0523 L
.6368 .06896 L
.63791 .08183 L
.63913 .09286 L
.63978 .09724 L
.64011 .09908 L
.64047 .10076 L
.64078 .10196 L
.64106 .10285 L
.64133 .10352 L
.64148 .1038 L
.64162 .10402 L
.64177 .1042 L
.64186 .10428 L
.64194 .10433 L
.64208 .1044 L
.64223 .10441 L
.64231 .1044 L
.6424 .10436 L
.64249 .1043 L
.64257 .10423 L
.64273 .10406 L
.64289 .10381 L
.6432 .10319 L
.64353 .10228 L
.64411 .10004 L
.64481 .09642 L
.64545 .09228 L
.64787 .07017 L
.65039 .0401 L
.65149 .02599 L
.6518 .02212 L
.65196 .01999 L
.65212 .01799 L
.65227 .01614 L
.65243 .0153 L
.65257 .01712 L
.65271 .0188 L
.65497 .04521 L
.6562 .05738 L
.65736 .06687 L
.65845 .07383 L
.65906 .07685 L
Mistroke
.65961 .07902 L
.66019 .08067 L
.66052 .08133 L
.66067 .08156 L
.66083 .08177 L
.66091 .08186 L
.66099 .08193 L
.66115 .08204 L
.66129 .0821 L
.66144 .08212 L
.66152 .08212 L
.6616 .0821 L
.66176 .08204 L
.66185 .08198 L
.66194 .08191 L
.6621 .08174 L
.66239 .08133 L
.66265 .08082 L
.66326 .07918 L
.66386 .07699 L
.6645 .074 L
.66566 .06708 L
.66672 .05923 L
.66919 .03702 L
.67039 .02506 L
.67096 .01935 L
.67122 .01684 L
.67136 .01542 L
.67149 .01533 L
.67162 .0166 L
.67176 .01796 L
.67204 .02072 L
.67263 .02645 L
.67371 .03635 L
.67608 .05464 L
.6773 .06153 L
.67799 .06455 L
.67863 .06675 L
.67895 .06761 L
.67925 .06829 L
.67952 .06879 L
.6798 .0692 L
.67995 .06936 L
.68012 .06951 L
.68027 .0696 L
.6804 .06966 L
.68049 .06968 L
.68057 .06969 L
.68072 .06968 L
.6808 .06966 L
Mistroke
.68088 .06964 L
.68096 .0696 L
.68105 .06954 L
.68119 .06944 L
.68134 .0693 L
.68164 .0689 L
.68192 .06842 L
.68218 .06787 L
.68277 .06628 L
.6834 .06407 L
.68456 .05873 L
.68561 .0526 L
.68812 .03427 L
.68922 .02523 L
.6898 .02035 L
.69012 .01765 L
.69028 .01633 L
.69043 .0151 L
.69057 .01551 L
.69072 .01675 L
.69104 .01937 L
.69159 .0239 L
.69268 .0324 L
.69507 .0482 L
.69631 .05434 L
.69701 .05702 L
.69766 .05898 L
.69822 .06027 L
.69854 .06082 L
.69884 .06122 L
.699 .06139 L
.69916 .06152 L
.6993 .0616 L
.69945 .06167 L
.69952 .0617 L
.69961 .06172 L
.6997 .06173 L
.69978 .06172 L
.69993 .0617 L
.70001 .06167 L
.70009 .06164 L
.70025 .06156 L
.70039 .06145 L
.70067 .06117 L
.70096 .06077 L
.70128 .06022 L
.70185 .05892 L
.70238 .05738 L
.70359 .05268 L
.70488 .04618 L
Mistroke
.70727 .03093 L
.70832 .02349 L
.70887 .01949 L
.70917 .01729 L
.70932 .01621 L
.70945 .01522 L
.7096 .01525 L
.70975 .01636 L
.71008 .01873 L
.71066 .02285 L
.7118 .03063 L
.71311 .03868 L
.71433 .04507 L
.71543 .04975 L
.71599 .05168 L
.71661 .05341 L
.71696 .05421 L
.71728 .05483 L
.71758 .05531 L
.71791 .05571 L
.71806 .05585 L
.71821 .05597 L
.71836 .05606 L
.71849 .05612 L
.71864 .05617 L
.71873 .05618 L
.7188 .05619 L
.71895 .05618 L
.7191 .05615 L
.71925 .05609 L
.71934 .05604 L
.71942 .05599 L
.71975 .05571 L
.72004 .05537 L
.72034 .05491 L
.72105 .05347 L
.72169 .05172 L
.72294 .04718 L
.72412 .04168 L
.72632 .02915 L
.72757 .0212 L
.72787 .01927 L
.72818 .01723 L
.72831 .01639 L
.72845 .01549 L
.7286 .01493 L
.72875 .01584 L
.72989 .02316 L
.73113 .0306 L
.73367 .0432 L
Mistroke
.7349 .04757 L
.7356 .04942 L
.73593 .05013 L
.73624 .05071 L
.73654 .05116 L
.73681 .0515 L
.7371 .05179 L
.73727 .05191 L
.73743 .052 L
.73758 .05206 L
.73766 .05209 L
.73774 .05211 L
.73788 .05212 L
.73802 .05212 L
.7381 .0521 L
.73819 .05209 L
.73834 .05203 L
.73842 .05199 L
.7385 .05195 L
.73867 .05183 L
.73899 .05154 L
.73928 .05118 L
.73994 .05007 L
.74052 .04875 L
.74114 .04702 L
.74338 .03819 L
.74576 .0256 L
.7468 .01954 L
.74709 .01786 L
.74724 .01693 L
.74739 .01606 L
.74753 .01525 L
.74768 .01507 L
.74781 .01586 L
.74794 .0166 L
.74914 .02352 L
.75028 .02972 L
.75158 .03607 L
.7528 .04106 L
.75389 .04461 L
.75445 .04605 L
.75507 .04731 L
.75541 .04787 L
.75574 .04829 L
.75604 .04861 L
.7562 .04874 L
.75637 .04885 L
.75652 .04893 L
.75666 .04898 L
.75679 .04901 L
Mistroke
.75693 .04903 L
.75709 .04902 L
.75723 .049 L
.75739 .04895 L
.75748 .04892 L
.75756 .04888 L
.75784 .0487 L
.75814 .04841 L
.75846 .04803 L
.75876 .04758 L
.75987 .04526 L
.7605 .04348 L
.76108 .0416 L
.76238 .03653 L
.76358 .03098 L
.76487 .02444 L
.76549 .02111 L
.76608 .01792 L
.76633 .01653 L
.76647 .01576 L
.7666 .01505 L
.76675 .01515 L
.7669 .01599 L
.76717 .01747 L
.76954 .02964 L
.77179 .03893 L
.77296 .04251 L
.77363 .04407 L
.77424 .04519 L
.77476 .04588 L
.77506 .04617 L
.77533 .04638 L
.77547 .04646 L
.77562 .04653 L
.77575 .04657 L
.77589 .0466 L
.77604 .04661 L
.77612 .04661 L
.7762 .0466 L
.77634 .04658 L
.77648 .04653 L
.77662 .04647 L
.77677 .04639 L
.77704 .04619 L
.77737 .04588 L
.77766 .04551 L
.7783 .04448 L
.7789 .0432 L
.77997 .04028 L
.78113 .03623 L
Mistroke
.78346 .026 L
.7847 .01986 L
.78504 .01813 L
.7854 .01631 L
.78555 .01556 L
.78571 .01475 L
.7858 .01514 L
.78588 .01556 L
.78604 .01638 L
.78848 .0282 L
.79077 .03722 L
.79197 .0407 L
.79255 .042 L
.79308 .043 L
.79366 .04382 L
.79397 .04414 L
.7943 .04441 L
.79447 .04451 L
.79455 .04455 L
.79465 .04459 L
.79474 .04463 L
.79482 .04465 L
.79497 .04468 L
.79513 .04469 L
.79521 .04469 L
.79529 .04468 L
.79544 .04465 L
.79559 .0446 L
.79574 .04454 L
.7959 .04445 L
.79619 .04423 L
.79647 .04396 L
.79673 .04365 L
.79733 .04274 L
.79796 .0415 L
.79901 .03879 L
.80017 .035 L
.8027 .02449 L
.80381 .01928 L
.80411 .01783 L
.80444 .01627 L
.8046 .01552 L
.80474 .0148 L
.80488 .01527 L
.80502 .01596 L
.8073 .02647 L
.80969 .0356 L
.81083 .03887 L
.81149 .04035 L
.81209 .04144 L
Mistroke
.81272 .04231 L
.81307 .04266 L
.81323 .04279 L
.8134 .0429 L
.81356 .04299 L
.8137 .04305 L
.81385 .0431 L
.81399 .04313 L
.81406 .04314 L
.81415 .04314 L
.81429 .04314 L
.81445 .04312 L
.81454 .0431 L
.81463 .04307 L
.81478 .04301 L
.81494 .04293 L
.81523 .04273 L
.81555 .04244 L
.81589 .04204 L
.81651 .0411 L
.81709 .03998 L
.81817 .0373 L
.81933 .03363 L
.8217 .02422 L
.82296 .01861 L
.82332 .01696 L
.8235 .01615 L
.82366 .0154 L
.82381 .01472 L
.82396 .01543 L
.8243 .01694 L
.82678 .02768 L
.82908 .03568 L
.83022 .03856 L
.83086 .03981 L
.83145 .0407 L
.83199 .04131 L
.8323 .04156 L
.83245 .04165 L
.83258 .04173 L
.83271 .04179 L
.83283 .04183 L
.83296 .04186 L
.83311 .04189 L
.83323 .04189 L
.83338 .04189 L
.83352 .04187 L
.83366 .04183 L
.83381 .04178 L
.83398 .0417 L
Mistroke
.83427 .04152 L
.83458 .04125 L
.83493 .04087 L
.83555 .03998 L
.83613 .03892 L
.83721 .03636 L
.83837 .03286 L
.84075 .02384 L
.842 .01846 L
.84237 .01688 L
.84254 .0161 L
.84271 .01538 L
.84285 .01473 L
.84301 .01539 L
.84334 .01684 L
.84583 .02719 L
.84814 .03488 L
.84928 .03767 L
.84992 .03887 L
.85051 .03973 L
.85105 .04032 L
.85136 .04056 L
.85151 .04065 L
.85164 .04073 L
.85177 .04078 L
.85189 .04082 L
.85202 .04086 L
.85216 .04088 L
.85229 .04089 L
.85243 .04088 L
.85258 .04086 L
.85272 .04083 L
.85287 .04077 L
.85304 .0407 L
.85333 .04052 L
.85364 .04026 L
.85399 .0399 L
.85461 .03904 L
.85519 .03801 L
.85627 .03554 L
.85743 .03216 L
.85982 .02344 L
.86047 .02077 L
.86116 .01785 L
.86145 .01664 L
.8616 .01601 L
.86176 .01534 L
.86184 .01498 L
.86193 .01484 L
.86202 .0152 L
Mistroke
.8621 .01553 L
.86241 .01687 L
.86493 .02696 L
.86721 .03431 L
.86837 .03702 L
.86903 .0382 L
.86963 .03903 L
.87016 .03957 L
.87046 .03979 L
.87074 .03994 L
.87089 .04 L
.87104 .04004 L
.87117 .04006 L
.87131 .04007 L
.87146 .04007 L
.87155 .04007 L
.87162 .04006 L
.87177 .04002 L
.87192 .03998 L
.87206 .03992 L
.87221 .03984 L
.87248 .03966 L
.8728 .03938 L
.87309 .03907 L
.87373 .03819 L
.87434 .03712 L
.8754 .0347 L
.87657 .03138 L
.8789 .02303 L
.87954 .02049 L
.88023 .01767 L
.88055 .01637 L
.88073 .01565 L
.88081 .0153 L
.88089 .01499 L
.88102 .01501 L
.88117 .01562 L
.88148 .0169 L
.88395 .02653 L
.88622 .03369 L
.88734 .03629 L
.88792 .03734 L
.88853 .03823 L
.88886 .03861 L
.88915 .03889 L
.88945 .03911 L
.88973 .03927 L
.88989 .03934 L
.88997 .03937 L
.89005 .03939 L
Mistroke
.89021 .03942 L
.89036 .03944 L
.89044 .03944 L
.89053 .03943 L
.89069 .03942 L
.89077 .0394 L
.89086 .03938 L
.89104 .03931 L
.89119 .03924 L
.89136 .03915 L
.89165 .03894 L
.89196 .03866 L
.89231 .03827 L
.89292 .03739 L
.8935 .03635 L
.89458 .0339 L
.89574 .03059 L
.89812 .02221 L
.89877 .01967 L
.89912 .01824 L
.89946 .01689 L
.89977 .01563 L
.89986 .01528 L
.89995 .01491 L
.90003 .01483 L
.90011 .01518 L
.90071 .01757 L
.90321 .02703 L
.90549 .03386 L
.90607 .03519 L
.9067 .03642 L
.90724 .0373 L
.90784 .03806 L
.90817 .03838 L
.90848 .03861 L
.90864 .03871 L
.9088 .03879 L
.90899 .03886 L
.90907 .03889 L
.90915 .03891 L
.9093 .03894 L
.90945 .03895 L
.9096 .03894 L
.90973 .03893 L
.90989 .0389 L
.91004 .03885 L
.9102 .03878 L
.91037 .0387 L
.91067 .03849 L
.91096 .03824 L
Mistroke
.9115 .03763 L
.91209 .03677 L
.91272 .03559 L
.91493 .02986 L
.91626 .02542 L
.9175 .02078 L
.91805 .01866 L
.91862 .01639 L
.91877 .01582 L
.91893 .0152 L
.91901 .01485 L
.9191 .01491 L
.91926 .01554 L
.91984 .01783 L
.92229 .02693 L
.92456 .0336 L
.92567 .03596 L
.92624 .03688 L
.92656 .03732 L
.92686 .03767 L
.92716 .03797 L
.92748 .03823 L
.92781 .03842 L
.92799 .03849 L
.92807 .03852 L
.92815 .03854 L
.92831 .03857 L
.92846 .03859 L
.92861 .03859 L
.92874 .03858 L
.92888 .03856 L
.92904 .03851 L
.92921 .03845 L
.92937 .03838 L
.92968 .03818 L
.92997 .03794 L
.93062 .03721 L
.9312 .03635 L
.93181 .03522 L
.93405 .02944 L
.93647 .02103 L
.93713 .01849 L
.93749 .01709 L
.93783 .01577 L
.93797 .01519 L
.93811 .01479 L
.93819 .01509 L
.93827 .01542 L
.93842 .01599 L
.93907 .01853 L
Mistroke
.94138 .02693 L
.94269 .03099 L
.94391 .03411 L
.94507 .03632 L
.94571 .03722 L
.94631 .03782 L
.94663 .03806 L
.94693 .03821 L
.9471 .03828 L
.94726 .03832 L
.94734 .03834 L
.94744 .03835 L
.94752 .03836 L
.94761 .03836 L
.94775 .03835 L
.94789 .03833 L
.94804 .0383 L
.94813 .03827 L
.94821 .03824 L
.94853 .03808 L
.94884 .03787 L
.9494 .03734 L
.95001 .03653 L
.95124 .03424 L
.95239 .03139 L
.95346 .02817 L
.95465 .02415 L
.9559 .01953 L
.95641 .01755 L
.95669 .01646 L
.95696 .01542 L
.95711 .01483 L
.9572 .01494 L
.95728 .01524 L
.95757 .01636 L
.95813 .01853 L
.96058 .02737 L
.96178 .03103 L
.96288 .03381 L
.96342 .03496 L
.96401 .03603 L
.96457 .03686 L
.96508 .03745 L
.96537 .03771 L
.96568 .03794 L
.96585 .03803 L
.966 .03811 L
.96615 .03816 L
.96631 .03821 L
.96644 .03823 L
Mistroke
.96659 .03825 L
.96673 .03825 L
.96685 .03824 L
.967 .03821 L
.96716 .03817 L
.96731 .03811 L
.96745 .03805 L
.96774 .03788 L
.96801 .03767 L
.96861 .03704 L
.96914 .03631 L
.9697 .03535 L
.97089 .03276 L
.97219 .02914 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309097 0.0974746 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01667 -12 -4.5 ]
[-0.0125 .01667 0 4.5 ]
[-0.0125 .11415 -12 -4.5 ]
[-0.0125 .11415 0 4.5 ]
[-0.0125 .21162 -12 -4.5 ]
[-0.0125 .21162 0 4.5 ]
[-0.0125 .3091 -6 -4.5 ]
[-0.0125 .3091 0 4.5 ]
[-0.0125 .40657 -6 -4.5 ]
[-0.0125 .40657 0 4.5 ]
[-0.0125 .50405 -6 -4.5 ]
[-0.0125 .50405 0 4.5 ]
[-0.0125 .60152 -6 -4.5 ]
[-0.0125 .60152 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01667 m
.00625 .01667 L
s
[(-3)] -0.0125 .01667 1 0 Mshowa
0 .11415 m
.00625 .11415 L
s
[(-2)] -0.0125 .11415 1 0 Mshowa
0 .21162 m
.00625 .21162 L
s
[(-1)] -0.0125 .21162 1 0 Mshowa
0 .3091 m
.00625 .3091 L
s
[(0)] -0.0125 .3091 1 0 Mshowa
0 .40657 m
.00625 .40657 L
s
[(1)] -0.0125 .40657 1 0 Mshowa
0 .50405 m
.00625 .50405 L
s
[(2)] -0.0125 .50405 1 0 Mshowa
0 .60152 m
.00625 .60152 L
s
[(3)] -0.0125 .60152 1 0 Mshowa
.125 Mabswid
0 .03617 m
.00375 .03617 L
s
0 .05566 m
.00375 .05566 L
s
0 .07516 m
.00375 .07516 L
s
0 .09465 m
.00375 .09465 L
s
0 .13364 m
.00375 .13364 L
s
0 .15314 m
.00375 .15314 L
s
0 .17263 m
.00375 .17263 L
s
0 .19213 m
.00375 .19213 L
s
0 .23112 m
.00375 .23112 L
s
0 .25061 m
.00375 .25061 L
s
0 .27011 m
.00375 .27011 L
s
0 .2896 m
.00375 .2896 L
s
0 .32859 m
.00375 .32859 L
s
0 .34809 m
.00375 .34809 L
s
0 .36758 m
.00375 .36758 L
s
0 .38708 m
.00375 .38708 L
s
0 .42607 m
.00375 .42607 L
s
0 .44556 m
.00375 .44556 L
s
0 .46506 m
.00375 .46506 L
s
0 .48455 m
.00375 .48455 L
s
0 .52354 m
.00375 .52354 L
s
0 .54304 m
.00375 .54304 L
s
0 .56253 m
.00375 .56253 L
s
0 .58203 m
.00375 .58203 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01667 m
1 .01667 L
s
.99375 .11415 m
1 .11415 L
s
.99375 .21162 m
1 .21162 L
s
.99375 .3091 m
1 .3091 L
s
.99375 .40657 m
1 .40657 L
s
.99375 .50405 m
1 .50405 L
s
.99375 .60152 m
1 .60152 L
s
.125 Mabswid
.99625 .03617 m
1 .03617 L
s
.99625 .05566 m
1 .05566 L
s
.99625 .07516 m
1 .07516 L
s
.99625 .09465 m
1 .09465 L
s
.99625 .13364 m
1 .13364 L
s
.99625 .15314 m
1 .15314 L
s
.99625 .17263 m
1 .17263 L
s
.99625 .19213 m
1 .19213 L
s
.99625 .23112 m
1 .23112 L
s
.99625 .25061 m
1 .25061 L
s
.99625 .27011 m
1 .27011 L
s
.99625 .2896 m
1 .2896 L
s
.99625 .32859 m
1 .32859 L
s
.99625 .34809 m
1 .34809 L
s
.99625 .36758 m
1 .36758 L
s
.99625 .38708 m
1 .38708 L
s
.99625 .42607 m
1 .42607 L
s
.99625 .44556 m
1 .44556 L
s
.99625 .46506 m
1 .46506 L
s
.99625 .48455 m
1 .48455 L
s
.99625 .52354 m
1 .52354 L
s
.99625 .54304 m
1 .54304 L
s
.99625 .56253 m
1 .56253 L
s
.99625 .58203 m
1 .58203 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .3091 m
1 .3091 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .46221 m
.02847 .38896 L
.03355 .30907 L
.03602 .27022 L
.03832 .23404 L
.04054 .19917 L
.04118 .18914 L
.04178 .17965 L
.04232 .17113 L
.04247 .16879 L
.04263 .16632 L
.04276 .16421 L
.04291 .46811 L
.04307 .46566 L
.04321 .4634 L
.04354 .45825 L
.04414 .44889 L
.04525 .43131 L
.04777 .39172 L
.05249 .31753 L
.0549 .27966 L
.05751 .23869 L
.05873 .21945 L
.06002 .19912 L
.06113 .18177 L
.06143 .17702 L
.0616 .1744 L
.06175 .17192 L
.0619 .16962 L
.06206 .47334 L
.0622 .47106 L
.06234 .46895 L
.06707 .3945 L
.07163 .32293 L
.07416 .28316 L
.07647 .24671 L
.07875 .21098 L
.07989 .19301 L
.0802 .18809 L
.08054 .18283 L
.0807 .18028 L
.08085 .17787 L
.08099 .48193 L
.08114 .47958 L
.08608 .40201 L
.09083 .3273 L
.0954 .25548 L
.09774 .21861 L
.09842 .20799 L
.09906 .19791 L
Mistroke
.09963 .18886 L
.09979 .18638 L
.09988 .18503 L
.09996 .18375 L
.10012 .48748 L
.10026 .48523 L
.10492 .41204 L
.10987 .33421 L
.11234 .29543 L
.11464 .25926 L
.11685 .22445 L
.11749 .21443 L
.11809 .20494 L
.11864 .19643 L
.11878 .1941 L
.11894 .19162 L
.11908 .49574 L
.11922 .49341 L
.12408 .4171 L
.12875 .34367 L
.13112 .30635 L
.13372 .26559 L
.13492 .24673 L
.1362 .2266 L
.13682 .21683 L
.13741 .20761 L
.13766 .20359 L
.13793 .19934 L
.13808 .19712 L
.13823 .5009 L
.13837 .49868 L
.1385 .49661 L
.14319 .42292 L
.14818 .34459 L
.15067 .30541 L
.15298 .26914 L
.15522 .23396 L
.15635 .21619 L
.15666 .21132 L
.15682 .20876 L
.15699 .20607 L
.15714 .2037 L
.15723 .50858 L
.15731 .50733 L
.1576 .50278 L
.1623 .42885 L
.1673 .35027 L
.16981 .3109 L
.17212 .27457 L
.17437 .23921 L
Mistroke
.17551 .22137 L
.17582 .21649 L
.17599 .21379 L
.17607 .21247 L
.17615 .21123 L
.1763 .51509 L
.17638 .51384 L
.17647 .5125 L
.17676 .50797 L
.18177 .42914 L
.18661 .35319 L
.19126 .28012 L
.19367 .24231 L
.19425 .23313 L
.19488 .22328 L
.19506 .22038 L
.19515 .21895 L
.19524 .21763 L
.19539 .52139 L
.19548 .52009 L
.19557 .5187 L
.19621 .50862 L
.20076 .43707 L
.20561 .36088 L
.21028 .28757 L
.2127 .24958 L
.21329 .24035 L
.21392 .23049 L
.2141 .22757 L
.21419 .22614 L
.21428 .22482 L
.21443 .52857 L
.21452 .52727 L
.21461 .5259 L
.21525 .51584 L
.21982 .44405 L
.22469 .36762 L
.22937 .29407 L
.23059 .27487 L
.23193 .25395 L
.23254 .24437 L
.23287 .23913 L
.23303 .23655 L
.23318 .23419 L
.23333 .23194 L
.23348 .53579 L
.23363 .53341 L
.2338 .5308 L
.23435 .52211 L
.23923 .44544 L
Mistroke
.24394 .37165 L
.24633 .33405 L
.24893 .29323 L
.25015 .27416 L
.25081 .26373 L
.25144 .25395 L
.25197 .24564 L
.25212 .24324 L
.25226 .24097 L
.25239 .54515 L
.25254 .54292 L
.25375 .52391 L
.25865 .44701 L
.26336 .373 L
.26577 .33523 L
.26838 .29436 L
.2696 .27517 L
.27027 .26469 L
.27089 .2549 L
.27117 .25061 L
.2713 .2485 L
.27143 .24655 L
.27157 .55053 L
.27172 .54809 L
.272 .54382 L
.27321 .52482 L
.27794 .45058 L
.28249 .37922 L
.28502 .33958 L
.28734 .30323 L
.28852 .28479 L
.28961 .26762 L
.29017 .25897 L
.29032 .25647 L
.29047 .25412 L
.29061 .55823 L
.29076 .55594 L
.29201 .53635 L
.29694 .45904 L
.30169 .38461 L
.30626 .31306 L
.30746 .29423 L
.3086 .27635 L
.30891 .27157 L
.30923 .26649 L
.30933 .26498 L
.30942 .26356 L
.3095 .26229 L
.30959 .56714 L
.30967 .56583 L
Mistroke
.30976 .56444 L
.30992 .56196 L
.31112 .54313 L
.31571 .47136 L
.32059 .39498 L
.32528 .32148 L
.32651 .30225 L
.32716 .29211 L
.32785 .28135 L
.32814 .27683 L
.32829 .27446 L
.32845 .27197 L
.32853 .27064 L
.32863 .57541 L
.32871 .57408 L
.32879 .57285 L
.32911 .56785 L
.33028 .54961 L
.33499 .47591 L
.34 .39761 L
.34251 .35836 L
.34483 .32221 L
.34599 .30399 L
.34656 .29509 L
.34708 .28696 L
.34722 .28486 L
.34736 .28256 L
.3475 .2804 L
.34763 .58462 L
.34777 .5825 L
.34792 .58017 L
.34822 .57543 L
.34947 .55592 L
.35431 .48033 L
.35897 .40763 L
.36134 .37075 L
.36393 .33037 L
.36512 .31176 L
.36578 .30153 L
.3661 .29651 L
.36625 .2943 L
.3664 .29187 L
.36655 .28961 L
.36668 .59372 L
.36683 .59149 L
.36698 .58909 L
.36761 .57932 L
.3687 .56224 L
.37368 .48483 L
.37847 .41034 L
Mistroke
.38307 .33875 L
.3843 .31978 L
.3849 .31047 L
.38516 .30638 L
.38545 .3019 L
.38552 .3007 L
.38561 .29942 L
.38576 .60332 L
.38584 .60195 L
.38593 .60066 L
.38608 .59824 L
.38677 .58754 L
.38798 .56888 L
.3926 .49719 L
.39752 .42102 L
.40226 .3478 L
.40681 .27751 L
.41166 .2028 L
.41633 .13106 L
.4187 .09469 L
.42129 .05497 L
.42249 .03664 L
.42314 .02658 L
.42347 .02164 L
.42361 .01947 L
.42376 .01709 L
.42391 .32109 L
.42405 .31901 L
.42434 .31446 L
.42497 .30487 L
.42607 .28813 L
.43075 .21678 L
.43573 .14123 L
.43822 .10361 L
.44053 .06882 L
.44168 .05149 L
.44224 .043 L
.44249 .03928 L
.44262 .03732 L
.44276 .03521 L
.44291 .33917 L
.44305 .33705 L
.44336 .33243 L
.44401 .3227 L
.44514 .30577 L
.45014 .23127 L
.45495 .1601 L
.45715 .12775 L
.4584 .10942 L
.45958 .09228 L
Mistroke
.46073 .07553 L
.46106 .07072 L
.46138 .06614 L
.46166 .06204 L
.46174 .06092 L
.46182 .05972 L
.46197 .36379 L
.46205 .36258 L
.46214 .36131 L
.4623 .35903 L
.46265 .35389 L
.4633 .34457 L
.4645 .3272 L
.46908 .26187 L
.47395 .19344 L
.4762 .16234 L
.47864 .12883 L
.47929 .12005 L
.47997 .11075 L
.48056 .10284 L
.48072 .10067 L
.4808 .09954 L
.48089 .09834 L
.48097 .40351 L
.48105 .40236 L
.4812 .40034 L
.48363 .36781 L
.48852 .30332 L
.49322 .24243 L
.49562 .21172 L
.49688 .19561 L
.49822 .17857 L
.4988 .17125 L
.49942 .1634 L
.4996 .16109 L
.49977 .15889 L
.49993 .15692 L
.50001 .46203 L
.5001 .461 L
.50073 .45293 L
.50304 .42351 L
.50777 .36307 L
.51278 .29786 L
.5153 .26462 L
.51641 .24992 L
.51762 .23372 L
.51818 .22613 L
.5185 .22194 L
.51865 .21988 L
.51879 .21797 L
Mistroke
.51892 .21618 L
.51906 .5205 L
.51921 .51859 L
.51936 .51648 L
.51988 .50943 L
.52227 .47688 L
.52712 .40975 L
.53179 .34394 L
.53416 .3101 L
.53542 .29211 L
.53676 .27283 L
.53743 .26318 L
.53775 .25843 L
.5379 .25635 L
.53806 .25405 L
.5382 .55822 L
.53833 .55629 L
.53862 .55208 L
.53924 .54318 L
.54154 .50961 L
.54623 .44081 L
.55121 .36697 L
.5537 .32981 L
.55491 .31169 L
.55601 .29527 L
.55656 .28695 L
.55671 .28468 L
.55687 .28227 L
.55701 .28022 L
.55716 .5842 L
.5573 .58207 L
.55743 .58013 L
.55772 .57577 L
.55824 .56791 L
.56062 .53209 L
.56544 .45929 L
.57007 .38895 L
.57241 .35323 L
.57366 .33425 L
.57434 .32378 L
.575 .31381 L
.57561 .30447 L
.57578 .30191 L
.57595 .29918 L
.57604 .29785 L
.57612 .2966 L
.57628 .60049 L
.57642 .59831 L
.57657 .59601 L
.57684 .59189 L
Mistroke
.57745 .58259 L
.57974 .54745 L
.58432 .47721 L
.5892 .40225 L
.59389 .32994 L
.59888 .25293 L
.60368 .17861 L
.6083 .10703 L
.61064 .07079 L
.61188 .05153 L
.61253 .04141 L
.61322 .03076 L
.61383 .02132 L
.61399 .01873 L
.61409 .01731 L
.61417 .01597 L
.61425 .01472 L
.61434 .31958 L
.61449 .31721 L
.61566 .29908 L
.61795 .26347 L
.62289 .18678 L
.62764 .11286 L
.63003 .0757 L
.63107 .05945 L
.63221 .04173 L
.63251 .03702 L
.63283 .03201 L
.63299 .02957 L
.63314 .02728 L
.63327 .02522 L
.63341 .32922 L
.63355 .32707 L
.6337 .32471 L
.63401 .31995 L
.63455 .31143 L
.63707 .27217 L
.64196 .19607 L
.64665 .12278 L
.64905 .08542 L
.65031 .06573 L
.651 .05494 L
.65165 .04483 L
.65193 .04047 L
.65222 .03589 L
.65237 .03348 L
.65246 .33835 L
.65254 .33709 L
.65284 .33248 L
.65415 .31201 L
Mistroke
.65646 .27592 L
.66117 .20225 L
.66618 .12394 L
.6687 .08464 L
.6698 .0674 L
.67038 .05826 L
.67071 .05322 L
.67101 .04845 L
.67115 .04623 L
.6713 .04388 L
.67138 .04265 L
.67147 .34752 L
.67162 .34513 L
.67218 .33642 L
.67327 .31936 L
.67566 .28202 L
.6805 .20622 L
.68516 .13326 L
.68753 .09621 L
.68878 .07661 L
.68947 .06583 L
.68981 .06053 L
.69012 .05564 L
.69027 .05321 L
.69042 .05092 L
.69057 .35477 L
.69065 .3535 L
.69074 .35215 L
.69141 .3416 L
.69259 .32316 L
.69489 .2871 L
.69987 .20919 L
.70466 .13413 L
.70707 .09625 L
.70813 .07975 L
.70868 .07107 L
.70898 .06634 L
.70927 .06191 L
.70941 .05961 L
.70957 .36338 L
.70966 .36198 L
.70974 .36065 L
.7099 .35816 L
.71049 .34898 L
.71164 .33093 L
.71417 .29127 L
.71879 .21877 L
.72371 .14162 L
.72616 .1033 L
.72736 .08453 L
Mistroke
.72788 .07631 L
.72816 .07197 L
.72831 .06958 L
.72845 .06733 L
.72859 .37137 L
.72874 .36901 L
.72901 .36487 L
.72952 .3568 L
.73064 .33917 L
.73301 .30211 L
.73794 .22467 L
.7427 .15009 L
.74509 .1126 L
.74613 .09622 L
.74668 .08757 L
.74727 .07836 L
.74744 .07571 L
.7476 .07321 L
.74774 .3772 L
.74789 .37478 L
.74847 .36569 L
.74962 .34776 L
.75214 .30821 L
.75709 .23047 L
.76186 .15559 L
.76426 .11789 L
.76531 .10144 L
.76586 .09277 L
.76616 .08802 L
.76645 .08358 L
.76659 .08131 L
.76675 .38509 L
.76683 .38371 L
.76692 .38239 L
.76708 .37991 L
.76766 .37077 L
.76881 .35277 L
.77133 .31314 L
.77593 .24085 L
.78083 .16391 L
.7831 .12834 L
.78429 .10962 L
.78494 .09939 L
.78526 .09439 L
.78555 .08984 L
.78571 .08735 L
.78586 .39121 L
.78602 .38872 L
.78619 .38601 L
.7869 .37496 L
Mistroke
.78813 .35554 L
.79056 .31734 L
.79548 .24013 L
.79792 .20179 L
.80021 .16578 L
.8024 .13139 L
.803 .12196 L
.80364 .11204 L
.80417 .10357 L
.80432 .10125 L
.80448 .09877 L
.80463 .09642 L
.80476 .40052 L
.80491 .39827 L
.80504 .39615 L
.80535 .39135 L
.80597 .38163 L
.80708 .3642 L
.80958 .32481 L
.81427 .25129 L
.81665 .21389 L
.81924 .17311 L
.82045 .15419 L
.82173 .13404 L
.82235 .12425 L
.82294 .11503 L
.82346 .10675 L
.82361 .10448 L
.82376 .10209 L
.82389 .40627 L
.82403 .40403 L
.82891 .32737 L
.83361 .25357 L
.836 .21598 L
.8386 .17512 L
.83982 .15607 L
.8411 .13585 L
.8422 .11858 L
.8425 .11385 L
.84266 .11137 L
.84275 .11002 L
.84283 .10876 L
.84297 .41269 L
.84305 .41147 L
.84313 .41017 L
.84341 .40577 L
.84842 .32706 L
.85325 .25121 L
.85789 .17824 L
.86029 .14052 L
Mistroke
.86087 .13135 L
.8615 .12151 L
.86169 .11861 L
.86178 .11718 L
.86186 .11586 L
.86202 .41962 L
.8621 .41832 L
.86219 .41694 L
.86283 .40684 L
.86738 .33538 L
.87222 .25927 L
.87688 .18603 L
.87929 .14811 L
.87988 .13889 L
.88051 .12903 L
.88069 .12612 L
.88078 .12469 L
.88087 .12337 L
.88102 .42712 L
.88111 .42582 L
.88119 .42444 L
.88184 .41436 L
.8864 .34264 L
.89126 .26626 L
.89593 .19275 L
.89715 .17359 L
.89848 .15268 L
.89909 .14312 L
.89943 .13787 L
.89959 .1353 L
.89974 .13293 L
.89988 .13068 L
.90003 .43454 L
.90019 .43215 L
.90035 .42954 L
.90091 .42082 L
.90578 .34418 L
.91048 .27041 L
.91286 .23284 L
.91546 .19199 L
.91667 .17296 L
.91734 .16253 L
.91796 .15274 L
.91849 .14444 L
.91863 .14216 L
.91879 .13977 L
.91892 .13772 L
.91906 .44171 L
.91922 .43921 L
.91936 .43694 L
Mistroke
.91969 .43184 L
.92027 .42266 L
.92509 .34686 L
.92973 .27392 L
.93208 .23697 L
.93467 .19634 L
.93585 .17773 L
.9365 .16747 L
.93712 .15774 L
.9377 .14871 L
.93785 .14623 L
.93794 .14488 L
.93802 .1436 L
.93818 .44734 L
.93832 .44509 L
.93942 .42785 L
.94408 .35465 L
.94903 .27681 L
.95149 .23801 L
.9538 .20183 L
.95493 .18394 L
.95601 .16701 L
.95661 .15766 L
.95677 .1551 L
.95694 .15238 L
.95709 .15006 L
.95717 .45496 L
.95725 .45372 L
.95838 .43596 L
.96305 .3625 L
.96802 .28439 L
.97281 .20916 L
.97619 .15598 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000U2000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00>Oooool3
o`0002;ooooo1Ol0000Qooooo`;o00009?ooool5o`0002Cooooo0ol0001Looooo`?o00008oooool5
o`00027ooooo0_l0000Sooooo`Go00009Oooool3o`0002Sooooo000jooooo`03o`000?oooooooooo
02;ooooo00Co0000oooooooooooo00008?ooool01?l0003oooooooooool0000Tooooo`04o`000?oo
ooooooooo`0002Gooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Sooooo`04o`00
0?ooooooooooo`00023ooooo00Co0000oooooooooooo00008oooool01?l0003oooooooooool0000V
ooooo`03o`000?oooooooooo02Oooooo000aooooo`Go000000?oooooo`000?l000000ol0000Loooo
o`Go00000oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0002Gooooo00?o0000
ooooooooool08_ooool5o`0005Cooooo1Ol000000ooooooo0000o`000003o`0001gooooo1Ol00003
ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00009?ooool00ol0003ooooooooo
o`0Sooooo`Go0000:?ooool003Oooooo00Co0000oooooooooooo00009_ooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool08Oooool01?l0003ooooo
ooooool0001Kooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool07oooool01?l0
003oooooooooool0000Uooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo0000:Ooo
ool003Sooooo00?o0000ooooool000008oooool01Ol0003ooooooooooooooooo0000023ooooo00Co
0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooool0
0000G?ooool00ol0003oooooo`00000Tooooo`05o`000?ooooooooooooooool000008?ooool01?l0
003oooooooooool0000Rooooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooo`00
000Yooooo`00>Oooool2o`0002?ooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?oo
ooooooooo`0002?ooooo00Go0000ooooooooooooooooo`00000Tooooo`;o0000GOooool2o`0002Co
oooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0002;ooooo00Go0000
ooooooooooooooooo`00000Uooooo`;o0000:Oooool003[ooooo00?o0000ooooooooool08_ooool3
o`0002;ooooo0_l0000Uooooo`?o00009_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo02?ooooo0ol0000Rooooo`;o00009?ooool3o`0002Oooooo00?o0000ooooooooool09oooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool001kooooocol0000[oooooloo00004Ooo
ool001Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool3
o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`005oooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00oooooo000Gooooo`04o`000?ooooooooooo`0000?ooooo0ol0
0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000Goooo
o`04ool00?ooooooooooool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000oooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`;o0000
7?ooool5o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0?ooooo`005ooo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool01Oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool08_ooool2o`0000Go
oooo0_l0001Eooooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool05Oooool00ooo003o
ooooooooo`1;ooooo`;o00004Oooool001Oooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`03ooooo`04ool00?ooooooooooool000?ooooo0_oo00000oooooooo`00ool00002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool01Oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool0
0?oooooooooo00;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo05Cooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03ool0
0?oooooooooo04cooooo00?o0000ooooooooool03oooool001Oooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`000_ooool2ool00003oooo
oooo003oo`0000;ooooo0ooo00002Oooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ool000;ooooo
0_oo0002ooooo`;oo`0000Coooooool00?l0003oo`000_ooool2ool000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Gooooo
ool00?ooooooo`00ooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0E?ooool00ooo003oooooooooo`0=ooooo`03o`00
0?oooooooooo01Gooooo00?oo`00ooooooooool00_oo001:ooooo`03o`000?oooooooooo00oooooo
000Hooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`0Nool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool00003oooooooo003o000000?oo`0000Go
ooooool00?ooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00007oooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool01_oo0005ooooo`03
o`000?oooooooooo027ooooo0ol00005ooooo`03o`000?oooooooooo05Cooooo00?oo`00oooooooo
ool03Oooool00ol0003oooooooooo`0Dooooo`;oo`000_ooool2ool000;ooooo00?oo`00oooooooo
ool0AOooool00ol0003oooooooooo`0?ooooo`007_ooool2o`0000Gooooo0_oo00001Oooooooo`00
ool00?oo003ooooo00?oo`0000Goooooool00?oo003oo`00ooooo`03ool00005oooooooo003oo`00
ool00?ooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`04ool00?oooooo
o`00ool000;ooooo0_oo00003?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000Oooooo
00?oo`00ooooooooool00_oo0002ooooo`;oo`0000Coooooool00?oooooooooo0_oo00002_l0003o
ooooool00?oo003oooooool00?ooooooo`00oooooooo0002ooooo`05ool00?oooooooooooooooooo
00001oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`0001Ooooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`03ool0
0003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`001Oooool00ol0003oooooooooo`0Yooooo`;o0000EOooool01Ooo003ooooooooooooooooo
o`0000_ooooo00?o0000ooooooooool05?ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooo
oooo04Cooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`0Hooooo`03ool00?oooooooooo
00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00003_oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2
ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003ooooooooo
o`02ool000;ooooo0_oo00000oooooooo`00ooooo`03ooooo`03o`000?oooooooooo00?ooooo0_oo
00001Oooooooo`00ooooooooooooo`0000?ooooo00?oo`00ooooooooool01Oooool01Ooo003ooooo
ooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool01?oo003oooooool00?ooool2ool0
00;ooooo0_oo00001_ooooooo`00oooooooo003oooooool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo01Oooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Dooooo`05ool00?oooooooooooooooooo
00002oooool00ol0003oooooooooo`0Dooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooo
ooooooooool00013ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo02Oo
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00003_ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo00Goo`00oooo
ooooooooooooool00007ooooo`03ool00?oooooooooo00;oo`0000Coooooool00?oooooooooo0_oo
0004ooooo`03o`000?oooooooooo00?ooooo0_oo00001_ooooooo`00oooooooo003oooooool000;o
oooo00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002oooo
o`;oo`000_ooool01_oo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool00ooo003oooooooooo`0Wooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0E?ooool01Ooo003oooooooooooooooooo`0000_ooooo00?o0000ooooooooool0
5?ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo0000@oooool00ol0003o
ooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`0cooooo`;oo`000_ooool2ool0000:oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo0002ooooo`05ool00?oo
oooooooooooooooo00001_ooool2ool000;ooooo0_oo00001Oooooooo`00ooooooooooooo`0000Go
oooo00?o0000ooooooooool00oooool2ool00006oooooooo003oooooool00?ooooooo`000_ooool0
0ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo00Ko
o`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`00=?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo05Cooooo00Goo`00ooooooooooooooooool0000;oooo
o`03o`000?oooooooooo01Cooooo0_oo0002ooooo`;oo`000_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0
003oooooooooo`0gooooo`;oo`000_ooool2ool0000;oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooool00_oo0003ooooo`03ool00?oooooooooo00Cooooo0_oo0002ooooo`;o
o`0000?oooooool00?ooool01oooool00ol0003oooooooooo`06ooooo`05ool00?ooooooo`00oooo
oooo00000_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;oo`000_ooool01_oo
003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo000hooooo`03o`000?oo
oooooooo02Wooooo0_l0001Eooooo`05ool00?oooooooooooooooooo00002oooool00ol0003ooooo
ooooo`0Dooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo03cooooo0_l0000Aooooo`007_ooool2o`0003cooooo0_oo00002oooooooo`00
ool00?oo003oooooool00?ooooooo`00oooooooo003ooooo00;oo`000oooool00ooo003ooooooooo
o`04ooooo`;oo`000_ooool01?oo003oooooool00?oo0008ooooo`03o`000?oooooooooo00Oooooo
0_oo00001Oooooooo`00ooooooooooooo`0000Oooooo00?oo`00ooooooooool00_oo0002ooooo`06
ool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`00??ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo05Cooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00Gooooo00?o0000ooooooooool05?ooool2ool000;ooooo0_oo0002ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0003_ooooo00?o0000oooooooo
ool03oooool001kooooo00?o0000ooooooooool0?oooool2ool0000;oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooool00_oo0006ooooo`;oo`000_ooool01?oo003oooooool0
0?oo0008ooooo`03o`000?oooooooooo00Oooooo0_oo00001Oooooooo`00ooooooooooooo`0000Oo
oooo00Woo`00ooooooooooooo`00oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`00@?oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05Cooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool05?ooool2ool000;ooooo
0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool0=Oooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003o
ooooooooo`0oooooo`0=ool00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00ooooo`02ool000Kooooo0_oo0002ooooo`04ool00?ooooooo`00ool000Sooooo00?o0000oooo
ooooool01oooool2ool00005oooooooo003ooooooooooooo00001oooool02Ooo003ooooooooooooo
003oooooool00?ooooooo`00ooooo`02ool000;ooooo0_oo0010ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0E?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool01Oooool00ol0003oooooooooo`0Dooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0003?ooooo00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0@ooo
ool2ool00007oooooooo003oooooool00?ooooooo`00ooooo`02ool000Kooooo0_oo00000ooooooo
o`00ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00Coo`00ooooooooooooo`001oooool02Ooo
003ooooooooooooo003oooooool00?ooooooo`00ooooo`02ool004Cooooo00?o0000ooooooooool0
:Oooool2o`0005Gooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00Go
oooo00?o0000ooooooooool05?ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
000booooo`;o00004Oooool001kooooo00?o0000ooooooooool0@oooool02Ooo003ooooooooooooo
003oooooool00?ooooooo`00ooooo`02ool000Kooooo0_oo00000oooooooo`00ooooo`0;ooooo`03
o`000?oooooooooo00[ooooo00Coo`00ooooooooooooo`001_ooool2ool000;ooooo00Koo`00oooo
oooo003oooooool00?ooool2ool004Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`1Cooooo`;oo`000oooool01Ooo003oooooooooooooooooo`0000Oooooo00?o0000ooooooooool0
5?ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo02gooooo00?o0000ooooooooool03oooool001kooooo0_l00017ooooo`06ool00?ooooooo`00
oooooooo003ooooo0_oo0006ooooo`;oo`0000?oooooool00?ooool02oooool00ol0003ooooooooo
o`0:ooooo`04ool00?ooooooo`00ool000Kooooo0_oo0002ooooo`04ool00?ooooooo`00ool004So
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Cooooo`;oo`000oooool01Ooo003o
ooooooooooooooooo`0000Oooooo00?o0000ooooooooool05?ooool2ool000;ooooo0_oo0002oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000:oooool00ol0003o
ooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`16ooooo`06ool00?ooooooo`00oooooooo
003ooooo0_oo0006ooooo`;oo`0000?oooooool00?ooool02oooool00ol0003oooooooooo`0:oooo
o`04ool00?ooooooo`00ool000Kooooo0_oo0002ooooo`04ool00?ooooooo`00ool004Sooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1Cooooo`;oo`000_ooool2ool000?ooooo00?o
o`00ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03ool00?ooooooo`0000;ooooo0_oo
0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000:oooool0
0ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`17ooooo`;oo`0000?oooooool0
0?ooool00_oo0006ooooo`;oo`0000?oooooool00?ooool02oooool00ol0003oooooooooo`0:oooo
o`04ool00?ooooooo`00ool000Kooooo0_oo0002ooooo`04ool00?ooooooo`00ool004Sooooo00?o
0000ooooooooool0:Oooool2o`0005Cooooo0_oo0002ooooo`;oo`000oooool00ooo003ooooooooo
o`05ooooo`03o`000?oooooooooo01?ooooo00?oo`00oooooooo00000_ooool2ool000;ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo02Cooooo0_l0000Aooooo`007_ooool00ol0003oooooooooo`17ooooo`05ool00?oooooooooo
ool00?ooool00_oo0006ooooo`;oo`0000?oooooool00?ooool02oooool00ol0003oooooooooo`0;
ooooo`?oo`001_ooool2ool000;ooooo00Coo`00oooooooo003oo`00B?ooool00ol0003ooooooooo
o`0Pooooo`Go00001?ooool00ol0003oooooooooo`1Cooooo`;oo`000_ooool2ool000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`03o`000?oooooooooo01?ooooo00Ooo`00oooooooo003o
ooooool00?ooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00008oooool00ol0003oooooooooo`0?oooo
o`007_ooool00ol0003oooooooooo`17ooooo`05ool00?ooooooooooool00?ooool00_oo0006oooo
o`04ool00?ooooooo`00ool000cooooo00?o0000ooooooooool02oooool2ool00003oooooooo003o
oooo00Cooooo0_oo0002ooooo`04ool00?ooooooo`00ool004Sooooo00?o0000ooooooooool08Ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05?ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000?ooooo00Goo`00ooooooooooooooooo`00000Eooooo`07ool00?ooooooo`00oooo
oooo003oooooool00002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0002?ooooo00?o0000ooooooooool03oooool0
01kooooo0_l0001;ooooo`04ool00?ooooooo`00ool000Kooooo00Coo`00oooooooo003oo`003?oo
ool00ol0003oooooooooo`0;ooooo`;oo`0000?oooooool00?ooool01?ooool01Ooo003oooooool0
0?ooooooo`0004_ooooo00?o0000ooooooooool06_ooool5o`0000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Cooooo`;oo`000_ooool2ool000;ooooo0_oo0003ooooo`05ool0
0?ooooooooooooooool000005Oooool02?oo003oooooool00?ooooooo`00oooooooo003ooooo0_oo
0002ooooo`;oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0
003oooooooooo`1:ooooo`04ool00?ooooooo`00ool000Kooooo00Coo`00oooooooo003oo`003?oo
ool00ol0003oooooooooo`0;ooooo`;oo`0000?oooooool00?ooool01?ooool01Ooo003oooooool0
0?ooooooo`0004_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`;o0000
E?ooool2ool000;ooooo0_oo0002ooooo`;oo`000oooool01Ooo003ooooooooooooooooo000001Go
oooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00006_ooool2o`00017ooooo000Gooooo`?o00001?ooool00ol0003oooooooooo`1:
ooooo`04ool00?ooooooo`00ool000Kooooo00Coo`00oooooooo003oo`003?ooool00ol0003ooooo
ooooo`0;ooooo`;oo`0000?oooooool00?ooool01?ooool01Ooo003oooooool00?ooooooo`0004_o
oooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0Doooool2ool000;ooooo0_oo0002ooooo`;oo`000oooool01Ooo003ooooooooooooooooo
000001Gooooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0001_ooooo00?o0000ooooooooool03oooool001Kooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo04[ooooo00Coo`00oooooooo003oo`001_ooool01?oo003o
ooooool00?oo000<ooooo`03o`000?oooooooooo00_ooooo0_oo00000oooooooo`00ooooo`04oooo
o`04ool00?ooooooo`00ool004cooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0Doooool2ool000;ooooo0_oo0002ooooo`;oo`000ooo
ool01Ooo003ooooooooooooooooo000001Gooooo00Soo`00oooooooo003oooooool00?ooooooo`00
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool00_oo0003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool05Oooool00ol0003o
ooooooooo`0?ooooo`006_ooool01Ol0003ooooooooooooooooo000004cooooo00Coo`00oooooooo
003oo`001_ooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?oo`00oooo
ooooool00oooool01?oo003oooooool00?oo001<ooooo`03o`000?oooooooooo027ooooo0ol00005
ooooo`03o`000?oooooooooo05?ooooo0_oo0002ooooo`;oo`000_ooool2ool000?ooooo00Goo`00
ooooooooooooooooo`00000Eooooo`08ool00?ooooooo`00oooooooo003oooooool00?ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0003ooooo`05ool00?oooooooooo
oooooooo00000_ooool2ool000;ooooo0_oo0003ooooo`03ool00?oooooooooo00;oo`000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool04Oooool00ol0003ooooooooo
o`0?ooooo`006_ooool01?l0003oooooooooooooool3o`0004[ooooo00Coo`00oooooooo003oo`00
1_ooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0
0oooool01?oo003oooooool00?oo001;ooooo`;o0000:oooool2o`0005Cooooo0_oo0002ooooo`;o
o`000_ooool2ool000?ooooo00Goo`00ooooooooooooooooo`00000Eooooo`08ool00?ooooooo`00
oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo013o
oooo0_l0000Aooooo`005_ooool4o`0000Cooooo00?o0000ooooooooool0B_ooool01?oo003ooooo
ool00?oo0006ooooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ooo003o
ooooooooo`03ooooo`04ool00?ooooooo`00ool004cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`1Cooooo`;oo`000_ooool2ool000;ooooo0_oo0003ooooo`05ool00?oooooooooo
ooooool000005Oooool02?oo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000oooooo00?o0000ooooooooool03oooool001Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1:ooooo`05ool00?ooooooo`00oooooooo00001Oooool00ooo003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool00oooool01?oo003o
ooooool00?oo001<ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Doooool2ool0
00;ooooo0_oo0002ooooo`;oo`000oooool01Ooo003ooooooooooooooooo000001Cooooo00Woo`00
ooooooooooooo`00oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`005_ooool5o`0000?ooooo
00?o0000ooooooooool0Boooool2ool00003oooooooo003ooooo00Cooooo00?oo`00ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooooooo003o
o`00C?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0003ooooo`03o`000?oooooooooo01;ooooo00Woo`00oooooooo
ooooo`00oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Go
o`00ooooooooooooooooool00008ooooo`03o`000?oooooooooo00oooooo000Nooooo`;o0000C?oo
ool01?oo003ooooooooooooo0005ooooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool0
3_ooool00ooo003oooooooooo`03ooooo`04ool00?ooooooo`00ool004cooooo00?o0000oooooooo
ool0:Oooool2o`0005Cooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0003ooooo`03
o`000?oooooooooo01;ooooo00?oo`00ooooooooool00_oo0002ooooo`04ool00?ooooooo`00ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000Oooooo0_l0000A
ooooo`007_ooool00ol0003oooooooooo`1;ooooo`04ool00?ooooooooooool000Gooooo00?oo`00
ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo00Coo`00
oooooooo003oo`00C?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0003ooooo`03ool00?oooooooooo01;ooooo00?o
o`00ooooooooool00_oo0002ooooo`04ool00?ooooooo`00ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ol0003o
ooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool0COooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo
00?oo`00ooooooooool0B_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000?ooooo
00?oo`00ooooooooool04_ooool00ooo003oooooooooo`02ool000;ooooo0_oo00001?ooooooo`00
ooooooooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo04ko
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00ko
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool01_ooool01Ooo003oooooooooooooooooo`0004Oooooo00?oo`00oooo
oooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`0Boooo
o`03ool00?oooooooooo00;oo`000_ooool2ool00006oooooooo003oooooool00?ooooooo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0C_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool0:Oooool2o`0000Oooooo00Go
o`00ooooooooooooooooool00017ooooo`03ool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000?ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`02ool000;ooooo
0_oo00002_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oo
oooooooooooooooo00000oooool01?oo003oooooooooooooool2o`00017ooooo000Nooooo`;o0000
Coooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`05ooooo`;oo`000oooool01Ooo003oooooooooooooooooo`0004?o
oooo00?oo`00oooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000oooool00ooo003o
ooooooooo`0Booooo`03ool00?oooooooooo00;oo`000_ooool2ool0000>oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool03oooool001kooooo00?o0000oooo
ooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04gooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`05ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`03ool00?oooooooooo03kooooo00Ooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo
0002ooooo`;oo`000oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00;oo`000_oo
ool2ool0000Boooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?o0000
ooooooooool03oooool001kooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo04gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`05oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo03kooooo00Ooo`00oooo
oooo003oooooool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`000oooool00ooo003ooooooooo
o`0Booooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo00003_ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;ooooo00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0
C_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool0
:Oooool2o`0000Kooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooooooo
ooooool0000looooo`07ool00?ooooooo`00oooooooo003oooooool00002ooooo`;oo`000_ooool2
ool000;ooooo0_oo000Dooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0000
4_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`04ool00?ooooooooooooooo`;o00004Oooool001kooooo00?o0000oooo
ooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000oooo
ooooool03_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04gooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`05ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0fooooo`0;ool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo00000_ooool2ool000;ooooo0_oo000Doooo
o`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo00005_ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo0002ooooo`;oo`000_ooool2ool00008oooooooo003oooooool00?ooooooo`00oooo
oooo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`00
7_ooool2o`0004oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1=ooooo`03o`00
0?oooooooooo027ooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo0000=?ooool02ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000;o
oooo0_oo0002ooooo`;oo`005?ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;o
o`0001Koooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo0_oo00002?oooooo
o`00oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo
00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0C_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000=?ooool02ooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`00
5?ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`0001[oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo00002?ooooooo`00oooooooo003o
ooooool00?ooooooo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?o0000oooooooo
ool03oooool001kooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo04gooooo00?o0000ooooooooool06_ooool5o`0000?ooooo00?o0000ooooooooool0
1?ooool2o`0000Kooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0^oooo
o`0;ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00000_ooool2ool000;o
oooo0_oo000Dooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo00006_oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool00008oooooooo003o
ooooool00?ooooooo`00oooooooo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooooooo0_l0000A
ooooo`007_ooool00ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool03_ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool0COooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
;?ooool02ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo
0002ooooo`;oo`000oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00;oo`000_oo
ool2ool000;ooooo0_oo00006_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`000_ooool2ool0000<oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`000_ooool2ool000;ooooo0_oo00001?ooooooo`00oooooooo0002ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo000Noooo
o`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>oooo
o`03o`000?oooooooooo00kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1=oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000/ooooo`0;ool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00000_ooool2ool000;ooooo0_oo
0003ooooo`03ool00?oooooooooo00gooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`00
0_ooool2ool0000Joooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0002oooo
o`;oo`0000coooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0002oooo
o`;oo`000_ooool2ool00005oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`000oooool0
0ooo003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo000Nooooo`;o0000Coooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool08Oooool2o`00
00Kooooo00?o0000ooooooooool01Oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`0Vooooo`0;ool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo00000_ooool2ool000;ooooo0_oo0003ooooo`03ool00?oo
oooooooo00gooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2ool0000^oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
00;ooooo0_oo00001Oooooooo`00oooooooo003ooooo00;oo`000_ooool2ool000?ooooo00?oo`00
ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`1>oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Cooooo0_l00006ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00009?ooool03ooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00002oooo
o`;oo`000oooool00ooo003oooooooooo`0=ooooo`05ool00?oooooooooooooooooo00000oooool2
ool000;ooooo0_oo0000=oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo
0002ooooo`;oo`000oooool01?oo003oooooooooooooool2o`00017ooooo000Aooooo`?o00001?oo
ool2o`0000Cooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo04gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`05ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00009?ooool03ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00002ooooo`;oo`000oooool00ooo003oooooooooo`0=ooooo`05ool00?oo
oooooooooooooooo00000oooool2ool000;ooooo0_oo0000=oooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooool00_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`02ooooo`03
o`000?oooooooooo00oooooo000Booooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool0COooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo01kooooo00ooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo00000_ooool2ool000?ooooo00?oo`00oooooooo
ool03Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002
ooooo`0fool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000ooo
ool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo000Booooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1>ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00Gooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool00_oo
0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00006oooool0
4?oo003ooooooooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo0002ooooo`;oo`000_ooool2ool000oooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000_ooool0=_oo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooo`;oo`000_ooool2ool000?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0?
ooooo`004_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo0ol0001>
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0C?ooool2o`0002_ooooo0_l00006
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0001_ooooo013oo`00oooo
ooooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_oo
ool2ool000;ooooo0_oo000?ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000;ooooo0_oo0002ooooo`0bool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo
0_oo0002ooooo`03ool00?oooooooooo00;ooooo0_l0000Aooooo`004_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0C_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool03oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`04ooooo`03ool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003ooooo
ooooo`02ool000?ooooo00?oo`00ooooooooool00_oo0003ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool00_oo0002ooooo`09ool00?oooooo
o`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`000oooool00ooo003o
ooooooooo`09ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo02[oo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooo
oooo00?ooooo00?o0000ooooooooool03oooool0017ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo04gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`03ool00?oooooo
o`0000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool04Oooool00ooo003oooooooooo`02ool000;ooooo00Woo`00oooooooo003oooooool00?oooooo
o`00oooooooo00000_ooool2ool000;ooooo0_oo0003ooooo`03ool00?oooooooooo00Wooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool0:_oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ol0003o
ooooooooo`0?ooooo`004_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003ooooo
ooooo`1>ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03_ooool00ol0003ooooo
ooooo`0?ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0COooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Cooooo00Ooo`00oooooooo003oooooool00?ooooooo`00
00;ooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0001?ooooo00?oo`00ooooooooool0
0_oo0002ooooo`09ool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo0002
ooooo`;oo`000oooool00ooo003oooooooooo`09ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
02[oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo
0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool03oooool001kooooo00?o
0000ooooooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o
0000ooooooooool0:Oooool2o`0000Gooooo00_oo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00002ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000?ooooo00?oo`00ooooooooool00_oo0003ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
3Oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo
00000_ooool2ool000;ooooo0_oo0003ooooo`03ool00?oooooooooo00Wooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo02Koo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;o
o`000_ooool2ool000;ooooo00?oo`00ooooooooool00_ooool2o`00017ooooo000Nooooo`;o0000
Coooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool0
3oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`04ooooo`0;ool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo00000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool03Oooool00ooo003ooooo
ooooo`02ool000;ooooo0_oo0002ooooo`09ool00?ooooooo`00oooooooo003oooooool00?oooooo
o`0000;ooooo0_oo0003ooooo`03ool00?oooooooooo00Wooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`0Rool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;o
oooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003ooooo
ooooo`1>ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03_ooool00ol0003ooooo
ooooo`0?ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0COooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Cooooo00_oo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00002ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`09ool00?ooooooo`00oooooooo
003oooooool00?ooooooo`0000;ooooo0_oo0003ooooo`05ool00?oooooooooooooooooo00001ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`0N
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo
000Nooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0>ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`1=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01?ooool02ooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo00?oo`00ooooooooool00_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0003ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo00Wo
o`00oooooooo003oooooool00?ooooooo`00oooooooo00000_ooool2ool000?ooooo00Goo`00oooo
ooooooooooooool00007ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`0Jool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?o0000oooo
ooooool03oooool001kooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00kooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo04gooooo00?o0000ooooooooool0:Oooool2o`0000Gooooo00_oo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00002ooooo`03ool00?oooooooooo00;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo
00Woo`00oooooooo003oooooool00?ooooooo`00oooooooo00000_ooool2ool000;ooooo0_oo0003
ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`0Fool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool00_ooool2o`00017ooooo
000Nooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0>ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`1=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01?ooool03?oo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`09ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`000oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool0
3_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo
0002ooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo000N
ooooo`;o0000Coooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000
ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000
ooooooooool08_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool03?oo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00
ooooooooooooooooool00004ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000;ooooo0_oo0003ooooo`05ool0
0?oooooooooooooooooo00000_ooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo00koo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0?
ooooo`007_ooool00ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool03_ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0COooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01?ooool03?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oo
oooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo0000
0_ooool2ool000;ooooo0_oo0003ooooo`05ool00?oooooooooooooooooo00000_ooool00ooo003o
ooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`0:ool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00oooooooo
ool00oooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`1>ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`0Qooooo`04o`00
0?ooooooooooo`0000Cooooo1ol000003?oo003o0000ool00?l0003oo`00o`000?oo003o0000ool0
0?l0003oo`00o`0000;oo`000_l00002ool000;o00000_oo0002o`0000;oo`000_l00002ool000;o
00000_oo0002o`0000;oo`000_l00002ool000;o00000_oo0002o`0000;oo`000_l00002ool000;o
00000_oo0002o`0000;oo`000_l00002ool000;o000000Goo`00o`000?l0003o0000ool00004o`00
0003ool00?l0003o000000;oo`000_l00002ool000;o00000_oo0002o`000005ool00?l0003oo`00
o`000?oo00000_l00002ool000;o00000_oo0002o`0000;oo`000ol000001?oo003o0000o`000?oo
0004o`000005ool00?l0003o0000o`000?oo00000ol000000ooo003o0000o`000002ool000;o0000
0_oo0002o`0000;oo`000_l00002ool000;o00000_oo0002o`0000;oo`000_l00002ool000;o0000
0_oo0002o`0000;oo`000_l00002ool000;o00000_oo0002o`0000;oo`000_l00002ool000;o0000
00Coo`00o`000?oo003oo`000_l00002ool000;o000000?oo`00o`000?l000001?l0000Aooooo`00
7_ooool00ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
COooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01?ooool03?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00004ooooo`04ool00?oooooooooo
ool000?ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000?ooooo00Coo`00ooooooooooooo`001?ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Coooooool00?oo
oooooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool03oooool001ko
oooo0_l0001?ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0COooool00ol0003o
ooooooooo`0Qooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool03?oo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool00004oooooooo003oooooool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`04ool00?ooooooooooooooo`;oo`000_ooool01Ooo003oooooool00?ooooooo`00
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000?ooooo00Coo`00ooooooooooooo`001?ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Ko
ooooool00?ooooooo`00oooooooo0002ooooo`03ool00?oooooooooo00?ooooo00?o0000oooooooo
ool03oooool001kooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo04gooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Cooooo00coo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?oooooo
o`00oooooooo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003oooooooooooooool2ool000;ooooo
00Goo`00oooooooo003oooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool00ooo003oooooooooo`06ooooo`05ool00?oooooooooooooooooo00000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo00001_ooooooo`00oooooooo003oooooool000;ooooo00?oo`00ooooooooool00ooo
ool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`1>ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`0Rooooo`;o00001Oooool2
o`0000Gooooo00coo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2
ool000;ooooo0_oo00002?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool00008
oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool01Oooool01?oo003oooooooooooooool2ool000;o
oooo00Goo`00oooooooo003oooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool00ooo003oooooooooo`06ooooo`05ool00?oooooooooooooooooo00000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo00002?ooooooo`00oooooooo003oooooool00?ooooooo`001Oooool2o`00017o
oooo000Nooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool01?ooool03?oo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool00008oooooooo003oooooool0
0?ooooooo`00oooooooo0002ooooo`;oo`0000coooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`05ooooo`04ool00?ooooooooooooooo`;oo`000_ooool02Ooo003oooooool00?ooooooo`00
oooooooo003oooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oo
oooooooo00[ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Soooooool00?ooooooo`00
oooooooo003oooooool000Kooooo00?o0000ooooooooool03oooool001kooooo00?o0000oooooooo
ool0Coooool01Ooo003oooooooooooooooooo`00013ooooo00?o0000ooooooooool03oooool01Ooo
003oooooooooooooooooo`00053ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04
ooooo`0<ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002
ooooo`;oo`0001Soooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo
00000oooool2ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool00_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`0000Soooooool00?ooooooo`00oooooooo003oooooool000Kooooo00?o0000ooooooooool0
3oooool001kooooo0_l0001@ooooo`05ool00?oooooooooooooooooo00004?ooool00ol0003ooooo
ooooo`0?ooooo`05ool00?oooooooooooooooooo0000D?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Cooooo00coo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooool2ool000;ooooo0_oo00006?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00Wooooo00Coo`00
oooooooooooooooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0=ooooo`;oo`000_ooool2ool000;ooooo
00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`0000Soooooool00?ooooooo`00oooooooo003oooooool000Kooooo00?o0000ooooooooool03ooo
ool001kooooo00?o0000ooooooooool0Coooool01Ooo003oooooooooooooooooo`00013ooooo00?o
0000ooooooooool03oooool01Ooo003oooooooooooooooooo`00053ooooo00?o0000ooooooooool0
:Oooool2o`0000Gooooo00coo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooool2ool000;ooooo0_oo00006?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00Wooooo00Coo`00oooo
oooooooooooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool00ooo003oooooooooo`0=ooooo`04ool00?ooooooooooooooo`;oo`00
0_ooool01?oo003oooooooooooooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo0005ooooo`;o0000
4Oooool001kooooo00?o0000ooooooooool0Coooool01Ooo003oooooooooooooooooo`00013ooooo
00?o0000ooooooooool03oooool01Ooo003oooooooooooooooooo`00053ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`03ooooo`0=ool00?ooooooooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ooooo`02ool000;ooooo0_oo00006?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00004oooooooo003ooooo
ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool02Oooool01?oo003oooooooooooooool2ool000;ooooo00Goo`00oooooooo003o
ooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo017o
oooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00002?ooooooo`00oooooooo003oooooool00?oo
ooooo`001_ooool00ol0003oooooooooo`0?ooooo`004Oooool3o`0000?ooooo0ol00004ooooo`03
o`000?oooooooooo04oooooo00Goo`00ooooooooooooooooool0000@ooooo`03o`000?oooooooooo
00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool00oooool00ooo003oooooooooo`02ool000;ooooo00Koo`00oooooooo003oooooool0
0?ooool2ool0000Toooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool00004oooooooo003ooooo
ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo00000oooool01Ooo003ooooooooooooo
ooooo`0000_ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo
00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0Aooooo`05
ool00?oooooooooooooooooo00000oooool01?oo003oooooooooooooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool01?oo003oooooooooooooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`0000Soooooool00?ooooooo`00oooooooo003oooooool0
00Kooooo00?o0000ooooooooool03oooool001;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool00000DOooool01Ooo003oooooooooooooooooo`00013ooooo00?o
0000ooooooooool03oooool01Ooo003oooooooooooooooooo`00053ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo
03Coo`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool00003oooooooo003oo`0000?ooooo
00Goo`00ooooooooooooooooool0000;ooooo`04ool00?ooooooooooooooo`;oo`000_ooool01Ooo
003oooooool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00
ooooooooool05Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooooooo
0_oo0002ooooo`;oo`000_ooool01?oo003oooooooooooooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Soooooool00?ooooooo`00oooooooo003o
ooooool000Kooooo00?o0000ooooooooool03oooool001;ooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooooooool3o`0004oooooo00Goo`00ooooooooooooooooool0000@ooooo`03o`00
0?oooooooooo00oooooo00Goo`00ooooooooooooooooool0001?ooooo`;o0000:oooool2o`0000Co
oooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool0000boooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo0002ooooo`;oo`0000?oooooool00?oo00000oooool01Ooo003oooooooooooooooooo`0000oo
oooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`0000?oooooool00?ooool06oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00
oooooooooooooooo0_oo0002ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00002?ooooooo`00oooooooo003oooooool0
0?ooooooo`001Oooool2o`00017ooooo000Booooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`00001Aooooo`05ool00?oooooooooooooooooo00004?ooool00ol0003ooooooooo
o`0?ooooo`05ool00?oooooooooooooooooo0000D?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool0000boooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo0002ooooo`;oo`0000?oooooool00?oo00000oooool01Ooo003ooooooooo
ooooooooo`0000oooooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`0000?oooooool00?ooool06oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000ooo
ool01?oo003oooooooooooooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00008oooo
oooo003oooooool00?ooooooo`00oooooooo0006ooooo`03o`000?oooooooooo00oooooo000Boooo
o`04o`000?ooooooooooooooo`Co00001?ooool00ol0003oooooooooo`1?ooooo`04ool00?oooooo
ooooool0017ooooo00?o0000ooooooooool03oooool01Ooo003oooooooooooooooooo`00053ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`00
0_ooool2ool000;ooooo0_oo0000<_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool00003oooooooo
003oo`0000;ooooo0_oo0003ooooo`03ool00?oooooooooo00gooooo0_oo0002ooooo`05ool00?oo
ooooo`00oooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?ooool0
7oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool01?oo003oooooooooooooool2ool000;ooooo0_oo
0002ooooo`;oo`0000Soooooool00?ooooooo`00oooooooo003oooooool000Kooooo00?o0000oooo
ooooool03oooool0017ooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo00oooooo00Goo`00oooo
ooooooooooooool0001@ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool0
0ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`0000Goooooool00?ooooooo`00oooo
o`02ool000;ooooo02koo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`0=ooooo`;o
o`000_ooool02Ooo003oooooool00?ooooooo`00oooooooo003oooooool00002ooooo`;oo`000_oo
ool2ool00003oooooooo003ooooo02?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooo
oooooooooooo0_oo0002ooooo`;oo`0000Soooooool00?ooooooo`00oooooooo003oooooool000Ko
oooo00?o0000ooooooooool03oooool001;ooooo00Co0000oooooooooooooooo1Ol00003ooooo`03
o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0?oooo
o`05ool00?oooooooooooooooooo0000D?ooool00ol0003oooooooooo`0Yooooo`;o00001?ooool0
0ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`0000Goooooool00?ooooooo`00oooo
o`02ool000;ooooo0_oo0002ooooo`0Zool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0>ooooo`0=ool00?oo
oooooooooooooooo003oooooool00?ooooooo`00oooooooo003oooooool00002ooooo`;oo`000_oo
ool2ool00003oooooooo003ooooo02?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`;oo`0000Soooooool00?ooooooo`00oooooooo003oooooool000Go
oooo0_l0000Aooooo`007_ooool2o`00053ooooo00Coo`00ooooooooooooo`004Oooool00ol0003o
ooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000D?ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool0
0005oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`000_ooool0:_oo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00
ooooooooool03_ooool03Ooo003oooooooooooooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo00000_ooool2ool000;ooooo0_oo00000oooooooo`00ooooo`0Wooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool01ooo003oooooool00?oooooo
o`00oooooooo00001_ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`1?
ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool03oooool01Ooo003ooooooooo
ooooooooo`00053ooooo00?o0000ooooooooool08Oooool3o`0000Gooooo00?o0000ooooooooool0
0oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo0000
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo02;oo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
oooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0>ooooo`04ool00?oooooooooooooo
o`;oo`000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0002ooooo`;oo`0000?ooooo
ool00?ooool0:oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;o
oooo00?oo`00oooooooo00001_ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003ooooo
ooooo`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool03oooool01Ooo003o
ooooooooooooooooo`00053ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool0
0003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`0Rool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool03_ooool0
1?oo003oooooooooooooool2ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`;oo`00
0_ooool2ool00003oooooooo003ooooo02_ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool00_oo0002ooooo`;oo`001oooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0
003oooooooooo`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool03oooool0
1Ooo003oooooooooooooooooo`00053ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`04ooooo`;o00001?ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`0000?o
ooooool00?oo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`0Nool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0>ooooo`04ool00?oooooo
ooooooooo`;oo`000_ooool02Ooo003oooooool00?ooooooo`00oooooooo003oooooool00002oooo
o`;oo`0000?oooooool00?ooool0;oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo
0_oo0006ooooo`;o00004Oooool001kooooo00?o0000ooooooooool0Coooool01?oo003ooooooooo
oooo000Aooooo`03o`000?oooooooooo00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo00000oooooooo`00ool00002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool05_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`03
ool00?oooooooooo01;ooooo0_oo0002ooooo`09ool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`0000;ooooo0_oo00000oooooooo`00ooooo`0cooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`;o
o`001oooool00ol0003oooooooooo`0?ooooo`007_ooool2o`00053ooooo00Coo`00oooooooooooo
o`004Oooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000D?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool01?oo
003ooooooooooooo0003ooooo`;oo`000_ooool2ool00003oooooooo003oo`0000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool04_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00oooooooo
ool04_ooool2ool000;ooooo00Woo`00oooooooo003oooooool00?ooooooo`00oooooooo00000_oo
ool2ool00003oooooooo003ooooo03?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0007ooooo`03
o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo04oooooo00Coo`00oooooooooooo
o`004Oooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000D?ooool00ol0
003oooooooooo`0Qooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`04ool00?oooooooooo
ool000?ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo00000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool03_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0Booooo`;oo`000_oo
ool02Ooo003oooooool00?ooooooo`00oooooooo003oooooool00002ooooo`;oo`0000?oooooool0
0?ooool0=oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0002ooooo`;oo`000_ooool2ool000Oooooo00?o0000ooooooooool03oooool001kooooo00?o0000
ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo00oooooo00Go
o`00ooooooooooooooooool0001@ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
1?ooool2o`0000Cooooo00Coo`00ooooooooooooo`000oooool2ool000;ooooo0_oo00000ooooooo
o`00ool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool02_oo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`03ool0
0?oooooooooo01;ooooo0_oo0002ooooo`09ool00?ooooooo`00oooooooo003oooooool00?oooooo
o`0000;ooooo0_oo00000oooooooo`00ooooo`0kooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`02ool000;ooooo0_oo0006ooooo`;o00004Oooool001kooooo00?o0000
ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo00oooooo00Go
o`00ooooooooooooooooool0001@ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
0_ooool01Ooo003oooooooooooooooooo`0000?ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo
00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00[oo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool00ooo003ooooo
ooooo`0Booooo`;oo`000_ooool03ooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00010ooooo`05ool00?oooooooooooooooooo00000_ooool2ool0
00;ooooo0_oo0007ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo04oo
oooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooo
oooooooo0000D?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo00Goo`00
ooooooooooooooooool00003ooooo`04ool00?ooooooooooooooo`;oo`0000?oooooool00?oo0000
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00[oo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool00ooo003ooooooooo
o`0Booooo`;oo`000_ooool03ooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00010ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;o
oooo0_oo0007ooooo`03o`000?oooooooooo00oooooo000Nooooo`;o0000D?ooool01?oo003ooooo
oooooooo000Aooooo`03o`000?oooooooooo00oooooo00Goo`00ooooooooooooooooool0001@oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Coo`00oooooooooooooooo0_oo00000oooooooo`00ool00002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`04ool00?oo
ooooo`00ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo01;ooooo0_oo0002ooooo`0?ool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0004Co
oooo00?oo`00ooooooooool00_oo0002ooooo`;oo`001oooool00ol0003oooooooooo`0?ooooo`00
7_ooool00ol0003oooooooooo`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000oooooooo
ool03oooool01Ooo003oooooooooooooooooo`00053ooooo00?o0000ooooooooool0:Oooool2o`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`04ool00?ooooooo`00ool000;ooooo00?oo`00ooooooooool0
4_ooool04?oo003oooooooooooooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool2ool004Gooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`001_ooool2o`00
017ooooo000Nooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Oooool00ol0
003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000D?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Goooooool00?oooooo
ooooool0000Dooooo`04ool00?ooooooooooooooo`;oo`000_ooool02?oo003oooooool00?oooooo
o`00oooooooo003ooooo0_oo0018ooooo`05ool00?oooooooooooooooooo00002?ooool00ol0003o
ooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`1?ooooo`04ool00?ooooooooooool0017o
oooo00?o0000ooooooooool03oooool01Ooo003oooooooooooooooooo`00053ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00005oooooooo
003ooooooooooooo00005?ooool01?oo003oooooooooooooool2ool000;ooooo00Soo`00oooooooo
003oooooool00?ooooooo`00ooooo`;oo`00C?ooool00ooo003oooooooooo`06ooooo`03o`000?oo
oooooooo00oooooo000Nooooo`;o0000D?ooool01?oo003ooooooooooooo000Aooooo`03o`000?oo
oooooooo00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00002ooooo`;oo`000_ooool01?oo003oooooooooooooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00005oooooooo003o
oooooooooooo00005?ooool01?oo003oooooooooooooool2ool000;ooooo00Soo`00oooooooo003o
ooooool00?ooooooo`00ooooo`;oo`00EOooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0
003oooooooooo`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool03oooool0
1Ooo003oooooooooooooooooo`00053ooooo00?o0000ooooooooool0:Oooool2o`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;o
oooo00Goo`00ooooooooooooooooool00003ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo00001?ooooooo`00oooooooo000Eooooo`04ool00?oooooo
ooooooooo`;oo`000_ooool02?oo003oooooool00?ooooooo`00oooooooo003ooooo0_oo001Doooo
o`;o00004Oooool001kooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000Aoooo
o`03o`000?oooooooooo00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool01_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool00_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooo
ooooooooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?oooooo
o`00oooooooo000Eooooo`04o`000?ooooooooooooooo`;oo`000_ooool02?oo003oooooool00?oo
ooooo`00oooooooo003ooooo0_oo001Eooooo`03o`000?oooooooooo00oooooo000@ooooo`Go0000
0oooool2o`0000Cooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03
o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`000_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`005Oooool01?l0003ooooo
ooooooooool2ool000;ooooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`00EOoo
ool00ol0003oooooooooo`0?ooooo`004Oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03
o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00kooooo00?oo`00ooooooooool00_oo0002ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool00004oooooooo003oooooool001Gooooo00Co0000oooooooooooo
oooo0_oo0002ooooo`;oo`000_ooool01?oo003oooooool00?ooool2ool005Gooooo00?o0000oooo
ooooool03oooool001;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`?o0000Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo00?oo`00
oooooooo0000D?ooool2o`0002_ooooo0_l0000?ooooo`03ool00?oooooooooo00;oo`000_ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?ooooooo`00oooooooo000Eoooo
o`04o`000?ooooooooooooooo`;oo`000_ooool2ool000;ooooo00Coo`00oooooooo003ooooo0_oo
001Dooooo`;o00004Oooool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool00000DOooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013o
oooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo017o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool0
0?ooooooooooooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo00001?ooooooo`00oooooooo000Eooooo`04o`000?ooooooooooooooo`;oo`000_ooool2
ool000;ooooo00Coo`00oooooooo003ooooo0_oo001Eooooo`03o`000?oooooooooo00oooooo000@
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo04oooooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0@ooooo`03
ool00?ooooooo`00057ooooo00?o0000ooooooooool08?ooool5o`0000Cooooo00?o0000oooooooo
ool05Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo
00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`0000Coooooool00?ooooooo`005Oooool01?l0003oooooooooooooool2ool000;ooooo0_oo0002
ooooo`04ool00?ooooooo`00ooooo`;oo`00EOooool00ol0003oooooooooo`0?ooooo`004?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool04?ooool00ooo003o
ooooool0001Aooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool01?oo003oooooooooooooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo00001?ooooooo`00oooooooo000Eooooo`05o`000?oooooooooooooooooo00000ooo
ool2ool000;ooooo0_oo0002ooooo`;oo`00EOooool00ol0003oooooooooo`0?ooooo`004Oooool3
o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Ooo
ool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`04ooooo`;o00006_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo00001?ooooooo`00oooooooo000Eooooo`05o`000?oooooooooooooooooo
00000oooool2ool000;ooooo0_oo0002ooooo`;oo`00E?ooool2o`00017ooooo000Nooooo`;o0000
D?ooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo
0000DOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool07Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?ooooooo`00oooooooo000Eooooo`05
o`000?oooooooooooooooooo00000oooool2ool000;ooooo0_oo0002ooooo`;oo`00EOooool00ol0
003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`1?ooooo`04ool00?ooooooooooool0
017ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo
023ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo027ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`;oo`000_ooool2ool0
00;ooooo0_oo00001?ooooooo`00oooooooo000Eooooo`05o`000?oooooooooooooooooo00000ooo
ool2ool000;ooooo0_oo0002ooooo`;oo`00EOooool00ol0003oooooooooo`0?ooooo`007_ooool0
0ol0003oooooooooo`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool04?oo
ool00ooo003oooooool0001Aooooo`03o`000?oooooooooo023ooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo027ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2ool00004oooo
oooo003oooooool001Gooooo00Go0000ooooooooooooooooool00003ooooo`;oo`000_ooool2ool0
00;ooooo0_oo001Eooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo04oo
oooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00
057ooooo00?o0000ooooooooool08Oooool3o`0000Gooooo0_l0000Vooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003oooooooooooooool2ool0
0004oooooooo003oooooool001Gooooo00Go0000ooooooooooooooooool00003ooooo`;oo`000_oo
ool2ool000;ooooo0_oo001Dooooo`;o00004Oooool001kooooo00?o0000ooooooooool0Coooool0
1?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOoo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Wooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`06ool00?ooooooooooool00?ooooooo`00
5Oooool00ol0003oooooooooo`05ooooo`;oo`000_ooool2ool000;ooooo0_oo001Eooooo`03o`00
0?oooooooooo00oooooo000Nooooo`;o0000D?ooool00ooo003oooooool0000Booooo`03o`000?oo
oooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo02gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002
ooooo`03ool00?ooooooo`0001Gooooo00?o0000ooooooooool01Oooool01?oo003ooooooooooooo
ool2ool000;ooooo0_oo001Eooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooo
oooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02gooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00002ooooo`;oo`005_ooool00ol0003oooooooooo`05oooo
o`04ool00?ooooooooooooooo`;oo`000_ooool2ool005Gooooo00?o0000ooooooooool03oooool0
01kooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo
003oooooool0001Aooooo`03o`000?oooooooooo02Wooooo0_l0000booooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00;oo`005_ooool00ol0003oooooooooo`05ooooo`04ool0
0?ooooooooooooooo`;oo`000_ooool2ool005Cooooo0_l0000Aooooo`007_ooool00ol0003ooooo
ooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0aooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00;oo`005_ooool00ol0003oooooooooo`05ooooo`04ool00?oooooo
ooooooooo`;oo`000_ooool2ool005Gooooo00?o0000ooooooooool03oooool001kooooo00?o0000
ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001A
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000_ooool2ool001Kooooo00?o0000ooooooooool01Oooool01?oo003oooooooooooooool2ool0
00;ooooo0_oo001Eooooo`03o`000?oooooooooo00oooooo000Nooooo`;o0000DOooool2ool001;o
oooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0>Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00;oo`005_ooool00ol0003oooooooooo`05
ooooo`05ool00?oooooooooooooooooo00000oooool2ool005Gooooo00?o0000ooooooooool03ooo
ool001kooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool0
0ooo003oooooool0001Aooooo`03o`000?oooooooooo02Wooooo0_l0000jooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
0_oo000Fooooo`03o`000?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00003ooooo`;o
o`00E?ooool2o`00017ooooo000Nooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`00
0?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo03gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000_ooool2ool001Kooooo00?o0000ooooooooool02Oooool01?oo003oooooooooooooool2
ool005Gooooo00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0D?ooool2ool0
01;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0@Oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool00_oo000Fooooo`03o`000?oooooooooo00Wooooo00Goo`00ooooooooooooooooool0
001Fooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo053ooooo0_oo000B
ooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo047ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;oo`005_ooool00ol0003oooooooooo`09ooooo`05ool00?oooooooooooooooooo0000
E_ooool00ol0003oooooooooo`0?ooooo`007_ooool2o`00057ooooo0_oo000Booooo`03o`000?oo
oooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Yooooo`;o0000A_oo
ool01Ooo003oooooooooooooooooo`0000;ooooo0_oo000Fooooo`03o`000?oooooooooo00Wooooo
00Goo`00ooooooooooooooooool0001Eooooo`;o00004Oooool001kooooo00?o0000ooooooooool0
D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0AOooool01Ooo003oooooooooooooooooo`0000;o
oooo0_oo000Fooooo`03o`000?oooooooooo00Wooooo00Goo`00ooooooooooooooooool0001Foooo
o`03o`000?oooooooooo00oooooo000@ooooo`Go00000_ooool3o`0000Cooooo00?o0000oooooooo
ool0D?ooool2ool001;ooooo00?o0000ooooooooool04Oooool2ool0057ooooo00?o0000oooooooo
ool08Oooool3o`0000Gooooo00?o0000ooooooooool0BOooool00ooo003oooooooooo`02ool001Ko
oooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`1Dooooo`03o`000?oooooooooo00oo
oooo000Aooooo`06o`000?ooooooooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo
000005;ooooo0_oo000Booooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0D?ooool0
0ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`19ooooo`03ool00?oooooooooo00;oo`005_ooool00ol0003oooooooooo`0=ooooo`03ool00?oo
oooooooo05Cooooo00?o0000ooooooooool03oooool001;ooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooooooool3o`00053ooooo0_oo000Booooo`03o`000?oooooooooo017ooooo00?o
o`00ooooooooool0Coooool2o`0002Kooooo00?o0000ooooooooool00_ooool2o`0004gooooo0_oo
000Fooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0Doooool2o`00017ooooo000C
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00001Cooooo`03ool00?oo
oooooooo013ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oo
oooooooo02;ooooo0_l00005ooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool05Ooo
ool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00oooooo000@ooooo`06o`000?oooooo
ooooooooool0003ooooo1?l00004ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
3oooool0013ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo000Aooooo`?o00000_ooool5o`0000?o
oooocol0000Sooooo`?o00001Oooooo?o`00017ooooo003oooooooWooooo003oooooooWooooo003o
ooooooWooooo003oooooooWooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {147.312, 0}} -> {-0.0551454, -0.0147182, \
0.00419541, 0.00419541}, {{13.125, 240.125}, {143.75, 3.5}} -> {-6.82097, \
-3.74986, 0.0509597, 0.206369}, {{262.812, 489.812}, {143.75, 3.5}} -> \
{-19.5092, -3.92367, 0.0508661, 0.049699}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plot more than one period of the DTFT as a function of \
frequency\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Abs[X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-2.5\) 
            fs, 2.5  fs}, \ PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
        AspectRatio \[Rule] 1/3, PlotPoints \[Rule] 400, \ 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0190476 0.00793648 0.0126841 [
[.11905 -0.0125 -9 -9 ]
[.11905 -0.0125 9 0 ]
[.30952 -0.0125 -9 -9 ]
[.30952 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -6 -9 ]
[.69048 -0.0125 6 0 ]
[.88095 -0.0125 -6 -9 ]
[.88095 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -6 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .07136 -6 -4.5 ]
[-0.0125 .07136 0 4.5 ]
[-0.0125 .13478 -12 -4.5 ]
[-0.0125 .13478 0 4.5 ]
[-0.0125 .1982 -12 -4.5 ]
[-0.0125 .1982 0 4.5 ]
[-0.0125 .26162 -12 -4.5 ]
[-0.0125 .26162 0 4.5 ]
[-0.0125 .32504 -12 -4.5 ]
[-0.0125 .32504 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-20)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-10)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(10)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(20)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.15714 0 m
.15714 .00375 L
s
.19524 0 m
.19524 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.27143 0 m
.27143 .00375 L
s
.34762 0 m
.34762 .00375 L
s
.38571 0 m
.38571 .00375 L
s
.42381 0 m
.42381 .00375 L
s
.4619 0 m
.4619 .00375 L
s
.5381 0 m
.5381 .00375 L
s
.57619 0 m
.57619 .00375 L
s
.61429 0 m
.61429 .00375 L
s
.65238 0 m
.65238 .00375 L
s
.72857 0 m
.72857 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.80476 0 m
.80476 .00375 L
s
.84286 0 m
.84286 .00375 L
s
.08095 0 m
.08095 .00375 L
s
.04286 0 m
.04286 .00375 L
s
.00476 0 m
.00476 .00375 L
s
.91905 0 m
.91905 .00375 L
s
.95714 0 m
.95714 .00375 L
s
.99524 0 m
.99524 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(0)] -0.0125 .00794 1 0 Mshowa
0 .07136 m
.00625 .07136 L
s
[(5)] -0.0125 .07136 1 0 Mshowa
0 .13478 m
.00625 .13478 L
s
[(10)] -0.0125 .13478 1 0 Mshowa
0 .1982 m
.00625 .1982 L
s
[(15)] -0.0125 .1982 1 0 Mshowa
0 .26162 m
.00625 .26162 L
s
[(20)] -0.0125 .26162 1 0 Mshowa
0 .32504 m
.00625 .32504 L
s
[(25)] -0.0125 .32504 1 0 Mshowa
.125 Mabswid
0 .02062 m
.00375 .02062 L
s
0 .0333 m
.00375 .0333 L
s
0 .04599 m
.00375 .04599 L
s
0 .05867 m
.00375 .05867 L
s
0 .08404 m
.00375 .08404 L
s
0 .09672 m
.00375 .09672 L
s
0 .10941 m
.00375 .10941 L
s
0 .12209 m
.00375 .12209 L
s
0 .14746 m
.00375 .14746 L
s
0 .16015 m
.00375 .16015 L
s
0 .17283 m
.00375 .17283 L
s
0 .18551 m
.00375 .18551 L
s
0 .21088 m
.00375 .21088 L
s
0 .22357 m
.00375 .22357 L
s
0 .23625 m
.00375 .23625 L
s
0 .24893 m
.00375 .24893 L
s
0 .2743 m
.00375 .2743 L
s
0 .28699 m
.00375 .28699 L
s
0 .29967 m
.00375 .29967 L
s
0 .31235 m
.00375 .31235 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.11905 .32708 m
.11905 .33333 L
s
.30952 .32708 m
.30952 .33333 L
s
.5 .32708 m
.5 .33333 L
s
.69048 .32708 m
.69048 .33333 L
s
.88095 .32708 m
.88095 .33333 L
s
.125 Mabswid
.15714 .32958 m
.15714 .33333 L
s
.19524 .32958 m
.19524 .33333 L
s
.23333 .32958 m
.23333 .33333 L
s
.27143 .32958 m
.27143 .33333 L
s
.34762 .32958 m
.34762 .33333 L
s
.38571 .32958 m
.38571 .33333 L
s
.42381 .32958 m
.42381 .33333 L
s
.4619 .32958 m
.4619 .33333 L
s
.5381 .32958 m
.5381 .33333 L
s
.57619 .32958 m
.57619 .33333 L
s
.61429 .32958 m
.61429 .33333 L
s
.65238 .32958 m
.65238 .33333 L
s
.72857 .32958 m
.72857 .33333 L
s
.76667 .32958 m
.76667 .33333 L
s
.80476 .32958 m
.80476 .33333 L
s
.84286 .32958 m
.84286 .33333 L
s
.08095 .32958 m
.08095 .33333 L
s
.04286 .32958 m
.04286 .33333 L
s
.00476 .32958 m
.00476 .33333 L
s
.91905 .32958 m
.91905 .33333 L
s
.95714 .32958 m
.95714 .33333 L
s
.99524 .32958 m
.99524 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .07136 m
1 .07136 L
s
.99375 .13478 m
1 .13478 L
s
.99375 .1982 m
1 .1982 L
s
.99375 .26162 m
1 .26162 L
s
.99375 .32504 m
1 .32504 L
s
.125 Mabswid
.99625 .02062 m
1 .02062 L
s
.99625 .0333 m
1 .0333 L
s
.99625 .04599 m
1 .04599 L
s
.99625 .05867 m
1 .05867 L
s
.99625 .08404 m
1 .08404 L
s
.99625 .09672 m
1 .09672 L
s
.99625 .10941 m
1 .10941 L
s
.99625 .12209 m
1 .12209 L
s
.99625 .14746 m
1 .14746 L
s
.99625 .16015 m
1 .16015 L
s
.99625 .17283 m
1 .17283 L
s
.99625 .18551 m
1 .18551 L
s
.99625 .21088 m
1 .21088 L
s
.99625 .22357 m
1 .22357 L
s
.99625 .23625 m
1 .23625 L
s
.99625 .24893 m
1 .24893 L
s
.99625 .2743 m
1 .2743 L
s
.99625 .28699 m
1 .28699 L
s
.99625 .29967 m
1 .29967 L
s
.99625 .31235 m
1 .31235 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
.5 0 m
.5 .33333 L
s
1 0 0 r
.5 Mabswid
.02381 .00794 m
.02435 .0134 L
.02466 .01611 L
.02494 .01813 L
.02508 .01895 L
.02524 .01966 L
.02532 .01998 L
.0254 .02021 L
.02548 .02039 L
.02552 .02046 L
.02556 .02052 L
.02563 .02059 L
.0257 .02063 L
.02577 .02062 L
.02583 .02057 L
.02591 .02047 L
.02598 .02034 L
.02605 .02014 L
.02613 .01988 L
.0263 .01916 L
.02646 .0183 L
.02682 .01573 L
.02713 .01297 L
.02729 .01136 L
.02746 .00957 L
.02754 .00872 L
.02762 .00796 L
.02769 .00868 L
.02777 .00947 L
.02805 .01235 L
.02837 .01531 L
.02867 .01763 L
.02894 .01923 L
.02909 .01988 L
.02923 .02032 L
.02931 .02048 L
.02938 .02059 L
.02946 .02067 L
.0295 .02069 L
.02954 .02069 L
.02962 .02065 L
.02966 .02061 L
.0297 .02056 L
.02978 .02042 L
.02986 .02022 L
.03001 .0197 L
.03017 .01895 L
.03046 .0171 L
.0308 .01425 L
.03112 .01115 L
Mistroke
.03127 .00957 L
.03135 .00879 L
.03142 .00807 L
.0315 .00864 L
.03154 .00908 L
.03158 .00954 L
.03173 .01109 L
.03207 .01445 L
.03239 .01712 L
.03267 .01893 L
.03283 .0197 L
.03297 .02023 L
.03305 .02046 L
.03313 .02062 L
.03317 .02069 L
.03321 .02074 L
.03325 .02078 L
.0333 .02081 L
.03337 .02081 L
.03344 .02077 L
.03352 .02067 L
.03356 .0206 L
.0336 .02051 L
.03376 .02005 L
.03384 .01975 L
.03392 .01936 L
.0341 .01836 L
.03426 .01724 L
.03456 .01477 L
.03488 .01166 L
.03505 .00998 L
.03513 .00914 L
.0352 .00836 L
.03527 .00823 L
.03534 .00898 L
.03549 .01056 L
.03605 .01598 L
.03632 .0181 L
.03647 .01901 L
.03662 .01979 L
.03676 .02033 L
.03683 .02057 L
.0369 .02074 L
.03697 .02086 L
.03703 .02094 L
.0371 .02099 L
.03716 .02101 L
.03724 .02097 L
.03731 .02089 L
.03735 .02082 L
Mistroke
.0374 .02074 L
.03747 .02055 L
.03762 .02003 L
.03776 .0194 L
.03809 .01729 L
.0384 .01464 L
.0387 .01171 L
.03884 .01017 L
.03898 .00872 L
.03905 .00797 L
.03909 .00839 L
.03913 .00884 L
.0393 .01065 L
.03959 .01366 L
.03987 .01622 L
.04016 .01849 L
.04031 .01938 L
.04044 .02007 L
.04056 .02056 L
.04063 .02077 L
.0407 .02096 L
.04077 .02111 L
.04084 .0212 L
.04091 .02126 L
.04099 .02127 L
.04106 .02123 L
.04113 .02114 L
.0412 .02101 L
.04126 .02086 L
.04142 .02034 L
.04158 .01955 L
.04189 .01756 L
.04249 .01196 L
.04265 .01018 L
.04275 .00918 L
.04279 .00869 L
.04283 .00822 L
.04287 .00808 L
.04291 .00854 L
.043 .00951 L
.04315 .01118 L
.04345 .01428 L
.04377 .0172 L
.04391 .01835 L
.04407 .01939 L
.0442 .02014 L
.04435 .02078 L
.04443 .02108 L
.04451 .0213 L
.04459 .02146 L
Mistroke
.04466 .02156 L
.04471 .02159 L
.04475 .02161 L
.04479 .02161 L
.04483 .0216 L
.04488 .02157 L
.04492 .02151 L
.04497 .02143 L
.04501 .02135 L
.04509 .02115 L
.04516 .02092 L
.04532 .02024 L
.04546 .01946 L
.04561 .01844 L
.04623 .01279 L
.0464 .01094 L
.04649 .00991 L
.04658 .00892 L
.04665 .00808 L
.04673 .0087 L
.04678 .00921 L
.04682 .0097 L
.0469 .01061 L
.04749 .01671 L
.04779 .01911 L
.04796 .02021 L
.04811 .021 L
.04826 .02155 L
.04833 .02175 L
.04841 .02191 L
.04845 .02197 L
.04849 .02201 L
.04854 .02204 L
.04858 .02205 L
.04865 .02203 L
.04869 .022 L
.04873 .02195 L
.0488 .02183 L
.04887 .02167 L
.04901 .02118 L
.04916 .02051 L
.04931 .01958 L
.04961 .01729 L
.04989 .01458 L
.05016 .0116 L
.0503 .01006 L
.05035 .00937 L
.05042 .00862 L
.05049 .0081 L
.05056 .00898 L
Mistroke
.05072 .01084 L
.051 .01395 L
.05129 .01698 L
.05161 .01965 L
.05177 .02067 L
.05191 .02144 L
.05204 .02198 L
.05212 .02221 L
.05218 .02237 L
.05225 .02249 L
.05231 .02256 L
.05237 .02259 L
.05244 .02258 L
.05251 .02253 L
.05259 .02242 L
.05265 .02228 L
.05272 .02208 L
.05287 .02148 L
.05304 .02059 L
.05334 .01837 L
.0539 .0126 L
.05406 .01064 L
.05422 .00876 L
.0543 .00807 L
.05434 .00861 L
.05438 .0091 L
.05456 .01126 L
.05485 .01469 L
.05516 .01793 L
.05544 .02033 L
.05559 .02135 L
.05576 .02221 L
.05583 .02252 L
.0559 .02279 L
.05597 .02297 L
.05604 .02312 L
.05611 .02321 L
.05618 .02326 L
.05625 .02326 L
.05631 .02322 L
.05638 .02311 L
.05642 .02303 L
.05647 .02292 L
.05661 .02242 L
.0567 .02204 L
.05679 .02156 L
.05695 .02049 L
.05727 .01777 L
.05755 .01467 L
.05784 .01119 L
Mistroke
.05792 .01014 L
.058 .00914 L
.05807 .00824 L
.05815 .00861 L
.05821 .00947 L
.05829 .01041 L
.05843 .01229 L
.0587 .01549 L
.05901 .01883 L
.05918 .02039 L
.05934 .02164 L
.05949 .02259 L
.05957 .02301 L
.05966 .02338 L
.05973 .02363 L
.05981 .02385 L
.05988 .02399 L
.05994 .02407 L
.06001 .0241 L
.06009 .02408 L
.06016 .024 L
.06023 .02387 L
.0603 .02367 L
.06039 .02338 L
.06054 .02267 L
.06069 .02168 L
.06086 .02037 L
.06116 .01744 L
.06141 .01445 L
.06169 .01088 L
.06177 .00979 L
.06185 .00875 L
.06191 .00807 L
.06199 .0091 L
.06227 .01292 L
.06257 .01666 L
.06288 .02015 L
.06303 .0215 L
.06318 .02272 L
.06331 .02359 L
.06346 .02431 L
.06354 .02464 L
.06362 .02487 L
.0637 .02503 L
.06377 .02512 L
.06382 .02514 L
.06386 .02514 L
.0639 .02512 L
.06394 .02508 L
.06398 .02501 L
Mistroke
.06403 .02491 L
.06412 .02467 L
.0642 .02438 L
.06428 .02399 L
.06443 .02308 L
.06472 .02072 L
.06501 .01756 L
.06533 .01347 L
.06547 .01143 L
.06555 .01029 L
.06563 .00922 L
.06569 .00829 L
.06576 .00858 L
.06583 .00968 L
.0659 .01069 L
.06624 .01551 L
.06656 .0196 L
.06685 .02259 L
.067 .02387 L
.06716 .02498 L
.06724 .0254 L
.06732 .02576 L
.06739 .02603 L
.06746 .02622 L
.06753 .02635 L
.0676 .02643 L
.06767 .02644 L
.06774 .02639 L
.06782 .02626 L
.0679 .02606 L
.06798 .02578 L
.06806 .02539 L
.0682 .02454 L
.06836 .02333 L
.06864 .02058 L
.06893 .01687 L
.06919 .01313 L
.06933 .01094 L
.0694 .00985 L
.06947 .00884 L
.06951 .00822 L
.06955 .0083 L
.06959 .00895 L
.06963 .00967 L
.06978 .01205 L
.07008 .01652 L
.0704 .0209 L
.07057 .02297 L
.07074 .02465 L
.0709 .02596 L
Mistroke
.07098 .02653 L
.07107 .02704 L
.07114 .0274 L
.07122 .02771 L
.0713 .02792 L
.07136 .02804 L
.07144 .02811 L
.07151 .0281 L
.07158 .02803 L
.07165 .02789 L
.07172 .02766 L
.0718 .02733 L
.07195 .02652 L
.0721 .02534 L
.07227 .02378 L
.07257 .02022 L
.07291 .01509 L
.07308 .01231 L
.07315 .01105 L
.07323 .00967 L
.07331 .00838 L
.07338 .00869 L
.07344 .00984 L
.07351 .01106 L
.07381 .01618 L
.07414 .02134 L
.07445 .02529 L
.0746 .02694 L
.07475 .0282 L
.0749 .02922 L
.07498 .02963 L
.07507 .02996 L
.07511 .03009 L
.07515 .03018 L
.0752 .03025 L
.07525 .0303 L
.07529 .0303 L
.07533 .03029 L
.07537 .03024 L
.07542 .03016 L
.07546 .03006 L
.0755 .02993 L
.07559 .0296 L
.07566 .02919 L
.07574 .02873 L
.0759 .02746 L
.07605 .02594 L
.07633 .02236 L
.07662 .01761 L
.07678 .0148 L
Mistroke
.07695 .01163 L
.07703 .01006 L
.07711 .00856 L
.07718 .00867 L
.07726 .01015 L
.07754 .01565 L
.07784 .02114 L
.07816 .02619 L
.07843 .02961 L
.07859 .0311 L
.07866 .03166 L
.07874 .03217 L
.0788 .03252 L
.07887 .03284 L
.07893 .03305 L
.07899 .03319 L
.07906 .03328 L
.07913 .03329 L
.0792 .03321 L
.07927 .03304 L
.07934 .0328 L
.07941 .03244 L
.07955 .03156 L
.07971 .03013 L
.07986 .02846 L
.08017 .02378 L
.08047 .01821 L
.08073 .01283 L
.08081 .01121 L
.08088 .00967 L
.08094 .00827 L
.08101 .00913 L
.08108 .01085 L
.08116 .01266 L
.08131 .01588 L
.08158 .02187 L
.08188 .02752 L
.08216 .03195 L
.08231 .03392 L
.08248 .0356 L
.08255 .03619 L
.08263 .03671 L
.08269 .03705 L
.08277 .03734 L
.08284 .03751 L
.08291 .03758 L
.08297 .03756 L
.08304 .03745 L
.08312 .03722 L
.08319 .03685 L
Mistroke
.08327 .03639 L
.08334 .03587 L
.08347 .03461 L
.08361 .03286 L
.08387 .02877 L
.08444 .01628 L
.0846 .01228 L
.08468 .01001 L
.08473 .00888 L
.08477 .00804 L
.08484 .01008 L
.08492 .01231 L
.08507 .01621 L
.08538 .02441 L
.08572 .03232 L
.08588 .03545 L
.08604 .03832 L
.08618 .04039 L
.08634 .04215 L
.08641 .04283 L
.08648 .04336 L
.08654 .04373 L
.08661 .04403 L
.08668 .04421 L
.08675 .04429 L
.08681 .04427 L
.08687 .04414 L
.08695 .04385 L
.08702 .04346 L
.0871 .04287 L
.08717 .04215 L
.08731 .04053 L
.08746 .03826 L
.08811 .02286 L
.08826 .01832 L
.08841 .01325 L
.08848 .0111 L
.08855 .00876 L
.08862 .00972 L
.08869 .01216 L
.08899 .02225 L
.0893 .0327 L
.08958 .04085 L
.08988 .04816 L
.09006 .05151 L
.09013 .05273 L
.09022 .05387 L
.09029 .05471 L
.09037 .05541 L
.09042 .05572 L
Mistroke
.09046 .05594 L
.0905 .05611 L
.09054 .05623 L
.09061 .05631 L
.09069 .05621 L
.09076 .05594 L
.09083 .05554 L
.0909 .05488 L
.09099 .05394 L
.09114 .05162 L
.09128 .04877 L
.09144 .045 L
.09171 .03641 L
.09201 .02479 L
.09217 .01787 L
.09226 .01389 L
.09234 .01005 L
.09238 .00795 L
.09243 .01028 L
.09251 .01438 L
.09268 .02251 L
.093 .03858 L
.09331 .05337 L
.0936 .06553 L
.09388 .07486 L
.09404 .0789 L
.09418 .08172 L
.09426 .08294 L
.09433 .08379 L
.09437 .08413 L
.09441 .08442 L
.09446 .08462 L
.0945 .08473 L
.09458 .08467 L
.09465 .08436 L
.09469 .08407 L
.09473 .08366 L
.09481 .08266 L
.09489 .08116 L
.09497 .07936 L
.09512 .075 L
.09529 .06883 L
.09546 .06043 L
.09578 .04089 L
.09593 .02955 L
.09607 .01819 L
.09614 .0122 L
.09622 .01045 L
.09629 .01706 L
.09636 .02338 L
Mistroke
.09666 .05437 L
.0972 .11627 L
.09785 .19093 L
.09845 .2534 L
.09871 .27603 L
.09899 .29581 L
.09913 .30431 L
.09929 .31204 L
.09944 .31758 L
.09957 .32143 L
.09965 .32307 L
.09969 .32375 L
.09973 .32435 L
.09981 .3251 L
.09988 .32539 L
.09995 .3253 L
.10002 .32489 L
.10009 .32409 L
.10017 .32281 L
.10025 .321 L
.10034 .31848 L
.1005 .3125 L
.10081 .29661 L
.10113 .27409 L
.10143 .24825 L
.10199 .19138 L
.10261 .12377 L
.10326 .05603 L
.10353 .0304 L
.10361 .02412 L
.10369 .01753 L
.10376 .01156 L
.10383 .00962 L
.10387 .01254 L
.10392 .01567 L
.104 .02174 L
.10416 .03159 L
.10446 .04743 L
.10474 .05776 L
.1049 .06192 L
.10497 .06348 L
.10504 .06471 L
.1051 .06567 L
.10516 .06637 L
.10523 .06697 L
.1053 .06739 L
.10537 .06759 L
.10544 .06758 L
.10551 .06738 L
.10558 .06701 L
Mistroke
.10565 .06639 L
.10572 .0656 L
.10586 .06365 L
.106 .06091 L
.10616 .05725 L
.10671 .04054 L
.10702 .02936 L
.10735 .01727 L
.10749 .01244 L
.10756 .00996 L
.10763 .00846 L
.10768 .0098 L
.10772 .01123 L
.1078 .0137 L
.10795 .01828 L
.10827 .02656 L
.10842 .02992 L
.10856 .03255 L
.10869 .03451 L
.10883 .03624 L
.10898 .03753 L
.10905 .03804 L
.10913 .03839 L
.1092 .03864 L
.10925 .03873 L
.10929 .03877 L
.10936 .03874 L
.1094 .03868 L
.10944 .03859 L
.10951 .03835 L
.10959 .03797 L
.10973 .03698 L
.1099 .03538 L
.11007 .03322 L
.11039 .02836 L
.11096 .01744 L
.11112 .0141 L
.11128 .01096 L
.11134 .00962 L
.11141 .00821 L
.11149 .00918 L
.11157 .01056 L
.11185 .01547 L
.11214 .01986 L
.11239 .02283 L
.11254 .02417 L
.11267 .02516 L
.11281 .02596 L
.11289 .02629 L
.11296 .02652 L
Mistroke
.11303 .02667 L
.11309 .02676 L
.11316 .0268 L
.11323 .02677 L
.11331 .02667 L
.11338 .0265 L
.11346 .02627 L
.11352 .02601 L
.11369 .02515 L
.11384 .02408 L
.11437 .01894 L
.11494 .01178 L
.11509 .00978 L
.11518 .00874 L
.11522 .00821 L
.11526 .00822 L
.1153 .00872 L
.11534 .00924 L
.11542 .01017 L
.11556 .01189 L
.11583 .01481 L
.11613 .01748 L
.1163 .01878 L
.11647 .01975 L
.11662 .02047 L
.1167 .02075 L
.11679 .02099 L
.11686 .02116 L
.11694 .02126 L
.11701 .02132 L
.11705 .02133 L
.1171 .02133 L
.11717 .02128 L
.11725 .02118 L
.11732 .02104 L
.11739 .02087 L
.11754 .02035 L
.1177 .01959 L
.118 .01775 L
.1183 .01529 L
.11864 .01211 L
.11879 .01061 L
.11887 .0098 L
.11895 .00893 L
.11902 .00818 L
.11907 .00813 L
.1191 .00853 L
.11925 .01 L
.1198 .01534 L
.12008 .01763 L
Mistroke
.12023 .01868 L
.12038 .01952 L
.12051 .02017 L
.12063 .02064 L
.1207 .02084 L
.12077 .02102 L
.12084 .02117 L
.12091 .02127 L
.12099 .02132 L
.12106 .02133 L
.12113 .02129 L
.12118 .02124 L
.12121 .02118 L
.12129 .02103 L
.12138 .0208 L
.12154 .0202 L
.12168 .01946 L
.12184 .01848 L
.12211 .01624 L
.12241 .01321 L
.12258 .01134 L
.12273 .00949 L
.12281 .00849 L
.12286 .00795 L
.1229 .00847 L
.12308 .01083 L
.1234 .01497 L
.12371 .01871 L
.12403 .02217 L
.12431 .02449 L
.12447 .02549 L
.12454 .02585 L
.12462 .02619 L
.12469 .02643 L
.12476 .02661 L
.12483 .02673 L
.1249 .02679 L
.12498 .02678 L
.12504 .02671 L
.1251 .02659 L
.12517 .02641 L
.12524 .02615 L
.12532 .02578 L
.12548 .02478 L
.12563 .02355 L
.12577 .02215 L
.12637 .01346 L
.12645 .01199 L
.12654 .01033 L
.12658 .00955 L
Mistroke
.12663 .00871 L
.12671 .0087 L
.12675 .00948 L
.12679 .01034 L
.12687 .01191 L
.12701 .01488 L
.12764 .02707 L
.12794 .03206 L
.12822 .0356 L
.12837 .03702 L
.12844 .03754 L
.12851 .038 L
.12859 .03837 L
.12866 .03861 L
.12874 .03875 L
.12878 .03877 L
.12882 .03876 L
.12886 .0387 L
.12891 .0386 L
.12895 .03847 L
.12899 .03831 L
.12906 .03792 L
.12914 .03736 L
.12932 .03556 L
.12949 .03328 L
.13005 .02106 L
.13033 .01267 L
.13041 .01017 L
.13045 .00873 L
.13049 .00848 L
.13057 .01111 L
.13064 .01366 L
.13129 .03723 L
.13158 .04693 L
.13189 .05621 L
.13204 .05973 L
.13219 .0629 L
.13227 .06411 L
.13234 .0652 L
.13241 .06606 L
.13248 .06668 L
.13255 .0672 L
.13263 .06753 L
.1327 .06761 L
.13277 .06748 L
.13281 .06732 L
.13285 .06708 L
.13292 .06645 L
.133 .0655 L
.13309 .06411 L
Mistroke
.13324 .06105 L
.13337 .05736 L
.13366 .04592 L
.13394 .03142 L
.13406 .02358 L
.1342 .01428 L
.13424 .0114 L
.13428 .00829 L
.13436 .01335 L
.1345 .02536 L
.13478 .05005 L
.13539 .11335 L
.1365 .23247 L
.13707 .28202 L
.13739 .30268 L
.13754 .3103 L
.13768 .31603 L
.13781 .3202 L
.13788 .32185 L
.13795 .32331 L
.13803 .32439 L
.13811 .32512 L
.13818 .32539 L
.13825 .32529 L
.13831 .32488 L
.13837 .32423 L
.13844 .32321 L
.13851 .32178 L
.13866 .31774 L
.13879 .31282 L
.13908 .29765 L
.13939 .27581 L
.13994 .2244 L
.14055 .15682 L
.14119 .08124 L
.14151 .0466 L
.14167 .03064 L
.14173 .02389 L
.14181 .01664 L
.14188 .01041 L
.14194 .01115 L
.14201 .01696 L
.14208 .02299 L
.14237 .04488 L
.14265 .06148 L
.14281 .06868 L
.14295 .07418 L
.14308 .07823 L
.1432 .08106 L
.14327 .08231 L
Mistroke
.14333 .08325 L
.1434 .08399 L
.14348 .08451 L
.14355 .08473 L
.14362 .08469 L
.14369 .08435 L
.14377 .08374 L
.14384 .08296 L
.1439 .08203 L
.14404 .07928 L
.1442 .07524 L
.14435 .07077 L
.14467 .05841 L
.14499 .04381 L
.14533 .02708 L
.14547 .02009 L
.14562 .01268 L
.14566 .01052 L
.1457 .0085 L
.14578 .01111 L
.14593 .01819 L
.14649 .0399 L
.14664 .04446 L
.1468 .04853 L
.14695 .0516 L
.14709 .05374 L
.14716 .0546 L
.14724 .05532 L
.14732 .05584 L
.14736 .05605 L
.1474 .05619 L
.14747 .05631 L
.14754 .05627 L
.14762 .05604 L
.14769 .05565 L
.14773 .05539 L
.14777 .05504 L
.14785 .05418 L
.148 .05212 L
.14818 .04893 L
.14834 .04526 L
.14897 .02685 L
.14928 .01634 L
.14936 .01367 L
.14943 .01116 L
.14949 .00892 L
.14957 .00934 L
.14963 .01154 L
.1497 .01383 L
.14982 .01781 L
Mistroke
.1501 .026 L
.1504 .03363 L
.15068 .03895 L
.15082 .04099 L
.1509 .04187 L
.15097 .04265 L
.15104 .04322 L
.15112 .0437 L
.15119 .04402 L
.15125 .0442 L
.15133 .04429 L
.15141 .04424 L
.15147 .04407 L
.15155 .04376 L
.15159 .04352 L
.15163 .04328 L
.15171 .0426 L
.15186 .04099 L
.15214 .03692 L
.15243 .03104 L
.15297 .01777 L
.15311 .01394 L
.15319 .01182 L
.15326 .00981 L
.15333 .00796 L
.15341 .00992 L
.15354 .01338 L
.15417 .0277 L
.15449 .03289 L
.15465 .03483 L
.15474 .03571 L
.15482 .03638 L
.1549 .03684 L
.15498 .0372 L
.15505 .03745 L
.1551 .03753 L
.15514 .03758 L
.15521 .03757 L
.15528 .03746 L
.15536 .03723 L
.15543 .0369 L
.1555 .03649 L
.15558 .03596 L
.15571 .03473 L
.15602 .03082 L
.15634 .02525 L
.15664 .01923 L
.15691 .01323 L
.15698 .01154 L
.15706 .00975 L
Mistroke
.15714 .00806 L
.15721 .00933 L
.15775 .02063 L
.15804 .02566 L
.1582 .02795 L
.15835 .02974 L
.15849 .03109 L
.15861 .03205 L
.15869 .03248 L
.15875 .0328 L
.15883 .03305 L
.1589 .03322 L
.15898 .03329 L
.15905 .03326 L
.1591 .0332 L
.15913 .03312 L
.15918 .03301 L
.15922 .03285 L
.1593 .03248 L
.15938 .03203 L
.15956 .03066 L
.15971 .02909 L
.15985 .0274 L
.16016 .02278 L
.16045 .01765 L
.16061 .01463 L
.16076 .01173 L
.16089 .00923 L
.16096 .00804 L
.16102 .00931 L
.16131 .0148 L
.16162 .02009 L
.16196 .02484 L
.16211 .02658 L
.16227 .02808 L
.16235 .02868 L
.16243 .02916 L
.1625 .02955 L
.16256 .02983 L
.16263 .03006 L
.16271 .03022 L
.16278 .0303 L
.16285 .0303 L
.16292 .03021 L
.16299 .03006 L
.16307 .0298 L
.16315 .02943 L
.16331 .0285 L
.16345 .02733 L
.16378 .02375 L
Mistroke
.16431 .01578 L
.16445 .01331 L
.16461 .01062 L
.16468 .0093 L
.16476 .00805 L
.16482 .00893 L
.16489 .01013 L
.16521 .01555 L
.16551 .01998 L
.1658 .02345 L
.16595 .02494 L
.16611 .02624 L
.16618 .02673 L
.16625 .02714 L
.16632 .02746 L
.16639 .0277 L
.16645 .02788 L
.16651 .02802 L
.16658 .02809 L
.16665 .02811 L
.16672 .02805 L
.16679 .02794 L
.16686 .02774 L
.16694 .02745 L
.16708 .02678 L
.16722 .0258 L
.16754 .0228 L
.16784 .01908 L
.16811 .01516 L
.1684 .01067 L
.16847 .00952 L
.16855 .00828 L
.16859 .0083 L
.16863 .00894 L
.16871 .0102 L
.169 .01461 L
.16932 .01894 L
.1695 .02098 L
.16966 .02265 L
.16981 .02394 L
.16997 .02504 L
.17004 .02543 L
.17012 .02577 L
.17019 .02603 L
.17025 .02621 L
.17032 .02634 L
.17039 .02642 L
.17045 .02644 L
.17052 .02641 L
.17059 .02632 L
Mistroke
.17065 .02617 L
.17073 .02595 L
.1708 .02564 L
.17095 .02487 L
.17111 .02376 L
.1714 .0211 L
.17174 .01708 L
.17205 .01275 L
.1722 .01067 L
.17227 .00963 L
.17233 .00868 L
.17241 .0083 L
.17245 .00888 L
.17249 .00949 L
.17263 .01153 L
.17295 .01596 L
.17326 .01954 L
.17355 .02226 L
.17371 .02342 L
.17386 .02423 L
.17395 .02458 L
.17403 .02482 L
.17407 .02493 L
.17411 .02501 L
.17416 .02508 L
.17421 .02512 L
.17424 .02514 L
.17429 .02514 L
.17436 .02508 L
.1744 .02502 L
.17444 .02495 L
.17453 .02472 L
.17565 .01512 L
.17596 .01106 L
.17604 .01003 L
.17612 .00893 L
.17616 .00829 L
.17621 .00816 L
.17625 .00874 L
.17629 .00929 L
.17688 .01675 L
.17717 .01981 L
.17734 .02118 L
.17749 .02225 L
.17758 .02276 L
.17767 .02322 L
.17775 .02353 L
.17779 .02368 L
.17784 .02379 L
.17788 .02389 L
Mistroke
.17792 .02397 L
.17796 .02403 L
.178 .02408 L
.17808 .0241 L
.17816 .02406 L
.17823 .02397 L
.1783 .02381 L
.17838 .02358 L
.17846 .02329 L
.17859 .02264 L
.17874 .02175 L
.17907 .01901 L
.17937 .01582 L
.17966 .01237 L
.17981 .01037 L
.17989 .00938 L
.17996 .00846 L
.18003 .00828 L
.1801 .0092 L
.18025 .01111 L
.18051 .0143 L
.18079 .01742 L
.1811 .02015 L
.18128 .02137 L
.18144 .02224 L
.18152 .02256 L
.1816 .02285 L
.18164 .02295 L
.18168 .02305 L
.18175 .02318 L
.18183 .02325 L
.18187 .02327 L
.18191 .02327 L
.18195 .02325 L
.18199 .02321 L
.18204 .02315 L
.18208 .02308 L
.18215 .0229 L
.18222 .02269 L
.18237 .02205 L
.18253 .02117 L
.1827 .01996 L
.18305 .01684 L
.18335 .01354 L
.18351 .01157 L
.18367 .00963 L
.18374 .00876 L
.18382 .00805 L
.18386 .00859 L
.1839 .00907 L
Mistroke
.18398 .01002 L
.18426 .01334 L
.18455 .01648 L
.18486 .01923 L
.18513 .02099 L
.18528 .02172 L
.18535 .02199 L
.18542 .0222 L
.18549 .02239 L
.18554 .02246 L
.18558 .02252 L
.18565 .02258 L
.18569 .0226 L
.18573 .02259 L
.1858 .02254 L
.18587 .02245 L
.18594 .0223 L
.18602 .02208 L
.18618 .02145 L
.18633 .02066 L
.18667 .01818 L
.18697 .01529 L
.1873 .01167 L
.18745 .00991 L
.18753 .00894 L
.18761 .00802 L
.18768 .00863 L
.18775 .00946 L
.1879 .01121 L
.18818 .01431 L
.18848 .01721 L
.18876 .01939 L
.18889 .02025 L
.18902 .02089 L
.18917 .0215 L
.18925 .02173 L
.18929 .02182 L
.18934 .02191 L
.18941 .022 L
.18947 .02205 L
.18955 .02204 L
.18963 .02199 L
.18967 .02193 L
.18971 .02186 L
.18979 .02168 L
.18987 .02143 L
.18997 .02107 L
.19013 .02024 L
.19029 .01925 L
.19087 .01417 L
Mistroke
.19103 .01248 L
.19119 .01061 L
.19128 .00968 L
.19135 .00879 L
.19142 .008 L
.1915 .00873 L
.19209 .01511 L
.19239 .01778 L
.19256 .01899 L
.19271 .01993 L
.19285 .02058 L
.19299 .0211 L
.19307 .02132 L
.19315 .02148 L
.19322 .02156 L
.19329 .02161 L
.19336 .02161 L
.19343 .02156 L
.1935 .02147 L
.19357 .02133 L
.19364 .02116 L
.19369 .02098 L
.19383 .02045 L
.19398 .01968 L
.19411 .01883 L
.19442 .01645 L
.19496 .01097 L
.19511 .00933 L
.19519 .00849 L
.19523 .00802 L
.19527 .0083 L
.19531 .00878 L
.19535 .00923 L
.19544 .01021 L
.1956 .01193 L
.1959 .01488 L
.19621 .01756 L
.19637 .01869 L
.19652 .01959 L
.19667 .02029 L
.19673 .02054 L
.1968 .02077 L
.19686 .02094 L
.19693 .02108 L
.197 .02119 L
.19706 .02125 L
.19714 .02127 L
.19721 .02124 L
.19728 .02117 L
.19735 .02106 L
Mistroke
.19743 .02088 L
.1975 .02067 L
.19766 .02002 L
.19783 .01917 L
.198 .01804 L
.19831 .01552 L
.1986 .01274 L
.19888 .0098 L
.19896 .00893 L
.19903 .00811 L
.1991 .0085 L
.19917 .0093 L
.1998 .0156 L
.20012 .01811 L
.2003 .01919 L
.20046 .01998 L
.2006 .02049 L
.20068 .0207 L
.20075 .02084 L
.20083 .02095 L
.20088 .02098 L
.20092 .021 L
.20099 .021 L
.20103 .02097 L
.20107 .02094 L
.20114 .02083 L
.20121 .02069 L
.20129 .02049 L
.20137 .02023 L
.20153 .01953 L
.20168 .01871 L
.20223 .01434 L
.20254 .01128 L
.2027 .00957 L
.20275 .00912 L
.20279 .00862 L
.20284 .00816 L
.20288 .00814 L
.20295 .00893 L
.20303 .00975 L
.20319 .01148 L
.20349 .01434 L
.20378 .01686 L
.20406 .01875 L
.20422 .01955 L
.2043 .0199 L
.20438 .02021 L
.20446 .02042 L
.20454 .0206 L
.20461 .02072 L
Mistroke
.20468 .02079 L
.20474 .02081 L
.20482 .0208 L
.20489 .02074 L
.20495 .02064 L
.20501 .02053 L
.20508 .02037 L
.20521 .01993 L
.20535 .0193 L
.2055 .01845 L
.20578 .0165 L
.20636 .01118 L
.20651 .00955 L
.20656 .00911 L
.2066 .00864 L
.20664 .00819 L
.20668 .0081 L
.20676 .00891 L
.20684 .00977 L
.20699 .01126 L
.20759 .01675 L
.20776 .01792 L
.20793 .01898 L
.2081 .01975 L
.20818 .02004 L
.20825 .02026 L
.20833 .02044 L
.2084 .02057 L
.20848 .02065 L
.20854 .02069 L
.20861 .02068 L
.20869 .02063 L
.20873 .02058 L
.20877 .02051 L
.20885 .02035 L
.20892 .02016 L
.209 .01991 L
.20914 .01932 L
.2094 .01783 L
.20999 .0129 L
.21015 .01129 L
.21033 .00949 L
.21041 .00865 L
.21045 .00822 L
.21049 .00811 L
.21057 .00893 L
.21064 .00969 L
.21097 .01293 L
.21127 .01566 L
.21156 .01786 L
Mistroke
.21183 .01937 L
.21198 .01994 L
.21205 .02016 L
.21213 .02036 L
.21221 .0205 L
.21225 .02056 L
.21229 .0206 L
.21237 .02063 L
.21245 .02061 L
.21252 .02054 L
.21257 .02047 L
.21261 .0204 L
.21269 .02023 L
.21276 .02001 L
.21292 .01938 L
.2131 .01846 L
.2134 .01643 L
.21367 .01408 L
.214 .01088 L
.21416 .00927 L
.21423 .00856 L
.2143 .0081 L
.21438 .00887 L
.21445 .00968 L
.21462 .01136 L
.21491 .01422 L
.21525 .017 L
.21542 .01812 L
.21557 .019 L
.21571 .01965 L
.21586 .02016 L
.21595 .02037 L
.21599 .02045 L
.21603 .02051 L
.2161 .02059 L
.21618 .02063 L
.21625 .02062 L
.21631 .02057 L
.21638 .02048 L
.21645 .02034 L
.21653 .02014 L
.2166 .01991 L
.21674 .01936 L
.21689 .01859 L
.21705 .01758 L
.21734 .01536 L
.21768 .0122 L
.21783 .0107 L
.21791 .00989 L
.21799 .00901 L
Mistroke
.21807 .00823 L
.21814 .00835 L
.2182 .00907 L
.21827 .00974 L
.21856 .01266 L
.21887 .01555 L
.21916 .01776 L
.21942 .01925 L
.21955 .01981 L
.21969 .02027 L
.21977 .02045 L
.21983 .02057 L
.21991 .02065 L
.21999 .02069 L
.22006 .02068 L
.22012 .02063 L
.22019 .02054 L
.22026 .0204 L
.22277 .01632 L
.22292 .01748 L
.22308 .01855 L
.22324 .01938 L
.22338 .01999 L
.22346 .02026 L
.22354 .02049 L
.22362 .02064 L
.22369 .02074 L
.22376 .0208 L
.22381 .02081 L
.22385 .02081 L
.22389 .02079 L
.22393 .02075 L
.22398 .0207 L
.22402 .02062 L
.2241 .02047 L
.22416 .02029 L
.22431 .01975 L
.22445 .0191 L
.22458 .01835 L
.22518 .01346 L
.22546 .01061 L
.22554 .00983 L
.22562 .00898 L
.22569 .00818 L
.22576 .00843 L
.22582 .0091 L
.22589 .00982 L
.22601 .01112 L
.22629 .01392 L
.2266 .0166 L
Mistroke
.22676 .01786 L
.22692 .01887 L
.22706 .01964 L
.2272 .0202 L
.22727 .02044 L
.22734 .02065 L
.22742 .02082 L
.22746 .02089 L
.2275 .02094 L
.22758 .021 L
.22762 .02101 L
.22766 .021 L
.22773 .02095 L
.2278 .02086 L
.22785 .02079 L
.22789 .0207 L
.22796 .0205 L
.22813 .01988 L
.22828 .01914 L
.22842 .0183 L
.22873 .01593 L
.22927 .01066 L
.22935 .00986 L
.22943 .00899 L
.2295 .00816 L
.22957 .00848 L
.22964 .00917 L
.22971 .00992 L
.22985 .01143 L
.23014 .01434 L
.23045 .01711 L
.23059 .01819 L
.23075 .01918 L
.23088 .01989 L
.23102 .0205 L
.23111 .02078 L
.23118 .02098 L
.23126 .02112 L
.23133 .02122 L
.23138 .02125 L
.23142 .02127 L
.2315 .02125 L
.23155 .02121 L
.23159 .02116 L
.23164 .02109 L
.23168 .021 L
.23175 .02082 L
.23183 .02057 L
.23199 .0199 L
.23214 .01908 L
Mistroke
.23228 .01817 L
.23258 .01575 L
.23291 .01258 L
.23306 .01099 L
.23314 .0101 L
.23322 .00925 L
.23329 .00845 L
.23337 .00829 L
.23344 .00908 L
.2335 .0098 L
.23404 .0154 L
.23434 .01794 L
.23462 .0198 L
.23476 .02054 L
.23484 .02085 L
.23492 .02113 L
.23499 .02131 L
.23507 .02147 L
.23514 .02156 L
.2352 .02161 L
.23527 .02161 L
.23534 .02158 L
.2354 .02151 L
.23547 .02139 L
.23554 .02123 L
.23561 .021 L
.23575 .02046 L
.23591 .01961 L
.23609 .01846 L
.2364 .01584 L
.23671 .01277 L
.23686 .01115 L
.237 .00962 L
.23706 .00885 L
.23714 .008 L
.23721 .00867 L
.23727 .0094 L
.23757 .01271 L
.23786 .01577 L
.23819 .01861 L
.23835 .01968 L
.23851 .02063 L
.23859 .02099 L
.23867 .02131 L
.23874 .02156 L
.23881 .02175 L
.23889 .02191 L
.23893 .02197 L
.23897 .02201 L
.23904 .02205 L
Mistroke
.23912 .02204 L
.23916 .022 L
.23921 .02195 L
.23925 .02188 L
.2393 .02178 L
.23938 .02158 L
.23946 .02129 L
.23961 .02061 L
.23978 .01966 L
.24007 .01742 L
.24041 .0141 L
.24058 .01227 L
.24073 .01051 L
.24088 .00877 L
.24096 .00798 L
.241 .00849 L
.24104 .00895 L
.24137 .01278 L
.24194 .01851 L
.24224 .02068 L
.24241 .02156 L
.2425 .02189 L
.24257 .02215 L
.24264 .02232 L
.24271 .02246 L
.24279 .02256 L
.24286 .0226 L
.24293 .02258 L
.24301 .0225 L
.24305 .02244 L
.24309 .02236 L
.24317 .02216 L
.24331 .02164 L
.24347 .02085 L
.24375 .01888 L
.24428 .01365 L
.24456 .01042 L
.24464 .00945 L
.24471 .00853 L
.24478 .00818 L
.24485 .00909 L
.24518 .01301 L
.24548 .01639 L
.2458 .01939 L
.24597 .02073 L
.24614 .02175 L
.24628 .02242 L
.24635 .02269 L
.24643 .02293 L
.24651 .02311 L
Mistroke
.24655 .02318 L
.24659 .02323 L
.24667 .02327 L
.24675 .02325 L
.24682 .02317 L
.24686 .0231 L
.2469 .02302 L
.24698 .02281 L
.24707 .02251 L
.24722 .02179 L
.24736 .02093 L
.2477 .01812 L
.24803 .01468 L
.24831 .01129 L
.24838 .01035 L
.24846 .00933 L
.24854 .00835 L
.24861 .00842 L
.24865 .00894 L
.24869 .0095 L
.24878 .01064 L
.24894 .01262 L
.24924 .01626 L
.24956 .01951 L
.24971 .02084 L
.24985 .02189 L
.24998 .02267 L
.25012 .02334 L
.2502 .0236 L
.25026 .0238 L
.25034 .02396 L
.25041 .02406 L
.25049 .0241 L
.25057 .02408 L
.25061 .02403 L
.25065 .02398 L
.25069 .0239 L
.25073 .0238 L
.25082 .02354 L
.2509 .02324 L
.25107 .02232 L
.25121 .02138 L
.25136 .02013 L
.25167 .01702 L
.25199 .01323 L
.25214 .0112 L
.25222 .01019 L
.25228 .00927 L
.25235 .00835 L
.25241 .00838 L
Mistroke
.25248 .00929 L
.25255 .01027 L
.25284 .01417 L
.25316 .01806 L
.2535 .02144 L
.25364 .02256 L
.25378 .02355 L
.25387 .02402 L
.25395 .02437 L
.25403 .02466 L
.2541 .02488 L
.25417 .02501 L
.25424 .02511 L
.25432 .02514 L
.25439 .0251 L
.25446 .02501 L
.25454 .02484 L
.25458 .02472 L
.25462 .02458 L
.2547 .02427 L
.25485 .02349 L
.25499 .02252 L
.25525 .02019 L
.25585 .01285 L
.25601 .01051 L
.2561 .00921 L
.25615 .00857 L
.25619 .00798 L
.25626 .00895 L
.25634 .01007 L
.2565 .01245 L
.25705 .01978 L
.25734 .02269 L
.2575 .02403 L
.25765 .02502 L
.25772 .02543 L
.25781 .02581 L
.25789 .0261 L
.25794 .02622 L
.25798 .02631 L
.25806 .02642 L
.25813 .02644 L
.25817 .02643 L
.25821 .02639 L
.25829 .02627 L
.25837 .02608 L
.25845 .0258 L
.25861 .025 L
.25875 .02399 L
.25889 .02282 L
Mistroke
.25952 .01531 L
.25967 .01311 L
.25983 .01067 L
.2599 .00946 L
.25998 .0083 L
.26004 .00861 L
.26011 .00973 L
.26065 .01787 L
.26095 .0218 L
.26123 .02476 L
.26137 .02593 L
.2615 .02682 L
.26158 .02722 L
.26166 .02757 L
.26173 .02781 L
.2618 .02798 L
.26187 .02808 L
.26194 .02811 L
.26202 .02807 L
.26206 .02801 L
.2621 .02793 L
.26218 .02772 L
.26226 .02741 L
.26235 .02698 L
.26243 .0265 L
.26275 .02374 L
.26304 .02024 L
.26336 .01554 L
.26353 .0127 L
.26362 .01126 L
.26369 .00993 L
.26377 .0087 L
.26383 .00835 L
.2639 .00959 L
.26398 .01094 L
.2643 .01632 L
.26485 .02443 L
.26516 .02771 L
.26526 .02843 L
.26534 .029 L
.26542 .02944 L
.2655 .0298 L
.26557 .03004 L
.26565 .03022 L
.26572 .03029 L
.26579 .0303 L
.26587 .03021 L
.26594 .03005 L
.26598 .02993 L
.26602 .02977 L
Mistroke
.2661 .02941 L
.26624 .02853 L
.26639 .02726 L
.26667 .02418 L
.267 .01938 L
.26729 .01416 L
.26744 .01133 L
.26753 .00975 L
.2676 .00824 L
.26765 .0085 L
.2677 .00944 L
.26778 .01108 L
.26794 .01425 L
.26826 .02017 L
.26856 .02506 L
.26883 .02876 L
.26898 .03028 L
.26913 .0316 L
.26922 .03219 L
.2693 .03263 L
.26938 .03294 L
.26941 .03307 L
.26946 .03317 L
.26953 .03327 L
.26957 .03329 L
.26961 .03328 L
.26968 .0332 L
.26976 .03301 L
.26984 .03271 L
.26991 .03234 L
.27007 .0312 L
.27022 .02976 L
.27036 .02807 L
.27068 .02325 L
.27102 .01671 L
.27117 .01373 L
.27124 .01204 L
.27132 .0104 L
.27139 .00887 L
.27146 .00869 L
.27153 .01022 L
.27159 .01165 L
.27222 .02503 L
.27254 .03053 L
.27283 .03444 L
.273 .03597 L
.27309 .03662 L
.27317 .03707 L
.27325 .03735 L
.27333 .03753 L
Mistroke
.27337 .03757 L
.27341 .03759 L
.27348 .03752 L
.27356 .03734 L
.2736 .03719 L
.27364 .03701 L
.27372 .03657 L
.2738 .03595 L
.27396 .03448 L
.2741 .03273 L
.27442 .02736 L
.27476 .02002 L
.27504 .01306 L
.27512 .01095 L
.2752 .00893 L
.27527 .00877 L
.27534 .01076 L
.27567 .01956 L
.27598 .02727 L
.27625 .03342 L
.27655 .03876 L
.27672 .04109 L
.27687 .04269 L
.27694 .04327 L
.27698 .04353 L
.27703 .04376 L
.2771 .04408 L
.27717 .04425 L
.27725 .04429 L
.27732 .0442 L
.2774 .04395 L
.27744 .04377 L
.27748 .04353 L
.27756 .04301 L
.27763 .04231 L
.27777 .04067 L
.27795 .0379 L
.27812 .03462 L
.27844 .02692 L
.27874 .01804 L
.27889 .0133 L
.27895 .01116 L
.27902 .00879 L
.2791 .00955 L
.27916 .01192 L
.27932 .01719 L
.27964 .02818 L
.27992 .03694 L
.28022 .045 L
.28036 .04827 L
Mistroke
.2805 .05091 L
.28062 .05287 L
.28075 .05451 L
.28083 .05522 L
.28089 .05572 L
.28096 .05607 L
.28103 .05626 L
.28111 .05631 L
.28118 .05618 L
.28126 .05584 L
.28129 .0556 L
.28134 .05527 L
.28142 .05448 L
.28149 .05358 L
.28166 .05087 L
.2818 .04773 L
.28196 .04369 L
.28226 .03385 L
.28254 .02248 L
.28266 .017 L
.28279 .01094 L
.28286 .00819 L
.28294 .01184 L
.28307 .01836 L
.28364 .04675 L
.28394 .05997 L
.28426 .07182 L
.28441 .07638 L
.28456 .07988 L
.28469 .08226 L
.28476 .08327 L
.28483 .08398 L
.2849 .08447 L
.28496 .08471 L
.28502 .08473 L
.28509 .08455 L
.28516 .08411 L
.28523 .08335 L
.28529 .08247 L
.28536 .08126 L
.28551 .07763 L
.28568 .07219 L
.28598 .05833 L
.28627 .04001 L
.28654 .01912 L
.28661 .01291 L
.28669 .00991 L
.28676 .0167 L
.28683 .02312 L
.28715 .05597 L
Mistroke
.2878 .12996 L
.2884 .19926 L
.28872 .23419 L
.28903 .26341 L
.28932 .28644 L
.28948 .29664 L
.28964 .30586 L
.28977 .31231 L
.28992 .31795 L
.28999 .31993 L
.29006 .32172 L
.29012 .32298 L
.29018 .32406 L
.29026 .32489 L
.29034 .32534 L
.29041 .32535 L
.29048 .32501 L
.29052 .32467 L
.29056 .32418 L
.29063 .32301 L
.29071 .32131 L
.2908 .31894 L
.29095 .3138 L
.2911 .30673 L
.29139 .29014 L
.29196 .24335 L
.29248 .19019 L
.29363 .06566 L
.29395 .03575 L
.29412 .02089 L
.29421 .01406 L
.29428 .00808 L
.29435 .01303 L
.29442 .01779 L
.29457 .02757 L
.29488 .04483 L
.29504 .05158 L
.29519 .05682 L
.29532 .06067 L
.29546 .06378 L
.29553 .06503 L
.29562 .06611 L
.29569 .06683 L
.29576 .06729 L
.2958 .06747 L
.29584 .06758 L
.29591 .06759 L
.29599 .06737 L
.29604 .06713 L
.29608 .06684 L
Mistroke
.29614 .06627 L
.29621 .0655 L
.29633 .06369 L
.29648 .06091 L
.29661 .05783 L
.29718 .04052 L
.29773 .02063 L
.29789 .01493 L
.29797 .0122 L
.29804 .00972 L
.29811 .00836 L
.29818 .01064 L
.29832 .01524 L
.29863 .02386 L
.29879 .02773 L
.29897 .03127 L
.29913 .03395 L
.29928 .03589 L
.29935 .03665 L
.29943 .03734 L
.2995 .03783 L
.29957 .03824 L
.29961 .03841 L
.29965 .03856 L
.29972 .03872 L
.29976 .03877 L
.29981 .03877 L
.29985 .03873 L
.29989 .03867 L
.29996 .03845 L
.30001 .03828 L
.30004 .03809 L
.30019 .03713 L
.30032 .03594 L
.30046 .03432 L
.30076 .03014 L
.30109 .02414 L
.30141 .01778 L
.3017 .01193 L
.30178 .01035 L
.30183 .00949 L
.30187 .00869 L
.30195 .00872 L
.30202 .01009 L
.30258 .01933 L
.30273 .0213 L
.30289 .02308 L
.30305 .02443 L
.30319 .02541 L
.30326 .02581 L
Mistroke
.30333 .02617 L
.30338 .02633 L
.30342 .02646 L
.30349 .02665 L
.30356 .02675 L
.30363 .02679 L
.30371 .02677 L
.30378 .02667 L
.30382 .02659 L
.30386 .02649 L
.30395 .02621 L
.3041 .02551 L
.30428 .02438 L
.30444 .02306 L
.30507 .01617 L
.30538 .01219 L
.30552 .01042 L
.30559 .00948 L
.30567 .00848 L
.30574 .00828 L
.30581 .00909 L
.30593 .01063 L
.30621 .01376 L
.30651 .01673 L
.30679 .01885 L
.30694 .01973 L
.30708 .02038 L
.30722 .02089 L
.30731 .02109 L
.30738 .02122 L
.30745 .0213 L
.30751 .02133 L
.30758 .02132 L
.30765 .02128 L
.30773 .02118 L
.3078 .02104 L
.30786 .02087 L
.30793 .02066 L
.30808 .02007 L
.30825 .01922 L
.30858 .01695 L
.30918 .01148 L
.30933 .00991 L
.30941 .00913 L
.30948 .00842 L
.30955 .0082 L
.30963 .00901 L
.30979 .01069 L
.31035 .01598 L
.31066 .01833 L
Mistroke
.31082 .01933 L
.31099 .02019 L
.31114 .02075 L
.31123 .02099 L
.31127 .02108 L
.31131 .02116 L
.31138 .02126 L
.31145 .02132 L
.31152 .02133 L
.3116 .02129 L
.31167 .02121 L
.31174 .02109 L
.31182 .02092 L
.31189 .02068 L
.31202 .02016 L
.31217 .01942 L
.31249 .01712 L
.31279 .01429 L
.31294 .01267 L
.3131 .01077 L
.31318 .00987 L
.31326 .00889 L
.31333 .00804 L
.3134 .00879 L
.31374 .01322 L
.31405 .01714 L
.31437 .02072 L
.31466 .02354 L
.31479 .02453 L
.31493 .02541 L
.31501 .02582 L
.31508 .02614 L
.31515 .02638 L
.31522 .02658 L
.3153 .02673 L
.31534 .02677 L
.31538 .02679 L
.31545 .02678 L
.31553 .02669 L
.31557 .02661 L
.31562 .02649 L
.31571 .02619 L
.31579 .02581 L
.31587 .02538 L
.31601 .02438 L
.31616 .02298 L
.31648 .01922 L
.31677 .01467 L
.31693 .01185 L
.31701 .0104 L
Mistroke
.31708 .00906 L
.31715 .00809 L
.31721 .00931 L
.31735 .01205 L
.31764 .01795 L
.31825 .02946 L
.31856 .03401 L
.31873 .03601 L
.31881 .03675 L
.3189 .03743 L
.31898 .03795 L
.31905 .03833 L
.31912 .03858 L
.3192 .03873 L
.31927 .03877 L
.31935 .03869 L
.31941 .03853 L
.31948 .03825 L
.31955 .03783 L
.31964 .03722 L
.3198 .03551 L
.31996 .03336 L
.3201 .03088 L
.32063 .01799 L
.32078 .01358 L
.32086 .01103 L
.32093 .00857 L
.321 .00945 L
.32107 .0118 L
.32121 .01693 L
.32184 .03972 L
.32215 .04982 L
.32244 .05792 L
.32257 .061 L
.32272 .06371 L
.3228 .06497 L
.32287 .06592 L
.32295 .06667 L
.32302 .06718 L
.32309 .06748 L
.32316 .06761 L
.32321 .06757 L
.32328 .06736 L
.32335 .06693 L
.32342 .06623 L
.32349 .06534 L
.32356 .06434 L
.32369 .06152 L
.32384 .05735 L
.32415 .04541 L
Mistroke
.32444 .03018 L
.32456 .02208 L
.32463 .01748 L
.3247 .01233 L
.32478 .00945 L
.32486 .01519 L
.32502 .02852 L
.3253 .05479 L
.32595 .12233 L
.32715 .24887 L
.32748 .27668 L
.32782 .30021 L
.32797 .30783 L
.32812 .31457 L
.32821 .31772 L
.32829 .32014 L
.32837 .32216 L
.32845 .32358 L
.32852 .3246 L
.32859 .32519 L
.32867 .3254 L
.32871 .32533 L
.32875 .32516 L
.32882 .32461 L
.32889 .32365 L
.32897 .32225 L
.32904 .32057 L
.3292 .31536 L
.32935 .30902 L
.32968 .28953 L
.32997 .26729 L
.33028 .23836 L
.33085 .17675 L
.33146 .10479 L
.33204 .04086 L
.33218 .02664 L
.33226 .01921 L
.33233 .01251 L
.33241 .01041 L
.33245 .01402 L
.33249 .01779 L
.33264 .02992 L
.33299 .05364 L
.33314 .062 L
.33331 .06968 L
.33345 .07507 L
.33361 .07951 L
.33369 .08137 L
.33377 .08271 L
.33385 .08371 L
Mistroke
.33392 .08434 L
.33396 .08455 L
.334 .08469 L
.33405 .08474 L
.33409 .0847 L
.33416 .08439 L
.3342 .0841 L
.33424 .08376 L
.33432 .08281 L
.33441 .08142 L
.33459 .07758 L
.33475 .0731 L
.33489 .06826 L
.33522 .0552 L
.3358 .02708 L
.33595 .01956 L
.33609 .0126 L
.33617 .00915 L
.33624 .01037 L
.33628 .01241 L
.33633 .01433 L
.3364 .01786 L
.33696 .0396 L
.33711 .04415 L
.33727 .04825 L
.3374 .05113 L
.33755 .05354 L
.33765 .05465 L
.33769 .05505 L
.33773 .05542 L
.33777 .0557 L
.33781 .05594 L
.33785 .05613 L
.3379 .05624 L
.33794 .0563 L
.33798 .05631 L
.33806 .05616 L
.33813 .05583 L
.33821 .05535 L
.33828 .05472 L
.33835 .0539 L
.33848 .05203 L
.33879 .0461 L
.33904 .03937 L
.33933 .03073 L
.33964 .02035 L
.33981 .01447 L
.33989 .01158 L
.33997 .00893 L
.34004 .00942 L
Mistroke
.34012 .012 L
.34028 .01729 L
.34057 .0258 L
.34086 .03318 L
.34114 .03861 L
.34129 .04087 L
.34137 .04183 L
.34145 .04269 L
.34153 .04332 L
.34161 .04376 L
.34168 .04406 L
.34175 .04424 L
.34181 .04429 L
.34188 .04424 L
.34195 .04405 L
.34202 .04377 L
.34209 .04339 L
.34214 .04297 L
.34228 .04175 L
.34242 .04001 L
.34257 .03768 L
.34285 .03238 L
.34314 .02554 L
.34346 .01729 L
.34361 .01334 L
.34369 .01118 L
.34376 .00917 L
.34383 .00841 L
.3439 .01022 L
.34404 .01398 L
.34464 .02766 L
.34482 .03079 L
.34499 .03324 L
.34514 .035 L
.34523 .0358 L
.3453 .0364 L
.34537 .03683 L
.34545 .03718 L
.34552 .03744 L
.3456 .03756 L
.34567 .03758 L
.34574 .03749 L
.3458 .03733 L
.34587 .03707 L
.34596 .03664 L
.34603 .03613 L
.3462 .03462 L
.34635 .03289 L
.3465 .0307 L
.34711 .0192 L
Mistroke
.34729 .01534 L
.34746 .0116 L
.34753 .00996 L
.34761 .00823 L
.34765 .00855 L
.34769 .00954 L
.34777 .01126 L
.34806 .01753 L
.34838 .02348 L
.34868 .02801 L
.34882 .02971 L
.34895 .03101 L
.34909 .03202 L
.34916 .03246 L
.34923 .03277 L
.3493 .03304 L
.34938 .03322 L
.34945 .03329 L
.34952 .03327 L
.34959 .03318 L
.34965 .03303 L
.34971 .03279 L
.34978 .03246 L
.34993 .03153 L
.35006 .03041 L
.35035 .02706 L
.35066 .02242 L
.35092 .01773 L
.35121 .01226 L
.35129 .01074 L
.35137 .00913 L
.35144 .00812 L
.35151 .00961 L
.3518 .01504 L
.35214 .02075 L
.35246 .02515 L
.3526 .02675 L
.35275 .02814 L
.35283 .02873 L
.35292 .02927 L
.353 .02968 L
.35308 .02996 L
.35315 .03015 L
.35322 .03026 L
.35329 .0303 L
.35337 .03026 L
.35343 .03015 L
.35351 .02995 L
.35358 .02969 L
.35364 .0294 L
Mistroke
.3538 .02837 L
.35395 .02711 L
.35429 .02329 L
.35458 .01904 L
.3549 .01385 L
.35506 .01111 L
.35513 .00976 L
.35521 .0085 L
.35527 .00851 L
.35534 .00971 L
.35549 .01221 L
.35603 .02059 L
.35634 .02416 L
.35649 .0255 L
.35663 .02654 L
.3567 .02701 L
.35679 .02742 L
.35687 .02772 L
.35694 .02792 L
.35698 .02801 L
.35703 .02807 L
.3571 .02811 L
.35715 .0281 L
.35719 .02807 L
.35723 .02801 L
.35728 .02791 L
.35735 .0277 L
.35743 .0274 L
.35758 .02663 L
.35772 .02563 L
.35785 .0245 L
.35846 .01706 L
.35873 .0129 L
.35887 .01077 L
.35899 .0088 L
.35906 .00808 L
.35912 .00914 L
.35926 .01133 L
.35956 .01577 L
.35986 .01965 L
.36014 .02265 L
.36029 .02396 L
.36046 .02509 L
.36053 .02548 L
.36061 .02583 L
.36068 .02606 L
.36075 .02625 L
.36082 .02638 L
.36089 .02644 L
.36096 .02644 L
Mistroke
.36102 .02638 L
.3611 .02625 L
.36118 .02604 L
.36125 .02577 L
.36132 .02546 L
.36145 .02472 L
.36159 .0237 L
.36185 .02132 L
.36215 .01784 L
.36247 .0135 L
.36263 .01126 L
.36271 .01014 L
.36278 .0091 L
.36284 .00815 L
.36291 .00872 L
.36298 .00972 L
.36305 .01081 L
.36366 .01871 L
.36382 .02045 L
.364 .02205 L
.36416 .0232 L
.36424 .02372 L
.36432 .02414 L
.3644 .02447 L
.36448 .02475 L
.36455 .02494 L
.36462 .02506 L
.36469 .02512 L
.36476 .02514 L
.36483 .02509 L
.3649 .02498 L
.36494 .0249 L
.36498 .02479 L
.36506 .02454 L
.3652 .02389 L
.36537 .02284 L
.36553 .02162 L
.36584 .01853 L
.36618 .01444 L
.36634 .01239 L
.36651 .01016 L
.36657 .00922 L
.36665 .00823 L
.36669 .00822 L
.36673 .00874 L
.3668 .00975 L
.36734 .01659 L
.36762 .01954 L
.36792 .02196 L
.36808 .02289 L
Mistroke
.36816 .02328 L
.36825 .02362 L
.36829 .02374 L
.36833 .02385 L
.36841 .02399 L
.36848 .02408 L
.36856 .0241 L
.36864 .02406 L
.36871 .02396 L
.36875 .02389 L
.36879 .02378 L
.36887 .02355 L
.36902 .02291 L
.36916 .02212 L
.36944 .01996 L
.36974 .01695 L
.37001 .01391 L
.37029 .01033 L
.37038 .00924 L
.37042 .00864 L
.37047 .00808 L
.37054 .00878 L
.37063 .00987 L
.37094 .01379 L
.37123 .01695 L
.37153 .01981 L
.37168 .02091 L
.37184 .02187 L
.37192 .02225 L
.37199 .02255 L
.37206 .02278 L
.37213 .02298 L
.3722 .02314 L
.37224 .0232 L
.37228 .02324 L
.37235 .02327 L
.37243 .02325 L
.37247 .02321 L
.37251 .02315 L
.37255 .02308 L
.37259 .02299 L
.37267 .02278 L
.37275 .0225 L
.37289 .02183 L
.37305 .02088 L
.37333 .01865 L
.37386 .01308 L
.37401 .01137 L
.37416 .0095 L
.37423 .00858 L
Mistroke
.3743 .00817 L
.37437 .00894 L
.37444 .00979 L
.37506 .01683 L
.37538 .01958 L
.37555 .02066 L
.37572 .02159 L
.3758 .02191 L
.37588 .02215 L
.37592 .02226 L
.37596 .02237 L
.37604 .0225 L
.37611 .02258 L
.37619 .02259 L
.37627 .02255 L
.37633 .02247 L
.3764 .02233 L
.37647 .02216 L
.37663 .0216 L
.37677 .02084 L
.37694 .01982 L
.37749 .01486 L
.37783 .01111 L
.37791 .01018 L
.37799 .00917 L
.37806 .00831 L
.37811 .00806 L
.37814 .00852 L
.37843 .01184 L
.37874 .01519 L
.37905 .018 L
.37933 .02004 L
.37948 .02081 L
.37963 .02144 L
.37972 .0217 L
.37976 .02181 L
.3798 .02188 L
.37987 .02199 L
.37991 .02203 L
.37995 .02205 L
.38002 .02205 L
.38009 .022 L
.38016 .02191 L
.38023 .02177 L
.38029 .02161 L
.38035 .02142 L
.38048 .02088 L
.38063 .02011 L
.38077 .01925 L
.38107 .01684 L
Mistroke
.38136 .01398 L
.38167 .0106 L
.3818 .00915 L
.38187 .00833 L
.38194 .00829 L
.38201 .00918 L
.38209 .01 L
.38223 .01157 L
.38283 .01743 L
.38299 .01868 L
.38317 .01979 L
.38331 .02054 L
.3834 .02088 L
.38348 .02114 L
.38355 .02132 L
.38362 .02147 L
.38366 .02153 L
.3837 .02157 L
.38378 .02161 L
.38385 .0216 L
.38393 .02154 L
.384 .02142 L
.38404 .02134 L
.38409 .02123 L
.38423 .02078 L
.38438 .0201 L
.38464 .01844 L
.38496 .01584 L
.3853 .01251 L
.38546 .01076 L
.38554 .00988 L
.38561 .00907 L
.38568 .00832 L
.38575 .00834 L
.38582 .00913 L
.3859 .00999 L
.38651 .01612 L
.38668 .01749 L
.38685 .01875 L
.38702 .01972 L
.38717 .02042 L
.38725 .02068 L
.38733 .02092 L
.38741 .02109 L
.38746 .02117 L
.3875 .02122 L
.38758 .02127 L
.38765 .02126 L
.38769 .02124 L
.38773 .02121 L
Mistroke
.38781 .02109 L
.38788 .02093 L
.38795 .02074 L
.38811 .02017 L
.38825 .01947 L
.38838 .01866 L
.38897 .01376 L
.38913 .01219 L
.38929 .01044 L
.38937 .00958 L
.38945 .00875 L
.38952 .00801 L
.38959 .00867 L
.39012 .01416 L
.39042 .01679 L
.3907 .01877 L
.39084 .01951 L
.39097 .02013 L
.39105 .02039 L
.39113 .02062 L
.3912 .02079 L
.39127 .0209 L
.39131 .02095 L
.39135 .02098 L
.39143 .02101 L
.3915 .02098 L
.39157 .02091 L
.39164 .02079 L
.39173 .0206 L
.39181 .02034 L
.39189 .02004 L
.39221 .01835 L
.3925 .01618 L
.39282 .01329 L
.39299 .01154 L
.39316 .00983 L
.39323 .00905 L
.39331 .00823 L
.39335 .00807 L
.39339 .00854 L
.39347 .00937 L
.39375 .01229 L
.3943 .01718 L
.39461 .01916 L
.3947 .0196 L
.39479 .01995 L
.39486 .02022 L
.39495 .02045 L
.39502 .02061 L
.3951 .02073 L
Mistroke
.39517 .0208 L
.39523 .02081 L
.39531 .02079 L
.39538 .02071 L
.39546 .02058 L
.39555 .02039 L
.39569 .01991 L
.39584 .01921 L
.39601 .01825 L
.39617 .01719 L
.39647 .01471 L
.39675 .01201 L
.397 .00942 L
.39707 .00866 L
.39714 .00794 L
.3972 .00858 L
.39727 .00929 L
.39784 .01491 L
.39814 .0173 L
.3983 .01838 L
.39846 .01922 L
.39859 .01979 L
.39873 .02025 L
.3988 .02044 L
.39884 .02051 L
.39888 .02057 L
.39895 .02065 L
.39902 .02069 L
.3991 .02067 L
.39915 .02064 L
.39919 .0206 L
.39926 .02048 L
.3993 .0204 L
.39934 .0203 L
.39949 .01983 L
.39963 .01922 L
.39995 .01732 L
.40029 .01459 L
.40058 .01178 L
.40074 .01013 L
.40082 .00931 L
.40089 .00855 L
.40094 .00811 L
.40098 .00823 L
.40103 .0087 L
.40107 .00922 L
.40124 .01091 L
.40156 .01402 L
.40186 .01658 L
.40203 .01777 L
Mistroke
.40218 .01872 L
.40233 .01945 L
.40241 .01977 L
.40249 .02005 L
.40256 .02024 L
.40263 .02041 L
.4027 .02053 L
.40277 .02059 L
.40284 .02063 L
.40291 .02061 L
.40298 .02056 L
.40305 .02047 L
.40313 .02032 L
.40321 .0201 L
.40336 .01956 L
.40352 .0188 L
.40368 .0178 L
.40398 .01555 L
.40451 .01054 L
.40466 .00903 L
.4047 .0086 L
.40474 .00818 L
.40481 .00847 L
.40488 .0092 L
.40495 .00987 L
.40509 .01137 L
.4054 .01432 L
.40573 .01704 L
.40588 .01808 L
.40605 .01899 L
.40618 .01963 L
.40626 .01992 L
.40633 .02015 L
.4064 .02033 L
.40648 .02048 L
.40655 .02057 L
.40661 .02062 L
.40668 .02063 L
.40676 .02059 L
.4068 .02056 L
.40684 .0205 L
.40691 .02037 L
.40698 .02021 L
.40706 .01998 L
.40719 .01945 L
.40745 .01806 L
.40777 .01572 L
.40807 .01301 L
.40835 .01028 L
.40848 .00885 L
Mistroke
.40856 .00803 L
.40864 .00861 L
.40895 .01185 L
.40924 .01461 L
.40956 .01717 L
.40972 .01828 L
.4099 .01925 L
.41005 .01991 L
.41014 .0202 L
.41022 .02041 L
.4103 .02055 L
.41037 .02064 L
.41044 .02068 L
.41048 .02069 L
.41052 .02068 L
.4106 .02062 L
.41067 .02053 L
.41071 .02045 L
.41076 .02036 L
.41083 .02015 L
.41098 .01961 L
.41112 .01895 L
.41138 .01734 L
.41166 .01508 L
.41194 .01252 L
.41224 .00946 L
.41232 .00863 L
.41236 .00817 L
.4124 .00813 L
.41248 .00894 L
.41255 .00971 L
.41285 .01275 L
.41312 .01527 L
.41341 .01754 L
.41356 .01853 L
.41372 .01942 L
.41387 .02005 L
.41394 .02027 L
.41401 .02047 L
.41405 .02057 L
.41409 .02065 L
.41413 .02071 L
.41417 .02076 L
.41425 .02081 L
.41432 .02081 L
.41437 .02079 L
.41441 .02075 L
.41445 .0207 L
.4145 .02063 L
.41458 .02046 L
Mistroke
.41466 .02021 L
.41481 .01963 L
.41498 .01878 L
.41528 .01674 L
.41584 .01159 L
.41601 .00988 L
.41609 .00902 L
.41616 .00824 L
.41624 .00846 L
.41628 .00892 L
.41632 .00935 L
.4165 .01121 L
.41679 .01407 L
.4171 .01684 L
.41725 .0179 L
.4174 .0189 L
.41754 .01961 L
.41768 .02024 L
.41776 .0205 L
.41784 .0207 L
.41792 .02086 L
.41796 .02092 L
.418 .02096 L
.41808 .021 L
.41816 .02099 L
.41823 .02093 L
.4183 .02083 L
.41836 .0207 L
.41843 .02053 L
.41856 .0201 L
.4187 .01943 L
.41884 .01867 L
.41941 .01412 L
.41969 .01123 L
.41985 .00955 L
.41993 .00872 L
.42 .00794 L
.42007 .00866 L
.42014 .00943 L
.42029 .01104 L
.42055 .01373 L
.42084 .01637 L
.42114 .01868 L
.42132 .01971 L
.42148 .02043 L
.42156 .0207 L
.42164 .02094 L
.42168 .02103 L
.42172 .0211 L
.4218 .02121 L
Mistroke
.42186 .02126 L
.42194 .02127 L
.42202 .02122 L
.42209 .02113 L
.42216 .021 L
.42222 .02085 L
.42236 .02038 L
.42251 .01969 L
.42267 .01874 L
.42297 .01653 L
.42325 .01397 L
.42354 .01091 L
.42366 .00959 L
.42373 .00885 L
.42379 .00815 L
.42387 .00856 L
.42393 .00931 L
.42407 .01078 L
.42465 .01657 L
.42497 .01905 L
.42512 .01996 L
.42526 .02063 L
.42539 .02111 L
.42546 .02129 L
.42554 .02145 L
.42561 .02155 L
.42569 .02161 L
.42576 .02161 L
.42583 .02156 L
.4259 .02147 L
.42596 .02135 L
.42603 .02118 L
.42611 .02094 L
.42623 .02044 L
.42637 .01973 L
.42668 .01757 L
.42698 .01492 L
.42725 .01212 L
.42739 .01049 L
.42753 .00891 L
.42761 .00801 L
.42766 .00837 L
.4277 .00883 L
.42785 .01052 L
.42813 .01368 L
.42845 .01679 L
.42862 .01826 L
.42879 .01947 L
.42894 .02036 L
.4291 .02113 L
Mistroke
.42917 .0214 L
.42924 .02163 L
.4293 .02179 L
.42937 .02192 L
.42945 .02201 L
.42951 .02205 L
.42958 .02204 L
.42966 .02198 L
.42972 .02189 L
.42978 .02176 L
.42985 .02159 L
.42992 .02135 L
.43008 .02065 L
.43026 .01964 L
.43057 .01719 L
.43088 .01421 L
.43116 .01105 L
.4313 .00941 L
.43137 .00859 L
.43144 .00804 L
.43151 .00891 L
.43159 .00986 L
.43173 .0115 L
.43206 .01513 L
.43236 .018 L
.43251 .01924 L
.43267 .02039 L
.43281 .0212 L
.43297 .02189 L
.43306 .02217 L
.43314 .02237 L
.43318 .02245 L
.43322 .02251 L
.43327 .02256 L
.43331 .02259 L
.43339 .02259 L
.43346 .02253 L
.43354 .02242 L
.43358 .02233 L
.43362 .02222 L
.43378 .02169 L
.43386 .02129 L
.43394 .02087 L
.43424 .01881 L
.43455 .01595 L
.43489 .01221 L
.43502 .01055 L
.43517 .00876 L
.43525 .00806 L
.43529 .0086 L
Mistroke
.43533 .00911 L
.43548 .01093 L
.43604 .01725 L
.43634 .01994 L
.43649 .02101 L
.43663 .02183 L
.43675 .02242 L
.43682 .02266 L
.43689 .02288 L
.43696 .02306 L
.43703 .02318 L
.4371 .02325 L
.43717 .02327 L
.43724 .02324 L
.43731 .02315 L
.43738 .02302 L
.43745 .02285 L
.43752 .0226 L
.4376 .02226 L
.43775 .02148 L
.43807 .0191 L
.43837 .01618 L
.43865 .01295 L
.43881 .01104 L
.43888 .01007 L
.43895 .00916 L
.43902 .00831 L
.43909 .00847 L
.43917 .00948 L
.43924 .01039 L
.4395 .01368 L
.4398 .01722 L
.44014 .02042 L
.44029 .0216 L
.44045 .02262 L
.44059 .02329 L
.44067 .02358 L
.44074 .0238 L
.44081 .02396 L
.44085 .02402 L
.44089 .02407 L
.44097 .0241 L
.44104 .02408 L
.44108 .02404 L
.44112 .02398 L
.4412 .02383 L
.44128 .0236 L
.44137 .02326 L
.44152 .02251 L
.44168 .02146 L
Mistroke
.44196 .01898 L
.44224 .01592 L
.44254 .01218 L
.44267 .01055 L
.44273 .00963 L
.4428 .00875 L
.44287 .00816 L
.44294 .00911 L
.44308 .01097 L
.44369 .01869 L
.44401 .02178 L
.44419 .02313 L
.44427 .02363 L
.44436 .02409 L
.44444 .02446 L
.44452 .02472 L
.44459 .02492 L
.44467 .02506 L
.44474 .02513 L
.4448 .02514 L
.44487 .0251 L
.44495 .02499 L
.44499 .0249 L
.44503 .0248 L
.44512 .02451 L
.44528 .02376 L
.44542 .02283 L
.44557 .02162 L
.44614 .01537 L
.44644 .0113 L
.44658 .00914 L
.44663 .00854 L
.44667 .00797 L
.44675 .00912 L
.44732 .01721 L
.44758 .02031 L
.44785 .02301 L
.448 .02423 L
.44808 .02478 L
.44817 .02528 L
.44825 .02567 L
.44832 .02595 L
.4484 .02618 L
.44847 .02633 L
.4485 .02638 L
.44855 .02642 L
.44859 .02644 L
.44863 .02644 L
.44871 .02638 L
.44875 .02631 L
Mistroke
.44879 .02623 L
.44887 .026 L
.44895 .02566 L
.44913 .02468 L
.44929 .0235 L
.44944 .02218 L
.44976 .01848 L
.45004 .01466 L
.4502 .01229 L
.45035 .00999 L
.45042 .00885 L
.45049 .0081 L
.45057 .00936 L
.45064 .0105 L
.45095 .0153 L
.4515 .02268 L
.45165 .02425 L
.45181 .02565 L
.45196 .02671 L
.4521 .02742 L
.45218 .02773 L
.45226 .02794 L
.4523 .02802 L
.45234 .02807 L
.45239 .02811 L
.45243 .02811 L
.45247 .02809 L
.45251 .02805 L
.45259 .02792 L
.45266 .0277 L
.45275 .02736 L
.45289 .02659 L
.45304 .02548 L
.45331 .02276 L
.45364 .0185 L
.45394 .01385 L
.45408 .01147 L
.45416 .01013 L
.45423 .00885 L
.45428 .00812 L
.45432 .00855 L
.4544 .00994 L
.45455 .01264 L
.45489 .01823 L
.4552 .02285 L
.45548 .02616 L
.45562 .02752 L
.45577 .02872 L
.45586 .02926 L
.45594 .02966 L
Mistroke
.45602 .02995 L
.45606 .03008 L
.4561 .03017 L
.45617 .03028 L
.45622 .0303 L
.45625 .0303 L
.45632 .03024 L
.4564 .0301 L
.45648 .02985 L
.45655 .02954 L
.45671 .02858 L
.45686 .02734 L
.457 .02589 L
.45732 .02173 L
.45767 .01606 L
.45781 .01348 L
.45796 .0106 L
.45803 .00918 L
.4581 .00806 L
.45816 .00928 L
.45823 .01063 L
.45886 .02225 L
.45917 .02706 L
.45935 .0292 L
.45951 .03085 L
.45967 .03202 L
.45975 .03252 L
.45983 .03287 L
.4599 .03309 L
.45997 .03324 L
.46005 .03329 L
.46012 .03325 L
.4602 .03311 L
.46024 .033 L
.46028 .03285 L
.46035 .03252 L
.46042 .03211 L
.46058 .03091 L
.46075 .02915 L
.46106 .02484 L
.46135 .0198 L
.46163 .01405 L
.46176 .01107 L
.46182 .00974 L
.46189 .00829 L
.46196 .00911 L
.46202 .01056 L
.46216 .01375 L
.46246 .0203 L
.46274 .0258 L
Mistroke
.46303 .03082 L
.4632 .03316 L
.46335 .03491 L
.46343 .0356 L
.46351 .03624 L
.46358 .03671 L
.46366 .0371 L
.4637 .03728 L
.46374 .0374 L
.46378 .03749 L
.46382 .03756 L
.4639 .03758 L
.46397 .03749 L
.46402 .03739 L
.46406 .03725 L
.46415 .03684 L
.46423 .03631 L
.46431 .03567 L
.46446 .03412 L
.4646 .0323 L
.46492 .02692 L
.4652 .02094 L
.46535 .01744 L
.4655 .01354 L
.46564 .00999 L
.46571 .00794 L
.46579 .00986 L
.46605 .01688 L
.46635 .02484 L
.46668 .03253 L
.46684 .03557 L
.467 .03837 L
.46715 .04055 L
.46729 .04213 L
.46736 .04278 L
.46743 .04335 L
.46747 .04361 L
.46751 .04382 L
.46759 .04411 L
.46765 .04426 L
.46773 .04429 L
.4678 .04419 L
.46787 .04397 L
.46795 .04357 L
.46803 .04299 L
.46818 .04152 L
.46834 .03934 L
.46852 .03627 L
.46909 .02184 L
.46923 .01761 L
Mistroke
.46938 .01291 L
.46944 .01092 L
.4695 .00876 L
.46957 .00952 L
.46964 .01179 L
.46993 .02197 L
.47025 .03257 L
.47052 .04054 L
.47081 .04779 L
.47099 .05119 L
.47107 .05256 L
.47115 .05363 L
.47123 .0545 L
.47131 .05526 L
.47135 .05559 L
.47139 .05584 L
.47143 .05603 L
.47147 .05618 L
.47154 .05631 L
.47162 .05626 L
.47169 .05604 L
.47176 .05568 L
.47184 .05507 L
.47192 .05419 L
.47207 .05196 L
.47221 .04924 L
.47236 .0456 L
.47264 .03725 L
.47294 .02587 L
.47311 .01856 L
.47319 .0148 L
.47326 .01131 L
.4733 .00949 L
.47334 .00838 L
.47342 .01205 L
.47358 .02026 L
.47392 .03716 L
.47423 .05204 L
.47453 .06442 L
.4748 .07393 L
.47494 .07781 L
.4751 .08114 L
.47518 .08257 L
.47523 .08314 L
.47526 .08358 L
.47534 .08426 L
.47538 .08451 L
.47542 .08467 L
.4755 .08473 L
.47557 .08454 L
Mistroke
.47564 .08403 L
.47568 .08366 L
.47572 .08316 L
.47581 .08184 L
.47589 .08022 L
.47604 .0762 L
.4762 .0704 L
.47638 .06239 L
.47669 .04355 L
.47685 .03251 L
.47699 .02136 L
.47706 .01538 L
.47712 .00962 L
.47719 .01247 L
.47727 .01948 L
.47757 .04986 L
.47811 .11108 L
.47875 .18563 L
.47935 .24902 L
.47964 .27428 L
.47994 .29615 L
.4801 .30535 L
.48028 .31353 L
.48036 .31647 L
.48044 .31917 L
.48051 .32126 L
.48059 .32282 L
.48066 .32399 L
.48073 .32485 L
.4808 .32531 L
.48085 .3254 L
.48089 .32536 L
.48096 .325 L
.48102 .32435 L
.4811 .32328 L
.48117 .32175 L
.4813 .31814 L
.48143 .3137 L
.4817 .29995 L
.48201 .2797 L
.48234 .2524 L
.48293 .19263 L
.48405 .07148 L
.48433 .04485 L
.48448 .03123 L
.48462 .0191 L
.4847 .01264 L
.48475 .00911 L
.48479 .00995 L
.48486 .01539 L
Mistroke
.48494 .02091 L
.48525 .03911 L
.48541 .04712 L
.48559 .05427 L
.48576 .05957 L
.48591 .06324 L
.48598 .06448 L
.48605 .06558 L
.48613 .0665 L
.4862 .06711 L
.48624 .06734 L
.48629 .06751 L
.48636 .06761 L
.48644 .06747 L
.48651 .06713 L
.48658 .06659 L
.48666 .06583 L
.48679 .06398 L
.48693 .06135 L
.48709 .05779 L
.48763 .04136 L
.48795 .0303 L
.48828 .01822 L
.48844 .0125 L
.48852 .00977 L
.48859 .00856 L
.48866 .01074 L
.48873 .01299 L
.48887 .01751 L
.48917 .02534 L
.48944 .03124 L
.4896 .03379 L
.48976 .03597 L
.48983 .03673 L
.48991 .03741 L
.48998 .03789 L
.49005 .03828 L
.49013 .03857 L
.4902 .03872 L
.49027 .03877 L
.49031 .03875 L
.49035 .03869 L
.49042 .03851 L
.49049 .03826 L
.49056 .03787 L
.49063 .0374 L
.49076 .0363 L
.49088 .03502 L
.49115 .03135 L
.4917 .02166 L
Mistroke
.492 .01564 L
.49214 .01265 L
.49228 .00991 L
.49236 .00839 L
.4924 .00832 L
.49244 .00908 L
.49261 .01231 L
.49292 .01739 L
.49321 .02128 L
.49337 .02306 L
.49352 .02442 L
.49366 .02541 L
.49373 .02582 L
.49381 .02618 L
.49386 .02634 L
.4939 .02647 L
.49398 .02666 L
.49405 .02676 L
.49412 .0268 L
.49419 .02676 L
.49426 .02667 L
.49433 .02652 L
.49439 .02634 L
.49453 .02576 L
.49468 .0249 L
.49499 .02242 L
.49528 .01943 L
.49559 .01567 L
.49576 .01356 L
.49593 .01129 L
.49609 .00926 L
.49613 .00871 L
.49618 .00812 L
.49622 .0083 L
.49626 .0088 L
.49656 .01243 L
.49685 .01544 L
.49716 .01811 L
.4973 .0191 L
.49746 .01995 L
.4976 .02058 L
.49773 .02098 L
.4978 .02113 L
.49787 .02124 L
.49794 .02131 L
.49801 .02133 L
.49808 .02131 L
.49814 .02126 L
.49821 .02117 L
.49828 .02103 L
Mistroke
.49947 .01331 L
.4998 .01003 L
.49988 .00921 L
.49992 .00877 L
.49996 .00832 L
.50001 .00807 L
.50006 .00854 L
.50015 .00946 L
.50077 .01552 L
.50106 .0178 L
.50121 .01885 L
.50136 .01969 L
.5015 .02033 L
.50158 .0206 L
.50165 .02085 L
.50172 .02102 L
.50179 .02116 L
.50185 .02126 L
.50192 .02131 L
.50199 .02133 L
.50204 .02132 L
.50208 .02129 L
.50215 .02121 L
.50223 .02106 L
.5023 .02089 L
.50237 .02068 L
.50252 .02006 L
.50268 .01918 L
.50283 .01817 L
.50317 .01528 L
.50345 .01226 L
.50361 .01043 L
.50369 .00949 L
.50376 .00861 L
.50382 .00811 L
.50389 .00901 L
.50404 .01095 L
.5043 .01433 L
.5049 .02137 L
.50508 .02301 L
.50524 .02433 L
.50539 .02532 L
.50547 .02576 L
.50555 .02611 L
.50562 .02637 L
.5057 .02659 L
.50577 .02672 L
.50584 .02678 L
.5059 .02679 L
.50597 .02674 L
Mistroke
.50604 .02662 L
.50611 .02645 L
.50619 .02616 L
.50627 .02582 L
.50641 .02496 L
.50656 .02374 L
.50672 .02208 L
.507 .01859 L
.50729 .01394 L
.50743 .01154 L
.5075 .01018 L
.50757 .00888 L
.50763 .00813 L
.50769 .00936 L
.50783 .01202 L
.50839 .02337 L
.50869 .02884 L
.50902 .03376 L
.50919 .03584 L
.50927 .03659 L
.50936 .0373 L
.50943 .03782 L
.50951 .03825 L
.50956 .03844 L
.5096 .03857 L
.50964 .03867 L
.50968 .03874 L
.50975 .03877 L
.50983 .03868 L
.5099 .03848 L
.50997 .0382 L
.51004 .03774 L
.51013 .03709 L
.51028 .0355 L
.51042 .03352 L
.51058 .0309 L
.51085 .0249 L
.51115 .01668 L
.51131 .01175 L
.51135 .0105 L
.51139 .00914 L
.51144 .00826 L
.51148 .00971 L
.51166 .0159 L
.51182 .0218 L
.51214 .03356 L
.51275 .05353 L
.5129 .05759 L
.51306 .0613 L
.51322 .06409 L
Mistroke
.51336 .06598 L
.5134 .06641 L
.51344 .06679 L
.51352 .0673 L
.51356 .06748 L
.5136 .06758 L
.51365 .06761 L
.5137 .06755 L
.51374 .06742 L
.51378 .0672 L
.51383 .0669 L
.51387 .06656 L
.51394 .06572 L
.51402 .06455 L
.51416 .06169 L
.51432 .05751 L
.51459 .04698 L
.51492 .02945 L
.51508 .01914 L
.51516 .01386 L
.51523 .00876 L
.5153 .0125 L
.51537 .01858 L
.51551 .03022 L
.51582 .05834 L
.51636 .11545 L
.51701 .18629 L
.51761 .24747 L
.51815 .29108 L
.51831 .30076 L
.51846 .30857 L
.5186 .31488 L
.51874 .31936 L
.51881 .32127 L
.51889 .32294 L
.51893 .32367 L
.51897 .32423 L
.51904 .32502 L
.51911 .32535 L
.51918 .32535 L
.51926 .32494 L
.51933 .32418 L
.51937 .32359 L
.51941 .32281 L
.51949 .32104 L
.51964 .31652 L
.51982 .30929 L
.51998 .3008 L
.52056 .25727 L
.5211 .20209 L
Mistroke
.52171 .13235 L
.52204 .09386 L
.52234 .05951 L
.52262 .03021 L
.5227 .02228 L
.52278 .01504 L
.52285 .00874 L
.52292 .01372 L
.52323 .03831 L
.52356 .05894 L
.52383 .07174 L
.52399 .07705 L
.52407 .0791 L
.52414 .08075 L
.5242 .08198 L
.52427 .08307 L
.52434 .08382 L
.52439 .08431 L
.52446 .08466 L
.52453 .08474 L
.5246 .08458 L
.52467 .08418 L
.52474 .08354 L
.52482 .08258 L
.52495 .08021 L
.52511 .07638 L
.52526 .07203 L
.52588 .04665 L
.52616 .03328 L
.5263 .02605 L
.52645 .01838 L
.52659 .01178 L
.52666 .00808 L
.52673 .01119 L
.52699 .02295 L
.52729 .03482 L
.52745 .0402 L
.52762 .04516 L
.52778 .0491 L
.52793 .05195 L
.528 .05308 L
.52807 .05411 L
.52815 .05489 L
.52821 .05547 L
.52828 .05589 L
.52835 .05618 L
.52842 .05631 L
.52849 .05626 L
.52857 .05604 L
.52861 .05584 L
Mistroke
.52865 .0556 L
.52872 .05506 L
.52879 .05431 L
.52892 .05261 L
.52905 .05058 L
.52933 .04454 L
.52992 .02704 L
.53007 .02178 L
.53024 .01605 L
.53032 .01326 L
.5304 .01063 L
.53047 .00829 L
.53054 .0101 L
.53107 .02656 L
.53137 .03399 L
.53152 .03697 L
.53165 .03927 L
.53178 .04112 L
.53193 .04266 L
.53201 .04329 L
.53208 .04374 L
.53215 .04405 L
.53222 .04424 L
.53226 .04429 L
.5323 .04429 L
.53235 .04425 L
.53239 .04417 L
.53247 .04391 L
.53251 .0437 L
.53255 .04346 L
.53269 .04232 L
.53285 .04059 L
.53301 .03823 L
.53319 .0351 L
.53351 .02816 L
.53382 .02037 L
.53397 .01632 L
.53411 .01256 L
.53418 .01069 L
.53425 .00897 L
.53431 .0087 L
.53439 .01064 L
.53468 .01814 L
.53501 .02553 L
.53531 .03096 L
.53546 .03315 L
.53562 .03505 L
.5357 .03575 L
.53578 .03637 L
.53585 .03684 L
Mistroke
.53592 .03716 L
.536 .03742 L
.53604 .03751 L
.53608 .03757 L
.53615 .03758 L
.53623 .03747 L
.53627 .03737 L
.53631 .03722 L
.53641 .03679 L
.53649 .03625 L
.53657 .03562 L
.53685 .0325 L
.53716 .02768 L
.53746 .02191 L
.53778 .01497 L
.53794 .01149 L
.53801 .00976 L
.53808 .00818 L
.53815 .00913 L
.53822 .01064 L
.53836 .01375 L
.5389 .02412 L
.53919 .02845 L
.53933 .03006 L
.53946 .03127 L
.53961 .03232 L
.53969 .03273 L
.53973 .03289 L
.53977 .03304 L
.53982 .03315 L
.53985 .03322 L
.53993 .03329 L
.54 .03327 L
.54007 .03316 L
.54014 .03297 L
.5402 .03273 L
.54027 .03238 L
.54034 .03196 L
.5406 .0298 L
.54074 .02816 L
.54087 .02641 L
.54117 .02174 L
.54145 .01673 L
.5416 .01394 L
.54175 .01094 L
.54182 .00965 L
.54189 .00828 L
.54196 .0091 L
.54204 .01048 L
.5423 .01536 L
Mistroke
.54263 .02098 L
.54295 .0253 L
.54308 .0268 L
.54323 .02812 L
.5433 .02869 L
.54339 .02922 L
.54346 .02959 L
.54354 .0299 L
.54361 .03013 L
.54369 .03026 L
.54373 .03029 L
.54377 .0303 L
.54385 .03025 L
.54392 .03012 L
.54399 .02992 L
.54407 .02962 L
.54415 .02922 L
.54428 .02831 L
.54441 .02723 L
.54471 .02403 L
.54502 .0197 L
.54535 .01424 L
.54551 .01158 L
.54559 .01011 L
.54567 .00872 L
.54574 .00833 L
.54581 .00958 L
.54596 .01222 L
.54629 .01749 L
.5466 .02179 L
.54688 .02482 L
.54704 .02613 L
.54711 .02661 L
.54719 .02706 L
.54727 .02743 L
.54734 .02769 L
.5474 .02789 L
.54747 .02803 L
.54754 .0281 L
.5476 .02811 L
.54766 .02807 L
.54773 .02796 L
.5478 .02778 L
.54789 .02749 L
.54803 .02675 L
.54818 .02578 L
.54831 .02466 L
.54889 .01776 L
.54915 .01383 L
.54929 .01157 L
Mistroke
.54943 .00944 L
.5495 .0083 L
.54958 .00879 L
.54962 .00948 L
.54966 .01014 L
.54974 .01134 L
.55003 .0156 L
.55033 .01964 L
.55049 .02147 L
.55067 .02316 L
.55083 .02441 L
.55097 .0253 L
.55104 .02564 L
.55111 .02594 L
.55119 .02616 L
.55125 .02631 L
.55129 .02637 L
.55133 .02642 L
.55141 .02644 L
.55148 .0264 L
.55155 .02629 L
.55163 .02612 L
.55171 .02585 L
.55179 .02548 L
.55187 .02506 L
.55215 .02302 L
.55241 .02048 L
.55298 .01307 L
.55313 .01091 L
.55327 .00885 L
.55334 .00805 L
.55342 .00917 L
.55358 .0115 L
.55413 .01866 L
.55445 .02181 L
.55461 .02304 L
.5547 .02362 L
.55478 .02407 L
.55485 .02439 L
.55493 .02468 L
.55498 .02481 L
.55501 .02491 L
.55509 .02506 L
.55516 .02512 L
.55523 .02514 L
.55531 .02508 L
.55538 .02498 L
.55546 .02479 L
.55554 .02453 L
.55568 .02388 L
Mistroke
.55584 .02293 L
.55601 .02161 L
.5566 .01518 L
.55688 .01155 L
.55702 .00957 L
.5571 .00857 L
.55714 .008 L
.55718 .00841 L
.55746 .01221 L
.55772 .01547 L
.55802 .01881 L
.55818 .0203 L
.55835 .02164 L
.5585 .02258 L
.55858 .023 L
.55866 .02337 L
.55874 .02365 L
.55881 .02384 L
.55888 .02398 L
.55895 .02407 L
.55902 .0241 L
.55908 .02409 L
.55915 .02401 L
.55922 .02389 L
.55929 .02373 L
.55935 .02354 L
.55948 .02299 L
.55962 .02224 L
.55976 .02122 L
.56006 .01859 L
.56038 .01516 L
.56068 .01149 L
.56081 .00982 L
.56088 .00889 L
.56095 .00803 L
.56102 .00878 L
.5611 .0098 L
.56124 .01158 L
.56184 .01834 L
.56201 .01979 L
.56218 .02107 L
.56233 .02195 L
.56242 .02235 L
.5625 .02266 L
.56257 .02289 L
.56265 .02308 L
.56273 .0232 L
.56277 .02325 L
.56281 .02327 L
.56289 .02326 L
Mistroke
.56296 .02319 L
.563 .02314 L
.56304 .02306 L
.56311 .02288 L
.56319 .02264 L
.56325 .02238 L
.5634 .02164 L
.56367 .01979 L
.56399 .01687 L
.56433 .01316 L
.56462 .00969 L
.5647 .00872 L
.56474 .00817 L
.56478 .0082 L
.56486 .00916 L
.56494 .01007 L
.56523 .01352 L
.56554 .0168 L
.56583 .01931 L
.5661 .02108 L
.56623 .02173 L
.5663 .022 L
.56638 .02223 L
.56646 .02242 L
.56651 .02249 L
.56655 .02254 L
.56662 .02259 L
.5667 .02259 L
.56674 .02256 L
.56678 .02251 L
.56683 .02244 L
.56687 .02235 L
.56695 .02215 L
.56704 .02186 L
.5672 .02113 L
.56735 .02025 L
.56765 .01793 L
.56798 .01475 L
.56826 .01154 L
.56842 .00969 L
.5685 .00878 L
.56857 .00794 L
.56864 .0087 L
.5687 .0095 L
.56885 .01116 L
.56915 .01451 L
.56943 .01718 L
.56969 .01925 L
.56983 .02017 L
.56999 .02098 L
Mistroke
.57006 .02127 L
.57013 .02152 L
.5702 .02172 L
.57026 .02186 L
.57033 .02197 L
.57041 .02204 L
.57048 .02205 L
.57055 .02201 L
.57059 .02197 L
.57063 .02191 L
.57071 .02177 L
.57079 .02153 L
.57087 .02125 L
.57102 .02061 L
.57115 .01987 L
.57144 .01772 L
.57198 .01248 L
.57212 .01087 L
.57226 .00931 L
.57234 .00844 L
.57238 .00795 L
.57242 .00838 L
.57256 .01003 L
.57311 .01576 L
.5734 .01818 L
.57356 .01932 L
.57371 .02018 L
.57387 .02087 L
.57396 .02115 L
.574 .02126 L
.57404 .02137 L
.57412 .02151 L
.57419 .02158 L
.57424 .02161 L
.57428 .02161 L
.57435 .02159 L
.57442 .02151 L
.5745 .02138 L
.57457 .02121 L
.57463 .02102 L
.57479 .0204 L
.57494 .01961 L
.57524 .01755 L
.57556 .01467 L
.57584 .0118 L
.57599 .01014 L
.57607 .00931 L
.57614 .00854 L
.5762 .00806 L
.57627 .00883 L
Mistroke
.57642 .01043 L
.57667 .01312 L
.57696 .01593 L
.57724 .01816 L
.5774 .01916 L
.57756 .02005 L
.57764 .02036 L
.57771 .02065 L
.57779 .02087 L
.57785 .02103 L
.57792 .02115 L
.57799 .02122 L
.57805 .02127 L
.57813 .02126 L
.57819 .02122 L
.57826 .02114 L
.57832 .02102 L
.57838 .02088 L
.57852 .02042 L
.57868 .01972 L
.57896 .01798 L
.57926 .01555 L
.57958 .01244 L
.57973 .01081 L
.57988 .00922 L
.57995 .00853 L
.58001 .00809 L
.58009 .0089 L
.58016 .00965 L
.58076 .01566 L
.58108 .01811 L
.58126 .01921 L
.58142 .02002 L
.5815 .02029 L
.58157 .02053 L
.58164 .0207 L
.58171 .02084 L
.58175 .02091 L
.58179 .02095 L
.58187 .021 L
.58194 .021 L
.58202 .02094 L
.58209 .02084 L
.58217 .02068 L
.58224 .02048 L
.58231 .02025 L
.58248 .01954 L
.58264 .01865 L
.58317 .01447 L
.58345 .01173 L
Mistroke
.5836 .01021 L
.58368 .00936 L
.58375 .00856 L
.58379 .00815 L
.58383 .00816 L
.58388 .00865 L
.58392 .0091 L
.58407 .01072 L
.58437 .01374 L
.58467 .01632 L
.58494 .01828 L
.58508 .01914 L
.58525 .01989 L
.58533 .02018 L
.58541 .02043 L
.58546 .02054 L
.5855 .02062 L
.58554 .02069 L
.58559 .02075 L
.58566 .0208 L
.58573 .02081 L
.58577 .0208 L
.58581 .02077 L
.58588 .02068 L
.58596 .02054 L
.58604 .02035 L
.5862 .01978 L
.58635 .01908 L
.58648 .0183 L
.58678 .0161 L
.58733 .01097 L
.58748 .00943 L
.58752 .00902 L
.58756 .00858 L
.58763 .0081 L
.58768 .00855 L
.58772 .00897 L
.58781 .00991 L
.58797 .01156 L
.58826 .01438 L
.58857 .01697 L
.58873 .01807 L
.58888 .01895 L
.58903 .01964 L
.58909 .01989 L
.58916 .02013 L
.58922 .0203 L
.58929 .02045 L
.58936 .02057 L
.58942 .02065 L
Mistroke
.5895 .02069 L
.58957 .02068 L
.58964 .02063 L
.58971 .02054 L
.58975 .02047 L
.58979 .02037 L
.58987 .02016 L
.59002 .01962 L
.59019 .01878 L
.59035 .0178 L
.59095 .0128 L
.59124 .00995 L
.59132 .00911 L
.59139 .0083 L
.59146 .0083 L
.59154 .00909 L
.59209 .01449 L
.5924 .01705 L
.59257 .0182 L
.59273 .0191 L
.59287 .01971 L
.59302 .0202 L
.59309 .02039 L
.59314 .02047 L
.59318 .02053 L
.59325 .0206 L
.59333 .02063 L
.59341 .02061 L
.59344 .02057 L
.59349 .02053 L
.59356 .0204 L
.59363 .02024 L
.59379 .01973 L
.59396 .01896 L
.59427 .01699 L
.59456 .01467 L
.59483 .01208 L
.59498 .01062 L
.59506 .00981 L
.59513 .00903 L
.5952 .00829 L
.59528 .00839 L
.59535 .00912 L
.59542 .00979 L
.59568 .01244 L
.59596 .01507 L
.59627 .01744 L
.59641 .01839 L
.59655 .01915 L
.59668 .0197 L
Mistroke
.59681 .02016 L
.59689 .02035 L
.59696 .02049 L
.59704 .02058 L
.59708 .02061 L
.59712 .02063 L
.59719 .02062 L
.59727 .02056 L
.59734 .02046 L
.59741 .02033 L
.59749 .0201 L
.59757 .01984 L
.59772 .01921 L
.59788 .01834 L
.59806 .0172 L
.59836 .0148 L
.59868 .01176 L
.59883 .01018 L
.59891 .00939 L
.59898 .00865 L
.59904 .00798 L
.59911 .00861 L
.59926 .01011 L
.59986 .01583 L
.60017 .01814 L
.60035 .01915 L
.60052 .01989 L
.60059 .02013 L
.60067 .02033 L
.60074 .02049 L
.6008 .02059 L
.60088 .02067 L
.60092 .02069 L
.60096 .02069 L
.60104 .02066 L
.60111 .02058 L
.60119 .02046 L
.60127 .02027 L
.60141 .01981 L
.60158 .01904 L
.60174 .01814 L
.60231 .01355 L
.60259 .01078 L
.60272 .00936 L
.60278 .00873 L
.60285 .00803 L
.60292 .00859 L
.60299 .00938 L
.60315 .01101 L
.60343 .01373 L
Mistroke
.60372 .01634 L
.60389 .01757 L
.60404 .01858 L
.60418 .01936 L
.60434 .02003 L
.60441 .02026 L
.60448 .02046 L
.60454 .0206 L
.60461 .02071 L
.60468 .02078 L
.60475 .02081 L
.60482 .0208 L
.60489 .02075 L
.60495 .02066 L
.60501 .02055 L
.60508 .02039 L
.60515 .02018 L
.6053 .01957 L
.60547 .01871 L
.60576 .01669 L
.60611 .01367 L
.60643 .01042 L
.6065 .0097 L
.60658 .00891 L
.60665 .00815 L
.60671 .00842 L
.60679 .00922 L
.60687 .01008 L
.60701 .01157 L
.60734 .0148 L
.60765 .01734 L
.60792 .01913 L
.60806 .01982 L
.60821 .0204 L
.60829 .02063 L
.60836 .02079 L
.6084 .02086 L
.60844 .02093 L
.60852 .02099 L
.6086 .021 L
.60867 .02097 L
.60874 .02089 L
.60881 .02076 L
.60889 .02058 L
.60896 .02037 L
.60909 .01987 L
.60923 .01917 L
.60938 .01824 L
.60991 .01383 L
.61007 .0123 L
Mistroke
.61023 .01057 L
.61031 .00975 L
.61039 .00888 L
.61046 .00813 L
.61053 .00856 L
.61061 .00936 L
.61067 .01008 L
.61082 .01168 L
.6111 .01442 L
.61141 .01714 L
.61157 .01835 L
.61174 .01943 L
.6119 .02018 L
.61198 .0205 L
.61206 .02079 L
.61214 .02099 L
.61222 .02113 L
.61228 .02122 L
.61236 .02127 L
.61243 .02126 L
.61247 .02124 L
.61251 .0212 L
.61258 .0211 L
.61266 .02094 L
.61273 .02076 L
.61279 .02055 L
.61293 .01996 L
.61309 .01912 L
.61323 .0182 L
.61355 .01564 L
.61382 .01301 L
.61396 .01151 L
.61411 .00986 L
.61419 .00903 L
.61426 .00824 L
.61432 .00835 L
.61439 .00911 L
.61465 .01194 L
.61522 .01742 L
.61538 .01861 L
.61555 .01969 L
.61571 .0205 L
.61585 .02105 L
.61593 .02128 L
.61597 .02137 L
.61601 .02145 L
.61609 .02155 L
.61616 .02161 L
.61621 .02161 L
.61625 .0216 L
Mistroke
.61633 .02154 L
.61637 .02148 L
.61641 .02141 L
.6165 .02119 L
.61658 .02094 L
.61666 .02065 L
.6168 .01997 L
.61712 .01786 L
.61771 .0123 L
.61785 .01074 L
.618 .00901 L
.61805 .00849 L
.61809 .00801 L
.61813 .00831 L
.61817 .00878 L
.61833 .01057 L
.6189 .01653 L
.61918 .01886 L
.61944 .02049 L
.61957 .02112 L
.61971 .02161 L
.61978 .02179 L
.61985 .02192 L
.61992 .02201 L
.62 .02205 L
.62004 .02205 L
.62008 .02203 L
.62012 .02199 L
.62017 .02194 L
.62024 .0218 L
.62033 .02158 L
.6204 .02133 L
.62048 .02101 L
.62062 .02029 L
.62096 .01792 L
.62128 .01493 L
.6216 .01149 L
.62175 .00976 L
.62182 .00899 L
.62189 .00814 L
.62196 .00856 L
.62203 .00943 L
.62219 .01124 L
.62246 .01438 L
.62276 .01735 L
.62293 .01877 L
.62308 .01993 L
.62322 .02083 L
.62338 .02162 L
.62345 .02189 L
Mistroke
.62352 .02214 L
.62358 .02231 L
.62365 .02245 L
.62372 .02254 L
.62378 .02259 L
.62384 .02259 L
.62391 .02256 L
.62398 .02248 L
.62404 .02237 L
.62411 .02219 L
.62419 .02195 L
.62434 .02128 L
.62451 .02033 L
.6248 .01805 L
.62515 .01463 L
.62547 .01091 L
.62554 .01008 L
.62561 .00917 L
.62568 .0083 L
.62575 .00837 L
.62583 .00931 L
.62591 .0103 L
.62605 .01203 L
.62638 .01581 L
.62668 .0188 L
.62699 .02112 L
.62714 .02199 L
.62722 .02239 L
.6273 .0227 L
.62739 .02296 L
.62743 .02305 L
.62747 .02313 L
.62752 .02319 L
.62756 .02324 L
.6276 .02326 L
.62765 .02327 L
.62769 .02325 L
.62773 .02322 L
.62778 .02317 L
.62782 .0231 L
.62789 .02293 L
.62797 .02268 L
.62813 .022 L
.62828 .02116 L
.6286 .01861 L
.62919 .0122 L
.62934 .0103 L
.62941 .00935 L
.62948 .00848 L
.62955 .00832 L
Mistroke
.62963 .00931 L
.62979 .0114 L
.63035 .01792 L
.63065 .02077 L
.63082 .02196 L
.63099 .02295 L
.63106 .02328 L
.63114 .02358 L
.63118 .02372 L
.63123 .02382 L
.63127 .02392 L
.63131 .02399 L
.63137 .02407 L
.63145 .0241 L
.63152 .02408 L
.6316 .02398 L
.63167 .02383 L
.63175 .0236 L
.63184 .02328 L
.63192 .02291 L
.63221 .02098 L
.63238 .01952 L
.63254 .01798 L
.63288 .01395 L
.63318 .01004 L
.63326 .00893 L
.63331 .00831 L
.63335 .00813 L
.63339 .00866 L
.63343 .00924 L
.6335 .01027 L
.63409 .01783 L
.63437 .02072 L
.63467 .02311 L
.63475 .02365 L
.63484 .02409 L
.63492 .02444 L
.63499 .02471 L
.63506 .0249 L
.63514 .02505 L
.63521 .02512 L
.63525 .02514 L
.6353 .02513 L
.63537 .02507 L
.63541 .02501 L
.63545 .02494 L
.63553 .02473 L
.63561 .02443 L
.63577 .02368 L
.63591 .02277 L
Mistroke
.63624 .01977 L
.63656 .01605 L
.63687 .01195 L
.63701 .00983 L
.63708 .00888 L
.63715 .00802 L
.63722 .0091 L
.63729 .01011 L
.63744 .01234 L
.63777 .01683 L
.63805 .02024 L
.63834 .0232 L
.63847 .02416 L
.6386 .02502 L
.63867 .02543 L
.63874 .02574 L
.63881 .02599 L
.63888 .02619 L
.63896 .02635 L
.63903 .02643 L
.6391 .02644 L
.63916 .0264 L
.63923 .02629 L
.63931 .0261 L
.63939 .02583 L
.63947 .02549 L
.63961 .02471 L
.63973 .0238 L
.64002 .02112 L
.64033 .01731 L
.64066 .0125 L
.64082 .00999 L
.6409 .00874 L
.64097 .00829 L
.64104 .00935 L
.64111 .01047 L
.64126 .0128 L
.64154 .01711 L
.64185 .02122 L
.64213 .02433 L
.64227 .02556 L
.6424 .02649 L
.64255 .02732 L
.64263 .02764 L
.64267 .02777 L
.64271 .02789 L
.64278 .02803 L
.64285 .0281 L
.64293 .02811 L
.643 .02804 L
Mistroke
.64307 .02789 L
.64315 .02767 L
.64323 .02734 L
.64331 .0269 L
.64349 .0257 L
.64365 .02428 L
.64394 .02093 L
.64425 .01651 L
.64452 .01217 L
.64459 .01097 L
.64466 .00965 L
.64474 .00839 L
.6448 .00865 L
.64488 .01002 L
.64496 .01147 L
.64511 .014 L
.6454 .01874 L
.64574 .02365 L
.64589 .02546 L
.64605 .02715 L
.6462 .02837 L
.64636 .02936 L
.64644 .02976 L
.64652 .03003 L
.6466 .03021 L
.64667 .03029 L
.64671 .0303 L
.64676 .03029 L
.6468 .03024 L
.64684 .03017 L
.64692 .02998 L
.64696 .02984 L
.647 .02968 L
.64708 .02926 L
.64717 .02867 L
.64734 .02728 L
.64765 .02381 L
.64797 .01894 L
.64826 .01393 L
.64841 .011 L
.64849 .00953 L
.64856 .00818 L
.64863 .00914 L
.64871 .0107 L
.64888 .01398 L
.64918 .01952 L
.6495 .02485 L
.64967 .02725 L
.64985 .02943 L
.65 .03094 L
Mistroke
.65008 .03159 L
.65017 .03219 L
.65025 .03262 L
.65032 .03293 L
.65039 .03313 L
.65047 .03326 L
.65054 .03329 L
.65061 .03323 L
.65069 .03308 L
.65075 .03287 L
.65083 .03253 L
.65091 .03205 L
.65106 .03089 L
.6512 .02946 L
.65135 .02757 L
.65163 .02334 L
.65193 .01773 L
.65208 .01445 L
.65225 .01079 L
.6523 .00974 L
.65235 .00874 L
.65239 .00804 L
.65243 .00901 L
.65259 .0127 L
.65291 .0198 L
.65323 .02607 L
.65352 .031 L
.65379 .03455 L
.65395 .03598 L
.65402 .03647 L
.65409 .0369 L
.65413 .03708 L
.65417 .03725 L
.65425 .03747 L
.65429 .03754 L
.65433 .03758 L
.65437 .03758 L
.65441 .03755 L
.65448 .03741 L
.65456 .03715 L
.6546 .03697 L
.65464 .03674 L
.65472 .03624 L
.65488 .03477 L
.65506 .03259 L
.65538 .02721 L
.65569 .02053 L
.65585 .01686 L
.65599 .01333 L
.65605 .01157 L
Mistroke
.65613 .00962 L
.6562 .00811 L
.65626 .00984 L
.65656 .0178 L
.65689 .02625 L
.65718 .03302 L
.65734 .036 L
.6575 .03878 L
.65764 .04077 L
.6578 .04247 L
.65788 .04317 L
.65796 .04368 L
.65801 .0439 L
.65805 .04405 L
.65809 .04419 L
.65814 .04426 L
.65821 .04428 L
.65829 .04417 L
.65837 .04389 L
.65841 .0437 L
.65845 .04343 L
.6586 .04218 L
.65868 .04123 L
.65876 .04019 L
.65906 .03496 L
.65933 .02859 L
.65962 .0204 L
.65978 .01527 L
.65987 .01246 L
.65991 .0109 L
.65996 .00944 L
.66004 .00913 L
.66008 .01057 L
.66012 .01212 L
.66028 .0174 L
.66087 .03697 L
.66117 .04501 L
.66133 .04867 L
.66148 .05152 L
.66165 .0539 L
.66174 .05485 L
.66178 .05525 L
.66183 .05561 L
.66187 .05585 L
.66191 .05605 L
.66196 .0562 L
.662 .05629 L
.66204 .05631 L
.66208 .05629 L
.66215 .05611 L
Mistroke
.66222 .05577 L
.6623 .05521 L
.66238 .05441 L
.66245 .05347 L
.66259 .05131 L
.66273 .04833 L
.66306 .03911 L
.66336 .02804 L
.66365 .01557 L
.66373 .01171 L
.66381 .008 L
.66388 .01126 L
.66395 .01497 L
.6645 .04234 L
.66482 .05693 L
.66515 .06997 L
.66529 .07437 L
.66544 .07832 L
.66552 .0802 L
.6656 .08165 L
.66568 .08284 L
.66575 .08371 L
.66582 .08427 L
.66589 .08464 L
.66597 .08474 L
.66604 .08454 L
.66611 .08407 L
.66619 .08325 L
.66627 .08202 L
.66635 .08054 L
.66649 .07696 L
.66662 .07274 L
.6669 .05989 L
.66721 .04081 L
.66737 .02872 L
.66746 .02156 L
.66754 .01452 L
.66762 .00811 L
.6677 .0149 L
.66786 .03087 L
.66815 .06131 L
.66934 .19842 L
.66997 .2618 L
.67029 .28711 L
.67047 .29908 L
.67064 .30822 L
.67078 .31469 L
.67094 .32006 L
.67103 .32214 L
.67111 .32361 L
Mistroke
.67115 .32424 L
.67119 .32469 L
.67123 .32508 L
.67128 .3253 L
.67135 .32538 L
.67143 .32504 L
.67149 .32442 L
.67157 .32336 L
.67164 .32181 L
.67173 .31967 L
.67188 .31457 L
.67203 .30813 L
.67219 .29952 L
.67248 .27992 L
.67303 .23179 L
.67369 .16181 L
.67431 .09363 L
.67487 .03833 L
.67503 .02494 L
.67511 .01801 L
.67519 .01181 L
.67525 .00915 L
.67533 .01438 L
.67548 .02471 L
.67578 .0421 L
.67594 .04945 L
.67611 .05586 L
.67626 .06028 L
.67634 .06219 L
.67642 .06391 L
.6765 .0652 L
.67657 .06613 L
.67664 .0668 L
.67671 .06729 L
.67678 .06755 L
.67684 .06761 L
.67692 .06747 L
.67699 .06713 L
.67705 .06665 L
.67711 .06608 L
.67725 .06431 L
.67738 .06193 L
.67753 .05869 L
.67783 .05046 L
.67843 .02991 L
.67873 .01913 L
.67887 .01399 L
.67893 .0118 L
.679 .00948 L
.67908 .00903 L
Mistroke
.67915 .01145 L
.67932 .0165 L
.67966 .02575 L
.67981 .02914 L
.67997 .03218 L
.68011 .03434 L
.68026 .03621 L
.68034 .03699 L
.68041 .03759 L
.68048 .03805 L
.68056 .03841 L
.68063 .03863 L
.68069 .03874 L
.68076 .03877 L
.68083 .03869 L
.68091 .03848 L
.68095 .0383 L
.68099 .0381 L
.68115 .03707 L
.68129 .03575 L
.68144 .03399 L
.68202 .02458 L
.68255 .01412 L
.6827 .01106 L
.68277 .00959 L
.68284 .00827 L
.68291 .00898 L
.68299 .01042 L
.68315 .01334 L
.68344 .018 L
.6837 .02153 L
.68385 .02311 L
.68401 .02454 L
.68417 .02562 L
.68426 .02607 L
.68435 .02639 L
.68442 .0266 L
.6845 .02674 L
.68457 .02679 L
.68464 .02678 L
.68472 .0267 L
.68476 .02662 L
.6848 .02652 L
.68488 .02628 L
.68496 .02598 L
.68606 .01578 L
.68636 .01191 L
.68653 .00975 L
.68656 .00924 L
.68661 .0087 L
Mistroke
.68668 .00814 L
.68676 .00911 L
.68683 .00996 L
.68699 .01186 L
.68727 .01489 L
.68756 .01756 L
.68772 .0187 L
.68788 .0197 L
.68803 .02038 L
.6881 .02067 L
.68819 .02092 L
.68826 .0211 L
.68833 .02122 L
.6884 .02129 L
.68846 .02133 L
.68854 .02132 L
.68858 .0213 L
.68862 .02126 L
.68869 .02115 L
.68874 .02106 L
.68878 .02097 L
.68892 .02053 L
.68907 .0199 L
.68938 .01805 L
.68973 .01533 L
.69005 .01234 L
.6902 .01076 L
.69035 .00927 L
.69042 .00857 L
.69048 .00797 L
.69055 .00866 L
.69062 .00942 L
.69091 .01239 L
.69122 .01532 L
.69152 .0177 L
.69168 .0188 L
.69186 .01979 L
.69202 .0205 L
.69209 .02075 L
.69217 .02096 L
.69224 .02112 L
.69232 .02124 L
.69238 .0213 L
.69245 .02133 L
.69252 .02131 L
.69259 .02125 L
.69263 .0212 L
.69267 .02113 L
.69275 .02097 L
.69281 .02078 L
Mistroke
.69289 .02053 L
.69303 .01989 L
.69329 .01829 L
.69362 .01548 L
.69394 .01215 L
.69408 .01054 L
.69415 .00963 L
.69422 .00875 L
.69426 .00824 L
.69431 .00818 L
.69438 .00916 L
.69453 .01108 L
.6951 .01825 L
.69541 .02165 L
.6957 .02419 L
.69585 .02521 L
.69601 .02604 L
.6961 .02638 L
.69615 .02652 L
.69619 .02661 L
.69627 .02674 L
.69631 .02678 L
.69635 .0268 L
.69642 .02677 L
.6965 .02666 L
.69657 .02649 L
.69664 .02628 L
.69671 .02597 L
.69679 .02555 L
.69695 .02444 L
.69711 .02307 L
.69727 .02126 L
.69757 .01714 L
.69784 .0127 L
.69798 .01012 L
.69802 .00935 L
.69806 .00861 L
.69813 .00868 L
.69821 .01023 L
.6983 .01194 L
.69845 .01506 L
.69879 .02185 L
.69908 .02732 L
.69939 .03241 L
.69956 .03463 L
.69971 .03629 L
.69986 .03752 L
.69993 .03798 L
.69998 .0382 L
.70002 .03837 L
Mistroke
.70009 .03862 L
.70016 .03874 L
.70023 .03877 L
.70031 .03867 L
.70038 .03848 L
.70045 .03816 L
.70051 .03779 L
.70058 .03729 L
.70074 .03564 L
.70089 .03361 L
.70123 .0272 L
.70153 .01962 L
.70169 .01487 L
.70177 .01239 L
.70184 .01003 L
.70191 .00818 L
.70199 .01072 L
.70214 .01622 L
.70242 .02615 L
.70303 .04768 L
.70329 .05521 L
.70356 .06167 L
.70371 .06443 L
.70379 .06546 L
.70386 .06625 L
.70393 .06686 L
.704 .06733 L
.70407 .06756 L
.70414 .06761 L
.70421 .06744 L
.70428 .06706 L
.70432 .06676 L
.70436 .06636 L
.70444 .06546 L
.70458 .06296 L
.70471 .05978 L
.70485 .05547 L
.705 .04983 L
.70532 .03416 L
.70545 .0264 L
.70559 .01717 L
.70565 .01239 L
.70572 .00821 L
.70578 .01261 L
.70584 .01756 L
.70641 .06961 L
.70757 .19545 L
.70823 .26011 L
.70854 .28475 L
.70882 .30284 L
Mistroke
.70896 .3099 L
.70912 .31619 L
.70927 .32091 L
.70935 .32278 L
.70943 .32408 L
.70951 .32491 L
.70958 .32532 L
.70964 .32539 L
.70971 .32513 L
.70978 .32445 L
.70986 .32329 L
.70993 .32195 L
.71001 .32007 L
.71017 .31461 L
.71032 .30799 L
.71066 .28769 L
.71096 .26422 L
.71127 .23481 L
.71189 .16695 L
.71247 .09856 L
.71299 .04074 L
.71314 .02629 L
.71322 .01871 L
.71329 .01185 L
.71335 .00969 L
.71342 .01557 L
.71356 .02738 L
.71388 .04992 L
.71404 .05904 L
.71418 .06627 L
.71432 .07219 L
.71445 .07655 L
.71459 .08029 L
.71467 .08185 L
.71474 .08301 L
.71482 .08387 L
.71486 .08422 L
.7149 .08447 L
.71498 .08473 L
.71502 .08473 L
.71506 .08465 L
.71513 .0843 L
.71521 .08363 L
.71528 .08274 L
.71535 .08169 L
.7155 .07863 L
.71567 .07419 L
.716 .06229 L
.7166 .0348 L
.7169 .02004 L
Mistroke
.71697 .01635 L
.71704 .01291 L
.7171 .00986 L
.71717 .00927 L
.71725 .01301 L
.71732 .01637 L
.71748 .02354 L
.71783 .03686 L
.71812 .04578 L
.71827 .0493 L
.71843 .05235 L
.71858 .05443 L
.71866 .05527 L
.71874 .05582 L
.71881 .05614 L
.71889 .0563 L
.71897 .05627 L
.71904 .05606 L
.71911 .0557 L
.71918 .05517 L
.71931 .05383 L
.71945 .05185 L
.7196 .0491 L
.71991 .04165 L
.72025 .03169 L
.72055 .02192 L
.72071 .01638 L
.72086 .01118 L
.72093 .00866 L
.72101 .00989 L
.72105 .01139 L
.7211 .01281 L
.72118 .01543 L
.72147 .02447 L
.72182 .03336 L
.72199 .03684 L
.72214 .03945 L
.72229 .04143 L
.72242 .04282 L
.7225 .04339 L
.72257 .04379 L
.72264 .0441 L
.72268 .0442 L
.72272 .04427 L
.72276 .04429 L
.7228 .04428 L
.72288 .04414 L
.72292 .044 L
.72296 .04383 L
.72305 .04333 L
Mistroke
.72312 .04279 L
.7232 .04208 L
.72335 .04022 L
.72365 .03539 L
.72396 .02877 L
.72423 .02213 L
.72452 .0145 L
.7246 .01223 L
.72468 .0101 L
.72475 .00818 L
.72483 .00974 L
.72512 .01719 L
.72546 .02496 L
.72577 .03082 L
.72592 .03291 L
.72605 .03455 L
.72612 .0353 L
.7262 .03601 L
.72628 .03654 L
.72634 .03693 L
.72642 .03726 L
.72646 .03739 L
.7265 .03749 L
.72654 .03756 L
.72659 .03759 L
.72663 .03758 L
.72667 .03754 L
.72675 .03737 L
.72679 .03723 L
.72683 .03707 L
.7269 .03668 L
.72697 .03621 L
.72712 .03489 L
.72729 .03303 L
.72758 .02869 L
.72792 .02221 L
.72824 .01545 L
.72838 .01233 L
.72845 .01068 L
.72853 .00891 L
.7286 .00865 L
.72867 .01017 L
.7288 .01309 L
.7291 .01914 L
.72941 .0248 L
.72956 .02697 L
.72971 .02895 L
.72985 .03047 L
.72998 .03161 L
.7301 .03241 L
Mistroke
.73017 .03275 L
.73023 .03299 L
.7303 .03317 L
.73038 .03327 L
.73045 .03329 L
.73051 .03322 L
.73059 .03307 L
.73066 .03281 L
.73072 .03252 L
.73079 .03213 L
.73095 .03097 L
.73109 .02957 L
.73136 .0263 L
.73164 .02193 L
.73197 .0159 L
.73214 .01274 L
.73221 .01134 L
.73229 .00978 L
.73236 .00839 L
.73242 .00878 L
.73249 .01015 L
.73257 .0116 L
.73288 .01722 L
.73317 .02198 L
.73349 .02604 L
.73367 .02781 L
.73383 .02902 L
.73391 .02947 L
.734 .02984 L
.73404 .02998 L
.73408 .0301 L
.73415 .03024 L
.73423 .0303 L
.7343 .03028 L
.73437 .03017 L
.73445 .02998 L
.73452 .02973 L
.73458 .02943 L
.73473 .02855 L
.73487 .02738 L
.73503 .02577 L
.73536 .02164 L
.73567 .01684 L
.73583 .01427 L
.73597 .0118 L
.7361 .00955 L
.73617 .00829 L
.73624 .00873 L
.73631 .00997 L
.73639 .01131 L
Mistroke
.73653 .01368 L
.73684 .01863 L
.73718 .02297 L
.73747 .02574 L
.73755 .02632 L
.73763 .02686 L
.73771 .02727 L
.73778 .02759 L
.73786 .02783 L
.73789 .02793 L
.73794 .02801 L
.73798 .02807 L
.73802 .0281 L
.7381 .0281 L
.73817 .02802 L
.73824 .02789 L
.73831 .02767 L
.73839 .02735 L
.73857 .02634 L
.73874 .02503 L
.73906 .02174 L
.73965 .01352 L
.73979 .01129 L
.73987 .01004 L
.73994 .00885 L
.73998 .00818 L
.74003 .00842 L
.74007 .00909 L
.74011 .0097 L
.74027 .01215 L
.74085 .02015 L
.74102 .02198 L
.74118 .02344 L
.74132 .02453 L
.74147 .02543 L
.74154 .02572 L
.7416 .02598 L
.74168 .0262 L
.74175 .02635 L
.74182 .02642 L
.74188 .02644 L
.74194 .02641 L
.742 .02634 L
.74207 .02619 L
.74215 .02597 L
.74223 .02566 L
.7423 .0253 L
.74258 .02342 L
.74286 .02069 L
.74317 .01697 L
Mistroke
.74347 .01282 L
.74364 .01042 L
.74372 .00923 L
.7438 .00812 L
.74387 .00878 L
.74394 .00987 L
.7441 .01213 L
.74437 .01584 L
.74465 .01913 L
.74491 .02169 L
.74505 .02281 L
.74521 .0238 L
.74528 .02415 L
.74535 .02446 L
.74542 .02471 L
.74548 .02488 L
.74556 .02504 L
.7456 .02509 L
.74564 .02513 L
.74572 .02513 L
.74576 .02511 L
.7458 .02507 L
.74587 .02494 L
.74594 .02477 L
.74602 .02452 L
.74609 .02421 L
.74622 .02351 L
.74636 .02256 L
.74662 .02039 L
.74692 .01715 L
.74719 .01373 L
.74733 .01189 L
.74748 .00983 L
.74755 .00888 L
.74762 .00801 L
.74769 .00896 L
.74776 .00982 L
.74805 .01369 L
.74837 .01744 L
.74866 .02034 L
.74879 .02138 L
.74893 .02235 L
.74907 .02307 L
.74919 .02358 L
.74926 .02379 L
.74932 .02393 L
.7494 .02404 L
.74947 .0241 L
.74954 .0241 L
.74961 .02404 L
Mistroke
.74968 .02393 L
.74974 .02379 L
.74981 .02357 L
.74989 .02328 L
.75005 .0225 L
.7502 .0215 L
.75037 .02019 L
.75066 .01731 L
.75096 .01387 L
.75111 .01204 L
.75124 .01032 L
.75137 .00873 L
.75143 .00795 L
.7515 .00883 L
.75177 .01231 L
.75209 .01597 L
.75238 .01893 L
.75265 .02102 L
.7528 .02191 L
.75294 .02255 L
.75302 .02282 L
.75306 .02294 L
.75311 .02304 L
.75314 .02312 L
.75319 .02318 L
.75326 .02325 L
.75333 .02327 L
.75341 .02322 L
.75348 .02312 L
.75355 .02298 L
.75363 .02274 L
.75371 .02246 L
.75388 .02162 L
.75404 .02065 L
.7542 .0194 L
.75476 .01368 L
.75492 .01185 L
.75508 .00987 L
.75515 .00904 L
.75522 .00816 L
.7553 .00869 L
.75537 .00959 L
.75594 .01611 L
.7562 .01846 L
.75647 .0205 L
.75663 .02137 L
.75677 .02197 L
.75685 .02222 L
.75693 .02239 L
.75697 .02247 L
Mistroke
.75701 .02253 L
.75705 .02257 L
.75709 .02259 L
.75717 .02259 L
.75724 .02253 L
.75729 .02247 L
.75733 .0224 L
.75741 .02219 L
.75749 .02193 L
.75758 .02158 L
.75776 .02066 L
.75806 .01848 L
.75839 .01544 L
.75867 .01235 L
.75883 .01055 L
.75897 .00884 L
.75904 .00797 L
.75912 .00884 L
.75929 .0108 L
.75959 .01408 L
.75993 .0174 L
.7601 .01877 L
.76025 .01985 L
.76041 .02074 L
.76056 .02135 L
.76064 .02162 L
.76072 .02181 L
.76076 .0219 L
.7608 .02196 L
.76084 .02201 L
.76089 .02204 L
.76096 .02205 L
.76103 .02201 L
.7611 .02193 L
.76116 .02181 L
.76124 .02163 L
.76132 .02137 L
.76147 .02075 L
.76161 .01998 L
.76176 .01897 L
.76203 .01674 L
.76233 .01381 L
.7625 .01199 L
.76266 .01023 L
.76274 .00932 L
.76281 .00846 L
.76285 .00798 L
.7629 .00841 L
.76298 .00931 L
.76332 .01304 L
Mistroke
.76363 .01613 L
.76392 .01851 L
.76419 .0202 L
.76427 .02057 L
.76435 .02087 L
.76442 .02112 L
.76449 .0213 L
.76456 .02145 L
.76461 .02152 L
.76465 .02156 L
.76471 .02161 L
.76479 .02161 L
.76483 .02159 L
.76487 .02155 L
.76492 .02149 L
.76496 .02141 L
.76504 .02124 L
.76512 .021 L
.76528 .02034 L
.76546 .01937 L
.76578 .01701 L
.76609 .01414 L
.76638 .01108 L
.76652 .00954 L
.76659 .00878 L
.76666 .00806 L
.76673 .00863 L
.76677 .00906 L
.76681 .00952 L
.76695 .01105 L
.76757 .01707 L
.76774 .0183 L
.76792 .01942 L
.76808 .02024 L
.76816 .02055 L
.76824 .02079 L
.76831 .02098 L
.76838 .02111 L
.76845 .02121 L
.76853 .02127 L
.76861 .02126 L
.76865 .02124 L
.76869 .0212 L
.76876 .02109 L
.76884 .02093 L
.76898 .02048 L
.76914 .0198 L
.76942 .01811 L
.76971 .01579 L
.77002 .01276 L
Mistroke
.77016 .0113 L
.77032 .00968 L
.77039 .00892 L
.77046 .00812 L
.77052 .00844 L
.77059 .0092 L
.77111 .01449 L
.7714 .01699 L
.77156 .01815 L
.77171 .01909 L
.77185 .01981 L
.77192 .02012 L
.772 .0204 L
.77208 .02062 L
.77214 .02077 L
.77221 .02089 L
.77227 .02096 L
.77235 .021 L
.77239 .02101 L
.77243 .02099 L
.7725 .02093 L
.77255 .02087 L
.77259 .02081 L
.77266 .02065 L
.77273 .02043 L
.77288 .01991 L
.77304 .01909 L
.77321 .01801 L
.77353 .01555 L
.7738 .01298 L
.77409 .01001 L
.77416 .00923 L
.77424 .00839 L
.77429 .00796 L
.77433 .0084 L
.77441 .00925 L
.7747 .01227 L
.77497 .01487 L
.77527 .01728 L
.7754 .01821 L
.77554 .01905 L
.77567 .01965 L
.7758 .02017 L
.77588 .0204 L
.77595 .02058 L
.77602 .0207 L
.7761 .02078 L
.77616 .02081 L
.77623 .02081 L
.77629 .02076 L
Mistroke
.77637 .02067 L
.77644 .02053 L
.77652 .02032 L
.77669 .01973 L
.77684 .019 L
.77698 .01816 L
.77751 .01388 L
.77779 .01115 L
.77794 .00958 L
.77801 .0088 L
.77808 .00809 L
.77815 .00856 L
.77823 .00939 L
.7784 .01113 L
.7787 .01401 L
.77901 .01672 L
.77918 .01792 L
.77936 .01898 L
.77953 .01976 L
.77968 .02027 L
.77976 .02044 L
.7798 .02052 L
.77984 .02058 L
.77991 .02066 L
.77998 .02069 L
.78005 .02068 L
.78013 .02061 L
.7802 .02051 L
.78027 .02038 L
.78034 .02018 L
.78042 .01991 L
.78057 .01927 L
.78087 .01756 L
.78114 .01544 L
.78147 .01244 L
.78161 .01102 L
.78176 .00941 L
.78184 .00863 L
.78192 .00807 L
.78199 .00885 L
.78206 .00956 L
.78237 .01272 L
.78269 .01561 L
.78303 .01809 L
.78317 .01889 L
.78331 .01959 L
.7834 .01991 L
.78348 .02016 L
.78355 .02035 L
.78363 .02049 L
Mistroke
.78369 .02057 L
.78377 .02062 L
.78383 .02063 L
.78389 .0206 L
.78396 .02052 L
.78404 .02039 L
.78412 .02023 L
.78418 .02003 L
.78433 .01946 L
.78447 .01877 L
.78479 .01669 L
.7851 .0141 L
.78543 .01085 L
.78559 .00921 L
.78567 .00837 L
.78572 .00798 L
.78576 .00842 L
.78606 .01154 L
.78637 .01451 L
.78666 .01686 L
.78679 .01778 L
.78694 .01866 L
.78707 .01936 L
.7872 .01987 L
.78727 .0201 L
.78734 .0203 L
.78738 .02039 L
.78742 .02046 L
.7875 .02056 L
.78756 .02061 L
.78763 .02063 L
.78771 .02059 L
.78778 .02052 L
.78785 .0204 L
.78793 .02021 L
.78808 .01974 L
.78823 .01904 L
.7884 .01806 L
.789 .01326 L
.78928 .01051 L
.78935 .00973 L
.78943 .00889 L
.7895 .00818 L
.78958 .00848 L
.78965 .00922 L
.78971 .00989 L
.78986 .01137 L
.79012 .0139 L
.79041 .01641 L
.79072 .01853 L
Mistroke
.79084 .01922 L
.79098 .01981 L
.79106 .02009 L
.79113 .02029 L
.7912 .02046 L
.79127 .02058 L
.79135 .02066 L
.79142 .02069 L
.79146 .02069 L
.7915 .02067 L
.79158 .0206 L
.79165 .02048 L
.79173 .02031 L
.79187 .01988 L
.79203 .01918 L
.79218 .01835 L
.79252 .01589 L
.79282 .01318 L
.79298 .01161 L
.79315 .00988 L
.79322 .00914 L
.7933 .00833 L
.79334 .008 L
.79338 .00843 L
.79346 .00925 L
.79374 .0122 L
.79429 .01704 L
.79456 .01884 L
.79472 .01962 L
.79486 .02018 L
.79494 .02041 L
.79502 .0206 L
.79509 .02071 L
.79517 .02079 L
.79521 .02081 L
.79525 .02081 L
.79529 .0208 L
.79534 .02078 L
.79541 .02069 L
.79545 .02062 L
.79549 .02054 L
.79557 .02034 L
.79565 .02011 L
.79578 .01955 L
.79593 .01878 L
.79609 .01777 L
.79667 .01284 L
.79682 .01137 L
.79695 .00994 L
.79708 .00863 L
Mistroke
.79715 .00798 L
.79721 .00867 L
.79749 .01159 L
.79779 .01451 L
.79808 .01706 L
.79824 .0182 L
.79841 .01923 L
.79858 .02002 L
.79873 .02055 L
.7988 .02073 L
.79884 .02081 L
.79888 .02088 L
.79896 .02097 L
.79903 .021 L
.79907 .021 L
.79911 .02099 L
.79916 .02096 L
.79921 .0209 L
.79929 .02077 L
.79933 .02067 L
.79937 .02056 L
.79952 .02005 L
.79968 .01929 L
.8 .01722 L
.80029 .01473 L
.80061 .0116 L
.80078 .00982 L
.80087 .00887 L
.80091 .00834 L
.80096 .00802 L
.80104 .00884 L
.80112 .00973 L
.80126 .01128 L
.80155 .01416 L
.80187 .01704 L
.80217 .01914 L
.80232 .01993 L
.80247 .02058 L
.80255 .02083 L
.80263 .02102 L
.80267 .0211 L
.80271 .02117 L
.80276 .02122 L
.8028 .02125 L
.80287 .02127 L
.80295 .02124 L
.80302 .02116 L
.80309 .02105 L
.80317 .02086 L
.80325 .02061 L
Mistroke
.8034 .02 L
.80354 .01929 L
.80368 .01834 L
.80398 .01598 L
.80424 .01355 L
.80452 .01063 L
.8046 .00976 L
.80468 .00882 L
.80475 .00802 L
.8048 .00831 L
.80483 .00874 L
.80513 .01202 L
.80569 .01738 L
.80585 .01855 L
.80601 .0196 L
.80615 .02035 L
.8063 .02096 L
.80638 .02122 L
.80646 .0214 L
.80654 .02153 L
.80661 .02159 L
.80665 .02161 L
.8067 .02161 L
.80678 .02157 L
.80682 .02152 L
.80686 .02146 L
.80695 .02127 L
.80807 .01348 L
.80838 .01013 L
.80845 .00929 L
.80849 .00884 L
.80853 .00837 L
.80858 .00803 L
.80862 .00851 L
.8087 .00946 L
.80929 .01574 L
.80958 .01832 L
.80975 .0195 L
.8099 .02042 L
.80999 .02086 L
.81008 .02126 L
.81016 .02153 L
.81024 .02177 L
.81028 .02185 L
.81033 .02192 L
.81037 .02198 L
.81041 .02202 L
.81045 .02205 L
.81049 .02205 L
.81057 .02202 L
Mistroke
.81064 .02194 L
.81071 .02182 L
.81079 .02162 L
.81087 .02137 L
.811 .02082 L
.81114 .02003 L
.81147 .01763 L
.81178 .01477 L
.81206 .0117 L
.81221 .0099 L
.81229 .009 L
.81236 .00816 L
.81243 .0085 L
.8125 .00934 L
.81265 .01109 L
.81291 .01403 L
.81319 .01693 L
.8135 .01953 L
.81368 .02069 L
.81384 .02153 L
.81399 .02212 L
.81407 .02232 L
.81411 .02241 L
.81415 .02248 L
.81423 .02257 L
.8143 .0226 L
.81438 .02256 L
.81443 .02252 L
.81447 .02245 L
.81455 .0223 L
.81462 .02211 L
.81477 .02151 L
.81491 .02079 L
.81506 .01982 L
.81533 .01758 L
.81565 .01436 L
.81582 .01239 L
.81599 .01044 L
.81606 .00953 L
.81614 .00857 L
.81618 .00806 L
.81623 .00837 L
.8163 .00935 L
.81659 .01284 L
.81691 .01637 L
.81721 .01922 L
.81748 .02122 L
.81763 .02206 L
.81777 .02266 L
.81784 .02288 L
Mistroke
.81792 .02307 L
.81799 .02319 L
.81806 .02325 L
.81814 .02327 L
.81818 .02324 L
.81822 .02321 L
.8183 .02309 L
.81834 .023 L
.81838 .0229 L
.81854 .02233 L
.81863 .02189 L
.81871 .02142 L
.81903 .01908 L
.81957 .01332 L
.81973 .01138 L
.81988 .00948 L
.81995 .00865 L
.82001 .00812 L
.82009 .0091 L
.82016 .01001 L
.82046 .01386 L
.8208 .01771 L
.82109 .02042 L
.82125 .02167 L
.8214 .02262 L
.82155 .02331 L
.82162 .02361 L
.8217 .02382 L
.82177 .02398 L
.82182 .02404 L
.82186 .02408 L
.82193 .0241 L
.82201 .02407 L
.82207 .02398 L
.82215 .02384 L
.82221 .02366 L
.82227 .02344 L
.82242 .02276 L
.82257 .0219 L
.82288 .01935 L
.82317 .01629 L
.82348 .01239 L
.82364 .01019 L
.82374 .00896 L
.82378 .00835 L
.82382 .00807 L
.8239 .00912 L
.82398 .01024 L
.82415 .01259 L
.82446 .01649 L
Mistroke
.82474 .01971 L
.82489 .02116 L
.82506 .02249 L
.8252 .02346 L
.82527 .02389 L
.82535 .02428 L
.82543 .02458 L
.8255 .0248 L
.82556 .02495 L
.82563 .02507 L
.8257 .02513 L
.82577 .02514 L
.82583 .02509 L
.82589 .02501 L
.82596 .02485 L
.82604 .02463 L
.82618 .02404 L
.82632 .02322 L
.82647 .02209 L
.82675 .0195 L
.82705 .01597 L
.82737 .01152 L
.82746 .01029 L
.82755 .00897 L
.82763 .00804 L
.82767 .00869 L
.82771 .0093 L
.82803 .01396 L
.82832 .01783 L
.82864 .02147 L
.82879 .02289 L
.82894 .02417 L
.82909 .02513 L
.82923 .02578 L
.82931 .02606 L
.82938 .02626 L
.82942 .02633 L
.82946 .02639 L
.82951 .02643 L
.82955 .02644 L
.82962 .02641 L
.82969 .02632 L
.82973 .02625 L
.82977 .02614 L
.82985 .02589 L
.82993 .02558 L
.83 .02522 L
.83013 .02439 L
.83043 .0218 L
.83068 .01886 L
Mistroke
.83096 .01509 L
.83124 .01094 L
.83132 .00969 L
.83139 .0085 L
.83146 .00845 L
.83153 .00962 L
.83186 .0147 L
.83216 .01908 L
.83248 .02301 L
.83266 .02476 L
.83282 .02609 L
.83296 .02698 L
.83303 .02734 L
.83311 .02765 L
.83319 .02789 L
.83323 .02799 L
.83328 .02805 L
.83335 .02811 L
.83343 .02809 L
.8335 .02799 L
.83355 .0279 L
.83358 .0278 L
.83366 .02752 L
.83375 .02713 L
.8339 .02617 L
.83404 .02503 L
.83439 .0213 L
.83471 .0167 L
.83499 .01215 L
.83507 .01077 L
.83515 .00946 L
.83522 .00827 L
.83529 .00889 L
.83533 .00959 L
.83538 .01035 L
.83546 .01188 L
.83562 .01458 L
.83593 .01952 L
.83624 .02397 L
.8364 .0258 L
.83654 .02725 L
.83667 .02831 L
.83681 .02924 L
.83688 .02961 L
.83695 .02989 L
.83702 .0301 L
.8371 .03025 L
.83718 .0303 L
.83725 .03027 L
.8373 .03021 L
Mistroke
.83733 .03014 L
.83738 .03002 L
.83742 .02988 L
.83751 .02953 L
.83758 .02911 L
.83776 .02784 L
.8379 .02652 L
.83805 .02477 L
.83836 .0204 L
.83867 .01504 L
.83883 .01215 L
.8389 .01085 L
.83897 .0094 L
.83904 .00809 L
.8391 .00901 L
.83924 .01172 L
.83953 .01731 L
.83983 .02252 L
.84014 .02718 L
.8403 .02918 L
.84048 .03095 L
.84056 .03158 L
.84064 .03215 L
.84072 .03258 L
.84079 .03289 L
.84086 .03312 L
.8409 .0332 L
.84094 .03326 L
.84099 .03329 L
.84103 .03329 L
.84111 .0332 L
.84118 .03302 L
.84125 .03277 L
.84133 .03241 L
.8414 .03192 L
.84158 .03042 L
.84175 .02853 L
.84207 .02387 L
.84236 .01868 L
.84265 .01244 L
.84273 .01078 L
.84281 .00898 L
.84286 .00794 L
.8429 .00889 L
.84298 .01076 L
.84328 .0175 L
.84384 .02854 L
.84412 .03279 L
.84428 .03467 L
.84443 .03603 L
Mistroke
.84451 .03658 L
.8446 .03704 L
.84467 .03732 L
.84475 .03751 L
.84479 .03757 L
.84483 .03759 L
.84488 .03757 L
.84492 .03751 L
.845 .0373 L
.84504 .03714 L
.84508 .03695 L
.84522 .03605 L
.8453 .03536 L
.84537 .03461 L
.84568 .03039 L
.84598 .02474 L
.84631 .01723 L
.84646 .01345 L
.84654 .01131 L
.84662 .00926 L
.84669 .00854 L
.84677 .01064 L
.8469 .01432 L
.84748 .02908 L
.84776 .03507 L
.84802 .03942 L
.84816 .04129 L
.8483 .04267 L
.84837 .04325 L
.84844 .04368 L
.84851 .04402 L
.84859 .04423 L
.84867 .04429 L
.84871 .04427 L
.84875 .04421 L
.84882 .04398 L
.84889 .04364 L
.84897 .0431 L
.84905 .04244 L
.84922 .04042 L
.84939 .03782 L
.84954 .03479 L
.84983 .0278 L
.85015 .01874 L
.85031 .01344 L
.8504 .01041 L
.85045 .0089 L
.85049 .00838 L
.85057 .01098 L
.85065 .01382 L
Mistroke
.85079 .01882 L
.85108 .0284 L
.85137 .03762 L
.8517 .04622 L
.85183 .04912 L
.85197 .05175 L
.85211 .05372 L
.85223 .05506 L
.8523 .0556 L
.85237 .05597 L
.85244 .05622 L
.85251 .05631 L
.85259 .05621 L
.85267 .05593 L
.85273 .05551 L
.85281 .05489 L
.85288 .05408 L
.85295 .05317 L
.8531 .05058 L
.85338 .04398 L
.8537 .03344 L
.854 .02102 L
.85415 .01415 L
.8542 .0121 L
.85424 .01015 L
.85432 .00942 L
.85439 .01298 L
.85446 .01629 L
.85461 .02384 L
.85527 .05568 L
.85555 .06716 L
.85571 .07251 L
.85585 .0768 L
.85599 .08004 L
.85606 .08143 L
.85614 .08265 L
.85621 .08347 L
.85628 .08414 L
.85634 .08454 L
.8564 .08472 L
.85647 .08469 L
.85655 .08434 L
.85659 .08403 L
.85664 .08361 L
.85671 .08259 L
.85679 .08124 L
.85686 .07965 L
.857 .07588 L
.85716 .07004 L
.85731 .06334 L
Mistroke
.85765 .04363 L
.85793 .02241 L
.85801 .01557 L
.85809 .0088 L
.85815 .01337 L
.85823 .02045 L
.85878 .07781 L
.85937 .14647 L
.86002 .22023 L
.86031 .24972 L
.86063 .27724 L
.8609 .29663 L
.86105 .30502 L
.86121 .31247 L
.86129 .31593 L
.86137 .31861 L
.86145 .32089 L
.86153 .32258 L
.86161 .32401 L
.86165 .32456 L
.8617 .325 L
.86178 .32537 L
.86182 .32539 L
.86186 .32527 L
.86194 .32472 L
.86202 .32379 L
.86208 .32262 L
.86216 .32099 L
.86232 .316 L
.86247 .30978 L
.86277 .29275 L
.8631 .26834 L
.8637 .21196 L
.86482 .09019 L
.86539 .03423 L
.86555 .02081 L
.86564 .01384 L
.86568 .01053 L
.86572 .00834 L
.8658 .01393 L
.86588 .01972 L
.86602 .02909 L
.86634 .04609 L
.86664 .05751 L
.86679 .06159 L
.86695 .06478 L
.86703 .066 L
.86708 .06651 L
.86713 .0669 L
.8672 .06738 L
Mistroke
.86725 .06753 L
.86729 .06761 L
.86736 .06755 L
.86741 .06742 L
.86745 .06723 L
.86753 .06668 L
.86757 .06626 L
.86761 .06581 L
.86776 .06366 L
.86791 .06093 L
.86823 .05289 L
.86857 .04181 L
.86888 .03098 L
.8692 .01916 L
.86936 .01353 L
.86944 .01084 L
.86951 .00842 L
.86957 .00961 L
.86964 .01184 L
.86979 .01631 L
.87008 .02441 L
.87036 .03055 L
.87051 .03324 L
.87068 .03556 L
.87075 .03639 L
.87083 .03713 L
.8709 .0377 L
.87097 .03811 L
.87104 .03842 L
.8711 .03863 L
.87117 .03875 L
.87124 .03877 L
.87131 .03869 L
.87137 .03852 L
.87144 .03827 L
.8715 .03797 L
.87164 .03697 L
.87179 .03548 L
.87207 .03184 L
.87265 .02174 L
.87297 .01514 L
.87312 .01223 L
.87319 .01072 L
.87327 .00912 L
.87331 .00834 L
.87336 .00839 L
.87343 .00987 L
.87359 .01269 L
.87393 .0182 L
.87424 .02224 L
Mistroke
.8744 .02377 L
.87454 .02492 L
.87468 .02576 L
.87475 .02612 L
.87482 .02638 L
.8749 .0266 L
.87494 .02668 L
.87498 .02674 L
.87505 .02679 L
.87513 .02677 L
.8752 .02668 L
.87528 .02651 L
.87536 .02628 L
.87543 .02601 L
.87559 .02513 L
.87575 .02403 L
.87628 .0188 L
.87686 .01152 L
.87702 .00953 L
.87706 .00898 L
.87711 .00841 L
.87714 .00794 L
.87718 .00847 L
.87749 .0121 L
.87778 .01525 L
.87805 .01763 L
.8782 .01873 L
.87836 .01972 L
.87845 .02016 L
.87854 .02051 L
.87862 .0208 L
.8787 .02102 L
.87877 .02116 L
.87884 .02126 L
.87888 .0213 L
.87892 .02132 L
.879 .02133 L
.87908 .02128 L
.87915 .02119 L
.87923 .02104 L
.87931 .02082 L
.87946 .0203 L
.87961 .01957 L
.87989 .01782 L
.88019 .01548 L
.88051 .01247 L
.88069 .01064 L
.88078 .00972 L
.88086 .00886 L
.88094 .00808 L
Mistroke
.88098 .00823 L
.88102 .00862 L
.88119 .01037 L
.88151 .0136 L
.88181 .01626 L
.88209 .01839 L
.88224 .01931 L
.88241 .02012 L
.88249 .02047 L
.88257 .02074 L
.88265 .02096 L
.88272 .02112 L
.88276 .02119 L
.8828 .02125 L
.88284 .02129 L
.88289 .02132 L
.88293 .02133 L
.88297 .02133 L
.88305 .02128 L
.88313 .02117 L
.8832 .02103 L
.88328 .02082 L
.88336 .02053 L
.88352 .01984 L
.88366 .01903 L
.88395 .01689 L
.88422 .01432 L
.88452 .01092 L
.8846 .01001 L
.88467 .00912 L
.88473 .00831 L
.8848 .00846 L
.88488 .00941 L
.88495 .0103 L
.8851 .01229 L
.88542 .01643 L
.88596 .0224 L
.88623 .02463 L
.88639 .02558 L
.88653 .02624 L
.88661 .02647 L
.88668 .02665 L
.88675 .02675 L
.88682 .02679 L
.88689 .02677 L
.88694 .02673 L
.88698 .02666 L
.88705 .02649 L
.88713 .02623 L
.8872 .02591 L
Mistroke
.88728 .02548 L
.88742 .02449 L
.88759 .02297 L
.88775 .02125 L
.88802 .01754 L
.88832 .01263 L
.88846 .01014 L
.88853 .0087 L
.8886 .0085 L
.88867 .00977 L
.88874 .01116 L
.88886 .01371 L
.88948 .02601 L
.88979 .03117 L
.89006 .03494 L
.89021 .03651 L
.89036 .03764 L
.89043 .0381 L
.8905 .03842 L
.89058 .03866 L
.89062 .03873 L
.89067 .03877 L
.89071 .03877 L
.89075 .03872 L
.89083 .03854 L
.89088 .03838 L
.89092 .0382 L
.89101 .03763 L
.89109 .03698 L
.89117 .03625 L
.89133 .03418 L
.89162 .02901 L
.89193 .02161 L
.8922 .01381 L
.89228 .01136 L
.89235 .00897 L
.89242 .0091 L
.89249 .01155 L
.8928 .02256 L
.89308 .03307 L
.89342 .04486 L
.89374 .05457 L
.89401 .06117 L
.89416 .06399 L
.8943 .06591 L
.89438 .06666 L
.89445 .06717 L
.89452 .06751 L
.89457 .0676 L
.89461 .06761 L
Mistroke
.89469 .06744 L
.89473 .06723 L
.89477 .06696 L
.89485 .06627 L
.89493 .06525 L
.89508 .06255 L
.89524 .05844 L
.89539 .05339 L
.89553 .04777 L
.89587 .03001 L
.89603 .01928 L
.89611 .01354 L
.89619 .00801 L
.89626 .01332 L
.89634 .01932 L
.89649 .03267 L
.89677 .05815 L
.89738 .12254 L
.89849 .24055 L
.89906 .28792 L
.89922 .29849 L
.89938 .30701 L
.89952 .31342 L
.89967 .31878 L
.8998 .32217 L
.89987 .32357 L
.89994 .32453 L
.90001 .32509 L
.90007 .32536 L
.90013 .32536 L
.9002 .32504 L
.90027 .32438 L
.90034 .32329 L
.90041 .32191 L
.90047 .32036 L
.90063 .31536 L
.90077 .30914 L
.90105 .29331 L
.90136 .27048 L
.90198 .2105 L
.90309 .08245 L
.9034 .048 L
.90356 .03209 L
.90363 .02465 L
.9037 .01811 L
.90377 .01188 L
.90383 .00968 L
.9039 .01549 L
.90397 .02154 L
.90426 .04356 L
Mistroke
.90458 .06248 L
.90474 .06982 L
.90491 .07618 L
.90506 .0802 L
.90515 .08189 L
.90522 .08308 L
.9053 .0839 L
.90537 .08448 L
.90545 .08472 L
.90552 .0847 L
.90559 .0844 L
.90566 .08386 L
.90573 .08316 L
.9058 .08219 L
.90595 .07921 L
.9061 .07554 L
.90636 .06693 L
.90664 .0555 L
.90698 .03985 L
.90729 .02413 L
.90743 .01725 L
.9075 .01353 L
.90757 .01009 L
.90765 .00945 L
.90769 .01137 L
.90773 .0134 L
.90788 .02009 L
.90818 .03232 L
.90849 .04295 L
.90866 .04736 L
.90884 .05123 L
.90892 .05259 L
.909 .05382 L
.90908 .05475 L
.90916 .05542 L
.90923 .05589 L
.9093 .05619 L
.90935 .05629 L
.90939 .05631 L
.90947 .05622 L
.9095 .0561 L
.90955 .05592 L
.90962 .05546 L
.9097 .05477 L
.90979 .05379 L
.90993 .0517 L
.91009 .04885 L
.91037 .04225 L
.91098 .02344 L
.91114 .01773 L
Mistroke
.91124 .01457 L
.91132 .0116 L
.91136 .01025 L
.9114 .00884 L
.91145 .00858 L
.91149 .00999 L
.91164 .01501 L
.91222 .03154 L
.91238 .03508 L
.91254 .03828 L
.91269 .04051 L
.91277 .04155 L
.91285 .04238 L
.91293 .04309 L
.913 .04359 L
.91308 .04398 L
.91312 .04412 L
.91317 .04423 L
.91324 .04429 L
.91331 .04424 L
.91338 .04405 L
.91346 .0437 L
.91351 .04344 L
.91355 .04315 L
.91364 .04236 L
.91381 .04045 L
.91397 .03819 L
.91413 .03533 L
.91471 .02197 L
.91487 .01792 L
.91503 .01342 L
.91511 .01134 L
.91515 .01021 L
.91519 .00914 L
.91526 .00861 L
.91534 .01065 L
.91564 .01822 L
.91596 .02544 L
.91623 .03042 L
.91638 .03272 L
.91652 .03448 L
.91665 .0358 L
.91672 .03634 L
.9168 .03682 L
.91688 .0372 L
.91695 .03744 L
.91703 .03756 L
.91709 .03758 L
.91716 .03752 L
.91722 .03739 L
Mistroke
.91728 .03717 L
.91735 .03683 L
.91742 .03639 L
.91749 .03588 L
.91762 .03468 L
.91792 .03079 L
.9182 .02615 L
.91849 .02025 L
.91865 .01689 L
.91881 .01323 L
.91895 .01004 L
.91899 .00917 L
.91903 .00823 L
.91911 .00932 L
.91918 .01095 L
.91925 .01247 L
.91938 .01527 L
.91992 .02527 L
.92019 .02907 L
.92035 .03073 L
.9205 .03192 L
.92058 .03239 L
.92065 .03278 L
.92072 .03302 L
.9208 .0332 L
.92084 .03326 L
.92088 .03329 L
.92092 .03329 L
.92096 .03326 L
.92104 .03313 L
.92108 .03302 L
.92112 .03289 L
.92118 .03262 L
.92125 .03225 L
.92137 .0314 L
.92152 .03009 L
.92165 .02861 L
.92222 .02001 L
.92251 .01467 L
.92267 .0116 L
.92275 .01009 L
.92282 .00869 L
.92289 .0085 L
.92296 .00989 L
.92311 .01276 L
.92337 .0175 L
.92366 .0221 L
.92396 .02606 L
.92414 .02779 L
.9243 .02899 L
Mistroke
.92438 .02943 L
.92446 .02981 L
.92454 .03007 L
.92462 .03023 L
.92469 .0303 L
.92476 .03029 L
.92483 .03022 L
.9249 .03007 L
.92497 .02982 L
.92505 .02947 L
.9252 .0286 L
.92534 .02743 L
.92548 .02607 L
.92574 .02295 L
.92634 .01367 L
.9265 .01085 L
.92659 .00929 L
.92663 .00852 L
.92667 .00804 L
.92674 .00928 L
.92682 .0106 L
.92698 .01333 L
.92754 .02156 L
.92782 .02465 L
.92798 .026 L
.92813 .02698 L
.92821 .02738 L
.92829 .0277 L
.92836 .02791 L
.92844 .02805 L
.92848 .02809 L
.92852 .02811 L
.92857 .0281 L
.92861 .02807 L
.92869 .02794 L
.92874 .02784 L
.92878 .02772 L
.92892 .02713 L
.92899 .02669 L
.92907 .02621 L
.92938 .02351 L
.93 .01537 L
.93015 .01308 L
.93031 .01058 L
.93039 .00935 L
.93046 .00819 L
.93053 .00872 L
.9306 .00983 L
.93113 .01768 L
.93143 .0213 L
Mistroke
.93158 .02276 L
.93171 .0239 L
.93184 .02484 L
.93199 .02561 L
.93207 .02593 L
.93214 .02616 L
.93221 .02632 L
.93228 .02641 L
.93236 .02644 L
.9324 .02643 L
.93244 .0264 L
.93251 .02629 L
.93258 .02611 L
.93266 .02583 L
.93274 .02551 L
.93291 .02452 L
.93308 .02326 L
.93323 .02182 L
.93352 .01856 L
.93384 .01445 L
.934 .01211 L
.93409 .01078 L
.93418 .00952 L
.93425 .0084 L
.9343 .0081 L
.93434 .00868 L
.93448 .01078 L
.93476 .01472 L
.93509 .01873 L
.93538 .02166 L
.93552 .02272 L
.93566 .02367 L
.9358 .02435 L
.93586 .02459 L
.93592 .02479 L
.93599 .02496 L
.93605 .02507 L
.93613 .02513 L
.9362 .02513 L
.93627 .02507 L
.93635 .02494 L
.93642 .02475 L
.93649 .02451 L
.93664 .02385 L
.9368 .02288 L
.93708 .0205 L
.93741 .01692 L
.93772 .0131 L
.93786 .01112 L
.938 .00921 L
Mistroke
.93808 .00815 L
.93812 .00832 L
.93816 .00887 L
.93831 .01084 L
.93886 .01764 L
.93911 .02014 L
.93939 .02221 L
.93954 .02307 L
.93969 .02364 L
.93976 .02383 L
.93983 .02398 L
.9399 .02407 L
.93997 .0241 L
.94003 .02409 L
.94011 .02401 L
.94017 .02389 L
.94024 .02374 L
.9403 .02352 L
.94038 .02322 L
.94053 .02245 L
.94068 .02146 L
.94085 .02018 L
.94114 .01736 L
.94143 .01392 L
.94175 .00993 L
.94183 .00889 L
.94187 .00832 L
.94192 .00809 L
.94197 .00873 L
.94201 .00931 L
.9421 .01043 L
.94242 .01436 L
.9427 .01742 L
.943 .02009 L
.94317 .0213 L
.94333 .02216 L
.9434 .02249 L
.94348 .02278 L
.94356 .02299 L
.94363 .02314 L
.94371 .02323 L
.94378 .02327 L
.94384 .02325 L
.94391 .02319 L
.94399 .02306 L
.94403 .02297 L
.94407 .02286 L
.94422 .02233 L
.94435 .02165 L
.9445 .02073 L
Mistroke
.94477 .01862 L
.94536 .01227 L
.94552 .0103 L
.94561 .0092 L
.94566 .00866 L
.9457 .00816 L
.94577 .00868 L
.94582 .00919 L
.94586 .00973 L
.94601 .01153 L
.94631 .01495 L
.94663 .01812 L
.94679 .0194 L
.94694 .02044 L
.94707 .02121 L
.94722 .02185 L
.94729 .0221 L
.94737 .02232 L
.94744 .02246 L
.94751 .02255 L
.94758 .02259 L
.94766 .02258 L
.9477 .02255 L
.94774 .02251 L
.94778 .02244 L
.94782 .02236 L
.94791 .02214 L
.94799 .02186 L
.94814 .02118 L
.94831 .02021 L
.94849 .0189 L
.94878 .01624 L
.9491 .01285 L
.94926 .01108 L
.9494 .00936 L
.94947 .0086 L
.94954 .00808 L
.94961 .00896 L
.94968 .00978 L
.95028 .01629 L
.95046 .01788 L
.95063 .01918 L
.95079 .02023 L
.95094 .021 L
.95108 .02152 L
.95116 .02173 L
.95123 .02188 L
.9513 .02199 L
.95134 .02203 L
.95138 .02205 L
Mistroke
.95146 .02204 L
.95153 .02199 L
.95161 .02188 L
.95168 .02171 L
.95176 .02149 L
.95183 .02125 L
.95199 .02052 L
.95215 .01953 L
.95268 .01506 L
.95296 .01213 L
.95311 .01049 L
.95326 .00872 L
.95334 .00805 L
.95339 .00856 L
.95343 .00904 L
.95358 .01076 L
.95388 .01399 L
.95417 .01672 L
.95444 .01885 L
.9546 .0198 L
.95476 .02062 L
.95484 .02091 L
.95491 .02116 L
.95499 .02135 L
.95505 .02147 L
.95509 .02153 L
.95514 .02158 L
.95521 .02161 L
.95526 .02161 L
.9553 .02159 L
.95534 .02155 L
.95539 .02149 L
.95543 .02143 L
.95547 .02133 L
.95555 .02112 L
.9557 .02057 L
.95585 .01988 L
.956 .01896 L
.95627 .01687 L
.95657 .01409 L
.9569 .01066 L
.95698 .00972 L
.95703 .00921 L
.95707 .00872 L
.95711 .00826 L
.95716 .00811 L
.95724 .00897 L
.95756 .01245 L
.95787 .01552 L
.95816 .01792 L
Mistroke
.95844 .01966 L
.95859 .02037 L
.95873 .02085 L
.95881 .02104 L
.95889 .02117 L
.95893 .02121 L
.95897 .02125 L
.95901 .02127 L
.95906 .02127 L
.95913 .02123 L
.9592 .02115 L
.95928 .02101 L
.95936 .02081 L
.95951 .02027 L
.95967 .01949 L
.95997 .01758 L
.96031 .01463 L
.96063 .01144 L
.96078 .00979 L
.96086 .00897 L
.96093 .00822 L
.961 .00844 L
.96108 .00929 L
.96124 .01106 L
.96156 .01427 L
.96191 .01726 L
.96207 .01836 L
.96223 .01934 L
.96239 .02007 L
.96253 .02056 L
.96261 .02075 L
.96268 .02087 L
.96275 .02097 L
.96279 .02099 L
.96284 .02101 L
.96291 .02099 L
.96298 .02093 L
.96306 .02082 L
.96312 .02068 L
.96327 .02023 L
.96336 .01989 L
.96343 .01953 L
.96373 .01775 L
.96403 .0153 L
.96437 .01208 L
.9645 .01074 L
.96464 .00927 L
.96468 .00884 L
.96472 .00842 L
.96479 .00822 L
Mistroke
.96486 .00895 L
.96493 .00973 L
.96521 .01262 L
.96552 .01551 L
.9658 .01771 L
.96596 .0187 L
.9661 .01948 L
.96618 .01983 L
.96627 .02015 L
.96635 .02039 L
.96642 .02057 L
.9665 .0207 L
.96654 .02075 L
.96658 .02078 L
.96665 .02081 L
.96672 .0208 L
.96679 .02074 L
.96686 .02065 L
.96693 .02051 L
.967 .02031 L
.96716 .01976 L
.9673 .01908 L
.96757 .01737 L
.96783 .01532 L
.96813 .01251 L
.96841 .00962 L
.96848 .00886 L
.96855 .00813 L
.96859 .00814 L
.96863 .00858 L
.96871 .00935 L
.96903 .01265 L
.96931 .01523 L
.9696 .01755 L
.96975 .01848 L
.96988 .01922 L
.97001 .01976 L
.97014 .02021 L
.97021 .0204 L
.97028 .02053 L
.97035 .02063 L
.97042 .02068 L
.9705 .02069 L
.97057 .02065 L
.97064 .02056 L
.97068 .0205 L
.97073 .02041 L
.97088 .01998 L
.97097 .01965 L
.97105 .0193 L
Mistroke
.97135 .01753 L
.97188 .01301 L
.97203 .01162 L
.97218 .01005 L
.97225 .00932 L
.97232 .00854 L
.97239 .008 L
.97246 .00874 L
.97277 .01191 L
.97305 .01457 L
.97333 .01692 L
.9736 .01863 L
.97375 .01944 L
.97391 .02001 L
.97399 .02025 L
.97407 .02042 L
.97411 .0205 L
.97415 .02055 L
.9742 .02059 L
.97424 .02062 L
.97431 .02062 L
.97439 .02058 L
.97446 .0205 L
.97453 .02037 L
.97461 .02018 L
.97469 .01993 L
.97484 .01932 L
.97501 .01841 L
.97517 .01737 L
.97553 .01447 L
.97619 .00794 L
Mfstroke
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00E?ooool5o`0000?ooooo0_l0001=ooooo`?o00001?ooool2o`0004oooooo0_l0001@oooo
o`?o00001?ooool2o`0004gooooo1Ol00003ooooo`;o0000@oooool005Gooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0001=ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000COooool01?l0003oooooooooool0001@ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000COooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0004;ooooo001>ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0004Gooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000COoo
ool01?l0003oooooooooool0001@ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000C_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0004;ooooo001Gooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000COooool01?l0003oooooooooool0001@ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000Coooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool0@?ooool005Cooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0004gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001=
ooooo`04o`000?ooooooooooo`00053ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0001<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00012oooo
o`00E?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000C?ooool2
o`0000Cooooo00Co0000oooooooooooo0000COooool01?l0003oooooooooool0001?ooooo`;o0000
1?ooool01?l0003oooooooooool0001<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00012ooooo`00EOooool3o`0000Cooooo0_l0001>ooooo`03o`000?oooooooooo
00?ooooo0_l0001?ooooo`;o0000DOooool00ol0003oooooooooo`03ooooo`;o0000C_ooool3o`00
00Cooooo0_l00013ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`008?ooooooo`000<Wo00004?oo
ool001Oooooo0_l00007ooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooo`00000@ooooo`005_ooool01?l0003oooooooooool00006ooooo`04o`000?oo
ooooooooo`00013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooo`00000@ooooo`005_oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo000Fooooo`04o`000?oo
ooooooooo`0000Kooooo1?l00007ooooo`04ool00?ooooooo`00ooooo`;oo`0000Goooooool00?oo
ooooo`00ooooo`02ool00005oooooooo003oooooool00?ooool00_oo00000oooooooo`00ooooo`04
ool00003oooooooo003ooooo00;oo`001_ooool01?oo003oooooool00?ooool4ool00003oooooooo
003ooooo00;oo`001Oooool2ool00005oooooooo003oooooool00?ooool00_oo00000oooooooo`00
ooooo`04ool00003oooooooo003ooooo00;oo`0000Goooooool00?ooooooo`00ooooo`02ool00006
oooooooo003oooooool00?ooooooo`000_ooool00ooo003oooooool00003ool00003oooooooo003o
oooo00;oo`0000Goooooool00?ooooooo`00ooooo`02ool00005oooooooo003oooooool00?ooool0
0_oo00000oooooooo`00ooooo`03ooooo`04ool00?ooooooo`00ooooo`;oo`0000Goooooool00?oo
ooooo`00ooooo`02ool00003oooooooo003ooooo00?ooooo00Coo`00oooooooo003ooooo0_oo0000
1Oooooooo`00oooooooo003ooooo00;oo`0000Goooooool00?ooooooo`00ooooo`02ool00005oooo
oooo003oooooool00?ooool00_oo00000oooooooo`00ooooo`04ool00003oooooooo003ooooo00;o
o`0000Goooooool00?ooooooo`00ooooo`02ool00003oooooooo003ooooo00Coo`0000?oooooool0
0?ooool00_oo00001_ooooooo`00oooooooo003oooooool000Cooooo00Ooo`00oooooooo003oo`00
oooooooo003ooooo00Coo`0000Coooooool00?ooooooo`000_ooool01?oo003oooooool00?ooool2
ool00005oooooooo003oooooool00?ooool00_oo00000oooooooo`00ooooo`04ool00003oooooooo
003ooooo00;oo`0000Goooooool00?ooooooo`00ooooo`04ool00003oooooooo003oo`0000;oo`00
00?oooooool00?ooool01?oo00000oooooooo`00ooooo`02ool00005oooooooo003oooooool00?oo
ool00_oo00001Oooooooo`00oooooooo003ooooo00;oo`0000[oooooool00?ooooooooooool00?oo
ooooo`00oooooooo003ooooo0_oo00001Oooooooo`00oooooooo003ooooo00;oo`001Oooool2ool0
0003oooooooo003ooooo00;oo`0000Goooooool00?ooooooo`00ooooo`02ool00005oooooooo003o
ooooool00?ooool00_oo00000oooooooo`00ooooo`04ool00003oooooooo003ooooo00Coo`0000?o
ooooool00?ooool00_oo00001Oooooooo`00oooooooo003ooooo00;oo`0000?oooooool00?ooool0
1?oo00000oooooooo`00ooooo`02ool00006oooooooo003oooooool00?ooooooo`000_ooool01?oo
003oooooool00?ooool2ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool00oooool0
1?oo003oooooool00?ooool2ool00005oooooooo003oooooool00?ooool00_oo00000oooooooo`00
ooooo`04ool00003oooooooo003ooooo00;oo`0000Goooooool00?ooooooo`00ooooo`02ool000Oo
oooo1?l0000@ooooo`005_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00So
oooo00Coo`00oooooooo003ooooo1?oo00000oooooooo`00ooooo`02ool00003oooooooo003ooooo
00Coo`0000?oooooool00?ooool01?oo00000oooooooo`00ooooo`02ool00003oooooooo003ooooo
00;ooooo0_oo00000oooooooo`00ooooo`04ool00003oooooooo003ooooo00;oo`000oooool02Ooo
003oooooool00?oo003oooooool00?ooooooo`00ooooo`02ool00003oooooooo003ooooo00Coo`00
00?oooooool00?ooool00_oo00001Oooooooo`00oooooooo003ooooo00Coo`0000Coooooool00?oo
003oo`000_ooool00ooo003oooooool00003ool00003oooooooo003ooooo00Coo`0000?oooooool0
0?ooool00_oo00001Oooooooo`00oooooooo003ooooo00;oo`0000Coooooool00?ooooooo`000_oo
ool01?oo003oooooool00?ooool4ool00003oooooooo003ooooo00;oo`0000?oooooool00?ooool0
0_ooool2ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool01?oo00000oooooooo`00
ool00002ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool01?oo00000oooooooo`00
ooooo`04ool00003oooooooo003oo`0000;oo`0000?oooooool00?ooool01?oo00000oooooooo`00
ooooo`04ool00003oooooooo003ooooo00;oo`000oooool01ooo003oooooool00?oo003oooooool0
0?ooool01?oo00001?ooooooo`00oooooooo0002ooooo`04ool00?ooooooo`00ooooo`;oo`0000?o
ooooool00?ooool01?oo00000oooooooo`00ooooo`04ool00003oooooooo003ooooo00Coo`0000?o
ooooool00?oo00000_oo00000oooooooo`00ooooo`04ool00003oooooooo003ooooo00Coo`0000?o
ooooool00?ooool00_oo00001Oooooooo`00oooooooo003ooooo00;oo`0000Goooooool00?oooooo
o`00ooooo`02ool0000:oooooooo003ooooooooooooo003oooooool00?ooooooo`00ooooo`;oo`00
00Goooooool00?ooooooo`00ooooo`02ool000?ooooo00Ooo`00oooooooo003oo`00oooooooo003o
oooo00Coo`0000?oooooool00?ooool00_oo00000oooooooo`00ooooo`04ool00003oooooooo003o
oooo00Coo`0000?oooooool00?ooool01?oo00000oooooooo`00ool00002ool00003oooooooo003o
oooo00Coo`0000?oooooool00?ooool01?oo00000oooooooo`00ooooo`02ool00006oooooooo003o
ooooool00?ooooooo`000_ooool00ooo003oooooool00003ool00003oooooooo003ooooo00Coo`00
00[oooooool00?ooooooooooool00?ooooooo`00oooooooo003ooooo0_oo00000oooooooo`00oooo
o`04ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool01?oo00000oooooooo`00ool0
0002ool000[ooooo00?o0000ooooooooool03_ooool001Kooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`08ooooo`04ool00?ooooooo`00ooooo`Coo`0000?oooooool00?oo0000
0_oo00000oooooooo`00ooooo`04ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool0
0_oo00000oooooooo`00ooooo`02ooooo`;oo`0000?oooooool00?ooool01?oo00000oooooooo`00
ooooo`03ool000;ooooo00Woo`00oooooooo003oo`00oooooooo003oooooool00?ooool00_oo0000
0oooooooo`00ooooo`04ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool01?oo0000
1?ooooooo`00ool00?oo0002ooooo`03ool00?ooooooo`0000?oo`0000?oooooool00?oo00001?oo
00000oooooooo`00ool00002ool00003oooooooo003ooooo00Coo`0000Coooooool00?ooooooo`00
0_ooool01?oo003oooooool00?ooool4ool00003oooooooo003ooooo00;oo`0000?oooooool00?oo
ool00_ooool2ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool01?oo00000ooooooo
o`00ool00002ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool01?oo00000ooooooo
o`00ooooo`04ool00003oooooooo003oo`0000;oo`0000?oooooool00?ooool01?oo00000ooooooo
o`00ooooo`04ool00003oooooooo003ooooo00;oo`000oooool01ooo003oooooool00?oo003ooooo
ool00?ooool01?oo00001?ooooooo`00oooooooo0002ooooo`04ool00?ooooooo`00ooooo`;oo`00
00?oooooool00?ooool01?oo00000oooooooo`00ooooo`04ool00003oooooooo003ooooo00Coo`00
00?oooooool00?oo00001?oo00000oooooooo`00ool00002ool00003oooooooo003ooooo00Coo`00
00?oooooool00?ooool00_oo00001Oooooooo`00oooooooo003ooooo00;oo`0000?oooooool00?oo
ool01?oo00001?ooooooo`00ooooooooool3ool00003oooooooo003ooooo00Coo`0000?oooooool0
0?ooool00_oo0003ooooo`Coo`0000?oooooool00?ooool01?oo00000oooooooo`00ooooo`04ool0
0003oooooooo003oo`0000Coo`0000?oooooool00?oo00000_oo00000oooooooo`00ooooo`04ool0
0003oooooooo003oo`0000Coo`0000?oooooool00?oo00001?oo00000oooooooo`00ool00002ool0
0003oooooooo003ooooo00;oo`0000Koooooool00?ooooooo`00oooooooo0002ooooo`03ool00?oo
ooooo`0000?oo`0000?oooooool00?ooool01?oo00002_ooooooo`00ooooooooooooo`00oooooooo
003oooooool00?ooool2ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool01?oo0000
0oooooooo`00ooooo`04ool00003oooooooo003oo`0000;oo`002_ooool00ol0003oooooooooo`0>
ooooo`005oooool2o`0000Oooooo00?o0000ooooooooool02?ooool00ooo003oooooool00005ool0
0003oooooooo003oo`0000Coo`0000?oooooool00?oo00001?oo00000oooooooo`00ool00002ool0
0003oooooooo003ooooo00;oo`0000?oooooool00?ooool00_ooool2ool00003oooooooo003ooooo
00Koo`0000Coooooool00?oo003oo`000_ooool01ooo003oooooool00?oo003oooooool00?ooool0
1_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000Coo`0000?oooooool00?oo0000
1?oo00001?ooooooo`00ool00?oo0002ooooo`goo`0000?oooooool00?oo00001?oo00000ooooooo
o`00ool00002ool00004oooooooo003oooooool000;ooooo00Coo`00oooooooo003ooooo2Ooo0000
0oooooooo`00ooooo`02ooooo`;oo`0000?oooooool00?ooool01?oo00000oooooooo`00ooooo`04
ool00003oooooooo003oo`0000Woo`0000?oooooool00?oo00004_oo00000oooooooo`00ool00002
ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool00_oo0003ooooo`07ool00?oooooo
o`00ool00?ooooooo`00ooooo`04ool00004oooooooo003oooooool000;ooooo00Coo`00oooooooo
003ooooo1?oo00000oooooooo`00ool00004ool00003oooooooo003oo`0000;oo`0000?oooooool0
0?ooool02ooo00000oooooooo`00ool00009ool00003oooooooo003ooooo00Coo`0000?oooooool0
0?ooool00_oo00000oooooooo`00ooooo`04ool00004oooooooo003oooooooooo`?oo`0000?ooooo
ool00?oo00001_oo00000oooooooo`00ool00003ooooo`Coo`0000?oooooool00?ooool01?oo0000
0oooooooo`00ooooo`04ool00003oooooooo003oo`00013oo`0000?oooooool00?oo00001?oo0000
0oooooooo`00ool00004ool00003oooooooo003oo`0000;oo`0000?oooooool00?ooool01?oo0000
1?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000Goo`0000?oooooool00?oo00000_oo
00002_ooooooo`00ooooooooooooo`00oooooooo003oooooool00?ooool2ool00003oooooooo003o
oooo00Coo`0000?oooooool00?ooool02ooo00000oooooooo`00ool00002ool000[ooooo00?o0000
ooooooooool03_ooool0023ooooo00?o0000ooooooooool02OoooolEool00003oooooooo003oo`00
00;oo`0000?oooooool00?ooool00_oo00000oooooooo`00ooooo`02ooooo`;oo`0000?oooooool0
0?oo00001_oo00001?ooooooo`00ool00?oo0002ooooo`03ool00?ooooooo`0000?oo`0000?ooooo
ool00?oo00001?oo00000oooooooo`00ool0000Dool00003oooooooo003oo`0001?oo`0000?ooooo
ool00?oo00000_oo00001?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000[oo`0000?o
ooooool00?ooool00_ooool2ool00003oooooooo003ooooo00Coo`0000?oooooool00?oo00001?oo
00000oooooooo`00ool0000Nool00003oooooooo003oo`0000;oo`0000?oooooool00?ooool01?oo
00000oooooooo`00ooooo`02ool000?ooooo1_oo00000oooooooo`00ool00002ool00004oooooooo
003oooooool000;ooooo00Coo`00oooooooo003ooooo1?oo00000oooooooo`00ool00004ool00003
oooooooo003oo`0002?oo`0000?oooooool00?oo00000_oo00000oooooooo`00ooooo`04ool00004
oooooooo003oooooooooo`?oo`0000?oooooool00?oo00001_oo00000oooooooo`00ool00003oooo
o`Coo`0000?oooooool00?ooool01?oo00000oooooooo`00ool0000Uool00003oooooooo003oo`00
00;oo`0000?oooooool00?oo00001?oo00001?ooooooo`00oooooooo0002ooooo`03ool00?oooooo
o`0000[oo`0000Soooooool00?ooooooooooool00?ooooooo`00ooooo`Coo`0000?oooooool00?oo
ool01?oo00000oooooooo`00ool0000@ool000[ooooo00?o0000ooooooooool03_ooool0023ooooo
00?o0000ooooooooool02Oooool00ooo003oooooool0000Iool00003oooooooo003oo`0000;oo`00
0oooool2ool00003oooooooo003oo`0000Koo`0000Coooooool00?oo003oo`000_ooool00ooo003o
ooooool00003ool00003oooooooo003oo`0000Coo`0000?oooooool00?oo0000:_oo00000ooooooo
o`00ool00002ool00004oooooooo003oooooool000;ooooo00?oo`00oooooooo00002_oo00000ooo
ooooo`00ooooo`02ooooo`;oo`0000?oooooool00?ooool06?oo00000oooooooo`00ool0000Mool0
0003oooooooo003ooooo00;oo`000oooool=ool00006oooooooo003ooooooooooooo003ooooo1_oo
00000oooooooo`00ool0000Mool00003oooooooo003oo`00017oo`0000?oooooool00?oo00000_oo
00001?ooooooo`00ooooooooool3ool00003oooooooo003oo`0000Woo`000oooool4ool00003oooo
oooo003oo`0001Soo`0000?oooooool00?oo00002Ooo00000oooooooo`00ool0000Aool00004oooo
oooo003oooooool000;ooooo00?oo`00oooooooo00001?oo00000oooooooo`00ool00003ool00008
oooooooo003ooooooooooooo003oooooool00?ooool4ool00003oooooooo003oo`0001Ooo`002_oo
ool00ol0003oooooooooo`0>ooooo`008?ooool3o`0000Wooooo00?oo`00oooooooo00000ooo0000
0oooooooo`00ooooo`0Cool00003oooooooo003oo`0000;oo`000oooool2ool00003oooooooo003o
o`0000Koo`0000Coooooool00?oo003oo`000_ooool00ooo003oooooool0000@ool00003oooooooo
003oo`0000;oo`0000?oooooool00?ooool01?oo00000oooooooo`00ooooo`04ool00003oooooooo
003oo`0000Coo`0000?oooooool00?oo00003ooo00001?ooooooo`00oooooooo0002ooooo`03ool0
0?ooooooo`0000Coo`0000?oooooool00?oo00000ooo00000oooooooo`00ooooo`02ooooo`;oo`00
00?oooooool00?ooool04Ooo00000oooooooo`00ooooo`04ool00003oooooooo003ooooo00;oo`00
00?oooooool00?ooool01?oo00000oooooooo`00ooooo`04ool00003oooooooo003oo`0000[oo`00
00?oooooool00?ooool00_oo0003ooooo`Ooo`0000?o0000ool00?oo00000ooo00001_ooooooo`00
ooooooooooooo`00ooooo`Koo`0000?oooooool00?oo00002_oo00000oooooooo`00ool00004ool0
0003oooooooo003oo`0000;oo`0000?oooooool00?ooool01?oo00000oooooooo`00ool00004ool0
0003oooooooo003oo`0000[oo`0000?oooooool00?oo00000_oo00001?ooooooo`00ooooooooool3
ool00003oooooooo003oo`0000Woo`000oooool4ool00003oooooooo003oo`00017oo`0000?ooooo
ool00?ooool00_oo00001Oooooooo`00oooooooo003ooooo00;oo`0000?oooooool00?ooool02ooo
00000oooooooo`00ool0000:ool00004oooooooo003oooooool000;ooooo00?oo`00oooooooo0000
1?oo00000oooooooo`00ool00003ool00008oooooooo003ooooooooooooo003oooooool00?oooolC
ool00003oooooooo003oo`0000;oo`0000?oooooool00?ooool00ooo0008ooooo`?o00004?ooool0
023ooooo00?o0000ooooooooool05ooooolCool000?ooooo1Ooo0004ooooo`;oo`0000Coooooool0
0?oo003oo`000_oooolCool001cooooo4_oo00001_ooooooo`00ooooooooooooo`00ooooo`Coo`00
0oooool4ool00004oooooooo003oooooooooo`?oo`0000?oooooool00?oo00003?oo00000ooooooo
o`00ooooo`0Kooooo`03ool00?ooooooo`0000_oo`0000?oooooool00?oo00000_oo0003ooooo`Ko
o`0000?oooooo`000?ooool01?oo00001_ooooooo`00ooooooooooooo`00ooooo`Koo`0000?ooooo
ool00?oo00000ooo00000oooooooo`00ool00003ool001cooooo3?oo00000oooooooo`00ool00002
ool00004oooooooo003oooooooooo`?oo`0000?oooooool00?oo00001?ooool5ool000?ooooo1?oo
00000oooooooo`00ool0000:ool00003oooooooo003ooooo01_ooooo0ooo00000oooooooo`00ool0
000:ool00004oooooooo003oooooool000;ooooo00?oo`00oooooooo00000ooo0003ooooo`Coo`00
00Soooooool00?ooooooooooool00?ooooooo`00ooooo`coo`0000Coooooool00?oo003oo`006?oo
ool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`0Jooooo`?oo`0000?ooooo
ool00?oo00002_oo0003ooooo`Goo`001?ooool2ool00004oooooooo003oo`00ool000;ooooo3?oo
00001?ooooooo`00oooooooo000Sooooo`03ool00?ooooooo`0000_oo`0000Koooooool00?oooooo
ooooool00?ooool4ool000Cooooo0ooo00001?ooooooo`00ooooooooool3ool00003oooooooo003o
o`0000[oo`009?ooool4ool00003oooooooo003oo`0000?oo`0000?oooooool00?oo00000_oo0003
ooooo`Goo`000_ooool00ol0003oooooool00003ool00006oooooooo003ooooooooooooo003ooooo
3?oo00000oooooooo`00ooooo`0Rooooo`03ool00?ooooooo`0000_oo`0000Coooooool00?oooooo
oooo0ooo00000oooooooo`00ool00004ooooo`Goo`000oooool4ool00003oooooooo003oo`0000Go
o`0000Coooooool00?oo003oo`008oooool<ool00004oooooooo003oooooool000;ooooo00?oo`00
oooooooo00000ooo0003ooooo`Coo`0000Soooooool00?ooooooooooool00?ooooooo`00ooooo`co
o`007?ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`0Nooooo`coo`00
0_ooool5ool000Kooooo1Ooo0002ooooo`coo`00:_ooool;ool00006oooooooo003ooooooooooooo
003ooooo0_oo0007ooooo`;oo`0000Coooooool00?oooooooooo0ooo00000oooooooo`00ool00005
ool00003oooooooo003ooooo02Wooooo00?oo`00oooooooo00001?oo00000oooooooo`00ool00002
ool000?ooooo1?oo0003ooooo`04o`000?ooooooooooooooo`;oo`0000Koooooool00?oooooooooo
ool00?ooool;ool002[ooooo2_oo00001?ooooooo`00ooooooooool5ool000Kooooo1?oo0003oooo
o`Coo`0000?oooooool00?oo00001Ooo000Zooooo`Woo`0000Coooooool00?ooooooo`000_ooool0
1?oo003oooooool00?oo0007ooooo`Coo`000_ooool01?oo003oooooool00?ooool7ool00003oooo
oooo003ooooo01kooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool08?oo
ool:ool000;ooooo1Ooo0007ooooo`Coo`000_ooool;ool002gooooo00?oo`00oooooooo00001_oo
00001_ooooooo`00ooooooooooooo`00ooooo`;oo`001oooool4ool000;ooooo2ooo000^ooooo`[o
o`000oooool4ool000?ooooo00Co0000oooooooooooooooo0_oo00001_ooooooo`00oooooooooooo
o`00ooooo`Ooo`0000?oooooool00?ooool0;?ooool;ool000;ooooo1?oo0007ooooo`Coo`000ooo
ool:ool002kooooo00?oo`00oooooooo00001?oo00001?ooooooo`00oooooooo0002ooooo`04ool0
0?ooooooo`00ool000Oooooo1?oo0002ooooo`04ool00?ooooooo`00ooooo`Goo`0000?oooooool0
0?ooool08?ooool00ol0003oooooooooo`0>ooooo`008?ooool3o`00027ooooo2Ooo0002ooooo`Co
o`002?ooool4ool000;ooooo1ooo00000oooooooo`00ooooo`0`ooooo`Ooo`0000Koooooool00?oo
ooooooooool00?ooool2ool000Oooooo1?oo0002ooooo`[oo`00<?ooool9ool000?ooooo1?oo0003
ooooo`04o`000?ooooooooooooooo`;oo`0000Koooooool00?ooooooooooool00?ooool7ool0037o
oooo00?oo`00oooooooo00001_oo0002ooooo`Coo`001oooool4ool000?ooooo1Ooo00001?oooooo
o`00ool00?oo000aooooo`Goo`0000Coooooool00?ooooooo`000_ooool01?oo003oooooool00?oo
0007ooooo`Coo`000_ooool01?oo003oooooool00?ooool6ool0023ooooo0ol0000@ooooo`008?oo
ool00ol0003oooooooooo`0Sooooo`Ooo`000_ooool4ool000Sooooo1?oo0002ooooo`Ooo`00=?oo
ool6ool00006oooooooo003ooooooooooooo003ooooo0_oo0007ooooo`Coo`000_ooool8ool003Co
oooo1ooo0003ooooo`Coo`000oooool01?l0003oooooooooooooool2ool00006oooooooo003ooooo
oooooooo003ooooo1Ooo000eooooo`Ooo`000_ooool4ool000Sooooo0ooo0003ooooo`Goo`0000?o
ooooool00?ooool0<oooool8ool000;ooooo00Coo`00oooooooo003oo`001oooool4ool000;ooooo
2?oo000Tooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo02?ooooo1ooo
0002ooooo`Coo`002?ooool4ool000;ooooo1ooo000eooooo`Goo`0000Koooooool00?oooooooooo
ool00?ooool2ool000Oooooo1?oo0002ooooo`Soo`00=?ooool8ool000;ooooo1?oo0003ooooo`04
o`000?ooooooooooooooo`;oo`0000Koooooool00?ooooooooooool00?ooool5ool003Gooooo1ooo
0002ooooo`Coo`002?ooool3ool000?ooooo1Ooo00000oooooooo`00ooooo`0cooooo`Soo`000_oo
ool4ool000Oooooo1?oo0002ooooo`Soo`009?ooool00ol0003oooooooooo`0>ooooo`008?ooool0
0ol0003oooooooooo`0Uooooo`Goo`000_ooool4ool000Sooooo1?oo0002ooooo`Koo`00=oooool4
ool00004oooooooo003oooooooooo`Coo`001oooool4ool000;ooooo1_oo000hooooo`Koo`000_oo
ool4ool000?ooooo00Co0000oooooooooooooooo0_oo00001_ooooooo`00ooooooooooooo`00oooo
o`Coo`00=oooool6ool000;ooooo1?oo0008ooooo`?oo`000oooool5ool003Sooooo1_oo0002oooo
o`Coo`001oooool4ool000;ooooo1_oo000Vooooo`03o`000?oooooooooo00kooooo000Pooooo`03
o`000?oooooooooo02Gooooo1Ooo0002ooooo`?oo`002_ooool3ool000;ooooo1Ooo000hooooo`Co
o`0000Coooooool00?oooooooooo0ooo000:ooooo`;oo`000_ooool6ool003Sooooo1_oo0002oooo
o`;oo`001Oooool00ol0003oooooooooo`02ooooo`?oo`000_ooool00ooo003oooooool00003ool0
03Oooooo1_oo0002ooooo`?oo`002_ooool2ool000?ooooo1Ooo000hooooo`Koo`000_ooool2ool0
00_ooooo0_oo0002ooooo`Koo`009_ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003o
ooooooooo`0Uooooo`Goo`000_ooool3ool000[ooooo0ooo0002ooooo`Goo`00>?ooool4ool00004
oooooooo003oooooooooo`?oo`002_ooool2ool000;ooooo1?oo00000oooooooo`00ooooo`0goooo
o`Koo`000_ooool2ool000Gooooo00?o0000ooooooooool00_ooool3ool000;ooooo00?oo`00oooo
oooo00000ooo000hooooo`Goo`000_ooool3ool000[ooooo0_oo0003ooooo`Goo`00>?ooool6ool0
00;ooooo0_oo000;ooooo`;oo`000_ooool4ool00003oooooooo003ooooo02Gooooo00?o0000oooo
ooooool03_ooool0023ooooo0ol0000Vooooo`Coo`000_ooool3ool000[ooooo0ooo0002ooooo`Co
o`00>oooool2ool00004oooooooo003oooooooooo`?oo`002_ooool2ool000;ooooo1?oo000loooo
o`Coo`000_ooool2ool000Gooooo00?o0000ooooooooool00oooool2ool000;ooooo00Coo`00oooo
oooo003oo`00>oooool4ool000;ooooo0ooo000:ooooo`?oo`000_ooool4ool003_ooooo1?oo0002
ooooo`;oo`002oooool2ool000;ooooo1?oo000Vooooo`?o00004?ooool0023ooooo00?o0000oooo
ooooool09_ooool4ool000;ooooo0ooo000:ooooo`?oo`000_ooool4ool003_ooooo0_oo00001?oo
ooooo`00ooooooooool3ool000[ooooo0_oo0002ooooo`Coo`00??ooool4ool000;ooooo0_oo0005
ooooo`03o`000?oooooooooo00?ooooo0_oo0002ooooo`04ool00?ooooooo`00ool003_ooooo1?oo
0002ooooo`?oo`002_ooool3ool000;ooooo1?oo000kooooo`Coo`000_ooool2ool000_ooooo0_oo
0002ooooo`Coo`00:?ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`0V
ooooo`Coo`000_ooool3ool000[ooooo0ooo0002ooooo`Coo`00>oooool4ool000;ooooo0_oo000;
ooooo`;oo`000_ooool4ool003cooooo1?oo0002ooooo`;oo`001Oooool00ol0003oooooooooo`03
ooooo`;oo`000_ooool01?oo003oooooool00?oo000kooooo`Coo`000_ooool3ool000[ooooo0ooo
0002ooooo`Coo`00>oooool4ool000;ooooo0_oo000;ooooo`;oo`000_ooool4ool002Sooooo00?o
0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool09_ooool4ool000;ooooo0ooo000:
ooooo`?oo`000_ooool4ool003_ooooo1?oo0002ooooo`;oo`002oooool2ool000;ooooo1?oo000l
ooooo`Coo`000_ooool2ool000Gooooo00?o0000ooooooooool00oooool2ool000;ooooo00Coo`00
oooooooo003oo`00>oooool4ool000;ooooo0ooo000:ooooo`?oo`000_ooool4ool003_ooooo1?oo
0002ooooo`;oo`002oooool2ool000;ooooo1?oo000Xooooo`03o`000?oooooooooo00kooooo000P
ooooo`03o`000?oooooooooo02Kooooo1?oo0002ooooo`?oo`002_ooool3ool000;ooooo1?oo000k
ooooo`04ool00?ooooooo`00ool000;ooooo0_oo000;ooooo`;oo`000_ooool4ool003cooooo1?oo
0002ooooo`;oo`001Oooool00ol0003oooooooooo`03ooooo`;oo`000_ooool01?oo003oooooool0
0?oo000kooooo`Coo`000_ooool3ool000[ooooo0ooo0002ooooo`Coo`00>oooool4ool000;ooooo
0_oo000;ooooo`;oo`000_ooool4ool002Sooooo00?o0000ooooooooool03_ooool0023ooooo00?o
0000ooooooooool09oooool3ool000;ooooo0ooo000:ooooo`?oo`000_ooool4ool003_ooooo00Co
o`00oooooooo003oo`000_ooool2ool000_ooooo0_oo0002ooooo`Coo`00??ooool4ool000;ooooo
0_oo0005ooooo`03o`000?oooooooooo00?ooooo0_oo0002ooooo`04ool00?ooooooo`00ool003_o
oooo1?oo0002ooooo`?oo`002_ooool3ool000;ooooo1?oo000kooooo`Coo`000_ooool2ool000_o
oooo0_oo0002ooooo`Coo`00:?ooool00ol0003oooooooooo`0>ooooo`008?ooool3o`0002Sooooo
0_oo0002ooooo`?oo`002_ooool3ool000;ooooo0_oo000oooooo`;oo`000_ooool2ool000_ooooo
0_oo0002ooooo`?oo`00?_ooool3ool000;ooooo0_oo0005ooooo`03o`000?oooooooooo00?ooooo
0_oo0002ooooo`03ool00?ooooooo`0003kooooo0_oo0002ooooo`?oo`002_ooool3ool000;ooooo
0_oo000nooooo`?oo`000_ooool2ool000_ooooo0_oo0002ooooo`?oo`009oooool3o`00013ooooo
000Pooooo`03o`000?oooooooooo02Sooooo0_oo0002ooooo`?oo`002_ooool3ool000;ooooo0_oo
000oooooo`;oo`000_ooool2ool000_ooooo0_oo0002ooooo`?oo`00?_ooool3ool000;ooooo0_oo
0005ooooo`03o`000?oooooooooo00?ooooo0_oo0002ooooo`;oo`00?oooool2ool000;ooooo0_oo
000;ooooo`?oo`000_ooool2ool003kooooo0ooo0002ooooo`;oo`002oooool2ool000;ooooo0ooo
000Yooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo02Sooooo0_oo0002
ooooo`?oo`002oooool2ool000;ooooo0_oo000oooooo`;oo`000_ooool2ool000_ooooo0_oo0002
ooooo`?oo`00?_ooool3ool000;ooooo0_oo0005ooooo`03o`000?oooooooooo00?ooooo0_oo0002
ooooo`;oo`00?oooool2ool000;ooooo0_oo000;ooooo`?oo`000_ooool2ool003kooooo0ooo0002
ooooo`;oo`002oooool2ool000;ooooo0ooo000Yooooo`03o`000?oooooooooo00kooooo000Foooo
o`?o00001oooool00ol0003oooooooooo`0Xooooo`;oo`000_ooool2ool000cooooo0_oo0002oooo
o`;oo`00?oooool2ool000;ooooo0_oo000;ooooo`;oo`000_ooool3ool003kooooo0ooo0002oooo
o`;oo`001Oooool00ol0003oooooooooo`03ooooo`;oo`000_ooool2ool003oooooo0_oo0002oooo
o`;oo`002oooool3ool000;ooooo0_oo000nooooo`?oo`000_ooool2ool000_ooooo0_oo0002oooo
o`?oo`00:Oooool00ol0003oooooooooo`0>ooooo`005Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0:?ooool2ool000;ooooo0ooo000;ooooo`;oo`000_ooool2ool0
03oooooo0_oo0002ooooo`;oo`002oooool2ool000;ooooo0ooo000nooooo`?oo`000_ooool2ool0
00Gooooo00?o0000ooooooooool00oooool2ool000;ooooo0_oo000oooooo`;oo`000_ooool2ool0
00cooooo0_oo0002ooooo`;oo`00?_ooool3ool000;ooooo0_oo000;ooooo`;oo`000_ooool3ool0
02Wooooo00?o0000ooooooooool03_ooool001Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Xooooo`;oo`000_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00;o
o`00?oooool2ool000;ooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`03ool003ko
oooo0ooo0002ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ooo003o
ooooooooo`02ool003oooooo0_oo0002ooooo`03ool00?oooooooooo00cooooo00?oo`00oooooooo
ool00_oo000nooooo`?oo`000_ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00?o
o`00:Oooool00ol0003oooooooooo`0>ooooo`006Oooool00ol0003oooooooooo`04ooooo`Co0000
9oooool2ool000;ooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`02ool003oooooo
0_oo0002ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00ooo000nooooo`?oo`00
0_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0
0_oo000oooooo`;oo`000_ooool00ooo003oooooooooo`0<ooooo`03ool00?ooooooo`0000;oo`00
?oooool2ool000;ooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`03ool002Kooooo
1?l0000@ooooo`005Oooool4o`0000Oooooo00?o0000ooooooooool0:?ooool2ool000;ooooo00?o
o`00ooooooooool03?ooool00ooo003oooooooooo`02ool003oooooo0_oo0002ooooo`03ool00?oo
oooooooo00_ooooo00?oo`00ooooooooool00ooo000nooooo`?oo`000_ooool00ooo003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool00_oo000oooooo`;oo`000_oo
ool00ooo003oooooooooo`0<ooooo`03ool00?ooooooo`0000;oo`00?oooool2ool000;ooooo00?o
o`00ooooooooool02oooool00ooo003oooooooooo`02ool002[ooooo00?o0000ooooooooool03_oo
ool001Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Xooooo`;oo`000_ooool0
0ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00;oo`00?oooool2ool000;ooooo00?oo`00
ooooooooool02oooool00ooo003oooooooooo`03ool003kooooo0ooo0002ooooo`03ool00?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`02ool003oooooo0_oo0002
ooooo`03ool00?oooooooooo00cooooo00?oo`00oooooooo00000_oo000oooooo`;oo`000_ooool0
0ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00;oo`00:_ooool00ol0003oooooooooo`0>
ooooo`005Oooool5o`0000Kooooo00?o0000ooooooooool0:?ooool2ool000;ooooo00?oo`00oooo
ooooool03?ooool00ooo003oooooooooo`02ool003oooooo0_oo0002ooooo`03ool00?oooooooooo
00_ooooo00?oo`00ooooooooool00ooo000nooooo`?oo`000_ooool00ooo003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool00_oo000oooooo`;oo`000_ooool00ooo
003oooooooooo`0<ooooo`03ool00?ooooooo`0000;oo`00?oooool2ool000;ooooo00?oo`00oooo
ooooool02oooool00ooo003oooooooooo`02ool002[ooooo00?o0000ooooooooool03_ooool0023o
oooo00?o0000ooooooooool0:?ooool2ool000;ooooo00?oo`00ooooooooool03?ooool00ooo003o
ooooooooo`02ool003oooooo0_oo0002ooooo`03ool00?oooooooooo00_ooooo00?oo`00oooooooo
ool00_oo000oooooo`?oo`000_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?oo`00ooooooooool00_oo000oooooo`;oo`000_ooool00ooo003oooooooooo`0<ooooo`03
ool00?ooooooo`0000;oo`00?oooool2ool000;ooooo00?oo`00ooooooooool02oooool00ooo003o
ooooooooo`02ool002[ooooo00?o0000ooooooooool03_ooool0023ooooo0ol0000Xooooo`;oo`00
0_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00;oo`00?oooool2ool000;ooooo
00?oo`00ooooooooool02oooool00ooo003oooooooooo`03ool003kooooo0ooo0002ooooo`03ool0
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`02ool003oooooo
0_oo0002ooooo`03ool00?oooooooooo00cooooo00?oo`00oooooooo00000_oo000oooooo`;oo`00
0_ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00;oo`00:?ooool3o`00013ooooo
000Pooooo`03o`000?oooooooooo02Sooooo0_oo0002ooooo`03ool00?oooooooooo00cooooo00?o
o`00ooooooooool00_oo000oooooo`;oo`000_ooool00ooo003oooooooooo`0;ooooo`03ool00?oo
oooooooo00;oo`00@?ooool2ool000;ooooo00?oo`00ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03ool00?oooooooooo00;oo`00?oooool2ool000;ooooo00?oo`00ooooooooool03?oo
ool01Ooo003oooooool00?ooooooo`0003oooooo0_oo0002ooooo`03ool00?oooooooooo00_ooooo
00?oo`00ooooooooool00_oo000Zooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oo
oooooooo02[ooooo00?oo`00oooooooo00003_ooool01?oo003ooooooooooooo0011ooooo`04ool0
0?ooooooooooool000gooooo00Coo`00ooooooooooooo`00@_ooool01?oo003ooooooooooooo0006
ooooo`03o`000?oooooooooo00Cooooo00Coo`00ooooooooooooo`00@Oooool01?oo003ooooooooo
oooo000>ooooo`03ool00?ooooooo`0004;ooooo00Coo`00ooooooooooooo`003Oooool01?oo003o
oooooooooooo000[ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo02[o
oooo00?oo`00oooooooo00003_ooool01?oo003ooooooooooooo0011ooooo`04ool00?oooooooooo
ool000kooooo00?oo`00oooooooo0000@_ooool01?oo003ooooooooooooo0006ooooo`03o`000?oo
oooooooo00Cooooo00Coo`00ooooooooooooo`00@Oooool01?oo003ooooooooooooo000>ooooo`03
ool00?ooooooo`0004;ooooo00Coo`00ooooooooooooo`003Oooool01?oo003ooooooooooooo000[
ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo02[ooooo00?oo`00oooo
oooo00003_ooool01?oo003ooooooooooooo0011ooooo`04ool00?ooooooooooool000kooooo00?o
o`00oooooooo0000@_ooool01?oo003ooooooooooooo0006ooooo`03o`000?oooooooooo00Cooooo
00Coo`00ooooooooooooo`00@Oooool01?oo003ooooooooooooo000>ooooo`03ool00?ooooooo`00
04;ooooo00Coo`00ooooooooooooo`003Oooool01?oo003ooooooooooooo000[ooooo`03o`000?oo
oooooooo00kooooo000Pooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo00003_ooool0
1?oo003ooooooooooooo0011ooooo`04ool00?ooooooooooool000kooooo00?oo`00oooooooo0000
@_ooool01?oo003ooooooooooooo0006ooooo`03o`000?oooooooooo00Cooooo00Coo`00oooooooo
ooooo`00@Oooool01?oo003ooooooooooooo000>ooooo`03ool00?ooooooo`0004;ooooo00Coo`00
ooooooooooooo`003Oooool01?oo003ooooooooooooo000[ooooo`03o`000?oooooooooo00kooooo
000Pooooo`?o0000:_ooool00ooo003oooooool0000>ooooo`04ool00?ooooooooooool0047ooooo
00Coo`00ooooooooooooo`003_ooool00ooo003oooooool00012ooooo`04ool00?ooooooooooool0
00Kooooo00?o0000ooooooooool01?ooool01?oo003ooooooooooooo0011ooooo`04ool00?oooooo
ooooool000kooooo00?oo`00oooooooo0000@_ooool01?oo003ooooooooooooo000=ooooo`04ool0
0?ooooooooooool002Wooooo0ol0000@ooooo`008?ooool00ol0003oooooooooo`0Zooooo`03ool0
0?ooooooo`0000kooooo00Coo`00ooooooooooooo`00@Oooool01?oo003ooooooooooooo000>oooo
o`03ool00?ooooooo`0004;ooooo00Coo`00ooooooooooooo`001_ooool00ol0003oooooooooo`04
ooooo`04ool00?ooooooooooool0047ooooo00Coo`00ooooooooooooo`003_ooool00ooo003ooooo
ool00012ooooo`04ool00?ooooooooooool000gooooo00Coo`00ooooooooooooo`00:oooool00ol0
003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`0Zooooo`03ool00?ooooooo`0000ko
oooo00Coo`00ooooooooooooo`00@Oooool01?oo003ooooooooooooo000>ooooo`03ool00?oooooo
o`0004;ooooo00Coo`00ooooooooooooo`001_ooool00ol0003oooooooooo`04ooooo`04ool00?oo
ooooooooool0047ooooo00Coo`00ooooooooooooo`003_ooool00ooo003oooooool00012ooooo`04
ool00?ooooooooooool000gooooo00Coo`00ooooooooooooo`00:oooool00ol0003oooooooooo`0>
ooooo`008?ooool00ol0003oooooooooo`0Zooooo`03ool00?ooooooo`0000kooooo00Coo`00oooo
ooooooooo`00@Oooool01?oo003ooooooooooooo000>ooooo`03ool00?ooooooo`0004;ooooo00Co
o`00ooooooooooooo`001_ooool00ol0003oooooooooo`04ooooo`04ool00?ooooooooooool0047o
oooo00Coo`00ooooooooooooo`003_ooool00ooo003oooooool00012ooooo`04ool00?oooooooooo
ool000gooooo00Coo`00ooooooooooooo`00:oooool00ol0003oooooooooo`0>ooooo`008?ooool0
0ol0003oooooooooo`0Zooooo`03ool00?ooooooo`0000kooooo00Coo`00ooooooooooooo`00@Ooo
ool01?oo003ooooooooooooo000>ooooo`03ool00?ooooooo`0004;ooooo00Coo`00oooooooooooo
o`001_ooool00ol0003oooooooooo`04ooooo`04ool00?ooooooooooool0047ooooo00Coo`00oooo
ooooooooo`003_ooool00ooo003oooooool00012ooooo`04ool00?ooooooooooool000gooooo00Co
o`00ooooooooooooo`00:oooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003ooooooooo
o`0Zooooo`03ool00?ooooooo`0000kooooo00Coo`00ooooooooooooo`00@Oooool01?oo003ooooo
oooooooo000>ooooo`03ool00?ooooooo`0004;ooooo00Coo`00ooooooooooooo`001_ooool00ol0
003oooooooooo`04ooooo`04ool00?ooooooooooool0047ooooo00Coo`00ooooooooooooo`003_oo
ool00ooo003oooooool00012ooooo`04ool00?ooooooooooool000gooooo00Coo`00oooooooooooo
o`00:oooool00ol0003oooooooooo`0>ooooo`008?ooool3o`0002[ooooo00?oo`00oooooooo0000
3_ooool01?oo003ooooooooooooo0011ooooo`04ool00?ooooooooooool000kooooo00?oo`00oooo
oooo0000@_ooool01?oo003ooooooooooooo0006ooooo`03o`000?oooooooooo00Cooooo00Coo`00
ooooooooooooo`00@Oooool01?oo003ooooooooooooo000>ooooo`03ool00?ooooooo`0004;ooooo
00Coo`00ooooooooooooo`003Oooool01?oo003ooooooooooooo000Yooooo`?o00004?ooool0023o
oooo00?o0000ooooooooool0:_ooool00ooo003oooooool0000>ooooo`04ool00?ooooooooooool0
047ooooo00Coo`00ooooooooooooo`003_ooool00ooo003oooooool00012ooooo`04ool00?oooooo
ooooool000Kooooo00?o0000ooooooooool01?ooool01?oo003ooooooooooooo0011ooooo`04ool0
0?ooooooooooool000kooooo00?oo`00oooooooo0000@_ooool01?oo003ooooooooooooo000=oooo
o`04ool00?ooooooooooool002_ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooo
ooooool0:_ooool00ooo003oooooool0000>ooooo`04ool00?ooooooooooool0047ooooo00Coo`00
ooooooooooooo`003_ooool00ooo003oooooool00012ooooo`04ool00?ooooooooooool000Kooooo
00?o0000ooooooooool01?ooool01?oo003ooooooooooooo0011ooooo`04ool00?ooooooooooool0
00kooooo00?oo`00oooooooo0000@_ooool01?oo003ooooooooooooo000=ooooo`04ool00?oooooo
ooooool002_ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0:_ooool0
0ooo003oooooool0000>ooooo`04ool00?ooooooooooool0047ooooo00Coo`00ooooooooooooo`00
3_ooool00ooo003oooooool00012ooooo`04ool00?ooooooooooool000Kooooo00?o0000oooooooo
ool01?ooool01?oo003ooooooooooooo0011ooooo`04ool00?ooooooooooool000kooooo00?oo`00
oooooooo0000@_ooool01?oo003ooooooooooooo000=ooooo`04ool00?ooooooooooool002_ooooo
00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0:_ooool00ooo003oooooool0
000>ooooo`04ool00?ooooooooooool0047ooooo00Coo`00ooooooooooooo`003_ooool00ooo003o
ooooool00012ooooo`04ool00?ooooooooooool000Kooooo00?o0000ooooooooool01?ooool01?oo
003ooooooooooooo0011ooooo`04ool00?ooooooooooool000kooooo00?oo`00oooooooo0000@_oo
ool01?oo003ooooooooooooo000=ooooo`04ool00?ooooooooooool002_ooooo00?o0000oooooooo
ool03_ooool0023ooooo00?o0000ooooooooool0:_ooool00ooo003oooooool0000>ooooo`03ool0
0?ooooooo`0004;ooooo00Coo`00ooooooooooooo`003_ooool00ooo003oooooool00012ooooo`04
ool00?ooooooooooool000Kooooo00?o0000ooooooooool01?ooool01?oo003ooooooooooooo0011
ooooo`04ool00?ooooooooooool000kooooo00?oo`00oooooooo0000@_ooool01?oo003ooooooooo
oooo000=ooooo`04ool00?ooooooooooool002_ooooo00?o0000ooooooooool03_ooool0023ooooo
0ol0000Zooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000@_ooool01?oo003ooooo
oooooooo000>ooooo`03ool00?ooooooo`0004;ooooo00Coo`00ooooooooooooo`001_ooool00ol0
003oooooooooo`04ooooo`04ool00?ooooooooooool0047ooooo00Coo`00ooooooooooooo`003_oo
ool00ooo003oooooool00012ooooo`04ool00?ooooooooooool000gooooo00Coo`00oooooooooooo
o`00:Oooool3o`00013ooooo000Pooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo0000
3_ooool00ooo003oooooool00012ooooo`04ool00?ooooooooooool000kooooo00?oo`00oooooooo
0000@_ooool01?oo003ooooooooooooo0006ooooo`03o`000?oooooooooo00Cooooo00Coo`00oooo
ooooooooo`00@Oooool01?oo003ooooooooooooo000>ooooo`03ool00?ooooooo`0004;ooooo00Co
o`00ooooooooooooo`003Oooool01?oo003ooooooooooooo000[ooooo`03o`000?oooooooooo00ko
oooo000Pooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo00003_ooool00ooo003ooooo
ool00012ooooo`04ool00?ooooooooooool000kooooo00?oo`00oooooooo0000@_ooool01?oo003o
oooooooooooo0006ooooo`03o`000?oooooooooo00Cooooo00Coo`00ooooooooooooo`00@Oooool0
1?oo003ooooooooooooo000>ooooo`03ool00?ooooooo`0004;ooooo00Coo`00ooooooooooooo`00
3Oooool01?oo003ooooooooooooo000[ooooo`03o`000?oooooooooo00kooooo000@ooooo`?o0000
1?ooool2o`0000Oooooo00?o0000ooooooooool0:_ooool00ooo003oooooool0000>ooooo`03ool0
0?ooooooo`0004;ooooo00?oo`00oooooooo00003oooool00ooo003oooooool00012ooooo`04ool0
0?ooooooooooool000Kooooo00?o0000ooooooooool01?ooool01?oo003ooooooooooooo0011oooo
o`04ool00?ooooooooooool000kooooo00?oo`00oooooooo0000@_ooool01?oo003ooooooooooooo
000=ooooo`04ool00?ooooooooooool002_ooooo00?o0000ooooooooool03_ooool0017ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02[ooooo
00?oo`00oooooooo00003_ooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000oooooo
00?oo`00oooooooo0000@_ooool01?oo003ooooooooooooo0006ooooo`03o`000?oooooooooo00Co
oooo00Coo`00ooooooooooooo`00@_ooool00ooo003oooooool0000>ooooo`03ool00?ooooooo`00
04;ooooo00Coo`00ooooooooooooo`003Oooool01?oo003ooooooooooooo000[ooooo`03o`000?oo
oooooooo00kooooo000Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_oo
ool4o`0002Wooooo00?oo`00oooooooo00003_ooool00ooo003oooooool00012ooooo`03ool00?oo
ooooo`0000oooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool00007ooooo`03o`000?oo
oooooooo00Cooooo00Coo`00ooooooooooooo`00@_ooool00ooo003oooooool0000>ooooo`03ool0
0?ooooooo`0004;ooooo00Coo`00ooooooooooooo`003Oooool01?oo003ooooooooooooo000Xoooo
o`Co00004?ooool0017ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo02[ooooo00?oo`00oooooooo00003_ooool00ooo003oooooool00012oooo
o`03ool00?ooooooo`0000oooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool00007oooo
o`03o`000?oooooooooo00Cooooo00Coo`00ooooooooooooo`00@_ooool00ooo003oooooool0000>
ooooo`03ool00?ooooooo`0004;ooooo00Coo`00ooooooooooooo`003Oooool01?oo003ooooooooo
oooo000[ooooo`03o`000?oooooooooo00kooooo000Aooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0Zooooo`03ool00?ooooooo`0000kooooo
00?oo`00oooooooo0000@_ooool00ooo003oooooool0000?ooooo`03ool00?ooooooo`0004;ooooo
00?oo`00oooooooo00001oooool00ol0003oooooooooo`04ooooo`04ool00?ooooooooooool004;o
oooo00?oo`00oooooooo00003_ooool00ooo003oooooool00012ooooo`04ool00?ooooooooooool0
00gooooo00Coo`00ooooooooooooo`00:oooool00ol0003oooooooooo`0>ooooo`004?ooool2o`00
00Cooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Zooooo`03ool00?oooooo
o`0000kooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool0000?ooooo`03ool00?oooooo
o`0004;ooooo00?oo`00oooooooo00001oooool00ol0003oooooooooo`04ooooo`04ool00?oooooo
ooooool004;ooooo00?oo`00oooooooo00003_ooool00ooo003oooooool00012ooooo`04ool00?oo
ooooooooool000gooooo00Coo`00ooooooooooooo`00:oooool00ol0003oooooooooo`0>ooooo`00
4Oooool00ol0003oooooooooo`03ooooo`;o00001oooool00ol0003oooooooooo`0Zooooo`03ool0
0?ooooooo`0000kooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool0000?ooooo`03ool0
0?ooooooo`0004;ooooo00?oo`00oooooooo00001oooool00ol0003oooooooooo`04ooooo`04ool0
0?ooooooooooool004;ooooo00?oo`00oooooooo00003_ooool00ooo003oooooool00012ooooo`04
ool00?ooooooooooool000gooooo00Coo`00ooooooooooooo`00:oooool00ol0003oooooooooo`0>
ooooo`008?ooool00ol0003oooooooooo`0Zooooo`03ool00?ooooooo`0000kooooo00?oo`00oooo
oooo0000@_ooool00ooo003oooooool0000?ooooo`03ool00?ooooooo`0004;ooooo00?oo`00oooo
oooo00001oooool00ol0003oooooooooo`04ooooo`04ool00?ooooooooooool004;ooooo00?oo`00
oooooooo00003_ooool00ooo003oooooool00012ooooo`04ool00?ooooooooooool000gooooo00Co
o`00ooooooooooooo`00:oooool00ol0003oooooooooo`0>ooooo`008?ooool3o`0002[ooooo00?o
o`00oooooooo00003_ooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000oooooo00?o
o`00oooooooo0000@_ooool00ooo003oooooool00007ooooo`03o`000?oooooooooo00Cooooo00Co
o`00ooooooooooooo`00@_ooool00ooo003oooooool0000>ooooo`03ool00?ooooooo`0004;ooooo
00Coo`00ooooooooooooo`003Oooool01?oo003ooooooooooooo000Yooooo`?o00004?ooool0023o
oooo00?o0000ooooooooool0:_ooool00ooo003oooooool0000>ooooo`03ool00?ooooooo`0004;o
oooo00?oo`00oooooooo00003oooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000Oo
oooo00?o0000ooooooooool01?ooool01?oo003ooooooooooooo0012ooooo`03ool00?ooooooo`00
00kooooo00?oo`00oooooooo0000@_ooool01?oo003ooooooooooooo000=ooooo`04ool00?oooooo
ooooool002_ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0:_ooool0
0ooo003oooooool0000>ooooo`03ool00?ooooooo`0004;ooooo00?oo`00oooooooo00003oooool0
0ooo003oooooool00012ooooo`03ool00?ooooooo`0000Oooooo00?o0000ooooooooool01?ooool0
1?oo003ooooooooooooo0012ooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000@_oo
ool01?oo003ooooooooooooo000=ooooo`04ool00?ooooooooooool002_ooooo00?o0000oooooooo
ool03_ooool0023ooooo00?o0000ooooooooool0:_ooool00ooo003oooooool0000>ooooo`03ool0
0?ooooooo`0004;ooooo00?oo`00oooooooo00003oooool00ooo003oooooool00012ooooo`03ool0
0?ooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ooo003oooooool00012ooooo`03ool0
0?ooooooo`0000kooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool0000>ooooo`04ool0
0?ooooooooooool002_ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0
:_ooool00ooo003oooooool0000>ooooo`03ool00?ooooooo`0004;ooooo00?oo`00oooooooo0000
3oooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000Oooooo00?o0000ooooooooool0
1Oooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000
@_ooool00ooo003oooooool0000>ooooo`04ool00?ooooooooooool002_ooooo00?o0000oooooooo
ool03_ooool0023ooooo00?o0000ooooooooool0:_ooool00ooo003oooooool0000>ooooo`03ool0
0?ooooooo`0004;ooooo00?oo`00oooooooo00003oooool00ooo003oooooool00012ooooo`03ool0
0?ooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ooo003oooooool00012ooooo`03ool0
0?ooooooo`0000kooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool0000>ooooo`04ool0
0?ooooooooooool002_ooooo00?o0000ooooooooool03_ooool0023ooooo0ol0000Zooooo`03ool0
0?ooooooo`0000kooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool0000?ooooo`03ool0
0?ooooooo`0004;ooooo00?oo`00oooooooo00001oooool00ol0003oooooooooo`05ooooo`03ool0
0?ooooooo`0004;ooooo00?oo`00oooooooo00003_ooool00ooo003oooooool00012ooooo`03ool0
0?ooooooo`0000kooooo00Coo`00ooooooooooooo`00:Oooool3o`00013ooooo000Pooooo`03o`00
0?oooooooooo02[ooooo00?oo`00oooooooo00003_ooool00ooo003oooooool00012ooooo`03ool0
0?ooooooo`0000oooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool00007ooooo`03o`00
0?oooooooooo00Gooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool0000>ooooo`03ool0
0?ooooooo`0004;ooooo00?oo`00oooooooo00003_ooool01?oo003ooooooooooooo000[ooooo`03
o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo0000
3_ooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000oooooo00?oo`00oooooooo0000
@_ooool00ooo003oooooool00007ooooo`03o`000?oooooooooo00Gooooo00?oo`00oooooooo0000
@_ooool00ooo003oooooool0000>ooooo`03ool00?ooooooo`0004;ooooo00?oo`00oooooooo0000
3_ooool01?oo003ooooooooooooo000[ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`00
0?oooooooooo02[ooooo00?oo`00oooooooo00003_ooool00ooo003oooooool00013ooooo`;oo`00
3oooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000Oooooo00?o0000ooooooooool0
1Oooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000
@_ooool00ooo003oooooool0000>ooooo`04ool00?ooooooooooool002_ooooo00?o0000oooooooo
ool03_ooool0023ooooo00?o0000ooooooooool0:_ooool00ooo003oooooool0000>ooooo`03ool0
0?ooooooo`0004?ooooo0_oo000?ooooo`03ool00?ooooooo`0004;ooooo00?oo`00oooooooo0000
1oooool00ol0003oooooooooo`05ooooo`;oo`00@oooool00ooo003oooooool0000>ooooo`03ool0
0?ooooooo`0004;ooooo00?oo`00oooooooo00003_ooool01?oo003ooooooooooooo000[ooooo`03
o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo0000
3_ooool00ooo003oooooool00013ooooo`;oo`003oooool00ooo003oooooool00012ooooo`03ool0
0?ooooooo`0000Oooooo00?o0000ooooooooool01Oooool2ool004?ooooo00?oo`00oooooooo0000
3_ooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000kooooo00Coo`00oooooooooooo
o`00:oooool00ol0003oooooooooo`0>ooooo`008?ooool3o`0002[ooooo00?oo`00oooooooo0000
3_ooool00ooo003oooooool00013ooooo`;oo`003oooool00ooo003oooooool00012ooooo`03ool0
0?ooooooo`0000Oooooo00?o0000ooooooooool01Oooool2ool004?ooooo00?oo`00oooooooo0000
3_ooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000kooooo00Coo`00oooooooooooo
o`00:Oooool3o`00013ooooo000Pooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo0000
3_ooool00ooo003oooooool00013ooooo`;oo`003oooool00ooo003oooooool00012ooooo`03ool0
0?ooooooo`0000Oooooo00?o0000ooooooooool01Oooool2ool004?ooooo00?oo`00oooooooo0000
3_ooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000kooooo00Coo`00oooooooooooo
o`00:oooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`0Zooooo`03ool0
0?ooooooo`0000kooooo00?oo`00oooooooo0000@oooool2ool000oooooo00?oo`00oooooooo0000
@_ooool00ooo003oooooool00007ooooo`03o`000?oooooooooo00Gooooo0_oo0013ooooo`03ool0
0?ooooooo`0000kooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool0000>ooooo`04ool0
0?ooooooooooool002_ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0
:_ooool00ooo003oooooool0000>ooooo`03ool00?ooooooo`0004?ooooo0_oo000?ooooo`03ool0
0?ooooooo`0004;ooooo00?oo`00oooooooo00001oooool00ol0003oooooooooo`05ooooo`;oo`00
@oooool00ooo003oooooool0000>ooooo`03ool00?ooooooo`0004;ooooo00?oo`00oooooooo0000
3_ooool01?oo003ooooooooooooo000[ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`00
0?oooooooooo02[ooooo00?oo`00oooooooo00003_ooool00ooo003oooooool00013ooooo`;oo`00
3oooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000Oooooo00?o0000ooooooooool0
1Oooool2ool004?ooooo00?oo`00oooooooo00003_ooool00ooo003oooooool00012ooooo`03ool0
0?ooooooo`0000kooooo00Coo`00ooooooooooooo`00:oooool00ol0003oooooooooo`0>ooooo`00
8?ooool00ol0003oooooooooo`0Zooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000
@oooool2ool000oooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool00007ooooo`03o`00
0?oooooooooo00Gooooo0_oo0013ooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000
@oooool2ool000oooooo00?oo`00oooooooo0000:oooool00ol0003oooooooooo`0>ooooo`008?oo
ool3o`0002[ooooo00?oo`00oooooooo00003_ooool00ooo003oooooool00013ooooo`;oo`003ooo
ool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000Oooooo00?o0000ooooooooool01Ooo
ool2ool004?ooooo00?oo`00oooooooo00003_ooool00ooo003oooooool00013ooooo`;oo`003ooo
ool00ooo003oooooool0000Yooooo`?o00004?ooool0023ooooo00?o0000ooooooooool0:_ooool0
0ooo003oooooool0000>ooooo`03ool00?ooooooo`0004?ooooo0_oo000?ooooo`03ool00?oooooo
o`0004;ooooo00?oo`00oooooooo00001oooool00ol0003oooooooooo`05ooooo`;oo`00@oooool0
0ooo003oooooool0000>ooooo`03ool00?ooooooo`0004?ooooo0_oo000?ooooo`03ool00?oooooo
o`0002_ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0:_ooool00ooo
003oooooool0000>ooooo`03ool00?ooooooo`0004?ooooo0_oo000?ooooo`03ool00?ooooooo`00
04;ooooo00?oo`00oooooooo00001oooool00ol0003oooooooooo`05ooooo`;oo`00@oooool00ooo
003oooooool0000>ooooo`03ool00?ooooooo`0004?ooooo0_oo000?ooooo`03ool00?ooooooo`00
02_ooooo00?o0000ooooooooool03_ooool0013ooooo0ol00003ooooo`?o00001oooool00ol0003o
ooooooooo`0Zooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000@oooool2ool000oo
oooo00?oo`00oooooooo0000@_ooool00ooo003oooooool00007ooooo`03o`000?oooooooooo00Go
oooo0_oo0013ooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000@oooool2ool000oo
oooo00?oo`00oooooooo0000:oooool00ol0003oooooooooo`0>ooooo`004Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`03
ool00?ooooooo`0000kooooo00?oo`00oooooooo0000@oooool2ool000oooooo00?oo`00oooooooo
0000@_ooool00ooo003oooooool00007ooooo`03o`000?oooooooooo00Gooooo0_oo0013ooooo`03
ool00?ooooooo`0000kooooo00?oo`00oooooooo0000@oooool2ool000oooooo00?oo`00oooooooo
0000:oooool00ol0003oooooooooo`0>ooooo`004Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo1?l0000Yooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000
@oooool2ool000oooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool00007ooooo`03o`00
0?oooooooooo00Gooooo0_oo0013ooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000
@oooool2ool000oooooo00?oo`00oooooooo0000:?ooool4o`00013ooooo000Aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`03ool00?oo
ooooo`0000kooooo00?oo`00oooooooo0000@oooool2ool000oooooo00?oo`00oooooooo0000@_oo
ool00ooo003oooooool00007ooooo`03o`000?oooooooooo00Gooooo0_oo0013ooooo`;oo`003ooo
ool00ooo003oooooool00013ooooo`;oo`003oooool00ooo003oooooool0000[ooooo`03o`000?oo
oooooooo00kooooo000Aooooo`04o`000?ooooooooooooooo`Co00001oooool00ol0003ooooooooo
o`0Zooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000@oooool2ool000oooooo00?o
o`00oooooooo0000@_ooool00ooo003oooooool00007ooooo`03o`000?oooooooooo00Gooooo0_oo
0013ooooo`;oo`003oooool00ooo003oooooool00013ooooo`;oo`003oooool00ooo003oooooool0
000[ooooo`03o`000?oooooooooo00kooooo000@ooooo`;o00000oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo00003_ooool00ooo003oooooool00013
ooooo`;oo`003oooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000Oooooo00?o0000
ooooooooool01Oooool2ool004?ooooo0_oo000?ooooo`03ool00?ooooooo`0004?ooooo0_oo000?
ooooo`03ool00?ooooooo`0002_ooooo00?o0000ooooooooool03_ooool0017ooooo00Co0000oooo
oooooooooooo1Ol00006ooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo00003_ooool0
0ooo003oooooool00013ooooo`;oo`003oooool00ooo003oooooool00012ooooo`03ool00?oooooo
o`0000Oooooo00?o0000ooooooooool01Oooool2ool004?ooooo0_oo000?ooooo`03ool00?oooooo
o`0004?ooooo0_oo000?ooooo`03ool00?ooooooo`0002_ooooo00?o0000ooooooooool03_ooool0
023ooooo00?o0000ooooooooool0:_ooool00ooo003oooooool0000>ooooo`03ool00?ooooooo`00
04?ooooo0_oo000?ooooo`03ool00?ooooooo`0004;ooooo00?oo`00oooooooo00001oooool00ol0
003oooooooooo`05ooooo`;oo`00@oooool2ool000oooooo00?oo`00oooooooo0000@oooool2ool0
00oooooo00?oo`00oooooooo0000:oooool00ol0003oooooooooo`0>ooooo`008?ooool3o`0002[o
oooo00?oo`00oooooooo00003_ooool00ooo003oooooool00013ooooo`;oo`003oooool00ooo003o
ooooool00012ooooo`03ool00?ooooooo`0000Oooooo00?o0000ooooooooool01Oooool2ool004?o
oooo0_oo000?ooooo`03ool00?ooooooo`0004?ooooo0_oo000?ooooo`03ool00?ooooooo`0002Wo
oooo0ol0000@ooooo`008?ooool00ol0003oooooooooo`0Zooooo`03ool00?ooooooo`0000kooooo
00?oo`00oooooooo0000@oooool2ool000oooooo00?oo`00oooooooo0000@_ooool00ooo003ooooo
ool00007ooooo`03o`000?oooooooooo00Gooooo0_oo0013ooooo`;oo`003oooool00ooo003ooooo
ool00013ooooo`;oo`003oooool00ooo003oooooool0000[ooooo`03o`000?oooooooooo00kooooo
000Pooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo00003_ooool00ooo003oooooool0
0013ooooo`;oo`003oooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000Oooooo00?o
0000ooooooooool01Oooool2ool004?ooooo0_oo000?ooooo`03ool00?ooooooo`0004?ooooo0_oo
000?ooooo`03ool00?ooooooo`0002_ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000
ooooooooool0:_ooool00ooo003oooooool0000>ooooo`03ool00?ooooooo`0004?ooooo0_oo000?
ooooo`03ool00?ooooooo`0004;ooooo00?oo`00oooooooo00001oooool00ol0003oooooooooo`05
ooooo`;oo`00@oooool2ool000oooooo00?oo`00oooooooo0000@oooool2ool000oooooo00?oo`00
oooooooo0000:oooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`0Zoooo
o`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000@oooool2ool000oooooo00?oo`00oooo
oooo0000@_ooool00ooo003oooooool00007ooooo`03o`000?oooooooooo00Gooooo0_oo0013oooo
o`;oo`003oooool00ooo003oooooool00013ooooo`;oo`003oooool00ooo003oooooool0000[oooo
o`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo
00003_ooool00ooo003oooooool00013ooooo`;oo`003oooool00ooo003oooooool00012ooooo`03
ool00?ooooooo`0000Oooooo00?o0000ooooooooool01Oooool2ool004?ooooo0_oo000?ooooo`03
ool00?ooooooo`0004?ooooo0_oo000?ooooo`03ool00?ooooooo`0002_ooooo00?o0000oooooooo
ool03_ooool0023ooooo0ol0000Zooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000
@oooool2ool000oooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool00007ooooo`03o`00
0?oooooooooo00Gooooo0_oo0013ooooo`;oo`003oooool00ooo003oooooool00013ooooo`;oo`00
3oooool00ooo003oooooool0000Yooooo`?o00004?ooool0023ooooo00?o0000ooooooooool0:_oo
ool00ooo003oooooool0000>ooooo`03ool00?ooooooo`0004?ooooo0_oo000?ooooo`03ool00?oo
ooooo`0004;ooooo00?oo`00oooooooo00001oooool00ol0003oooooooooo`05ooooo`;oo`00@ooo
ool2ool000oooooo00?oo`00oooooooo0000@oooool2ool000oooooo00?oo`00oooooooo0000:ooo
ool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`0Zooooo`03ool00?oooooo
o`0000kooooo00?oo`00oooooooo0000@oooool2ool000oooooo00?oo`00oooooooo0000@_ooool0
0ooo003oooooool00007ooooo`03o`000?oooooooooo00Gooooo0_oo0013ooooo`;oo`003oooool0
0ooo003oooooool00013ooooo`;oo`003oooool00ooo003oooooool0000[ooooo`03o`000?oooooo
oooo00kooooo000Pooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo00003_ooool00ooo
003oooooool00013ooooo`;oo`003oooool00ooo003oooooool00012ooooo`03ool00?ooooooo`00
00Oooooo00?o0000ooooooooool01Oooool2ool004?ooooo0_oo000?ooooo`03ool00?ooooooo`00
04?ooooo0_oo000?ooooo`03ool00?ooooooo`0002_ooooo00?o0000ooooooooool03_ooool0023o
oooo00?o0000ooooooooool0:_ooool00ooo003oooooool0000>ooooo`03ool00?ooooooo`0004?o
oooo0_oo000?ooooo`03ool00?ooooooo`0004;ooooo00?oo`00oooooooo00001oooool00ol0003o
ooooooooo`05ooooo`;oo`00@oooool2ool000oooooo00?oo`00oooooooo0000@oooool2ool000oo
oooo00?oo`00oooooooo0000:oooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003ooooo
ooooo`0Zooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000@oooool2ool000oooooo
00?oo`00oooooooo0000@_ooool00ooo003oooooool00007ooooo`03o`000?oooooooooo00Gooooo
0_oo0013ooooo`;oo`003oooool00ooo003oooooool00013ooooo`;oo`003oooool00ooo003ooooo
ool0000[ooooo`03o`000?oooooooooo00kooooo000Pooooo`?o0000:_ooool00ooo003oooooool0
000>ooooo`03ool00?ooooooo`0004?ooooo0_oo000?ooooo`03ool00?ooooooo`0004;ooooo00?o
o`00oooooooo00001oooool00ol0003oooooooooo`05ooooo`;oo`00@oooool2ool000oooooo00?o
o`00oooooooo0000@oooool2ool000oooooo00?oo`00oooooooo0000:Oooool3o`00013ooooo000P
ooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo00003_ooool00ooo003oooooool00013
ooooo`;oo`003oooool00ooo003oooooool00012ooooo`03ool00?ooooooo`0000Oooooo00?o0000
ooooooooool01Oooool2ool004?ooooo0_oo000?ooooo`03ool00?ooooooo`0004?ooooo0_oo000?
ooooo`03ool00?ooooooo`0002_ooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooo
ooooool0:_ooool00ooo003oooooool0000>ooooo`03ool00?ooooooo`0004?ooooo0_oo000?oooo
o`03ool00?ooooooo`0004;ooooo00?oo`00oooooooo00001oooool00ol0003oooooooooo`05oooo
o`;oo`00@oooool2ool000oooooo00?oo`00oooooooo0000@oooool2ool000oooooo0_oo000/oooo
o`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo
00003_ooool00ooo003oooooool00013ooooo`;oo`003oooool00ooo003oooooool00012ooooo`03
ool00?ooooooo`0000Oooooo00?o0000ooooooooool01Oooool2ool004?ooooo0_oo000?ooooo`03
ool00?ooooooo`0004?ooooo0_oo000?ooooo`;oo`00;?ooool00ol0003oooooooooo`0>ooooo`00
8?ooool00ol0003oooooooooo`0Zooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000
@oooool2ool000oooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool00007ooooo`03o`00
0?oooooooooo00Gooooo0_oo0013ooooo`;oo`003oooool00ooo003oooooool00013ooooo`;oo`00
3oooool2ool002cooooo00?o0000ooooooooool03_ooool0023ooooo0ol0000Zooooo`03ool00?oo
ooooo`0000kooooo00?oo`00oooooooo0000@oooool2ool000oooooo00?oo`00oooooooo0000@_oo
ool00ooo003oooooool00007ooooo`03o`000?oooooooooo00Gooooo0_oo0013ooooo`;oo`003ooo
ool00ooo003oooooool00013ooooo`;oo`003oooool2ool002[ooooo0ol0000@ooooo`008?ooool0
0ol0003oooooooooo`0Zooooo`03ool00?ooooooo`0000kooooo00?oo`00oooooooo0000@oooool2
ool000oooooo00?oo`00oooooooo0000@_ooool00ooo003oooooool00007ooooo`03o`000?oooooo
oooo00Gooooo0_oo0013ooooo`;oo`003oooool00ooo003oooooool00013ooooo`;oo`003oooool2
ool002cooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0:_ooool00ooo
003oooooool0000>ooooo`03ool00?ooooooo`0004?ooooo0_oo000?ooooo`03ool00?ooooooo`00
04;ooooo00?oo`00oooooooo00001oooool00ol0003oooooooooo`05ooooo`;oo`00@oooool2ool0
00oooooo00?oo`00oooooooo0000@oooool2ool000oooooo0_oo000/ooooo`03o`000?oooooooooo
00kooooo000Pooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo00003_ooool00ooo003o
ooooool00013ooooo`;oo`003oooool2ool004?ooooo00?oo`00oooooooo00001oooool00ol0003o
ooooooooo`05ooooo`;oo`00@oooool2ool000oooooo00?oo`00oooooooo0000@oooool2ool000oo
oooo0_oo000/ooooo`03o`000?oooooooooo00kooooo000?ooooo`Go00000oooool2o`0000Oooooo
00?o0000ooooooooool0:_ooool00ooo003oooooool0000>ooooo`03ool00?ooooooo`0004?ooooo
0_oo000?ooooo`;oo`00@oooool00ooo003oooooool00007ooooo`03o`000?oooooooooo00Gooooo
0_oo0013ooooo`;oo`003oooool00ooo003oooooool00013ooooo`;oo`003oooool2ool002cooooo
00?o0000ooooooooool03_ooool0013ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo02[ooooo00?oo`00oooooooo00003oooool2ool004?o
oooo0_oo000?ooooo`;oo`00@oooool00ooo003oooooool00007ooooo`03o`000?oooooooooo00Go
oooo0_oo0013ooooo`;oo`003oooool00ooo003oooooool00013ooooo`;oo`003oooool2ool002co
oooo00?o0000ooooooooool03_ooool0017ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00006ooooo`Co0000:Oooool00ooo003oooooool0000?ooooo`;oo`00@oooool2ool000oo
oooo0_oo0013ooooo`03ool00?ooooooo`0000Oooooo00?o0000ooooooooool01Oooool2ool004?o
oooo0_oo000?ooooo`03ool00?ooooooo`0004?ooooo0_oo000?ooooo`;oo`00:Oooool4o`00013o
oooo000Booooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02[ooooo0_oo000@ooooo`;oo`00@oooool2ool000oooooo0_oo0014ooooo`;o
o`001oooool00ol0003oooooooooo`05ooooo`;oo`00@oooool2ool000oooooo00?oo`00oooooooo
0000@oooool2ool000oooooo0_oo000/ooooo`03o`000?oooooooooo00kooooo000?ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo
02[ooooo0_oo000@ooooo`;oo`00@oooool2ool000oooooo0_oo0014ooooo`;oo`001oooool00ol0
003oooooooooo`05ooooo`;oo`00@oooool2ool000oooooo00?oo`00oooooooo0000@oooool2ool0
00oooooo0_oo000/ooooo`03o`000?oooooooooo00kooooo000?ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02[ooooo0_oo000@
ooooo`;oo`00@oooool2ool000oooooo0_oo0014ooooo`;oo`001oooool00ol0003oooooooooo`05
ooooo`;oo`00@oooool2ool000oooooo00?oo`00oooooooo0000@oooool2ool000oooooo0_oo000/
ooooo`03o`000?oooooooooo00kooooo000@ooooo`?o00001?ooool2o`0000Oooooo00?o0000oooo
ooooool0:_ooool2ool0013ooooo0_oo0013ooooo`;oo`003oooool2ool004Cooooo0_oo0007oooo
o`03o`000?oooooooooo00Gooooo0_oo0013ooooo`;oo`003oooool00ooo003oooooool00013oooo
o`;oo`003oooool2ool002cooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooooooo
ool0:_ooool2ool0013ooooo0_oo0013ooooo`;oo`003oooool2ool004Cooooo0_oo0007ooooo`03
o`000?oooooooooo00Gooooo0_oo0013ooooo`;oo`003oooool00ooo003oooooool00013ooooo`;o
o`003oooool2ool002cooooo00?o0000ooooooooool03_ooool0023ooooo0ol0000Zooooo`;oo`00
4?ooool2ool004?ooooo0_oo000?ooooo`;oo`00A?ooool2ool000Oooooo00?o0000ooooooooool0
1Oooool2ool004?ooooo0_oo000@ooooo`;oo`00@oooool2ool000oooooo0_oo000Zooooo`?o0000
4?ooool0023ooooo00?o0000ooooooooool0:_ooool2ool0013ooooo0_oo0013ooooo`;oo`003ooo
ool2ool004Cooooo0_oo0007ooooo`03o`000?oooooooooo00Gooooo0_oo0013ooooo`;oo`004?oo
ool2ool004?ooooo0_oo000?ooooo`;oo`00;?ooool00ol0003oooooooooo`0>ooooo`008?ooool0
0ol0003oooooooooo`0Zooooo`;oo`004?ooool2ool004?ooooo0_oo000?ooooo`;oo`00A?ooool2
ool000Oooooo00?o0000ooooooooool01Oooool2ool004?ooooo0_oo000@ooooo`;oo`00@oooool2
ool000oooooo0_oo000/ooooo`03o`000?oooooooooo00kooooo000Pooooo`03o`000?oooooooooo
02[ooooo0_oo000@ooooo`;oo`00@oooool2ool000oooooo0_oo0014ooooo`;oo`001oooool00ol0
003oooooooooo`05ooooo`;oo`00@oooool2ool0013ooooo0_oo0013ooooo`;oo`003oooool2ool0
02cooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0:_ooool2ool0013o
oooo0_oo0013ooooo`;oo`003oooool2ool004Cooooo0_oo0007ooooo`03o`000?oooooooooo00Go
oooo0_oo0013ooooo`;oo`004?ooool2ool004?ooooo0_oo000?ooooo`;oo`00;?ooool00ol0003o
ooooooooo`0>ooooo`008?ooool00ol0003oooooooooo`0Zooooo`;oo`004?ooool2ool004?ooooo
0_oo000?ooooo`;oo`00A?ooool2ool000Oooooo00?o0000ooooooooool01Oooool2ool004?ooooo
0_oo000@ooooo`;oo`00@oooool2ool000oooooo0_oo000/ooooo`03o`000?oooooooooo00kooooo
000Pooooo`?o0000:_ooool2ool0013ooooo0_oo0013ooooo`;oo`003oooool2ool004Cooooo0_oo
0007ooooo`03o`000?oooooooooo00Gooooo0_oo0013ooooo`;oo`004?ooool2ool004?ooooo0_oo
000?ooooo`;oo`00:_ooool3o`00013ooooo000Pooooo`03o`000?oooooooooo02[ooooo0_oo000@
ooooo`;oo`00@oooool2ool000oooooo0_oo0014ooooo`;oo`001oooool00ol0003oooooooooo`05
ooooo`;oo`00@oooool2ool0013ooooo0_oo0013ooooo`;oo`003oooool2ool002cooooo00?o0000
ooooooooool03_ooool0023ooooo00?o0000ooooooooool0:_ooool2ool0013ooooo0_oo0013oooo
o`;oo`003oooool2ool004Cooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`;oo`00@oooool2ool0013ooooo0_oo0013ooooo`;oo`003oooool2ool002cooooo00?o0000oooo
ooooool03_ooool0023ooooo00?o0000ooooooooool0:_ooool2ool0013ooooo0_oo0013ooooo`;o
o`003oooool2ool004Cooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o
o`00@oooool2ool0013ooooo0_oo0013ooooo`;oo`003oooool2ool002cooooo00?o0000oooooooo
ool03_ooool0023ooooo00?o0000ooooooooool0:_ooool2ool0013ooooo0_oo0013ooooo`;oo`00
3oooool2ool004Cooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;oo`00
@oooool2ool0013ooooo0_oo0013ooooo`;oo`003oooool2ool002cooooo00?o0000ooooooooool0
3_ooool0023ooooo0ol0000Zooooo`;oo`004?ooool2ool004?ooooo0_oo000?ooooo`;oo`00A?oo
ool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_oo0013ooooo`;oo`004?oo
ool00ooo003oooooooooo`12ooooo`;oo`003oooool2ool002[ooooo0ol0000@ooooo`008?ooool0
0ol0003oooooooooo`0Zooooo`;oo`004?ooool2ool004?ooooo0_oo000?ooooo`;oo`00A?ooool0
0ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_oo0013ooooo`;oo`004?ooool0
0ooo003oooooooooo`12ooooo`;oo`003oooool2ool002cooooo00?o0000ooooooooool03_ooool0
023ooooo00?o0000ooooooooool0:_ooool2ool0013ooooo0_oo0013ooooo`;oo`003oooool2ool0
04Cooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;oo`00@oooool2ool0
013ooooo00?oo`00ooooooooool0@_ooool2ool000oooooo0_oo000/ooooo`03o`000?oooooooooo
00kooooo000Pooooo`03o`000?oooooooooo02[ooooo0_oo000@ooooo`;oo`00@oooool2ool0013o
oooo00?oo`00ooooooooool0@_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo0_oo0013ooooo`;oo`004?ooool00ooo003oooooooooo`12ooooo`;oo`003oooool2ool002co
oooo00?o0000ooooooooool03_ooool0023ooooo00?o0000ooooooooool0:_ooool2ool0013ooooo
0_oo0013ooooo`;oo`004?ooool00ooo003oooooooooo`12ooooo`03ool00?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool2ool004?ooooo0_oo000@ooooo`03ool00?oooooooooo04;ooooo
0_oo000?ooooo`;oo`00;?ooool00ol0003oooooooooo`0>ooooo`008?ooool00ol0003ooooooooo
o`0[ooooo`03ool00?oooooooooo00kooooo0_oo0013ooooo`;oo`004?ooool00ooo003ooooooooo
o`12ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2ool004?ooooo0_oo
000@ooooo`03ool00?oooooooooo04;ooooo0_oo000?ooooo`;oo`00;?ooool00ol0003ooooooooo
o`0>ooooo`008?ooool3o`0002_ooooo00?oo`00ooooooooool03_ooool2ool004?ooooo0_oo000@
ooooo`03ool00?oooooooooo04;ooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`;oo`00@oooool2ool0013ooooo00?oo`00ooooooooool0@_ooool2ool000oooooo0_oo000Z
ooooo`?o00004?ooool0023ooooo00?o0000ooooooooool0:oooool00ooo003oooooooooo`0>oooo
o`;oo`00@oooool2ool0013ooooo00?oo`00ooooooooool0@_ooool00ooo003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo0_oo0013ooooo`;oo`004?ooool00ooo003oooooooooo`12oooo
o`;oo`003oooool2ool002cooooo00?o0000ooooooooool03_ooool0023ooooo00?o0000oooooooo
ool0:oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo04;ooooo0_oo000@ooooo`03
ool00?oooooooooo04;ooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o
o`00@oooool2ool0013ooooo00?oo`00ooooooooool0@_ooool2ool000oooooo0_oo000/ooooo`03
o`000?oooooooooo00kooooo000?ooooo`Go00000_ooool3o`0000Oooooo00?o0000ooooooooool0
:oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo04;ooooo0_oo000@ooooo`03ool0
0?oooooooooo04;ooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;oo`00
A?ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo04;ooooo0_oo000@ooooo`03ool0
0?oooooooooo02[ooooo00?o0000ooooooooool03_ooool0013ooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:oooool00ooo003o
ooooooooo`0>ooooo`03ool00?oooooooooo04;ooooo0_oo000@ooooo`03ool00?oooooooooo04;o
oooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;oo`00A?ooool00ooo003o
ooooooooo`0>ooooo`03ool00?oooooooooo04;ooooo00?oo`00ooooooooool03oooool00ooo003o
ooooooooo`0Zooooo`03o`000?oooooooooo00kooooo000Aooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`03ool00?oooooooooo00kooooo
00?oo`00ooooooooool0@_ooool2ool0013ooooo00?oo`00ooooooooool0@_ooool00ooo003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo0_oo0014ooooo`03ool00?oooooooooo00kooooo
00?oo`00ooooooooool0@_ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo02[ooooo
00?o0000ooooooooool03_ooool001;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`Co0000:_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo04;ooooo0_oo
000@ooooo`03ool00?oooooooooo04;ooooo00?oo`00ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`;oo`00A?ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo04;ooooo00?o
o`00ooooooooool03oooool00ooo003oooooooooo`0Wooooo`Co00004?ooool000oooooo00Ko0000
ooooooooooooooooo`000?ooool4o`0000Oooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0Doooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03_ooool000oooooo00Oo
0000ooooooooooooooooo`000?oooooo000000[ooooo00Co0000oooooooooooo00004?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooo0000013ooooo000@ooooo`?o00000_ooool5o`0000Ko
oooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo0000
013ooooo000Poooooooo0000bOl0000@ooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-30.0484, -3.17161, 0.115447, \
0.173365}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example #1b: 1Hz cosine (finite length, continuous-time)", "Subsection"],

Cell[CellGroupData[{

Cell["Length =  5 seconds", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := Cos[2  \[Pi]\ t]\ \((u[t]\  - \ u[t - 5])\);\)\), "\n", 
    \(\(Plot[x[t], \ {t, \ \(-1\), 6}, \ PlotStyle \[Rule] Blue, \ 
        ImageSize \[Rule] 504, \ AspectRatio \[Rule] 1/3, \ 
        Axes \[Rule] False];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.159864 0.136054 0.166667 0.15873 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.15986 -0.0125 -3 -9 ]
[.15986 -0.0125 3 0 ]
[.29592 -0.0125 -3 -9 ]
[.29592 -0.0125 3 0 ]
[.43197 -0.0125 -3 -9 ]
[.43197 -0.0125 3 0 ]
[.56803 -0.0125 -3 -9 ]
[.56803 -0.0125 3 0 ]
[.70408 -0.0125 -3 -9 ]
[.70408 -0.0125 3 0 ]
[.84014 -0.0125 -3 -9 ]
[.84014 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -12 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .0873 -24 -4.5 ]
[-0.0125 .0873 0 4.5 ]
[-0.0125 .16667 -6 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .24603 -18 -4.5 ]
[-0.0125 .24603 0 4.5 ]
[-0.0125 .3254 -6 -4.5 ]
[-0.0125 .3254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-1)] .02381 -0.0125 0 1 Mshowa
.15986 0 m
.15986 .00625 L
s
[(0)] .15986 -0.0125 0 1 Mshowa
.29592 0 m
.29592 .00625 L
s
[(1)] .29592 -0.0125 0 1 Mshowa
.43197 0 m
.43197 .00625 L
s
[(2)] .43197 -0.0125 0 1 Mshowa
.56803 0 m
.56803 .00625 L
s
[(3)] .56803 -0.0125 0 1 Mshowa
.70408 0 m
.70408 .00625 L
s
[(4)] .70408 -0.0125 0 1 Mshowa
.84014 0 m
.84014 .00625 L
s
[(5)] .84014 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(6)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05102 0 m
.05102 .00375 L
s
.07823 0 m
.07823 .00375 L
s
.10544 0 m
.10544 .00375 L
s
.13265 0 m
.13265 .00375 L
s
.18707 0 m
.18707 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2415 0 m
.2415 .00375 L
s
.26871 0 m
.26871 .00375 L
s
.32313 0 m
.32313 .00375 L
s
.35034 0 m
.35034 .00375 L
s
.37755 0 m
.37755 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45918 0 m
.45918 .00375 L
s
.48639 0 m
.48639 .00375 L
s
.51361 0 m
.51361 .00375 L
s
.54082 0 m
.54082 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62245 0 m
.62245 .00375 L
s
.64966 0 m
.64966 .00375 L
s
.67687 0 m
.67687 .00375 L
s
.73129 0 m
.73129 .00375 L
s
.7585 0 m
.7585 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81293 0 m
.81293 .00375 L
s
.86735 0 m
.86735 .00375 L
s
.89456 0 m
.89456 .00375 L
s
.92177 0 m
.92177 .00375 L
s
.94898 0 m
.94898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(-1)] -0.0125 .00794 1 0 Mshowa
0 .0873 m
.00625 .0873 L
s
[(-0.5)] -0.0125 .0873 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(0)] -0.0125 .16667 1 0 Mshowa
0 .24603 m
.00625 .24603 L
s
[(0.5)] -0.0125 .24603 1 0 Mshowa
0 .3254 m
.00625 .3254 L
s
[(1)] -0.0125 .3254 1 0 Mshowa
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .07143 m
.00375 .07143 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .13492 m
.00375 .13492 L
s
0 .15079 m
.00375 .15079 L
s
0 .18254 m
.00375 .18254 L
s
0 .19841 m
.00375 .19841 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .2619 m
.00375 .2619 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.15986 .32708 m
.15986 .33333 L
s
.29592 .32708 m
.29592 .33333 L
s
.43197 .32708 m
.43197 .33333 L
s
.56803 .32708 m
.56803 .33333 L
s
.70408 .32708 m
.70408 .33333 L
s
.84014 .32708 m
.84014 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.05102 .32958 m
.05102 .33333 L
s
.07823 .32958 m
.07823 .33333 L
s
.10544 .32958 m
.10544 .33333 L
s
.13265 .32958 m
.13265 .33333 L
s
.18707 .32958 m
.18707 .33333 L
s
.21429 .32958 m
.21429 .33333 L
s
.2415 .32958 m
.2415 .33333 L
s
.26871 .32958 m
.26871 .33333 L
s
.32313 .32958 m
.32313 .33333 L
s
.35034 .32958 m
.35034 .33333 L
s
.37755 .32958 m
.37755 .33333 L
s
.40476 .32958 m
.40476 .33333 L
s
.45918 .32958 m
.45918 .33333 L
s
.48639 .32958 m
.48639 .33333 L
s
.51361 .32958 m
.51361 .33333 L
s
.54082 .32958 m
.54082 .33333 L
s
.59524 .32958 m
.59524 .33333 L
s
.62245 .32958 m
.62245 .33333 L
s
.64966 .32958 m
.64966 .33333 L
s
.67687 .32958 m
.67687 .33333 L
s
.73129 .32958 m
.73129 .33333 L
s
.7585 .32958 m
.7585 .33333 L
s
.78571 .32958 m
.78571 .33333 L
s
.81293 .32958 m
.81293 .33333 L
s
.86735 .32958 m
.86735 .33333 L
s
.89456 .32958 m
.89456 .33333 L
s
.92177 .32958 m
.92177 .33333 L
s
.94898 .32958 m
.94898 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .07143 m
1 .07143 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .13492 m
1 .13492 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .19841 m
1 .19841 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .16667 m
.06244 .16667 L
.10458 .16667 L
.12507 .16667 L
.13506 .16667 L
.14415 .16667 L
.14868 .16667 L
.1536 .16667 L
.15586 .16667 L
.15709 .16667 L
.15825 .16667 L
.15923 .16667 L
.16029 .32537 L
.16146 .32496 L
.16254 .32419 L
.16375 .32285 L
.16504 .32089 L
.16736 .31598 L
.17012 .30792 L
.17262 .29863 L
.18221 .24813 L
.19236 .17782 L
.20308 .10125 L
.21223 .04768 L
.21474 .03634 L
.21742 .02612 L
.21996 .01846 L
.22227 .01325 L
.22341 .01132 L
.22466 .0097 L
.22597 .00856 L
.2272 .00802 L
.22834 .00797 L
.22939 .00832 L
.23054 .00913 L
.23176 .01046 L
.23299 .01232 L
.23431 .01486 L
.23668 .02084 L
.23951 .03023 L
.24207 .04077 L
.25172 .09472 L
.26083 .15876 L
.27055 .22835 L
.27586 .26205 L
.28084 .28844 L
.28507 .30591 L
.28745 .31342 L
.28963 .31874 L
.29086 .32108 L
Mistroke
.292 .3228 L
.29325 .32419 L
.29395 .32474 L
.29458 .3251 L
.29575 .32539 L
.29701 .3252 L
.2982 .32452 L
.29929 .32347 L
.30056 .32177 L
.30176 .31966 L
.30401 .31445 L
.30642 .30708 L
.30905 .29708 L
.31815 .24881 L
.32799 .18089 L
.33883 .10325 L
.34376 .07208 L
.34906 .044 L
.3515 .03345 L
.35406 .02419 L
.35625 .01785 L
.35864 .01267 L
.35933 .01153 L
.36007 .01048 L
.36072 .0097 L
.36141 .00902 L
.36271 .00819 L
.36392 .00794 L
.36458 .00801 L
.3653 .00825 L
.3666 .00912 L
.36739 .00994 L
.36814 .0109 L
.36954 .01321 L
.37206 .01895 L
.37439 .02604 L
.37967 .04796 L
.38429 .07298 L
.38928 .10471 L
.39831 .16921 L
.40814 .23856 L
.41334 .27016 L
.4162 .28511 L
.4189 .29734 L
.4215 .3072 L
.42433 .31561 L
.42557 .31852 L
.4269 .32105 L
.42802 .32276 L
.42926 .32416 L
Mistroke
.43052 .32504 L
.43167 .32538 L
.4323 .32538 L
.43299 .32522 L
.43425 .32452 L
.43542 .32339 L
.43667 .32168 L
.43892 .31731 L
.44165 .30979 L
.44461 .29911 L
.44998 .2736 L
.46001 .20994 L
.46945 .14138 L
.47957 .0735 L
.48538 .04277 L
.48813 .0312 L
.49067 .02244 L
.49322 .01565 L
.49456 .01291 L
.49599 .01065 L
.49723 .00924 L
.49839 .00838 L
.49966 .00796 L
.50037 .00796 L
.50103 .00812 L
.50224 .00878 L
.50333 .00981 L
.5046 .01151 L
.5058 .01359 L
.50792 .01844 L
.51023 .02531 L
.51546 .0467 L
.52028 .07261 L
.54054 .21377 L
.54959 .27127 L
.55467 .29616 L
.55708 .30555 L
.55932 .31272 L
.56194 .31916 L
.56332 .32166 L
.56403 .32269 L
.56479 .32363 L
.56552 .32434 L
.5662 .32483 L
.56752 .32535 L
.56872 .32532 L
.56998 .32475 L
.57117 .32372 L
.57245 .3221 L
.57365 .32007 L
Mistroke
.57474 .31782 L
.57743 .31068 L
.57996 .3019 L
.58457 .28128 L
.58965 .25262 L
.59993 .18215 L
.60938 .11392 L
.61836 .05803 L
.6232 .03507 L
.62595 .02492 L
.62849 .01752 L
.6297 .01472 L
.63084 .01251 L
.63188 .01087 L
.63298 .00954 L
.63417 .00853 L
.63528 .00804 L
.63646 .00796 L
.63776 .00843 L
.63843 .00889 L
.63916 .00957 L
.64049 .01125 L
.64178 .01345 L
.64297 .01597 L
.64568 .02336 L
.64856 .03367 L
.65335 .05592 L
.65864 .08672 L
.66885 .15773 L
.6796 .23431 L
.68404 .26212 L
.68878 .2874 L
.69151 .29938 L
.69399 .30846 L
.69648 .31571 L
.69769 .31854 L
.69883 .32075 L
.69999 .32258 L
.70106 .32385 L
.70224 .32483 L
.70352 .32534 L
.70473 .32532 L
.70542 .32509 L
.70606 .32473 L
.70723 .32372 L
.70848 .32213 L
.70964 .3202 L
.71089 .31762 L
.71315 .31167 L
.71738 .29638 L
Mistroke
.72248 .27144 L
.72787 .23888 L
.7375 .171 L
.747 .10321 L
.75223 .07028 L
.75717 .04423 L
.76177 .02568 L
.76437 .01797 L
.76561 .01503 L
.76677 .01273 L
.76782 .01103 L
.76879 .0098 L
.76986 .00879 L
.77101 .00814 L
.77206 .00794 L
.77321 .00814 L
.7744 .00883 L
.77552 .0099 L
.7768 .01164 L
.77815 .01407 L
.78058 .01992 L
.78319 .02827 L
.78606 .03975 L
.796 .09516 L
.8146 .22724 L
.81983 .26055 L
.82478 .28714 L
.82923 .30569 L
.83175 .31363 L
.83408 .31922 L
.83527 .32141 L
.83656 .32323 L
.83777 .32445 L
.83889 .32513 L
.84012 .3254 L
.84083 .16667 L
.84148 .16667 L
.84421 .16667 L
.85498 .16667 L
.89398 .16667 L
.93543 .16667 L
.97537 .16667 L
.97619 .16667 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00<_ooool3o`0003Wooooo0_l0000kooooo`?o0000>_ooool5o`0003[ooooo0ol0000koooo
o`?o0000>_ooool3o`0003_ooooo0ol0000Eooooo`00<oooool00ol0003oooooooooo`0gooooo`04
o`000?ooooooooooo`0003_ooooo00?o0000ooooooooool0>_ooool01?l0003oooooooooool0000i
ooooo`05o`000?ooooooooooooooool00000>oooool00ol0003oooooooooo`0hooooo`05o`000?oo
ooooooooooooool00000>Oooool01Ol0003ooooooooooooooooo000001Cooooo000[ooooo`Go0000
0oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03Kooooo1Ol0000mooooo`03
o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00000Dooooo`00<oooool00ol0003o
ooooooooo`0gooooo`04o`000?ooooooooooo`0003_ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0jooooo`;o0000>Oooool01?l0003oooooooooool0000nooooo`03o`000?oooooo
oooo03Oooooo1?l0000Eooooo`00<oooool00ol0003oooooooooo`0gooooo`04o`000?oooooooooo
o`0003_ooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo000003gooooo00?o
0000ooooooooool0=oooool00ol0003oooooo`00000jooooo`Co0000>_ooool00ol0003ooooooooo
o`0Fooooo`00<_ooool2o`0003Wooooo00Co0000oooooooooooo0000>_ooool2o`0003_ooooo00Go
0000ooooooooooooooooo`00000iooooo`05o`000?ooooooooooooooool00000>_ooool2o`0003[o
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Eooooo`00<oooool00ol0003ooooo
ooooo`0hooooo`;o0000??ooool00ol0003oooooooooo`0jooooo`?o0000>oooool3o`0003cooooo
00?o0000ooooooooool0>?ooool5o`0003_ooooo0_l0000Eooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`009oooooooo`000<So00002_ooool001cooooo0ol00008ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool001gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo000Eooooo`Go00000oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo000Mooooo`03o`000?oooooooooo00Oooooo0ol0001S
ooooo`?o003o>oooool3o`00oc_ooooo0ol00?lkooooo`?o003o>_ooool3o`00of?ooooo1?l0000:
ooooo`007Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06;ooooo0_l00?l2oooo
o`03o`00oooooooooooo03Oooooo0_l00?l2ooooo`03o`00oooooooooooo03Oooooo00?o003ooooo
ooooool00_l00?liooooo`03o`00oooooooooooo00;o003o>?ooool2o`00o`;ooooo0_l00?mToooo
o`03o`000?oooooooooo00Sooooo000Looooo`;o00002Oooool00ol0003oooooooooo`1Rooooo`05
o`00ooooooooooooooooool00?l0>Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
03Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0fooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0=_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
06;ooooo00?o0000ooooooooool02?ooool001gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Rooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0=Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo03Gooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0fooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0=?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo06;ooooo00?o0000ooooooooool02?ooool002Oooooo
00?o0000ooooooooool0HOooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo03Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool0=?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo03Cooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`1Rooooo`03o`000?oooooooooo00Sooooo
000Wooooo`03o`000?oooooooooo067ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0cooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0<oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo03Cooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0dooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0HOooool00ol0003ooooooooo
o`08ooooo`009oooool00ol0003oooooooooo`1Qooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo03?ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool0<oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo067ooooo00?o0000
ooooooooool02?ooool002Oooooo0_l0001Qooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool0<_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo03;ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool0<_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05oooooo0ol0000:oooo
o`009oooool00ol0003oooooooooo`1Oooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool0<_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo063ooooo00?o0000oooooooo
ool02?ooool002Oooooo00?o0000ooooooooool0Goooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo037ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0aooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`1Pooooo`03o`00
0?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05oooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0<?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0H?oo
ool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Nooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo02oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo05oooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0G_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0_ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0<?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`1Oooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05ko
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02oo
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool0Goooool00ol0003oooooooooo`08ooooo`009oooool2o`0005oooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool0;_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo02oooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool0G?ooool3o`0000[ooooo000Wooooo`03o`000?oooooooooo05kooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool0;_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo02oooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool0G_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1M
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0]
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0;_ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo05kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooo
ooooool0GOooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo02gooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool0;Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo02kooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`1Nooooo`03o`000?oooooooooo00Sooooo000Wooooo`03
o`000?oooooooooo05gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0]ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo02gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0^ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool0GOooool00ol0003oooooooooo`08ooooo`00
9oooool00ol0003oooooooooo`1Mooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
;?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo02cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
;Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo05gooooo00?o0000ooooooooool0
2?ooool002Oooooo00?o0000ooooooooool0GOooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo02_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0/ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo02cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Mooooo`03o`000?oo
oooooooo00Sooooo000Wooooo`;o0000G_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo02_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0/ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo02cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Kooooo`?o00002_ooool0
02Oooooo00?o0000ooooooooool0G?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
02_ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0[ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
02cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`1Mooooo`03o`000?oooooooooo
00Sooooo000Wooooo`03o`000?oooooooooo05cooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`0[ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0:oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0[ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0GOooool00ol0003o
ooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Looooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool0:oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo02[ooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`0[ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0:oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo05cooooo
00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0G?ooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`0Zooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0:oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`1Looooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool0:_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo02[ooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool0G?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Loooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo02Wooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0Yoooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo05cooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooooooo
ool0Foooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo02Wooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool0:Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo02Wooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`1Looooo`03o`000?oooooooooo00Sooooo000Wooooo`;o0000
G?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
:Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`1Jooooo`?o00002_ooool002Oooooo00?o0000ooooooooool0Fooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0:Ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`1Looooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooo
oooo05_ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo02Sooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool0Foooool00ol0003oooooooooo`08ooooo`009oooool00ol0
003oooooooooo`1Kooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0:?ooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`0Xooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0:?ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo05_ooooo00?o0000ooooooooool02?ooool0017o
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo05_o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo02So
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool0Foooool00ol0003oooooooooo`08ooooo`004?ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`1Joooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo02Oooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Woooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo05_ooooo00?o0000ooooooooool02?ooool000Wooooo1Ol00002ooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Joooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo02Kooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Woooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo05_ooooo00?o0000ooooooooool02?ooool0013ooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooooooo`05ooooo`?o0000F_ooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo02Oooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo02Kooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`1Hoooo
o`Co00002_ooool0013ooooo00Co0000oooooooooooo00001oooool4o`0000Sooooo00?o0000oooo
ooooool0F_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo02Kooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool09_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo02Kooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo00Sooooo000@ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Joooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo02Kooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo05[ooooo00?o0000ooooooooool02?ooool0017ooooo0_l00008ooooo`Go
00001oooool00ol0003oooooooooo`1Jooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool09_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo02Kooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool09_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo05[ooooo00?o0000oooooooo
ool02?ooool002Oooooo00?o0000ooooooooool0FOooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo02Gooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Vooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo02Gooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`1Jooooo`03o`00
0?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05Wooooo00?o003oooooooooool04ooo
ool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool05?oo
ool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0F_oo
ool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Iooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo02Cooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo05[ooooo00?o0000ooooooooool02?ooool002Oooooo0_l0001Jooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo
02Cooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
05Oooooo0ol0000:ooooo`009oooool00ol0003oooooooooo`1Iooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo02Co
oooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo05Wo
oooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0FOooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool04oooool00ol00?oooooo
ooooo`0Tooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool09?ooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`1Iooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05Sooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool09?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo02?ooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo01Cooooo00?o
003oooooooooool0FOooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1H
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0S
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo05Wooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooo
ooooool0F?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo02?ooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool08_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo02?ooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`1Iooooo`03o`000?oooooooooo00Sooooo000Wooooo`03
o`000?oooooooooo05Sooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Sooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo02;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Rooooo`03
o`00oooooooooooo01Gooooo00?o003oooooooooool0FOooool00ol0003oooooooooo`08ooooo`00
9oooool2o`0005Wooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo02;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Rooooo`03o`00
oooooooooooo01Kooooo00?o003oooooooooool0E_ooool3o`0000[ooooo000Wooooo`03o`000?oo
oooooooo05Sooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo02;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool0F?ooool00ol0003oooooooooo`08ooooo`009oooool0
0ol0003oooooooooo`1Hooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool08_ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool05_ooool0
0ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool08_ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool02?ooool0
02Oooooo00?o0000ooooooooool0Eoooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
02;ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
02;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1Hooooo`03o`000?oooooooooo
00Sooooo000Wooooo`03o`000?oooooooooo05Oooooo00?o003oooooooooool05oooool00ol00?oo
ooooooooo`0Qooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool08Oooool00ol00?oo
ooooooooo`0Fooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool05oooool00ol00?oo
ooooooooo`0Rooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0F?ooool00ol0003o
ooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Gooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo027ooooo
00?o003oooooooooool05oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo05Sooooo
00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0Eoooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`0Qooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool08?ooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`1Hooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o0000F?ooool00ol00?ooooooooooo`0G
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0P
ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0H
ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1E
ooooo`?o00002_ooool002Oooooo00?o0000ooooooooool0Eoooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo023ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Poooo
o`03o`00oooooooooooo01Sooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo023ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1Goooo
o`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo05Oooooo00?o003ooooooooo
ool06?ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo01Sooooo00?o003ooooooooo
ool07oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo023ooooo00?o003ooooooooo
ool06?ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo01Sooooo00?o003ooooooooo
ool0Eoooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`1Fooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo01oooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo01Sooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo05Oooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0E_oo
ool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool06?oo
ool00ol00?ooooooooooo`1Gooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooo
oooo05Kooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo01Wooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooo
oooo01kooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooo
oooo01Sooooo00?o003oooooooooool0Eoooool00ol0003oooooooooo`08ooooo`009oooool00ol0
003oooooooooo`1Fooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`0Iooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool06Oooool00ol0
0?ooooooooooo`0Nooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo05Kooooo00?o0000ooooooooool02?ooool002Oo
oooo00?o0000ooooooooool0E_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo01Wo
oooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`1Fooooo`03o`000?oooooooooo00So
oooo000Wooooo`;o0000Eoooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo01kooooo
00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01[ooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo01kooooo
00?o003oooooooooool06_ooool00ol00?ooooooooooo`1Dooooo`?o00002_ooool002Oooooo00?o
0000ooooooooool0E_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo01kooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01[ooooo00?o
003oooooooooool07_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo01kooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`1Fooooo`03o`000?oooooooooo00Sooooo000W
ooooo`03o`000?oooooooooo05Gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0N
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0N
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0E_ooool00ol0003oooooooooo`08
ooooo`009oooool00ol0003oooooooooo`1Eooooo`03o`00oooooooooooo01_ooooo00?o003ooooo
ooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003ooooo
ooooool07_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo05Kooooo00?o0000oooo
ooooool02?ooool001gooooo0_l00008ooooo`03o`000?oooooooooo05Gooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo01[ooooo00?o003ooooooooo
ool0E_ooool00ol0003oooooooooo`08ooooo`007?ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo05Gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`03
o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Nooooo`03
o`00oooooooooooo01_ooooo00?o003oooooooooool0EOooool00ol0003oooooooooo`08ooooo`00
7?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo05Gooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool0EOooool00ol0003oooooooooo`08ooooo`007?ooool01?l0003oooooooooool00007ooooo`?o
00001oooooloo`00o`oooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool03Ooooolno`00o`Oooooo1?l0000:ooooo`00
7?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo04Gooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo04Gooooo00?o0000oooooooo
ool02?ooool001cooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`15ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`15ooooo`03
o`000?oooooooooo00Sooooo000Mooooo`;o00002?ooool00ol0003oooooooooo`15ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00
oooooooooooo01gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`15ooooo`03o`00
0?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Ooo
ool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool06_oo
ool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo04Gooooo00?o0000ooooooooool02?oo
ool002Oooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo01gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooo
oooo01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooo
oooo01gooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool0AOooool00ol0003oooooooooo`08ooooo`009oooool00ol0
003oooooooooo`15ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool06_ooool00ol0
0?ooooooooooo`0Mooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool07Oooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`15ooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o0000A_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool06_ooool00ol00?oo
ooooooooo`0Nooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool07Oooool00ol00?oo
ooooooooo`0Jooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool06_ooool00ol00?oo
ooooooooo`0Nooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0@oooool3o`0000[o
oooo000Wooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0Nooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool07_ooool00ol00?oooooo
ooooo`0Jooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool06_ooool00ol00?oooooo
ooooo`0Nooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool07_ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo04Gooooo00?o0000ooooooooool02?ooool002Oooooo00?o
0000ooooooooool0AOooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo01Wooooo00?o
003oooooooooool07_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo01kooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool0AOooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`15
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0I
ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0N
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`15
ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo04Gooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo01Wooooo00?o003ooooo
ooooool07oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool06Oooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo01[ooooo00?o003ooooo
ooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo04Gooooo00?o0000oooo
ooooool02?ooool002Oooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo01oooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Oooooo`03
o`00oooooooooooo01Wooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0Hooooo`03
o`00oooooooooooo01oooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Pooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool0AOooool00ol0003oooooooooo`08ooooo`00
9oooool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
8?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool0
6Oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
7oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`15ooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o0000A_oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool06?oo
ool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool06?oo
ool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0@ooo
ool3o`0000[ooooo000Wooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool08?ooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool08?ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo04Gooooo00?o0000ooooooooool02?ooool0
02Oooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
027ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
023ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool0AOooool00ol0003oooooooooo`08ooooo`009oooool00ol0003o
ooooooooo`15ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool08Oooool00ol00?oo
ooooooooo`0Gooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool05oooool00ol00?oo
ooooooooo`0Pooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool08?ooool00ol00?oo
ooooooooo`0Hooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`15ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo04Gooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo027ooooo
00?o003oooooooooool05oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool08_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04Gooooo
00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0AOooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool05_ooool00ol00?oooooooooo
o`0Qooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool08Oooool00ol00?oooooooooo
o`0Gooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`0Rooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0AOooool00ol0003ooooooooo
o`08ooooo`009oooool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool08_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool05oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool08Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo02;ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`15ooooo`03o`000?oooooooooo00Sooooo000Woooo
o`03o`000?oooooooooo04Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Roooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooooooo027ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Roooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo04Gooooo00?o0000ooooooooool02?ooool002Oooooo0_l00016ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo02?ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Qooooo`03
o`00oooooooooooo01Kooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Fooooo`03
o`00oooooooooooo02;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`13ooooo`?o
00002_ooool002Oooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo02?ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo01Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo02;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Rooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool0AOooool00ol0003oooooooooo`08ooooo`009ooo
ool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool08_oo
ool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`15ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooo
oooo04Gooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo02?ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo04Gooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0AOooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool05?ooool00ol0
0?ooooooooooo`0Sooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool08oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0Tooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0AOooool00ol0
003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo02?o
oooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo02Co
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`15ooooo`03o`000?oooooooooo00So
oooo000Wooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool08oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`0Tooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool09?ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo04Gooooo00?o0000ooooooooool02?ooool002Oooooo0_l0
0016ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`0Cooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool05?ooool00ol00?oooooooooo
o`0Tooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool09?ooool00ol00?oooooooooo
o`0Dooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`13ooooo`?o00002_ooool002Oooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0U
ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0D
ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0AOooool00ol0003oooooooooo`08
ooooo`009oooool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool09Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo02Gooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool09?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo02Gooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`15ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03
o`000?oooooooooo04Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Uooooo`03
o`00oooooooooooo01?ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Cooooo`03
o`00oooooooooooo02Gooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Tooooo`03
o`00oooooooooooo01?ooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo04Gooooo00?o0000ooooooooool02?ooool0017ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
9Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
9_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo04Gooooo00?o0000ooooooooool0
2?ooool0013ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02Ko
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo01?o
oooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo02Co
oooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool0AOooool00ol0003oooooooooo`08ooooo`004?ooool01?l0003ooooo
ooooool0000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0AOooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`0Vooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool09_ooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`0Vooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0AOooool00ol0003o
ooooooooo`08ooooo`004?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Go
oooo0ol00015ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool09oooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`0Vooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool09_ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`12ooooo`Co00002_ooool0013ooooo00Co0000oooooooooooo00001oooool4o`0000So
oooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Oo
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo02Ko
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool0A_ooool00ol0003oooooooooo`08ooooo`004?ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0AOooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`0Wooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool09oooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`0Wooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0A_ooool00ol0003o
ooooooooo`08ooooo`004Oooool2o`0000Sooooo1Ol00007ooooo`03o`000?oooooooooo04Gooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool09oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo02Oooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool09oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo04Kooooo
00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0AOooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`0Wooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool09oooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`0Xooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A_ooool00ol0003ooooooooo
o`08ooooo`009oooool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool0:Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo02Sooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool09oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo02Sooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`16ooooo`03o`000?oooooooooo00Sooooo000Woooo
o`03o`000?oooooooooo04Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Yoooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo02Sooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Xoooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo04Kooooo00?o0000ooooooooool02?ooool002Oooooo0_l00016ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo02Sooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Xooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo02Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`?o
00002_ooool002Oooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo02Wooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0Yooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo02Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0Yooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool0A_ooool00ol0003oooooooooo`08ooooo`009ooo
ool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0:Ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0:?oo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`16ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooo
oooo04Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo02[ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo04Kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0AOooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0Zooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0:_ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`0Zooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A_ooool00ol0
003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo02[o
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo02[o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`16ooooo`03o`000?oooooooooo00So
oooo000Wooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0[ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0:_ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`0Zooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0:_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo04Kooooo00?o0000ooooooooool02?ooool002Oooooo0_l0
0016ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0:oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`0[ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0:oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`14ooooo`?o00002_ooool002Oooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0[
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo02cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0[
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0A_ooool00ol0003oooooooooo`08
ooooo`009oooool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool0;?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool0;?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo02_ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`16ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03
o`000?oooooooooo04Gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0]ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo02cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0/ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0;?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo04Kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0
AOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
;Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
A_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`15ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo02gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0]ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool0;_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo02cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`16ooooo`03o`000?oo
oooooooo00Sooooo000Wooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0;Oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0;?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04Kooooo00?o0000ooooooooool02?ooool0
02Oooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
02gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
02kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0A_ooool00ol0003oooooooooo`08ooooo`009oooool2o`0004Ko
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02oo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool0;_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04Co
oooo0ol0000:ooooo`009oooool00ol0003oooooooooo`15ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool0;oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02oooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool0;oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02kooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`16ooooo`03o`000?oooooooooo00Sooooo
000Wooooo`03o`000?oooooooooo04Gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0_ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0;oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0`ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0;_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo04Kooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000
ooooooooool0AOooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02oooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool0;oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo033ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0A_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`15oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo037ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0aoooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo033ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`16oooo
o`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo04Gooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool0<Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool0<?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04Kooooo00?o0000oooooooo
ool02?ooool002Oooooo00?o0000ooooooooool0AOooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo037ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0aooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo03;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0`ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0A_ooool00ol0003oooooooooo`08ooooo`009ooo
ool2o`0004Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0aooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo03?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0booooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo04Cooooo0ol0000:ooooo`009oooool00ol0003oooooooooo`15ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo03;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo03;ooooo00Go003oooooooooooooooooo`00o`18ooooo`03o`000?oooooooooo00Sooooo000W
ooooo`03o`000?oooooooooo04Gooooo00Go003oooooooooooooooooo`00o`0eooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo03Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0cooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0<_ooool01Ol00?oooooooooooooooooo003o04Sooooo
00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0AOooool01Ol00?oooooooooo
oooooooo003o03Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0cooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0=Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo03Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0dooooo`04o`00
ooooooooooooo`00odSooooo00?o0000ooooooooool02?ooool001cooooo0ol00008ooooo`03o`00
0?oooooooooo04Gooooo00Go003oooooooooooooooooo`00o`0fooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool0=Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo03Go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0eooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool0=Oooool00ol00?ooooooo`00o`18ooooo`03o`000?oooooooooo00So
oooo000Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0AOooool01?l00?oooooo
ooooool00?lhooooo`05o`00ooooooooooooooooool00?l0>Oooool01Ol00?oooooooooooooooooo
003o03Wooooo00Go003oooooooooooooooooo`00o`0hooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0=_ooool00ol00?ooooooo`00o`18ooooo`03o`000?oooooooooo00Sooooo000M
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0AOooool3o`00ocWooooo0_l00?l2
ooooo`03o`00oooooooooooo03Oooooo0_l00?l00ooooooo003oooooo`0iooooo`04o`00oooooooo
ooooo`00oc[ooooo00Co003ooooooooooooo003o>_ooool2o`00odSooooo00?o0000ooooooooool0
2?ooool001gooooo00?o0000ooooooooool01oooool3o`0004Gooooo0_l00?lkooooo`?o003o>ooo
ool3o`00oc_ooooo0ol00?lkooooo`;o003o>oooool2o`00odGooooo1?l0000:ooooo`007Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Looooo`;o00002Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Mooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooooooo`000<So0000
2_ooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-1.80829, -1.25358, 0.0161798, \
0.0138684}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xf\  = \ 
        Integrate[
            Cos[2  \[Pi]\ t]\ Exp[\(-I\)\ 2  \[Pi]\ f\ t], {t, 0, \ 
              5}]\  // \ FullSimplify;\)\), "\[IndentingNewLine]", 
    \(xf\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-\(\(\[ImaginaryI]\ \((1 - \
\[ExponentialE]\^\(\(-10\)\ \[ImaginaryI]\ f\ \[Pi]\))\)\ f\)\/\(2\ \((f\^2 - 
                1)\)\ \[Pi]\)\)\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g1 = 
        Plot[Abs[xf], {f, \(-5\), 5}, \ PlotStyle \[Rule] {Red}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[Arg[xf], {f, \(-5\), 5}, \ PlotStyle \[Rule] {Red}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.235091 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13226 -18 -4.5 ]
[-0.0125 .13226 0 4.5 ]
[-0.0125 .24981 -6 -4.5 ]
[-0.0125 .24981 0 4.5 ]
[-0.0125 .36735 -18 -4.5 ]
[-0.0125 .36735 0 4.5 ]
[-0.0125 .4849 -6 -4.5 ]
[-0.0125 .4849 0 4.5 ]
[-0.0125 .60244 -18 -4.5 ]
[-0.0125 .60244 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13226 m
.00625 .13226 L
s
[(0.5)] -0.0125 .13226 1 0 Mshowa
0 .24981 m
.00625 .24981 L
s
[(1)] -0.0125 .24981 1 0 Mshowa
0 .36735 m
.00625 .36735 L
s
[(1.5)] -0.0125 .36735 1 0 Mshowa
0 .4849 m
.00625 .4849 L
s
[(2)] -0.0125 .4849 1 0 Mshowa
0 .60244 m
.00625 .60244 L
s
[(2.5)] -0.0125 .60244 1 0 Mshowa
.125 Mabswid
0 .03822 m
.00375 .03822 L
s
0 .06173 m
.00375 .06173 L
s
0 .08524 m
.00375 .08524 L
s
0 .10875 m
.00375 .10875 L
s
0 .15577 m
.00375 .15577 L
s
0 .17928 m
.00375 .17928 L
s
0 .20279 m
.00375 .20279 L
s
0 .2263 m
.00375 .2263 L
s
0 .27331 m
.00375 .27331 L
s
0 .29682 m
.00375 .29682 L
s
0 .32033 m
.00375 .32033 L
s
0 .34384 m
.00375 .34384 L
s
0 .39086 m
.00375 .39086 L
s
0 .41437 m
.00375 .41437 L
s
0 .43788 m
.00375 .43788 L
s
0 .46139 m
.00375 .46139 L
s
0 .50841 m
.00375 .50841 L
s
0 .53191 m
.00375 .53191 L
s
0 .55542 m
.00375 .55542 L
s
0 .57893 m
.00375 .57893 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13226 m
1 .13226 L
s
.99375 .24981 m
1 .24981 L
s
.99375 .36735 m
1 .36735 L
s
.99375 .4849 m
1 .4849 L
s
.99375 .60244 m
1 .60244 L
s
.125 Mabswid
.99625 .03822 m
1 .03822 L
s
.99625 .06173 m
1 .06173 L
s
.99625 .08524 m
1 .08524 L
s
.99625 .10875 m
1 .10875 L
s
.99625 .15577 m
1 .15577 L
s
.99625 .17928 m
1 .17928 L
s
.99625 .20279 m
1 .20279 L
s
.99625 .2263 m
1 .2263 L
s
.99625 .27331 m
1 .27331 L
s
.99625 .29682 m
1 .29682 L
s
.99625 .32033 m
1 .32033 L
s
.99625 .34384 m
1 .34384 L
s
.99625 .39086 m
1 .39086 L
s
.99625 .41437 m
1 .41437 L
s
.99625 .43788 m
1 .43788 L
s
.99625 .46139 m
1 .46139 L
s
.99625 .50841 m
1 .50841 L
s
.99625 .53191 m
1 .53191 L
s
.99625 .55542 m
1 .55542 L
s
.99625 .57893 m
1 .57893 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02608 .02044 L
.02847 .02567 L
.02972 .0278 L
.03089 .0293 L
.03157 .02992 L
.03188 .03015 L
.03218 .03032 L
.03252 .03048 L
.03269 .03054 L
.03288 .03059 L
.03296 .03061 L
.03305 .03062 L
.0332 .03064 L
.03329 .03065 L
.03338 .03065 L
.03346 .03065 L
.03355 .03065 L
.03363 .03064 L
.03371 .03063 L
.03386 .03061 L
.03402 .03057 L
.03419 .03052 L
.0345 .0304 L
.0348 .03024 L
.03534 .02986 L
.03592 .02931 L
.03725 .02756 L
.03845 .02543 L
.04095 .01974 L
.04205 .01688 L
.04235 .01608 L
.04251 .01566 L
.04267 .01521 L
.04282 .01482 L
.0429 .01483 L
.04298 .01504 L
.04326 .01579 L
.0455 .02164 L
.04788 .02687 L
.04915 .02897 L
.04977 .02978 L
.05035 .03039 L
.05087 .03082 L
.05114 .03099 L
.05142 .03115 L
.05157 .03121 L
.05171 .03126 L
.05185 .03131 L
.05198 .03134 L
Mistroke
.05213 .03137 L
.05221 .03138 L
.05229 .03139 L
.05245 .03139 L
.05259 .03139 L
.05274 .03138 L
.05287 .03136 L
.05302 .03133 L
.05318 .03128 L
.05351 .03115 L
.0538 .03099 L
.05437 .03058 L
.05492 .03005 L
.05612 .02845 L
.05743 .02608 L
.05977 .02057 L
.06101 .01721 L
.06135 .01626 L
.06154 .01574 L
.06171 .01525 L
.06186 .01484 L
.06202 .01504 L
.06211 .01529 L
.06219 .01553 L
.06235 .01598 L
.0648 .02262 L
.06709 .02778 L
.06827 .02977 L
.06891 .03062 L
.06951 .03126 L
.07003 .03168 L
.07031 .03186 L
.07057 .032 L
.07086 .03211 L
.07102 .03215 L
.07117 .03218 L
.0713 .0322 L
.07145 .03221 L
.0716 .03221 L
.07174 .0322 L
.07188 .03218 L
.07203 .03215 L
.07218 .03211 L
.07231 .03206 L
.07262 .03192 L
.07292 .03174 L
.07352 .03126 L
.07417 .03056 L
.07533 .02885 L
.0764 .0268 L
Mistroke
.07885 .02076 L
.07947 .01904 L
.08005 .01736 L
.08058 .01582 L
.08072 .0154 L
.08088 .01494 L
.08102 .01491 L
.08115 .0153 L
.08335 .02167 L
.08458 .02492 L
.08572 .02756 L
.08682 .02972 L
.08804 .03153 L
.08867 .03222 L
.08926 .03268 L
.08959 .03287 L
.08988 .033 L
.09005 .03305 L
.09013 .03307 L
.09023 .03308 L
.09031 .0331 L
.09039 .03311 L
.09055 .03312 L
.0907 .03311 L
.09083 .0331 L
.09098 .03307 L
.09107 .03305 L
.09114 .03303 L
.0913 .03298 L
.09147 .03292 L
.09177 .03276 L
.09235 .03233 L
.09289 .03179 L
.09411 .03006 L
.0954 .02754 L
.09776 .02148 L
.09882 .01835 L
.09938 .01664 L
.09969 .01569 L
.09984 .01523 L
.09997 .0148 L
.10005 .01488 L
.10014 .01514 L
.10032 .0157 L
.10063 .01666 L
.10123 .01853 L
.10242 .02211 L
.10466 .02801 L
.10581 .03042 L
.10644 .03151 L
Mistroke
.10703 .03238 L
.10759 .03304 L
.10788 .03333 L
.10819 .03358 L
.10845 .03376 L
.10874 .03392 L
.10887 .03397 L
.109 .03402 L
.10913 .03406 L
.10925 .03409 L
.10932 .0341 L
.10941 .03411 L
.10955 .03412 L
.10963 .03412 L
.10972 .03412 L
.10988 .03411 L
.11002 .03408 L
.11016 .03405 L
.11031 .034 L
.11046 .03394 L
.11082 .03375 L
.11116 .03351 L
.11179 .0329 L
.1124 .03213 L
.11295 .03126 L
.11422 .02878 L
.11647 .02289 L
.11776 .0189 L
.11833 .01707 L
.11863 .01609 L
.11879 .01555 L
.11895 .01503 L
.1191 .01488 L
.11918 .01516 L
.11926 .01541 L
.11954 .01633 L
.12009 .01813 L
.12128 .02195 L
.12258 .02582 L
.1238 .029 L
.12498 .03157 L
.12606 .03337 L
.12667 .03414 L
.12726 .03469 L
.12758 .03492 L
.12788 .03507 L
.12805 .03514 L
.1282 .03519 L
.12829 .03521 L
.12838 .03523 L
Mistroke
.12847 .03524 L
.12855 .03525 L
.1287 .03526 L
.12885 .03525 L
.12898 .03523 L
.12912 .0352 L
.12927 .03516 L
.12943 .0351 L
.12972 .03495 L
.12999 .03478 L
.13025 .03458 L
.13082 .03399 L
.13145 .03315 L
.13202 .0322 L
.13332 .0295 L
.1356 .02311 L
.13691 .01881 L
.13753 .01668 L
.1378 .01574 L
.13795 .0152 L
.1381 .01473 L
.13824 .01521 L
.13838 .01572 L
.13868 .01677 L
.13932 .01897 L
.14047 .02285 L
.143 .03026 L
.14422 .03299 L
.14487 .03415 L
.14555 .03514 L
.14615 .0358 L
.14649 .03608 L
.14681 .03628 L
.14695 .03636 L
.1471 .03642 L
.14723 .03646 L
.14737 .0365 L
.14752 .03652 L
.14766 .03654 L
.14775 .03654 L
.14783 .03654 L
.14798 .03652 L
.14812 .0365 L
.14827 .03646 L
.14841 .03641 L
.14854 .03635 L
.14885 .03617 L
.14915 .03595 L
.14974 .03535 L
.15039 .03448 L
Mistroke
.15154 .03235 L
.15261 .02979 L
.15488 .02287 L
.15607 .01866 L
.15639 .01751 L
.15672 .01627 L
.15689 .01566 L
.15704 .01509 L
.15718 .01486 L
.15733 .01542 L
.15797 .0178 L
.15868 .02039 L
.15992 .02475 L
.16107 .0285 L
.16235 .03207 L
.16358 .03482 L
.16414 .03582 L
.16473 .03667 L
.16504 .03703 L
.16537 .03736 L
.16568 .03761 L
.16595 .03778 L
.16612 .03786 L
.16628 .03792 L
.16636 .03794 L
.16645 .03796 L
.16655 .03798 L
.16663 .03799 L
.16679 .038 L
.16694 .038 L
.16702 .03799 L
.1671 .03797 L
.16718 .03795 L
.16727 .03793 L
.16742 .03788 L
.16758 .03781 L
.16788 .03763 L
.16816 .03741 L
.16843 .03716 L
.16903 .03643 L
.16966 .03543 L
.17072 .03325 L
.17188 .03019 L
.17319 .02602 L
.17444 .02154 L
.17555 .01724 L
.17586 .01604 L
.17602 .01537 L
.17618 .01475 L
.17632 .01521 L
Mistroke
.17646 .01578 L
.17676 .01699 L
.17901 .02563 L
.18146 .03349 L
.1821 .0351 L
.18278 .03658 L
.18337 .03764 L
.18401 .03855 L
.18435 .03893 L
.18466 .03921 L
.18496 .03942 L
.18512 .03951 L
.18528 .03958 L
.18543 .03963 L
.18556 .03966 L
.1857 .03968 L
.18583 .03969 L
.18598 .03969 L
.18612 .03967 L
.18627 .03963 L
.18635 .03961 L
.18643 .03958 L
.18671 .03944 L
.18702 .03923 L
.18735 .03894 L
.18765 .0386 L
.18876 .03685 L
.1894 .03551 L
.18998 .03408 L
.19128 .03022 L
.19249 .02592 L
.19378 .02084 L
.19431 .01863 L
.19488 .01622 L
.19505 .01551 L
.19521 .01483 L
.19535 .01521 L
.19551 .01588 L
.1961 .01838 L
.19853 .02828 L
.20073 .03557 L
.20132 .03711 L
.20196 .03855 L
.20251 .03958 L
.20311 .04048 L
.20342 .04085 L
.20375 .04117 L
.20393 .04131 L
.2041 .04142 L
.20427 .04151 L
Mistroke
.20443 .04158 L
.20457 .04162 L
.20472 .04165 L
.20488 .04167 L
.20497 .04167 L
.20505 .04166 L
.2052 .04164 L
.20533 .0416 L
.20548 .04155 L
.20564 .04148 L
.20595 .04127 L
.20624 .04102 L
.20679 .04038 L
.20738 .03945 L
.20802 .03818 L
.20917 .03521 L
.21024 .03179 L
.21142 .02732 L
.2127 .02194 L
.21331 .01919 L
.21361 .0178 L
.2139 .01651 L
.21415 .01534 L
.21429 .01475 L
.21442 .01534 L
.21499 .01799 L
.21738 .0286 L
.21957 .03669 L
.2207 .03987 L
.22128 .04117 L
.22189 .04231 L
.22222 .04279 L
.22251 .04317 L
.22282 .04348 L
.22309 .0437 L
.22325 .0438 L
.22342 .04389 L
.22359 .04395 L
.22368 .04398 L
.22377 .044 L
.22385 .04401 L
.22393 .04401 L
.22408 .04401 L
.22423 .04399 L
.22432 .04397 L
.22441 .04394 L
.22456 .04388 L
.22473 .04379 L
.22502 .04358 L
.22533 .04328 L
Mistroke
.22568 .04286 L
.2263 .04187 L
.22688 .04069 L
.22796 .03783 L
.22913 .03392 L
.23151 .02369 L
.23217 .02053 L
.23253 .01876 L
.23286 .01708 L
.23315 .01564 L
.23323 .01524 L
.23331 .01483 L
.23346 .01535 L
.23354 .01574 L
.23362 .01617 L
.23377 .01693 L
.23411 .01866 L
.23642 .02987 L
.23892 .03979 L
.23957 .04177 L
.24026 .04355 L
.2409 .04487 L
.24121 .0454 L
.24149 .04581 L
.24176 .04613 L
.24205 .04642 L
.24221 .04655 L
.24236 .04665 L
.2425 .04672 L
.24265 .04678 L
.24274 .04681 L
.24282 .04683 L
.24297 .04685 L
.24312 .04685 L
.24327 .04683 L
.24334 .04681 L
.24343 .04679 L
.24358 .04673 L
.24376 .04663 L
.24392 .04652 L
.2442 .04627 L
.2445 .04592 L
.24512 .04498 L
.24569 .04381 L
.24623 .04248 L
.24743 .03867 L
.24873 .03346 L
.25116 .02145 L
.25174 .01825 L
.25207 .01646 L
Mistroke
.25223 .01558 L
.25237 .01477 L
.25246 .01513 L
.25255 .01563 L
.25273 .01668 L
.25306 .01851 L
.2537 .02206 L
.25609 .03453 L
.25828 .04355 L
.25885 .04539 L
.25948 .04709 L
.26003 .04829 L
.26063 .0493 L
.26095 .04972 L
.26126 .05002 L
.26143 .05014 L
.26158 .05023 L
.26176 .05031 L
.26184 .05033 L
.26193 .05036 L
.26209 .05037 L
.26224 .05036 L
.26232 .05035 L
.2624 .05033 L
.26256 .05028 L
.26271 .0502 L
.26287 .0501 L
.26315 .04986 L
.26345 .04951 L
.26374 .0491 L
.26428 .0481 L
.26487 .04673 L
.2655 .04488 L
.26771 .03593 L
.27009 .02293 L
.27077 .01879 L
.2711 .01673 L
.27125 .01582 L
.27133 .01533 L
.27141 .01481 L
.27156 .01552 L
.27169 .01637 L
.27199 .01822 L
.27262 .02211 L
.27501 .03619 L
.27627 .04257 L
.27761 .04813 L
.27879 .05178 L
.27912 .05255 L
.27947 .05326 L
Mistroke
.27977 .05377 L
.2801 .05422 L
.28025 .05438 L
.28041 .05453 L
.28054 .05463 L
.28069 .05473 L
.28078 .05477 L
.28086 .0548 L
.28101 .05485 L
.28116 .05487 L
.28131 .05486 L
.28144 .05484 L
.28158 .05479 L
.28171 .05472 L
.28183 .05465 L
.28213 .05439 L
.28241 .05406 L
.28302 .05305 L
.28357 .0518 L
.28481 .04785 L
.28595 .0429 L
.28703 .03725 L
.28821 .03012 L
.28946 .02185 L
.28997 .01828 L
.2901 .01733 L
.29025 .0163 L
.29039 .01532 L
.29052 .01502 L
.29067 .0161 L
.29083 .01726 L
.29112 .0193 L
.29168 .02328 L
.29407 .03928 L
.29625 .05116 L
.29682 .05362 L
.29744 .05593 L
.29804 .05775 L
.29859 .05905 L
.29889 .05963 L
.29922 .06013 L
.2994 .06035 L
.29956 .06052 L
.29972 .06065 L
.29981 .06071 L
.29989 .06075 L
.30003 .06081 L
.30019 .06085 L
.30033 .06085 L
.30047 .06083 L
Mistroke
.30063 .06078 L
.30077 .06071 L
.30093 .0606 L
.3011 .06044 L
.30139 .0601 L
.30169 .05962 L
.30223 .05849 L
.30281 .05687 L
.30345 .05464 L
.30459 .04948 L
.30565 .04347 L
.30791 .02764 L
.30853 .02279 L
.30887 .02007 L
.30919 .01749 L
.30932 .01636 L
.30945 .01528 L
.30961 .01539 L
.30974 .01654 L
.31036 .02163 L
.31293 .04213 L
.31411 .05039 L
.31536 .05789 L
.31601 .06112 L
.31662 .06372 L
.31721 .06579 L
.31775 .06729 L
.31827 .06834 L
.31853 .06873 L
.31868 .0689 L
.31882 .06903 L
.31897 .06915 L
.31911 .06922 L
.31926 .06927 L
.31934 .06928 L
.31942 .06929 L
.31955 .06927 L
.31969 .06923 L
.31983 .06915 L
.31997 .06905 L
.32012 .06891 L
.32027 .06874 L
.32054 .06833 L
.32087 .0677 L
.32116 .067 L
.3218 .06501 L
.32241 .0626 L
.32348 .0571 L
.32464 .0495 L
.327 .0299 L
Mistroke
.32764 .02381 L
.328 .02037 L
.32817 .01866 L
.32833 .01707 L
.32848 .01557 L
.32856 .01482 L
.32865 .01545 L
.32899 .01885 L
.32958 .02481 L
.33206 .04878 L
.33434 .06703 L
.33547 .07386 L
.33605 .07663 L
.33667 .079 L
.33699 .08 L
.33729 .08075 L
.33759 .08136 L
.33787 .08178 L
.33803 .08196 L
.33811 .08204 L
.3382 .0821 L
.33834 .08218 L
.3385 .08222 L
.33859 .08223 L
.33867 .08222 L
.33883 .08216 L
.33892 .08211 L
.339 .08205 L
.33918 .08188 L
.33934 .08168 L
.3395 .08142 L
.33979 .08083 L
.34011 .08002 L
.34046 .07892 L
.34108 .0764 L
.34166 .07341 L
.34274 .06629 L
.3439 .05657 L
.34513 .04427 L
.34646 .02901 L
.34707 .02155 L
.34738 .01769 L
.34747 .01663 L
.34756 .01548 L
.34764 .01504 L
.34772 .01604 L
.34889 .03099 L
.35137 .06184 L
.35257 .0752 L
.35367 .08572 L
Mistroke
.35481 .09459 L
.35534 .09783 L
.35589 .10065 L
.35617 .10183 L
.35648 .10293 L
.35677 .10374 L
.35703 .10431 L
.35719 .10458 L
.35734 .10479 L
.3575 .10494 L
.35759 .105 L
.35767 .10504 L
.35782 .10507 L
.35796 .10505 L
.35812 .10496 L
.35827 .10482 L
.35841 .10464 L
.35856 .1044 L
.35883 .10381 L
.35915 .10287 L
.35945 .10178 L
.36009 .09866 L
.36069 .09478 L
.36176 .08574 L
.36292 .07293 L
.36531 .03818 L
.36589 .02838 L
.3662 .02308 L
.36652 .0174 L
.3666 .01592 L
.36669 .0151 L
.36679 .01685 L
.36688 .01849 L
.3672 .02448 L
.36785 .03641 L
.37025 .08112 L
.37152 .10306 L
.37286 .12362 L
.37406 .13877 L
.37469 .14527 L
.37537 .15092 L
.37569 .15306 L
.376 .15478 L
.37629 .15614 L
.37657 .15712 L
.37683 .1578 L
.37696 .15805 L
.3771 .15824 L
.37725 .15836 L
.3774 .1584 L
Mistroke
.37755 .15835 L
.37769 .15822 L
.37784 .158 L
.37799 .1577 L
.37826 .1569 L
.37855 .15571 L
.37887 .15402 L
.37944 .14992 L
.37997 .1449 L
.38118 .12884 L
.38246 .10495 L
.3836 .07806 L
.38422 .06103 L
.38482 .04348 L
.38537 .02607 L
.38552 .02112 L
.38561 .01837 L
.38568 .01576 L
.38584 .01881 L
.38597 .02353 L
.38703 .06157 L
.39168 .25609 L
.39404 .35792 L
.39663 .4588 L
.39782 .49855 L
.39909 .53508 L
.40029 .56282 L
.40139 .58235 L
.40199 .5903 L
.40262 .5967 L
.40295 .59918 L
.40326 .60098 L
.40343 .60178 L
.40359 .60237 L
.40377 .60285 L
.40386 .60303 L
.40396 .60318 L
.40403 .60326 L
.40412 .60332 L
.40427 .60331 L
.40443 .60318 L
.40456 .60295 L
.40471 .60258 L
.40488 .60204 L
.40521 .6005 L
.40551 .59867 L
.40582 .59621 L
.40638 .59047 L
.40702 .58209 L
.40761 .57253 L
Mistroke
.40894 .54487 L
.41136 .47581 L
.41609 .29634 L
.41851 .19811 L
.42112 .09955 L
.42234 .05827 L
.42302 .03751 L
.42334 .02788 L
.42349 .02378 L
.42364 .01941 L
.42378 .01545 L
.42391 .01758 L
.42404 .02097 L
.42417 .0245 L
.42475 .03893 L
.42596 .06574 L
.42709 .08603 L
.42772 .09521 L
.42831 .10261 L
.42886 .10832 L
.42947 .11332 L
.43001 .11678 L
.43026 .118 L
.43052 .11908 L
.43067 .1196 L
.43084 .12009 L
.43099 .12046 L
.43113 .12074 L
.4313 .12098 L
.43139 .12108 L
.43147 .12115 L
.43163 .12121 L
.43171 .12122 L
.43179 .12121 L
.43194 .12114 L
.43207 .12102 L
.43222 .12082 L
.43238 .12055 L
.4327 .11977 L
.43299 .11881 L
.43352 .11656 L
.43409 .11335 L
.43524 .10474 L
.4376 .0802 L
.44013 .04856 L
.44136 .03282 L
.44201 .02476 L
.44237 .02046 L
.44254 .01839 L
.4427 .01652 L
Mistroke
.44285 .01479 L
.44299 .01627 L
.4433 .01979 L
.44397 .02696 L
.44513 .03836 L
.44629 .04791 L
.44752 .05592 L
.44812 .05896 L
.44869 .06131 L
.4492 .06299 L
.44974 .06435 L
.45003 .06487 L
.45019 .06511 L
.45034 .06529 L
.45048 .06544 L
.45063 .06556 L
.45077 .06565 L
.45089 .0657 L
.45104 .06573 L
.45118 .06573 L
.45134 .0657 L
.45142 .06566 L
.4515 .06562 L
.45165 .06552 L
.45182 .06538 L
.45215 .06497 L
.45249 .06441 L
.45279 .06378 L
.45347 .06197 L
.45469 .05742 L
.45701 .04536 L
.45952 .02959 L
.46076 .02168 L
.46137 .01793 L
.46163 .01633 L
.46177 .01549 L
.46192 .01481 L
.46208 .01572 L
.46222 .01655 L
.46251 .01816 L
.46313 .02156 L
.46446 .02799 L
.46559 .03247 L
.46618 .03443 L
.46681 .03618 L
.46735 .03746 L
.46795 .03857 L
.46822 .03897 L
.4685 .03933 L
.46874 .03958 L
Mistroke
.46901 .03981 L
.46916 .03991 L
.46932 .04 L
.46941 .04004 L
.46949 .04008 L
.46965 .04012 L
.46979 .04015 L
.46995 .04016 L
.4701 .04015 L
.47024 .04013 L
.47033 .04011 L
.47042 .04008 L
.47058 .04002 L
.47074 .03994 L
.47089 .03985 L
.47122 .03958 L
.47158 .03922 L
.47218 .03843 L
.47274 .03751 L
.47401 .03481 L
.4787 .0211 L
.47993 .01749 L
.48027 .01655 L
.48062 .01558 L
.48077 .01519 L
.48093 .01478 L
.48102 .01488 L
.4811 .0151 L
.48126 .0155 L
.48252 .01835 L
.48369 .02048 L
.4848 .02198 L
.48541 .02259 L
.48597 .02301 L
.4863 .0232 L
.48659 .02333 L
.48692 .02344 L
.48708 .02348 L
.48717 .02349 L
.48726 .02351 L
.48742 .02352 L
.48756 .02353 L
.48772 .02353 L
.4878 .02353 L
.48789 .02352 L
.48803 .0235 L
.48817 .02348 L
.48833 .02345 L
.48847 .02341 L
.48876 .02331 L
Mistroke
.48904 .0232 L
.48965 .02287 L
.4909 .02191 L
.49313 .01963 L
.49538 .01723 L
.49657 .01616 L
.49722 .01568 L
.49783 .01531 L
.49846 .01502 L
.4988 .0149 L
.49897 .01485 L
.49916 .01481 L
.49933 .01477 L
.49949 .01475 L
.49964 .01473 L
.49973 .01472 L
.49981 .01472 L
.49995 .01472 L
.50011 .01472 L
.50026 .01472 L
.5004 .01474 L
.50054 .01475 L
.50069 .01478 L
.50096 .01483 L
.50128 .01493 L
.50158 .01503 L
.50222 .01534 L
.50282 .01571 L
.50399 .01663 L
.50522 .01784 L
.50744 .02026 L
.50857 .02142 L
.50979 .02248 L
.51035 .02287 L
.51094 .02319 L
.51118 .02329 L
.51144 .02338 L
.51159 .02343 L
.51173 .02346 L
.51186 .02349 L
.51199 .02351 L
.51214 .02352 L
.51227 .02353 L
.51235 .02353 L
.51243 .02353 L
.51258 .02352 L
.51273 .02351 L
.51287 .02349 L
.51303 .02345 L
.5132 .02341 L
Mistroke
.5135 .0233 L
.51378 .02316 L
.51431 .02282 L
.51493 .02226 L
.51551 .02161 L
.51681 .01963 L
.51791 .01743 L
.51852 .01604 L
.51881 .01531 L
.51894 .01498 L
.51909 .01482 L
.51924 .01522 L
.51941 .01567 L
.51976 .01662 L
.52038 .01836 L
.52158 .02196 L
.52411 .02973 L
.52522 .03285 L
.52643 .03583 L
.527 .03702 L
.52761 .0381 L
.52814 .03888 L
.52871 .03952 L
.52904 .0398 L
.52919 .0399 L
.52935 .03999 L
.5295 .04005 L
.52965 .04011 L
.52973 .04013 L
.52981 .04014 L
.52996 .04016 L
.53011 .04016 L
.53024 .04015 L
.53039 .04011 L
.53055 .04006 L
.5307 .03999 L
.53084 .03991 L
.5311 .03972 L
.53139 .03944 L
.53167 .03912 L
.53228 .03817 L
.53289 .03693 L
.53353 .03528 L
.5347 .03142 L
.53576 .027 L
.53688 .02149 L
.5375 .01816 L
.5378 .01646 L
.53793 .0157 L
.53807 .01486 L
Mistroke
.53822 .01547 L
.53837 .01634 L
.53869 .01828 L
.53937 .02252 L
.54058 .03021 L
.54315 .04629 L
.54436 .05296 L
.54548 .05815 L
.54665 .06231 L
.54726 .06389 L
.54757 .06451 L
.54791 .06505 L
.54806 .06525 L
.54821 .0654 L
.54834 .06552 L
.54848 .06561 L
.54863 .06569 L
.54877 .06572 L
.54892 .06573 L
.54901 .06572 L
.54909 .0657 L
.54923 .06565 L
.54937 .06557 L
.54949 .06547 L
.54962 .06534 L
.54992 .06495 L
.5502 .06447 L
.55081 .06298 L
.55147 .06072 L
.55209 .05795 L
.55266 .05485 L
.55491 .03802 L
.556 .02735 L
.5566 .02089 L
.55689 .01757 L
.55704 .01592 L
.55717 .01501 L
.55732 .01683 L
.55749 .01878 L
.55784 .02298 L
.55845 .03053 L
.55966 .0458 L
.56218 .07759 L
.56328 .09025 L
.5645 .10238 L
.56506 .10724 L
.56567 .11175 L
.56619 .11501 L
.56676 .11784 L
.5671 .11912 L
Mistroke
.5674 .12005 L
.5677 .12069 L
.56785 .12092 L
.56793 .12101 L
.56801 .1211 L
.56816 .12119 L
.5683 .12122 L
.56844 .12119 L
.5686 .12109 L
.56874 .12094 L
.56889 .12071 L
.56915 .12012 L
.5693 .11969 L
.56946 .11914 L
.5698 .11775 L
.57039 .11434 L
.57108 .10882 L
.57173 .10211 L
.5729 .0861 L
.57416 .06332 L
.57539 .03567 L
.57572 .02718 L
.57591 .02237 L
.576 .01997 L
.57608 .01774 L
.57623 .01569 L
.57638 .02009 L
.57672 .02971 L
.57915 .10888 L
.58392 .29689 L
.58851 .47176 L
.59087 .54039 L
.5922 .56898 L
.59278 .57903 L
.5934 .58785 L
.59397 .59428 L
.59428 .59701 L
.5946 .5994 L
.5949 .6011 L
.59518 .60224 L
.59531 .60264 L
.59545 .60298 L
.59559 .60319 L
.59571 .6033 L
.59587 .60332 L
.59596 .60327 L
.59604 .60319 L
.59619 .60294 L
.59635 .60255 L
.59649 .60208 L
Mistroke
.59662 .60155 L
.59693 .59998 L
.59725 .59773 L
.59755 .59519 L
.59822 .58775 L
.5988 .57941 L
.59942 .56868 L
.60052 .54476 L
.60303 .47089 L
.60758 .28847 L
.61011 .17793 L
.61122 .13106 L
.61243 .08227 L
.613 .06047 L
.61361 .03817 L
.61391 .02773 L
.61405 .0227 L
.61418 .01813 L
.61431 .01541 L
.61444 .01971 L
.61471 .02858 L
.61586 .06343 L
.6171 .0952 L
.61833 .12059 L
.61946 .13811 L
.62 .14458 L
.6206 .1502 L
.62087 .15228 L
.62115 .15415 L
.6214 .15548 L
.62167 .15664 L
.62182 .15717 L
.62199 .15763 L
.62208 .15784 L
.62216 .158 L
.62224 .15813 L
.62232 .15823 L
.62247 .15836 L
.62263 .1584 L
.62277 .15835 L
.62292 .15822 L
.62308 .15799 L
.62316 .15782 L
.62325 .15763 L
.62356 .15671 L
.62392 .15521 L
.62426 .15335 L
.62486 .14913 L
.62542 .14418 L
.62669 .12968 L
Mistroke
.62917 .09138 L
.63141 .05031 L
.632 .03929 L
.63262 .02773 L
.63288 .02303 L
.63315 .01802 L
.63331 .01518 L
.63345 .01683 L
.6336 .0194 L
.63373 .02182 L
.63624 .06194 L
.63741 .07684 L
.63864 .08946 L
.6397 .09738 L
.6403 .10066 L
.64086 .10292 L
.64116 .10377 L
.64143 .10437 L
.64159 .10463 L
.64173 .10482 L
.64181 .1049 L
.64189 .10497 L
.64205 .10505 L
.6422 .10507 L
.64228 .10506 L
.64236 .10503 L
.64245 .10498 L
.64252 .10492 L
.6427 .10474 L
.64284 .10453 L
.643 .10425 L
.6433 .10357 L
.64386 .10171 L
.64445 .09898 L
.64553 .0922 L
.64677 .08172 L
.64811 .0678 L
.64927 .05419 L
.65055 .03822 L
.65115 .0305 L
.65179 .02221 L
.65211 .01821 L
.65226 .01626 L
.6524 .01497 L
.65253 .0166 L
.65267 .01832 L
.65296 .02191 L
.6555 .05077 L
.65663 .06126 L
.65785 .07041 L
Mistroke
.65841 .07379 L
.659 .07675 L
.6595 .07878 L
.66005 .08047 L
.66036 .08116 L
.66052 .08146 L
.66069 .08172 L
.66084 .0819 L
.66092 .08198 L
.66101 .08206 L
.66116 .08215 L
.6613 .08221 L
.66144 .08223 L
.6616 .0822 L
.66175 .08214 L
.66189 .08204 L
.66201 .08193 L
.66215 .08177 L
.66242 .08134 L
.66275 .08066 L
.66305 .07988 L
.66373 .07756 L
.66432 .0749 L
.66495 .07152 L
.66733 .05415 L
.66954 .03353 L
.67015 .0275 L
.67081 .02091 L
.67111 .01789 L
.67127 .01624 L
.67143 .01473 L
.67156 .01603 L
.6717 .01743 L
.672 .02038 L
.67424 .04084 L
.67546 .05027 L
.67679 .05867 L
.6774 .06175 L
.67805 .06448 L
.67866 .06651 L
.67922 .06788 L
.6795 .06839 L
.67981 .06882 L
.67996 .06899 L
.68013 .06912 L
.68028 .06922 L
.68043 .06927 L
.68057 .06929 L
.6807 .06928 L
.68084 .06924 L
Mistroke
.681 .06916 L
.68113 .06907 L
.68125 .06896 L
.68154 .06863 L
.68185 .06813 L
.68217 .06747 L
.68275 .06593 L
.68337 .06376 L
.68405 .06084 L
.68642 .04683 L
.68894 .02737 L
.68954 .02243 L
.69018 .01717 L
.69034 .01585 L
.69043 .01511 L
.69051 .01499 L
.69061 .01579 L
.6907 .01654 L
.69087 .01798 L
.69152 .02316 L
.69395 .04095 L
.69511 .04788 L
.69634 .0538 L
.69694 .05607 L
.69751 .05781 L
.69801 .05905 L
.69856 .06003 L
.69885 .06039 L
.69901 .06055 L
.69916 .06066 L
.69929 .06074 L
.69944 .06081 L
.69958 .06084 L
.69971 .06085 L
.69986 .06084 L
.7 .0608 L
.70016 .06073 L
.70024 .06067 L
.70032 .06062 L
.70064 .06031 L
.70097 .05986 L
.70128 .05933 L
.7016 .05865 L
.70219 .0571 L
.70351 .05223 L
.70475 .04617 L
.70609 .03829 L
.70725 .03067 L
.70787 .02643 L
.70852 .0218 L
Mistroke
.70886 .01943 L
.70917 .01719 L
.70931 .01622 L
.70946 .01518 L
.70953 .01479 L
.70962 .01538 L
.70977 .01643 L
.71093 .02445 L
.71347 .03995 L
.7146 .04544 L
.7158 .04998 L
.71642 .05179 L
.71676 .05258 L
.71711 .0533 L
.71744 .05385 L
.71773 .05424 L
.71788 .0544 L
.71803 .05454 L
.71817 .05465 L
.71831 .05474 L
.71846 .0548 L
.7186 .05484 L
.71874 .05487 L
.7189 .05486 L
.71904 .05484 L
.71919 .05479 L
.71933 .05472 L
.71945 .05464 L
.71976 .05437 L
.7201 .05396 L
.72071 .05292 L
.72135 .05141 L
.72203 .04939 L
.72324 .04476 L
.72561 .03273 L
.72667 .02647 L
.72783 .01936 L
.72814 .01738 L
.72832 .01629 L
.7284 .01576 L
.72848 .01527 L
.72862 .01502 L
.72877 .01595 L
.72909 .01792 L
.73028 .02512 L
.73252 .03705 L
.73363 .04181 L
.73481 .04583 L
.73548 .0476 L
.7361 .04883 L
Mistroke
.7364 .0493 L
.73672 .04972 L
.73702 .05001 L
.73716 .05012 L
.7373 .05021 L
.73746 .05028 L
.7376 .05033 L
.73774 .05036 L
.73787 .05037 L
.73802 .05036 L
.73816 .05033 L
.73824 .05031 L
.73832 .05028 L
.73847 .0502 L
.73875 .05001 L
.73905 .04972 L
.73957 .04901 L
.74018 .04785 L
.74076 .04648 L
.74206 .04237 L
.74452 .03152 L
.74561 .02583 L
.74676 .0195 L
.74733 .01631 L
.74749 .01544 L
.74758 .01495 L
.74766 .01493 L
.74781 .0158 L
.74796 .01662 L
.74907 .02266 L
.75158 .0348 L
.75273 .03926 L
.75337 .04132 L
.75396 .04298 L
.75452 .04428 L
.75513 .04539 L
.75539 .04579 L
.75568 .04614 L
.75592 .04638 L
.75618 .04659 L
.75634 .04669 L
.75649 .04676 L
.75663 .04681 L
.75678 .04684 L
.75691 .04685 L
.75704 .04685 L
.75718 .04683 L
.75732 .04679 L
.75747 .04674 L
.75764 .04665 L
Mistroke
.75796 .04641 L
.75827 .04611 L
.75855 .04575 L
.75911 .04486 L
.75962 .04383 L
.76076 .0408 L
.76307 .03213 L
.76427 .02666 L
.76558 .0202 L
.76618 .01719 L
.76635 .01632 L
.76651 .01549 L
.76666 .01475 L
.76674 .0151 L
.76682 .01549 L
.76798 .02125 L
.77052 .03255 L
.77179 .03708 L
.77299 .0404 L
.77352 .04154 L
.77407 .04251 L
.77436 .04292 L
.77468 .0433 L
.77497 .04357 L
.77524 .04377 L
.77539 .04385 L
.77554 .04392 L
.7757 .04397 L
.77579 .04399 L
.77587 .044 L
.77602 .04401 L
.77616 .044 L
.77631 .04398 L
.77647 .04393 L
.77661 .04388 L
.77675 .0438 L
.77701 .04362 L
.77732 .04335 L
.7776 .04303 L
.77822 .04212 L
.7789 .04081 L
.78012 .03765 L
.78252 .02902 L
.78375 .02374 L
.78442 .02069 L
.78506 .01774 L
.78535 .01641 L
.78551 .01568 L
.78565 .015 L
.78581 .01517 L
Mistroke
.7859 .01556 L
.78599 .01598 L
.7863 .0174 L
.78743 .02248 L
.78964 .03134 L
.79089 .03539 L
.79205 .03833 L
.79264 .03948 L
.79326 .04045 L
.79362 .04088 L
.79396 .0412 L
.79426 .04142 L
.79444 .04151 L
.79459 .04158 L
.79474 .04162 L
.79489 .04165 L
.79502 .04166 L
.79516 .04166 L
.79531 .04165 L
.79539 .04163 L
.79547 .04161 L
.79562 .04156 L
.79576 .0415 L
.79603 .04134 L
.79628 .04114 L
.79685 .04053 L
.79743 .03969 L
.79806 .03851 L
.79934 .03537 L
.80169 .02743 L
.80301 .02217 L
.80422 .01704 L
.80437 .01641 L
.80452 .01573 L
.80468 .01509 L
.80481 .01493 L
.80496 .01556 L
.80511 .01622 L
.80545 .01762 L
.80678 .02312 L
.80795 .02757 L
.80921 .03176 L
.81046 .03517 L
.81159 .03749 L
.81214 .03833 L
.81242 .03869 L
.81273 .03901 L
.813 .03924 L
.81329 .03944 L
.81342 .03951 L
Mistroke
.81356 .03957 L
.81368 .03962 L
.81381 .03965 L
.81388 .03967 L
.81397 .03968 L
.81411 .03969 L
.8142 .03969 L
.81428 .03968 L
.81444 .03966 L
.81458 .03963 L
.81472 .03958 L
.81487 .03951 L
.81503 .03943 L
.81539 .03917 L
.81573 .03885 L
.81636 .03805 L
.81696 .03706 L
.81752 .03595 L
.81878 .03281 L
.82104 .02545 L
.82234 .02053 L
.82296 .01811 L
.82353 .01583 L
.82367 .01527 L
.82381 .01473 L
.82396 .01532 L
.8241 .01587 L
.82473 .01834 L
.82587 .02268 L
.82709 .02698 L
.82838 .03095 L
.82954 .03384 L
.83015 .03509 L
.8308 .03619 L
.83141 .03698 L
.83196 .03751 L
.83222 .0377 L
.83236 .03778 L
.83251 .03785 L
.83264 .0379 L
.83278 .03794 L
.83291 .03797 L
.83303 .03799 L
.83317 .038 L
.83332 .038 L
.83347 .03798 L
.8336 .03795 L
.83375 .03791 L
.83392 .03784 L
.83422 .03768 L
Mistroke
.83453 .03745 L
.83487 .03714 L
.83546 .03641 L
.83653 .03462 L
.8377 .03196 L
.84004 .02491 L
.84135 .0203 L
.84198 .01796 L
.84256 .01583 L
.8427 .01528 L
.84286 .01474 L
.84301 .01529 L
.84315 .0158 L
.84378 .01812 L
.84511 .02283 L
.84636 .02688 L
.84753 .03017 L
.84872 .0329 L
.84981 .03477 L
.85043 .03554 L
.85101 .03608 L
.85133 .03628 L
.85163 .03642 L
.85178 .03647 L
.85187 .03649 L
.85195 .03651 L
.85204 .03652 L
.85213 .03653 L
.85221 .03654 L
.8523 .03654 L
.85245 .03653 L
.85253 .03652 L
.85261 .0365 L
.85275 .03647 L
.8529 .03641 L
.85317 .0363 L
.85345 .03612 L
.85376 .03588 L
.85409 .03556 L
.85468 .03483 L
.85584 .03287 L
.8569 .03051 L
.85939 .0233 L
.86049 .01964 L
.86107 .01762 L
.86138 .01656 L
.86154 .01597 L
.8617 .01543 L
.86184 .01495 L
.86199 .015 L
Mistroke
.86207 .0153 L
.86215 .01557 L
.8623 .01609 L
.86285 .018 L
.86394 .02163 L
.86632 .02859 L
.86749 .03126 L
.86813 .03246 L
.86873 .0334 L
.86928 .0341 L
.86978 .0346 L
.87005 .03481 L
.87035 .03499 L
.87051 .03507 L
.87065 .03513 L
.8708 .03518 L
.87095 .03522 L
.8711 .03524 L
.87118 .03525 L
.87126 .03526 L
.87135 .03526 L
.87142 .03525 L
.87151 .03525 L
.8716 .03523 L
.87174 .03521 L
.87188 .03517 L
.87203 .03511 L
.87219 .03504 L
.87252 .03485 L
.87283 .03462 L
.87353 .03391 L
.87414 .03308 L
.8747 .03216 L
.87596 .02956 L
.87825 .0234 L
.87955 .01929 L
.88017 .01728 L
.88044 .01639 L
.8806 .01588 L
.88074 .0154 L
.88088 .01495 L
.88103 .01496 L
.88118 .01548 L
.88133 .01595 L
.88196 .01801 L
.88311 .02162 L
.88442 .0254 L
.88564 .02845 L
.88684 .0309 L
.88793 .03257 L
Mistroke
.88855 .03326 L
.88914 .03373 L
.88946 .03391 L
.88962 .03397 L
.88976 .03403 L
.88992 .03407 L
.89 .03409 L
.89009 .0341 L
.89018 .03411 L
.89027 .03412 L
.89035 .03412 L
.89043 .03412 L
.89058 .03411 L
.89071 .03409 L
.89086 .03406 L
.89102 .03401 L
.89128 .03391 L
.89157 .03375 L
.89188 .03353 L
.89222 .03323 L
.89282 .03257 L
.89415 .0305 L
.89536 .02798 L
.89787 .02126 L
.89897 .01791 L
.89956 .0161 L
.89973 .01557 L
.89981 .01531 L
.89988 .01507 L
.90003 .0148 L
.90018 .01529 L
.90135 .01887 L
.90244 .02207 L
.90367 .02536 L
.90483 .02804 L
.906 .03024 L
.90708 .03175 L
.90766 .03234 L
.90796 .03258 L
.90827 .03278 L
.90844 .03287 L
.90859 .03294 L
.90875 .033 L
.90889 .03304 L
.90905 .03308 L
.90914 .0331 L
.90923 .03311 L
.90939 .03312 L
.90948 .03311 L
.90956 .03311 L
Mistroke
.90971 .03309 L
.9098 .03308 L
.90987 .03307 L
.91002 .03303 L
.91016 .03298 L
.91047 .03284 L
.91081 .03263 L
.91143 .03212 L
.91201 .03148 L
.91309 .02987 L
.91424 .02766 L
.91664 .0217 L
.91768 .01873 L
.91824 .01711 L
.91854 .01622 L
.91882 .01538 L
.91897 .01496 L
.91912 .01493 L
.9192 .01518 L
.91929 .01544 L
.91945 .0159 L
.92003 .0176 L
.92118 .02085 L
.9224 .02404 L
.9237 .02701 L
.92495 .02931 L
.92608 .03086 L
.92663 .0314 L
.92692 .03163 L
.92722 .03184 L
.92749 .03198 L
.92763 .03204 L
.92778 .0321 L
.92792 .03214 L
.92805 .03217 L
.92818 .03219 L
.9283 .0322 L
.92845 .03221 L
.92853 .03221 L
.92861 .03221 L
.92876 .03219 L
.92891 .03217 L
.92904 .03213 L
.92917 .0321 L
.92946 .03198 L
.92977 .03181 L
.93006 .03162 L
.93069 .03106 L
.93124 .03043 L
.93183 .02961 L
Mistroke
.93291 .02777 L
.9353 .02235 L
.93653 .0191 L
.9372 .01723 L
.93753 .0163 L
.93784 .01543 L
.93799 .01502 L
.93812 .0148 L
.93828 .01525 L
.93843 .01565 L
.93907 .01744 L
.9402 .02048 L
.9424 .02573 L
.94358 .02796 L
.94422 .02896 L
.94482 .02975 L
.94538 .03035 L
.94588 .03078 L
.94615 .03097 L
.94645 .03113 L
.94661 .0312 L
.94676 .03126 L
.9469 .0313 L
.94705 .03134 L
.94719 .03137 L
.94734 .03139 L
.94748 .03139 L
.94761 .03139 L
.94776 .03138 L
.9479 .03136 L
.94798 .03135 L
.94806 .03133 L
.94821 .03129 L
.94849 .03119 L
.94878 .03104 L
.9493 .03069 L
.94991 .03013 L
.95048 .02946 L
.95178 .02748 L
.95423 .0223 L
.95531 .01958 L
.95647 .01654 L
.95679 .01567 L
.95694 .01525 L
.95709 .01486 L
.95722 .01493 L
.95736 .0153 L
.95766 .01609 L
.95876 .01899 L
.96126 .02485 L
Mistroke
.9624 .027 L
.96304 .02799 L
.96363 .02879 L
.96419 .02942 L
.96479 .02996 L
.96506 .03015 L
.96534 .03032 L
.96558 .03043 L
.96584 .03053 L
.96599 .03058 L
.96613 .03061 L
.96628 .03063 L
.96643 .03065 L
.96658 .03065 L
.96672 .03065 L
.96684 .03064 L
.96698 .03062 L
.96712 .03059 L
.96728 .03055 L
.96761 .03042 L
.96791 .03027 L
.9682 .03009 L
.96875 .02964 L
.96926 .02913 L
.9704 .02761 L
.9727 .02327 L
.9752 .01725 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.0936792 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02798 -12 -4.5 ]
[-0.0125 .02798 0 4.5 ]
[-0.0125 .12166 -12 -4.5 ]
[-0.0125 .12166 0 4.5 ]
[-0.0125 .21534 -12 -4.5 ]
[-0.0125 .21534 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .4027 -6 -4.5 ]
[-0.0125 .4027 0 4.5 ]
[-0.0125 .49638 -6 -4.5 ]
[-0.0125 .49638 0 4.5 ]
[-0.0125 .59005 -6 -4.5 ]
[-0.0125 .59005 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02798 m
.00625 .02798 L
s
[(-3)] -0.0125 .02798 1 0 Mshowa
0 .12166 m
.00625 .12166 L
s
[(-2)] -0.0125 .12166 1 0 Mshowa
0 .21534 m
.00625 .21534 L
s
[(-1)] -0.0125 .21534 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .4027 m
.00625 .4027 L
s
[(1)] -0.0125 .4027 1 0 Mshowa
0 .49638 m
.00625 .49638 L
s
[(2)] -0.0125 .49638 1 0 Mshowa
0 .59005 m
.00625 .59005 L
s
[(3)] -0.0125 .59005 1 0 Mshowa
.125 Mabswid
0 .04672 m
.00375 .04672 L
s
0 .06545 m
.00375 .06545 L
s
0 .08419 m
.00375 .08419 L
s
0 .10292 m
.00375 .10292 L
s
0 .14039 m
.00375 .14039 L
s
0 .15913 m
.00375 .15913 L
s
0 .17787 m
.00375 .17787 L
s
0 .1966 m
.00375 .1966 L
s
0 .23407 m
.00375 .23407 L
s
0 .25281 m
.00375 .25281 L
s
0 .27155 m
.00375 .27155 L
s
0 .29028 m
.00375 .29028 L
s
0 .32775 m
.00375 .32775 L
s
0 .34649 m
.00375 .34649 L
s
0 .36522 m
.00375 .36522 L
s
0 .38396 m
.00375 .38396 L
s
0 .42143 m
.00375 .42143 L
s
0 .44017 m
.00375 .44017 L
s
0 .4589 m
.00375 .4589 L
s
0 .47764 m
.00375 .47764 L
s
0 .51511 m
.00375 .51511 L
s
0 .53385 m
.00375 .53385 L
s
0 .55258 m
.00375 .55258 L
s
0 .57132 m
.00375 .57132 L
s
0 .00924 m
.00375 .00924 L
s
0 .60879 m
.00375 .60879 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02798 m
1 .02798 L
s
.99375 .12166 m
1 .12166 L
s
.99375 .21534 m
1 .21534 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .4027 m
1 .4027 L
s
.99375 .49638 m
1 .49638 L
s
.99375 .59005 m
1 .59005 L
s
.125 Mabswid
.99625 .04672 m
1 .04672 L
s
.99625 .06545 m
1 .06545 L
s
.99625 .08419 m
1 .08419 L
s
.99625 .10292 m
1 .10292 L
s
.99625 .14039 m
1 .14039 L
s
.99625 .15913 m
1 .15913 L
s
.99625 .17787 m
1 .17787 L
s
.99625 .1966 m
1 .1966 L
s
.99625 .23407 m
1 .23407 L
s
.99625 .25281 m
1 .25281 L
s
.99625 .27155 m
1 .27155 L
s
.99625 .29028 m
1 .29028 L
s
.99625 .32775 m
1 .32775 L
s
.99625 .34649 m
1 .34649 L
s
.99625 .36522 m
1 .36522 L
s
.99625 .38396 m
1 .38396 L
s
.99625 .42143 m
1 .42143 L
s
.99625 .44017 m
1 .44017 L
s
.99625 .4589 m
1 .4589 L
s
.99625 .47764 m
1 .47764 L
s
.99625 .51511 m
1 .51511 L
s
.99625 .53385 m
1 .53385 L
s
.99625 .55258 m
1 .55258 L
s
.99625 .57132 m
1 .57132 L
s
.99625 .00924 m
1 .00924 L
s
.99625 .60879 m
1 .60879 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02847 .53133 L
.03355 .45281 L
.03602 .41463 L
.03832 .37907 L
.04054 .34481 L
.04118 .33494 L
.04178 .32562 L
.04232 .31724 L
.04247 .31495 L
.04263 .31252 L
.04276 .31044 L
.04291 .60246 L
.04307 .60006 L
.04321 .59783 L
.04354 .59278 L
.04414 .58357 L
.04525 .56629 L
.04777 .52739 L
.05249 .45447 L
.0549 .41725 L
.05751 .37699 L
.05873 .35808 L
.06002 .3381 L
.06113 .32105 L
.06143 .31637 L
.0616 .3138 L
.06175 .31136 L
.0619 .3091 L
.06206 .60094 L
.0622 .5987 L
.06234 .59663 L
.06707 .52346 L
.07163 .45311 L
.07416 .41403 L
.07647 .3782 L
.07875 .34308 L
.07989 .32542 L
.0802 .32058 L
.08054 .31541 L
.0807 .31291 L
.08085 .31054 L
.08099 .60271 L
.08114 .60041 L
.08608 .52416 L
.09083 .45073 L
.0954 .38013 L
.09774 .3439 L
.09842 .33346 L
.09906 .32355 L
Mistroke
.09963 .31466 L
.09979 .31222 L
.09988 .31089 L
.09996 .30963 L
.10012 .60148 L
.10026 .59927 L
.10492 .52733 L
.10987 .45083 L
.11234 .4127 L
.11464 .37715 L
.11685 .34293 L
.11749 .33308 L
.11809 .32376 L
.11864 .31539 L
.11878 .31309 L
.11894 .31066 L
.11908 .60289 L
.11922 .6006 L
.12408 .52559 L
.12875 .4534 L
.13112 .41671 L
.13372 .37664 L
.13492 .3581 L
.1362 .33831 L
.13682 .32871 L
.13741 .31965 L
.13766 .31569 L
.13793 .31151 L
.13808 .30933 L
.13823 .60123 L
.13837 .59905 L
.1385 .59701 L
.14319 .52456 L
.14818 .44755 L
.15067 .40903 L
.15298 .37336 L
.15522 .33877 L
.15635 .3213 L
.15666 .31651 L
.15682 .314 L
.15699 .31135 L
.15714 .30902 L
.15723 .602 L
.15731 .60078 L
.1576 .5963 L
.1623 .5236 L
.1673 .44634 L
.16981 .40762 L
.17212 .37189 L
.17437 .33712 L
Mistroke
.17551 .31958 L
.17582 .31478 L
.17599 .31213 L
.17607 .31082 L
.17615 .30961 L
.1763 .60158 L
.17638 .60035 L
.17647 .59904 L
.17676 .59458 L
.18177 .51705 L
.18661 .44236 L
.19126 .37048 L
.19367 .3333 L
.19425 .32426 L
.19488 .31458 L
.19506 .31172 L
.19515 .31032 L
.19524 .30902 L
.19539 .60089 L
.19548 .59962 L
.19557 .59826 L
.19621 .58834 L
.20076 .51796 L
.20561 .44301 L
.21028 .37088 L
.2127 .33351 L
.21329 .32442 L
.21392 .31472 L
.2141 .31185 L
.21419 .31044 L
.21428 .30914 L
.21443 .60101 L
.21452 .59973 L
.21461 .59838 L
.21525 .58848 L
.21982 .51785 L
.22469 .44264 L
.22937 .37026 L
.23059 .35136 L
.23193 .33077 L
.23254 .32135 L
.23287 .31618 L
.23303 .31365 L
.23318 .31132 L
.23333 .30911 L
.23348 .60108 L
.23363 .59873 L
.2338 .59617 L
.23435 .5876 L
.23923 .51214 L
Mistroke
.24394 .43951 L
.24633 .40249 L
.24893 .3623 L
.25015 .34353 L
.25081 .33326 L
.25144 .32363 L
.25197 .31544 L
.25212 .31309 L
.25226 .31084 L
.25239 .60314 L
.25254 .60094 L
.25375 .58222 L
.25865 .5065 L
.26336 .43361 L
.26577 .3964 L
.26838 .35615 L
.2696 .33725 L
.27027 .32692 L
.27089 .31728 L
.27117 .31306 L
.2713 .31098 L
.27143 .30905 L
.27157 .60114 L
.27172 .59874 L
.272 .59453 L
.27321 .57581 L
.27794 .50266 L
.28249 .43234 L
.28502 .39328 L
.28734 .35745 L
.28852 .33927 L
.28961 .32235 L
.29017 .31382 L
.29032 .31136 L
.29047 .30904 L
.29061 .60126 L
.29076 .599 L
.29201 .57968 L
.29694 .50346 L
.30169 .43006 L
.30626 .35948 L
.30746 .3409 L
.3086 .32326 L
.30891 .31855 L
.30923 .31353 L
.30933 .31204 L
.30942 .31064 L
.3095 .30938 L
.30959 .60233 L
.30967 .60103 L
Mistroke
.30976 .59967 L
.30992 .59722 L
.31112 .57863 L
.31571 .5078 L
.32059 .4324 L
.32528 .35982 L
.32651 .34083 L
.32716 .33081 L
.32785 .32019 L
.32814 .31572 L
.32829 .31338 L
.32845 .31092 L
.32853 .3096 L
.32863 .60247 L
.32871 .60116 L
.32879 .59994 L
.32911 .595 L
.33028 .57698 L
.33499 .50415 L
.34 .42674 L
.34251 .38792 L
.34483 .35217 L
.34599 .33414 L
.34656 .32533 L
.34708 .3173 L
.34722 .31521 L
.34736 .31295 L
.3475 .3108 L
.34763 .60312 L
.34777 .60103 L
.34792 .59871 L
.34822 .59403 L
.34947 .57472 L
.35431 .49988 L
.35897 .42788 L
.36134 .39133 L
.36393 .3513 L
.36512 .33285 L
.36578 .3227 L
.3661 .31771 L
.36625 .31552 L
.3664 .31311 L
.36655 .31087 L
.36668 .60308 L
.36683 .60086 L
.36698 .59848 L
.36761 .58879 L
.3687 .57185 L
.37368 .49501 L
.37847 .42101 L
Mistroke
.38307 .34982 L
.3843 .33094 L
.3849 .32167 L
.38516 .31761 L
.38545 .31315 L
.38552 .31196 L
.38561 .31068 L
.38576 .60267 L
.38584 .60131 L
.38593 .60002 L
.38608 .59761 L
.38677 .58695 L
.38798 .56837 L
.3926 .49693 L
.39752 .42092 L
.40226 .34774 L
.40681 .27738 L
.41166 .20245 L
.41633 .13035 L
.4187 .09372 L
.42129 .05367 L
.42249 .03517 L
.42314 .02501 L
.42347 .02001 L
.42361 .01782 L
.42376 .01541 L
.42391 .30747 L
.42405 .30537 L
.42434 .30076 L
.42497 .29106 L
.42607 .27412 L
.43075 .20176 L
.43573 .12483 L
.43822 .08638 L
.44053 .05073 L
.44168 .03294 L
.44224 .02421 L
.44249 .02039 L
.44262 .01837 L
.44276 .0162 L
.44291 .30817 L
.44305 .30599 L
.44336 .30123 L
.44401 .29121 L
.44514 .27375 L
.45014 .19656 L
.45495 .1222 L
.45715 .08817 L
.4584 .06882 L
.45958 .05067 L
Mistroke
.46073 .03288 L
.46106 .02776 L
.46138 .02289 L
.46166 .01851 L
.46174 .01732 L
.46182 .01604 L
.46197 .30804 L
.46205 .30675 L
.46214 .3054 L
.4623 .30296 L
.46265 .29747 L
.4633 .2875 L
.4645 .26887 L
.46908 .19815 L
.47395 .12287 L
.4762 .08818 L
.47864 .05042 L
.47929 .04046 L
.47997 .02988 L
.48056 .02085 L
.48072 .01837 L
.4808 .01707 L
.48089 .0157 L
.48097 .3088 L
.48105 .30749 L
.4812 .30517 L
.48363 .26769 L
.48852 .19215 L
.49322 .11944 L
.49562 .08237 L
.49688 .06285 L
.49822 .04216 L
.4988 .03328 L
.49942 .02372 L
.4996 .02092 L
.49977 .01825 L
.49993 .01586 L
.50001 .60311 L
.5001 .60185 L
.50073 .59204 L
.50304 .55631 L
.50777 .48334 L
.51278 .4058 L
.5153 .36688 L
.51641 .34981 L
.51762 .33109 L
.51818 .32236 L
.5185 .31755 L
.51865 .31519 L
.51879 .313 L
Mistroke
.51892 .31095 L
.51906 .60307 L
.51921 .60088 L
.51936 .59847 L
.51988 .59043 L
.52227 .55351 L
.52712 .47854 L
.53179 .4064 L
.53416 .36975 L
.53542 .35037 L
.53676 .32969 L
.53743 .31936 L
.53775 .31429 L
.5379 .31206 L
.53806 .30962 L
.5382 .60172 L
.53833 .59967 L
.53862 .59517 L
.53924 .5857 L
.54154 .5501 L
.54623 .4777 L
.55121 .40074 L
.5537 .36225 L
.55491 .34353 L
.55601 .32659 L
.55656 .31803 L
.55671 .31568 L
.55687 .31321 L
.55701 .3111 L
.55716 .60309 L
.5573 .60089 L
.55743 .5989 L
.55772 .59442 L
.55824 .58634 L
.56062 .54958 L
.56544 .47518 L
.57007 .40361 L
.57241 .36738 L
.57366 .34815 L
.57434 .33755 L
.575 .32746 L
.57561 .31801 L
.57578 .31543 L
.57595 .31267 L
.57604 .31132 L
.57612 .31006 L
.57628 .602 L
.57642 .5998 L
.57657 .59748 L
.57684 .59331 L
Mistroke
.57745 .58391 L
.57974 .54845 L
.58432 .4777 L
.5892 .40238 L
.59389 .32989 L
.59888 .25282 L
.60368 .17858 L
.6083 .10717 L
.61064 .07105 L
.61188 .05187 L
.61253 .04179 L
.61322 .03118 L
.61383 .02178 L
.61399 .01921 L
.61409 .01779 L
.61417 .01646 L
.61425 .01521 L
.61434 .30816 L
.61449 .3058 L
.61566 .28775 L
.61795 .25232 L
.62289 .17608 L
.62764 .10267 L
.63003 .06578 L
.63107 .04966 L
.63221 .03208 L
.63251 .02741 L
.63283 .02243 L
.63299 .02002 L
.63314 .01774 L
.63327 .0157 L
.63341 .30779 L
.63355 .30566 L
.6337 .30332 L
.63401 .2986 L
.63455 .29015 L
.63707 .25122 L
.64196 .1758 L
.64665 .10321 L
.64905 .06623 L
.65031 .04673 L
.651 .03606 L
.65165 .02605 L
.65193 .02174 L
.65222 .0172 L
.65237 .01482 L
.65246 .30778 L
.65254 .30653 L
.65284 .30197 L
.65415 .28172 L
Mistroke
.65646 .24601 L
.66117 .17317 L
.66618 .09575 L
.6687 .05692 L
.6698 .03988 L
.67038 .03085 L
.67071 .02588 L
.67101 .02116 L
.67115 .01897 L
.6713 .01665 L
.67138 .01543 L
.67147 .3084 L
.67162 .30603 L
.67218 .29743 L
.67327 .28058 L
.67566 .24369 L
.6805 .16885 L
.68516 .09683 L
.68753 .06026 L
.68878 .04092 L
.68947 .03028 L
.68981 .02506 L
.69012 .02023 L
.69027 .01783 L
.69042 .01558 L
.69057 .30753 L
.69065 .30628 L
.69074 .30494 L
.69141 .29453 L
.69259 .27634 L
.69489 .24077 L
.69987 .16392 L
.70466 .0899 L
.70707 .05255 L
.70813 .03629 L
.70868 .02773 L
.70898 .02306 L
.70927 .0187 L
.70941 .01644 L
.70957 .30831 L
.70966 .30693 L
.70974 .30562 L
.7099 .30316 L
.71049 .29411 L
.71164 .27632 L
.71417 .23724 L
.71879 .16578 L
.72371 .08976 L
.72616 .052 L
.72736 .03351 L
Mistroke
.72788 .02541 L
.72816 .02113 L
.72831 .01878 L
.72845 .01656 L
.72859 .30871 L
.72874 .30638 L
.72901 .30231 L
.72952 .29436 L
.73064 .27699 L
.73301 .24049 L
.73794 .16421 L
.7427 .09076 L
.74509 .05385 L
.74613 .03771 L
.74668 .0292 L
.74727 .02013 L
.74744 .01752 L
.7476 .01506 L
.74774 .30716 L
.74789 .30478 L
.74847 .29583 L
.74962 .27817 L
.75214 .23924 L
.75709 .1627 L
.76186 .089 L
.76426 .05189 L
.76531 .0357 L
.76586 .02716 L
.76616 .02249 L
.76645 .01811 L
.76659 .01588 L
.76675 .30778 L
.76683 .30642 L
.76692 .30512 L
.76708 .30268 L
.76766 .29368 L
.76881 .27597 L
.77133 .23696 L
.77593 .16583 L
.78083 .09012 L
.7831 .05511 L
.78429 .0367 L
.78494 .02663 L
.78526 .02172 L
.78555 .01723 L
.78571 .01478 L
.78586 .30676 L
.78602 .30431 L
.78619 .30164 L
.7869 .29077 L
Mistroke
.78813 .27166 L
.79056 .23408 L
.79548 .15812 L
.79792 .12041 L
.80021 .08498 L
.8024 .05115 L
.803 .04189 L
.80364 .03212 L
.80417 .02379 L
.80432 .02151 L
.80448 .01907 L
.80463 .01676 L
.80476 .30897 L
.80491 .30675 L
.80504 .30467 L
.80535 .29995 L
.80597 .29039 L
.80708 .27324 L
.80958 .2345 L
.81427 .16219 L
.81665 .12541 L
.81924 .0853 L
.82045 .0667 L
.82173 .04688 L
.82235 .03725 L
.82294 .02818 L
.82346 .02004 L
.82361 .01781 L
.82376 .01546 L
.82389 .30775 L
.82403 .30554 L
.82891 .23015 L
.83361 .15758 L
.836 .12062 L
.8386 .08044 L
.83982 .06171 L
.8411 .04183 L
.8422 .02485 L
.8425 .0202 L
.84266 .01776 L
.84275 .01643 L
.84283 .01519 L
.84297 .30723 L
.84305 .30604 L
.84313 .30476 L
.84341 .30043 L
.84842 .22304 L
.85325 .14847 L
.85789 .07673 L
.86029 .03964 L
Mistroke
.86087 .03063 L
.8615 .02095 L
.86169 .0181 L
.86178 .0167 L
.86186 .0154 L
.86202 .30728 L
.8621 .306 L
.86219 .30464 L
.86283 .29471 L
.86738 .22446 L
.87222 .14964 L
.87688 .07764 L
.87929 .04036 L
.87988 .0313 L
.88051 .02161 L
.88069 .01875 L
.88078 .01734 L
.88087 .01604 L
.88102 .30791 L
.88111 .30663 L
.88119 .30528 L
.88184 .29537 L
.8864 .22486 L
.89126 .14978 L
.89593 .07753 L
.89715 .0587 L
.89848 .03814 L
.89909 .02875 L
.89943 .02359 L
.89959 .02106 L
.89974 .01873 L
.89988 .01652 L
.90003 .30849 L
.90019 .30615 L
.90035 .30358 L
.90091 .29501 L
.90578 .21968 L
.91048 .14717 L
.91286 .11025 L
.91546 .07009 L
.91667 .05139 L
.91734 .04114 L
.91796 .03152 L
.91849 .02336 L
.91863 .02112 L
.91879 .01877 L
.91892 .01676 L
.91906 .30886 L
.91922 .3064 L
.91936 .30417 L
Mistroke
.91969 .29916 L
.92027 .29014 L
.92509 .21563 L
.92973 .14394 L
.93208 .10763 L
.93467 .06769 L
.93585 .0494 L
.9365 .03932 L
.93712 .02975 L
.9377 .02088 L
.93785 .01845 L
.93794 .01711 L
.93802 .01586 L
.93818 .30772 L
.93832 .30551 L
.93942 .28856 L
.94408 .21662 L
.94903 .14011 L
.95149 .10198 L
.9538 .06643 L
.95493 .04884 L
.95601 .03221 L
.95661 .02302 L
.95677 .0205 L
.95694 .01783 L
.95709 .01554 L
.95717 .30855 L
.95725 .30733 L
.95838 .28987 L
.96305 .21768 L
.96802 .14092 L
.97281 .06698 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000U2000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00??ooool3
o`0002;ooooo1Ol0000Qooooo`;o00009?ooool5o`0002Cooooo0ol0001Iooooo`?o00008_ooool5
o`0002;ooooo0_l0000Tooooo`Go00009?ooool3o`0002Sooooo000mooooo`03o`000?oooooooooo
02;ooooo00Co0000oooooooooooo00008?ooool01?l0003oooooooooool0000Tooooo`04o`000?oo
ooooooooo`0002Gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Rooooo`04o`00
0?ooooooooooo`00027ooooo00Co0000oooooooooooo00009?ooool01?l0003oooooooooool0000U
ooooo`03o`000?oooooooooo02Oooooo000dooooo`Go000000?oooooo`000?l000000ol0000Loooo
o`Go00000oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0002Gooooo00?o0000
ooooooooool08_ooool5o`00057ooooo1Ol000000ooooooo0000o`000003o`0001cooooo1Ol00003
ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00009Oooool00ol0003ooooooooo
o`0Rooooo`Go0000:?ooool003[ooooo00Co0000oooooooooooo00009_ooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool08Oooool01?l0003ooooo
ooooool0001Hooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool08?ooool01?l0
003oooooooooool0000Vooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000:Ooo
ool003_ooooo00?o0000ooooool000008oooool01Ol0003ooooooooooooooooo0000023ooooo00Co
0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooool0
0000FOooool00ol0003oooooo`00000Sooooo`05o`000?ooooooooooooooool000008Oooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooo`00
000Yooooo`00??ooool2o`0002?ooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?oo
ooooooooo`0002?ooooo00Go0000ooooooooooooooooo`00000Tooooo`;o0000F_ooool2o`0002?o
oooo00Go0000ooooooooooooooooo`00000Qooooo`04o`000?ooooooooooo`0002?ooooo00Go0000
ooooooooooooooooo`00000Tooooo`;o0000:Oooool003gooooo00?o0000ooooooooool08_ooool3
o`0002;ooooo0_l0000Uooooo`?o00009_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo02;ooooo0ol0000Sooooo`;o00009Oooool3o`0002Kooooo00?o0000ooooooooool09oooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool0027ooooocol0000Wooooom7o00004?oo
ool001_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000009oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00kooooo000Jooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool09Oooool2o`0001Oooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Eooooo`;o00004?ooool001[ooooo00Co0000oooooooooooo00000oooool3o`0000;ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool03Oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool0000?ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooo
ooooooooo`000oooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000;ooooo0_l0000Wooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool07Ooo
ool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool09?oo
ool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo000Jooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001oooool01Ooo003o
ooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`0000Coooooool00?oo003oo`000_ooool2
ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00Gooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooooooo`02ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo0ol00005ooooo`03o`00
0?oooooooooo05Gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00001?ooool00ol0003oooooooooo`0>ooooo`006_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool00003
oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0ooo
00000ooooooo0000ooooo`04ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo00000oooooooo`00ool00002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo
00;ooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0EOooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo01Gooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ol0003oooooooooo`0>ooooo`006_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00?ooooo0ooo00004oooooooo`00ool00?oo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`00
0_ooool01Ooo003ooooooooooooooooo000000Cooooo00Coo`00ooooooooooooo`000oooool01Ooo
003oooooooooooooooooo`0000Oooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00003oooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooo`03ool00005oooooooo003oo`00ool00?oo
ool00_oo0002ooooo`;oo`001Oooool00ol0003oooooooooo`0Fooooo`Go00001Oooool00ol0003o
ooooooooo`02ooooo`;o0000E_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo01Gooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo
0_l0000@ooooo`006oooool2o`0000Cooooo00?o0000ooooooooool01?ooool01?oo003ooooooooo
ooooool2ool00005oooooooo003oo`00ool00?ooool00ooo00001Oooooooo`00ool00?oo003ooooo
00?oo`0000Goooooool00?oo003oo`00ooooo`03ool00003oooooooo003oo`0000;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`000_ooool2ool000;ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00;oo`000_ooool2ool00003oooooooo003ooooo00?o
oooo00?o0000ooooooooool00oooool01?oo003oooooool00?oo0002ooooo`05ool00?oooooooooo
oooooooo00001oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`0000_oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`03
ool00005oooooooo003oo`00ool00?ooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0005ooooo`03o`000?oooooooooo01kooooo0_l00005ooooo`03o`000?oooooooooo05Gooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooooooo`0Eooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00001?ooool00ol0003oooooooooo`0>ooooo`008Oooool2o`00
01Wooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool0000>oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo0002ooooo`;oo`0000?oooooool00?oo00000oooool01Ooo003ooooooooooooo
ooooo`0000Kooooo0_oo0002ooooo`;oo`000_ooool01?oo003oooooool00?oo0004ooooo`03o`00
0?oooooooooo00?ooooo0_oo00001Oooooooo`00ooooooooooooo`0000?ooooo00?oo`00oooooooo
ool01Oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00000oooooooo`00ooooo`03ool0
0005oooooooo003oo`00ool00?ooool00_oo0003ooooo`05ool00?oooooooooooooooooo00006Ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0EOoo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo01Gooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`000oooool00ooo
003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00004ooooo`03o`000?oooooooooo00kooooo000Qooooo`03
o`000?oooooooooo02Cooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo00003oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00ooooo`02ool000?ooooo00Goo`00ooooooooooooooooool00006ooooo`;oo`000_ooool2
ool00005oooooooo003ooooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`;oo`0000Co
ooooool00?oooooooooo0_oo0002ooooo`03ool00?oooooooooo00Gooooo00Goo`00oooooooooooo
ooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Coooooool00?oo
oooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo
02?ooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0EOooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo01Cooooo0_oo0003ooooo`03ool00?oooooooooo00;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`04ool00?ooooooooooool000Gooooo00?o0000ooooooooool03_ooool0027ooooo00?o
0000ooooooooool0;oooool2ool000;ooooo0_oo0002ooooo`;oo`0000_oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooo`02ool000?ooooo00Goo`00ooooooooooooooooool0
0006ooooo`;oo`000_ooool2ool00003oooooooo003ooooo00Oooooo00?o0000ooooooooool01_oo
ool00ooo003oooooooooo`02ool000;ooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool01_oo003oooooool00?ooooooo`00ooooo`;o
o`000_ooool2ool000;ooooo0_oo000`ooooo`03o`000?oooooooooo01gooooo0ol00005ooooo`;o
0000E_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo01Cooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo
003ooooooooooooo0004ooooo`;o00004?ooool0027ooooo00?o0000ooooooooool0<oooool2ool0
00;ooooo0_oo00003_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`000_ooool01Ooo003oooooooooooooooooo`0000Kooooo0_oo0002ooooo`;oo`0000?o
ooooool00?ooool01oooool00ol0003oooooooooo`06ooooo`05ool00?ooooooo`00oooooooo0000
0_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo
00Koo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`00=?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo05Gooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Dooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`001Oooool00ol0003ooooooooo
o`0>ooooo`008Oooool00ol0003oooooooooo`0gooooo`04ool00?ooooooooooooooo`;oo`0000_o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool000;ooooo0_oo0006
ooooo`;oo`000_ooool01?oo003oooooool00?oo0008ooooo`03o`000?oooooooooo00Oooooo0_oo
00001Oooooooo`00ooooooooooooo`0000Oooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`00
0_ooool01?oo003oooooool00?oo0002ooooo`;oo`000_ooool2ool003Sooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1Eooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000;ooooo0_oo000Fooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Coo`00ooooooooooooo`001Oooool00ol0003oooooooooo`0>ooooo`008Oooool2o`00
03cooooo0_oo00003oooooooo`00ool00?oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00ooooo`02ool000Kooooo0_oo0002ooooo`04ool00?ooooooo`00ool000Sooooo00?o
0000ooooooooool01oooool2ool00005oooooooo003ooooooooooooo00001oooool00ooo003ooooo
ooooo`02ool000;ooooo00Koo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo000loooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0EOooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`005_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`04ool00?ooooooooooool000Gooooo00?o0000ooooooooool03_oo
ool0027ooooo00?o0000ooooooooool0?oooool2ool0000;oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooool00_oo0006ooooo`;oo`0000Coooooool00?oooooooooo0_oo0008
ooooo`03o`000?oooooooooo00Oooooo0_oo00001Oooooooo`00ooooooooooooo`0000Oooooo00?o
o`00ooooooooool00_oo0002ooooo`04ool00?ooooooo`00ool000;ooooo0_oo0010ooooo`03o`00
0?oooooooooo02Gooooo0_l0001Fooooo`05ool00?oooooooooooooooooo00000_ooool2ool000?o
oooo00?oo`00ooooooooool00_oo000Fooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo
00Coo`00ooooooooooooo`001?ooool2o`00013ooooo000Qooooo`03o`000?oooooooooo03oooooo
00goo`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00;oo`00
1_ooool2ool00003oooooooo003ooooo00_ooooo00?o0000ooooooooool02_ooool00ooo003ooooo
ooooo`02ool000Kooooo00Woo`00ooooooooooooo`00oooooooo003oooooool00?ooool00_oo0002
ooooo`;oo`00@?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05Gooooo00?oo`00
ooooooooool00_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`02ool001Kooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0003ooooo`05ool0
0?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0005ooooo`03o`000?oooooooooo
00kooooo000Qooooo`03o`000?oooooooooo04;ooooo0ooo00001oooooooo`00oooooooo003ooooo
ool00?ooool00_oo0006ooooo`;oo`0000?oooooool00?ooool02oooool00ol0003oooooooooo`0:
ooooo`05ool00?ooooooo`00oooooooo00001_ooool02Ooo003ooooooooooooo003oooooool00?oo
ooooo`00ooooo`02ool004Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Eoooo
o`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`005_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooool000Gooooo00?o0000oooooooo
ool03_ooool0027ooooo00?o0000ooooooooool0@oooool02Ooo003ooooooooooooo003oooooool0
0?ooooooo`00ooooo`02ool000Kooooo0_oo00000oooooooo`00ooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00Goo`00oooooooo003oooooool00006ooooo`09ool00?ooooooooooool00?oooooo
o`00oooooooo003ooooo00;oo`00A?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05Cooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`005_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooool000Gooooo00?o0000oooooooo
ool03_ooool0027ooooo0_l00017ooooo`06ool00?ooooooo`00oooooooo003ooooo0_oo0006oooo
o`;oo`0000?oooooool00?ooool02oooool00ol0003oooooooooo`0:ooooo`05ool00?ooooooo`00
oooooooo00001_ooool02?oo003ooooooooooooo003oooooool00?ooooooo`00Aoooool00ol0003o
ooooooooo`0Uooooo`;o0000EOooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo000Fooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00;oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`00
1?ooool2o`00013ooooo000Qooooo`03o`000?oooooooooo04Kooooo00Koo`00oooooooo003ooooo
ool00?ooool2ool000Kooooo0_oo00000oooooooo`00ooooo`0;ooooo`03o`000?oooooooooo00[o
oooo00Goo`00oooooooo003oooooool00006ooooo`05ool00?ooooooooooool00?ooool00_oo0018
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0E?ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo000Fooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00;oo`000oooool00ooo003oooooooooo`02ool000;ooooo
0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool03_ooool0027ooooo00?o
0000ooooooooool0A_ooool3ool00003oooooooo003ooooo00;oo`001_ooool2ool00003oooooooo
003ooooo00_ooooo00?o0000ooooooooool02_ooool01Ooo003oooooool00?ooooooo`0000Kooooo
00Goo`00ooooooooooooo`00ooooo`02ool004Sooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1Dooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool001Ko
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?o0000
ooooooooool03_ooool0027ooooo00?o0000ooooooooool0Aoooool2ool00003oooooooo003ooooo
00;oo`001_ooool01?oo003oooooool00?oo000<ooooo`03o`000?oooooooooo00_ooooo0_oo0000
0oooooooo`00ooooo`05ooooo`05ool00?ooooooooooool00?ooool00_oo0018ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0E?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo000Fooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003o
ooooooooo`03ooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo04Oooooo
00Goo`00ooooooooooooo`00ooooo`02ool000Kooooo00Coo`00oooooooo003oo`003?ooool00ol0
003oooooooooo`0;ooooo`;oo`0000?oooooool00?ooool01Oooool01Ooo003ooooooooooooo003o
oooo00;oo`00B?ooool00ol0003oooooooooo`0Uooooo`;o0000EOooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo000Fooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`0000?oooooool00?oo00000oooool00ooo003oooooooooo`02ool000?ooooo00Goo`00
ooooooooooooooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool00ooo003oooooooooo`02ooooo`;o00004?ooool0027ooooo0_l0001;ooooo`04ool00?oooooo
o`00ool000Kooooo00Coo`00oooooooo003oo`003?ooool00ol0003oooooooooo`0;ooooo`;oo`00
00?oooooool00?ooool01?ooool01Ooo003oooooool00?ooooooo`0004_ooooo00?o0000oooooooo
ool07?ooool5o`0000Cooooo00?o0000ooooooooool0E?ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo000Fooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`0000?oooooool00?oo00000_ooool2ool000;ooooo0_oo0003ooooo`05ool00?oooooooooooooo
oooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00003oooooooo003ooooo
00Gooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0B_ooool01?oo003o
ooooool00?oo0006ooooo`04ool00?ooooooo`00ool000cooooo00?o0000ooooooooool02oooool2
ool00003oooooooo003ooooo00Cooooo00Coo`00oooooooo003oo`00C?ooool00ol0003ooooooooo
o`0Mooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0E?ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo000Fooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo00001Oooooooo`00oooooooo003ooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00003
oooooooo003ooooo00Gooooo00?o0000ooooooooool03_ooool000oooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo04[ooooo00Coo`00oooooooo003o
o`001_ooool01?oo003oooooool00?oo000<ooooo`03o`000?oooooooooo00_ooooo0_oo00000ooo
ooooo`00ooooo`04ooooo`04ool00?ooooooo`00ool004cooooo00?o0000ooooooooool05_ooool5
o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Dooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool001Kooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool00005oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`0000Coooooool00?ooooooo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
00?oooooool00?ooool01Oooool00ol0003oooooooooo`0>ooooo`003_ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1:ooooo`04
ool00?ooooooo`00ool000Kooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0>oooo
o`03ool00?oooooooooo00?ooooo00Coo`00oooooooo003oo`00C?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00?ooooo0_l0001Eooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool001Kooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00005oooooooo003o
ooooool00?ooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Co
ooooool00?ooooooo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?ooool0
1?ooool2o`00013ooooo000>ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000oooooooooooo
ooooo`00001<ooooo`04ool00?ooooooo`00ool000Kooooo00?oo`00ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooooooo003oo`00C?ooool0
0ol0003oooooooooo`0Looooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`1Dooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool001Kooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`00
0_ooool2ool000;ooooo0_oo00002Oooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?ooooooo`00oooooooo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00000oooooooo`00ooooo`05ooooo`03o`000?oo
oooooooo00kooooo000>ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooooooo
0ol0001:ooooo`04ool00?ooooooo`00ool000Kooooo00?oo`00ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooooooo003oo`00Boooool2o`00
01kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05Cooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`005_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo00005Oooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00002?ooooooo`00oooooooo003o
ooooool00?ooooooo`000_ooool2ool000;ooooo0_oo00000oooooooo`00ooooo`05ooooo`03o`00
0?oooooooooo00kooooo000>ooooo`04o`000?ooooooooooo`0000Oooooo1?l00004ooooo`03o`00
0?oooooooooo04[ooooo00Coo`00oooooooo003oo`001_ooool00ooo003oooooooooo`0=ooooo`03
o`000?oooooooooo00kooooo00?oo`00ooooooooool00oooool01?oo003oooooool00?oo001<oooo
o`03o`000?oooooooooo01gooooo0ol00005ooooo`03o`000?oooooooooo05Cooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`005_ooool2ool000;ooooo0_oo0002oooo
o`;oo`0001goooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00002?ooooooo`00
oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo0_oo00000oooooooo`00ooooo`05
ooooo`03o`000?oooooooooo00kooooo000>ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`?oo`001_ooool00ooo003oooooooooo`0=
ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool00oooool01?oo003oooooool00?oo
001<ooooo`03o`000?oooooooooo02Gooooo0_l0001Eooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool001Kooooo0_oo00009Oooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool00_oo0002ooooo`;oo`0000Coooooool00?ooooooo`000_ooool2ool000;ooooo0_oo00002?oo
ooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo0_oo00000oooooooo`00
ooooo`04ooooo`;o00004?ooool000oooooo0_l00008ooooo`Go00000oooool00ol0003ooooooooo
o`1;ooooo`?oo`001_ooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o
o`00ooooooooool00oooool01?oo003oooooool00?oo001<ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0E?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo000Eooooo`0Xool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`0000So
ooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo0002ooooo`;oo`0000Soooooool0
0?ooooooo`00oooooooo003oooooool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?ooool0
1Oooool00ol0003oooooooooo`0>ooooo`008Oooool2o`0004cooooo00?oo`00oooooooo00001_oo
ool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool00ooo
ool01?oo003oooooool00?oo001<ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
E?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo000Eooooo`0Rool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00ooooo`;oo`000_ooool03?oo003oooooool00?oo003oooooool00?ooooooo`00oooo
oooo003oooooool000;ooooo0_oo0002ooooo`;oo`0000Soooooool00?ooooooo`00oooooooo003o
ooooool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?ooool01Oooool00ol0003ooooooooo
o`0>ooooo`008Oooool00ol0003oooooooooo`1;ooooo`03ool00?ooooooo`0000Kooooo00?oo`00
ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo00Coo`00
oooooooo003oo`00C?ooool00ol0003oooooooooo`0Uooooo`;o0000EOooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool00004oooooooo003oooooool001Gooooo02;oo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
oooo0_oo0002ooooo`0<ool00?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?oooooo
o`000_ooool2ool000;ooooo0_oo00002?ooooooo`00oooooooo003oooooool00?ooooooo`000_oo
ool2ool000;ooooo0_oo00000oooooooo`00ooooo`04ooooo`;o00004?ooool0027ooooo00?o0000
ooooooooool0C_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00gooooo00?o0000
ooooooooool03_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1Dooooo`;oo`000_ooool2ool00004oooooooo003o
ooooool000;ooooo0_oo00001?ooooooo`00oooooooo000Eooooo`0Rool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;o
o`000_ooool03?oo003oooooool00?oo003oooooool00?ooooooo`00oooooooo003oooooool000;o
oooo0_oo0002ooooo`;oo`0000Soooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo
0002ooooo`;oo`0000?oooooool00?ooool01Oooool00ol0003oooooooooo`0>ooooo`008Oooool0
0ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0COooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo01?oo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001Go
oooo02;oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003ooooo0_oo0002ooooo`0<ool00?ooooooo`00ool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`000_ooool2ool000;ooooo0_oo00002?ooooooo`00oooooooo003o
ooooool00?ooooooo`000_ooool2ool00006oooooooo003oooooool00?ooooooo`001_ooool00ol0
003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05?o
oooo01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`0001Gooooo02;oo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`0<ool0
0?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo
0_oo00002?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool00006oooooooo003o
ooooool00?ooooooo`001_ooool00ol0003oooooooooo`0>ooooo`008Oooool2o`0004oooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo02Gooooo0_l0
001Dooooo`0Cool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool0000Eooooo`0Rool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool0
3?oo003oooooool00?oo003oooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo0002
ooooo`;oo`0000Soooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo00001_oooooo
o`00oooooooo003oooooool000Gooooo0_l0000@ooooo`008Oooool00ol0003oooooooooo`1>oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0>oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05?ooooo01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001Gooooo02;oo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
oooo0_oo0002ooooo`0<ool00?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?oooooo
o`000_ooool2ool000;ooooo0_oo00004_ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool000Kooooo00?o0000ooooooooool03_oo
ool0027ooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00gooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo04gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Cooooo`0Cool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool0000Eooooo`0Rool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool03?oo003oooooool00?oo003o
ooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo0002ooooo`;oo`0000ooooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0007
ooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo04kooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0Doooool04ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo00005Oooool08_oo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;o
oooo01?oo`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003ooooo00;oo`000_ooool03?oo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ooooo`;oo`001oooool00ol0003oooooooooo`0>ooooo`008Oooool0
0ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03Oooool0
0ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0COooool0
0ol0003oooooooooo`0Uooooo`;o0000E?ooool04ooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00005Oooool08_oo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool2ool000;ooooo01?oo`00oooooooo003oo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00;oo`000_ooool03?oo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`001_ooool2o`00013ooooo
000Qooooo`;o0000Coooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00gooooo00?o
0000ooooooooool03_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1Cooooo`0Cool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Eoooo
o`0Rool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00ooooo`;oo`000_ooool2ool00003oooooooo003oo`0000;ooooo00coo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo00Soo`00
oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000Oooooo00?o0000oooooooo
ool03_ooool0027ooooo00?o0000ooooooooool0C_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00gooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo04gooooo00?o0000ooooooooool07Oooool3o`0000Gooooo00?o0000ooooooooool0
Doooool04ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo00005Oooool04_oo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00000oooooooo`00ool00002ooooo`0<
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`08
ool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0007ooooo`03o`000?oo
oooooooo00kooooo000Qooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`1=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Cooooo`0Cool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool0000Eooooo`0>ool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00003oooooooo003oo`00
00;ooooo00coo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool0
00;ooooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000Oooooo
00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0C_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool03oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool05_ooool5o`0000?ooooo00?o
0000ooooooooool01?ooool2o`0005Cooooo01?oo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001Gooooo00[oo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo
00000_ooool03?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;o
o`000_ooool02?oo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`001_oo
ool2o`00013ooooo000Qooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`1=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Cooooo`0Cool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool0000Dooooo`03ool00?oooooooooo00;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo00000_ooool03?oo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool02?oo003o
ooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`001oooool00ol0003ooooooooo
o`0>ooooo`008Oooool2o`0004oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0=
ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1=
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1C
ooooo`0Cool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool0000Dooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`0000?oooooool00?oo00000_ooool03?oo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool02?oo003oooooool00?ooooooo`00
oooooooo003ooooo0_oo0002ooooo`;oo`001oooool00ol0003oooooooooo`0>ooooo`008Oooool0
0ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03Oooool0
0ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0COooool0
0ol0003oooooooooo`0Mooooo`;o00001_ooool00ol0003oooooooooo`1Cooooo`0Cool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool0000Dooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`0000?oooooool00?oo00000_ooool03?oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00ooooo`;oo`000_ooool02?oo003oooooool00?ooooooo`00oooooooo003ooooo0_oo
0002ooooo`;oo`001oooool00ol0003oooooooooo`0>ooooo`006_ooool3o`0000Cooooo00?o0000
ooooooooool0C_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00gooooo00?o0000
ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`04ooooo`;o0000E?ooool03_oo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`03ool00?oo
oooooooo01;ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
00000oooooooo`00ool00002ooooo`0<ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003ooooo0_oo0002ooooo`08ool00?ooooooo`00oooooooo003oooooool00?ooool2ool0
00;ooooo0_oo0006ooooo`;o00004?ooool001_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03Oooool00ol0003o
ooooooooo`0?ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0COooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo05?ooooo00Coo`00oooooooo003oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo
00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo00000_ooool03?oo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool02?oo
003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`001oooool00ol0003ooooo
ooooo`0>ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04kooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0D_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`02ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool00003oooooooo003oo`0000;ooooo00coo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo00Soo`00oooooooo003ooooo
ool00?ooooooo`00ooooo`;oo`000_ooool2ool000Oooooo00?o0000ooooooooool03_ooool001_o
oooo00?o0000ooooooooool00oooool3o`0004kooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`1<ooooo`;o00009oooool00ol0003oooooooooo`1Booooo`03ool00?oooooooooo00;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0Booooo`03
ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo
00000_ooool03?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;o
o`000_ooool02?oo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`001ooo
ool00ol0003oooooooooo`0>ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooo
oooo00oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1=ooooo`03o`000?oooooo
oooo02Gooooo0_l0001Cooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo00000_ooool03?oo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool02?oo003oooooool00?oo
ooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`001_ooool2o`00013ooooo000Jooooo`;o0000
1Oooool00ol0003oooooooooo`1>ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
COooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo00?oo`00ooooooooool0
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo01;ooooo
00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool0
0_oo0002ooooo`0<ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
0_oo0002ooooo`04ool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00oooooooo
ool01_ooool00ol0003oooooooooo`0>ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo04kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1=ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0D_ooool00ooo003oooooooooo`02ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool04_ooool00ooo003ooooo
ooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000;ooooo0_oo0002ooooo`08ool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00Ko
oooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0C_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool03oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`1Booooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`000_oo
ool01?oo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo
000Qooooo`;o0000Coooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o
0000ooooooooool09Oooool2o`0005?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo01;ooooo00Coo`00ooooooooooooo`00
0oooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool01Oooool2o`00013ooooo000Q
ooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1=
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0D_ooool00ooo003oooooooooo`02
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool04_ooool0
1?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooo
oooo00Kooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0C_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool03oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1Booooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo00Coo`00oooo
oooooooooooo0_oo0002ooooo`03ool00?oooooooooo01;ooooo00Coo`00ooooooooooooo`000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooo
oooo00kooooo000Qooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`1=ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0D_ooool01?oo
003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool2ool000;ooooo00?o
o`00ooooooooool04_ooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000
ooooooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000
ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000
ooooooooool09Oooool2o`0005?ooooo00Coo`00ooooooooooooo`000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000Dooooo`04ool00?ooooooooooool0
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool01Oooool2o`00013o
oooo000Qooooo`;o0000Coooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo
00?o0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo
00?o0000ooooooooool07_ooool2o`0000Gooooo00?o0000ooooooooool0D_ooool01?oo003ooooo
oooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0001?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000oooo
ooooool0C_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o0000oooo
ooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000oooo
ooooool07Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05;ooooo00Coo`00
ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool0000Cooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool03_ooool0027o
oooo00?o0000ooooooooool0Coooool01Ooo003oooooooooooooooooo`00013ooooo00?o0000oooo
ooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000oooo
ooooool07Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05;ooooo00Coo`00
ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool0000Cooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`;o
o`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`06ooooo`03o`000?oo
oooooooo00kooooo000Qooooo`03o`000?oooooooooo04oooooo00Goo`00ooooooooooooooooool0
000@ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`1=ooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo00001?ooool9o`000005ool0
0?l0003o0000o`000?oo00000ol000001Ooo003o0000o`000?l0003oo`0000?o000000Goo`00o`00
0?l0003o0000ool00003o`000005ool00?l0003o0000o`000?oo00000ol000001Ooo003o0000o`00
0?l0003oo`0000?o000000Coo`00o`000?l0003oo`000ol000001Ooo003o0000o`000?l0003oo`00
00?o000000Goo`00o`000?l0003o0000ool00003o`000005ool00?l0003o0000o`000?oo00000ol0
00000ooo003o0000o`000002o`000003ool00?l0003o000000co000000Goo`00o`000?l0003o0000
ool00003o`000005ool00?l0003o0000o`000?oo00000ol000001Ooo003o0000o`000?l0003oo`00
00?o000000?oo`00o`000?l000003Ol000000ooo003o0000o`000005o`000005ool00?l0003o0000
o`000?oo00003_l000000ooo003o0000o`00000Ao`000005ool00?l0003o0000o`000?oo00001ol0
00000ooo003o0000o`000007o`00013ooooo000Qooooo`;o0000D?ooool01Ooo003ooooooooooooo
ooooo`00013ooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo04gooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Kooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo017ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0005?ooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000oooooooo
ool0Coooool01Ooo003oooooooooooooooooo`00013ooooo00?o0000ooooooooool03oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool07Oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Kooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2
ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo017ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0005?ooooo00?o0000ooooooooool0
3_ooool0027ooooo00?o0000ooooooooool0Coooool01Ooo003oooooooooooooooooo`00013ooooo
00?o0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo
00?o0000ooooooooool07_ooool2o`0000Gooooo00?o0000ooooooooool01_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo017ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0005?ooooo00?o0000oooooooo
ool03_ooool0027ooooo00?o0000ooooooooool0Coooool01Ooo003oooooooooooooooooo`00013o
oooo00?o0000ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04go
oooo00?o0000ooooooooool09Oooool2o`0000Oooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000?ooooo00Goo`00
ooooooooooooooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0A
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo
00Goo`00ooooooooooooooooool0001Booooo`;o00004?ooool0027ooooo00?o0000ooooooooool0
Coooool01Ooo003oooooooooooooooooo`00013ooooo00?o0000ooooooooool03oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`06ooooo`03ool00?oooooooooo00;oo`000oooool00ooo003oooooooooo`02ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool00ooo003oooooooooo`0Aooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0001Cooooo`03o`000?oooooo
oooo00kooooo000Qooooo`;o0000D?ooool01Ooo003oooooooooooooooooo`00013ooooo00?o0000
ooooooooool03oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04gooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo00;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool04Oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool00_oo0003ooooo`05ool00?oooooooooooooooooo0000Dooo
ool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1?ooooo`05ool00?oooooo
oooooooooooo00004?ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool0COooool00ol0003oooooooooo`0Uooooo`;o00001_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooo
oooo00;oo`000_ooool2ool000;ooooo0_oo0003ooooo`05ool00?oooooooooooooooooo0000D_oo
ool2o`00013ooooo000Qooooo`03o`000?oooooooooo04oooooo00Goo`00ooooooooooooooooool0
000@ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`1=ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooo
oooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`1A
ooooo`03o`000?oooooooooo00kooooo000>ooooo`?o00001?ooool00ol0003oooooooooo`02oooo
o`?o00001?ooool00ol0003oooooooooo`1?ooooo`05ool00?oooooooooooooooooo00004?ooool0
0ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0COooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`02ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000?ooooo00?oo`00ooooooooool0DOooool00ol0
003oooooooooo`0>ooooo`003oooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`1?ooooo`05ool00?oooooooooooooooooo00004?ooool0
0ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0COooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`02ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000?ooooo00?oo`00ooooooooool0DOooool00ol0
003oooooooooo`0>ooooo`003oooool00ol0003oooooooooo`0;ooooo`04o`000?oooooooooooooo
o`?o0000Coooool01Ooo003oooooooooooooooooo`00013ooooo00?o0000ooooooooool03oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo04cooooo0_l0000Wooooo`;o00001_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Aoooo
o`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000oooool00ooo
003oooooooooo`1@ooooo`;o00004?ooool000oooooo00?o0000ooooooooool02oooool01Ol0003o
oooooooooooooooo0000057ooooo00Goo`00ooooooooooooooooool0000@ooooo`03o`000?oooooo
oooo00oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1=ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool01Oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`1Booooo`03o`000?oooooooooo
00kooooo000?ooooo`03o`000?oooooooooo00Oooooo1?l00004ooooo`03o`000?oooooooooo04oo
oooo00Goo`00ooooooooooooooooool0000@ooooo`03o`000?oooooooooo00oooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool01Oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool00_oo0002ooooo`;oo`000oooool01Ooo003oooooooooooooooooo`0001?ooooo
00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool0
0?oooooooooo05;ooooo00?o0000ooooooooool03_ooool000kooooo0_l00009ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Coooool01Ooo003oooooooooooooooooo`00013ooooo
00?o0000ooooooooool03oooool01Ooo003oooooooooooooooooo`00053ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`05ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000oooool01Ooo003o
ooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000oooool01Ooo003ooooooooooooooooo
o`0001?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`03ool00?oooooooooo05;ooooo00?o0000ooooooooool03_ooool000oooooo00?o0000oooo
ooooool01oooool5o`0000?ooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000A
ooooo`03o`000?oooooooooo00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03o`000?oo
oooooooo02Gooooo0_l00006ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000oooool01Ooo003ooooooooo
ooooooooo`0000;ooooo0_oo0002ooooo`;oo`000oooool01Ooo003oooooooooooooooooo`0001?o
oooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03
ool00?oooooooooo057ooooo0_l0000@ooooo`008Oooool2o`00053ooooo00Coo`00oooooooooooo
o`004Oooool00ol0003oooooooooo`0@ooooo`04ool00?ooooooooooool0053ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`05ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool00003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000oooool01Ooo
003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00
ooooooooool04_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo00?oo`00ooooooooool0D_ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0
003oooooooooo`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool04?ooool0
1?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01gooooo0ol00005ooooo`03o`000?oo
oooooooo00Gooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo00000oooooooo`00ool00002ooooo`;oo`000_ooool2ool000?ooooo00Goo`00oooo
ooooooooooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooo
oooo01;ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`03ool00?oooooooooo05;ooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000oooo
ooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo00Coo`00
ooooooooooooo`00D?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00004oooooooo
003oooooool000;ooooo0_oo00002?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo00000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00
ooooooooool04_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo00?oo`00ooooooooool0D_ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0
003oooooooooo`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool04?ooool0
1?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?oo
ool2o`0000Gooooo00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00002
ooooo`;oo`00013oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo0000
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`02ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool0DOooool2o`00013ooooo
000Qooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Oooool00ol0003ooooo
ooooo`0@ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00_oo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00002ooooo`;oo`0001Coooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo
00001Oooooooo`00oooooooo003ooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
00?oo`00ooooooooool0D_ooool00ol0003oooooooooo`0>ooooo`008Oooool2o`00053ooooo00Co
o`00ooooooooooooo`004Oooool00ol0003oooooooooo`0@ooooo`04ool00?ooooooooooool0053o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00002ooooo`;oo`00
01goooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool00_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo05;ooooo00?o0000
ooooooooool03_ooool0027ooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000A
ooooo`03o`000?oooooooooo013ooooo00Coo`00ooooooooooooo`00D?ooool00ol0003ooooooooo
o`0Mooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`0/ool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool0
0?oooooooooo01;ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`03ool00?oooooooooo05;ooooo00?o0000ooooooooool03_ooool0027ooooo00?o
0000ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo
00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Co
oooo0_l00005ooooo`0/ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo01;ooooo00?oo`00oooo
ooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo
057ooooo0_l0000@ooooo`008Oooool00ol0003oooooooooo`1?ooooo`04ool00?ooooooooooool0
017ooooo00?o0000ooooooooool04?ooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool01?ooool0;?oo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003ooooooooo
o`0Booooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool00ooo003oooooooooo`1Booooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooo
oooo04oooooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0@ooooo`04ool00?oo
ooooooooool0053ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`04ooooo`0/ool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool00_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo05;ooooo00?o0000oooooooo
ool03_ooool0027ooooo0_l0001@ooooo`04ool00?ooooooooooool0017ooooo00?o0000oooooooo
ool04?ooool01?oo003ooooooooooooo001@ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool01?ooool0;?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooo
oooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`1B
ooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo04oooooo00Coo`00oooo
ooooooooo`004Oooool00ol0003oooooooooo`0@ooooo`04ool00?ooooooooooool0053ooooo00?o
0000ooooooooool09Oooool2o`0000Gooooo02coo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`0000Coooooool00?oooooo
o`000_ooool00ooo003oooooooooo`1Aooooo`;o00004?ooool0027ooooo00?o0000ooooooooool0
Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo00Coo`00oooooooo
ooooo`00D?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo02coo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`02ool0000>oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo001Eooooo`03o`000?oo
oooooooo00kooooo000Qooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Ooo
ool00ol0003oooooooooo`0@ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`04ooooo`0/ool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo01;o
oooo01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`0005Gooooo00?o0000ooooooooool03_ooool0027ooooo0_l0001@
ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool04?ooool01?oo003ooooooooo
oooo001@ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool0;?oo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool00ooo003oooooooooo`0Booooo`0Cool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0001Eooooo`03o`000?oo
oooooooo00kooooo000Qooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Ooo
ool00ol0003oooooooooo`0@ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0
9Oooool2o`0000Gooooo03Coo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`000_ooool00ooo003o
ooooooooo`0Booooo`0Cool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool0001Dooooo`;o00004?ooool0027ooooo00?o0000
ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo00Co
o`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo
03Coo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo00002_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Eooooo`0Cool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool0001Eooooo`03o`000?oooooooooo00kooooo000Iooooo`Go00000oooool00ol0003o
ooooooooo`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool04?ooool01?oo
003ooooooooooooo001@ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool0
<_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003ooooo0_oo00001_ooooooo`00oooooooo003oooooool000;ooooo0_oo
00003_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
5Oooool04ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo0000EOooool00ol0003oooooooooo`0>ooooo`006_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Ooo
ool00ol0003oooooooooo`0@ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`04ooooo`0^ool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool0000Hoooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`005Oooool04ooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000EOooool00ol0003o
ooooooooo`0>ooooo`006oooool00ol0003oooooooooo`03ooooo`?o0000Coooool01?oo003ooooo
oooooooo000Aooooo`03o`000?oooooooooo013ooooo00Coo`00ooooooooooooo`00Coooool2o`00
02Oooooo0_l00005ooooo`0Zool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003ooooo0_oo0002ooooo`;oo`000_ooool2ool0000Hoooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`005Oooool04ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo0000E?ooool2o`00013ooooo000Looooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03
o`000?oooooooooo013ooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Loooo
o`Go00001?ooool00ol0003oooooooooo`04ooooo`0Nool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool0000Hoooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`005Oooool04ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo0000EOooool00ol0003oooooooooo`0>ooooo`006Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0Coooool01?oo003ooooo
oooooooo000Aooooo`03o`000?oooooooooo013ooooo00Coo`00ooooooooooooo`00D?ooool00ol0
003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool0
2_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo00coo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0000Hoooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`005Oooool04ooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000EOooool00ol0003o
ooooooooo`0>ooooo`006Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo00Coo`00oooo
ooooooooo`00D?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool01?oo003oooooool00?oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00006?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool001Gooooo01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`0005Gooooo00?o0000ooooooooool03_ooool0
01[ooooo0ol00004ooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Oooool0
0ol0003oooooooooo`0@ooooo`04ool00?ooooooooooool0053ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool00ooo003oooooooooo`02ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0000Hoooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`005Oooool04ooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000E?ooool2
o`00013ooooo000Qooooo`;o0000D?ooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooo
oooo013ooooo00Coo`00ooooooooooooo`00D?ooool00ol0003oooooooooo`0Looooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
01Soooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Eooooo`0Cool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
001Eooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo04oooooo00Coo`00
ooooooooooooo`004Oooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o
0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
0oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool0000Hoooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`005Oooool04ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo0000EOooool00ol0003oooooooooo`0>ooooo`008Oooool0
0ol0003oooooooooo`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool04?oo
ool00ooo003oooooool0001Aooooo`03o`000?oooooooooo01gooooo0ol00005ooooo`03o`000?oo
oooooooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00006?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool001Gooooo01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`0005Gooooo00?o0000ooooooooool03_ooool0
027ooooo00?o0000ooooooooool0D?ooool00ooo003oooooool0000Aooooo`03o`000?oooooooooo
013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Uooooo`;o00001?ooool00ooo
003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool0000Hoooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`005Oooool0
2?oo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool005Go
oooo0_l0000@ooooo`008Oooool00ol0003oooooooooo`1@ooooo`03ool00?ooooooo`00017ooooo
00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0000Hoooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`005Oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo001Fooooo`03o`000?oooooooooo00kooooo000Qooooo`;o0000DOooool00ooo003ooooo
ool0000Aooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00006?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool001Gooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`00E_ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003ooooo
ooooo`1@ooooo`03ool00?ooooooo`00017ooooo00?o0000ooooooooool04?ooool00ooo003ooooo
ool0001Aooooo`03o`000?oooooooooo02Gooooo0_l00004ooooo`03ool00?oooooooooo00;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
01Soooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Eooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool005Gooooo0_l0000@ooooo`008Oooool00ol0003ooooo
ooooo`1@ooooo`03ool00?ooooooo`00017ooooo00?o0000ooooooooool04?ooool00ooo003ooooo
ool0001Aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool00ooo003ooooo
ooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool0000Aoooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`005_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo001Fooooo`03o`000?oooooooooo00kooooo000Qooooo`03
o`000?oooooooooo053ooooo00?oo`00oooooooo00004Oooool00ol0003oooooooooo`0@ooooo`03
ool00?ooooooo`00057ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`03
ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`0;ool00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?ooool0
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo000Fooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool005Kooooo00?o0000ooooooooool03_ooool0027ooooo00?o
0000ooooooooool0D?ooool00ooo003oooooool0000Aooooo`03o`000?oooooooooo013ooooo00?o
o`00oooooooo0000DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo00?o
o`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool001Kooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`00E_ooool00ol0003oooooooooo`0>ooooo`008Oooool2o`00057ooooo00?oo`00
oooooooo00004Oooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000
ooooooooool09Oooool2o`0000Cooooo00Coo`00ooooooooooooo`000oooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo000Fooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool005Gooooo0_l0000@ooooo`008Ooo
ool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?oo
ooooo`00057ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`04ool00?oo
ooooooooool000?ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool001Kooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`00E_ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003o
ooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`04ool00?ooooooooooool0
00?ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`005_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo001Fooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oo
oooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo00Coo`00ooooooooooooo`00
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`005_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo001Fooooo`03o`000?oooooooooo00ko
oooo000Qooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo
00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Uooooo`;o00000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
01Kooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool0E?ooool2o`00013ooooo000Qooooo`;o0000DOooool2ool001;ooooo00?o0000oooo
ooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool001Kooooo0_oo0002ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0005Oooooo00?o0000ooooooooool03_ooool0027ooooo
00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04Oooool2ool0057ooooo
00?o0000ooooooooool07Oooool3o`0000Gooooo00?o0000ooooooooool00_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
01Kooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo00kooooo000=ooooo`Go00000oooool0
0ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool0
0ol0003oooooooooo`0Aooooo`;oo`00DOooool00ol0003oooooooooo`0Looooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`02ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool0000Goooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool0EOooool00ol0003oooooooooo`0>ooooo`003_ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1@ooooo`;oo`00
4_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`02ooooo`;o00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002oooo
o`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
000Gooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool0E?ooool2o`00013ooooo000?ooooo`03o`000?oooooooooo00_ooooo
00Co0000oooooooooooooooo0ol0001@ooooo`;oo`004_ooool00ol0003oooooooooo`0Aooooo`03
ool00?oooooooooo04oooooo0_l0000Pooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00005oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo05Gooooo00?o0000
ooooooooool03_ooool0013ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo
000005?ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooo
oooo053ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000Gooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
EOooool00ol0003oooooooooo`0>ooooo`003Oooool01Ol0003ooooooooooooooooo000000Oooooo
1?l00004ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00007ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool0000?ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0001Oooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`1Eooooo`03o`000?oooooooooo00kooooo000=ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000007oooool3o`0000Go
oooo0_l0001Vooooo`03o`000?oooooooooo06Cooooo0_l0000@ooooo`003_ooool3o`0000Sooooo
1Ol00003oooooloo00009oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo
003ooooooaSooooodOl0000@ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
\
\>"],
  ImageRangeCache->{{{0, 503}, {147.312, 0}} -> {-0.0551454, -0.0147182, \
0.00419541, 0.00419541}, {{13.125, 240.125}, {143.75, 3.5}} -> {-6.97149, \
-0.375033, 0.0509423, 0.0206373}, {{262.812, 489.812}, {143.75, 3.5}} -> \
{-19.3474, -4.07637, 0.0504429, 0.0512823}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Length =  10 seconds", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := Cos[2  \[Pi]\ t]\ \((u[t]\  - \ u[t - 10])\);\)\), "\n", 
    \(\(Plot[x[t], \ {t, \ \(-5\), 15}, \ 
        PlotStyle \[Rule] Blue];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.0476191 0.309017 0.294302 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -12 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .16187 -24 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-5)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(5)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(15)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(-1)] -0.0125 .01471 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04414 m
.00375 .04414 L
s
0 .07357 m
.00375 .07357 L
s
0 .103 m
.00375 .103 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04414 m
1 .04414 L
s
.99625 .07357 m
1 .07357 L
s
.99625 .103 m
1 .103 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.2619 0 m
.2619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.24141 .30902 L
.25127 .30902 L
.25666 .30902 L
.2593 .30902 L
.26045 .30902 L
.26171 .30902 L
.26301 .60019 L
.26425 .58935 L
.26494 .5801 L
.26567 .56781 L
.26698 .53973 L
.27003 .44989 L
.27279 .34858 L
.27538 .24855 L
.27811 .15069 L
.28045 .08289 L
.28178 .05355 L
.28302 .03318 L
.28427 .02002 L
.28542 .01494 L
.28605 .01501 L
.28674 .01742 L
.288 .02796 L
.28864 .0364 L
.28935 .04801 L
.2908 .07843 L
.29339 .15304 L
.29805 .3258 L
.3007 .42523 L
.30316 .50539 L
.30438 .53805 L
.30553 .56344 L
.30617 .57498 L
.30686 .58537 L
.30807 .59793 L
.30938 .60327 L
.31004 .60264 L
.31077 .59938 L
.31205 .58715 L
.31325 .56849 L
.31444 .54344 L
.31558 .51427 L
.31771 .44771 L
.3225 .26746 L
Mistroke
.32501 .17506 L
.32639 .12995 L
.32768 .09286 L
.32889 .06384 L
.3302 .03952 L
.33139 .02435 L
.33248 .01657 L
.33379 .01524 L
.33501 .02185 L
.33571 .02901 L
.33634 .03761 L
.33777 .0638 L
.33915 .0972 L
.34064 .14133 L
.34336 .23677 L
.3479 .41015 L
.35028 .49063 L
.35158 .52745 L
.35278 .55594 L
.35412 .58022 L
.35483 .58969 L
.35558 .5971 L
.35627 .60138 L
.35693 .6032 L
.35814 .60075 L
.3594 .59035 L
.36056 .57394 L
.36183 .54884 L
.36317 .51502 L
.36838 .33502 L
.37331 .152 L
.37604 .07449 L
.37678 .05815 L
.37758 .04344 L
.37826 .03307 L
.379 .02441 L
.38027 .0159 L
.38147 .0154 L
.38216 .01844 L
.38289 .02427 L
.38419 .04121 L
.38542 .06438 L
.38654 .09104 L
.38904 .16702 L
.39356 .33611 L
.39608 .43056 L
.39742 .47555 L
.39883 .51758 L
.40006 .54846 L
.40071 .56231 L
Mistroke
.40142 .57511 L
.40265 .59197 L
.40381 .60098 L
.40502 .60314 L
.40615 .59837 L
.40739 .58575 L
.40871 .56419 L
.40997 .5364 L
.41116 .50449 L
.41338 .43273 L
.41791 .26107 L
.42213 .1147 L
.42329 .08338 L
.42438 .05855 L
.42564 .03641 L
.42679 .02278 L
.42807 .01537 L
.42924 .01587 L
.43053 .02453 L
.43119 .03205 L
.43191 .04274 L
.43324 .06887 L
.43447 .09939 L
.43723 .18677 L
.44223 .37634 L
.44431 .45147 L
.44653 .51979 L
.4478 .55125 L
.44896 .57389 L
.45013 .59042 L
.45123 .59992 L
.45238 .60332 L
.4536 .59955 L
.45463 .59041 L
.45578 .57428 L
.457 .55025 L
.45832 .51743 L
.4607 .44302 L
.46562 .25763 L
.46831 .15998 L
.47084 .08496 L
.47229 .05281 L
.47311 .03876 L
.47385 .02859 L
.47449 .02212 L
.47518 .01733 L
.4759 .01492 L
.47658 .0151 L
.47727 .01769 L
.47792 .02237 L
Mistroke
.47915 .03681 L
.48046 .06025 L
.48189 .09416 L
.49146 .4354 L
.49408 .51801 L
.49555 .55409 L
.49625 .56805 L
.4969 .57905 L
.49815 .59459 L
.49881 .5997 L
.49951 .60271 L
.50082 .60161 L
.502 .59314 L
.50324 .57682 L
.50455 .5518 L
.5069 .48947 L
.51221 .29726 L
.51685 .13034 L
.51819 .09208 L
.51945 .06202 L
.52059 .04087 L
.52183 .02472 L
.52313 .01589 L
.52379 .01472 L
.52452 .016 L
.5258 .02484 L
.52701 .04056 L
.52822 .06325 L
.52934 .08961 L
.53185 .16535 L
.53717 .36516 L
.54009 .46974 L
.54153 .5133 L
.54285 .54703 L
.54405 .57127 L
.54532 .58983 L
.54659 .6006 L
.54731 .60307 L
.54799 .60297 L
.54916 .59725 L
.55023 .58597 L
.55147 .56607 L
.55265 .54081 L
.55491 .4772 L
.55701 .40477 L
.56177 .22312 L
.56448 .13005 L
.56581 .09204 L
.56703 .06295 L
.56814 .04196 L
Mistroke
.56932 .02606 L
.5705 .01693 L
.57179 .01505 L
.57251 .0177 L
.57319 .0226 L
.57446 .03792 L
.57517 .04985 L
.57583 .0629 L
.57731 .09909 L
.58247 .27539 L
.58711 .44968 L
.58838 .4909 L
.58972 .52871 L
.59088 .55593 L
.59211 .57863 L
.59329 .59361 L
.59435 .60131 L
.59542 .60323 L
.59643 .59966 L
.59762 .58896 L
.5987 .5731 L
.5999 .54946 L
.60116 .51799 L
.60626 .34316 L
.6111 .1622 L
.61377 .08319 L
.6145 .06605 L
.61528 .05031 L
.61595 .0389 L
.61668 .02896 L
.61793 .01793 L
.6191 .01472 L
.61978 .01608 L
.62049 .02005 L
.62177 .03352 L
.623 .05379 L
.62411 .07803 L
.62662 .14968 L
.63113 .31587 L
.63604 .49216 L
.63739 .52999 L
.63882 .56247 L
.64003 .58314 L
.64073 .59177 L
.64138 .59772 L
.64259 .60314 L
.64375 .6013 L
.64478 .59387 L
.64591 .57969 L
.64714 .55756 L
Mistroke
.64845 .52686 L
.6508 .45609 L
.65513 .2949 L
.6597 .13058 L
.66093 .09502 L
.66225 .0632 L
.66301 .04826 L
.6637 .03691 L
.6644 .02778 L
.66506 .02132 L
.66629 .01509 L
.66742 .01617 L
.66867 .02489 L
.66929 .03222 L
.66999 .04253 L
.67143 .07094 L
.67275 .10456 L
.67573 .20118 L
.68112 .40599 L
.68339 .48365 L
.68581 .54928 L
.68653 .56426 L
.6872 .57631 L
.68847 .59307 L
.68966 .6016 L
.69094 .60276 L
.69219 .59583 L
.6929 .58843 L
.69356 .57931 L
.69489 .55473 L
.69633 .5199 L
.70129 .35128 L
.7062 .16698 L
.70761 .12166 L
.70894 .08493 L
.71015 .05748 L
.71142 .03545 L
.71211 .02677 L
.71286 .01991 L
.71418 .01474 L
.71492 .01575 L
.71572 .01997 L
.71647 .02687 L
.71716 .03556 L
.71846 .05833 L
.71989 .09148 L
.72247 .17025 L
.72754 .36115 L
.73032 .46144 L
.73168 .50389 L
Mistroke
.73292 .53731 L
.73398 .56091 L
.73513 .58109 L
.73635 .59556 L
.73751 .60245 L
.73878 .30902 L
.73949 .30902 L
.74014 .30902 L
.74257 .30902 L
.78261 .30902 L
.82114 .30902 L
.86212 .30902 L
.90158 .30902 L
.93953 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`008_ooool3o`0003Wooooo0_l0000kooooo`?o0000=oooool3o`0000Co
oooo0_l0000eooooo`?o00000oooool3o`0000Cooooo000Qooooo`05o`000?ooooooooooooooool0
0000=oooool01?l0003oooooooooool0000iooooo`05o`000?ooooooooooooooool00000=oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003Gooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo007ooooo000Kooooo`Go00001Oooool00ol0003ooooooooo
o`0eooooo`04o`000?ooooooooooo`0003gooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0003Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`01ooooo`009Oooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0003go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
03Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`01ooooo`008Oooool4o`0003So
oooo00Co0000oooooooooooo0000>Oooool4o`0003Sooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000eooooo`04o`000?ooooooooooooooo`Co00001?ooool0027ooooo00?o0000
ooooooooool0>Oooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo03Sooooo0_l0
0004ooooo`04o`000?ooooooooooo`0003Cooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo
000Qooooo`Go0000>?ooool2o`0003[ooooo1Ol0000gooooo`03o`000?oooooooooo00?ooooo0_l0
000fooooo`04o`000?ooooooooooooooo`Go00000oooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool001_oooooool00005o`00007ooooo000C
ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`7o00000Oooool001Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;cooooo0Ol00001oooo
o`003?ooool5o`0000?ooooo00?o0000ooooooooool01?ooool2o`0004;ooooo00?o0000oooooooo
ool00oooool00ol00?ooooooooooo`0^ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Kooooo00?o003ooooooooo
ool0A_ooool2o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool2o`00o`_ooooo00?o003oooooooooool02Oooool2o`00o`_ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`;o003o2oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo04Oooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`;o003o2_oo
ool2o`00o`_ooooo00?o003oooooooooool02Oooool2o`00o`_ooooo00?o003oooooooooool02Ooo
ool2o`00o`[ooooo0_l00?l:ooooo`;o003o2oooool2o`00odSooooo0Ol00001ooooo`004oooool2
o`0000Kooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`03ooooo`;o003o2_ooool2
o`00o`[ooooo0_l00?l;ooooo`;o003o2_ooool2o`00o`[ooooo0_l00?l;ooooo`;o003o2_ooool2
o`00o`[ooooo0_l00?l;ooooo`;o003oB?ooool1o`00007ooooo000Dooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooo003o
00[ooooo0_l00?l:ooooo`;o003o2oooool2o`00o`[ooooo0_l00?l:ooooo`;o003o2oooool2o`00
o`[ooooo0_l00?l:ooooo`;o003o2oooool2o`00odSooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o003oooooool00?l02_ooool2o`00o`[o
oooo0_l00?l:ooooo`03o`00oooooooo003o00[ooooo0_l00?l:ooooo`;o003o2oooool2o`00o`[o
oooo0_l00?l:ooooo`03o`00oooooooo003o00[ooooo0_l00?m8ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooo003o00Wooooo
00?o003oooooool00?l02_ooool2o`00o`[ooooo00?o003oooooool00?l02_ooool2o`00o`[ooooo
00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`0:ooooo`;o003o2_ooool00ol00?oooooo
o`00o`09ooooo`03o`00oooooooo003o04Sooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo00;ooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00
o`0:ooooo`;o003o2_ooool00ol00?ooooooo`00o`0:ooooo`;o003o2_ooool00ol00?ooooooo`00
o`09ooooo`03o`00oooooooo003o00[ooooo0_l00?l:ooooo`03o`00oooooooo003o00Wooooo00?o
003oooooool00?l0B?ooool1o`00007ooooo000Kooooo`;o0000@_ooool00ol0003oooooooooo`02
ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02_ooool2o`00o`[ooooo00?o003o
ooooool00?l02_ooool2o`00o`[ooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`0:
ooooo`;o003o2_ooool00ol00?ooooooo`00o`09ooooo`03o`00oooooooo003o04Oooooo0_l00001
ooooo`006oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ool00?l02Oooool00ol00?ooooooo`00o`0:ooooo`;o003o2_ooool00ol00?ooooooo`00o`09oooo
o`03o`00oooooooo003o00[ooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`09oooo
o`03o`00oooooooo003o00[ooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`18oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03
o`00oooooooo003o00Wooooo00?o003oooooool00?l02_ooool2o`00o`[ooooo00?o003oooooool0
0?l02Oooool00ol00?ooooooo`00o`0:ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool0
0?l02Oooool00ol00?ooooooo`00o`0:ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool0
0?l0B?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
0_ooool00ol00?ooooooo`00o`09ooooo`03o`00oooooooo003o00[ooooo00?o003oooooool00?l0
2Oooool00ol00?ooooooo`00o`09ooooo`03o`00oooooooo003o00[ooooo00?o003oooooool00?l0
2Oooool00ol00?ooooooo`00o`09ooooo`03o`00oooooooo003o00[ooooo00?o003oooooool00?l0
2Oooool00ol00?ooooooo`00o`18ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02_oo
ool00ol00?ooooooo`00o`09ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02_oo
ool00ol00?ooooooo`00o`09ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02_oo
ool00ol00?ooooooo`00o`09ooooo`03o`00oooooooo003o04Sooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o003oooooool00?l02Oooool0
0ol00?ooooooo`00o`0:ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02Oooool0
0ol00?ooooooo`00o`0:ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02Oooool0
0ol00?ooooooo`00o`0:ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l0B?ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool00ol0
0?ooooooo`00o`09ooooo`03o`00oooooooo003o00[ooooo00?o003oooooool00?l02Oooool00ol0
0?ooooooo`00o`09ooooo`03o`00oooooooo003o00[ooooo00?o003oooooool00?l02Oooool00ol0
0?ooooooo`00o`09ooooo`03o`00oooooooo003o00[ooooo00?o003oooooool00?l02Oooool00ol0
0?ooooooo`00o`18ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02Oooool01?l00?oo
ooooooooool00?l9ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02_ooool00ol0
0?ooooooo`00o`09ooooo`03o`00oooooooo003o00Wooooo00Co003ooooooooooooo003o2Oooool0
0ol00?ooooooo`00o`09ooooo`03o`00oooooooo003o04Sooooo0Ol00001ooooo`006oooool2o`00
04;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooo`00o`09ooooo`03o`00oooooooo003o
00Wooooo00Co003ooooooooooooo003o2Oooool00ol00?ooooooo`00o`09ooooo`03o`00oooooooo
003o00[ooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`09ooooo`04o`00oooooooo
ooooo`00o`Wooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`17ooooo`;o00000Ooo
ool001_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooo
003o00Wooooo00?o003oooooool00?l02Oooool01?l00?ooooooooooool00?l9ooooo`03o`00oooo
oooo003o00Wooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l9ooooo`03
o`00oooooooo003o00Wooooo00Co003ooooooooooooo003o2Oooool00ol00?ooooooo`00o`09oooo
o`04o`00ooooooooooooo`00odOooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo00;ooooo00?o003oooooool00?l02Oooool01?l00?ooooooooooool00?l8
ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003oooooool00?l02Oooool01?l00?oooooooooo
ool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Co003ooooooooooooo003o2?ooool01?l0
0?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Co003ooooooooooooo003o
Aoooool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool00_oo
ool00ol00?ooooooo`00o`09ooooo`04o`00ooooooooooooo`00o`Sooooo00Co003ooooooooooooo
003o2Oooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Sooooo00Co003o
oooooooooooo003o2Oooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`So
oooo00Co003ooooooooooooo003o2Oooool01?l00?ooooooooooool00?m7ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooo003o
00Wooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l9ooooo`04o`00oooo
ooooooooo`00o`Sooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l9oooo
o`04o`00ooooooooooooo`00o`Sooooo00Co003ooooooooooooo003o2?ooool01?l00?oooooooooo
ool00?l9ooooo`04o`00ooooooooooooo`00odOooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o003oooooool00?l02Oooool01?l00?oooooo
ooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Co003ooooooooooooo003o2?ooool0
1?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Co003ooooooooooooo
003o2?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Co003o
oooooooooooo003oAoooool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool00_ooool00ol00?ooooooo`00o`09ooooo`04o`00ooooooooooooo`00o`Sooooo00Co
003ooooooooooooo003o2Oooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00
o`Sooooo00Co003ooooooooooooo003o2Oooool01?l00?ooooooooooool00?l8ooooo`04o`00oooo
ooooooooo`00o`Sooooo00Co003ooooooooooooo003o2Oooool01?l00?ooooooooooool00?m7oooo
o`7o00000Oooool001_ooooo0_l00012ooooo`03o`000?oooooooooo00;ooooo00?o003oooooool0
0?l02Oooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Sooooo00Go003o
ooooooooooooooooo`00o`08ooooo`04o`00ooooooooooooo`00o`Sooooo00Co003ooooooooooooo
003o2Oooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Sooooo00Co003o
oooooooooooo003o2Oooool01?l00?ooooooooooool00?m6ooooo`;o00000Oooool001_ooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooo003o00Wooooo00Co
003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l8ooooo`05o`00oooooooooooooooo
ool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Co
003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00
o`Sooooo00Go003oooooooooooooooooo`00o`17ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooo003o00Wooooo00Co003ooooo
oooooooo003o2?ooool01?l00?ooooooooooool00?l8ooooo`05o`00ooooooooooooooooool00?l0
2?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Co003ooooo
oooooooo003o2?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Sooooo
00Go003oooooooooooooooooo`00o`17ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooo003o00Sooooo00Go003ooooooooooooo
ooooo`00o`08ooooo`04o`00ooooooooooooo`00o`Sooooo00Go003oooooooooooooooooo`00o`08
ooooo`04o`00ooooooooooooo`00o`Sooooo00Co003ooooooooooooo003o2?ooool01Ol00?oooooo
oooooooooooo003o00Sooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l8
ooooo`05o`00ooooooooooooooooool00?l0Aoooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool00_ooool01?l00?ooooooooooool00?l7ooooo`05o`00oooo
ooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`05o`00oooooooooooooooo
ool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Sooooo00Go
003oooooooooooooooooo`00o`08ooooo`04o`00ooooooooooooo`00o`Sooooo00Co003ooooooooo
oooo003o2?ooool01Ol00?oooooooooooooooooo003o04Oooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`11ooooo`05o`000?ooooooooooooooool00?l00oooool00ol00?ooooooooooo`05
ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`05o`00
ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00oooooooooooo
o`00o`Sooooo00Go003oooooooooooooooooo`00o`08ooooo`04o`00ooooooooooooo`00o`Sooooo
00Co003ooooooooooooo003o2?ooool01Ol00?oooooooooooooooooo003o04Oooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`11ooooo`05o`000?ooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool0
0?l8ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o00So
oooo00Co003ooooooooooooo003o2?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003o
ooooooooooooooooo`00o`08ooooo`04o`00ooooooooooooo`00o`Sooooo00Go003ooooooooooooo
ooooo`00o`17ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool01Ol0003ooooo
oooooooooooo003o00?ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o
00Sooooo00Co003ooooooooooooo003o2?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go
003oooooooooooooooooo`00o`08ooooo`04o`00ooooooooooooo`00o`Sooooo00Go003ooooooooo
ooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool0
0?l8ooooo`05o`00ooooooooooooooooool00?l0Aoooool1o`00007ooooo000Kooooo`;o0000@_oo
ool01Ol0003ooooooooooooooooo003o00?ooooo00?o003oooooooooool01Oooool01Ol00?oooooo
oooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00oooooooooooo
ooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003ooooooooooooooooo
o`00o`07ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o
00Sooooo00Co003ooooooooooooo003o2?ooool01Ol00?oooooooooooooooooo003o04Kooooo0_l0
0001ooooo`006oooool00ol0003oooooooooo`11ooooo`05o`000?ooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooo
oooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00oooooooooooo
ooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003ooooooooooooooooo
o`00o`07ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8oooo
o`05o`00ooooooooooooooooool00?l0Aoooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
047ooooo00Go0000ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Gooooo00Go003o
ooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooo
oooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00oooooooooooo
ooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003ooooooooooooooooo
o`00o`08ooooo`04o`00ooooooooooooo`00o`Sooooo00Go003oooooooooooooooooo`00o`17oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool01Ol0003ooooooooooooooooo003o
00?ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003o
ooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooo
oooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00oooooooooooo
ooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo00Co003ooooooooooooo003o
2?ooool01Ol00?oooooooooooooooooo003o04Oooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`11ooooo`05o`000?ooooooooooooooool00?l00oooool00ol00?ooooooooooo`05ooooo`05
o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003o
ooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooo
oooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00oooooooooooo
ooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`05o`00ooooooooooooooooool00?l0
Aoooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Ooo
ool00ol0003oooooooooo`11ooooo`05o`000?ooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`05ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o
00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l02?oo
ool01Ol00?oooooooooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`05
o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`05o`00oooooooo
ooooooooool00?l0Aoooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo047ooooo00Go0000oooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`08oooo
o`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Oooooo00Go
003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oo
oooooooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00oooooooo
ooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o04Oooooo0Ol00001ooooo`001Ol0
0002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`11ooooo`05o`000?ooooooooooooooool00?l00oooool00ol00?ooooooooooo`05ooooo`05
o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003o
ooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooo
oooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00oooooooooooo
ooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003ooooooooooooooooo
o`00o`17ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002oooool00ol0003ooooo
ooooo`02ooooo`;o0000@_ooool01Ol0003ooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool01Oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`07
ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo
00Go003oooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol0
0?oooooooooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00oooo
ooooooooooooool00?l0A_ooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo
1?l00005ooooo`03o`000?oooooooooo047ooooo00Go0000ooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00oooooooooooo
ooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003ooooooooooooooooo
o`00o`08ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o
00Oooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l01ooo
ool01Ol00?oooooooooooooooooo003o04Oooooo0Ol00001ooooo`001oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@Oooool01Ol0003ooooo
oooooooooooo003o00?ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o
00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l01ooo
ool01Ol00?oooooooooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`05
o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003o
ooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l0Aoooool1o`00007ooooo
0008ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool0@Oooool01Ol0003ooooooooo
oooooooo003o00?ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00So
oooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l01oooool0
1Ol00?oooooooooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00
ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003ooooo
ooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l0Aoooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo047ooooo00Go0000ooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00Gooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool0
0?l01oooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`08
ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Oooooo
00Go003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol0
0?oooooooooooooooooo003o04Oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`11oooo
o`05o`000?ooooooooooooooool00?l00oooool00ol00?ooooooooooo`05ooooo`05o`00oooooooo
ooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003ooooooooooooo
ooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool01Ol00?oo
oooooooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00oooooooo
ooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003ooooooooooooo
ooooo`00o`17ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool01Ol0003ooooo
oooooooooooo003o00?ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o
00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l01ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooooooooooo
o`00o`07ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o
00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l0Aooo
ool1o`00007ooooo000Kooooo`;o0000@_ooool01Ol0003ooooooooooooooooo003o00?ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00Go
003oooooooooooooooooo`00o`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooooooo
ooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool01Ol00?oo
oooooooooooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00oooooooo
ooooooooool00?l0A_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00Go0000
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`05ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05
o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o04Oooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`11ooooo`05o`000?ooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool0
1Ol00?oooooooooooooooooo003o00Kooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooo
oooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00Oo
oooo00Go003oooooooooooooooooo`00o`17ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0@Oooool01?l0003oooooooooool00?l4ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooo
oooooooo003o04Oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`11ooooo`04o`000?oo
ooooooooo`00o`Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Go
oooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l0Aoooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00Co0000oooooooooooo003o1?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool0
1Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooo
oooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`17ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0@Oooool01?l0003oooooooooool00?l4ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00oooooooooooooooo
ool00?l01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01Oooool01Ol00?oooooooooooooooooo003o04Oooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`11ooooo`04o`000?ooooooooooo`00o`Cooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l0Aoooool1o`00007ooooo000K
ooooo`;o0000@_ooool01?l0003oooooooooool00?l4ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04?ooooo0_l0
0001ooooo`006oooool00ol0003oooooooooo`11ooooo`04o`000?ooooooooooo`00o`Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0A?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00Co0000
oooooooooooo003o1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`14ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0@Oooool01?l0003oooooooooool00?l4ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04Cooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`11ooooo`04o`000?ooooooooooo`00o`Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0A?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00Co0000
oooooooooooo003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`14ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0@Oooool01?l0003oooooooooool00?l5ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04Cooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`11ooooo`04o`000?ooooooooooo`00o`Gooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0A?ooool1o`00007ooooo000Kooooo`;o0000@_ooool01?l0003oooooooooool0
0?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo04?ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`11
ooooo`04o`000?ooooooooooo`00o`Gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0A?ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo047ooooo00Co0000oooooooooooo003o1Oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`14ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool01?l0003oooooooooool0
0?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo04Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`11
ooooo`04o`000?ooooooooooo`00o`Gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0A?ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo047ooooo00Co0000oooooooooooo003o1Oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`14ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool01?l0003oooooooooool0
0?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo04Cooooo0Ol00001ooooo`006oooool2o`0004;ooooo00Co0000
oooooooooooo003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`13ooooo`;o00000Oooool001_ooooo00?o0000
ooooooooool0@Oooool01?l0003oooooooooool00?l5ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04Cooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`11ooooo`04o`000?ooooooooooo`00o`Gooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool0A?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00Co0000
oooooooooooo003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`14ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0@Oooool01?l0003oooooooooool00?l5ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04Cooooo0Ol0
0001ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0@Oooool01?l0003oooooooooool0
0?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo04Cooooo0Ol00001ooooo`004oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo047ooooo00Co0000oooooooooooo003o1Oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`14ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`11ooooo`04o`000?ooooooooooo`00o`Gooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0A?ooool1o`00007o
oooo000Cooooo`04o`000?ooooooooooo`0000Cooooo1_l0000oo`00o`;o000000?o003oo`000?l0
00000ol000000ol00?oo0000o`000003o`000003o`00ool0003o000000?o000000?o003oo`000?l0
00000ol000000ol00?oo0000o`000004o`000003o`00ool0003o000000?o000000?o003oo`000?l0
00000ol000000ol00?oo0000o`000003o`000003o`00ool0003o000000?o000000?o003oo`000?l0
00001?l000000ol00?oo0000o`000003o`000003o`00ool0003o000000?o000000?o003oo`000?l0
00000ol000000ol00?oo0000o`000003o`000003o`00ool0003o000000Co000000?o003oo`000?l0
00000ol000000ol00?oo0000o`000003o`000003o`00ool0003o000000?o000000?o003oo`000?l0
00000ol000001?l00?oo0000o`000?l0000no`00o`Ko00000Oooool001?ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`11ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00Go003o
ooooooooooooooooo`00o`12ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`11ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo
003o@_ooool1o`00007ooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`11ooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o@_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo047ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?m2
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool01?l00?ooooooooooool00?l5
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04
ooooo`04o`00ooooooooooooo`00od;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`11
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o@_ooool1o`00007ooooo
000Kooooo`;o0000@_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00od7o
oooo0_l00001ooooo`006oooool00ol0003oooooooooo`11ooooo`04o`00ooooooooooooo`00o`Go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Co
oooo00Co003ooooooooooooo003o@_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo047o
oooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?m2ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0@Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`04o`00oooooooo
ooooo`00od;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`11ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Cooooo00Co003ooooooooooooo003o@_ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo047ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?m2ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0@Oooool01?l00?ooooooooooool00?l5ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`04
o`00ooooooooooooo`00od;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`11ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o@_ooool1o`00007ooooo000Koooo
o`;o0000@_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00od7ooooo0_l0
0001ooooo`006oooool00ol0003oooooooooo`11ooooo`04o`00ooooooooooooo`00o`Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00Co
003ooooooooooooo003o@_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01?ooool01?l00?ooooooooooool00?m2ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0@Oooool01?l00?ooooooooooool00?l6ooooo`05o`00oooooooooooooooo
ool00?l01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00od;ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`11ooooo`04o`00ooooooooooooo`00o`Kooooo00Go003o
ooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o
@_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00Co003ooooooooooooo003o
1_ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?m2
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool01?l00?ooooooooooool00?l6
ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Gooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00od;o
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`11ooooo`04o`00ooooooooooooo`00o`Ko
oooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01Oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o@_oo
ool1o`00007ooooo000Kooooo`;o0000@_ooool01?l00?ooooooooooool00?l6ooooo`05o`00oooo
ooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo
00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00od7ooooo0_l00001oooo
o`006oooool00ol0003oooooooooo`11ooooo`03o`00oooooooo003o00Oooooo00Go003ooooooooo
ooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool01Ol0
0?oooooooooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Cooooo00Co003ooooooooooooo003o@_ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo047ooooo00?o003oooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Oooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool0
0?l01oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`07
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool0
0?m2ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool00ol00?ooooooo`00o`07
ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Gooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool0
0?l01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool01Oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`04ooooo`04o`00ooooooooooooo`00od;ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`11ooooo`03o`00oooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`07
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooo
oooo003o00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool0
0?l01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooo
oooo003o@_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00?o003oooooool0
0?l01oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooo
oooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Gooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01?ooool01?l00?ooooooooooool00?m2ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0@Oooool00ol00?ooooooo`00o`07ooooo`05o`00ooooooooooooooooool0
0?l01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooo
ooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00Oooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00od;o
oooo0Ol00001ooooo`006oooool2o`0004;ooooo00?o003oooooool00?l01oooool01Ol00?oooooo
oooooooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05
o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooooooooooo
o`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool01?l00?oooooo
ooooool00?m1ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool00ol00?oooooo
o`00o`07ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o
00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l01ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooooooooooo
o`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool01Ol00?oooooo
oooooooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`04
o`00ooooooooooooo`00od;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`11ooooo`03
o`00oooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00oooooooooooo
ooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003ooooooooooooooooo
o`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool01Ol00?oooooo
oooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00oooooooooooo
ooooool00?l01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00Co003o
oooooooooooo003o@_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00?o003o
ooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003ooooooooooooooooo
o`00o`08ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o
00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00oooooooooooo
ooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003ooooooooooooooooo
o`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool01?l00?oooooo
ooooool00?m2ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool00ol00?oooooo
o`00o`07ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o
00Sooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l01ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooooooooooo
o`00o`07ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o
00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`04o`00ooooooooooooo`00od;ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`11ooooo`03o`00oooooooo003o00Oooooo00Go003o
ooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooo
oooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00oooooooooooo
ooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003ooooooooooooooooo
o`00o`08ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o
00Oooooo00Co003ooooooooooooo003o@_ooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`11ooooo`03o`00oooooooo003o
00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l02?oo
ool01Ol00?oooooooooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`05
o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003o
ooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooo
oooooooooooo003o00Oooooo00Co003ooooooooooooo003o@_ooool1o`00007ooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo047ooooo00?o003oooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo00Co
003ooooooooooooo003o2?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003ooooooooo
ooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooo
oooo003o00Oooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool0
0?l01oooool01Ol00?oooooooooooooooooo003o00Oooooo00Co003ooooooooooooo003o@_ooool1
o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2
o`0004;ooooo00?o003oooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo00Co
003ooooooooooooo003o2?ooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003ooooooooo
ooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooooooo
oooo003o00Oooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool0
0?l01oooool01Ol00?oooooooooooooooooo003o00Oooooo00Co003ooooooooooooo003o@Oooool2
o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`11ooooo`03o`00oooooooo003o00Oooooo00Go003oooooooooooooooooo`00
o`08ooooo`04o`00ooooooooooooo`00o`Sooooo00Go003oooooooooooooooooo`00o`07ooooo`05
o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003o
ooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooo
oooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooo003o
04?ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0
003oooooooooo`11ooooo`03o`00oooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`08
ooooo`04o`00ooooooooooooo`00o`Sooooo00Go003oooooooooooooooooo`00o`07ooooo`05o`00
ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003ooooo
ooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooo
oooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooo003o04?o
oooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0@Oooool00ol00?ooooooo`00o`07ooooo`05o`00oooooooooooooooo
ool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`05o`00ooooooooooooooooool00?l01ooo
ool01Ol00?oooooooooooooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`08ooooo`05
o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003o
ooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?oooooo
o`00o`13ooooo`7o00000Oooool000Sooooo0_l00008ooooo`Go00001?ooool00ol0003ooooooooo
o`11ooooo`03o`00oooooooo003o00Oooooo00Go003oooooooooooooooooo`00o`08ooooo`04o`00
ooooooooooooo`00o`Sooooo00Co003ooooooooooooo003o2?ooool01Ol00?oooooooooooooooooo
003o00Oooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00ooooooooooooooooool00?l0
2?ooool01?l00?ooooooooooool00?l8ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol0
0?oooooooooooooooooo003o00Oooooo00?o003oooooool00?l0@oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo047ooooo00?o003oooooool00?l01oooool01Ol00?oooooooooooooooooo
003o00Sooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l8ooooo`05o`00
ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003ooooo
ooooooooooooo`00o`08ooooo`04o`00ooooooooooooo`00o`Sooooo00Go003ooooooooooooooooo
o`00o`07ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooo`00o`13ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0@Oooool00ol00?ooooooo`00o`07ooooo`05o`00
ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00oooooooooooo
o`00o`Sooooo00Go003oooooooooooooooooo`00o`08ooooo`04o`00ooooooooooooo`00o`Sooooo
00Go003oooooooooooooooooo`00o`08ooooo`04o`00ooooooooooooo`00o`Sooooo00Go003ooooo
ooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?ooooooo`00
o`13ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool00ol00?ooooooo`00o`07
ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00
ooooooooooooo`00o`Sooooo00Go003oooooooooooooooooo`00o`08ooooo`04o`00oooooooooooo
o`00o`Sooooo00Go003oooooooooooooooooo`00o`08ooooo`04o`00ooooooooooooo`00o`Sooooo
00Go003oooooooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l02?ooool2o`00
od?ooooo0Ol00001ooooo`006oooool2o`0004;ooooo00?o003oooooool00?l01oooool01Ol00?oo
oooooooooooooooo003o00Sooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool0
0?l8ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`05
o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`05o`00oooooooo
ooooooooool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo0_l00?m2ooooo`;o0000
0Oooool001_ooooo00?o0000ooooooooool0@Oooool00ol00?ooooooo`00o`07ooooo`05o`00oooo
ooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00
o`Wooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l8ooooo`05o`00oooo
ooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`05o`00oooooooooooooooo
ool00?l01oooool01Ol00?oooooooooooooooooo003o00Sooooo0_l00?m3ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0@Oooool00ol00?ooooooo`00o`07ooooo`05o`00oooooooooooo
ooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo
00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l8ooooo`05o`00oooooooooooo
ooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Sooooo
00Go003oooooooooooooooooo`00o`08ooooo`;o003o@oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo047ooooo0_l00?l8ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?oo
ooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Co003ooooooooooooo003o2?oo
ool01?l00?ooooooooooool00?l8ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?oo
ooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Sooooo00Go003oooooooooooooooooo`00
o`08ooooo`;o003o@oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo0_l00?l8
ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00
ooooooooooooo`00o`Wooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l8
ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00
ooooooooooooo`00o`Sooooo00Go003oooooooooooooooooo`00o`08ooooo`;o003o@oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo047ooooo0_l00?l8ooooo`05o`00oooooooooooooooo
ool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Co
003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l8ooooo`05o`00oooooooooooooooo
ool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Sooooo00Go
003oooooooooooooooooo`00o`08ooooo`;o003o@oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo047ooooo0_l00?l8ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?oooooo
ooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Co003ooooooooooooo003o2?ooool0
1?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Co003ooooooooooooo
003o2?ooool01?l00?ooooooooooool00?l8ooooo`05o`00ooooooooooooooooool00?l02?ooool2
o`00od?ooooo0Ol00001ooooo`006oooool2o`0004;ooooo0_l00?l8ooooo`05o`00oooooooooooo
ooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo
00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l8ooooo`04o`00oooooooooooo
o`00o`Wooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l8ooooo`05o`00
ooooooooooooooooool00?l02?ooool2o`00od;ooooo0_l00001ooooo`006oooool00ol0003ooooo
ooooo`11ooooo`;o003o2?ooool01Ol00?oooooooooooooooooo003o00Sooooo00Co003ooooooooo
oooo003o2?ooool01?l00?ooooooooooool00?l9ooooo`04o`00ooooooooooooo`00o`Sooooo00Co
003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l9ooooo`04o`00ooooooooooooo`00
o`Sooooo00Co003ooooooooooooo003o2Oooool01?l00?ooooooooooool00?l8ooooo`;o003o@ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo0_l00?l8ooooo`05o`00oooooooo
ooooooooool00?l02?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wo
oooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l8ooooo`04o`00oooooooo
ooooo`00o`Wooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l9ooooo`04
o`00ooooooooooooo`00o`Sooooo0_l00?m3ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0@Oooool2o`00o`Wooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l8
ooooo`04o`00ooooooooooooo`00o`Wooooo00Co003ooooooooooooo003o2?ooool01?l00?oooooo
ooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Co003ooooooooooooo003o2?ooool0
1?l00?ooooooooooool00?l9ooooo`04o`00ooooooooooooo`00o`Sooooo0_l00?m3ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0@Oooool2o`00o`Wooooo00Co003ooooooooooooo003o
2?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Co003ooooo
oooooooo003o2?ooool01?l00?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo
00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l9ooooo`04o`00oooooooooooo
o`00o`Sooooo0_l00?m3ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0@Oooool2o`00
o`Wooooo00?o003oooooool00?l02Oooool01?l00?ooooooooooool00?l8ooooo`04o`00oooooooo
ooooo`00o`Wooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l9ooooo`03
o`00oooooooo003o00Wooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l9
ooooo`04o`00ooooooooooooo`00o`Sooooo0_l00?m3ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0@Oooool2o`00o`Wooooo00?o003oooooool00?l02Oooool01?l00?ooooooooooool0
0?l9ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02Oooool01?l00?oooooooooo
ool00?l9ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02Oooool01?l00?oooooo
ooooool00?l9ooooo`04o`00ooooooooooooo`00o`Sooooo0_l00?m3ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0@Oooool2o`00o`Wooooo00?o003oooooool00?l02Oooool01?l00?oo
ooooooooool00?l9ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02Oooool01?l0
0?ooooooooooool00?l9ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02Oooool0
1?l00?ooooooooooool00?l9ooooo`03o`00oooooooo003o00Wooooo0_l00?m3ooooo`7o00000Ooo
ool001_ooooo0_l00012ooooo`;o003o2Oooool00ol00?ooooooo`00o`09ooooo`04o`00oooooooo
ooooo`00o`Wooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`09ooooo`04o`00oooo
ooooooooo`00o`Wooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`09ooooo`04o`00
ooooooooooooo`00o`Wooooo00?o003oooooool00?l02Oooool2o`00od;ooooo0_l00001ooooo`00
6oooool00ol0003oooooooooo`11ooooo`;o003o2Oooool00ol00?ooooooo`00o`09ooooo`04o`00
ooooooooooooo`00o`Wooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`09ooooo`04
o`00ooooooooooooo`00o`Wooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`0:oooo
o`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02Oooool2o`00od?ooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`11ooooo`;o003o2Oooool00ol00?ooooooo`00o`09ooooo`04
o`00ooooooooooooo`00o`Wooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`09oooo
o`04o`00ooooooooooooo`00o`Wooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`0:
ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02Oooool2o`00od?ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`11ooooo`;o003o2Oooool00ol00?ooooooo`00o`09oooo
o`04o`00ooooooooooooo`00o`Wooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`09
ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00
o`0:ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02Oooool2o`00od?ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`11ooooo`;o003o2Oooool00ol00?ooooooo`00o`09
ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00
o`09ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003oooooool00?l02Oooool00ol00?oooooo
o`00o`0:ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02Oooool2o`00od?ooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`11ooooo`;o003o2Oooool00ol00?ooooooo`00
o`09ooooo`03o`00oooooooo003o00[ooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00
o`0:ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00
o`0:ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02Oooool2o`00od?ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`11ooooo`;o003o2Oooool00ol00?ooooooo`00o`09
ooooo`03o`00oooooooo003o00[ooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`0:
ooooo`;o003o2_ooool00ol00?ooooooo`00o`09ooooo`03o`00oooooooo003o00[ooooo00?o003o
ooooool00?l02Oooool00ol00?ooooooo`00o`09ooooo`;o003o@oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo047ooooo0_l00?l9ooooo`03o`00oooooooo003o00[ooooo0_l00?l:oooo
o`03o`00oooooooo003o00Wooooo00?o003oooooool00?l02_ooool2o`00o`[ooooo00?o003ooooo
ool00?l02Oooool00ol00?ooooooo`00o`0:ooooo`;o003o2_ooool00ol00?ooooooo`00o`0:oooo
o`03o`00oooooooooooo047ooooo0Ol00001ooooo`006oooool2o`0004;ooooo0_l00?l9ooooo`03
o`00oooooooo003o00[ooooo0_l00?l:ooooo`03o`00oooooooo003o00Wooooo00?o003oooooool0
0?l02_ooool2o`00o`[ooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`0:ooooo`;o
003o2_ooool00ol00?ooooooo`00o`0:ooooo`03o`00oooooooooooo043ooooo0_l00001ooooo`00
6oooool00ol0003oooooooooo`11ooooo`;o003o2Oooool00ol00?ooooooo`00o`0:ooooo`;o003o
2_ooool00ol00?ooooooo`00o`09ooooo`03o`00oooooooo003o00[ooooo0_l00?l:ooooo`03o`00
oooooooo003o00Wooooo00?o003oooooool00?l02_ooool2o`00o`[ooooo00?o003oooooool00?l0
2_ooool00ol00?ooooooooooo`11ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0@Ooo
ool2o`00o`Wooooo00?o003oooooool00?l02_ooool2o`00o`[ooooo00?o003oooooool00?l02Ooo
ool00ol00?ooooooo`00o`0:ooooo`;o003o2_ooool00ol00?ooooooo`00o`09ooooo`03o`00oooo
oooo003o00[ooooo0_l00?l:ooooo`03o`00oooooooo003o00[ooooo00?o003oooooooooool0@Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooo`00o`0:ooooo`;o003o2_ooool00ol00?ooooooo`00o`0:ooooo`;o003o2_ooool2
o`00o`[ooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`0:ooooo`;o003o2_ooool0
0ol00?ooooooo`00o`0:ooooo`03o`00oooooooooooo047ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`11ooooo`03o`00oooooooooooo00Sooooo00?o003oooooool00?l02_ooool2o`00
o`[ooooo00?o003oooooool00?l02_ooool2o`00o`[ooooo0_l00?l:ooooo`03o`00oooooooo003o
00[ooooo0_l00?l:ooooo`;o003o2_ooool00ol00?ooooooo`00o`0:ooooo`03o`00oooooooooooo
047ooooo0Ol00001ooooo`004oooool3o`0000Gooooo00?o0000ooooooooool0@Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo0_l00?l:ooooo`;o003o2oooool2o`00o`[o
oooo0_l00?l:ooooo`;o003o2oooool2o`00o`[ooooo0_l00?l:ooooo`;o003o2oooool00ol00?oo
ooooooooo`11ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`11ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool2o`00o`_ooooo
00?o003oooooooooool02Oooool2o`00o`[ooooo0_l00?l;ooooo`03o`00oooooooooooo00Wooooo
0_l00?l:ooooo`;o003o2_ooool2o`00o`_ooooo00?o003oooooooooool0@Oooool1o`00007ooooo
000Dooooo`03o`000?oooooooooo00Cooooo0_l00012ooooo`03o`000?oooooooooo00Wooooo00?o
003oooooooooool02Oooool2o`00o`_ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`;o003o2oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo043ooooo0_l0
0001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool0_?ooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`004oooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00007ooooo000Dooooo`03o`00
0?oooooooooo00Coooooool00005o`00007ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-7.70385, -1.23352, \
0.0808852, 0.0130875}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xf\  = \ 
        FourierTransform[x[t], \ t, \ f]\  // \ 
          Simplify;\)\), "\[IndentingNewLine]", 
    \(xf\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\/4\ \((\(-\(\(\[ImaginaryI]\ \@\((f - 1)\)\^2\ \(cos(
                    20\ \@\((f - 1)\)\^2\ \[Pi])\)\ \(sgn(
                    1 - f)\)\)\/\(\((f - 1)\)\^2\ \[Pi]\)\)\) + \(\
\[ImaginaryI]\ \@\((\[Pi]\ f + \[Pi])\)\^2\ \(cos(20\ \@\((\[Pi]\ f + \
\[Pi])\)\^2)\)\ \(sgn(f + 1)\)\)\/\((\[Pi]\ f + \[Pi])\)\^2 + \(\@\((f - 1)\)\
\^2\ \(sin(20\ \@\((f - 1)\)\^2\ \[Pi])\)\)\/\(\((f - 1)\)\^2\ \[Pi]\) + \(\@\
\((\[Pi]\ f + \[Pi])\)\^2\ \(sin(20\ \@\((\[Pi]\ f + \[Pi])\)\^2)\)\)\/\((\
\[Pi]\ f + \[Pi])\)\^2 + \[ImaginaryI]\/\(\[Pi] - f\ \[Pi]\) - \
\[ImaginaryI]\/\(\((f + 1)\)\ \[Pi]\))\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g1 = 
        Plot[Abs[xf], {f, \(-5\), 5}, \ PlotStyle \[Rule] {Red}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[Arg[xf], {f, \(-5\), 5}, \ PlotStyle \[Rule] {Red}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.117679 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13239 -6 -4.5 ]
[-0.0125 .13239 0 4.5 ]
[-0.0125 .25007 -6 -4.5 ]
[-0.0125 .25007 0 4.5 ]
[-0.0125 .36775 -6 -4.5 ]
[-0.0125 .36775 0 4.5 ]
[-0.0125 .48543 -6 -4.5 ]
[-0.0125 .48543 0 4.5 ]
[-0.0125 .60311 -6 -4.5 ]
[-0.0125 .60311 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13239 m
.00625 .13239 L
s
[(1)] -0.0125 .13239 1 0 Mshowa
0 .25007 m
.00625 .25007 L
s
[(2)] -0.0125 .25007 1 0 Mshowa
0 .36775 m
.00625 .36775 L
s
[(3)] -0.0125 .36775 1 0 Mshowa
0 .48543 m
.00625 .48543 L
s
[(4)] -0.0125 .48543 1 0 Mshowa
0 .60311 m
.00625 .60311 L
s
[(5)] -0.0125 .60311 1 0 Mshowa
.125 Mabswid
0 .03825 m
.00375 .03825 L
s
0 .06179 m
.00375 .06179 L
s
0 .08532 m
.00375 .08532 L
s
0 .10886 m
.00375 .10886 L
s
0 .15593 m
.00375 .15593 L
s
0 .17947 m
.00375 .17947 L
s
0 .203 m
.00375 .203 L
s
0 .22654 m
.00375 .22654 L
s
0 .27361 m
.00375 .27361 L
s
0 .29715 m
.00375 .29715 L
s
0 .32068 m
.00375 .32068 L
s
0 .34422 m
.00375 .34422 L
s
0 .39129 m
.00375 .39129 L
s
0 .41482 m
.00375 .41482 L
s
0 .43836 m
.00375 .43836 L
s
0 .4619 m
.00375 .4619 L
s
0 .50897 m
.00375 .50897 L
s
0 .5325 m
.00375 .5325 L
s
0 .55604 m
.00375 .55604 L
s
0 .57958 m
.00375 .57958 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13239 m
1 .13239 L
s
.99375 .25007 m
1 .25007 L
s
.99375 .36775 m
1 .36775 L
s
.99375 .48543 m
1 .48543 L
s
.99375 .60311 m
1 .60311 L
s
.125 Mabswid
.99625 .03825 m
1 .03825 L
s
.99625 .06179 m
1 .06179 L
s
.99625 .08532 m
1 .08532 L
s
.99625 .10886 m
1 .10886 L
s
.99625 .15593 m
1 .15593 L
s
.99625 .17947 m
1 .17947 L
s
.99625 .203 m
1 .203 L
s
.99625 .22654 m
1 .22654 L
s
.99625 .27361 m
1 .27361 L
s
.99625 .29715 m
1 .29715 L
s
.99625 .32068 m
1 .32068 L
s
.99625 .34422 m
1 .34422 L
s
.99625 .39129 m
1 .39129 L
s
.99625 .41482 m
1 .41482 L
s
.99625 .43836 m
1 .43836 L
s
.99625 .4619 m
1 .4619 L
s
.99625 .50897 m
1 .50897 L
s
.99625 .5325 m
1 .5325 L
s
.99625 .55604 m
1 .55604 L
s
.99625 .57958 m
1 .57958 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02489 .01745 L
.02608 .02005 L
.02668 .02108 L
.027 .02155 L
.02732 .02192 L
.02761 .02219 L
.02776 .02231 L
.02792 .02241 L
.02806 .02248 L
.02821 .02254 L
.02834 .02258 L
.02847 .0226 L
.02855 .0226 L
.02863 .0226 L
.02878 .02259 L
.02887 .02257 L
.02896 .02255 L
.02912 .02248 L
.02928 .0224 L
.02942 .02231 L
.02975 .02204 L
.03032 .02136 L
.03092 .02039 L
.03219 .01765 L
.03252 .01682 L
.03289 .01588 L
.03305 .01545 L
.03315 .01521 L
.03323 .01498 L
.03338 .01485 L
.03346 .01506 L
.03355 .01529 L
.03479 .01841 L
.03592 .02076 L
.03648 .02164 L
.03679 .02202 L
.03707 .02231 L
.03732 .0225 L
.03744 .02258 L
.03758 .02265 L
.03773 .02271 L
.03787 .02275 L
.038 .02278 L
.03813 .02278 L
.03828 .02277 L
.03842 .02274 L
.03855 .0227 L
.03869 .02264 L
.03885 .02255 L
Mistroke
.03901 .02244 L
.0393 .02217 L
.03987 .02146 L
.04039 .0206 L
.04169 .01777 L
.04226 .01631 L
.04256 .01551 L
.04264 .0153 L
.04273 .01507 L
.04288 .01478 L
.04304 .01521 L
.04319 .01561 L
.04347 .01635 L
.04401 .01776 L
.04521 .02046 L
.04579 .02148 L
.04643 .02232 L
.04675 .02261 L
.04693 .02274 L
.04709 .02283 L
.04724 .0229 L
.0474 .02294 L
.04748 .02296 L
.04757 .02296 L
.04772 .02296 L
.04787 .02294 L
.04795 .02292 L
.04803 .0229 L
.04819 .02283 L
.04837 .02273 L
.04868 .02249 L
.04896 .0222 L
.04965 .02122 L
.0503 .01998 L
.05148 .01716 L
.05207 .01556 L
.05224 .01511 L
.05233 .01486 L
.05241 .0148 L
.05257 .01523 L
.05273 .01568 L
.05388 .01868 L
.05448 .02008 L
.05513 .02133 L
.05544 .02183 L
.05573 .02224 L
.05602 .02256 L
.05628 .0228 L
.05653 .02298 L
.05665 .02304 L
Mistroke
.05679 .0231 L
.05693 .02314 L
.05708 .02316 L
.05722 .02316 L
.05735 .02315 L
.05751 .02311 L
.05765 .02305 L
.05778 .02299 L
.05793 .0229 L
.05825 .02263 L
.05854 .02231 L
.05908 .02153 L
.05964 .02049 L
.06085 .01762 L
.06117 .01677 L
.06151 .01582 L
.06167 .01537 L
.06176 .01513 L
.06184 .0149 L
.06198 .01494 L
.06214 .01538 L
.06338 .01873 L
.06397 .02013 L
.06451 .02124 L
.06502 .02209 L
.06558 .02279 L
.06587 .02305 L
.066 .02315 L
.06614 .02322 L
.06628 .02329 L
.06642 .02333 L
.06657 .02336 L
.06672 .02337 L
.06687 .02335 L
.06701 .02332 L
.06717 .02326 L
.06731 .02318 L
.06758 .023 L
.06787 .02272 L
.06818 .02234 L
.06852 .02183 L
.06912 .02072 L
.07045 .0175 L
.07103 .01587 L
.07118 .01542 L
.07127 .01517 L
.07135 .01493 L
.07143 .01472 L
.07152 .01497 L
.07166 .01539 L
Mistroke
.07227 .01711 L
.07291 .01883 L
.07356 .0204 L
.07425 .02179 L
.07485 .0227 L
.07519 .02308 L
.07536 .02323 L
.07552 .02335 L
.07566 .02343 L
.07581 .0235 L
.07595 .02355 L
.07608 .02357 L
.07623 .02358 L
.07637 .02357 L
.07645 .02355 L
.07653 .02353 L
.07668 .02347 L
.07683 .0234 L
.07697 .02331 L
.07728 .02304 L
.07756 .02272 L
.07783 .02235 L
.07843 .0213 L
.07909 .01987 L
.07973 .01823 L
.08041 .01632 L
.08069 .0155 L
.08083 .01507 L
.08099 .01482 L
.08107 .01506 L
.08116 .01533 L
.08132 .0158 L
.08163 .0167 L
.08284 .01999 L
.08344 .02133 L
.08399 .02234 L
.08429 .0228 L
.08463 .0232 L
.08496 .02351 L
.08514 .02363 L
.08523 .02368 L
.08532 .02372 L
.08547 .02377 L
.08562 .0238 L
.08576 .02381 L
.0859 .02379 L
.08605 .02376 L
.0862 .0237 L
.08636 .02361 L
.08652 .02351 L
Mistroke
.08681 .02324 L
.08708 .02293 L
.0877 .02197 L
.0883 .02074 L
.08894 .01916 L
.08954 .0175 L
.08984 .01664 L
.09011 .01582 L
.09036 .01508 L
.09048 .01473 L
.09062 .01515 L
.09117 .01682 L
.09231 .01998 L
.09293 .02143 L
.09351 .02253 L
.09384 .02304 L
.09414 .02341 L
.09447 .02373 L
.09465 .02386 L
.09473 .0239 L
.09482 .02395 L
.09497 .024 L
.09512 .02404 L
.09527 .02405 L
.0954 .02404 L
.09556 .024 L
.0957 .02395 L
.09587 .02386 L
.09603 .02375 L
.09631 .02349 L
.09658 .02318 L
.09719 .02222 L
.09778 .02099 L
.09842 .01939 L
.09899 .01781 L
.09929 .01689 L
.09958 .01602 L
.09983 .01526 L
.09996 .01483 L
.10009 .01499 L
.10023 .01542 L
.10037 .01588 L
.10064 .01671 L
.10188 .02024 L
.10248 .02167 L
.10304 .02275 L
.10362 .02359 L
.10377 .02377 L
.10394 .02393 L
.1041 .02405 L
Mistroke
.10424 .02414 L
.10433 .02419 L
.10442 .02423 L
.10458 .02427 L
.10467 .02429 L
.10476 .0243 L
.10484 .0243 L
.10493 .02429 L
.10502 .02427 L
.10509 .02425 L
.10518 .02422 L
.10526 .02418 L
.10541 .0241 L
.10557 .02398 L
.10585 .02371 L
.10616 .02333 L
.10671 .02243 L
.10736 .02104 L
.10796 .01949 L
.1086 .01763 L
.10919 .01577 L
.10935 .01528 L
.10949 .01481 L
.10957 .01488 L
.10966 .01516 L
.10981 .01564 L
.11049 .01778 L
.11173 .02122 L
.11234 .02255 L
.11289 .0235 L
.11319 .0239 L
.11347 .02419 L
.11362 .02431 L
.11377 .02441 L
.11386 .02446 L
.11394 .02449 L
.1141 .02454 L
.11418 .02456 L
.11427 .02456 L
.11443 .02456 L
.11452 .02454 L
.1146 .02452 L
.11469 .02449 L
.11478 .02445 L
.11496 .02434 L
.11512 .02422 L
.11543 .0239 L
.11649 .02212 L
.11709 .0207 L
.11763 .0192 L
Mistroke
.11827 .01723 L
.11859 .01622 L
.11874 .01571 L
.11888 .01525 L
.11902 .01479 L
.11916 .01507 L
.11929 .01553 L
.11945 .01602 L
.12006 .01799 L
.12122 .02132 L
.12186 .02277 L
.12245 .02381 L
.12275 .02421 L
.12308 .02453 L
.12326 .02467 L
.12335 .02472 L
.12344 .02476 L
.1236 .02482 L
.12368 .02483 L
.12377 .02485 L
.12391 .02485 L
.12407 .02482 L
.12421 .02477 L
.12435 .02471 L
.12449 .02461 L
.12466 .02448 L
.12498 .02413 L
.12562 .02315 L
.1263 .02167 L
.12754 .01812 L
.12813 .0162 L
.12828 .01572 L
.12843 .0152 L
.12852 .0149 L
.1286 .0148 L
.12876 .01534 L
.12987 .01901 L
.13103 .02222 L
.13168 .02359 L
.13199 .0241 L
.13229 .0245 L
.13257 .02479 L
.13272 .02492 L
.13287 .02501 L
.13299 .02507 L
.13313 .02512 L
.13327 .02514 L
.1334 .02515 L
.13355 .02513 L
.13369 .02509 L
Mistroke
.13383 .02503 L
.13397 .02494 L
.13412 .02482 L
.13428 .02467 L
.13458 .02432 L
.13574 .02209 L
.13632 .02054 L
.13696 .01859 L
.1375 .01677 L
.1378 .01574 L
.13795 .01522 L
.13809 .01475 L
.13821 .01513 L
.13835 .0156 L
.13864 .0166 L
.13913 .01829 L
.14034 .02192 L
.14093 .02332 L
.14147 .02432 L
.14177 .02475 L
.14205 .02506 L
.14219 .02519 L
.14235 .0253 L
.14243 .02535 L
.14251 .02539 L
.14267 .02544 L
.14275 .02546 L
.14284 .02547 L
.143 .02546 L
.14308 .02545 L
.14316 .02542 L
.14325 .02539 L
.14335 .02534 L
.14352 .02524 L
.14368 .0251 L
.14399 .02477 L
.14453 .02392 L
.14505 .02284 L
.14565 .02129 L
.14619 .01965 L
.14679 .01766 L
.14711 .01655 L
.14728 .01593 L
.14744 .01534 L
.1476 .01479 L
.14768 .01495 L
.14776 .01524 L
.14805 .01628 L
.14862 .01826 L
.14976 .02185 L
Mistroke
.15041 .02348 L
.15072 .02414 L
.15101 .02465 L
.1513 .02507 L
.15161 .02542 L
.15178 .02557 L
.15193 .02567 L
.15208 .02575 L
.15216 .02577 L
.15224 .02579 L
.15233 .02581 L
.15241 .02581 L
.15257 .0258 L
.15265 .02578 L
.15273 .02575 L
.15282 .02571 L
.15292 .02566 L
.15309 .02554 L
.15325 .02539 L
.15355 .02504 L
.15461 .023 L
.15521 .02138 L
.15576 .01967 L
.1564 .01744 L
.15672 .01629 L
.15687 .01572 L
.15701 .0152 L
.15715 .01475 L
.15728 .01524 L
.15757 .01631 L
.15819 .01853 L
.15879 .02059 L
.15943 .02251 L
.16003 .02399 L
.16058 .02506 L
.16086 .02547 L
.16116 .02581 L
.16134 .02595 L
.1615 .02606 L
.16164 .02612 L
.1618 .02617 L
.16196 .02618 L
.16205 .02617 L
.16213 .02615 L
.16222 .02613 L
.1623 .02609 L
.16249 .02599 L
.16263 .02587 L
.1628 .02572 L
.16312 .02531 L
Mistroke
.16375 .02417 L
.16444 .02246 L
.16569 .0184 L
.16628 .01621 L
.16642 .01566 L
.16657 .01507 L
.16666 .01473 L
.16674 .01501 L
.1669 .01561 L
.16802 .01976 L
.16918 .02337 L
.16983 .0249 L
.17014 .02547 L
.17044 .0259 L
.17069 .02619 L
.17082 .02631 L
.17097 .02641 L
.17111 .02649 L
.17127 .02655 L
.17141 .02657 L
.17155 .02656 L
.1717 .02653 L
.17185 .02647 L
.17198 .0264 L
.17212 .02629 L
.17244 .02596 L
.17273 .02554 L
.17391 .02288 L
.17458 .0208 L
.17518 .01863 L
.17575 .01647 L
.1759 .01586 L
.17599 .01553 L
.17607 .01521 L
.17622 .01484 L
.17636 .01539 L
.17748 .01972 L
.17855 .02325 L
.17908 .02466 L
.17967 .02586 L
.17998 .02632 L
.18015 .02653 L
.18031 .02669 L
.18046 .02681 L
.18054 .02686 L
.18062 .0269 L
.18077 .02696 L
.18091 .02699 L
.18104 .02699 L
.18119 .02696 L
Mistroke
.18132 .02692 L
.18145 .02685 L
.18159 .02675 L
.18174 .02661 L
.18204 .02625 L
.18268 .02512 L
.18304 .02428 L
.18336 .02338 L
.18461 .01915 L
.18519 .01685 L
.18548 .01568 L
.1856 .01517 L
.18574 .01482 L
.18588 .01541 L
.18602 .01596 L
.18631 .01717 L
.18694 .01965 L
.18812 .02372 L
.18878 .02544 L
.1891 .02609 L
.18938 .02658 L
.18966 .02694 L
.1898 .02709 L
.18994 .02722 L
.19009 .02733 L
.19023 .02739 L
.19032 .02742 L
.1904 .02744 L
.19055 .02745 L
.19068 .02743 L
.19082 .02738 L
.19094 .02732 L
.19108 .02723 L
.19122 .0271 L
.19137 .02694 L
.19165 .02656 L
.19402 .01975 L
.19468 .0171 L
.19486 .01631 L
.19504 .01556 L
.1952 .01489 L
.19529 .01493 L
.19537 .01528 L
.19662 .02045 L
.19773 .02431 L
.19836 .02597 L
.19864 .02656 L
.19895 .0271 L
.19911 .02733 L
.19926 .02751 L
Mistroke
.19941 .02766 L
.19957 .02778 L
.19971 .02786 L
.19984 .02791 L
.19998 .02794 L
.20013 .02793 L
.20029 .0279 L
.20037 .02786 L
.20046 .02781 L
.20062 .0277 L
.2008 .02753 L
.20112 .02711 L
.20141 .02661 L
.20199 .02528 L
.20261 .02343 L
.20372 .01925 L
.20429 .01679 L
.20446 .01606 L
.20462 .01536 L
.20476 .01473 L
.20491 .01538 L
.20559 .01837 L
.20623 .02102 L
.20687 .02343 L
.20747 .02535 L
.20802 .02673 L
.20832 .02734 L
.2086 .02779 L
.20891 .02816 L
.20907 .0283 L
.20916 .02836 L
.20924 .0284 L
.20933 .02844 L
.20942 .02846 L
.20951 .02847 L
.2096 .02848 L
.20975 .02845 L
.20984 .02842 L
.20992 .02838 L
.21007 .02829 L
.21022 .02815 L
.2105 .02782 L
.2108 .02734 L
.21113 .02667 L
.21177 .02496 L
.21237 .02293 L
.2135 .0183 L
.21381 .01692 L
.21397 .01615 L
.21413 .01543 L
Mistroke
.21427 .01481 L
.21441 .01529 L
.21471 .0167 L
.21603 .02241 L
.21662 .0246 L
.21725 .02652 L
.21758 .02733 L
.21794 .02806 L
.2181 .02831 L
.21827 .02855 L
.21844 .02873 L
.21858 .02887 L
.21873 .02896 L
.21888 .02903 L
.21897 .02905 L
.21905 .02906 L
.2192 .02905 L
.21928 .02903 L
.21936 .029 L
.21951 .02892 L
.21959 .02886 L
.21967 .0288 L
.21985 .02861 L
.22014 .0282 L
.22041 .02772 L
.22101 .02626 L
.22159 .02443 L
.2222 .02209 L
.22273 .01981 L
.2233 .01716 L
.22347 .01635 L
.22365 .01548 L
.22381 .01473 L
.22389 .01512 L
.22398 .01552 L
.22461 .01856 L
.2258 .02375 L
.2264 .02592 L
.22672 .02689 L
.22706 .02779 L
.22736 .02843 L
.22768 .029 L
.22782 .0292 L
.22798 .02937 L
.22812 .02951 L
.22825 .0296 L
.22838 .02966 L
.22852 .0297 L
.22866 .0297 L
.22878 .02968 L
Mistroke
.22892 .02963 L
.22907 .02954 L
.22921 .02941 L
.22934 .02927 L
.22961 .0289 L
.2299 .02837 L
.23049 .0269 L
.23112 .02483 L
.23172 .02244 L
.23226 .02 L
.23284 .0172 L
.23301 .01636 L
.23317 .01556 L
.23331 .01484 L
.23346 .01538 L
.23361 .01612 L
.23377 .0169 L
.23404 .01829 L
.23536 .02431 L
.23595 .02651 L
.2365 .02819 L
.23681 .02894 L
.23715 .02958 L
.23729 .02981 L
.23745 .03001 L
.2376 .03016 L
.23773 .03027 L
.23786 .03035 L
.23799 .0304 L
.23813 .03041 L
.23827 .0304 L
.2384 .03036 L
.23854 .03028 L
.23867 .03018 L
.23878 .03006 L
.23907 .02968 L
.23938 .02911 L
.23994 .0277 L
.24054 .02573 L
.24109 .02349 L
.24175 .02044 L
.24235 .01741 L
.24265 .01583 L
.24273 .01539 L
.24282 .01493 L
.24298 .01534 L
.24312 .01612 L
.24326 .01684 L
.24357 .01848 L
.24489 .02479 L
Mistroke
.2455 .02719 L
.24607 .02897 L
.24638 .02974 L
.24667 .03031 L
.24698 .03078 L
.24715 .03096 L
.24724 .03103 L
.24732 .03109 L
.24745 .03116 L
.24759 .03119 L
.24773 .0312 L
.24787 .03116 L
.24801 .03109 L
.24814 .031 L
.24826 .03089 L
.24839 .03074 L
.24868 .03029 L
.24899 .02965 L
.24955 .02811 L
.25019 .02575 L
.25079 .02312 L
.25143 .01991 L
.25177 .01809 L
.25196 .01707 L
.25213 .0161 L
.25229 .01525 L
.25237 .01476 L
.25245 .01512 L
.25274 .01674 L
.25332 .01987 L
.25457 .02601 L
.25513 .02822 L
.25542 .0292 L
.25573 .0301 L
.256 .03075 L
.2563 .03132 L
.25643 .03153 L
.25657 .03171 L
.25669 .03184 L
.25682 .03194 L
.2569 .03199 L
.25699 .03204 L
.25714 .03207 L
.25723 .03208 L
.25732 .03206 L
.25741 .03203 L
.25749 .03199 L
.25764 .03189 L
.25773 .0318 L
.25781 .03172 L
Mistroke
.25812 .03127 L
.25842 .03067 L
.25869 .02998 L
.2593 .02801 L
.26052 .02253 L
.26109 .0194 L
.26163 .01632 L
.26178 .01547 L
.26191 .01477 L
.26207 .0157 L
.26222 .01654 L
.26286 .02025 L
.26415 .02689 L
.26475 .02934 L
.26531 .03113 L
.2656 .03182 L
.2659 .0324 L
.26608 .03265 L
.26624 .03284 L
.26639 .03295 L
.26648 .033 L
.26655 .03304 L
.26669 .03306 L
.26684 .03305 L
.26699 .03299 L
.26712 .03291 L
.26724 .0328 L
.26737 .03265 L
.26763 .03224 L
.26792 .03165 L
.26822 .03085 L
.26878 .02897 L
.27 .0232 L
.27065 .01949 L
.271 .01734 L
.27118 .01627 L
.27134 .01528 L
.27148 .01502 L
.27163 .01594 L
.27194 .01788 L
.2726 .02187 L
.27321 .0253 L
.27376 .02806 L
.27432 .03039 L
.27491 .03234 L
.27524 .03313 L
.27539 .0334 L
.27555 .03366 L
.27569 .03385 L
.27584 .034 L
Mistroke
.276 .03411 L
.27614 .03417 L
.27629 .03418 L
.27643 .03415 L
.27658 .03407 L
.27666 .034 L
.27674 .03393 L
.27688 .03377 L
.27703 .03354 L
.2773 .03302 L
.27757 .03236 L
.27785 .03151 L
.27836 .02962 L
.2795 .02386 L
.28013 .02004 L
.28044 .01805 L
.28058 .01716 L
.28073 .01618 L
.28087 .01526 L
.281 .01503 L
.28114 .01595 L
.28129 .01693 L
.28189 .02086 L
.28294 .02714 L
.2835 .02995 L
.2841 .03239 L
.28444 .0335 L
.28476 .0343 L
.28491 .03462 L
.28507 .0349 L
.28521 .03511 L
.28536 .03527 L
.28552 .03539 L
.28567 .03545 L
.28576 .03547 L
.28585 .03546 L
.28592 .03544 L
.28601 .03541 L
.28609 .03536 L
.28618 .03528 L
.28636 .03508 L
.28653 .03483 L
.28669 .03453 L
.287 .03381 L
.28728 .03296 L
.28791 .03049 L
.28909 .02409 L
.28966 .02042 L
.29019 .01674 L
.29034 .01571 L
Mistroke
.29049 .01483 L
.29057 .0154 L
.29066 .01604 L
.29082 .01715 L
.29139 .02116 L
.29268 .02923 L
.29331 .03235 L
.29362 .03362 L
.29391 .03464 L
.29419 .03546 L
.29444 .03606 L
.29458 .03631 L
.29472 .03654 L
.29488 .03673 L
.29503 .03686 L
.29518 .03693 L
.29533 .03695 L
.29541 .03694 L
.29549 .03691 L
.29558 .03686 L
.29566 .0368 L
.29583 .03662 L
.29599 .0364 L
.29634 .03568 L
.29662 .0349 L
.29692 .03385 L
.29754 .03111 L
.29876 .02379 L
.29934 .01967 L
.29962 .01757 L
.29975 .01665 L
.29988 .01564 L
.30002 .0149 L
.30016 .01595 L
.30046 .01824 L
.3011 .023 L
.30177 .02762 L
.30239 .03142 L
.30299 .03443 L
.30354 .03654 L
.30385 .03744 L
.30414 .03807 L
.3043 .03833 L
.30445 .03851 L
.30454 .03858 L
.30462 .03864 L
.30471 .03868 L
.30479 .0387 L
.30494 .03869 L
.30502 .03866 L
Mistroke
.3051 .03861 L
.30526 .03847 L
.30535 .03836 L
.30543 .03825 L
.30573 .03767 L
.30601 .03691 L
.30664 .03453 L
.30733 .03094 L
.30856 .02242 L
.30887 .02 L
.30917 .01763 L
.3093 .01659 L
.30943 .01547 L
.30958 .01519 L
.30972 .01634 L
.3103 .0211 L
.31093 .026 L
.31162 .03093 L
.31226 .03478 L
.31286 .03764 L
.31316 .03876 L
.3135 .03972 L
.31367 .0401 L
.31383 .04038 L
.31392 .0405 L
.31401 .04061 L
.3141 .04069 L
.31419 .04074 L
.31434 .04079 L
.31442 .04079 L
.3145 .04076 L
.31459 .04072 L
.31466 .04067 L
.31475 .04059 L
.31484 .04048 L
.31499 .04025 L
.31513 .03998 L
.31544 .03918 L
.31573 .03821 L
.316 .03709 L
.31661 .03391 L
.31727 .02956 L
.31841 .02038 L
.31872 .01764 L
.31889 .0161 L
.31898 .01534 L
.31906 .0148 L
.31921 .01616 L
.31937 .01765 L
.31966 .02025 L
Mistroke
.32097 .03119 L
.32161 .03565 L
.3222 .03898 L
.32278 .0414 L
.32307 .04227 L
.32324 .04265 L
.32339 .04293 L
.32347 .04304 L
.32356 .04315 L
.32372 .04328 L
.32387 .04333 L
.32401 .04332 L
.32417 .04323 L
.32425 .04315 L
.32434 .04305 L
.3245 .04278 L
.32468 .0424 L
.32495 .04163 L
.32525 .04054 L
.32585 .03756 L
.32641 .03397 L
.32692 .03 L
.32753 .0247 L
.32786 .02171 L
.32819 .01843 L
.32834 .01702 L
.32849 .0155 L
.32858 .0148 L
.32866 .0156 L
.32882 .01718 L
.32939 .02285 L
.33048 .03282 L
.33108 .03748 L
.33164 .04112 L
.33194 .04273 L
.33226 .04416 L
.33256 .04518 L
.3327 .04557 L
.33283 .04587 L
.33296 .04612 L
.33309 .0463 L
.33322 .04643 L
.33337 .04651 L
.33351 .04651 L
.33366 .04644 L
.3338 .0463 L
.33393 .0461 L
.33408 .04582 L
.33423 .04544 L
.33451 .04454 L
Mistroke
.33484 .04314 L
.33515 .04155 L
.33581 .03714 L
.33644 .03189 L
.33703 .02615 L
.33759 .02025 L
.3379 .01686 L
.33799 .01592 L
.33808 .01492 L
.33815 .01536 L
.33824 .0163 L
.33882 .02281 L
.33996 .03466 L
.34104 .04363 L
.34163 .04715 L
.34196 .04863 L
.34212 .0492 L
.34227 .04965 L
.34241 .04998 L
.34253 .05023 L
.34267 .05043 L
.34282 .05057 L
.34295 .05063 L
.3431 .0506 L
.34325 .05049 L
.34339 .0503 L
.34355 .05 L
.34372 .04956 L
.34403 .04848 L
.34434 .04708 L
.34461 .04549 L
.34525 .04088 L
.34592 .03467 L
.34705 .02177 L
.34721 .01984 L
.34738 .01771 L
.34746 .01672 L
.34754 .01567 L
.34769 .01566 L
.34785 .01766 L
.348 .01955 L
.34828 .02307 L
.34933 .03581 L
.35049 .04727 L
.35078 .04956 L
.3511 .05167 L
.35137 .05319 L
.35167 .0545 L
.35184 .0551 L
.352 .05553 L
Mistroke
.35215 .05585 L
.35223 .05596 L
.35232 .05606 L
.35247 .05615 L
.35262 .05615 L
.35277 .05603 L
.35291 .05584 L
.35304 .05558 L
.35318 .05521 L
.35343 .05434 L
.35373 .05294 L
.354 .05134 L
.35459 .0468 L
.35514 .04132 L
.35632 .02664 L
.3566 .02261 L
.35691 .01817 L
.357 .01684 L
.35708 .01558 L
.35716 .01499 L
.35724 .01623 L
.35756 .02092 L
.35871 .03755 L
.35979 .05088 L
.36033 .05616 L
.36092 .06047 L
.36124 .06214 L
.36139 .06279 L
.36157 .06335 L
.36172 .0637 L
.3618 .06385 L
.36188 .06395 L
.36203 .06406 L
.36217 .06406 L
.36231 .06394 L
.3624 .06383 L
.36247 .06368 L
.36263 .06329 L
.3628 .06273 L
.3631 .06132 L
.36338 .0596 L
.36406 .05379 L
.3647 .04628 L
.36586 .02886 L
.36619 .02316 L
.36635 .0203 L
.3665 .01763 L
.36664 .01517 L
.36679 .01687 L
.36693 .01951 L
Mistroke
.36709 .02241 L
.36823 .04267 L
.36931 .05926 L
.3699 .06643 L
.37021 .06952 L
.37054 .07222 L
.37082 .07399 L
.37097 .07474 L
.37112 .07539 L
.37127 .07585 L
.3714 .07615 L
.37153 .07633 L
.37166 .0764 L
.37182 .07633 L
.37197 .07612 L
.37204 .07594 L
.37213 .0757 L
.37229 .07513 L
.37243 .07445 L
.37259 .07357 L
.37287 .07158 L
.3735 .06525 L
.37419 .05549 L
.37476 .04537 L
.37539 .03267 L
.37568 .0264 L
.37584 .02287 L
.37598 .01949 L
.37612 .0163 L
.37627 .01662 L
.37641 .01982 L
.37653 .02277 L
.37785 .0535 L
.37843 .0659 L
.37905 .07761 L
.37967 .08709 L
.38023 .09345 L
.3805 .09565 L
.38065 .09657 L
.3808 .09735 L
.38093 .09788 L
.38107 .09828 L
.38121 .09848 L
.38133 .09852 L
.38148 .09838 L
.38157 .09821 L
.38165 .09798 L
.3818 .09742 L
.38196 .09658 L
.38226 .09435 L
Mistroke
.38253 .09159 L
.38285 .08747 L
.3832 .08198 L
.38382 .06938 L
.38442 .05442 L
.38507 .0357 L
.38538 .02582 L
.38553 .02079 L
.38567 .01607 L
.3858 .01771 L
.38594 .02237 L
.38623 .03238 L
.38744 .07479 L
.38813 .09763 L
.38877 .1163 L
.38931 .12968 L
.3899 .14106 L
.3902 .14542 L
.39049 .14841 L
.39065 .1496 L
.39079 .15038 L
.39087 .15069 L
.39096 .15093 L
.39111 .15108 L
.39125 .15091 L
.39138 .15049 L
.39152 .14975 L
.39167 .14861 L
.39183 .14703 L
.39198 .14517 L
.39226 .14068 L
.39277 .12935 L
.39332 .11216 L
.39391 .08833 L
.39454 .05641 L
.39483 .03972 L
.39499 .03009 L
.39514 .0208 L
.39527 .01681 L
.39541 .02579 L
.39569 .04559 L
.39702 .14769 L
.39823 .24972 L
.40062 .44523 L
.40127 .49 L
.40197 .53071 L
.40257 .55932 L
.40289 .57166 L
.40322 .58254 L
.40351 .59033 L
Mistroke
.40367 .59372 L
.40383 .59678 L
.40399 .59909 L
.40413 .60076 L
.40427 .60202 L
.4044 .60282 L
.40453 .60326 L
.40468 .6033 L
.4048 .60299 L
.40493 .60229 L
.40507 .60111 L
.40523 .59936 L
.40551 .59494 L
.40583 .58777 L
.40618 .57754 L
.40682 .55279 L
.40803 .48729 L
.41041 .30796 L
.41163 .20702 L
.41294 .10409 L
.41354 .06206 L
.41386 .04072 L
.41402 .03076 L
.41416 .02197 L
.4143 .01534 L
.41442 .02258 L
.4147 .03776 L
.41529 .06639 L
.4158 .08729 L
.41634 .10511 L
.41663 .11261 L
.41694 .11947 L
.41722 .12445 L
.41749 .128 L
.41763 .12952 L
.41779 .1308 L
.41788 .13139 L
.41796 .13184 L
.41812 .13243 L
.41826 .13269 L
.4184 .13267 L
.41855 .13238 L
.41871 .13176 L
.41884 .131 L
.41899 .12996 L
.41924 .12751 L
.41955 .12366 L
.41983 .11934 L
.42112 .09123 L
.42235 .05696 L
Mistroke
.42295 .03929 L
.42351 .023 L
.42365 .01912 L
.4238 .0151 L
.42395 .01867 L
.4241 .02256 L
.42475 .03876 L
.42581 .06023 L
.42641 .06908 L
.42668 .07222 L
.42697 .07494 L
.42712 .07612 L
.42729 .07723 L
.42744 .07806 L
.42758 .07867 L
.42775 .0792 L
.42784 .07941 L
.42792 .07955 L
.42807 .07968 L
.42816 .07967 L
.42824 .07962 L
.4284 .07938 L
.42855 .07901 L
.42868 .07855 L
.42882 .07792 L
.42914 .07603 L
.42944 .07374 L
.42996 .06853 L
.43053 .06134 L
.43168 .04341 L
.43232 .03244 L
.43263 .02696 L
.43292 .02191 L
.43318 .01739 L
.43331 .01513 L
.43345 .01675 L
.4336 .01917 L
.43376 .02173 L
.43404 .02622 L
.43468 .03558 L
.43536 .0439 L
.43593 .04953 L
.43626 .05206 L
.43656 .05396 L
.43687 .05544 L
.43703 .05604 L
.4372 .05653 L
.43735 .05685 L
.43749 .05705 L
.43764 .05717 L
Mistroke
.43773 .05719 L
.43781 .05717 L
.43795 .05707 L
.43808 .0569 L
.43823 .05661 L
.43838 .0562 L
.43865 .05529 L
.43893 .05395 L
.43956 .04995 L
.44024 .0442 L
.44146 .03115 L
.44202 .0246 L
.44233 .02096 L
.44261 .01754 L
.44269 .01661 L
.44278 .01562 L
.44287 .01488 L
.44296 .01587 L
.44327 .01939 L
.44388 .02588 L
.44446 .03142 L
.44509 .03643 L
.44545 .0388 L
.44578 .04062 L
.44611 .04213 L
.44642 .04317 L
.44656 .04355 L
.44672 .04388 L
.44686 .04412 L
.447 .04428 L
.44714 .04439 L
.44729 .04443 L
.44737 .04441 L
.44746 .04438 L
.44761 .04426 L
.44775 .04409 L
.44791 .04382 L
.44819 .04316 L
.44846 .04229 L
.44871 .0413 L
.44929 .03843 L
.44993 .03443 L
.45121 .0245 L
.45181 .01951 L
.45196 .0182 L
.45213 .0168 L
.45229 .01548 L
.45243 .01513 L
.45256 .01621 L
.45271 .01736 L
Mistroke
.45296 .0194 L
.45355 .02372 L
.45418 .02786 L
.45486 .03141 L
.45543 .03368 L
.45576 .03463 L
.45606 .03529 L
.45622 .03554 L
.4563 .03565 L
.45638 .03574 L
.45653 .03587 L
.45667 .03594 L
.45675 .03597 L
.45683 .03597 L
.45698 .03594 L
.45706 .0359 L
.45714 .03585 L
.45723 .03578 L
.45732 .03568 L
.45747 .03548 L
.45764 .0352 L
.45795 .03455 L
.45851 .03283 L
.45908 .03057 L
.45968 .02768 L
.46075 .02163 L
.46133 .01814 L
.46162 .01642 L
.46176 .01558 L
.46188 .01484 L
.46203 .01546 L
.46219 .01637 L
.46252 .01824 L
.46311 .0213 L
.46365 .02383 L
.46424 .02612 L
.4648 .0278 L
.46506 .02842 L
.46531 .0289 L
.46545 .02913 L
.46561 .02933 L
.46574 .02947 L
.46588 .02959 L
.46603 .02969 L
.46612 .02972 L
.46619 .02974 L
.46633 .02976 L
.46649 .02973 L
.46662 .02968 L
.46676 .02959 L
Mistroke
.46692 .02946 L
.46706 .02931 L
.46731 .02896 L
.46758 .02848 L
.46825 .02688 L
.46889 .0249 L
.47007 .02036 L
.47068 .01783 L
.47097 .01659 L
.47125 .01547 L
.47139 .01487 L
.47153 .01513 L
.47168 .01571 L
.47184 .01634 L
.47249 .01875 L
.47305 .02058 L
.47364 .0222 L
.4742 .02339 L
.47447 .02383 L
.47471 .02417 L
.47499 .02447 L
.47514 .02459 L
.4753 .02469 L
.47538 .02472 L
.47547 .02476 L
.47563 .0248 L
.47578 .02481 L
.47592 .02479 L
.47606 .02476 L
.47618 .02471 L
.47632 .02464 L
.47646 .02453 L
.47676 .02426 L
.47704 .02393 L
.47762 .02301 L
.47826 .02171 L
.47955 .01848 L
.48019 .01675 L
.4805 .0159 L
.48064 .01553 L
.48079 .01513 L
.48093 .01478 L
.48105 .01498 L
.48119 .01531 L
.48133 .01567 L
.48192 .01703 L
.4826 .01837 L
.48324 .01938 L
.48382 .02003 L
.48414 .02029 L
Mistroke
.48429 .02038 L
.48445 .02046 L
.48459 .02051 L
.48474 .02056 L
.48488 .02059 L
.485 .0206 L
.48516 .0206 L
.48529 .02058 L
.48537 .02057 L
.48545 .02055 L
.48561 .02051 L
.48574 .02045 L
.48588 .02038 L
.48617 .02021 L
.48669 .01978 L
.48731 .01911 L
.48798 .01824 L
.48918 .01651 L
.48977 .01566 L
.49009 .01521 L
.49025 .015 L
.4904 .01481 L
.49048 .01472 L
.49057 .01483 L
.49076 .01506 L
.49109 .01542 L
.49173 .01603 L
.49202 .01625 L
.49233 .01646 L
.49259 .0166 L
.49288 .01672 L
.49306 .01678 L
.49322 .01682 L
.49338 .01686 L
.49346 .01687 L
.49355 .01688 L
.4937 .01689 L
.49378 .01689 L
.49386 .01689 L
.494 .01689 L
.49415 .01688 L
.4943 .01686 L
.49446 .01683 L
.49475 .01676 L
.49504 .01667 L
.4953 .01657 L
.49653 .01596 L
.4976 .01539 L
.49819 .01512 L
.49875 .01491 L
Mistroke
.49904 .01483 L
.4992 .0148 L
.49936 .01477 L
.49951 .01475 L
.49965 .01473 L
.49979 .01472 L
.49992 .01472 L
.50005 .01472 L
.50019 .01472 L
.50031 .01473 L
.50044 .01474 L
.50059 .01476 L
.50074 .01479 L
.50101 .01485 L
.50133 .01494 L
.50168 .01506 L
.50232 .01535 L
.5035 .01598 L
.5041 .01629 L
.50474 .01658 L
.50505 .0167 L
.50534 .01678 L
.5056 .01684 L
.50575 .01687 L
.50589 .01688 L
.50605 .01689 L
.5062 .01689 L
.50633 .01689 L
.50648 .01688 L
.50663 .01685 L
.50671 .01684 L
.5068 .01682 L
.5071 .01673 L
.50727 .01666 L
.50743 .01659 L
.50779 .01639 L
.50843 .0159 L
.50901 .01532 L
.50916 .01515 L
.50933 .01496 L
.50948 .01477 L
.50962 .01484 L
.50975 .015 L
.50988 .01517 L
.51015 .01554 L
.51073 .01637 L
.51204 .01827 L
.51266 .01907 L
.51323 .0197 L
.51382 .0202 L
Mistroke
.51412 .02039 L
.51428 .02046 L
.51445 .02052 L
.5146 .02056 L
.51473 .02059 L
.51489 .0206 L
.51504 .02059 L
.51518 .02058 L
.51531 .02055 L
.51545 .0205 L
.5156 .02044 L
.51592 .02024 L
.51628 .01994 L
.51661 .01956 L
.51692 .01915 L
.51812 .01694 L
.51869 .01562 L
.51885 .01521 L
.51901 .01482 L
.51915 .01497 L
.5193 .01537 L
.52039 .01833 L
.52158 .02135 L
.52221 .0227 L
.52254 .0233 L
.52289 .02383 L
.5232 .02421 L
.52336 .02438 L
.52353 .02453 L
.52369 .02464 L
.52384 .02472 L
.52398 .02477 L
.52412 .0248 L
.52426 .02481 L
.52441 .02479 L
.52454 .02476 L
.52467 .0247 L
.52482 .02461 L
.52499 .02448 L
.52528 .02418 L
.5256 .02373 L
.52596 .02309 L
.5266 .02158 L
.52722 .01973 L
.52781 .01769 L
.52808 .01669 L
.52835 .01559 L
.5285 .015 L
.52858 .01476 L
.52866 .01508 L
Mistroke
.52894 .01624 L
.53019 .02144 L
.53081 .02384 L
.53149 .02614 L
.53213 .02787 L
.53244 .02852 L
.53272 .02901 L
.533 .02937 L
.53315 .02952 L
.53329 .02963 L
.53345 .02971 L
.53353 .02974 L
.53361 .02975 L
.53376 .02975 L
.53392 .02971 L
.534 .02967 L
.53408 .02962 L
.53426 .02948 L
.53442 .0293 L
.53458 .02907 L
.53487 .02856 L
.53519 .02784 L
.53574 .02617 L
.53634 .02385 L
.53743 .01853 L
.53773 .01681 L
.5379 .01583 L
.53806 .01491 L
.5382 .01532 L
.53834 .01618 L
.53865 .01804 L
.53999 .02587 L
.5406 .02909 L
.54125 .03196 L
.54181 .03387 L
.54212 .03471 L
.54241 .0353 L
.54257 .03554 L
.54273 .03574 L
.54287 .03586 L
.54302 .03594 L
.54311 .03597 L
.54319 .03597 L
.54328 .03596 L
.54336 .03593 L
.54352 .03584 L
.5436 .03576 L
.54368 .03567 L
.54384 .03545 L
.54399 .0352 L
Mistroke
.54426 .03457 L
.54456 .0337 L
.54488 .03253 L
.54545 .0299 L
.54605 .02641 L
.54712 .01871 L
.54727 .01754 L
.54743 .01625 L
.54758 .01501 L
.54772 .01557 L
.54785 .01662 L
.54799 .01779 L
.54827 .02015 L
.5495 .0302 L
.55005 .03423 L
.55064 .03802 L
.55116 .04072 L
.55144 .04192 L
.55171 .04285 L
.55186 .04328 L
.55202 .04368 L
.55216 .04394 L
.55231 .04417 L
.55245 .04432 L
.5526 .04441 L
.55274 .04442 L
.55287 .04438 L
.55294 .04433 L
.55303 .04425 L
.55319 .04405 L
.55334 .04377 L
.55348 .04345 L
.55379 .04247 L
.55413 .04107 L
.55475 .03752 L
.55534 .03312 L
.55598 .02732 L
.55632 .02389 L
.55668 .02 L
.55684 .01816 L
.557 .01638 L
.55714 .01477 L
.55729 .01643 L
.55786 .02318 L
.55911 .03755 L
.55967 .04333 L
.56027 .04863 L
.56078 .05229 L
.56107 .05397 L
.56134 .05523 L
Mistroke
.56164 .05627 L
.5618 .05667 L
.56188 .05683 L
.56197 .05697 L
.56205 .05707 L
.56213 .05714 L
.56228 .05718 L
.56242 .05714 L
.56256 .05699 L
.5627 .05676 L
.56284 .05642 L
.5631 .05557 L
.5634 .05414 L
.56368 .05245 L
.5643 .04741 L
.56498 .04002 L
.56561 .03153 L
.5662 .02243 L
.56647 .01808 L
.5666 .01584 L
.56675 .01608 L
.56691 .01881 L
.56705 .02137 L
.56734 .0263 L
.56859 .04789 L
.56981 .06583 L
.57017 .06991 L
.5705 .07319 L
.57082 .07577 L
.57112 .07763 L
.57126 .07829 L
.57139 .0788 L
.57154 .07925 L
.57168 .07952 L
.57183 .07967 L
.57197 .07966 L
.57213 .07948 L
.57222 .0793 L
.5723 .07909 L
.57246 .07853 L
.5726 .07784 L
.57294 .07569 L
.57323 .07312 L
.57354 .06971 L
.57409 .06191 L
.5746 .05276 L
.5752 .03983 L
.57576 .02612 L
.57606 .01834 L
.57621 .01514 L
Mistroke
.57629 .01747 L
.57637 .01968 L
.57703 .03861 L
.57822 .0735 L
.5793 .10156 L
.57986 .11374 L
.58046 .12387 L
.5808 .12803 L
.58097 .12956 L
.58111 .13072 L
.58126 .13162 L
.58134 .13199 L
.58142 .1323 L
.58156 .13263 L
.58172 .1327 L
.58187 .13247 L
.58201 .13197 L
.58209 .13158 L
.58218 .13105 L
.58233 .12985 L
.58263 .12656 L
.58291 .12236 L
.58342 .11149 L
.58399 .09483 L
.58458 .07219 L
.58514 .04617 L
.58541 .03177 L
.58556 .02343 L
.5857 .01527 L
.58579 .01891 L
.58587 .02416 L
.58603 .03355 L
.58632 .05273 L
.58757 .14293 L
.5898 .32548 L
.59104 .42296 L
.5922 .5014 L
.59283 .53643 L
.59341 .56264 L
.59405 .58452 L
.5944 .59311 L
.59456 .59618 L
.59474 .59889 L
.5949 .60085 L
.59505 .60215 L
.59519 .60295 L
.59534 .60332 L
.59548 .60323 L
.59561 .60279 L
.59575 .60191 L
Mistroke
.5959 .60052 L
.59605 .5985 L
.59623 .59571 L
.59654 .58903 L
.59685 .58058 L
.59713 .57109 L
.59821 .52119 L
.59935 .44767 L
.60173 .25382 L
.60277 .16502 L
.60391 .07455 L
.60419 .05365 L
.6045 .03236 L
.60464 .02242 L
.60478 .01613 L
.60491 .02411 L
.60504 .0325 L
.60624 .09494 L
.60688 .11893 L
.60723 .12921 L
.60755 .13701 L
.60783 .14228 L
.60813 .14654 L
.6083 .14833 L
.60838 .14905 L
.60846 .14961 L
.6086 .15042 L
.60876 .15093 L
.6089 .15108 L
.60905 .15091 L
.60918 .15051 L
.60932 .14982 L
.60947 .14876 L
.60963 .1473 L
.60992 .14382 L
.61021 .13926 L
.61049 .13405 L
.61101 .1222 L
.61221 .08655 L
.61287 .06405 L
.61349 .04229 L
.61377 .03234 L
.61404 .023 L
.61419 .01793 L
.61427 .01508 L
.61435 .01697 L
.61464 .02632 L
.6159 .06282 L
.61645 .07538 L
.61698 .08487 L
Mistroke
.61727 .08908 L
.61758 .09278 L
.61786 .09535 L
.61799 .09624 L
.61812 .09704 L
.61828 .09773 L
.61842 .09819 L
.61856 .09845 L
.61869 .09853 L
.61883 .09844 L
.61899 .09814 L
.61906 .09791 L
.61915 .0976 L
.6193 .09688 L
.61958 .09506 L
.61987 .09247 L
.62039 .0862 L
.62101 .07648 L
.62159 .06556 L
.62221 .05214 L
.62289 .03649 L
.62321 .02889 L
.62355 .02085 L
.62369 .01756 L
.62384 .01537 L
.62392 .01737 L
.624 .01918 L
.62416 .02269 L
.62536 .04757 L
.62591 .05694 L
.62651 .06527 L
.62678 .06835 L
.62707 .07109 L
.62732 .073 L
.6276 .07461 L
.62776 .07533 L
.62791 .07583 L
.628 .07604 L
.62807 .07619 L
.62816 .07631 L
.62825 .07638 L
.62839 .07638 L
.62853 .07626 L
.62868 .07598 L
.62876 .07578 L
.62884 .07552 L
.62902 .07483 L
.62918 .07403 L
.62953 .07166 L
.62987 .06879 L
Mistroke
.63019 .06551 L
.63135 .04959 L
.632 .03867 L
.63262 .02767 L
.63291 .0224 L
.63307 .01952 L
.63322 .01683 L
.63329 .01543 L
.63338 .01549 L
.63347 .01715 L
.63355 .01864 L
.63386 .02409 L
.63499 .04206 L
.63561 .05015 L
.63594 .05376 L
.63629 .05705 L
.63659 .05942 L
.63693 .06148 L
.63707 .0622 L
.63723 .06284 L
.63738 .06332 L
.63752 .06367 L
.63767 .06392 L
.63781 .06405 L
.63796 .06407 L
.63804 .06403 L
.63812 .06396 L
.63824 .06377 L
.63839 .06347 L
.63853 .06304 L
.63867 .06253 L
.63899 .06101 L
.63928 .0592 L
.63993 .05374 L
.64124 .03829 L
.64189 .02909 L
.64248 .02037 L
.64262 .01829 L
.64276 .0161 L
.64284 .01496 L
.64293 .01572 L
.64307 .01791 L
.64364 .02597 L
.64423 .03391 L
.64487 .04143 L
.64547 .04729 L
.64602 .05143 L
.64628 .05298 L
.64657 .05433 L
.6467 .05482 L
Mistroke
.64684 .05526 L
.64697 .0556 L
.64709 .05584 L
.64722 .05603 L
.64737 .05615 L
.64752 .05616 L
.64768 .05607 L
.64782 .05588 L
.64796 .05562 L
.64808 .05531 L
.64822 .05491 L
.64853 .05369 L
.64885 .05198 L
.64944 .04789 L
.65049 .03783 L
.65164 .02408 L
.65194 .02026 L
.6521 .01824 L
.65219 .01713 L
.65227 .01608 L
.65235 .01509 L
.65244 .01541 L
.65258 .01727 L
.65287 .02085 L
.65399 .03372 L
.65463 .03984 L
.65531 .04497 L
.65558 .04664 L
.65588 .04811 L
.65605 .04881 L
.65621 .04935 L
.65636 .0498 L
.65651 .05013 L
.65665 .05036 L
.65679 .05053 L
.65695 .05062 L
.65709 .05062 L
.65725 .05053 L
.65733 .05043 L
.65741 .05033 L
.65756 .05006 L
.65771 .04969 L
.65801 .04873 L
.65829 .04752 L
.65882 .04455 L
.65945 .03992 L
.66002 .03478 L
.66065 .02845 L
.66133 .02114 L
.66164 .01764 L
Mistroke
.6618 .01591 L
.66194 .01512 L
.66207 .01656 L
.66221 .01808 L
.6625 .02125 L
.6636 .03219 L
.66417 .03695 L
.66478 .04114 L
.66513 .04303 L
.66546 .04442 L
.66576 .04543 L
.66592 .04581 L
.666 .04598 L
.66609 .04614 L
.66625 .04635 L
.66639 .04647 L
.66655 .04652 L
.66664 .04651 L
.66673 .04647 L
.66688 .04634 L
.66702 .04616 L
.66718 .04586 L
.66733 .0455 L
.66761 .04465 L
.66787 .04363 L
.66845 .04059 L
.6691 .03621 L
.66968 .03148 L
.67031 .02569 L
.67066 .02235 L
.67098 .01917 L
.67126 .0164 L
.67142 .01484 L
.67156 .016 L
.67219 .02215 L
.67331 .03183 L
.67392 .0362 L
.67425 .03813 L
.6746 .03987 L
.6749 .04112 L
.67506 .04167 L
.67523 .04218 L
.67539 .04256 L
.67553 .04285 L
.67567 .04306 L
.67582 .04322 L
.67597 .04331 L
.67605 .04333 L
.67613 .04333 L
.67627 .04329 L
Mistroke
.67642 .04317 L
.67656 .043 L
.67668 .0428 L
.67697 .04215 L
.67728 .04118 L
.67757 .04006 L
.6782 .03678 L
.67934 .02876 L
.68042 .0195 L
.68069 .01712 L
.68083 .01586 L
.68097 .01489 L
.68105 .0156 L
.68114 .01636 L
.68129 .01771 L
.68158 .02031 L
.68282 .03018 L
.68337 .0338 L
.68397 .03693 L
.68426 .03814 L
.68453 .03908 L
.68477 .03975 L
.68504 .04029 L
.68519 .04051 L
.68532 .04065 L
.68548 .04076 L
.68563 .04079 L
.68576 .04076 L
.68589 .04069 L
.68603 .04056 L
.68618 .04037 L
.68634 .04008 L
.68652 .03969 L
.68684 .03877 L
.68743 .03636 L
.68808 .03287 L
.68875 .02836 L
.68939 .02356 L
.68997 .01889 L
.69025 .01658 L
.69041 .01526 L
.69056 .01538 L
.69068 .01643 L
.69083 .01759 L
.69111 .01989 L
.69234 .02888 L
.69289 .03218 L
.69348 .03507 L
.69375 .03613 L
.69404 .03706 L
Mistroke
.69428 .0377 L
.69455 .03821 L
.69471 .03843 L
.69486 .03858 L
.69493 .03863 L
.69502 .03867 L
.69511 .0387 L
.69519 .0387 L
.69534 .03866 L
.69548 .03857 L
.69556 .0385 L
.69564 .0384 L
.69579 .03819 L
.69607 .03763 L
.69638 .03682 L
.69692 .03483 L
.6976 .03144 L
.69824 .02752 L
.69882 .02358 L
.69944 .01894 L
.69974 .0167 L
.69982 .01605 L
.69991 .01544 L
.70006 .01514 L
.7002 .01622 L
.70033 .01721 L
.70063 .01942 L
.70187 .02788 L
.70243 .03098 L
.70295 .03337 L
.7035 .03525 L
.70379 .03597 L
.70395 .03629 L
.7041 .03653 L
.70426 .03673 L
.70441 .03685 L
.70456 .03693 L
.70465 .03695 L
.70473 .03695 L
.70487 .03692 L
.70502 .03682 L
.70517 .03667 L
.70532 .03648 L
.70549 .03619 L
.70566 .03585 L
.70596 .03505 L
.70665 .03252 L
.70725 .02958 L
.70781 .02636 L
.70842 .02244 L
Mistroke
.70874 .02026 L
.70907 .01791 L
.70936 .01587 L
.70944 .01531 L
.70952 .01472 L
.70968 .0158 L
.71023 .01966 L
.71132 .02655 L
.71199 .03004 L
.71262 .03262 L
.7129 .03351 L
.71319 .03427 L
.71334 .0346 L
.71351 .0349 L
.71365 .0351 L
.71381 .03527 L
.71396 .03539 L
.71411 .03545 L
.71419 .03547 L
.71428 .03546 L
.71443 .03542 L
.71458 .03532 L
.71472 .03519 L
.71487 .03499 L
.71503 .03474 L
.71531 .03416 L
.71556 .03348 L
.71615 .03145 L
.71679 .02856 L
.71737 .02541 L
.718 .02158 L
.71834 .01936 L
.71867 .01723 L
.7188 .01634 L
.71894 .01541 L
.7191 .01504 L
.71924 .01598 L
.71987 .02004 L
.72097 .02648 L
.72155 .02924 L
.72217 .03158 L
.72253 .03261 L
.72285 .03332 L
.723 .03359 L
.72317 .03383 L
.72333 .034 L
.72348 .0341 L
.72363 .03417 L
.72377 .03418 L
.7239 .03416 L
Mistroke
.72404 .03409 L
.7242 .03397 L
.72427 .0339 L
.72436 .03379 L
.72465 .03334 L
.72492 .03276 L
.72521 .03197 L
.72574 .03015 L
.72704 .02393 L
.72762 .02059 L
.72823 .01681 L
.72839 .01586 L
.72847 .01536 L
.72855 .01483 L
.72871 .01557 L
.72885 .01646 L
.72941 .01987 L
.73051 .02587 L
.73109 .02843 L
.7317 .03062 L
.73205 .03158 L
.73238 .03225 L
.73253 .03251 L
.7327 .03273 L
.73278 .03281 L
.73286 .03289 L
.73301 .03299 L
.73316 .03305 L
.73324 .03306 L
.73332 .03306 L
.73341 .03305 L
.73348 .03302 L
.73357 .03298 L
.73365 .03292 L
.7338 .03279 L
.73394 .03263 L
.73425 .03214 L
.73456 .03146 L
.7349 .03052 L
.73559 .02803 L
.73685 .02191 L
.73746 .01846 L
.73773 .01686 L
.73787 .01604 L
.73802 .01514 L
.73818 .01519 L
.73832 .01604 L
.73859 .0176 L
.73921 .02108 L
.73982 .02421 L
Mistroke
.74046 .02708 L
.74101 .0291 L
.7413 .02998 L
.74162 .03076 L
.74191 .03132 L
.74217 .0317 L
.7423 .03183 L
.74244 .03195 L
.74257 .03202 L
.74269 .03206 L
.74285 .03208 L
.74292 .03206 L
.74301 .03204 L
.74316 .03196 L
.7433 .03184 L
.74347 .03166 L
.74362 .03145 L
.74397 .03082 L
.74426 .03012 L
.74459 .02919 L
.74517 .0271 L
.74633 .02174 L
.7469 .01872 L
.74714 .01736 L
.74729 .01658 L
.74742 .01585 L
.74754 .01513 L
.74768 .01507 L
.74783 .01589 L
.74796 .01663 L
.74855 .01981 L
.74981 .02575 L
.75043 .02804 L
.75076 .02902 L
.75111 .02987 L
.75142 .03045 L
.75158 .03069 L
.75175 .0309 L
.75191 .03104 L
.75206 .03113 L
.7522 .03118 L
.75234 .0312 L
.75248 .03118 L
.75263 .03112 L
.75277 .03103 L
.75289 .03092 L
.75319 .03055 L
.7535 .02999 L
.75409 .02851 L
.75474 .02631 L
Mistroke
.75588 .02126 L
.75644 .01841 L
.75669 .01712 L
.75696 .01568 L
.75711 .01489 L
.75725 .01527 L
.7574 .01605 L
.75755 .01688 L
.7582 .02017 L
.75932 .02519 L
.76 .02753 L
.76033 .02846 L
.76064 .02916 L
.76092 .02967 L
.76122 .03006 L
.7613 .03015 L
.76139 .03023 L
.76147 .03028 L
.76155 .03033 L
.76171 .03039 L
.76185 .03041 L
.762 .0304 L
.76208 .03037 L
.76216 .03034 L
.7623 .03025 L
.76245 .03012 L
.76271 .02981 L
.76299 .02933 L
.7633 .02869 L
.76363 .02784 L
.76422 .02593 L
.76537 .02114 L
.76592 .01845 L
.76617 .01724 L
.76643 .01591 L
.76658 .01515 L
.76672 .01498 L
.76685 .01564 L
.76699 .01634 L
.76759 .01928 L
.76824 .02226 L
.76885 .02472 L
.76948 .02683 L
.77006 .0283 L
.77039 .02891 L
.77071 .02933 L
.77088 .02949 L
.77104 .02961 L
.77113 .02965 L
.77121 .02968 L
Mistroke
.77131 .0297 L
.7714 .02971 L
.77154 .02969 L
.77169 .02963 L
.77183 .02954 L
.77196 .02944 L
.77211 .02928 L
.77228 .02906 L
.77258 .02857 L
.77323 .02704 L
.77382 .02515 L
.7749 .02081 L
.77549 .01808 L
.77578 .01668 L
.77605 .01538 L
.77619 .01474 L
.77634 .01546 L
.77666 .01698 L
.77722 .01957 L
.77831 .02406 L
.77898 .02624 L
.77931 .0271 L
.77962 .02777 L
.77989 .02825 L
.78018 .02865 L
.78034 .02881 L
.78048 .02892 L
.78064 .029 L
.78072 .02903 L
.7808 .02905 L
.78094 .02906 L
.78107 .02904 L
.78122 .02899 L
.78138 .02889 L
.78153 .02876 L
.7817 .02858 L
.78199 .02816 L
.78252 .02709 L
.7831 .02551 L
.7844 .02067 L
.78502 .01789 L
.7853 .01663 L
.78546 .01591 L
.7856 .01523 L
.78575 .01486 L
.7859 .01557 L
.78621 .01701 L
.78687 .01992 L
.78749 .02241 L
.78807 .02446 L
Mistroke
.78863 .02609 L
.78893 .0268 L
.78924 .02742 L
.78953 .02787 L
.7898 .02817 L
.78992 .02828 L
.79006 .02837 L
.79019 .02843 L
.79031 .02847 L
.79046 .02848 L
.79061 .02845 L
.79074 .02841 L
.79088 .02833 L
.79103 .02821 L
.7912 .02805 L
.79149 .02766 L
.79176 .0272 L
.79201 .02667 L
.79259 .02518 L
.79379 .02097 L
.79446 .01817 L
.79478 .01674 L
.79492 .01611 L
.79508 .01542 L
.79523 .01476 L
.79537 .01529 L
.79564 .01649 L
.79624 .01906 L
.79684 .02146 L
.7975 .02378 L
.7981 .0255 L
.79843 .02627 L
.79874 .02687 L
.79891 .02714 L
.79909 .0274 L
.79924 .02757 L
.79941 .02772 L
.79957 .02783 L
.79966 .02787 L
.79974 .02791 L
.79989 .02794 L
.80005 .02794 L
.8002 .0279 L
.80033 .02784 L
.80049 .02774 L
.80064 .02761 L
.80091 .0273 L
.8012 .02686 L
.80185 .02546 L
.80246 .02373 L
Mistroke
.80309 .02155 L
.80377 .01889 L
.8041 .01753 L
.80441 .0162 L
.80455 .01562 L
.8047 .015 L
.80485 .01511 L
.805 .01574 L
.80617 .02048 L
.80726 .02415 L
.80789 .02571 L
.80824 .02638 L
.80857 .02686 L
.80884 .02716 L
.809 .02728 L
.80914 .02736 L
.8093 .02742 L
.80944 .02745 L
.80951 .02745 L
.8096 .02744 L
.80975 .0274 L
.8099 .02733 L
.81003 .02724 L
.81018 .02712 L
.81033 .02695 L
.8106 .02661 L
.81088 .02613 L
.81153 .02467 L
.81214 .02292 L
.81276 .02077 L
.81344 .01817 L
.81375 .01692 L
.81392 .01622 L
.81408 .01557 L
.81421 .01501 L
.81436 .01502 L
.81444 .01536 L
.81452 .01569 L
.81467 .01629 L
.81585 .02085 L
.81647 .02291 L
.81714 .02471 L
.81745 .02539 L
.81775 .02594 L
.81804 .02636 L
.81816 .02651 L
.8183 .02665 L
.81842 .02676 L
.81855 .02685 L
.81869 .02692 L
Mistroke
.81882 .02697 L
.81897 .02699 L
.81911 .02698 L
.81924 .02696 L
.81938 .0269 L
.81953 .02682 L
.81966 .02671 L
.81997 .02639 L
.82025 .02599 L
.82052 .02552 L
.82112 .02417 L
.82177 .02229 L
.82245 .01995 L
.8231 .01752 L
.82338 .01642 L
.82354 .01581 L
.82368 .01523 L
.82383 .01481 L
.82392 .01514 L
.82401 .01549 L
.82431 .01668 L
.82552 .02113 L
.82612 .02298 L
.82668 .02439 L
.82698 .02503 L
.82731 .02561 L
.82764 .02606 L
.82783 .02624 L
.828 .02638 L
.82815 .02647 L
.8283 .02653 L
.82843 .02656 L
.82858 .02657 L
.82874 .02654 L
.82882 .02652 L
.8289 .02648 L
.82906 .0264 L
.82921 .02628 L
.82949 .02599 L
.82976 .02562 L
.83038 .02446 L
.83097 .02296 L
.83162 .021 L
.83221 .01894 L
.83278 .01684 L
.83303 .0159 L
.83316 .01538 L
.83329 .01489 L
.83344 .01512 L
.83358 .01564 L
Mistroke
.83384 .01666 L
.83502 .02084 L
.83567 .02276 L
.83627 .02421 L
.83678 .02516 L
.83707 .02556 L
.83733 .02584 L
.83748 .02596 L
.83762 .02605 L
.83777 .02612 L
.83784 .02615 L
.83793 .02617 L
.83807 .02618 L
.83822 .02616 L
.83836 .02612 L
.8385 .02606 L
.83865 .02596 L
.8388 .02584 L
.83907 .02555 L
.83936 .02515 L
.83968 .02459 L
.84078 .0219 L
.84197 .01798 L
.8423 .01679 L
.84248 .01613 L
.84265 .0155 L
.8428 .01491 L
.84289 .01485 L
.84298 .01516 L
.84328 .01627 L
.84454 .02062 L
.84509 .02222 L
.84568 .02367 L
.84601 .02433 L
.84631 .02484 L
.8466 .02523 L
.84691 .02553 L
.84706 .02565 L
.84715 .0257 L
.84723 .02573 L
.84739 .02579 L
.84753 .02581 L
.84762 .02581 L
.8477 .0258 L
.84786 .02577 L
.84795 .02573 L
.84803 .02569 L
.84822 .02557 L
.84837 .02545 L
.84853 .02528 L
Mistroke
.84882 .02492 L
.84947 .02375 L
.85009 .02226 L
.85066 .02063 L
.85121 .01884 L
.85181 .01677 L
.85208 .01579 L
.85223 .01525 L
.85237 .01474 L
.85249 .01512 L
.85262 .01558 L
.85289 .01655 L
.85412 .02061 L
.85477 .02239 L
.85545 .02389 L
.85574 .02439 L
.85605 .02482 L
.85623 .02502 L
.85639 .02517 L
.85655 .02528 L
.85664 .02534 L
.85671 .02538 L
.85685 .02543 L
.857 .02546 L
.85714 .02547 L
.85727 .02545 L
.85742 .02541 L
.85756 .02535 L
.85772 .02526 L
.85788 .02513 L
.85819 .0248 L
.85848 .0244 L
.85902 .02342 L
.8596 .02206 L
.86024 .02027 L
.8608 .01852 L
.86139 .01652 L
.86167 .01552 L
.86182 .01503 L
.86194 .01486 L
.86206 .01527 L
.86219 .0157 L
.86245 .01661 L
.8636 .02029 L
.86423 .022 L
.86482 .02333 L
.86538 .02426 L
.86569 .02464 L
.86584 .02479 L
.86598 .0249 L
Mistroke
.86611 .02499 L
.86622 .02505 L
.86635 .0251 L
.86649 .02514 L
.86662 .02515 L
.86676 .02514 L
.8669 .02511 L
.86704 .02506 L
.86719 .02498 L
.86735 .02486 L
.86765 .02458 L
.86796 .02417 L
.86831 .02361 L
.86893 .02232 L
.86951 .02084 L
.87058 .01756 L
.87088 .01658 L
.87119 .01553 L
.87132 .01509 L
.87146 .01481 L
.87161 .01532 L
.87175 .0158 L
.87301 .01981 L
.87359 .0214 L
.8742 .02279 L
.87476 .02378 L
.87507 .0242 L
.87537 .0245 L
.87551 .02461 L
.87564 .0247 L
.87576 .02476 L
.87589 .02481 L
.87603 .02484 L
.87617 .02485 L
.8763 .02484 L
.87644 .02481 L
.87659 .02475 L
.87674 .02467 L
.8769 .02455 L
.87707 .0244 L
.87738 .02404 L
.87766 .02364 L
.87824 .02257 L
.87878 .02131 L
.88001 .01779 L
.88062 .0158 L
.88079 .01524 L
.88089 .01493 L
.88097 .01479 L
.88106 .01506 L
Mistroke
.88114 .01535 L
.8813 .01586 L
.88256 .01974 L
.88311 .02121 L
.88372 .02256 L
.88399 .02306 L
.88428 .02352 L
.88453 .02386 L
.8848 .02415 L
.88495 .02427 L
.8851 .02438 L
.88526 .02447 L
.8854 .02452 L
.88555 .02456 L
.88569 .02456 L
.88582 .02456 L
.88595 .02453 L
.8861 .02447 L
.88624 .0244 L
.88639 .0243 L
.88654 .02418 L
.88681 .0239 L
.88709 .02353 L
.88775 .02239 L
.88835 .02102 L
.88898 .01934 L
.88966 .01731 L
.88997 .01633 L
.89014 .01579 L
.8903 .01528 L
.89044 .01484 L
.89058 .01505 L
.89066 .01532 L
.89074 .01557 L
.89089 .01603 L
.89208 .01959 L
.89271 .02119 L
.89337 .02258 L
.89393 .02345 L
.89424 .02381 L
.89439 .02395 L
.89454 .02406 L
.89467 .02414 L
.89481 .02421 L
.89494 .02426 L
.89506 .02429 L
.8952 .0243 L
.89533 .02429 L
.89548 .02426 L
.89562 .02421 L
Mistroke
.89576 .02414 L
.89591 .02405 L
.89618 .02382 L
.8965 .02345 L
.89679 .02303 L
.89743 .02185 L
.89804 .02045 L
.8991 .0175 L
.89939 .01662 L
.8997 .01565 L
.89984 .01521 L
.89999 .01473 L
.90012 .0151 L
.90026 .01554 L
.90143 .01899 L
.90203 .02054 L
.90266 .02194 L
.90297 .02251 L
.90327 .02297 L
.90355 .02334 L
.90382 .02362 L
.90406 .02382 L
.90419 .02389 L
.90433 .02396 L
.90447 .02401 L
.90462 .02404 L
.90476 .02405 L
.90489 .02403 L
.90504 .024 L
.90519 .02394 L
.90532 .02387 L
.90546 .02378 L
.90578 .0235 L
.90608 .02315 L
.90661 .02232 L
.90718 .02119 L
.90839 .0181 L
.9087 .01718 L
.90905 .01615 L
.90921 .01567 L
.90938 .01516 L
.90952 .01472 L
.90968 .01519 L
.91092 .0188 L
.91205 .02149 L
.9126 .02247 L
.91289 .02289 L
.91319 .02325 L
.91346 .02349 L
.9136 .02359 L
Mistroke
.91375 .02368 L
.91389 .02374 L
.91402 .02378 L
.91414 .0238 L
.91426 .02381 L
.9144 .0238 L
.91455 .02376 L
.91469 .02371 L
.91482 .02365 L
.91497 .02356 L
.91514 .02343 L
.91544 .02313 L
.91575 .02273 L
.91608 .02222 L
.91668 .02107 L
.91784 .0182 L
.91835 .01676 L
.91864 .01592 L
.91878 .01551 L
.91891 .01513 L
.91904 .01473 L
.91917 .01509 L
.91946 .01592 L
.92004 .01758 L
.92125 .02065 L
.92176 .02168 L
.92231 .02255 L
.92259 .0229 L
.9229 .02321 L
.92304 .02331 L
.92319 .02341 L
.92333 .02348 L
.92346 .02353 L
.92361 .02357 L
.92376 .02358 L
.92389 .02358 L
.92403 .02355 L
.92419 .0235 L
.92426 .02347 L
.92435 .02343 L
.92464 .02323 L
.92492 .02297 L
.92521 .02262 L
.92575 .0218 L
.92705 .01894 L
.92762 .01743 L
.92794 .01652 L
.92825 .01566 L
.92838 .01527 L
.92852 .01485 L
Mistroke
.92868 .01503 L
.92882 .01545 L
.92944 .01719 L
.93055 .02 L
.93113 .02121 L
.93174 .02223 L
.9321 .02268 L
.93242 .023 L
.93258 .02311 L
.93275 .02322 L
.9329 .02329 L
.93305 .02333 L
.9332 .02336 L
.93335 .02337 L
.93347 .02335 L
.93362 .02332 L
.93377 .02327 L
.93393 .02319 L
.93422 .02298 L
.93452 .02269 L
.9348 .02235 L
.93531 .02155 L
.93651 .019 L
.93718 .01726 L
.93751 .01637 L
.9378 .01553 L
.93794 .01515 L
.93809 .01473 L
.93823 .01509 L
.93836 .01546 L
.93895 .0171 L
.93955 .01866 L
.94021 .02019 L
.94081 .02134 L
.94145 .02229 L
.9418 .02267 L
.94212 .02293 L
.94228 .02302 L
.94236 .02306 L
.94245 .02309 L
.94253 .02312 L
.94261 .02314 L
.94276 .02316 L
.9429 .02316 L
.94304 .02314 L
.94318 .02311 L
.94334 .02304 L
.94351 .02295 L
.94367 .02284 L
.94396 .02258 L
Mistroke
.9445 .02193 L
.94508 .02096 L
.94638 .01805 L
.94696 .01652 L
.94726 .01569 L
.94743 .01523 L
.94759 .01481 L
.94773 .01501 L
.94787 .01542 L
.94819 .01628 L
.94875 .01774 L
.94983 .02026 L
.9505 .02146 L
.95083 .02194 L
.95114 .0223 L
.95141 .02257 L
.9517 .02277 L
.95185 .02285 L
.952 .02291 L
.95215 .02295 L
.95224 .02296 L
.95232 .02297 L
.95247 .02296 L
.95262 .02294 L
.95275 .0229 L
.95289 .02284 L
.95305 .02275 L
.95321 .02264 L
.95351 .02238 L
.95403 .02174 L
.95461 .0208 L
.9559 .01797 L
.95653 .01635 L
.95681 .01562 L
.95696 .0152 L
.95711 .0148 L
.95725 .01501 L
.9574 .01542 L
.95772 .01624 L
.95837 .01792 L
.95895 .01929 L
.95957 .02053 L
.96013 .02146 L
.96042 .02186 L
.96074 .02221 L
.96103 .02246 L
.96129 .02263 L
.96142 .02269 L
.96156 .02273 L
.96169 .02276 L
Mistroke
.96181 .02278 L
.96196 .02278 L
.9621 .02276 L
.96223 .02273 L
.96237 .02268 L
.96252 .0226 L
.96269 .0225 L
.96298 .02226 L
.96327 .02195 L
.96355 .02159 L
.96407 .02078 L
.96527 .01828 L
.96594 .01662 L
.96626 .01577 L
.96641 .0154 L
.96656 .01499 L
.96671 .01483 L
.96685 .01519 L
.96712 .0159 L
.96771 .01741 L
.96831 .01882 L
.96897 .02019 L
.96957 .02119 L
.9699 .02164 L
.97021 .02199 L
.97038 .02215 L
.97056 .0223 L
.97073 .02241 L
.97088 .02249 L
.97104 .02255 L
.97113 .02257 L
.97121 .02259 L
.97136 .0226 L
.97152 .0226 L
.97166 .02258 L
.97179 .02254 L
.97194 .02249 L
.97208 .02241 L
.97233 .02224 L
.9726 .022 L
.97322 .02124 L
.97379 .0203 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309017 0.0936793 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02798 -12 -4.5 ]
[-0.0125 .02798 0 4.5 ]
[-0.0125 .12166 -12 -4.5 ]
[-0.0125 .12166 0 4.5 ]
[-0.0125 .21534 -12 -4.5 ]
[-0.0125 .21534 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .4027 -6 -4.5 ]
[-0.0125 .4027 0 4.5 ]
[-0.0125 .49638 -6 -4.5 ]
[-0.0125 .49638 0 4.5 ]
[-0.0125 .59005 -6 -4.5 ]
[-0.0125 .59005 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02798 m
.00625 .02798 L
s
[(-3)] -0.0125 .02798 1 0 Mshowa
0 .12166 m
.00625 .12166 L
s
[(-2)] -0.0125 .12166 1 0 Mshowa
0 .21534 m
.00625 .21534 L
s
[(-1)] -0.0125 .21534 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .4027 m
.00625 .4027 L
s
[(1)] -0.0125 .4027 1 0 Mshowa
0 .49638 m
.00625 .49638 L
s
[(2)] -0.0125 .49638 1 0 Mshowa
0 .59005 m
.00625 .59005 L
s
[(3)] -0.0125 .59005 1 0 Mshowa
.125 Mabswid
0 .04672 m
.00375 .04672 L
s
0 .06545 m
.00375 .06545 L
s
0 .08419 m
.00375 .08419 L
s
0 .10292 m
.00375 .10292 L
s
0 .14039 m
.00375 .14039 L
s
0 .15913 m
.00375 .15913 L
s
0 .17787 m
.00375 .17787 L
s
0 .1966 m
.00375 .1966 L
s
0 .23407 m
.00375 .23407 L
s
0 .25281 m
.00375 .25281 L
s
0 .27155 m
.00375 .27155 L
s
0 .29028 m
.00375 .29028 L
s
0 .32775 m
.00375 .32775 L
s
0 .34649 m
.00375 .34649 L
s
0 .36522 m
.00375 .36522 L
s
0 .38396 m
.00375 .38396 L
s
0 .42143 m
.00375 .42143 L
s
0 .44017 m
.00375 .44017 L
s
0 .4589 m
.00375 .4589 L
s
0 .47764 m
.00375 .47764 L
s
0 .51511 m
.00375 .51511 L
s
0 .53385 m
.00375 .53385 L
s
0 .55258 m
.00375 .55258 L
s
0 .57132 m
.00375 .57132 L
s
0 .00924 m
.00375 .00924 L
s
0 .60879 m
.00375 .60879 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02798 m
1 .02798 L
s
.99375 .12166 m
1 .12166 L
s
.99375 .21534 m
1 .21534 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .4027 m
1 .4027 L
s
.99375 .49638 m
1 .49638 L
s
.99375 .59005 m
1 .59005 L
s
.125 Mabswid
.99625 .04672 m
1 .04672 L
s
.99625 .06545 m
1 .06545 L
s
.99625 .08419 m
1 .08419 L
s
.99625 .10292 m
1 .10292 L
s
.99625 .14039 m
1 .14039 L
s
.99625 .15913 m
1 .15913 L
s
.99625 .17787 m
1 .17787 L
s
.99625 .1966 m
1 .1966 L
s
.99625 .23407 m
1 .23407 L
s
.99625 .25281 m
1 .25281 L
s
.99625 .27155 m
1 .27155 L
s
.99625 .29028 m
1 .29028 L
s
.99625 .32775 m
1 .32775 L
s
.99625 .34649 m
1 .34649 L
s
.99625 .36522 m
1 .36522 L
s
.99625 .38396 m
1 .38396 L
s
.99625 .42143 m
1 .42143 L
s
.99625 .44017 m
1 .44017 L
s
.99625 .4589 m
1 .4589 L
s
.99625 .47764 m
1 .47764 L
s
.99625 .51511 m
1 .51511 L
s
.99625 .53385 m
1 .53385 L
s
.99625 .55258 m
1 .55258 L
s
.99625 .57132 m
1 .57132 L
s
.99625 .00924 m
1 .00924 L
s
.99625 .60879 m
1 .60879 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02608 .53323 L
.02847 .45933 L
.03089 .38439 L
.03156 .36386 L
.03227 .34189 L
.03261 .33124 L
.03294 .32116 L
.03308 .31677 L
.03323 .31212 L
.03331 .30969 L
.0334 .60132 L
.03355 .5966 L
.03609 .5182 L
.03841 .44646 L
.03956 .41104 L
.04081 .37238 L
.04138 .3547 L
.04199 .33586 L
.04228 .32671 L
.04256 .31808 L
.04269 .31432 L
.04281 .31034 L
.04296 .60028 L
.04309 .59626 L
.04766 .45475 L
.05002 .38204 L
.0507 .3611 L
.05134 .34127 L
.05191 .32346 L
.05207 .31858 L
.05216 .31591 L
.05224 .3134 L
.05238 .60328 L
.05254 .5984 L
.05721 .45421 L
.05962 .37953 L
.06084 .34197 L
.06117 .33168 L
.06153 .32069 L
.0617 .31536 L
.06178 .31273 L
.06186 .31032 L
.06201 .6001 L
.06217 .59519 L
.06462 .51933 L
.06692 .44835 L
.06912 .38027 L
.06976 .36067 L
.07036 .34206 L
Mistroke
.0709 .32536 L
.07105 .32078 L
.07121 .31591 L
.07135 .31131 L
.07149 .60145 L
.07163 .59695 L
.07177 .59275 L
.07208 .58322 L
.0727 .56399 L
.07381 .52958 L
.07633 .45193 L
.07759 .41288 L
.07879 .37593 L
.07986 .34276 L
.08015 .33368 L
.08047 .32404 L
.08073 .3158 L
.08088 .31112 L
.08103 .60103 L
.08117 .59663 L
.08132 .59193 L
.08159 .58348 L
.08222 .5643 L
.08347 .52567 L
.0857 .45666 L
.08694 .41839 L
.08828 .37695 L
.08889 .35794 L
.08954 .33783 L
.0901 .32066 L
.09025 .31596 L
.09034 .31337 L
.09041 .31092 L
.09057 .60046 L
.09071 .59611 L
.09533 .45338 L
.09771 .37977 L
.09891 .34259 L
.09924 .3324 L
.0996 .32141 L
.09976 .31636 L
.09985 .3136 L
.09993 .31104 L
.10008 .60079 L
.10016 .59839 L
.10024 .59582 L
.10264 .52169 L
.10524 .44128 L
.10646 .40368 L
.10775 .36385 L
Mistroke
.10885 .32984 L
.10915 .32052 L
.10932 .31538 L
.10948 .3105 L
.10962 .60028 L
.10971 .59772 L
.10978 .59534 L
.11006 .5867 L
.11478 .44079 L
.11602 .40242 L
.11737 .36094 L
.11798 .34188 L
.11832 .33148 L
.11864 .32177 L
.11877 .31751 L
.1189 .31348 L
.11905 .60313 L
.11919 .59889 L
.1198 .58005 L
.12443 .43713 L
.12681 .36338 L
.12739 .34545 L
.12802 .32614 L
.12819 .32075 L
.12838 .31508 L
.12853 .31024 L
.12862 .6018 L
.1287 .59925 L
.12935 .57937 L
.13406 .43378 L
.13529 .39557 L
.13663 .35417 L
.13725 .33517 L
.13758 .32479 L
.13775 .31971 L
.1379 .31507 L
.13804 .31083 L
.13817 .6011 L
.1383 .59685 L
.13845 .59221 L
.13907 .57335 L
.14164 .49369 L
.14398 .4216 L
.14515 .3854 L
.14641 .34631 L
.14699 .32834 L
.14731 .31854 L
.14747 .31375 L
.14761 .3094 L
.14774 .59968 L
Mistroke
.14786 .59589 L
.14813 .58753 L
.1487 .5698 L
.15333 .42669 L
.15573 .35279 L
.15631 .33483 L
.15663 .32493 L
.15693 .31551 L
.15702 .31295 L
.1571 .31022 L
.1572 .60152 L
.15729 .59874 L
.15762 .5886 L
.15826 .56873 L
.16067 .49432 L
.16328 .41381 L
.1645 .37601 L
.16517 .35536 L
.16579 .33607 L
.16632 .31962 L
.16648 .31488 L
.16662 .31039 L
.16675 .60066 L
.16689 .59628 L
.16811 .55883 L
.17044 .48662 L
.17302 .40689 L
.1742 .37059 L
.17481 .35153 L
.17546 .33145 L
.17574 .32292 L
.17589 .31823 L
.17604 .3138 L
.17612 .31129 L
.17621 .60286 L
.17636 .5981 L
.17666 .58879 L
.17776 .5549 L
.18011 .48232 L
.18269 .40245 L
.18387 .3659 L
.18453 .34575 L
.18485 .33582 L
.18514 .32662 L
.18542 .31803 L
.18558 .31323 L
.18572 .60318 L
.18587 .59839 L
.18604 .59322 L
.18634 .58384 L
Mistroke
.18744 .54995 L
.1898 .47699 L
.19239 .39699 L
.19358 .36018 L
.19424 .33993 L
.19456 .32997 L
.19486 .32076 L
.195 .3163 L
.19514 .31211 L
.19528 .60205 L
.19543 .59724 L
.19606 .57786 L
.19716 .54398 L
.20183 .39965 L
.20308 .36088 L
.20369 .34199 L
.20425 .32485 L
.2044 .32035 L
.20455 .31549 L
.2047 .31089 L
.20484 .60096 L
.20498 .59647 L
.20514 .59153 L
.20547 .58156 L
.2068 .54048 L
.20934 .4618 L
.21167 .38999 L
.21282 .3544 L
.21342 .33562 L
.21376 .32533 L
.21392 .32028 L
.21407 .31565 L
.2142 .31158 L
.21434 .60159 L
.21448 .59728 L
.21463 .59257 L
.21526 .57335 L
.21635 .53945 L
.21891 .46038 L
.22124 .38845 L
.2224 .35262 L
.22301 .33374 L
.22334 .32341 L
.22351 .31835 L
.22366 .31373 L
.2238 .30941 L
.22393 .59961 L
.22407 .59528 L
.22422 .59055 L
.22485 .57131 L
Mistroke
.22594 .53741 L
.22851 .45794 L
.23085 .3859 L
.23201 .34981 L
.23263 .33083 L
.23296 .32047 L
.23313 .3154 L
.23328 .31079 L
.23342 .60073 L
.23355 .59661 L
.23384 .58752 L
.23447 .56824 L
.23557 .53434 L
.24019 .39147 L
.24142 .35344 L
.24202 .33482 L
.24257 .31775 L
.24272 .31323 L
.24286 .30902 L
.243 .59894 L
.24315 .59414 L
.24378 .57483 L
.24511 .53375 L
.24737 .46391 L
.24982 .38821 L
.25047 .36809 L
.25116 .3468 L
.25175 .32862 L
.25191 .32364 L
.25208 .31829 L
.25216 .3157 L
.25224 .31325 L
.25239 .60293 L
.25255 .59819 L
.25269 .5939 L
.253 .58428 L
.25356 .567 L
.25482 .52783 L
.25735 .44988 L
.25845 .41572 L
.25966 .37828 L
.26023 .36078 L
.26084 .34204 L
.26113 .33295 L
.26141 .32435 L
.26166 .31664 L
.2618 .31228 L
.26193 .60256 L
.26207 .59832 L
.26221 .59376 L
Mistroke
.26248 .58551 L
.26309 .56671 L
.26432 .52869 L
.26669 .4553 L
.26795 .41652 L
.26929 .37514 L
.26996 .35445 L
.27059 .33494 L
.27087 .32643 L
.27116 .31743 L
.27131 .31273 L
.27139 .31005 L
.27148 .60186 L
.27162 .59748 L
.27177 .59277 L
.27407 .52155 L
.27646 .44779 L
.27772 .40887 L
.27906 .3675 L
.28024 .33088 L
.28057 .32084 L
.28074 .31557 L
.28083 .3127 L
.28092 .31002 L
.28108 .59945 L
.28116 .59687 L
.28125 .59411 L
.28155 .58473 L
.28386 .51339 L
.28626 .43925 L
.28753 .4002 L
.28886 .35883 L
.28944 .34106 L
.29006 .32196 L
.29024 .31634 L
.29033 .31357 L
.29041 .31101 L
.29057 .60052 L
.29065 .59799 L
.29074 .5953 L
.29137 .57568 L
.29368 .50422 L
.29609 .4297 L
.29736 .39051 L
.2987 .34914 L
.29928 .33122 L
.2996 .32136 L
.29976 .3165 L
.2999 .31202 L
.29999 .30946 L
Mistroke
.30007 .60104 L
.30016 .59831 L
.30026 .5953 L
.30058 .58525 L
.30122 .5656 L
.30354 .49402 L
.30607 .41578 L
.30718 .38153 L
.30776 .36342 L
.30839 .34409 L
.30871 .33426 L
.30901 .32499 L
.30928 .31667 L
.30943 .31198 L
.30957 .60195 L
.3097 .5979 L
.30982 .59411 L
.3101 .58549 L
.31066 .56808 L
.31306 .49411 L
.3153 .4248 L
.31648 .38823 L
.31774 .34931 L
.3181 .33822 L
.31844 .32779 L
.31874 .31842 L
.31883 .31585 L
.31891 .31315 L
.31907 .60261 L
.31922 .59808 L
.31937 .59323 L
.31966 .58448 L
.3203 .56462 L
.32273 .48968 L
.32512 .41563 L
.32638 .37661 L
.32708 .35525 L
.32772 .33524 L
.32802 .32615 L
.3283 .3175 L
.32845 .31274 L
.32854 .31004 L
.32862 .60184 L
.32876 .59743 L
.32891 .59273 L
.33023 .55218 L
.33254 .48074 L
.33495 .40631 L
.33621 .36716 L
.33691 .34577 L
Mistroke
.33724 .33532 L
.33755 .32579 L
.33769 .32139 L
.33785 .31661 L
.338 .31209 L
.33813 .60221 L
.33827 .59779 L
.33843 .59291 L
.33875 .58303 L
.34007 .54234 L
.34238 .47079 L
.34491 .39264 L
.34602 .35842 L
.34661 .34032 L
.34693 .33037 L
.34723 .32098 L
.34738 .31654 L
.34753 .31183 L
.34761 .30938 L
.34769 .60098 L
.34785 .59622 L
.34841 .5789 L
.3495 .54506 L
.3519 .47111 L
.35444 .39257 L
.35564 .35533 L
.35623 .3372 L
.35676 .32079 L
.3569 .31653 L
.35705 .31193 L
.35719 .60189 L
.35732 .5979 L
.35791 .57959 L
.35916 .54088 L
.36144 .47042 L
.36391 .39418 L
.36511 .35697 L
.36568 .33935 L
.36621 .32308 L
.36648 .3149 L
.36661 .31078 L
.36676 .60053 L
.3669 .59598 L
.36706 .59108 L
.36735 .58222 L
.36843 .54896 L
.3708 .47569 L
.37317 .40234 L
.37443 .36356 L
.37511 .34227 L
Mistroke
.37545 .33182 L
.37576 .32219 L
.37592 .31735 L
.37607 .31282 L
.37622 .60239 L
.3763 .59989 L
.37639 .5972 L
.37706 .57632 L
.37824 .53986 L
.38055 .46864 L
.38293 .39491 L
.38419 .35601 L
.38488 .33468 L
.38522 .32423 L
.38537 .31965 L
.38553 .31464 L
.38568 .3102 L
.38581 .60037 L
.38595 .596 L
.3861 .59134 L
.38672 .57234 L
.38803 .53191 L
.39033 .46058 L
.39157 .42248 L
.3929 .38113 L
.39352 .36218 L
.39417 .34209 L
.39472 .32494 L
.39487 .32024 L
.39504 .31519 L
.39519 .31042 L
.39533 .60036 L
.39549 .59556 L
.39564 .59104 L
.39591 .58259 L
.39652 .56364 L
.39762 .52957 L
.40012 .45232 L
.40478 .30859 L
.40713 .2357 L
.40972 .15572 L
.41091 .11896 L
.41219 .07957 L
.41281 .06047 L
.41339 .04239 L
.41392 .02615 L
.41406 .0217 L
.41421 .01698 L
.41434 .30725 L
.41449 .3028 L
Mistroke
.41702 .22459 L
.41934 .15291 L
.42161 .08264 L
.42275 .04731 L
.42307 .03763 L
.4234 .02729 L
.42356 .02227 L
.42372 .01754 L
.42386 .30759 L
.424 .30298 L
.42636 .23032 L
.42894 .15042 L
.43013 .11382 L
.4314 .07451 L
.43201 .05547 L
.4326 .03741 L
.43285 .02955 L
.43312 .02119 L
.43328 .01638 L
.43342 .30632 L
.43356 .30194 L
.4337 .29782 L
.43835 .1539 L
.44076 .0794 L
.44198 .04191 L
.44231 .03164 L
.44249 .02599 L
.44267 .02065 L
.44274 .01824 L
.44283 .01568 L
.44292 .30717 L
.443 .30458 L
.44331 .29513 L
.44787 .15419 L
.45021 .0819 L
.45088 .06109 L
.45152 .04129 L
.4518 .03269 L
.4521 .02352 L
.45218 .0208 L
.45227 .01824 L
.45242 .30776 L
.45257 .30327 L
.45272 .29841 L
.45508 .22561 L
.45767 .14566 L
.45885 .10896 L
.46013 .0696 L
.46075 .05053 L
.46133 .03245 L
Mistroke
.46159 .02458 L
.46172 .02027 L
.46186 .01622 L
.462 .30617 L
.46215 .30135 L
.46243 .29287 L
.46709 .14875 L
.46951 .07411 L
.47072 .03657 L
.47105 .02628 L
.47124 .02063 L
.47133 .01785 L
.47141 .01529 L
.47149 .30718 L
.47157 .30462 L
.47175 .29922 L
.47205 .28979 L
.47662 .14865 L
.47896 .07622 L
.47964 .05536 L
.48028 .03555 L
.48056 .02694 L
.48071 .02222 L
.48085 .01777 L
.48094 .01523 L
.48102 .30679 L
.48118 .30201 L
.48148 .29268 L
.48384 .21973 L
.48643 .13974 L
.48762 .10294 L
.4889 .06353 L
.48952 .04442 L
.48982 .03502 L
.4901 .02633 L
.49023 .02226 L
.49036 .01845 L
.49048 .30878 L
.49063 .30439 L
.4912 .28674 L
.49587 .14243 L
.49829 .06764 L
.49888 .04946 L
.4995 .03006 L
.49969 .02431 L
.49978 .0215 L
.49986 .0189 L
.50002 .60264 L
.5001 .60008 L
.50019 .59737 L
Mistroke
.50083 .57758 L
.50541 .43625 L
.50775 .36368 L
.50843 .34278 L
.50876 .33249 L
.50907 .32295 L
.50935 .31433 L
.50949 .30998 L
.50965 .59946 L
.5098 .59466 L
.50997 .58947 L
.51028 .58008 L
.51264 .50699 L
.51523 .42694 L
.51643 .39005 L
.5177 .35058 L
.51832 .33144 L
.51863 .32203 L
.51876 .31789 L
.51891 .31334 L
.51904 .30927 L
.51916 .59975 L
.51929 .59573 L
.51943 .59139 L
.52 .57376 L
.52238 .50029 L
.52498 .42011 L
.52618 .38296 L
.52684 .36257 L
.52746 .34336 L
.52804 .32541 L
.5282 .32049 L
.52837 .31529 L
.52851 .31086 L
.52867 .60029 L
.52881 .59587 L
.52894 .59184 L
.52924 .58277 L
.52977 .56641 L
.53226 .48927 L
.53457 .4179 L
.53681 .34863 L
.53736 .3318 L
.53764 .32296 L
.5378 .31814 L
.53795 .31365 L
.53802 .31125 L
.53811 .60299 L
.5382 .60015 L
.53828 .59757 L
Mistroke
.53859 .58804 L
.53919 .56935 L
.5417 .49181 L
.54402 .42033 L
.54627 .35069 L
.54682 .33376 L
.54712 .32443 L
.54741 .31558 L
.54748 .31316 L
.54757 .31059 L
.54766 .60207 L
.54774 .59945 L
.54805 .58993 L
.54866 .57126 L
.55107 .49667 L
.55368 .41609 L
.55491 .37817 L
.55558 .35746 L
.5562 .33816 L
.55673 .32166 L
.55689 .31691 L
.55703 .31242 L
.55716 .60269 L
.55731 .5983 L
.55852 .56086 L
.56086 .48847 L
.56344 .40867 L
.56462 .37225 L
.56524 .35313 L
.56589 .33303 L
.56617 .32447 L
.56646 .31534 L
.56655 .31264 L
.56663 .31009 L
.56679 .59963 L
.56693 .59516 L
.56709 .59032 L
.56818 .55643 L
.57054 .48366 L
.57313 .40372 L
.57431 .36705 L
.57497 .34685 L
.57559 .3277 L
.57586 .31908 L
.57602 .31435 L
.57616 .30992 L
.57632 .59944 L
.5764 .5969 L
.57649 .59417 L
.57679 .58486 L
Mistroke
.57788 .55097 L
.58025 .47783 L
.58284 .39776 L
.58404 .36083 L
.58469 .34052 L
.58502 .33055 L
.58532 .32134 L
.58546 .31686 L
.5856 .31266 L
.58574 .60259 L
.58589 .59777 L
.58652 .57838 L
.58762 .5445 L
.5923 .39992 L
.59727 .24619 L
.59976 .16939 L
.60206 .09812 L
.60321 .0626 L
.60378 .04518 L
.60429 .02917 L
.60459 .02016 L
.60473 .01562 L
.60482 .30735 L
.60489 .30495 L
.60554 .28493 L
.60667 .25 L
.61137 .10491 L
.6126 .06695 L
.61324 .04694 L
.6136 .03597 L
.61393 .02568 L
.61407 .02134 L
.61422 .01676 L
.6143 .30867 L
.61438 .30605 L
.61453 .30146 L
.61519 .28101 L
.61636 .24498 L
.61892 .16571 L
.62125 .09373 L
.62242 .05777 L
.62303 .03884 L
.62336 .02849 L
.62353 .02343 L
.62368 .01881 L
.62382 .30878 L
.62395 .30467 L
.62424 .29559 L
.62487 .27633 L
.62596 .24243 L
Mistroke
.63058 .09981 L
.63181 .06192 L
.63241 .04334 L
.63296 .02629 L
.63312 .02131 L
.63327 .01668 L
.63343 .30614 L
.63351 .30358 L
.6336 .30084 L
.63429 .27952 L
.63549 .24236 L
.63789 .16832 L
.63915 .1293 L
.64049 .08793 L
.64168 .05113 L
.64201 .04104 L
.64236 .0302 L
.64253 .02495 L
.64269 .01995 L
.64283 .01547 L
.64299 .30488 L
.64315 .30004 L
.6433 .29548 L
.64357 .28696 L
.64419 .26785 L
.6453 .23346 L
.64995 .08982 L
.65119 .05141 L
.6518 .03265 L
.65207 .02445 L
.65221 .02013 L
.65235 .01554 L
.65251 .30502 L
.65265 .30057 L
.65294 .29178 L
.65357 .27242 L
.65489 .23134 L
.65945 .09069 L
.66058 .05558 L
.6612 .03643 L
.6615 .0271 L
.66164 .02302 L
.66178 .01861 L
.66193 .3081 L
.66208 .30355 L
.66241 .29355 L
.66309 .27237 L
.66429 .23519 L
.66664 .1626 L
.66789 .1241 L
Mistroke
.66923 .08273 L
.66989 .06241 L
.67051 .04311 L
.67107 .02578 L
.67122 .02103 L
.67131 .01843 L
.67139 .01598 L
.67154 .30551 L
.67168 .30119 L
.67398 .23022 L
.6762 .16161 L
.67746 .12269 L
.67863 .08639 L
.6798 .05045 L
.68013 .0401 L
.68045 .03031 L
.68073 .02151 L
.68081 .01911 L
.68089 .01655 L
.68104 .30626 L
.6812 .30142 L
.68134 .29698 L
.68167 .28699 L
.68225 .26891 L
.68358 .22772 L
.68606 .1511 L
.68727 .11377 L
.68837 .07989 L
.68892 .06289 L
.68951 .04449 L
.68979 .03604 L
.69008 .02711 L
.69032 .01948 L
.69046 .01515 L
.69059 .30541 L
.69074 .30086 L
.6909 .2959 L
.69119 .2869 L
.69174 .27 L
.69297 .232 L
.6953 .15987 L
.69654 .12154 L
.69788 .08017 L
.6985 .06104 L
.69915 .04088 L
.69942 .03256 L
.69971 .02366 L
.6998 .02103 L
.69988 .01855 L
.70003 .3082 L
Mistroke
.70017 .30384 L
.70032 .29911 L
.70261 .22829 L
.70496 .15579 L
.7062 .11732 L
.70754 .07595 L
.7082 .05566 L
.70882 .03638 L
.70909 .02801 L
.70924 .02341 L
.70938 .01908 L
.70946 .01661 L
.70955 .30825 L
.7097 .30359 L
.70999 .2945 L
.71229 .22356 L
.71465 .15068 L
.7159 .11207 L
.71724 .0707 L
.7179 .05025 L
.71822 .04018 L
.71852 .03087 L
.7188 .02244 L
.71894 .01818 L
.71909 .30778 L
.71924 .30309 L
.7194 .29802 L
.7197 .28887 L
.722 .2178 L
.72437 .14455 L
.72562 .10581 L
.72696 .06444 L
.72763 .04381 L
.72796 .03368 L
.72826 .02434 L
.7284 .01995 L
.72853 .01585 L
.72867 .30587 L
.72883 .30116 L
.72944 .28221 L
.73174 .21103 L
.73398 .14178 L
.73643 .0663 L
.73707 .04646 L
.73742 .03557 L
.73775 .02533 L
.7379 .02067 L
.73806 .01575 L
.73815 .30748 L
.73824 .30466 L
Mistroke
.7384 .2997 L
.73898 .28166 L
.74141 .20673 L
.74396 .12775 L
.74629 .05584 L
.74685 .03848 L
.74716 .02897 L
.74745 .02006 L
.7476 .01543 L
.74768 .30714 L
.74776 .30476 L
.7481 .29416 L
.7487 .2755 L
.75099 .20491 L
.75347 .12823 L
.75468 .09088 L
.75577 .057 L
.75633 .03998 L
.75661 .03103 L
.75677 .02614 L
.75692 .02156 L
.75705 .01757 L
.75719 .30758 L
.75734 .30282 L
.75748 .29848 L
.758 .28247 L
.76038 .20904 L
.76287 .13197 L
.76397 .09807 L
.76518 .06063 L
.76574 .04346 L
.76603 .03444 L
.76634 .02494 L
.76647 .02091 L
.76661 .0166 L
.76676 .30617 L
.7669 .30176 L
.76742 .28572 L
.7698 .21216 L
.7722 .13801 L
.77346 .09896 L
.7748 .05759 L
.77538 .03982 L
.7757 .03002 L
.776 .02071 L
.77608 .01818 L
.77617 .01547 L
.77626 .30681 L
.77635 .30406 L
.77667 .29405 L
Mistroke
.77731 .27443 L
.77962 .20297 L
.78203 .12844 L
.7833 .08925 L
.78399 .06785 L
.78464 .04788 L
.78522 .02995 L
.78539 .02479 L
.78555 .01991 L
.78569 .01552 L
.78584 .30505 L
.786 .30017 L
.78617 .29479 L
.78653 .28389 L
.78716 .26433 L
.78948 .19275 L
.79201 .1145 L
.79312 .08024 L
.7937 .06214 L
.79433 .0428 L
.79465 .03298 L
.79495 .0237 L
.79508 .01966 L
.79522 .01538 L
.79537 .30499 L
.79551 .30067 L
.7966 .26679 L
.799 .19281 L
.80139 .11894 L
.80243 .08666 L
.80357 .0515 L
.80387 .04213 L
.8042 .03217 L
.80435 .02732 L
.8045 .02277 L
.80463 .01868 L
.80478 .30856 L
.80492 .30428 L
.80507 .2996 L
.80537 .29015 L
.80592 .27324 L
.80844 .19535 L
.811 .1163 L
.81221 .07891 L
.81333 .04438 L
.81389 .027 L
.81402 .02277 L
.81417 .01823 L
.81426 .01562 L
.81433 .30754 L
Mistroke
.81448 .30287 L
.81574 .26399 L
.81803 .19337 L
.82051 .11664 L
.82172 .07927 L
.82282 .04539 L
.82337 .02835 L
.82352 .02368 L
.8236 .02113 L
.82368 .01875 L
.82382 .30884 L
.82396 .30422 L
.82505 .2708 L
.82742 .19736 L
.82967 .12791 L
.83086 .09128 L
.83212 .05236 L
.83275 .03282 L
.83292 .02747 L
.83311 .02169 L
.83319 .01904 L
.83328 .01624 L
.83336 .30816 L
.83345 .30555 L
.83468 .26751 L
.8371 .19252 L
.83967 .11333 L
.84088 .07589 L
.84199 .04137 L
.84256 .02392 L
.8427 .01968 L
.84284 .01513 L
.84293 .30682 L
.84301 .30443 L
.84316 .29976 L
.84442 .26082 L
.8467 .19016 L
.84919 .11327 L
.8504 .07586 L
.8515 .04198 L
.85205 .02489 L
.8522 .0202 L
.85229 .01765 L
.85236 .01526 L
.8525 .30534 L
.85265 .30072 L
.85373 .26726 L
.85611 .19376 L
.85836 .12417 L
.85955 .08749 L
Mistroke
.86081 .04857 L
.86144 .02896 L
.86162 .02359 L
.86171 .02077 L
.8618 .01781 L
.86189 .0152 L
.86198 .30665 L
.86207 .30406 L
.86214 .30165 L
.86338 .26356 L
.8658 .18853 L
.86807 .11857 L
.86926 .08176 L
.87052 .04283 L
.87083 .03329 L
.87116 .02306 L
.87126 .02005 L
.87135 .01719 L
.87143 .30893 L
.87152 .30613 L
.87186 .29564 L
.8731 .25743 L
.87553 .18229 L
.87786 .11014 L
.87911 .0718 L
.87976 .05165 L
.88011 .04066 L
.88044 .03043 L
.88074 .02136 L
.88082 .01875 L
.8809 .01628 L
.88105 .30597 L
.88113 .30348 L
.88122 .30084 L
.88137 .29611 L
.88172 .28542 L
.88288 .24935 L
.88518 .17852 L
.88756 .10483 L
.8886 .07261 L
.88974 .03744 L
.89004 .02812 L
.89021 .02301 L
.89036 .01819 L
.89051 .30799 L
.89067 .30312 L
.89094 .29463 L
.89208 .25936 L
.8946 .18153 L
.89696 .10863 L
Mistroke
.89821 .07002 L
.8989 .04877 L
.89924 .03832 L
.89955 .02865 L
.89985 .0194 L
.9 .01472 L
.90009 .30636 L
.90017 .30387 L
.90084 .28311 L
.90201 .24679 L
.90431 .17572 L
.90654 .10682 L
.90781 .06778 L
.90842 .04875 L
.90898 .03148 L
.90927 .02255 L
.90935 .0201 L
.90943 .01752 L
.90958 .30718 L
.90972 .30286 L
.90985 .29882 L
.91015 .28963 L
.9114 .25104 L
.91395 .17239 L
.91619 .10311 L
.91737 .06654 L
.91802 .04649 L
.91863 .02763 L
.91879 .02259 L
.91888 .01985 L
.91896 .01729 L
.91905 .30881 L
.91915 .30577 L
.91933 .30042 L
.91996 .28095 L
.92119 .24296 L
.92361 .16803 L
.92586 .09839 L
.92705 .06169 L
.9277 .04159 L
.92802 .03176 L
.92831 .02276 L
.92847 .01792 L
.92862 .30761 L
.92877 .30275 L
.92895 .29744 L
.92965 .27581 L
.93088 .23771 L
.93331 .16266 L
.93568 .08938 L
Mistroke
.93636 .06828 L
.93701 .0484 L
.93758 .03055 L
.93774 .02566 L
.93791 .02049 L
.93805 .01608 L
.93821 .30553 L
.93837 .30068 L
.93851 .29619 L
.93884 .28602 L
.93944 .26753 L
.94056 .23286 L
.94308 .15493 L
.94533 .08541 L
.94595 .06636 L
.94661 .04582 L
.94692 .03638 L
.94724 .02643 L
.94737 .02233 L
.94751 .01794 L
.94767 .30743 L
.94782 .30295 L
.95022 .22878 L
.95282 .14834 L
.95404 .11071 L
.95533 .07086 L
.95643 .03683 L
.95673 .02751 L
.9569 .02237 L
.95705 .01749 L
.9572 .30727 L
.95728 .30471 L
.95736 .30234 L
.95764 .29369 L
.96236 .14772 L
.96361 .10932 L
.96495 .06781 L
.96557 .04875 L
.9659 .03834 L
.96622 .02863 L
.96648 .02033 L
.96664 .01568 L
.96677 .30575 L
.96692 .30111 L
.96709 .29607 L
.96738 .28691 L
.97231 .13478 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000U2000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00=_ooool3
o`0002;ooooo1Ol0000Qooooo`;o00009?ooool5o`0002Cooooo0ol0001Oooooo`?o00008_ooool5
o`0002;ooooo0_l0000Tooooo`Go00009?ooool3o`0002Sooooo000gooooo`03o`000?oooooooooo
02;ooooo00Co0000oooooooooooo00008?ooool01?l0003oooooooooool0000Tooooo`04o`000?oo
ooooooooo`0002Gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Rooooo`04o`00
0?ooooooooooo`00027ooooo00Co0000oooooooooooo00009?ooool01?l0003oooooooooool0000U
ooooo`03o`000?oooooooooo02Oooooo000^ooooo`Go000000?oooooo`000?l000000ol0000Loooo
o`Go00000oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0002Gooooo00?o0000
ooooooooool08_ooool5o`0005Oooooo1Ol000000ooooooo0000o`000003o`0001cooooo1Ol00003
ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00009Oooool00ol0003ooooooooo
o`0Rooooo`Go0000:?ooool003Cooooo00Co0000oooooooooooo00009_ooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool08Oooool01?l0003ooooo
ooooool0001Nooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool08?ooool01?l0
003oooooooooool0000Vooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000:Ooo
ool003Gooooo00?o0000ooooool000008oooool01Ol0003ooooooooooooooooo0000023ooooo00Co
0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooool0
0000Goooool00ol0003oooooo`00000Sooooo`05o`000?ooooooooooooooool000008Oooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooo`00
000Yooooo`00=_ooool2o`0002?ooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?oo
ooooooooo`0002?ooooo00Go0000ooooooooooooooooo`00000Tooooo`;o0000H?ooool2o`0002?o
oooo00Go0000ooooooooooooooooo`00000Qooooo`04o`000?ooooooooooo`0002?ooooo00Go0000
ooooooooooooooooo`00000Tooooo`;o0000:Oooool003Oooooo00?o0000ooooooooool08_ooool3
o`0002;ooooo0_l0000Uooooo`?o00009_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo02;ooooo0ol0000Sooooo`;o00009Oooool3o`0002Kooooo00?o0000ooooooooool09oooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool001_ooooocol0000]ooooom7o00004?oo
ool001Gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo000Dooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0:oooool2o`0001Oooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Eooooo`;o00004?ooool001Cooooo00Co0000oooooooooooo00000oooool3
o`0000;ooooo00?oo`00oooooooo00000_oo00008Oooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`06ool0000Loooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000Wooooo00[oo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo1?oo00000oooooooo`00ool00005ool00008oooo
oooo003oooooool00?ooooooo`00oooooooo0003ooooo`03ool00?ooooooo`0000Gooooo01;oo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooool2ool00007oooooooo003oooooool00?ooooooo`00ooooo`03ool0000Uoooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00ooooo`06ool00003oooooooo003ooooo00;ooooo0_l0000]ooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool0D?ooool00ooo003oooooooooo`0=ooooo`03ool0
0?oooooooooo00;ooooo00?o0000ooooooooool03_ooool001Cooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`Coo`0000?oooooool00?oo00000ooo00003oooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`03ool00003
oooooooo003oo`0001Coo`0001[oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool000?ooooo00Koo`00oooooooo003oooooool00?oooolBool0000<oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`000oooool03_oo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003ooooo3_oo00000oooooooo`00ool00003ool0000G
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooool00ooo00000oooooooo`00ool0000>ool000Co
oooo00?o0000ooooooooool08oooool3o`0000Gooooo00?o0000ooooooooool0Doooool04ooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo00005Oooool09?oo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Koo`0002Coooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo0004ooooo`03o`000?oooooooooo00kooooo000Dooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool00oooooleool0000Hoooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`000oooool01?oo003oooooool00?ooool;ool000;ooooo00?o0000ooooooooool0
1_oo00002_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0003ooooo`0<ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo@Ooo0004ooooo`03o`000?oo
oooooooo02;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05?ooooo
01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`0001Gooooo02Coo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool6ool0000Toooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`001?ooool00ol0003oooooooooo`0>ooooo`005?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo01Wooooo00Koo`00oooooooo003oooooool00?oo
oolOool0000Boooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`000oooool00ooo003oooooool00009ool000Gooooo00?o0000oooo
ooooool01?ooool6ool00006oooooooo003oooooool00?ooooooo`000oooool02_oo003oooooool0
0?ooooooo`00oooooooo003oooooool00?oooolOool0000>oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo000Jooooo`03o`000?oooooooooo01cooooo1Ol0
0005ooooo`03o`000?oooooooooo00;ooooo0_l0001Dooooo`0Cool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Eoooo
o`0Pool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool3ool00003oooooooo003oo`0000Coo`0002Coooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
0003ooooo`;o00004?ooool001Gooooo0_l00004ooooo`03o`000?oooooooooo02kooooo4_oo0000
4?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo0003ooooo`[oo`001oooool00ol0003oooooooooo`06ooooo`Koo`0000Coooooool00?oooooo
o`000oooool02?oo003oooooool00?ooooooo`00oooooooo003ooooo5ooo00000oooooooo`00oooo
o`0_ooooo`03o`000?oooooooooo02Cooooo0_l00005ooooo`03o`000?oooooooooo05?ooooo01?o
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`0001Gooooo01koo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooool<ool0000Toooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`001?ooool0
0ol0003oooooooooo`0>ooooo`006oooool2o`0003Wooooo00?oo`00oooooooo00001?oo00000ooo
ooooo`00ooooo`02ool0000<oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`000oooool:ool000Oooooo00?o0000ooooooooool01_ooool00ooo003oooooool00003ool0
0004oooooooo003oooooool000?ooooo00Koo`00oooooooo003oooooool00?oooolBool003Wooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05?ooooo
01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`0001Gooooo01[oo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooa3oo`0002Coooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0004ooooo`03o`000?oooooooooo
00kooooo000Kooooo`03o`000?oooooooooo03kooooo00Koo`00oooooooo003oooooool00?ooool2
ool0000:oooooooo003oo`00ool00?ooooooo`00oooooooo003oooooool000?ooooo2?oo0009oooo
o`03o`000?oooooooooo00Sooooo1?oo00001?ooooooo`00oooooooo0003ooooo`06ool00?oooooo
o`00oooooooo003ooooo3?oo000oooooo`03o`000?oooooooooo02;ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo05?ooooo01?oo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001Gooooo01Ko
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003ooooo5?oo00009?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000Co
oooo00?o0000ooooooooool03_ooool001_ooooo00?o0000ooooooooool0@_ooool01?oo003ooooo
ool00?ooool4ool00006oooooooo003oooooool00?ooooooo`000oooool6ool000_ooooo00?o0000
ooooooooool02_ooool2ool00004oooooooo003oooooool000?ooooo00Coo`00oooooooo003ooooo
2_oo0013ooooo`03o`000?oooooooooo02?ooooo0ol00005ooooo`;o0000E?ooool04ooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo00005Oooool05_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooolDool0000Toooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`000oooool2o`00013ooooo000Kooooo`03o`000?oooooooooo04Cooooo00?o
o`00oooooooo00000ooo00001_ooooooo`00oooooooo003oooooool000?ooooo1_oo000;ooooo`03
o`000?oooooooooo00[ooooo0_oo00001?ooooooo`00oooooooo0003ooooo`04ool00?ooooooo`00
ooooo`Koo`0000?oooooool00?ooool0A?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo05?ooooo01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`0001Gooooo00[oo`00oooooooo003oooooool00?oooooo
o`00oooooooo003ooooo0ooo00001oooooooo`00ool00?oo003oooooool00?ooool05_oo00009?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool000Cooooo00?o0000ooooooooool03_ooool001_ooooo00?o0000
ooooooooool0A_ooool00ooo003oooooool00003ool00004oooooooo003oooooool000?ooooo1_oo
000;ooooo`03o`000?oooooooooo00[ooooo0_oo00001?ooooooo`00oooooooo0003ooooo`04ool0
0?ooooooo`00ooooo`Coo`0000?oooooool00?ooool0A_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo05?ooooo01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001Gooooo00Coo`00oooooooo003ooooo
0ooo00000oooooooo`00ooooo`0Pool0000Toooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`001?ooool00ol0
003oooooooooo`0>ooooo`006oooool2o`0004Wooooo1?oo00001?ooooooo`00oooooooo0003oooo
o`Coo`003Oooool00ol0003oooooooooo`0<ooooo`;oo`0000?oooooool00?ooool00_ooool00ooo
003oooooool00005ool004Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Coooo
o`0Cool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool0000Eooooo`?oo`0000Ooooooool00?oo003oo`00oooooooo003ooooo
023oo`0002Coooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo0004ooooo`03o`000?oooooooooo00kooooo000K
ooooo`03o`000?oooooooooo04Sooooo00?oo`00oooooooo00000ooo00000oooooooo`00ooooo`02
ooooo`Coo`003Oooool00ol0003oooooooooo`0<ooooo`;oo`0000?oooooool00?ooool00_ooool0
0ooo003oooooool00003ool00003oooooooo003ooooo04Sooooo00?o0000ooooooooool0:oooool2
o`0005Cooooo01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`0001Gooooo0ooo00001oooooooo`00ool00?oo003ooooo
ool00?ooool08?oo00009?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000?ooooo0_l0000@ooooo`006ooo
ool00ol0003oooooooooo`1:ooooo`Coo`0000?oooooool00?ooool00_ooool4ool000gooooo00?o
0000ooooooooool03?ooool2ool00003oooooooo003ooooo00;ooooo00Koo`00oooooooo003oo`00
oooooooo001;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Doooool04ooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo00005Oooool3ool00007oooooooo003oo`00ool00?ooooooo`00ooooo`0Pool0000T
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`001?ooool00ol0003oooooooooo`0>ooooo`006oooool00ol0
003oooooooooo`1:ooooo`Coo`0000?oooooool00?ooool00_ooool4ool000gooooo00?o0000oooo
ooooool03?ooool2ool00003oooooooo003ooooo00;ooooo00Koo`00oooooooo003oo`00oooooooo
001;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Doooool04ooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo00005Oooool3ool00003oooooooo003oo`0002Coo`00027oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0005oooo
o`03o`000?oooooooooo00kooooo000Kooooo`03o`000?oooooooooo04_ooooo0ooo00000ooooooo
o`00ooooo`02ooooo`Coo`003Oooool00ol0003oooooooooo`0<ooooo`;oo`0000?oooooool00?oo
ool00_ooool4ool004gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Cooooo`0C
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool0000Eooooob[oo`00027oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0005ooooo`03o`000?oo
oooooooo00kooooo000Kooooo`;o0000COooool2ool00004oooooooo003oooooooooo`?oo`003ooo
ool00ol0003oooooooooo`0=ooooo`03ool00?ooooooo`0000?ooooo1?oo001=ooooo`03o`000?oo
oooooooo02_ooooo0_l0001Dooooo`0Cool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Dooooob_oo`00027oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooool00_oo0004ooooo`;o00004?ooool001_ooooo00?o0000ooooooooool0C?ooool2ool00004
oooooooo003oooooooooo`?oo`003oooool00ol0003oooooooooo`0>ooooo`;oo`000oooool4ool0
04gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Cooooo`0>ool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool3ool00003oooooooo003o
oooo01?ooooo:ooo00008Oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooo`02ool000Gooooo00?o0000ooooooooool03_ooool0
01_ooooo00?o0000ooooooooool0C?ooool2ool00004oooooooo003oooooooooo`?oo`003oooool0
0ol0003oooooooooo`0>ooooo`;oo`000oooool2ool00003oooooooo003ooooo04cooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`1Cooooo`08ool00?ooooooo`00oooooooo003ooooo
ool00?ooool3ool00003oooooooo003ooooo00?oo`0000?oooooool00?ooool04oooool[ool0000Q
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003ooooo00;oo`001Oooool00ol0003oooooooooo`0>ooooo`006oooool00ol0003ooooo
ooooo`1<ooooo`;oo`0000Coooooool00?oooooooooo0ooo000?ooooo`03o`000?oooooooooo00ko
oooo0_oo0003ooooo`;oo`0000?oooooool00?ooool0C?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo05?ooooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`?oo`0000?o
ooooool00?ooool00ooo00000oooooooo`00ooooo`0Cooooob_oo`00027oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo
0005ooooo`03o`000?oooooooooo00kooooo000Kooooo`03o`000?oooooooooo04gooooo0ooo0002
ooooo`?oo`003oooool00ol0003oooooooooo`0>ooooo`;oo`000oooool2ool004oooooo00?o0000
ooooooooool0:oooool2o`0005Cooooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`?o
o`0000?oooooool00?ooool00ooo00000oooooooo`00ooooo`0Cooooob_oo`00027oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool00_oo0004ooooo`;o00004?ooool001_ooooo0_l0001>ooooo`?oo`000_ooool3ool000oooooo
00?o0000ooooooooool03_ooool2ool000?ooooo0_oo001?ooooo`03o`000?oooooooooo02;ooooo
1Ol00004ooooo`03o`000?oooooooooo05?ooooo00Soo`00oooooooo003oooooool00?ooooooo`00
ooooo`?oo`0000?oooooool00?ooool01Ooo000Dooooob_oo`00027oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0005
ooooo`03o`000?oooooooooo00kooooo000Kooooo`03o`000?oooooooooo04gooooo0ooo0002oooo
o`?oo`003oooool00ol0003oooooooooo`0>ooooo`;oo`000oooool2ool004oooooo00?o0000oooo
ooooool08oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05?ooooo00Soo`00
oooooooo003oooooool00?ooooooo`00ooooo`_oo`005?ooool[ool0000Qoooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00;o
o`001Oooool00ol0003oooooooooo`0>ooooo`005?ooool3o`0000Cooooo00?o0000ooooooooool0
COooool3ool000;ooooo0ooo000?ooooo`03o`000?oooooooooo00kooooo0_oo0003ooooo`;oo`00
Coooool00ol0003oooooooooo`0Looooo`Go00000oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo05?ooooo00Coo`00oooooooo003ooooo3ooo000Dooooob_oo`00027oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool00_oo0005ooooo`03o`000?oooooooooo00kooooo000Eooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0C_ooool2ool000;ooooo0ooo000?ooooo`03o`000?oooooooooo00kooooo
0_oo0003ooooo`;oo`00Coooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo
0_l0001Dooooo`?oo`0000?oooooool00?oo00003Ooo000Dooooob_oo`0001_oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooool00ooo00000oooooooo`00ooooo`02ool0
00Cooooo0_l0000@ooooo`005Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04ko
oooo0_oo0002ooooo`?oo`003oooool00ol0003oooooooooo`0>ooooo`;oo`000oooool2ool004oo
oooo00?o0000ooooooooool08_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0Doooool3ool00003oooooooo003oo`0000goo`005?ooool[ool0000Ioooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooo`05ool00003oooooooo003ooooo00;oo`001Oooool0
0ol0003oooooooooo`0>ooooo`005Oooool00ol0003oooooooooo`03ooooo`?o0000C_ooool2ool0
00;ooooo0ooo000?ooooo`03o`000?oooooooooo00kooooo0_oo0003ooooo`;oo`00C_ooool2o`00
02Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05?ooooo0ooo0000
0oooooooo`00ool0000=ool001Cooooo:ooo00006Oooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool02_oo0005ooooo`03o`000?oooooooooo00kooooo000Eooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0C_ooool2ool000;ooooo00?oo`00ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`04ool00?ooooooooooooooo`;oo`00Coooool00ol0003ooooooooo
o`0Sooooo`?o00001Oooool00ol0003oooooooooo`1Coooooa?oo`005?ooool[ool0000Goooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooool03?oo0005ooooo`03o`000?oooooooooo00kooooo000D
ooooo`;o00001Oooool00ol0003oooooooooo`1>ooooo`;oo`000_ooool00ooo003oooooooooo`0?
ooooo`03o`000?oooooooooo00oooooo00Coo`00oooooooooooooooo0_oo001?ooooo`03o`000?oo
oooooooo02_ooooo0_l0001CoooooaCoo`005?ooool[ool0000Eoooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
oooo00koo`001?ooool2o`00013ooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0C_ooool2ool000;ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0?oooo
o`04ool00?ooooooooooooooo`;oo`00Coooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo05;ooooo5?oo000Dooooob_oo`0000goooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003ooooo01Koo`001Oooool00ol0003oooooooooo`0>ooooo`006oooool2o`00
053ooooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0?ooooo`05ool00?oooooo
oooooooooooo0000D?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo05;ooooo5?oo
000Dooooob_oo`0000goooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003ooooo01Koo`001Oooool00ol0003oooooooooo`0>ooooo`006oooool00ol0003oooooooooo`1?
ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool03oooool01Ooo003ooooooooo
ooooooooo`00053ooooo00?o0000ooooooooool0:oooool2o`0005?ooooo5?oo000DooooobSoo`00
00Soooooool00?oo003oooooool00?ooooooo`00ooooo`Goo`0000?oooooool00?oo00005_oo0004
ooooo`;o00004?ooool001_ooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000A
ooooo`03o`000?oooooooooo00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0D_oooolDool001Cooooo:?oo00000oooooooo`00ool0
0004ool00003oooooooo003oo`0001coo`001Oooool00ol0003oooooooooo`0>ooooo`006oooool0
0ol0003oooooooooo`1?ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool03ooo
ool01Ooo003oooooooooooooooooo`00053ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`1BoooooaCoo`005?ooool:ool00003oooooooo003ooooo01_oo`0000?oooooool00?oo0000
8ooo0005ooooo`03o`000?oooooooooo00kooooo000Kooooo`03o`000?oooooooooo04oooooo00Co
o`00ooooooooooooo`004Oooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo
0000D?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo05;ooooo5?oo000Dooooo`[o
o`0000?oooooool00?ooool04Ooo00000oooooooo`00ooooo`05ool00003oooooooo003ooooo02Go
o`001Oooool00ol0003oooooooooo`0>ooooo`006oooool2o`00053ooooo00Coo`00oooooooooooo
o`004Oooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000D?ooool00ol0
003oooooooooo`0[ooooo`;o0000DooooolDool001Cooooo1_oo00001oooooooo`00ool00?oo003o
ooooool00?ooool04Ooo00001Oooooooo`00oooooooo003ooooo00?oo`0000?oooooool00?ooool0
9Ooo0004ooooo`;o00004?ooool001_ooooo00?o0000ooooooooool0Coooool01?oo003ooooooooo
oooo000Aooooo`03o`000?oooooooooo00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0D_oooolDool001Cooooo0_oo00001Ooooooo
o`00ool00?oo003ooooo00?oo`0000?oooooool00?ooool03ooo00003Oooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooool09Ooo0005ooooo`03o`000?oooooooooo
00kooooo000Kooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Oooool00ol0
003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000D?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo05;ooooo5?oo000Dooooo`;oo`0000Goooooool00?oo003oo`00oooo
o`03ool00003oooooooo003ooooo00goo`0000ooooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooool09Ooo0005ooooo`03o`000?oooooooooo00kooooo
000Kooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Oooool00ol0003ooooo
ooooo`0?ooooo`05ool00?oooooooooooooooooo0000D?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo05;ooooo5?oo000Dooooo`;oo`0000Goooooool00?oo003oo`00ooooo`03ool0
0003oooooooo003ooooo00_oo`00017oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`0Uool000Gooooo00?o0000ooooooooool03_oo
ool001_ooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oo
oooooooo00oooooo00Goo`00ooooooooooooooooool0001@ooooo`03o`000?oooooooooo02_ooooo
0_l0001CoooooaCoo`005?ooool2ool00005oooooooo003oo`00ool00?ooool00ooo00000ooooooo
o`00ooooo`05ool0000Goooooooo003oo`00ool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool09Ooo0004ooooo`;o
00004?ooool001_ooooo0_l0001@ooooo`04ool00?ooooooooooool0017ooooo00?o0000oooooooo
ool03oooool01Ooo003oooooooooooooooooo`00053ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`1BoooooaCoo`005?ooool2ool00005oooooooo003oo`00ool00?ooool00ooo0000
7oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooool09Ooo0005ooooo`03o`000?oooooooooo00kooooo000Kooooo`03o`000?oooooooooo04oo
oooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooo
oooooooo0000D?ooool00ol0003oooooooooo`0Sooooo`?o00001Oooool00ol0003oooooooooo`1B
oooooaCoo`005?ooool2ool00005oooooooo003oo`00ool00?ooool00ooo00007oooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool09Ooo0005
ooooo`03o`000?oooooooooo00kooooo000Kooooo`03o`000?oooooooooo04oooooo00Coo`00oooo
ooooooooo`004Oooool00ol0003oooooooooo`0?ooooo`04ool00?ooooooooooool0057ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05;ooooo5?oo
000Dooooo`;oo`0002Ooooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool09Ooo0005oooo
o`03o`000?oooooooooo00kooooo000Kooooo`03o`000?oooooooooo04oooooo00Coo`00oooooooo
ooooo`004Oooool00ol0003oooooooooo`0?ooooo`04ool00?ooooooooooool0057ooooo00?o0000
ooooooooool07?ooool5o`0000?ooooo00?o0000ooooooooool01?ooool2o`0005?ooooo5?oo000C
ooooo`0Zool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo9?oo0005
ooooo`;o00004?ooool001_ooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000A
ooooo`03o`000?oooooooooo00oooooo00Coo`00ooooooooooooo`00DOooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0D_oooolBool00003oooooooo
003ooooo01;ooooo02[oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
oolTool000Kooooo00?o0000ooooooooool03_ooool001_ooooo0_l0001@ooooo`04ool00?oooooo
ooooool0017ooooo00?o0000ooooooooool03oooool01?oo003ooooooooooooo001Aooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Booooo`coo`00
00?oooooool00?ooool00ooo00000oooooooo`00ooooo`0Booooo`0Zool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo8_oo00000oooooooo`00ooooo`05ooooo`03o`00
0?oooooooooo00kooooo000Kooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`00
4Oooool00ol0003oooooooooo`0?ooooo`04ool00?ooooooooooool0057ooooo00?o0000oooooooo
ool08oooool2o`0000Kooooo00?o0000ooooooooool0D_ooool6ool00003oooooooo003ooooo00?o
o`0000?oooooool00?ooool00ooo00000oooooooo`00ooooo`0Booooo`0Zool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003ooooo8_oo00000oooooooo`00ooooo`05ooooo`03
o`000?oooooooooo00kooooo000Cooooo`Go00000oooool00ol0003oooooooooo`1?ooooo`04ool0
0?ooooooooooool0017ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool01?ooool2o`0005?ooooo1_oo00000ooooooo
o`00ooooo`03ool00003oooooooo003ooooo00?oo`0000?oooooool00?ooool04_ooool0:_oo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooob;oo`0000?oooooool00?oo
ool01?ooool2o`00013ooooo000Dooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo00?oo`00oooo
oooo0000DOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo05;ooooo1_oo00000ooo
ooooo`00ooooo`03ool00003oooooooo003ooooo00?oo`0000?oooooool00?ooool04_ooool0:_oo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooob;oo`0000?oooooool0
0?ooool01Oooool00ol0003oooooooooo`0>ooooo`005Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0@oooo
o`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Boooo
o`Koo`0000?oooooool00?ooool00ooo00000oooooooo`00ooooo`03ool00003oooooooo003ooooo
01;ooooo02[oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooolRool0
0003oooooooo003ooooo00Gooooo00?o0000ooooooooool03_ooool001Kooooo00?o0000oooooooo
ool00_ooool3o`0004oooooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0@oooo
o`03ool00?ooooooo`00053ooooo0_l0000]ooooo`03o`000?oooooooooo05;ooooo1_oo00000ooo
ooooo`00ooooo`03ool00003oooooooo003ooooo00?oo`0000?oooooool00?ooool04_ooool0:_oo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooob;oo`0000?oooooool0
0?ooool01Oooool00ol0003oooooooooo`0>ooooo`004oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooo
oooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0[ooooo`;o0000Doooool6
ool00003oooooooo003ooooo00?oo`0000?oooooool00?ooool00ooo00000oooooooo`00ooooo`0B
ooooo`0Zool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo8_oo0000
0oooooooo`00ooooo`04ooooo`;o00004?ooool001?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Oooool00ol0003ooooooooo
o`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1Booooo`Koo`0000?oooooool00?ooool00ooo00002?ooooooo`00oooooooo003oooooool00?oo
ooooo`004oooool0:_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
ob;oo`0000?oooooool00?ooool01Oooool00ol0003oooooooooo`0>ooooo`005?ooool3o`0000Co
oooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo
013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
05;ooooo1_oo00003_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`004oooool0:_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooacoo`0000?oooooool00?oo00000ooo00000oooooooo`00ooooo`05ooooo`03o`000?oooooo
oooo00kooooo000Kooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Oooool0
0ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`1Booooo`;oo`0001;oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Cooooo`0Zool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003ooooo5_oo00001oooooooo`00ool00?oo003ooooo
ool00?ooool00ooo00001?ooooooo`00oooooooo0006ooooo`03o`000?oooooooooo00kooooo000K
ooooo`;o0000D?ooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo00?o
o`00oooooooo0000DOooool00ol0003oooooooooo`0[ooooo`;o0000Doooool2ool0000Boooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`004oooool0:_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oaKoo`0000Ooooooool00?oo003oo`00oooooooo003ooooo00?oo`0000Coooooool00?ooooooo`00
1Oooool2o`00013ooooo000Kooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`00
4Oooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`1Aooooo`0Eool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001?ooooo02[o
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooolFool00007oooooooo
003oooooool00?ooooooo`00ooooo`03ool00004oooooooo003oooooool000Kooooo00?o0000oooo
ooooool03_ooool001_ooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000Aoooo
o`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo057ooooo01Goo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00004oooool0:_oo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooa3oo`0001Coooooool00?oo
003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool000Kooooo00?o0000ooooooooool03_ooool001_ooooo00?o0000ooooooooool0Cooo
ool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000
DOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo057ooooo01Goo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo00004oooool0:_oo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00ooooo`[oo`0000Ooooooool00?ooooooo`00oooooooo003ooooo00?oo`00013oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`001_ooool0
0ol0003oooooooooo`0>ooooo`006oooool00ol0003oooooooooo`1?ooooo`04ool00?oooooooooo
ool0017ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooo
oooo02_ooooo0_l0001Booooo`0Eool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001?ooooo02[oo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool6ool0000;oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooool00ooo00004?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0005ooooo`;o00004?ooool0
01_ooooo0_l0001@ooooo`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool04?ooool0
0ooo003oooooool0001Aooooo`03o`000?oooooooooo02Cooooo0_l00005ooooo`03o`000?oooooo
oooo057ooooo01Goo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo00004oooool0:_oo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`Koo`0001koooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0006ooooo`03o`000?oooooooooo00ko
oooo000Kooooo`03o`000?oooooooooo04oooooo00Coo`00ooooooooooooo`004Oooool00ol0003o
ooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool08oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo057ooooo01Goo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
00004oooool0:_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Ko
o`0001koooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo0006ooooo`03o`000?oooooooooo00kooooo000Kooooo`03o`000?oooooooooo04oooooo00Co
o`00ooooooooooooo`004Oooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo
00?o0000ooooooooool08oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo057o
oooo01Goo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo00004oooool0:_oo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00ooooo`Coo`00023oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000Kooooo00?o0000ooooooooool0
3_ooool001_ooooo00?o0000ooooooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`00
0?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Sooooo`04o`00
0?ooooooooooo`0000Cooooo1ol000000ooo003o0000ool00003o`00000;ool00?l0003oo`00o`00
0?oo003o0000ool00?l0003oo`00o`000?oo00000ol000002ooo003o0000ool00?l0003oo`00o`00
0?oo003o0000ool00?l0003oo`0000?o000000_oo`00o`000?oo003o0000ool00?l0003oo`00o`00
0?oo003o0000ool00002o`00000;ool00?l0003oo`00o`000?oo003o0000ool00?l0003oo`00o`00
0?oo00000ol000004Ooo003o0000ool00?l0003oo`00o`000?oo003o0000ool00?l0003oo`00o`00
0?oo003o0000ool00?l0003oo`00017o000001Ooo`00o`000?oo003o0000ool00?l0003oo`00o`00
0?oo003o0000ool00?l0003oo`00o`000?oo003o0000ool00?l0003oo`00o`000?oo003o0000ool0
0003o`000003ool00?l0003oo`0000oo000000?oo`00o`000?oo00004_l000001Ooo003o0000o`00
0?l0003oo`0000Wo000000?oo`00o`000?l000001ol000000ooo003o0000o`00000?o`00013ooooo
000Kooooo`;o0000D?ooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo
00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Sooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01?ooool0:_oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00ooooo`Coo`00023oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool001?ooooo01Goo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000
Doooool00ol0003oooooooooo`0>ooooo`006oooool00ol0003oooooooooo`1?ooooo`04ool00?oo
ooooooooool0017ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`00
0?oooooooooo02?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`0V
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooool8ool0000Poooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Cooooo`0Eool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`0005?ooooo00?o0000ooooooooool03_ooool001_ooooo00?o0000oooo
ooooool0Coooool01?oo003ooooooooooooo000Aooooo`03o`000?oooooooooo013ooooo00?oo`00
oooooooo0000DOooool00ol0003oooooooooo`0Tooooo`;o00001Oooool00ol0003oooooooooo`04
ooooo`0Rool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ooooo`coo`00023oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool001?ooooo01Goo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo0000Doooool00ol0003oooooooooo`0>ooooo`006oooool00ol0003oooooooooo`1?oooo
o`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001A
ooooo`03o`000?oooooooooo02_ooooo0_l00005ooooo`0Jool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooool5ool00003oooooooo003oo`0000coo`00023oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool001?ooooo
01;oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooool2ool005?ooooo0_l0000@ooooo`006oooool00ol0003oooooooooo`1?oooo
o`04ool00?ooooooooooool0017ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001A
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01?ooool06_oo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo5?oo00008?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`004oooool04_oo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooo`;oo`00E?ooool00ol0003oooooooooo`0>ooooo`006oooool2o`00053ooooo00Coo`00oooo
ooooooooo`004Oooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`04ooooo`0Bool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0ooo00001Ooooooo
o`00ool00?oo003ooooo01Coo`00023oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool001?ooooo01;oo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool005Cooooo
00?o0000ooooooooool03_ooool001_ooooo00?o0000ooooooooool0Coooool01?oo003ooooooooo
oooo000Aooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003ooooo
ooooo`0[ooooo`;o00001Oooool04_oo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooo`?oo`0000Goooooool00?oo003oo`00oooo
o`0Dool0000Poooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo000Cooooo`0Bool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo001Cooooo`;o00004?ooool001_o
oooo00?o0000ooooooooool0D?ooool00ooo003oooooool0000Aooooo`03o`000?oooooooooo013o
oooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Co
oooo00koo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
o`?oo`0000?oooooool00?oo00006_oo00008?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`004oooool04_oo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`00
E?ooool00ol0003oooooooooo`0>ooooo`005?ooool3o`0000Cooooo00?o0000ooooooooool0D?oo
ool00ooo003oooooool0000Aooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOoo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Cooooo00Koo`00oooooooo003ooooo
ool00?ooool3ool00005oooooooo003oo`00ool00?ooool08?oo00008?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`004oooool04_oo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00ooooo`;oo`00E?ooool00ol0003oooooooooo`0>ooooo`004oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool0D?ooool00ooo003oooooool0000Aooooo`03o`00
0?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00Cooooo00Koo`00oooooooo003oooooool00?ooool3ool00005oooooooo003oo`00
ool00?ooool08?oo00008?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`004oooool04_oo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`00E?ooool00ol0003o
ooooooooo`0>ooooo`005oooool01?l0003oooooooooooooool3o`00053ooooo00?oo`00oooooooo
00004Oooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00053ooooo0_l0000]ooooo`;o
00001Oooool01?oo003oooooool00?oooolZool0000Poooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Cooooo`0Bool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
0_oo001Cooooo`;o00004?ooool001Gooooo0_l00004ooooo`03o`000?oooooooooo053ooooo00?o
o`00oooooooo00004Oooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`04ooooo`?oo`0000?oooooool00?oo0000:?oo
00008?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`004oooool04_oo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`00E?ooool00ol0003oooooooooo`0>oooo
o`005oooool01Ol0003ooooooooooooooooo000005;ooooo00?oo`00oooooooo00004Oooool00ol0
003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`04ooooo`?oo`0000?oooooool00?oo0000:?oo00008?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`004oooool00ooo
003oooooool00002ool00005oooooooo003oooooool00?ooool00ooo00001Oooooooo`00oooooooo
003ooooo00;oo`00E?ooool00ol0003oooooooooo`0>ooooo`004oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0D?ooool00ooo003oooooool0000Aooooo`03o`000?oo
oooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00?ooooo;ooo00008?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`004oooool00ooo003oooooool00002ool00005oooooooo
003oooooool00?ooool00ooo00001Oooooooo`00oooooooo003ooooo00;oo`00E?ooool00ol0003o
ooooooooo`0>ooooo`005?ooool3o`0000Cooooo00?o0000ooooooooool0D?ooool00ooo003ooooo
ool0000Aooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003ooooo
ooooo`0[ooooo`;o00001?ooool_ool0000Poooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo000Cooooo`03ool00?ooooooo`0000;oo`00
00Goooooool00?ooooooo`00ooooo`03ool00003oooooooo003ooooo00Coo`00Doooool2o`00013o
oooo000Kooooo`;o0000DOooool00ooo003oooooool0000Aooooo`03o`000?oooooooooo013ooooo
00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00?ooooo
;ooo00007Oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
oooo00;oo`005?ooool00ooo003oooooool00002ool00003oooooooo003oo`0000Goo`0000?ooooo
ool00?oo00001?oo001Dooooo`03o`000?oooooooooo00kooooo000Kooooo`03o`000?oooooooooo
053ooooo00?oo`00oooooooo00004Oooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00
057ooooo00?o0000ooooooooool08oooool3o`0000Gooooo00?o0000ooooooooool00oooool_ool0
000Moooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool0
0_oo000Dooooo`03ool00?ooooooo`0000;oo`0000?oooooool00?oo00003?oo001Dooooo`03o`00
0?oooooooooo00kooooo000Kooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oo
oooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool_ool0000Moooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo000Dooooo`03ool00?ooooooo`00
00;oo`0000?oooooool00?oo00003?oo001Dooooo`03o`000?oooooooooo00kooooo000Kooooo`03
o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo
0000DOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Cooooo0_l00004oooooboo
o`0001goooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
o`02ool001Cooooo1Ooo00000oooooooo`00ool0000<ool005?ooooo0_l0000@ooooo`006oooool0
0ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooo
o`00057ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo;ooo00006oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooo`04ool001Cooooo5?oo001Dooooo`03o`000?oooooooooo00kooooo000Kooooo`;o0000DOoo
ool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooobooo`0001_o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo000DoooooaCo
o`00E?ooool00ol0003oooooooooo`0>ooooo`006oooool00ol0003oooooooooo`1@ooooo`;oo`00
4_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0
8oooool2o`0000Kooooo00?o0000ooooooooool00oooool_ool0000Koooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo00Coo`005?oooolDool005Cooooo00?o0000oooo
ooooool03_ooool001_ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000oooooooo
ool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01?ooool2o`0000Cooooo;ooo00006oooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00ooooo`04ool001Cooooo5?oo001Cooooo`;o00004?ooool001_ooooo00?o0000oooo
ooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00oooool_ool0000Koooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00Coo`005?oooolDool005Cooooo00?o
0000ooooooooool03_ooool001_ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000
ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool00oooool_ool0000Koooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003ooooo00Coo`005?oooolDool005Cooooo00?o0000ooooooooool03_ooool001_ooooo0_l0
001Aooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`03ooooobooo`00017oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`07ool00003
oooooooo003oo`0000Coo`005?oooolDool005Cooooo00?o0000ooooooooool03_ooool001_ooooo
00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003ooooo
ool0001Aooooo`03o`000?oooooooooo02_ooooo0_l00004ooooob;oo`0000?oooooool00?oo0000
2_oo00004Oooooooo`00ool00?oo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003ooooo00koo`005?oooolDool005?ooooo0_l0000@ooooo`006oooool00ol0003o
ooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`03ooooob3oo`0000?oooooool00?oo
ool03?oo00003oooooooo`00ool00?oo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00ooooo`0@ool001Cooooo5?oo001Dooooo`03o`000?oooooooooo00kooooo000Kooooo`03
o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo
0000DOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00?ooooo7_oo00001Ooooooo
o`00oooooooo003ooooo00coo`0000ooooooool00?oo003oo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooool04?oo000DoooooaCoo`00E?ooool00ol0003oooooooooo`0>
ooooo`006oooool2o`00057ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo00?oo`00oooo
oooo0000DOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00?ooooo7?oo00001ooo
ooooo`00oooooooo003oooooool00?ooool03?oo00003Oooooooo`00ool00?oo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooool04_oo000DoooooaCoo`00E?ooool00ol0003ooooooooo
o`0>ooooo`006oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@
ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0:oooool2o`0000Cooooo6?oo0000
2oooooooo`00ool00?oo003oooooool00?ooooooo`00oooooooo003ooooo00coo`0000Woooooool0
0?oo003oo`00oooooooo003oooooool00?ooool00ooo00000oooooooo`00ool0000@ool001Cooooo
5?oo001Cooooo`;o00004?ooool001_ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o
0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool00ooooolHool0000;oooooooo003oo`00ool00?ooooooo`00oooooooo003ooooo
ool00?ooool02ooo00000oooooooo`00ool00002ool00005oooooooo003oooooool00?ooool05_oo
000DoooooaCoo`00E?ooool00ol0003oooooooooo`0>ooooo`005Oooool3o`0000?ooooo00?o0000
ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001A
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00ooooolHool0000;oooooooo003o
o`00ool00?ooooooo`00oooooooo003oooooool00?ooool02Ooo00000oooooooo`00ooooo`04ool0
0003oooooooo003ooooo01Soo`005?oooolDool005Cooooo00?o0000ooooooooool03_ooool001Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003o
ooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`03oooooaSoo`0000_oooooool00?oo003oo`00oooooooo003oooooool00?ooooooo`00
ooooo`09ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool06?oo000DoooooaCoo`00
E?ooool00ol0003oooooooooo`0>ooooo`004oooool5o`0000?ooooo0ol0001@ooooo`;oo`004_oo
ool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00053ooooo0_l0000]ooooo`;o00001?oo
oolHool0000=oooooooo003oo`00ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
o`07ool00003oooooooo003ooooo00Coo`0000?oooooool00?oo00006?oo000Doooooa?oo`00E?oo
ool2o`00013ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0D?oo
ool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oo
oooooooo02;ooooo1Ol00004ooooo`03o`000?oooooooooo00?ooooo0_oo00000oooooooo`00ool0
000;ool00003oooooooo003oo`0000Goo`0000goooooool00?oo003oo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003ooooo00Ooo`0000?oooooool00?ooool01?oo00000oooooooo`00ool0
000Hool001Cooooo4ooo001Eooooo`03o`000?oooooooooo00kooooo000Dooooo`03o`000?oooooo
000000Cooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool0
0ooo003oooooool0001Aooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`03ooooo`;oo`0000?oooooool00?oo00000ooo00000oooooooo`00ool0
0005ool00003oooooooo003oo`0000Goo`0000goooooool00?oo003oo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003ooooo00Ooo`0000?oooooool00?ooool07ooo000Doooooa?oo`00EOoo
ool00ol0003oooooooooo`0>ooooo`005Oooool2o`0000Cooooo00?o0000ooooooooool0D?ooool2
ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`;oo`0000?ooooo
ool00?oo00000ooo00001Oooooooo`00oooooooo003ooooo00?oo`0000?oooooool00?oo00001Ooo
00003Oooooooo`00ool00?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool01ooo
00000oooooooo`00ooooo`0Oool001Cooooo4ooo001Eooooo`03o`000?oooooooooo00kooooo000F
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000
ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00oooool2o`0000?ooooo00Coo`00oooooooo003ooooo1Ooo00001Oooooooo`00oooo
oooo003ooooo00?oo`0000?oooooool00?oo00001Ooo00003Oooooooo`00ool00?oo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooool01ooo00000oooooooo`00ooooo`0Oool001Cooooo
4ooo001Dooooo`;o00004?ooool001_ooooo0_l0001Aooooo`;oo`004_ooool00ol0003ooooooooo
o`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool08_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool00_ooool01?oo003oooooool00?ooool5ool00005
oooooooo003oooooool00?ooool00ooo00000oooooooo`00ool00005ool0000Goooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooool07ooo000Doooooa?oo`00EOooool00ol0003oooooooooo`0>oooo
o`006oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03
ool00?ooooooo`00057ooooo00?o0000ooooooooool08_ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool00_ooool01?oo003oooooool00?ooool5ool00005oooooooo003o
ooooool00?ooool00ooo00000oooooooo`00ool00005ool0000Goooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool07ooo000Doooooa?oo`00EOooool00ol0003oooooooooo`0>ooooo`006oooool0
0ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooo
o`00057ooooo00?o0000ooooooooool08oooool3o`0000Gooooo00?o0000ooooooooool00_ooool0
1?oo003oooooool00?ooool5ool00005oooooooo003oooooool00?ooool00ooo00007oooooooo`00
ool00?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool07ooo
000Dooooo`03ool00?ooooooo`00013oo`00EOooool00ol0003oooooooooo`0>ooooo`006oooool0
0ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooo
o`00057ooooo00?o0000ooooooooool0:oooool2o`0000?ooooo00Coo`00oooooooo003ooooo1Ooo
00001Oooooooo`00oooooooo003ooooo00?oo`0001ooooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003ooooo01ooo`005?ooool00ooo003oooooool0
000>ool00003oooooooo003ooooo05?ooooo0_l0000@ooooo`006oooool00ol0003oooooooooo`1@
ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`02ooooo`04ool00?ooooooo`00ooooo`Goo`0000Go
ooooool00?ooooooo`00ooooo`03ool0000Ooooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`0Oool001Cooooo00?oo`00oooooooo00003?oo
00001?ooooooo`00oooooooo001Eooooo`03o`000?oooooooooo00kooooo000Kooooo`;o0000DOoo
ool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool00_ooool01_oo003oooooool00?ooooooo`00ooooo`?o
o`0002Ooooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool07ooo000Dooooo`03ool00?oo
ooooo`0000[oo`0000Koooooool00?ooooooo`00oooooooo001Eooooo`03o`000?oooooooooo00ko
oooo000Kooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo
00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0[ooooo`;o00000oooool0<?oo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooaooo`005?ooool00ooo003oooooool00004ool00003oooooooo003oo`0000?oo`0000Kooooo
ool00?ooooooo`00oooooooo001Dooooo`;o00004?ooool001_ooooo00?o0000ooooooooool0D?oo
ool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool00_ooool0<?oo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooaooo`005?ooool00ooo
003oooooool00004ool0000<oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00EOooool00ol0003oooooooooo`0>ooooo`006oooool00ol0003oooooooooo`1@ooooo`;o
o`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`02ooooo`0`ool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo7ooo000Dooooo`03ool00?oo
ooooo`0000;oo`0000koooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool005Gooooo00?o0000ooooooooool03_ooool001_ooooo00?o0000ooooooooool0D?oo
ool2ool001;ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool00_ooool0<?oo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooaooo`005?ooool04ooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo0000EOooool00ol0003oooooooooo`0>ooooo`006oooool2o`00057ooooo0_oo
000Booooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0D?ooool00ol0003ooooooooo
o`0[ooooo`;o00000oooool0<?oo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooaooo`005?ooool04ooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000
E?ooool2o`00013ooooo000Kooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oo
oooooooo017ooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00;ooooo033oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?oooolLool00003oooooooo003oo`0001Cooooo01?oo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`0005Gooooo00?o0000ooooooooool03_ooool001_ooooo00?o0000ooooooooool0D?oo
ool2ool001;ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool00_ooool0<?oo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooa[oo`0000?oooooool0
0?ooool00_oo000Dooooo`0Cool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool0001Eooooo`03o`000?oooooooooo00kooooo
000Kooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo017ooooo00?o
o`00ooooooooool0D?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo033o
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?oooolBool00005oooooooo003oooooool00?ooool00ooo00000oooooooo`00ooooo`02
ool001Cooooo01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`0005Gooooo00?o0000ooooooooool03_ooool001_ooooo
00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04Oooool00ooo003ooooo
ooooo`1@ooooo`03o`000?oooooooooo02_ooooo0_l00003ooooo`0`ool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo4_oo0000
2oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00;oo`005?ooool04ooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo0000E?ooool2o`00013ooooo000Kooooo`;o0000DOooool2ool001;ooooo00?o
0000ooooooooool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool00_ooool0<?oo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooa3oo`0000goooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo00;oo`005?ooool04ooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000
EOooool00ol0003oooooooooo`0>ooooo`006oooool00ol0003oooooooooo`1@ooooo`;oo`004_oo
ool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool08ooo
ool3o`0000Gooooo00?o0000ooooooooool00_ooool0<?oo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooa3oo`0000koooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool001Gooooo01?oo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`0005Gooooo00?o0000ooooooooool03_ooool001Cooooo0ol00004ooooo`03o`00
0?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0
D?ooool00ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`02ooooo`0`ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003ooooo4?oo00003_ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`005Oooool04ooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000EOooool0
0ol0003oooooooooo`0>ooooo`004oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool0DOooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?oo`00
ooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo0_l00003
ooooo`0`ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003ooooo2?oo00000oooooooo`00ool00005ool0000>oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Eooooo`0Cool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool0001Dooooo`;o00004?ooool001Oooooo00Co0000oooooooooooooooo0ol0001Aooooo`03ool0
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1?ooooo`;o0000
9_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool0<?oo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Soo`0001Kooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`005Oooool04ooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000EOooool00ol0003o
ooooooooo`0>ooooo`005oooool01Ol0003ooooooooooooooooo000005?ooooo00?oo`00oooooooo
ool04?ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo053ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo033oo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool8ool0000Foooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool001Gooooo01?oo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
05Gooooo00?o0000ooooooooool03_ooool001?ooooo1?l00004ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02;o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?oo`00oooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000Wooooo00?oo`00oooooooo00001Oooool0
2Ooo003oooooooooooooooooo`00oooooooo003oooooool00003ooooo`03ool00?oooooooooo00Go
oooo0_oo00000oooooooo`00ooooo`06ooooo`07ool00?ooooooo`00oooooooo003oooooool00003
ooooo`05ool00?oooooooooooooooooo00006Oooool00ooo003oooooooooo`05ooooo`05ool00?oo
ooooo`00oooooooo00001Oooool00ooo003oooooooooo`1Cooooo`03o`000?oooooooooo00kooooo
000Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Sooooo`?o00001Oooool2o`0006Kooooo00?o0000ooooooooool0I?ooool2o`00013ooooo000C
ooooo`Go00000oooooo?o`0002gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>
ooooo`00oooooolHooooom7o00004?ooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {147.312, 0}} -> {-0.0551454, -0.0147182, \
0.00419541, 0.00419541}, {{13.125, 240.125}, {143.75, 3.5}} -> {-6.67303, \
-0.74978, 0.0509978, 0.0412727}, {{262.812, 489.812}, {143.75, 3.5}} -> \
{-19.3474, -4.07637, 0.0504429, 0.0512823}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Example #1c: 1Hz cosine (longer sampling length, \
discrete-time)\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["Sampled sequence", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := Cos[2  \[Pi]\ t];\)\), "\n", 
    \(xd = \ sampler[x, fs = 10, \ {0, 20}]; \ 
    If[OddQ[Length[xd]], \ xd\  = \ Drop[xd, \(-1\)]];\), "\n", 
    \(\(DiscreteListPlot2[xd, \ Blue, \ Frame \[Rule] True, 
        Axes \[Rule] {True, False}, \ AspectRatio \[Rule] 1/3, 
        ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00478583 0.166667 0.15873 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2631 -0.0125 -6 -9 ]
[.2631 -0.0125 6 0 ]
[.50239 -0.0125 -9 -9 ]
[.50239 -0.0125 9 0 ]
[.74168 -0.0125 -9 -9 ]
[.74168 -0.0125 9 0 ]
[.98098 -0.0125 -9 -9 ]
[.98098 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -12 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .0873 -24 -4.5 ]
[-0.0125 .0873 0 4.5 ]
[-0.0125 .16667 -6 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .24603 -18 -4.5 ]
[-0.0125 .24603 0 4.5 ]
[-0.0125 .3254 -6 -4.5 ]
[-0.0125 .3254 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2631 0 m
.2631 .00625 L
s
[(50)] .2631 -0.0125 0 1 Mshowa
.50239 0 m
.50239 .00625 L
s
[(100)] .50239 -0.0125 0 1 Mshowa
.74168 0 m
.74168 .00625 L
s
[(150)] .74168 -0.0125 0 1 Mshowa
.98098 0 m
.98098 .00625 L
s
[(200)] .98098 -0.0125 0 1 Mshowa
.125 Mabswid
.07167 0 m
.07167 .00375 L
s
.11953 0 m
.11953 .00375 L
s
.16738 0 m
.16738 .00375 L
s
.21524 0 m
.21524 .00375 L
s
.31096 0 m
.31096 .00375 L
s
.35882 0 m
.35882 .00375 L
s
.40668 0 m
.40668 .00375 L
s
.45453 0 m
.45453 .00375 L
s
.55025 0 m
.55025 .00375 L
s
.59811 0 m
.59811 .00375 L
s
.64597 0 m
.64597 .00375 L
s
.69383 0 m
.69383 .00375 L
s
.78954 0 m
.78954 .00375 L
s
.8374 0 m
.8374 .00375 L
s
.88526 0 m
.88526 .00375 L
s
.93312 0 m
.93312 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(-1)] -0.0125 .00794 1 0 Mshowa
0 .0873 m
.00625 .0873 L
s
[(-0.5)] -0.0125 .0873 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(0)] -0.0125 .16667 1 0 Mshowa
0 .24603 m
.00625 .24603 L
s
[(0.5)] -0.0125 .24603 1 0 Mshowa
0 .3254 m
.00625 .3254 L
s
[(1)] -0.0125 .3254 1 0 Mshowa
.125 Mabswid
0 .02381 m
.00375 .02381 L
s
0 .03968 m
.00375 .03968 L
s
0 .05556 m
.00375 .05556 L
s
0 .07143 m
.00375 .07143 L
s
0 .10317 m
.00375 .10317 L
s
0 .11905 m
.00375 .11905 L
s
0 .13492 m
.00375 .13492 L
s
0 .15079 m
.00375 .15079 L
s
0 .18254 m
.00375 .18254 L
s
0 .19841 m
.00375 .19841 L
s
0 .21429 m
.00375 .21429 L
s
0 .23016 m
.00375 .23016 L
s
0 .2619 m
.00375 .2619 L
s
0 .27778 m
.00375 .27778 L
s
0 .29365 m
.00375 .29365 L
s
0 .30952 m
.00375 .30952 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.2631 .32708 m
.2631 .33333 L
s
.50239 .32708 m
.50239 .33333 L
s
.74168 .32708 m
.74168 .33333 L
s
.98098 .32708 m
.98098 .33333 L
s
.125 Mabswid
.07167 .32958 m
.07167 .33333 L
s
.11953 .32958 m
.11953 .33333 L
s
.16738 .32958 m
.16738 .33333 L
s
.21524 .32958 m
.21524 .33333 L
s
.31096 .32958 m
.31096 .33333 L
s
.35882 .32958 m
.35882 .33333 L
s
.40668 .32958 m
.40668 .33333 L
s
.45453 .32958 m
.45453 .33333 L
s
.55025 .32958 m
.55025 .33333 L
s
.59811 .32958 m
.59811 .33333 L
s
.64597 .32958 m
.64597 .33333 L
s
.69383 .32958 m
.69383 .33333 L
s
.78954 .32958 m
.78954 .33333 L
s
.8374 .32958 m
.8374 .33333 L
s
.88526 .32958 m
.88526 .33333 L
s
.93312 .32958 m
.93312 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .24603 m
1 .24603 L
s
.99375 .3254 m
1 .3254 L
s
.125 Mabswid
.99625 .02381 m
1 .02381 L
s
.99625 .03968 m
1 .03968 L
s
.99625 .05556 m
1 .05556 L
s
.99625 .07143 m
1 .07143 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .13492 m
1 .13492 L
s
.99625 .15079 m
1 .15079 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .19841 m
1 .19841 L
s
.99625 .21429 m
1 .21429 L
s
.99625 .23016 m
1 .23016 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .27778 m
1 .27778 L
s
.99625 .29365 m
1 .29365 L
s
.99625 .30952 m
1 .30952 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .16667 m
1 .16667 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .16667 m
.02381 .3254 L
s
.0286 .16667 m
.0286 .29508 L
s
.03338 .16667 m
.03338 .21572 L
s
.03817 .16667 m
.03817 .11762 L
s
.04295 .16667 m
.04295 .03825 L
s
.04774 .16667 m
.04774 .00794 L
s
.05252 .16667 m
.05252 .03825 L
s
.05731 .16667 m
.05731 .11762 L
s
.0621 .16667 m
.0621 .21572 L
s
.06688 .16667 m
.06688 .29508 L
s
.07167 .16667 m
.07167 .3254 L
s
.07645 .16667 m
.07645 .29508 L
s
.08124 .16667 m
.08124 .21572 L
s
.08603 .16667 m
.08603 .11762 L
s
.09081 .16667 m
.09081 .03825 L
s
.0956 .16667 m
.0956 .00794 L
s
.10038 .16667 m
.10038 .03825 L
s
.10517 .16667 m
.10517 .11762 L
s
.10995 .16667 m
.10995 .21572 L
s
.11474 .16667 m
.11474 .29508 L
s
.11953 .16667 m
.11953 .3254 L
s
.12431 .16667 m
.12431 .29508 L
s
.1291 .16667 m
.1291 .21572 L
s
.13388 .16667 m
.13388 .11762 L
s
.13867 .16667 m
.13867 .03825 L
s
.14346 .16667 m
.14346 .00794 L
s
.14824 .16667 m
.14824 .03825 L
s
.15303 .16667 m
.15303 .11762 L
s
.15781 .16667 m
.15781 .21572 L
s
.1626 .16667 m
.1626 .29508 L
s
.16738 .16667 m
.16738 .3254 L
s
.17217 .16667 m
.17217 .29508 L
s
.17696 .16667 m
.17696 .21572 L
s
.18174 .16667 m
.18174 .11762 L
s
.18653 .16667 m
.18653 .03825 L
s
.19131 .16667 m
.19131 .00794 L
s
.1961 .16667 m
.1961 .03825 L
s
.20089 .16667 m
.20089 .11762 L
s
.20567 .16667 m
.20567 .21572 L
s
.21046 .16667 m
.21046 .29508 L
s
.21524 .16667 m
.21524 .3254 L
s
.22003 .16667 m
.22003 .29508 L
s
.22481 .16667 m
.22481 .21572 L
s
.2296 .16667 m
.2296 .11762 L
s
.23439 .16667 m
.23439 .03825 L
s
.23917 .16667 m
.23917 .00794 L
s
.24396 .16667 m
.24396 .03825 L
s
.24874 .16667 m
.24874 .11762 L
s
.25353 .16667 m
.25353 .21572 L
s
.25832 .16667 m
.25832 .29508 L
s
.2631 .16667 m
.2631 .3254 L
s
.26789 .16667 m
.26789 .29508 L
s
.27267 .16667 m
.27267 .21572 L
s
.27746 .16667 m
.27746 .11762 L
s
.28224 .16667 m
.28224 .03825 L
s
.28703 .16667 m
.28703 .00794 L
s
.29182 .16667 m
.29182 .03825 L
s
.2966 .16667 m
.2966 .11762 L
s
.30139 .16667 m
.30139 .21572 L
s
.30617 .16667 m
.30617 .29508 L
s
.31096 .16667 m
.31096 .3254 L
s
.31575 .16667 m
.31575 .29508 L
s
.32053 .16667 m
.32053 .21572 L
s
.32532 .16667 m
.32532 .11762 L
s
.3301 .16667 m
.3301 .03825 L
s
.33489 .16667 m
.33489 .00794 L
s
.33967 .16667 m
.33967 .03825 L
s
.34446 .16667 m
.34446 .11762 L
s
.34925 .16667 m
.34925 .21572 L
s
.35403 .16667 m
.35403 .29508 L
s
.35882 .16667 m
.35882 .3254 L
s
.3636 .16667 m
.3636 .29508 L
s
.36839 .16667 m
.36839 .21572 L
s
.37318 .16667 m
.37318 .11762 L
s
.37796 .16667 m
.37796 .03825 L
s
.38275 .16667 m
.38275 .00794 L
s
.38753 .16667 m
.38753 .03825 L
s
.39232 .16667 m
.39232 .11762 L
s
.3971 .16667 m
.3971 .21572 L
s
.40189 .16667 m
.40189 .29508 L
s
.40668 .16667 m
.40668 .3254 L
s
.41146 .16667 m
.41146 .29508 L
s
.41625 .16667 m
.41625 .21572 L
s
.42103 .16667 m
.42103 .11762 L
s
.42582 .16667 m
.42582 .03825 L
s
.43061 .16667 m
.43061 .00794 L
s
.43539 .16667 m
.43539 .03825 L
s
.44018 .16667 m
.44018 .11762 L
s
.44496 .16667 m
.44496 .21572 L
s
.44975 .16667 m
.44975 .29508 L
s
.45453 .16667 m
.45453 .3254 L
s
.45932 .16667 m
.45932 .29508 L
s
.46411 .16667 m
.46411 .21572 L
s
.46889 .16667 m
.46889 .11762 L
s
.47368 .16667 m
.47368 .03825 L
s
.47846 .16667 m
.47846 .00794 L
s
.48325 .16667 m
.48325 .03825 L
s
.48804 .16667 m
.48804 .11762 L
s
.49282 .16667 m
.49282 .21572 L
s
.49761 .16667 m
.49761 .29508 L
s
.50239 .16667 m
.50239 .3254 L
s
.50718 .16667 m
.50718 .29508 L
s
.51196 .16667 m
.51196 .21572 L
s
.51675 .16667 m
.51675 .11762 L
s
.52154 .16667 m
.52154 .03825 L
s
.52632 .16667 m
.52632 .00794 L
s
.53111 .16667 m
.53111 .03825 L
s
.53589 .16667 m
.53589 .11762 L
s
.54068 .16667 m
.54068 .21572 L
s
.54547 .16667 m
.54547 .29508 L
s
.55025 .16667 m
.55025 .3254 L
s
.55504 .16667 m
.55504 .29508 L
s
.55982 .16667 m
.55982 .21572 L
s
.56461 .16667 m
.56461 .11762 L
s
.56939 .16667 m
.56939 .03825 L
s
.57418 .16667 m
.57418 .00794 L
s
.57897 .16667 m
.57897 .03825 L
s
.58375 .16667 m
.58375 .11762 L
s
.58854 .16667 m
.58854 .21572 L
s
.59332 .16667 m
.59332 .29508 L
s
.59811 .16667 m
.59811 .3254 L
s
.6029 .16667 m
.6029 .29508 L
s
.60768 .16667 m
.60768 .21572 L
s
.61247 .16667 m
.61247 .11762 L
s
.61725 .16667 m
.61725 .03825 L
s
.62204 .16667 m
.62204 .00794 L
s
.62682 .16667 m
.62682 .03825 L
s
.63161 .16667 m
.63161 .11762 L
s
.6364 .16667 m
.6364 .21572 L
s
.64118 .16667 m
.64118 .29508 L
s
.64597 .16667 m
.64597 .3254 L
s
.65075 .16667 m
.65075 .29508 L
s
.65554 .16667 m
.65554 .21572 L
s
.66033 .16667 m
.66033 .11762 L
s
.66511 .16667 m
.66511 .03825 L
s
.6699 .16667 m
.6699 .00794 L
s
.67468 .16667 m
.67468 .03825 L
s
.67947 .16667 m
.67947 .11762 L
s
.68425 .16667 m
.68425 .21572 L
s
.68904 .16667 m
.68904 .29508 L
s
.69383 .16667 m
.69383 .3254 L
s
.69861 .16667 m
.69861 .29508 L
s
.7034 .16667 m
.7034 .21572 L
s
.70818 .16667 m
.70818 .11762 L
s
.71297 .16667 m
.71297 .03825 L
s
.71776 .16667 m
.71776 .00794 L
s
.72254 .16667 m
.72254 .03825 L
s
.72733 .16667 m
.72733 .11762 L
s
.73211 .16667 m
.73211 .21572 L
s
.7369 .16667 m
.7369 .29508 L
s
.74168 .16667 m
.74168 .3254 L
s
.74647 .16667 m
.74647 .29508 L
s
.75126 .16667 m
.75126 .21572 L
s
.75604 .16667 m
.75604 .11762 L
s
.76083 .16667 m
.76083 .03825 L
s
.76561 .16667 m
.76561 .00794 L
s
.7704 .16667 m
.7704 .03825 L
s
.77519 .16667 m
.77519 .11762 L
s
.77997 .16667 m
.77997 .21572 L
s
.78476 .16667 m
.78476 .29508 L
s
.78954 .16667 m
.78954 .3254 L
s
.79433 .16667 m
.79433 .29508 L
s
.79911 .16667 m
.79911 .21572 L
s
.8039 .16667 m
.8039 .11762 L
s
.80869 .16667 m
.80869 .03825 L
s
.81347 .16667 m
.81347 .00794 L
s
.81826 .16667 m
.81826 .03825 L
s
.82304 .16667 m
.82304 .11762 L
s
.82783 .16667 m
.82783 .21572 L
s
.83262 .16667 m
.83262 .29508 L
s
.8374 .16667 m
.8374 .3254 L
s
.84219 .16667 m
.84219 .29508 L
s
.84697 .16667 m
.84697 .21572 L
s
.85176 .16667 m
.85176 .11762 L
s
.85654 .16667 m
.85654 .03825 L
s
.86133 .16667 m
.86133 .00794 L
s
.86612 .16667 m
.86612 .03825 L
s
.8709 .16667 m
.8709 .11762 L
s
.87569 .16667 m
.87569 .21572 L
s
.88047 .16667 m
.88047 .29508 L
s
.88526 .16667 m
.88526 .3254 L
s
.89005 .16667 m
.89005 .29508 L
s
.89483 .16667 m
.89483 .21572 L
s
.89962 .16667 m
.89962 .11762 L
s
.9044 .16667 m
.9044 .03825 L
s
.90919 .16667 m
.90919 .00794 L
s
.91397 .16667 m
.91397 .03825 L
s
.91876 .16667 m
.91876 .11762 L
s
.92355 .16667 m
.92355 .21572 L
s
.92833 .16667 m
.92833 .29508 L
s
.93312 .16667 m
.93312 .3254 L
s
.9379 .16667 m
.9379 .29508 L
s
.94269 .16667 m
.94269 .21572 L
s
.94748 .16667 m
.94748 .11762 L
s
.95226 .16667 m
.95226 .03825 L
s
.95705 .16667 m
.95705 .00794 L
s
.96183 .16667 m
.96183 .03825 L
s
.96662 .16667 m
.96662 .11762 L
s
.9714 .16667 m
.9714 .21572 L
s
.97619 .16667 m
.97619 .29508 L
s
.005 w
.02381 .3254 Mdot
.0286 .29508 Mdot
.03338 .21572 Mdot
.03817 .11762 Mdot
.04295 .03825 Mdot
.04774 .00794 Mdot
.05252 .03825 Mdot
.05731 .11762 Mdot
.0621 .21572 Mdot
.06688 .29508 Mdot
.07167 .3254 Mdot
.07645 .29508 Mdot
.08124 .21572 Mdot
.08603 .11762 Mdot
.09081 .03825 Mdot
.0956 .00794 Mdot
.10038 .03825 Mdot
.10517 .11762 Mdot
.10995 .21572 Mdot
.11474 .29508 Mdot
.11953 .3254 Mdot
.12431 .29508 Mdot
.1291 .21572 Mdot
.13388 .11762 Mdot
.13867 .03825 Mdot
.14346 .00794 Mdot
.14824 .03825 Mdot
.15303 .11762 Mdot
.15781 .21572 Mdot
.1626 .29508 Mdot
.16738 .3254 Mdot
.17217 .29508 Mdot
.17696 .21572 Mdot
.18174 .11762 Mdot
.18653 .03825 Mdot
.19131 .00794 Mdot
.1961 .03825 Mdot
.20089 .11762 Mdot
.20567 .21572 Mdot
.21046 .29508 Mdot
.21524 .3254 Mdot
.22003 .29508 Mdot
.22481 .21572 Mdot
.2296 .11762 Mdot
.23439 .03825 Mdot
.23917 .00794 Mdot
.24396 .03825 Mdot
.24874 .11762 Mdot
.25353 .21572 Mdot
.25832 .29508 Mdot
.2631 .3254 Mdot
.26789 .29508 Mdot
.27267 .21572 Mdot
.27746 .11762 Mdot
.28224 .03825 Mdot
.28703 .00794 Mdot
.29182 .03825 Mdot
.2966 .11762 Mdot
.30139 .21572 Mdot
.30617 .29508 Mdot
.31096 .3254 Mdot
.31575 .29508 Mdot
.32053 .21572 Mdot
.32532 .11762 Mdot
.3301 .03825 Mdot
.33489 .00794 Mdot
.33967 .03825 Mdot
.34446 .11762 Mdot
.34925 .21572 Mdot
.35403 .29508 Mdot
.35882 .3254 Mdot
.3636 .29508 Mdot
.36839 .21572 Mdot
.37318 .11762 Mdot
.37796 .03825 Mdot
.38275 .00794 Mdot
.38753 .03825 Mdot
.39232 .11762 Mdot
.3971 .21572 Mdot
.40189 .29508 Mdot
.40668 .3254 Mdot
.41146 .29508 Mdot
.41625 .21572 Mdot
.42103 .11762 Mdot
.42582 .03825 Mdot
.43061 .00794 Mdot
.43539 .03825 Mdot
.44018 .11762 Mdot
.44496 .21572 Mdot
.44975 .29508 Mdot
.45453 .3254 Mdot
.45932 .29508 Mdot
.46411 .21572 Mdot
.46889 .11762 Mdot
.47368 .03825 Mdot
.47846 .00794 Mdot
.48325 .03825 Mdot
.48804 .11762 Mdot
.49282 .21572 Mdot
.49761 .29508 Mdot
.50239 .3254 Mdot
.50718 .29508 Mdot
.51196 .21572 Mdot
.51675 .11762 Mdot
.52154 .03825 Mdot
.52632 .00794 Mdot
.53111 .03825 Mdot
.53589 .11762 Mdot
.54068 .21572 Mdot
.54547 .29508 Mdot
.55025 .3254 Mdot
.55504 .29508 Mdot
.55982 .21572 Mdot
.56461 .11762 Mdot
.56939 .03825 Mdot
.57418 .00794 Mdot
.57897 .03825 Mdot
.58375 .11762 Mdot
.58854 .21572 Mdot
.59332 .29508 Mdot
.59811 .3254 Mdot
.6029 .29508 Mdot
.60768 .21572 Mdot
.61247 .11762 Mdot
.61725 .03825 Mdot
.62204 .00794 Mdot
.62682 .03825 Mdot
.63161 .11762 Mdot
.6364 .21572 Mdot
.64118 .29508 Mdot
.64597 .3254 Mdot
.65075 .29508 Mdot
.65554 .21572 Mdot
.66033 .11762 Mdot
.66511 .03825 Mdot
.6699 .00794 Mdot
.67468 .03825 Mdot
.67947 .11762 Mdot
.68425 .21572 Mdot
.68904 .29508 Mdot
.69383 .3254 Mdot
.69861 .29508 Mdot
.7034 .21572 Mdot
.70818 .11762 Mdot
.71297 .03825 Mdot
.71776 .00794 Mdot
.72254 .03825 Mdot
.72733 .11762 Mdot
.73211 .21572 Mdot
.7369 .29508 Mdot
.74168 .3254 Mdot
.74647 .29508 Mdot
.75126 .21572 Mdot
.75604 .11762 Mdot
.76083 .03825 Mdot
.76561 .00794 Mdot
.7704 .03825 Mdot
.77519 .11762 Mdot
.77997 .21572 Mdot
.78476 .29508 Mdot
.78954 .3254 Mdot
.79433 .29508 Mdot
.79911 .21572 Mdot
.8039 .11762 Mdot
.80869 .03825 Mdot
.81347 .00794 Mdot
.81826 .03825 Mdot
.82304 .11762 Mdot
.82783 .21572 Mdot
.83262 .29508 Mdot
.8374 .3254 Mdot
.84219 .29508 Mdot
.84697 .21572 Mdot
.85176 .11762 Mdot
.85654 .03825 Mdot
.86133 .00794 Mdot
.86612 .03825 Mdot
.8709 .11762 Mdot
.87569 .21572 Mdot
.88047 .29508 Mdot
.88526 .3254 Mdot
.89005 .29508 Mdot
.89483 .21572 Mdot
.89962 .11762 Mdot
.9044 .03825 Mdot
.90919 .00794 Mdot
.91397 .03825 Mdot
.91876 .11762 Mdot
.92355 .21572 Mdot
.92833 .29508 Mdot
.93312 .3254 Mdot
.9379 .29508 Mdot
.94269 .21572 Mdot
.94748 .11762 Mdot
.95226 .03825 Mdot
.95705 .00794 Mdot
.96183 .03825 Mdot
.96662 .11762 Mdot
.9714 .21572 Mdot
.97619 .29508 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00<?ooool2o`0006Oooooo0ol00004ooooo`;o0000HOooool3o`0000Cooooo0_l00004oooo
o`;o0000GOooool3o`0000?ooooo0ol00004ooooo`;o0000GOooool5o`0000?ooooo0_l00004oooo
o`;o00003Oooool002oooooo00Co0000oooooooooooo0000IOooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo0000HOooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo0000GOooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`1Kooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000<ooooo`00
;oooool01?l0003oooooooooool0001Yooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo0000GOooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool0G?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00003?ooool002oooooo00Co0000oooooooooooo0000JOooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0005gooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo05gooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool02_ooool0
02oooooo00Co0000oooooooooooo0000IOooool4o`0000?ooooo00Co0000oooooooooooo0000HOoo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
0000GOooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo0000G?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000<ooooo`00;oooool01?l0003oooooooooool0001Uooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo0000H?ooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0001Looooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0005cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00003?ooool0033ooooo0_l0001Vooooo`Go00000oooool2o`00
06;ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0001Nooooo`04o`000?oooooooooo
ooooo`Go00000oooool2o`0005kooooo0ol00004ooooo`;o00001?ooool2o`0000gooooo003ooooo
ooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003ooooo
ooWooooo003oooooooWooooo000Woooooooo0000b?l0000:ooooo`007?ooool3o`0000Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`007Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool001Gooooo1Ol00003oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`;o003o4oooool2o`00oaCooooo0_l00?lDooooo`;o003o5?ooool2o`00o`Wooooo00?o0000oooo
ooooool01oooool2o`00oaCooooo0_l00?lDooooo`;o003o5?ooool2o`00oa?ooooo0_l00?l:oooo
o`03o`000?oooooooooo00Oooooo0_l00?lDooooo`;o003o4oooool2o`00oaCooooo0_l00?lDoooo
o`;o003o2Oooool00ol0003oooooooooo`08ooooo`;o003o4oooool2o`00oaCooooo0_l00?lDoooo
o`;o003o5?ooool2o`00o`Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`007Oooool00ol0003oooooooooo`07ooooo`?o00004_ooool2o`00oa?ooooo0_l00?lDooooo`;o
003o5?ooool2o`00oaCooooo0_l00?lCooooo`;o003o5?ooool2o`00oaCooooo0_l00?lDooooo`;o
003o4oooool2o`00oaCooooo0_l00?lDooooo`;o003o4oooool2o`00oaCooooo0_l00?lDooooo`;o
003o5?ooool2o`00oa?ooooo0_l00?lDooooo`;o003o5?ooool2o`00oaCooooo0_l00?l?ooooo`Co
00002_ooool001gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`08ooooo`007?oo
ool2o`0000Wooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo017ooooo00?o0000ooooooooool02?ooool001gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04Oooool0
0ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`08ooooo`009oooool00ol0003o
ooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04Oooool00ol0003o
ooooooooo`08ooooo`009oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool04Oooool00ol0003oooooooooo`08ooooo`009oooool2o`0001?ooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`0?ooooo`?o00002_ooool002Oooooo00?o0000
ooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo017ooooo00?o0000
ooooooooool02?ooool002Oooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo017ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooooooo
ool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo017ooooo00?o0000oooooooo
ool02?ooool002Oooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo017ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool04_oo
ool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04ooo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04ooo
ool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04ooo
ool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04ooo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool02?oo
ool002Oooooo00?o0000ooooooooool03oooool2o`00o`03ooooool00?oooooo00;o003o3oooool2
o`00o`03ooooool00?oooooo00;o003o3oooool2o`00o`04ooooool00?oo003oo`00oa3ooooo0ol0
0?l00ooooooo003oo`00o`0?ooooo`;o003o00?oooooo`00ooooool00_l00?l?ooooo`;o003o00Co
ooooo`00ool00?oo003o4?ooool2o`00o`04ooooool00?oo003oo`00oa3ooooo0ol00?l00ooooooo
003oo`00o`0?ooooo`;o003o00?oooooo`00ooooool00_l00?l?ooooo`;o003o00Coooooo`00ool0
0?oo003o4?ooool2o`00o`04ooooool00?oo003oo`00oa3ooooo0ol00?l00ooooooo003oo`00o`0?
ooooo`;o003o00?oooooo`00ooooool00_l00?l?ooooo`;o003o00Coooooo`00ool00?oo003o4?oo
ool2o`00o`04ooooool00?oo003oo`00oa3ooooo0ol00?l00ooooooo003oo`00o`0?ooooo`;o003o
00?oooooo`00ooooool00_l00?l?ooooo`;o003o00Coooooo`00ool00?oo003o4?ooool2o`00o`04
ooooool00?oo003oo`00o`oooooo0_l00?l00ooooooo003oooooo`02o`00oa3ooooo00?o0000oooo
ooooool02?ooool002Oooooo0_l0000@ooooo`;o003o00?oooooo`00ooooool00_l00?l?ooooo`;o
003o00?oooooo`00ooooool00_l00?l?ooooo`;o003o00Coooooo`00ool00?oo003o4?ooool3o`00
o`03ooooool00?oo003o00oooooo0_l00?l00ooooooo003oooooo`02o`00o`oooooo0_l00?l01?oo
oooo003oo`00ool00?l@ooooo`;o003o00Coooooo`00ool00?oo003o4?ooool3o`00o`03ooooool0
0?oo003o00oooooo0_l00?l00ooooooo003oooooo`02o`00o`oooooo0_l00?l01?oooooo003oo`00
ool00?l@ooooo`;o003o00Coooooo`00ool00?oo003o4?ooool3o`00o`03ooooool00?oo003o00oo
oooo0_l00?l00ooooooo003oooooo`02o`00o`oooooo0_l00?l01?oooooo003oo`00ool00?l@oooo
o`;o003o00Coooooo`00ool00?oo003o4?ooool3o`00o`03ooooool00?oo003o00oooooo0_l00?l0
0ooooooo003oooooo`02o`00o`oooooo0_l00?l01?oooooo003oo`00ool00?l@ooooo`;o003o00Co
ooooo`00ool00?oo003o3oooool2o`00o`03ooooool00?oooooo00;o003o3_ooool3o`0000[ooooo
000Wooooo`03o`000?oooooooooo013ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00
oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003ooooo
ool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool0
1Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03
o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o
017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o
4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?oo
ooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool0
0?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool00ol0003oooooooooo`08ooooo`009ooo
ool00ol0003oooooooooo`0@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oooooo
o`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003o
ooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aoooo
o`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo
00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool0
0?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017o
oooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?oo
ool01Ol00?ooooooo`00oooooooo003o017ooooo00?o0000ooooooooool02?ooool002Oooooo00?o
0000ooooooooool04?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02oooo
o`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo
003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool0
0?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol0
0?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00
oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017o
oooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?oo
ool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05
o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go
003oooooool00?ooooooo`00o`0Aooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oo
oooooooo013ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_ooool00ol0
0?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooo
oooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;o
oooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003ooooo
ool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?oooooo
o`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05
o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go
003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oo
ooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooo
oooo003oooooool00?l04Oooool00ol0003oooooooooo`08ooooo`009oooool00ol0003ooooooooo
o`0@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017o
oooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003ooooo
ooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00
o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003o
ooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l0
0_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oo
ooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooo
oooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool0
0?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool04?oo
ool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05
o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo
00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?oo
ool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?oo
ooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo
003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;ooooo
00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool0
0?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003ooooo
ool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?oooooo
o`00o`0Aooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o00004Oooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003ooooo
ool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003ooooo
ool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?oooooooooo
ool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05
o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003o
oooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool0
3_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@oooo
o`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo
00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l0
0?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0?ooooo`?o0000
2_ooool002Oooooo00?o0000ooooooooool04?ooool01Ol00?ooooooo`00oooooooo003o017ooooo
00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol0
0?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0A
ooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3o
oooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003ooooo
ool00?l@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?oooooo
o`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00oooooooooooo
o`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?oo
ooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`03o`000?oooooooooo00Sooooo
000Wooooo`03o`000?oooooooooo013ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00
oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003ooooo
ool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool0
1Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03
o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o
017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o
4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?oo
ooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool0
0?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool00ol0003oooooooooo`08ooooo`009ooo
ool00ol0003oooooooooo`0@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oooooo
o`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003o
ooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aoooo
o`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo
00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool0
0?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017o
oooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?oo
ool01Ol00?ooooooo`00oooooooo003o017ooooo00?o0000ooooooooool02?ooool002Oooooo00?o
0000ooooooooool04?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02oooo
o`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo
003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool0
0?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol0
0?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00
oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017o
oooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?oo
ool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05
o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go
003oooooool00?ooooooo`00o`0Aooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oo
oooooooo013ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_ooool00ol0
0?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooo
oooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;o
oooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003ooooo
ool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?oooooo
o`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05
o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go
003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oo
ooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooo
oooo003oooooool00?l04Oooool00ol0003oooooooooo`08ooooo`009oooool00ol0003ooooooooo
o`0@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017o
oooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003ooooo
ooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00
o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003o
ooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l0
0_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oo
ooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooo
oooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool0
0?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool04?oo
ool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05
o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo
00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?oo
ool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?oo
ooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo
003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;ooooo
00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool0
0?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003ooooo
ool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?oooooo
o`00o`0Aooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o00004Oooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003ooooo
ool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003ooooo
ool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?oooooooooo
ool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05
o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003o
oooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool0
3_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@oooo
o`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo
00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l0
0?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0?ooooo`?o0000
2_ooool002Oooooo00?o0000ooooooooool04?ooool01Ol00?ooooooo`00oooooooo003o017ooooo
00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol0
0?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0A
ooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3o
oooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003ooooo
ool00?l@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?oooooo
o`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00oooooooooooo
o`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?oo
ooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`03o`000?oooooooooo00Sooooo
000Wooooo`03o`000?oooooooooo013ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00
oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003ooooo
ool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool0
1Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03
o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o
017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o
4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?oo
ooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool0
0?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool00ol0003oooooooooo`08ooooo`009ooo
ool00ol0003oooooooooo`0@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oooooo
o`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003o
ooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aoooo
o`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo
00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool0
0?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017o
oooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?oo
ool01Ol00?ooooooo`00oooooooo003o017ooooo00?o0000ooooooooool02?ooool0017ooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo013ooooo00Go
003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oo
ooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>oooo
o`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko
003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;ooooo00?o003ooooooooo
ool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@
ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03o`00
oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003ooooo
ool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?oooooo
o`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o
013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l0
4Oooool00ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`0@ooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00
o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00
oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003o
ooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?oooooo
ooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>oooo
o`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko
003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol0
0?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00oooo
ooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00?o0000oooo
ooooool02?ooool000Wooooo1Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0@ooooo`05o`00oooooooo003oooooool00?l04Oooool0
1Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00
oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017o
oooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?oo
ool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?oooooo
o`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?oooooo
o`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo
003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo
003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooo
oooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooo
oooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00?o0000ooooooooool02?ooool0
013ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`05ooooo`?o00004?ooool0
1Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00
oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00ko
oooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool0
1_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?oooooo
ooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o
013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;ooooo00?o
003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oo
ooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooo
oooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool0
0?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00
o`0>ooooo`Co00002_ooool0013ooooo00Co0000oooooooooooo00001oooool4o`0000Sooooo00?o
0000ooooooooool04?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02oooo
o`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo
003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool0
0?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol0
0?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00
oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017o
oooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?oo
ool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05
o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go
003oooooool00?ooooooo`00o`0Aooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`05o`00
oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003ooooo
ool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool0
1Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00
ooooooooooooo`00oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo
00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?oo
ool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?oo
ooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo
003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@
ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017o
oooo00?o0000ooooooooool02?ooool0017ooooo0_l00008ooooo`Go00001oooool00ol0003ooooo
ooooo`0@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o
017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003o
ooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oooooo
o`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?ooooooo`00o`02oooo
o`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo
003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool0
0?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol0
0?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00
oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003ooooo
ool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?oooooo
o`00oooooooo003o017ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0
4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aoooo
o`05o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l0
4?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol0
0?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooo
oooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;o
oooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003ooooo
ool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?oooooo
o`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003o
ooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo013ooooo
00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol0
0?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>
ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo
00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;ooooo00?o003ooooo
ooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00
o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003o
ooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo
003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool0
0?l04Oooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`0@ooooo`05o`00
oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003ooooo
ool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool0
1Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00
ooooooooooooo`00oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo
00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?oo
ool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?oo
ooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo
003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@
ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017o
oooo00?o0000ooooooooool02?ooool002Oooooo0_l0000Aooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@
ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooo
oooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooo
oooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003ooooo
ool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?oooooooooo
ool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05
o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003o
oooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oo
ooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00oooooooo
ooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o00oooooo0ol0000:ooooo`00
9oooool00ol0003oooooooooo`0@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oo
ooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo
003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go
003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol0
0?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0A
ooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3o
oooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003ooooo
ool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o
017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o
4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00?o0000ooooooooool02?ooool002Oooooo
00?o0000ooooooooool04?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool0
0?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02
ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooo
oooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003ooooo
ool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool0
1Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03
o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o
017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o
4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aoooo
o`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo
00Go003oooooool00?ooooooo`00o`0Aooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`00
0?oooooooooo013ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_ooool0
0ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00
oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003o
ooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aoooo
o`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo
00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol0
0?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00
oooooooo003oooooool00?l04Oooool00ol0003oooooooooo`08ooooo`009oooool00ol0003ooooo
ooooo`0@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o
017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003o
ooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oooooo
o`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?ooooooo`00o`02oooo
o`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo
003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool0
0?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol0
0?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00
oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003ooooo
ool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?oooooo
o`00oooooooo003o017ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool0
4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aoooo
o`05o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l0
4?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol0
0?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooo
oooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;o
oooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003ooooo
ool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?oooooo
o`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003o
ooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00gooooo
0_l00?l01ooooooo003oooooool00?ooooooo`00ooooool00_l00?l;ooooo`;o003o00Ooooooo`00
oooooooo003oooooool00?oooooo00;o003o2oooool2o`00o`05ooooool00?ooooooo`00ooooool0
0ol00?l;ooooo`;o003o00Coooooo`00oooooooo003o0_ooool3o`00o`_ooooo0_l00?l01ooooooo
003oooooool00?ooooooo`00ooooool00_l00?l;ooooo`;o003o00Ooooooo`00oooooooo003ooooo
ool00?oooooo00;o003o2oooool3o`00o`;ooooo00?o003oooooool00?l00_l00?l;ooooo`;o003o
00Coooooo`00oooooooo003o0_ooool3o`00o`_ooooo0_l00?l01ooooooo003oooooool00?oooooo
o`00ooooool00_l00?l;ooooo`;o003o00Ooooooo`00oooooooo003oooooool00?oooooo00;o003o
2oooool3o`00o`;ooooo00?o003oooooool00?l00_l00?l;ooooo`;o003o00Coooooo`00oooooooo
003o0_ooool3o`00o`_ooooo0_l00?l01ooooooo003oooooool00?ooooooo`00ooooool00_l00?l;
ooooo`;o003o00Ooooooo`00oooooooo003oooooool00?oooooo00;o003o2oooool3o`00o`;ooooo
00?o003oooooool00?l00_l00?l;ooooo`;o003o00Ooooooo`00oooooooo003oooooool00?oooooo
00;o003o2oooool2o`00o`07ooooool00?ooooooo`00oooooooo003oooooo`02o`00o`_ooooo0_l0
0?l01ooooooo003oooooool00?ooooooo`00ooooool00_l00?l;ooooo`?o003o0_ooool00ol00?oo
ooooo`00o`02o`00o`_ooooo0_l00?l01ooooooo003oooooool00?ooooooo`00ooooool00_l00?l>
ooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o00003_ooool2o`00o`07ooooool00?oooooo
o`00oooooooo003oooooo`02o`00o`_ooooo0_l00?l01ooooooo003oooooool00?ooooooo`00oooo
ool00_l00?l;ooooo`;o003o00Goooooo`00oooooooo003oooooo`03o`00o`_ooooo0_l00?l01?oo
oooo003oooooool00?l2ooooo`?o003o2oooool2o`00o`07ooooool00?ooooooo`00oooooooo003o
ooooo`02o`00o`_ooooo0_l00?l01ooooooo003oooooool00?ooooooo`00ooooool00_l00?l;oooo
o`?o003o0_ooool00ol00?ooooooo`00o`02o`00o`_ooooo0_l00?l01?oooooo003oooooool00?l2
ooooo`?o003o2oooool2o`00o`07ooooool00?ooooooo`00oooooooo003oooooo`02o`00o`_ooooo
0_l00?l01ooooooo003oooooool00?ooooooo`00ooooool00_l00?l;ooooo`?o003o0_ooool00ol0
0?ooooooo`00o`02o`00o`_ooooo0_l00?l01?oooooo003oooooool00?l2ooooo`?o003o2oooool2
o`00o`07ooooool00?ooooooo`00oooooooo003oooooo`02o`00o`_ooooo0_l00?l01ooooooo003o
ooooool00?ooooooo`00ooooool00_l00?l;ooooo`?o003o0_ooool00ol00?ooooooo`00o`02o`00
o`_ooooo0_l00?l01ooooooo003oooooool00?ooooooo`00ooooool00_l00?l;ooooo`;o003o00Oo
ooooo`00oooooooo003oooooool00?oooooo00;o003o2oooool2o`00o`07ooooool00?ooooooo`00
oooooooo003oooooo`02o`00o`_ooooo0ol00?l2ooooo`03o`00oooooooo003o00;o003o2oooool2
o`00o`07ooooool00?ooooooo`00oooooooo003oooooo`02o`00o`cooooo0ol0000:ooooo`009ooo
ool00ol0003oooooooooo`0>ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?oo
ool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`05o`00oooooooo
003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo
003oooooool00?l03?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l0
3?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool02Ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`0=ooooo`09o`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o00cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo
003o00cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Wo
003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?oo
ooooo`00oooooooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool0
0?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooo
oooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l0
0?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03o`00oooooooo003o00;o
oooo00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00
o`02ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000
ooooooooool03_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?oooooo
ooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003o
oooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool01Ol00?ooooooo`00oooooooo
003o00;ooooo00?o003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l0
0_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo
003o00cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Go
003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Wo003oooooool00?oo
ooooo`00oooooooo003oooooool00?l03Oooool02Ol00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00o`0<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<oooo
o`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`09o`00oooooooo
003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?oo
ooooo`00oooooooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool0
0?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:
ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooo
oooo003oooooool00?ooooooo`00oooooooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00
oooooooo003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool0
0ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo
00kooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_oo
ool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00oooooooooooo
o`00oooooooo003oooooool00?ooooooo`00o`cooooo00Go003oooooool00?ooooooo`00o`02oooo
o`03o`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o
003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<oooo
o`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`05o`00oooooooo
003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`09o`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o00gooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l0
3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01Ol00?oo
ooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool02Ol00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?oo
ooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo
00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooo
oooo003oooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00
oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003ooooo
ooooool03?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`0>ooooo`07
o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003o
ooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?oooooo
o`00oooooooo003oooooool00?l<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool00ol00?oo
ooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01Ol00?ooooooo`00oooooooo
003o00;ooooo00?o003oooooool00?l03?ooool02Ol00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00o`0=ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00?o
003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Go003oooooool00?oo
ooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Wo003oooooool00?ooooooo`00oooooooo
003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<
ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooo
oooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooo
oooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00
o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00co
oooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool03_ooool01ol00?oooooo
o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?oooooo
o`00oooooooo003o3?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l0
3?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:oooo
o`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00?o003oooooool00?l0
0_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Go003oooooool00?ooooooo`00o`02oooo
o`03o`00oooooooo003o00cooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l0
3Oooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooo
003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`05o`00oooooooo003oooooool00?l0
0_ooool00ol00?ooooooo`00o`0<ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo
003o00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool00ol0
0?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01ol00?ooooooo`00oooo
oooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooo
oooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool0
1ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0<ooooo`03o`00
0?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00kooooo00Oo003oooooool00?oooooo
o`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?oooooo
o`00o`cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo
003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooo003o00;ooooo00Go
003oooooool00?ooooooo`00o`0<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooo`00o`0<ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00gooooo00Wo
003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool00ol00?ooooooo`00o`02oooo
o`05o`00oooooooo003oooooool00?l03?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o
003oooooool00?l03?ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<oooo
o`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00?o003oooooool0
0?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooo
oooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`co
oooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Oo003ooooo
ool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool03?ooool00ol0003ooooooooo
o`08ooooo`009oooool2o`0000oooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo
00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<
ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00Go003ooooo
ool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00
oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`0<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00
o`0<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`09o`00
oooooooo003oooooool00?ooooooo`00oooooooo003o00gooooo00Wo003oooooool00?ooooooo`00
oooooooo003oooooool00?l03?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003ooooo
ool00?l03?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool0
2Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00
oooooooo003oooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?oooooo
o`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003o
ooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:
o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00?o003oooooool00?l0
0_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo
003o00;ooooo00?o003oooooooooool02_ooool3o`0000[ooooo000Wooooo`03o`000?oooooooooo
00kooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_oo
ool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00oooooooooooo
o`00oooooooo003oooooool00?ooooooo`00o`cooooo00Go003oooooool00?ooooooo`00o`02oooo
o`03o`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o
003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<oooo
o`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`05o`00oooooooo
003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`09o`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o00gooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l0
3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01Ol00?oo
ooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool02Ol00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?oo
ooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo
00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooo
oooo003oooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00
oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003ooooo
ooooool03?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`0>ooooo`07
o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003o
ooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?oooooo
o`00oooooooo003oooooool00?l<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool00ol00?oo
ooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01Ol00?ooooooo`00oooooooo
003o00;ooooo00?o003oooooool00?l03?ooool02Ol00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00o`0=ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00?o
003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Go003oooooool00?oo
ooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Wo003oooooool00?ooooooo`00oooooooo
003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<
ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooo
oooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooo
oooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00
o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00co
oooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool03_ooool01ol00?oooooo
o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?oooooo
o`00oooooooo003o3?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l0
3?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:oooo
o`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00?o003oooooool00?l0
0_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Go003oooooool00?ooooooo`00o`02oooo
o`03o`00oooooooo003o00cooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l0
3Oooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooo
003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`05o`00oooooooo003oooooool00?l0
0_ooool00ol00?ooooooo`00o`0<ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo
003o00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool00ol0
0?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01ol00?ooooooo`00oooo
oooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooo
oooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool0
1ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0<ooooo`03o`00
0?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00kooooo00Oo003oooooool00?oooooo
o`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?oooooo
o`00o`cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo
003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooo003o00;ooooo00Go
003oooooool00?ooooooo`00o`0<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooo`00o`0<ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00gooooo00Wo
003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool00ol00?ooooooo`00o`02oooo
o`05o`00oooooooo003oooooool00?l03?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o
003oooooool00?l03?ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<oooo
o`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00?o003oooooool0
0?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooo
oooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`co
oooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Oo003ooooo
ool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool03?ooool00ol0003ooooooooo
o`08ooooo`009oooool00ol0003oooooooooo`0>ooooo`07o`00oooooooo003oooooool00?oooooo
o`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003o
ooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<oooo
o`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07o`00oooooooo
003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?oo
ooooo`00oooooooo003oooooool00?l03?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo
003oooooool00?l03?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l0
3?ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0=ooooo`09o`00oooooooo
003oooooool00?ooooooo`00oooooooo003o00cooooo00?o003oooooool00?l00_ooool01Ol00?oo
ooooo`00oooooooo003o00cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo
003o00cooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?oo
ooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo
00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02
ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03o`00
oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool02?ooool0
02Oooooo00?o0000ooooooooool03_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_oo
ool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o
00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool01Ol00?oo
ooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo
003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o00cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo
003o00cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Wo
003oooooool00?ooooooo`00oooooooo003oooooool00?l03Oooool02Ol00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?oo
ooooo`00o`0<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<oooo
o`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo
003oooooool00?ooooooo`00oooooooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooo
oooo003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol0
0?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo
00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool00ol00?ooooooo`00
o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003ooooo
ool00?l00_ooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03
o`000?oooooooooo00kooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003o
ooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:
o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00Go003oooooool00?oo
ooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo
003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00o`0<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<oooo
o`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`09o`00oooooooo
003oooooool00?ooooooo`00oooooooo003o00gooooo00Wo003oooooool00?ooooooo`00oooooooo
003oooooool00?l03?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l0
3?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool02Ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo
003oooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooo
oooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003ooooooooo
ool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00oooo
ooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool0
1Ol00?ooooooo`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;o
oooo00?o003oooooooooool03?ooool00ol0003oooooooooo`08ooooo`009oooool2o`0000oooooo
00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooo
oooo003oooooool00?ooooooo`00o`cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00
oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003ooooo
ooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`03o`00
oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`05o`00oooooooo003ooooo
ool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`09o`00oooooooo003oooooool00?ooooooo`00
oooooooo003o00gooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool0
0ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01Ol00?ooooooo`00
oooooooo003o00;ooooo00?o003oooooool00?l03?ooool02Ol00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00
o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Oo003o
ooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?oooooo
o`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003o
ooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo
003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool0
2_ooool3o`0000[ooooo000Wooooo`03o`000?oooooooooo00kooooo00Oo003oooooool00?oooooo
o`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?oooooo
o`00o`cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo
003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooo003o00;ooooo00Go
003oooooool00?ooooooo`00o`0<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooo`00o`0<ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00gooooo00Wo
003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool00ol00?ooooooo`00o`02oooo
o`05o`00oooooooo003oooooool00?l03?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o
003oooooool00?l03?ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<oooo
o`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00?o003oooooool0
0?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooo
oooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`co
oooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Oo003ooooo
ool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool03?ooool00ol0003ooooooooo
o`08ooooo`009oooool00ol0003oooooooooo`0>ooooo`07o`00oooooooo003oooooool00?oooooo
o`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003o
ooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<oooo
o`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07o`00oooooooo
003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?oo
ooooo`00oooooooo003oooooool00?l03?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo
003oooooool00?l03?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l0
3?ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0=ooooo`09o`00oooooooo
003oooooool00?ooooooo`00oooooooo003o00cooooo00?o003oooooool00?l00_ooool01Ol00?oo
ooooo`00oooooooo003o00cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo
003o00cooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?oo
ooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo
00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02
ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03o`00
oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool02?ooool0
02Oooooo00?o0000ooooooooool03_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_oo
ool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o
00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool01Ol00?oo
ooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo
003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o00cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo
003o00cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Wo
003oooooool00?ooooooo`00oooooooo003oooooool00?l03Oooool02Ol00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?oo
ooooo`00o`0<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<oooo
o`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo
003oooooool00?ooooooo`00oooooooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooo
oooo003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol0
0?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo
00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool00ol00?ooooooo`00
o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003ooooo
ool00?l00_ooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo000Mooooo`;o
00002?ooool00ol0003oooooooooo`0>ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02
ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`05o`00
oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00
oooooooo003oooooool00?l03?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003ooooo
ool00?l03?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool0
2Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0=ooooo`09o`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003o00cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00
oooooooo003o00cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00co
oooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?oooooooooo
ool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003o
ooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?oo
ool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03o`00oooooooo
003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool02?ooool001cooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0>ooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00
oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003ooooo
ool00?l<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07
o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003o
ooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool00ol00?ooooooo`00o`02ooooo`05
o`00oooooooo003oooooool00?l03?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003o
ooooool00?l03?ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0=ooooo`09
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00?o003oooooool00?l00_oo
ool01Ol00?ooooooo`00oooooooo003o00cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03
o`00oooooooo003o00cooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?oo
ool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03o`00oooooooo
003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo
003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<
ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooo
oooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00cooooo00?o0000oooooooo
ool02?ooool001cooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0>ooooo`07
o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003o
ooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?oooooo
o`00oooooooo003oooooool00?l<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool00ol00?oo
ooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01Ol00?ooooooo`00oooooooo
003o00;ooooo00?o003oooooool00?l03?ooool02Ol00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00o`0=ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00?o
003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Go003oooooool00?oo
ooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Wo003oooooool00?ooooooo`00oooooooo
003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<
ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooo
oooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooo
oooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00
o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00co
oooo00?o0000ooooooooool02?ooool001cooooo00Co0000oooooooooooo00001oooool:o`00000>
o`00ool0003o0000o`00ool0003o003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?l2o`00
000;o`00ool0003o003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?l00_l000002ol00?oo
0000o`00ool0003o003oo`000?l00?oo0000o`00ool0003o003o00;o000000Wo003oo`000?l00?oo
0000o`00ool0003o003oo`000?l00?l00_l000002ol00?oo0000o`00ool0003o003oo`000?l00?oo
0000o`00ool0003o003o00;o000000_o003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?oo
0000o`00o`02o`00000;o`00ool0003o003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?l0
0_l000002Ol00?oo0000o`00ool0003o003oo`000?l00?oo0000o`00o`02o`00000;o`00ool0003o
003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?l00_l000002ol00?oo0000o`00ool0003o
003oo`000?l00?oo0000o`00ool0003o003o00;o000000_o003oo`000?l00?oo0000o`00ool0003o
003oo`000?l00?oo0000o`00o`02o`000009o`00ool0003o003oo`000?l00?oo0000o`00ool0003o
003o00;o000000_o003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?oo0000o`00o`02o`00
000;o`00ool0003o003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?l00_l000002ol00?oo
0000o`00ool0003o003oo`000?l00?oo0000o`00ool0003o003o00;o000000Wo003oo`000?l00?oo
0000o`00ool0003o003oo`000?l00?l00_l000002ol00?oo0000o`00ool0003o003oo`000?l00?oo
0000o`00ool0003o003o00;o000000_o003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?oo
0000o`00o`02o`00000;o`00ool0003o003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?l0
0_l000002Ol00?oo0000o`00ool0003o003oo`000?l00?oo0000o`00o`02o`00000;o`00ool0003o
003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?l00_l000002ol00?oo0000o`00ool0003o
003oo`000?l00?oo0000o`00ool0003o003o00;o000000_o003oo`000?l00?oo0000o`00ool0003o
003oo`000?l00?oo0000o`00o`02o`000009o`00ool0003o003oo`000?l00?oo0000o`00ool0003o
003o00;o000000_o003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?oo0000o`00o`02o`00
000;o`00ool0003o003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?l00_l000002ol00?oo
0000o`00ool0003o003oo`000?l00?oo0000o`00ool0003o003o00;o000000Wo003oo`000?l00?oo
0000o`00ool0003o003oo`000?l00?l00_l000002ol00?oo0000o`00ool0003o003oo`000?l00?oo
0000o`00ool0003o003o00;o000000_o003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?oo
0000o`00o`02o`00000;o`00ool0003o003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?l0
0_l000002Ol00?oo0000o`00ool0003o003oo`000?l00?oo0000o`00o`02o`00000;o`00ool0003o
003oo`000?l00?oo0000o`00ool0003o003oo`000?l00?l00_l000002ol00?oo0000o`00ool0003o
003oo`000?l00?oo0000o`00ool0003o003o00;o000000Go003oo`000?l00?oo0000o`00o`0;o`00
00[ooooo000Looooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01oooool01_l0
0?ooooooooooool00?ooooooo`00o`cooooo00Wo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03
o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003o
ooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?oooooo
o`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003o
ooooool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<oooo
o`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo
003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?oo
ooooo`00oooooooo003oooooool00?l<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol0
0?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooo
oooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l0
0?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`05o`00oooooooo003ooooo
ool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00
o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?l03?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool0
1Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool00ol00?ooooooo`00
o`0:ooooo`03o`000?oooooooooo00Sooooo000Looooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool01oooool01_l00?ooooooooooool00?ooooooo`00o`cooooo00Wo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooo
oooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00
o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[o
oooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?oooooooooo
ool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003o
ooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?oo
ool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`05o`00oooooooo
003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo
003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<
ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07o`00oooo
oooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l03?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooo
oooo003oooooool00?l03?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool0
0?l03?ooool00ol00?ooooooo`00o`0:ooooo`03o`000?oooooooooo00Sooooo000Mooooo`;o0000
2?ooool00ol0003oooooooooo`07ooooo`06o`00ooooooooooooo`00oooooooo003o3?ooool02Ol0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooo
oooo003oooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00
oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003ooooo
ooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00
ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_oo
ool01Ol00?ooooooo`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o
00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?oooooo
o`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00Go
003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo003oooooool00?oo
ooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?oo
ooooo`00o`cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo
00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooo003o00;ooooo
00Go003oooooool00?ooooooo`00o`0<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol0
0?ooooooo`00o`0<ooooo`03o`00oooooooo003o00[ooooo00?o0000ooooooooool02?ooool002Oo
oooo00?o0000ooooooooool01oooool01_l00?ooooooooooool00?ooooooo`00o`cooooo00Wo003o
ooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?oooooo
o`00oooooooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?oo
ooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?oo
ooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo
00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02
ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`05o`00
oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00
oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003ooooo
ool00?l<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07
o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003o
ooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool00ol00?ooooooo`00o`02ooooo`05
o`00oooooooo003oooooool00?l03?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003o
ooooool00?l03?ooool00ol00?ooooooo`00o`0:ooooo`03o`000?oooooooooo00Sooooo000Woooo
o`03o`000?oooooooooo00Oooooo00Ko003ooooooooooooo003oooooool00?l<ooooo`09o`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool0
0?ooooooo`00oooooooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003ooooo
ool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?oooooooooo
o`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooo
oooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05
o`00oooooooo003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_oo
ool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o
00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool01Ol00?oo
ooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo
003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo
003o3?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool01ol0
0?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o00cooooo00?o003oooooool00?l00_ooool01Ol0
0?ooooooo`00oooooooo003o00cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooo
oooo003o00cooooo00?o003oooooool00?l02_ooool00ol0003oooooooooo`08ooooo`009oooool0
0ol0003oooooooooo`07ooooo`06o`00ooooooooooooo`00oooooooo003o3?ooool02Ol00?oooooo
o`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003o
ooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo
003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool0
2_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00oooooooo
ooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol0
0?ooooooo`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo
00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<
ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00Go003ooooo
ool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00
oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00
o`cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo003o
ooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?oooooo
o`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooo003o00;ooooo00Go003o
ooooool00?ooooooo`00o`0<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oooooo
o`00o`0<ooooo`03o`00oooooooo003o00[ooooo00?o0000ooooooooool02?ooool002Oooooo0_l0
0008ooooo`06o`00ooooooooooooo`00oooooooo003o3?ooool02Ol00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?oooooo
o`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Oo
003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo
003oooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooo
oooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003ooooooooo
ool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00oooo
ooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00Go003oooooool00?ooooooo`00
o`02ooooo`03o`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;o
oooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00
o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00Go003o
ooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo003oooooool00?oooooo
o`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00o`0<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?oooooo
o`00o`0<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`03
o`00oooooooo003o00Sooooo0ol0000:ooooo`009oooool00ol0003oooooooooo`07ooooo`06o`00
ooooooooooooo`00oooooooo003o3?ooool02Ol00?ooooooo`00oooooooo003oooooool00?oooooo
o`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00?o
003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Oo003oooooool00?oo
ooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?oo
ooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo
00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooo
oooo003oooooool00?ooooooo`00o`cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00
oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003ooooo
ooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00
ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00Go003oooooool00?oooooo
o`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o
00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?oooooo
o`00o`0<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`05
o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`03o`00oooooooo003o
00[ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool01oooool01_l00?oo
ooooooooool00?ooooooo`00o`cooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03o`00
oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00
oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003ooooo
ool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`07
o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003o
ooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?oooooo
o`00oooooooo003oooooool00?l<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?oo
ooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`05o`00oooooooo003oooooool0
0?l00_ooool00ol00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02
ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l03?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01Ol0
0?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool00ol00?ooooooo`00o`0:
ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00Ko003ooooo
oooooooo003oooooool00?l<ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o
00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool00ol00?oo
ooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo
003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo
003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01ol0
0?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool0
0?ooooooo`00oooooooo003o3?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003ooooo
ool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?oooooooooo
o`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooo
oooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool01Ol00?ooooooo`00oooooooo003o
00;ooooo00?o003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_oo
ool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o
00cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Go003o
ooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00?o003oooooool00?l02_oo
ool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`06o`00oooooooo
ooooo`00oooooooo003o3?ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<
ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00?o003ooooo
ool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00
oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00
o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Oo003o
ooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?oooooo
o`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003o
ooooool00?ooooooo`00o`cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo
003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool0
2_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00oooooooo
ooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00Go003oooooool00?ooooooo`00o`02
ooooo`03o`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo
00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<
ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`05o`00oooo
oooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`03o`00oooooooo003o00[ooooo
00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool01oooool01_l00?oooooooooo
ool00?ooooooo`00o`cooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?oo
ool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03o`00oooooooo
003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo
003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<
ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<ooooo`07o`00oooo
oooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooo
oooo003oooooool00?l<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00
o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[o
oooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?oooooooooo
ool00?ooooooo`00oooooooo003oooooool00?l<ooooo`05o`00oooooooo003oooooool00?l00_oo
ool00ol00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?oo
ool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01Ol00?oooooo
o`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool00ol00?ooooooo`00o`0:ooooo`03
o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00Ko003ooooooooooooo
003oooooool00?l<ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo
00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool00ol00?ooooooo`00
o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003ooooo
ool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00
oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?oo
ool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01ol00?oooooo
o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?oooooo
o`00oooooooo003o3?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l0
3?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:oooo
o`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo
003oooooool00?ooooooo`00oooooooo003o3?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo
00?o003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol0
0?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo
00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Go003oooooool0
0?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00?o003oooooool00?l02_ooool00ol0
003oooooooooo`08ooooo`009oooool2o`0000Sooooo00Ko003ooooooooooooo003oooooool00?l<
ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooo
oooo003oooooool00?ooooooo`00oooooooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00
oooooooo003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool0
0ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00co
oooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool00ol00?oooooo
o`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003o
ooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?oooooo
o`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o
3?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool01ol00?oo
ooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo
003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?oo
ooooo`00oooooooo003o3?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool0
0?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:
ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00?o003oooooool0
0?l00_ooool01Ol00?ooooooo`00oooooooo003o00cooooo00Go003oooooool00?ooooooo`00o`02
ooooo`03o`00oooooooo003o00cooooo00?o003oooooool00?l02?ooool3o`0000[ooooo000Woooo
o`03o`000?oooooooooo00Oooooo00Ko003ooooooooooooo003oooooool00?l<ooooo`09o`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool0
0?ooooooo`00oooooooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003ooooo
ool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?oooooooooo
o`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooo
oooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05
o`00oooooooo003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_oo
ool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o
00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool01Ol00?oo
ooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo
003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo
003o3?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool01ol0
0?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o00cooooo00?o003oooooool00?l00_ooool01Ol0
0?ooooooo`00oooooooo003o00cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooo
oooo003o00cooooo00?o003oooooool00?l02_ooool00ol0003oooooooooo`08ooooo`009oooool0
0ol0003oooooooooo`07ooooo`06o`00ooooooooooooo`00oooooooo003o3?ooool02Ol00?oooooo
o`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003o
ooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo
003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool0
2_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00oooooooo
ooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol0
0?ooooooo`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo
00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<
ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00Go003ooooo
ool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00
oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00
o`cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo003o
ooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?oooooo
o`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooo003o00;ooooo00Go003o
ooooool00?ooooooo`00o`0<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?oooooo
o`00o`0<ooooo`03o`00oooooooo003o00[ooooo00?o0000ooooooooool02?ooool002Oooooo00?o
0000ooooooooool01oooool01_l00?ooooooooooool00?ooooooo`00o`cooooo00Wo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooo
oooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00
o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[o
oooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?oooooooooo
ool00?ooooooo`00oooooooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003o
ooooool00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?oo
ool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`05o`00oooooooo
003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo
003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<
ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07o`00oooo
oooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l03?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooo
oooo003oooooool00?l03?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool0
0?l03?ooool00ol00?ooooooo`00o`0:ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`00
0?oooooooooo00Oooooo00Ko003ooooooooooooo003oooooool00?l<ooooo`09o`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?oooooo
o`00oooooooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l0
3?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:oooo
o`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo
003oooooool00?ooooooo`00oooooooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooo
oooo003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol0
0?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo
00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool01Ol00?ooooooo`00
oooooooo003o00;ooooo00?o003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003ooooo
ool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00
oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?oo
ool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool01ol00?oooooo
o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o00cooooo00?o003oooooool00?l00_ooool01Ol00?oooooo
o`00oooooooo003o00cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o
00cooooo00?o003oooooool00?l02_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003o
ooooooooo`07ooooo`06o`00ooooooooooooo`00oooooooo003o3?ooool02Ol00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool0
0?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00co
oooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool0
2Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:o`00ooooooooooooo`00
oooooooo003oooooool00?ooooooo`00o`cooooo00?o003oooooool00?l00_ooool01Ol00?oooooo
o`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00?o003o
ooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0<ooooo`0:
o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo00Go003oooooool00?oo
ooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo003oooooool00?ooooooo`00oooooooo
003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00o`0<ooooo`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`cooooo
00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo00Oo003oooooool0
0?ooooooo`00oooooooo003o00;ooooo00?o003oooooooooool02_ooool02Ol00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool0
0?ooooooo`00o`0<ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<
ooooo`03o`00oooooooo003o00[ooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooo
ooooool01oooool01_l00?ooooooooooool00?ooooooo`00o`cooooo00Wo003oooooool00?oooooo
o`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003o
ooooool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool00?ooooooo`00o`0<oooo
o`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo
003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l00?ooooooooooool00?oo
ooooo`00oooooooo003oooooool00?l<ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool0
0?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`02ooooo`03o`00oooo
oooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l03?ooool02_l0
0?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`05o`00oooooooo003ooooo
ool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07o`00oooooooo003oooooool00?ooooooo`00
o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?l03?ooool02_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l<ooooo`05
o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0<ooooo`07o`00oooooooo003o
ooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo00Wo003oooooool00?oooooo
o`00oooooooo003oooooool00?l03?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003o
ooooool00?l03?ooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?oo
ool00ol00?ooooooo`00o`0:ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooo
oooo00Oooooo00Ko003ooooooooooooo003oooooool00?l<ooooo`09o`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooo
oooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l03?ooool0
1ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00
oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003ooooooooooooo003ooooo
ool00?ooooooo`00oooooooo003o3?ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003o
ooooool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l00_ooool00ol00?oooooo
ooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o00cooooo00[o003o
oooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool01Ol00?ooooooo`00oooooooo
003o00;ooooo00?o003oooooool00?l03?ooool01ol00?ooooooo`00oooooooo003oooooool00?l0
0_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo
003o00cooooo00[o003ooooooooooooo003oooooool00?ooooooo`00oooooooo003o3?ooool01Ol0
0?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l03?ooool01ol00?ooooooo`00oooo
oooo003oooooool00?l00_ooool00ol00?ooooooooooo`0:ooooo`09o`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o00cooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooo
oooo003o00cooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00cooooo
00?o003oooooool00?l02_ooool00ol0003oooooooooo`08ooooo`009oooool2o`0000Sooooo00?o
003oooooooooool00ol00?l;ooooo`;o003o00Ooooooo`00oooooooo003oooooool00?oooooo00;o
003o2oooool2o`00o`07ooooool00?ooooooo`00oooooooo003oooooo`02o`00o`_ooooo0ol00?l2
ooooo`03o`00oooooooo003o00;o003o2oooool2o`00o`07ooooool00?ooooooo`00oooooooo003o
ooooo`02o`00o`_ooooo0_l00?l01ooooooo003oooooool00?ooooooo`00ooooool00_l00?l;oooo
o`;o003o00Ooooooo`00oooooooo003oooooool00?oooooo00;o003o2oooool3o`00o`;ooooo00?o
003oooooool00?l00_l00?l;ooooo`;o003o00Ooooooo`00oooooooo003oooooool00?oooooo00;o
003o2oooool2o`00o`07ooooool00?ooooooo`00oooooooo003oooooo`02o`00o`_ooooo0_l00?l0
1Ooooooo003oooooool00?oooooo00?o003o3?ooool3o`00o`04ooooool00?ooooooooooo`?o003o
2oooool2o`00o`07ooooool00?ooooooo`00oooooooo003oooooo`02o`00o`_ooooo0_l00?l01ooo
oooo003oooooool00?ooooooo`00ooooool00_l00?l;ooooo`;o003o00Goooooo`00oooooooo003o
ooooo`03o`00o`_ooooo0_l00?l01?oooooo003oooooool00?l2ooooo`?o003o2oooool2o`00o`07
ooooool00?ooooooo`00oooooooo003oooooo`02o`00o`_ooooo0_l00?l01ooooooo003oooooool0
0?ooooooo`00ooooool00_l00?l;ooooo`?o003o0_ooool00ol00?ooooooo`00o`02o`00o`_ooooo
0_l00?l01?oooooo003oooooool00?l2ooooo`?o003o2oooool2o`00o`03ooooool00?oooooo00Oo
oooo0ol0000:ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00?o003o
2oooool2o`00o`07ooooool00?ooooooo`00oooooooo003oooooo`02o`00o`_ooooo0_l00?l01ooo
oooo003oooooool00?ooooooo`00ooooool00_l00?l;ooooo`?o003o0_ooool00ol00?ooooooo`00
o`02o`00o`_ooooo0_l00?l01ooooooo003oooooool00?ooooooo`00ooooool00_l00?l;ooooo`;o
003o00Ooooooo`00oooooooo003oooooool00?oooooo00;o003o2oooool2o`00o`07ooooool00?oo
ooooo`00oooooooo003oooooo`02o`00o`_ooooo0ol00?l2ooooo`03o`00oooooooo003o00;o003o
2oooool2o`00o`07ooooool00?ooooooo`00oooooooo003oooooo`02o`00o`_ooooo0_l00?l01ooo
oooo003oooooool00?ooooooo`00ooooool00_l00?l;ooooo`;o003o00Goooooo`00oooooooo003o
ooooo`03o`00o`cooooo0ol00?l01?oooooo003oooooooooool3o`00o`_ooooo0_l00?l01ooooooo
003oooooool00?ooooooo`00ooooool00_l00?l;ooooo`;o003o00Ooooooo`00oooooooo003ooooo
ool00?oooooo00;o003o2oooool2o`00o`05ooooool00?ooooooo`00ooooool00ol00?l;ooooo`;o
003o00Coooooo`00oooooooo003o0_ooool3o`00o`_ooooo0_l00?l01ooooooo003oooooool00?oo
ooooo`00ooooool00_l00?l;ooooo`;o003o00Ooooooo`00oooooooo003oooooool00?oooooo00;o
003o2oooool3o`00o`;ooooo00?o003oooooool00?l00_l00?l;ooooo`;o003o00Coooooo`00oooo
oooo003o0_ooool3o`00o`_ooooo0_l00?l00ooooooo003oooooo`09ooooo`03o`000?oooooooooo
00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00Co003ooooooooooooo003o4?ooool01Ol0
0?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00oooo
ooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003ooooo
ool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?oooooooooo
ool00?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003o
ooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_oo
ool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oooooo
o`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003o
ooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`04o`00ooooooooooooo`00oa3o
oooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool0
1_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05
o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003o
oooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oo
ooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo
003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go
003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aoooo
o`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo
00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Sooooo
00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool01oooool01?l00?oooooooooo
ool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o
013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l0
4Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@oooo
o`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo
00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol0
0?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0A
ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo
00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool0
0?l@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00Co003o
oooooooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oo
ooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooo
oooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool0
0?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00
o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013o
oooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00
o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00
oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07oooo
o`04o`00ooooooooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooo
oooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003ooooo
ool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00
oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003o
ooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oooooo
o`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?oooooo
o`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003o
ooooool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003o
ooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?oooooo
ooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo0_l00008ooooo`04
o`00ooooooooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo
003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool0
0?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooo
oooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00
o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003ooooo
ool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003ooooo
ool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?oooooooooo
ool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Kooooo0ol0000:ooooo`009oooool00ol0003oooooooooo`07ooooo`04o`00
ooooooooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003o
ooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo
003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@
ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooo
oooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool0
0?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool0
0?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool0
0?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool01ooo
ool01?l00?ooooooooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oo
ooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooo
oooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool0
0?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003ooooo
ool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003ooooo
ool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00
oooooooo003o013ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00
oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooo
oooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooo
oooo00Oooooo00Co003ooooooooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo
00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool0
1Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00
oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003o
ooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oooooo
o`00oooooooo003o013ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05
o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003o
ooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_oo
ool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06
o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`004Oooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000Sooooo00?o0000ooooooooool01oooool01?l0
0?ooooooooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00
oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003o
ooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oooooo
o`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo
003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l0
4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo
003o013ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo
003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo
003oooooool00?l@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Oooooo00Co003o
oooooooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oo
ooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooo
oooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool0
0?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00
o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013o
oooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00
o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00
oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool01?l00?ooooooooooool0
0?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013o
oooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Ooo
ool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06
o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go
003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aoooo
o`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o
003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l0
4Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@
ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo000@ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool01Oooool3o`0000Oooooo00Co003ooooooooooooo003o4?ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00
oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oooooo
o`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?oooooo
o`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l0
4Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_ooool00ol00?oo
ooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo
003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o
003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oo
ooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?ooooooo`00o`02
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool4o`0000[ooooo000@oooo
o`04o`000?ooooooooooo`0000Oooooo1?l00008ooooo`03o`000?oooooooooo00Oooooo00Co003o
oooooooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oo
ooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooo
oooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool0
0?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00
o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013o
oooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00
o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00
oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`004?ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool01?l00?ooooooooooool0
0?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013o
oooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Ooo
ool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06
o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go
003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aoooo
o`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o
003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l0
4Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@
ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo000Aooooo`;o00002?ooool5o`0000Oooooo00?o0000oooo
ooooool01oooool01?l00?ooooooooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Ooo
ool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@oooo
o`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go
003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol0
0?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooo
oooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo
00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol0
0?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>
ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo
00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;ooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03
o`000?oooooooooo00Oooooo00Co003ooooooooooooo003o4?ooool01Ol00?ooooooo`00oooooooo
003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo
003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0A
ooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3o
oooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool0
1Ol00?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_ooool00ol00?oooooooooo
o`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017o
oooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003ooooo
ooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00
o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`00
9oooool00ol0003oooooooooo`07ooooo`04o`00ooooooooooooo`00oa3ooooo00Go003oooooool0
0?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool0
0?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003ooooo
ool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o
017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003o
ooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oooooo
o`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003o
ooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l0
0_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0
2?ooool002Oooooo00?o0000ooooooooool01oooool01?l00?ooooooooooool00?l@ooooo`05o`00
oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooo
oooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oooooo
o`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00oooooooooooo
o`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02oooo
o`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo
003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l0
0_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oo
ooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooo
oooo003o00;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo000Wooooo`;o00002?ooool01?l00?ooooooooooool00?l@ooooo`05o`00oooo
oooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooo
oooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00
oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oooooo
o`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003o
ooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_oo
ool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oooooo
o`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo
003o00;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`?o00002_ooool0
02Oooooo00?o0000ooooooooool01oooool01?l00?ooooooooooool00?l@ooooo`05o`00oooooooo
003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo
003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooo
oooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooo
oooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00
o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00
oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_ooool0
0ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00
oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00Co003ooooooooooooo003o4?ooool01Ol0
0?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00oooo
ooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003ooooo
ool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?oooooooooo
ool00?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003o
ooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_oo
ool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oooooo
o`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003o
ooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`04o`00ooooooooooooo`00oa3o
oooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool0
1_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05
o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003o
oooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oo
ooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo
003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go
003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aoooo
o`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo
00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Sooooo
00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool01oooool01?l00?oooooooooo
ool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o
013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l0
4Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@oooo
o`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo
00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol0
0?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0A
ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo
00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool0
0?l@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo00Oooooo00Co003o
oooooooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oo
ooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooo
oooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool0
0?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00
o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013o
oooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00
o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00
oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07oooo
o`04o`00ooooooooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooo
oooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003ooooo
ool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00
oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003o
ooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?oooooo
o`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?oooooo
o`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003o
ooooool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003o
ooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?oooooo
ooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo0_l00008ooooo`04
o`00ooooooooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo
003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool0
0?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooo
oooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00
o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003ooooo
ool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003ooooo
ool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?oooooooooo
ool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Kooooo0ol0000:ooooo`009oooool00ol0003oooooooooo`07ooooo`04o`00
ooooooooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003o
ooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?oo
ooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo
003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@
ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooo
oooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool0
0?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool0
0?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool0
0?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Sooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000ooooooooool01ooo
ool01?l00?ooooooooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oo
ooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`05o`00oooo
oooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool0
0?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003ooooo
ool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003ooooo
ool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00
oooooooo003o013ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05o`00
oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooo
oooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000Wooooo`03o`000?oooooo
oooo00Oooooo00Co003ooooooooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo
00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool0
1Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00
oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00Go003o
ooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oooooo
o`00oooooooo003o013ooooo00?o003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`05
o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003o
ooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool03_oo
ool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06
o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0
003oooooooooo`07ooooo`04o`00ooooooooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00
o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00
oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04Ooo
ool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@oooo
o`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go
003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool0
3_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0Aoooo
o`05o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo
oooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l0
4?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o003oooooool00?l00_ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02?ooool002Oo
oooo00?o0000ooooooooool01oooool01?l00?ooooooooooool00?l@ooooo`05o`00oooooooo003o
ooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooooooooooo003o
ooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo
003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo
003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0A
ooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooo
oooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool0
0?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_ooool00ol0
0?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooo
oooo003o013ooooo00Ko003ooooooooooooo003oooooool00?l@ooooo`03o`00oooooooo003o00;o
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00So
oooo000Wooooo`03o`000?oooooooooo00Oooooo00Co003ooooooooooooo003o4?ooool01Ol00?oo
ooooo`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`06o`00oooooooo
ooooo`00oooooooo003o4?ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003oooooool0
0?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool0
0?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003ooooo
ool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00?o003oooooool00?l00_ooool0
0ol00?ooooooooooo`0>ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00
oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o00;o
oooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003ooooo
ool00?ooooooo`00o`0@ooooo`06o`00ooooooooooooo`00oooooooo003o4?ooool00ol00?oooooo
o`00o`02ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`04o`00ooooooooooooo`00oa3ooooo
00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool01_l0
0?ooooooooooool00?ooooooo`00oa3ooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05o`00
oooooooo003oooooool00?l04Oooool01Ol00?ooooooo`00oooooooo003o013ooooo00Ko003ooooo
oooooooo003oooooool00?l@ooooo`05o`00oooooooo003oooooool00?l04Oooool01Ol00?oooooo
o`00oooooooo003o017ooooo00Go003oooooool00?ooooooo`00o`0@ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooooooool03_ooool01Ol00?ooooooo`00oooooooo003o017ooooo00Go003o
ooooool00?ooooooo`00o`0Aooooo`05o`00oooooooo003oooooool00?l04?ooool00ol00?oooooo
o`00o`02ooooo`03o`00oooooooooooo00kooooo00Go003oooooool00?ooooooo`00o`0Aooooo`05
o`00oooooooo003oooooool00?l04?ooool01_l00?ooooooooooool00?ooooooo`00oa3ooooo00?o
003oooooool00?l00_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Sooooo00?o
0000ooooooooool02?ooool002Oooooo0_l00008ooooo`04o`00oooooooo003oo`00o`oooooo0_l0
0?l00ooooooo003oooooo`02o`00o`oooooo0_l00?l01?oooooo003oo`00ool00?l@ooooo`;o003o
00Coooooo`00ool00?oo003o4?ooool3o`00o`03ooooool00?oo003o00oooooo0_l00?l00ooooooo
003oooooo`02o`00o`oooooo0_l00?l01?oooooo003oo`00ool00?l@ooooo`;o003o00Coooooo`00
ool00?oo003o3oooool2o`00o`03ooooool00?oooooo00;o003o3oooool2o`00o`03ooooool00?oo
oooo00;o003o3oooool2o`00o`04ooooool00?oo003oo`00oa3ooooo0ol00?l00ooooooo003oo`00
o`0?ooooo`;o003o00?oooooo`00ooooool00_l00?l?ooooo`;o003o00?oooooo`00ooooool00_l0
0?l?ooooo`;o003o00Coooooo`00ool00?oo003o4?ooool3o`00o`03ooooool00?oo003o00oooooo
0_l00?l00ooooooo003oooooo`02o`00o`oooooo0_l00?l01?oooooo003oo`00ool00?l@ooooo`;o
003o00Coooooo`00ool00?oo003o4?ooool3o`00o`03ooooool00?oo003o00oooooo0_l00?l8oooo
o`?o00002_ooool002Oooooo00?o0000ooooooooool01oooool01?l00?ooooooo`00ool00?l?oooo
o`;o003o00?oooooo`00ooooool00_l00?l?ooooo`;o003o00Coooooo`00ool00?oo003o4?ooool2
o`00o`04ooooool00?oo003oo`00oa3ooooo0ol00?l00ooooooo003oo`00o`0?ooooo`;o003o00?o
ooooo`00ooooool00_l00?l?ooooo`;o003o00Coooooo`00ool00?oo003o4?ooool2o`00o`04oooo
ool00?oo003oo`00o`oooooo0_l00?l00ooooooo003oooooo`02o`00o`oooooo0_l00?l00ooooooo
003oooooo`02o`00o`oooooo0_l00?l01?oooooo003oo`00ool00?l@ooooo`?o003o00?oooooo`00
ool00?l03oooool2o`00o`03ooooool00?oooooo00;o003o3oooool2o`00o`03ooooool00?oooooo
00;o003o3oooool2o`00o`04ooooool00?oo003oo`00oa3ooooo0ol00?l00ooooooo003oo`00o`0?
ooooo`;o003o00?oooooo`00ooooool00_l00?l?ooooo`;o003o00Coooooo`00ool00?oo003o4?oo
ool2o`00o`04ooooool00?oo003oo`00oa3ooooo0ol00?l00ooooooo003oo`00o`0?ooooo`;o003o
2_ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool07?ooool00ol0003oooooooooo`08ooooo`009oooool0
0ol0003oooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool07?ooool0
0ol0003oooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool07?ooool00ol0003oooooooooo`08ooooo`009oooool00ol0003o
ooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool07?ooool00ol0003o
ooooooooo`08ooooo`009oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool07?ooool00ol0003oooooooooo`08ooooo`009oooool2o`0000Sooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`0Jooooo`?o00002_ooool002Oooooo00?o0000
ooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo00?o0000
ooooooooool02?ooool002Oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo01cooooo00?o0000ooooooooool02?ooool002Oooooo00?o0000oooooooo
ool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo00?o0000oooooooo
ool02?ooool001cooooo0ol00008ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`0Looooo`03o`000?oooooooooo00Sooooo000Mooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo01cooooo00?o0000ooooooooool02?ooool001gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool07?ooool0
0ol0003oooooooooo`08ooooo`007Oooool00ol0003oooooooooo`07ooooo`?o00001oooool2o`00
oa?ooooo0_l00?lDooooo`;o003o5?ooool2o`00oaCooooo0_l00?lCooooo`;o003o5?ooool2o`00
oaCooooo0_l00?lDooooo`;o003o4oooool2o`00oaCooooo0_l00?lDooooo`;o003o5?ooool2o`00
oa?ooooo0_l00?lDooooo`;o003o5?ooool2o`00oaCooooo0_l00?lCooooo`;o003o5?ooool2o`00
oaCooooo0_l00?lJooooo`Co00002_ooool001gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`;o003o4oooool2o`00oaCooooo0_l00?lDooooo`;o003o5?ooool2o`00oa?o
oooo0_l00?lDooooo`;o003o5?ooool2o`00oaCooooo0_l00?lCooooo`;o003o5?ooool2o`00oaCo
oooo0_l00?lDooooo`;o003o4oooool2o`00oaCooooo0_l00?lDooooo`;o003o5?ooool2o`00oa?o
oooo0_l00?lDooooo`;o003o5?ooool2o`00oaCooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`007?ooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`08ooooo`007Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool002Ooooooool00038o`0000[ooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-22.9245, -1.25358, 0.459967, \
0.0138684}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DTFT", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X\[Theta]\  = DTFT[xd, \[Theta]];\)\), "\[IndentingNewLine]", 
    \(X\[Theta]\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1 + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\) \
+ 1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-2\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-3\)\ \[ImaginaryI]\ \[Theta]\
\) + 1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-4\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-5\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-6\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-7\)\ \[ImaginaryI]\ \[Theta]\
\) + 1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-8\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-9\)\ \[ImaginaryI]\ \[Theta]\
\) + \[ExponentialE]\^\(\(-10\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-11\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-12\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-13\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-14\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-15\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-16\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-17\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-18\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-19\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-20\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-21\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-22\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-23\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-24\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-25\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-26\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-27\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-28\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-29\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-30\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-31\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-32\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-33\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-34\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-35\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-36\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-37\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-38\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-39\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-40\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-41\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-42\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-43\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-44\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-45\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-46\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-47\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-48\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-49\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-50\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-51\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-52\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-53\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-54\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-55\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-56\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-57\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-58\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-59\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-60\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-61\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-62\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-63\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-64\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-65\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-66\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-67\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-68\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-69\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-70\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-71\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-72\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-73\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-74\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-75\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-76\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-77\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-78\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-79\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-80\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-81\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-82\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-83\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-84\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-85\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-86\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-87\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-88\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-89\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-90\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-91\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-92\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-93\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-94\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-95\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-96\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-97\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-98\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-99\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-100\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-101\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-102\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-103\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-104\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-105\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-106\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-107\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-108\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-109\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-110\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-111\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-112\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-113\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-114\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-115\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-116\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-117\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-118\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-119\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-120\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-121\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-122\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-123\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-124\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-125\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-126\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-127\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-128\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-129\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-130\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-131\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-132\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-133\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-134\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-135\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-136\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-137\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-138\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-139\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-140\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-141\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-142\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-143\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-144\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-145\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-146\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-147\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-148\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-149\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-150\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-151\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-152\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-153\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-154\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-155\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-156\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-157\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-158\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-159\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-160\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-161\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-162\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-163\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-164\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-165\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-166\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-167\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-168\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-169\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-170\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-171\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-172\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-173\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-174\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-175\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-176\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-177\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-178\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-179\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-180\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-181\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-182\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-183\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-184\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-185\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-186\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-187\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-188\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-189\)\ \[ImaginaryI]\ \
\[Theta]\) + \[ExponentialE]\^\(\(-190\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-191\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-192\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-193\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-194\)\ \[ImaginaryI]\ \
\[Theta]\) - \[ExponentialE]\^\(\(-195\)\ \[ImaginaryI]\ \[Theta]\) + 
      1\/4\ \((\(-1\) - \@5)\)\ \[ExponentialE]\^\(\(-196\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 - \@5)\)\ \[ExponentialE]\^\(\(-197\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((\(-1\) + \@5)\)\ \[ExponentialE]\^\(\(-198\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      1\/4\ \((1 + \@5)\)\ \[ExponentialE]\^\(\(-199\)\ \[ImaginaryI]\ \
\[Theta]\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X\[Theta]\  = \ 
        X\[Theta]\  // \ Simplify;\)\), "\[IndentingNewLine]", 
    \(X\[Theta]\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\/4\ \[ExponentialE]\^\(\(-199\)\ \[ImaginaryI]\ \
\[Theta]\)\ \((\(-1\) - \@5 + 
          2\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) + \((\(-3\) + \
\@5)\)\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \[Theta]\) + 
          4\ \[ExponentialE]\^\(3\ \[ImaginaryI]\ \[Theta]\))\)\ \((\(-1\) - \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(5\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(6\ \[ImaginaryI]\ \[Theta]\) - \
\[ExponentialE]\^\(10\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(11\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(15\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(16\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(20\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(21\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(25\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(26\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(30\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(31\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(35\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(36\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(40\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(41\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(45\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(46\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(50\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(51\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(55\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(56\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(60\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(61\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(65\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(66\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(70\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(71\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(75\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(76\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(80\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(81\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(85\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(86\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(90\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(91\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(95\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(96\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(100\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(101\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(105\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(106\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(110\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(111\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(115\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(116\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(120\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(121\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(125\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(126\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(130\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(131\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(135\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(136\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(140\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(141\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(145\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(146\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(150\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(151\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(155\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(156\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(160\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(161\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(165\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(166\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(170\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(171\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(175\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(176\ \
\[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(180\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(181\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(185\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(186\ \[ImaginaryI]\ \[Theta]\) \
- \[ExponentialE]\^\(190\ \[ImaginaryI]\ \[Theta]\) - \[ExponentialE]\^\(191\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(195\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(196\ \[ImaginaryI]\ \[Theta]\))\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plots of DTFT", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g1 = 
        Plot[Abs[X\[Theta]], {\[Theta], \(-\[Pi]\), \[Pi]}, \ 
          PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[Arg[X\[Theta]], {\[Theta], \(-\[Pi]\), \[Pi]}, \ 
          PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.0147151 0.00588579 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13243 -12 -4.5 ]
[-0.0125 .13243 0 4.5 ]
[-0.0125 .25015 -12 -4.5 ]
[-0.0125 .25015 0 4.5 ]
[-0.0125 .36786 -12 -4.5 ]
[-0.0125 .36786 0 4.5 ]
[-0.0125 .48558 -12 -4.5 ]
[-0.0125 .48558 0 4.5 ]
[-0.0125 .60329 -18 -4.5 ]
[-0.0125 .60329 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13243 m
.00625 .13243 L
s
[(20)] -0.0125 .13243 1 0 Mshowa
0 .25015 m
.00625 .25015 L
s
[(40)] -0.0125 .25015 1 0 Mshowa
0 .36786 m
.00625 .36786 L
s
[(60)] -0.0125 .36786 1 0 Mshowa
0 .48558 m
.00625 .48558 L
s
[(80)] -0.0125 .48558 1 0 Mshowa
0 .60329 m
.00625 .60329 L
s
[(100)] -0.0125 .60329 1 0 Mshowa
.125 Mabswid
0 .04414 m
.00375 .04414 L
s
0 .07357 m
.00375 .07357 L
s
0 .103 m
.00375 .103 L
s
0 .16186 m
.00375 .16186 L
s
0 .19129 m
.00375 .19129 L
s
0 .22072 m
.00375 .22072 L
s
0 .27958 m
.00375 .27958 L
s
0 .309 m
.00375 .309 L
s
0 .33843 m
.00375 .33843 L
s
0 .39729 m
.00375 .39729 L
s
0 .42672 m
.00375 .42672 L
s
0 .45615 m
.00375 .45615 L
s
0 .51501 m
.00375 .51501 L
s
0 .54444 m
.00375 .54444 L
s
0 .57386 m
.00375 .57386 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13243 m
1 .13243 L
s
.99375 .25015 m
1 .25015 L
s
.99375 .36786 m
1 .36786 L
s
.99375 .48558 m
1 .48558 L
s
.99375 .60329 m
1 .60329 L
s
.125 Mabswid
.99625 .04414 m
1 .04414 L
s
.99625 .07357 m
1 .07357 L
s
.99625 .103 m
1 .103 L
s
.99625 .16186 m
1 .16186 L
s
.99625 .19129 m
1 .19129 L
s
.99625 .22072 m
1 .22072 L
s
.99625 .27958 m
1 .27958 L
s
.99625 .309 m
1 .309 L
s
.99625 .33843 m
1 .33843 L
s
.99625 .39729 m
1 .39729 L
s
.99625 .42672 m
1 .42672 L
s
.99625 .45615 m
1 .45615 L
s
.99625 .51501 m
1 .51501 L
s
.99625 .54444 m
1 .54444 L
s
.99625 .57386 m
1 .57386 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02847 .01511 L
.02964 .01853 L
.02998 .01943 L
.03014 .01978 L
.0303 .02006 L
.03043 .02026 L
.03058 .02043 L
.03073 .02054 L
.03082 .02058 L
.03089 .0206 L
.03098 .0206 L
.03107 .02058 L
.03116 .02055 L
.03124 .0205 L
.03139 .02036 L
.03156 .02014 L
.03175 .01981 L
.03193 .01942 L
.03227 .01852 L
.03289 .0164 L
.03304 .01583 L
.03321 .01521 L
.0333 .01485 L
.03338 .01491 L
.03347 .01524 L
.03355 .01556 L
.03412 .01765 L
.03442 .0186 L
.03474 .01944 L
.03502 .01999 L
.03517 .02023 L
.03532 .0204 L
.03545 .02052 L
.03557 .02058 L
.0357 .02061 L
.03584 .02059 L
.036 .0205 L
.03614 .02038 L
.0363 .02017 L
.03646 .01991 L
.03673 .01933 L
.03703 .01853 L
.03735 .0175 L
.0377 .01625 L
.03786 .01561 L
.03802 .01499 L
.03817 .01499 L
.03832 .0156 L
.03888 .01762 L
Mistroke
.03918 .01858 L
.03946 .01935 L
.03963 .01971 L
.03981 .02004 L
.03997 .02028 L
.04012 .02045 L
.04026 .02055 L
.04041 .02061 L
.04049 .02061 L
.04057 .0206 L
.04072 .02054 L
.0408 .02048 L
.04089 .02039 L
.04105 .0202 L
.04122 .01992 L
.0414 .01954 L
.04205 .01771 L
.04235 .01666 L
.04251 .01607 L
.04267 .01543 L
.04282 .01486 L
.04298 .01519 L
.04312 .01575 L
.04326 .01626 L
.04387 .01837 L
.04419 .01926 L
.04437 .01967 L
.04453 .01999 L
.04469 .02023 L
.04483 .0204 L
.04499 .02054 L
.04507 .02058 L
.04516 .02061 L
.0453 .02061 L
.04543 .02057 L
.04558 .02047 L
.04573 .02031 L
.04587 .02012 L
.04599 .0199 L
.04628 .01928 L
.0468 .01777 L
.04737 .01568 L
.04751 .01515 L
.04766 .01487 L
.04774 .0152 L
.04782 .0155 L
.04797 .01608 L
.04856 .01814 L
.04888 .01907 L
.04918 .01977 L
Mistroke
.04943 .02021 L
.04957 .02039 L
.0497 .02051 L
.04985 .0206 L
.05 .02063 L
.05015 .0206 L
.05028 .02052 L
.05044 .02038 L
.05053 .02027 L
.05061 .02015 L
.05092 .01957 L
.0512 .01887 L
.0515 .01797 L
.0518 .01694 L
.05211 .01575 L
.05221 .01539 L
.0523 .01504 L
.05238 .01473 L
.05246 .01504 L
.05279 .0163 L
.05334 .01821 L
.05362 .01905 L
.05393 .01976 L
.05409 .02006 L
.05426 .02032 L
.05434 .02041 L
.05442 .02049 L
.05457 .02059 L
.05465 .02062 L
.05474 .02064 L
.05489 .02062 L
.05504 .02054 L
.05518 .02042 L
.05532 .02024 L
.05548 .01999 L
.05576 .01939 L
.05641 .01747 L
.05676 .0162 L
.05693 .01554 L
.05709 .01492 L
.05723 .01507 L
.05739 .01567 L
.05771 .01689 L
.05832 .01887 L
.05862 .01963 L
.0588 .01998 L
.05896 .02024 L
.05913 .02045 L
.05923 .02054 L
.05932 .0206 L
Mistroke
.0594 .02063 L
.05948 .02065 L
.05957 .02065 L
.05966 .02063 L
.05982 .02054 L
.05996 .0204 L
.06013 .02019 L
.0603 .01989 L
.06061 .01919 L
.06095 .01821 L
.06125 .01719 L
.06157 .01601 L
.06174 .01538 L
.06189 .01478 L
.06203 .01519 L
.06218 .01577 L
.06274 .01781 L
.06302 .01871 L
.06333 .01952 L
.06348 .01984 L
.06362 .0201 L
.06374 .02029 L
.06388 .02045 L
.06403 .02058 L
.06412 .02063 L
.06419 .02065 L
.06433 .02066 L
.06448 .02062 L
.06456 .02057 L
.06465 .0205 L
.06483 .02029 L
.06499 .02004 L
.06514 .01975 L
.06578 .01799 L
.06637 .01588 L
.06652 .01527 L
.06661 .01494 L
.06669 .01481 L
.06678 .01515 L
.06687 .01553 L
.06704 .01618 L
.06768 .01841 L
.06797 .01923 L
.06828 .01993 L
.06846 .02023 L
.06862 .02044 L
.0687 .02052 L
.06878 .02059 L
.06893 .02066 L
.06908 .02068 L
Mistroke
.06924 .02064 L
.06932 .02059 L
.0694 .02052 L
.06955 .02035 L
.06971 .02013 L
.06985 .01986 L
.07013 .01924 L
.07068 .01754 L
.0712 .01563 L
.07133 .01512 L
.07146 .01486 L
.07162 .01546 L
.07176 .01602 L
.07236 .01816 L
.07265 .01903 L
.07296 .01978 L
.07311 .02007 L
.07325 .0203 L
.07338 .02046 L
.07352 .02059 L
.07367 .02067 L
.07376 .0207 L
.07384 .0207 L
.07392 .02068 L
.074 .02065 L
.07409 .0206 L
.07417 .02053 L
.07433 .02036 L
.07446 .02015 L
.07478 .01952 L
.07508 .01871 L
.07537 .01781 L
.0757 .0166 L
.07585 .01604 L
.07601 .01541 L
.07617 .01478 L
.07632 .01523 L
.07665 .01649 L
.077 .01777 L
.07733 .0188 L
.07762 .01956 L
.07793 .02019 L
.0781 .02043 L
.07825 .02059 L
.07834 .02065 L
.07842 .02069 L
.07851 .02071 L
.07859 .02072 L
.07874 .02069 L
.07889 .02059 L
Mistroke
.07903 .02044 L
.07917 .02027 L
.07949 .01966 L
.07979 .01889 L
.08031 .01718 L
.0806 .0161 L
.08074 .01556 L
.08087 .01506 L
.08101 .01493 L
.08116 .01552 L
.08147 .01674 L
.08203 .01865 L
.08233 .01946 L
.08261 .02007 L
.08275 .0203 L
.0829 .0205 L
.08299 .02058 L
.08307 .02065 L
.08323 .02073 L
.08336 .02074 L
.0835 .02071 L
.08363 .02063 L
.08375 .02051 L
.0839 .02033 L
.08405 .02008 L
.08433 .01948 L
.08497 .01758 L
.08531 .0163 L
.08548 .01564 L
.08564 .01503 L
.08578 .01497 L
.08591 .0155 L
.08621 .01665 L
.08653 .01782 L
.08684 .01879 L
.08713 .01958 L
.08728 .01992 L
.08745 .02022 L
.08758 .02042 L
.08773 .02059 L
.08787 .0207 L
.088 .02075 L
.08807 .02077 L
.08816 .02076 L
.08831 .02071 L
.08846 .0206 L
.08859 .02045 L
.08874 .02023 L
.0889 .01993 L
.08923 .01915 L
Mistroke
.08978 .01739 L
.09009 .01626 L
.09024 .01567 L
.09038 .01511 L
.09051 .01483 L
.09064 .01539 L
.09094 .01653 L
.09145 .01835 L
.09176 .01927 L
.09194 .0197 L
.0921 .02004 L
.09224 .0203 L
.09238 .02049 L
.09253 .02065 L
.09261 .02071 L
.09269 .02075 L
.09277 .02078 L
.09285 .02079 L
.09294 .02078 L
.09302 .02076 L
.09317 .02067 L
.09325 .02059 L
.09333 .0205 L
.09349 .02027 L
.09367 .01994 L
.09403 .01907 L
.09464 .01706 L
.0948 .01645 L
.09497 .01577 L
.09505 .01546 L
.09514 .01512 L
.09529 .01492 L
.09544 .01553 L
.09558 .01609 L
.0959 .01731 L
.09646 .01912 L
.09677 .01989 L
.09692 .02018 L
.09706 .02041 L
.09714 .02052 L
.09723 .02062 L
.09738 .02074 L
.09746 .02079 L
.09755 .02082 L
.09763 .02082 L
.09772 .02081 L
.09787 .02074 L
.09801 .02062 L
.09809 .02053 L
.09818 .02042 L
Mistroke
.09833 .02016 L
.09863 .01952 L
.09891 .01875 L
.09947 .01683 L
.09974 .01576 L
.09986 .01528 L
.09999 .01475 L
.10012 .01519 L
.10025 .01574 L
.10054 .01684 L
.10114 .01891 L
.10145 .01972 L
.10161 .02007 L
.10178 .02037 L
.10193 .02058 L
.10201 .02067 L
.10209 .02074 L
.10224 .02083 L
.10238 .02085 L
.10253 .02082 L
.10268 .02073 L
.10283 .02058 L
.10297 .0204 L
.10323 .01992 L
.10351 .01924 L
.10419 .01697 L
.10436 .01634 L
.10453 .01566 L
.10467 .01507 L
.10476 .01473 L
.10484 .01502 L
.10541 .01728 L
.10574 .01841 L
.10604 .01931 L
.10633 .02002 L
.10648 .0203 L
.10664 .02055 L
.10673 .02065 L
.10681 .02073 L
.10696 .02084 L
.10704 .02087 L
.10713 .02088 L
.10722 .02088 L
.1073 .02085 L
.10746 .02075 L
.10761 .0206 L
.10774 .02042 L
.10788 .02017 L
.1082 .01944 L
.1085 .01858 L
Mistroke
.10906 .01657 L
.1092 .01601 L
.10934 .01548 L
.10946 .01499 L
.10959 .01498 L
.10973 .01553 L
.10985 .01605 L
.11014 .01715 L
.11045 .01827 L
.11074 .01917 L
.11101 .01985 L
.1113 .02042 L
.11145 .02064 L
.11159 .02078 L
.11174 .02088 L
.11182 .02091 L
.1119 .02092 L
.11204 .0209 L
.11217 .02083 L
.11231 .0207 L
.11246 .02051 L
.11271 .02007 L
.11299 .0194 L
.11361 .0174 L
.11395 .01609 L
.11412 .01541 L
.11427 .01477 L
.11442 .01526 L
.11457 .01589 L
.1149 .01717 L
.11547 .01912 L
.11579 .01993 L
.11596 .02029 L
.11612 .02055 L
.11626 .02073 L
.11641 .02086 L
.11649 .02091 L
.11657 .02094 L
.11672 .02095 L
.11679 .02094 L
.11688 .0209 L
.11697 .02084 L
.11705 .02076 L
.1172 .02058 L
.11736 .02032 L
.11773 .0195 L
.11806 .01851 L
.11836 .01746 L
.11868 .01624 L
.11883 .01561 L
Mistroke
.11897 .01502 L
.11911 .01495 L
.11925 .01554 L
.11984 .01786 L
.12016 .01891 L
.12049 .01983 L
.12065 .02019 L
.1208 .02047 L
.12095 .02068 L
.12109 .02083 L
.12121 .02093 L
.12135 .02099 L
.12149 .02099 L
.12164 .02094 L
.12172 .02089 L
.1218 .02081 L
.12195 .02063 L
.12211 .02038 L
.12229 .02002 L
.1229 .01828 L
.12322 .01709 L
.12353 .01587 L
.1237 .01516 L
.1238 .01476 L
.12389 .01504 L
.12421 .01636 L
.1248 .01855 L
.12513 .01954 L
.12529 .01994 L
.12544 .02026 L
.12559 .02054 L
.12573 .02074 L
.12588 .02091 L
.12596 .02097 L
.12604 .02101 L
.12618 .02104 L
.12631 .02102 L
.12645 .02095 L
.1266 .02081 L
.12673 .02065 L
.12687 .02042 L
.12712 .01989 L
.12769 .01818 L
.12801 .01699 L
.12818 .01632 L
.12836 .01558 L
.12852 .01493 L
.12861 .01487 L
.12869 .01522 L
.129 .01647 L
Mistroke
.12961 .01874 L
.12989 .01957 L
.13018 .02027 L
.13034 .02056 L
.13048 .02077 L
.13061 .02092 L
.13075 .02103 L
.13091 .02108 L
.13099 .02108 L
.13107 .02107 L
.13123 .02098 L
.13137 .02085 L
.13145 .02075 L
.13153 .02063 L
.13168 .02036 L
.13197 .01971 L
.13262 .01762 L
.13291 .01649 L
.13318 .01536 L
.13333 .01473 L
.13341 .01506 L
.13349 .01539 L
.13378 .01656 L
.13434 .01866 L
.13458 .01942 L
.13485 .02011 L
.135 .02043 L
.13514 .02068 L
.13528 .02086 L
.13542 .02101 L
.13557 .0211 L
.13571 .02113 L
.13586 .0211 L
.13595 .02106 L
.13603 .021 L
.13617 .02085 L
.1363 .02067 L
.13659 .0201 L
.13685 .01942 L
.13713 .01855 L
.13745 .01737 L
.1378 .01596 L
.13796 .01529 L
.13804 .01494 L
.13813 .01486 L
.13829 .01553 L
.13843 .01615 L
.13905 .01852 L
.13932 .01939 L
.13962 .02017 L
Mistroke
.13976 .02047 L
.13991 .02074 L
.14 .02086 L
.14007 .02095 L
.14022 .02109 L
.14038 .02117 L
.14046 .02118 L
.14054 .02118 L
.14063 .02115 L
.14071 .02111 L
.1408 .02104 L
.14088 .02096 L
.14102 .02077 L
.14118 .02051 L
.14145 .0199 L
.14175 .01904 L
.14207 .01792 L
.14236 .01681 L
.14263 .01568 L
.14278 .01504 L
.14287 .01475 L
.14294 .01509 L
.14323 .0163 L
.14379 .01848 L
.14404 .01929 L
.14431 .02005 L
.14461 .02068 L
.14477 .02093 L
.14492 .02109 L
.14501 .02116 L
.14509 .0212 L
.14524 .02124 L
.14533 .02123 L
.14541 .0212 L
.1455 .02115 L
.14559 .02107 L
.14573 .0209 L
.14588 .02066 L
.14616 .02008 L
.14649 .01915 L
.14679 .01812 L
.14731 .01603 L
.14746 .01542 L
.14761 .01476 L
.14775 .01529 L
.14788 .01585 L
.14843 .01807 L
.14874 .01915 L
.14903 .01999 L
.14932 .02063 L
Mistroke
.14948 .0209 L
.14962 .02108 L
.14977 .02122 L
.14986 .02126 L
.14994 .02129 L
.15009 .02128 L
.15024 .02121 L
.15037 .0211 L
.15051 .02093 L
.15065 .02071 L
.15077 .02047 L
.15105 .01978 L
.15135 .01886 L
.15193 .01665 L
.1521 .01595 L
.15225 .01527 L
.1524 .01478 L
.15255 .01545 L
.15323 .01822 L
.15353 .01928 L
.15386 .0202 L
.15402 .02056 L
.15417 .02084 L
.1543 .02104 L
.15445 .02121 L
.15459 .02131 L
.15473 .02135 L
.15487 .02134 L
.155 .02127 L
.15508 .02121 L
.15516 .02113 L
.15531 .02093 L
.15547 .02065 L
.15565 .02027 L
.15625 .0184 L
.15658 .01714 L
.15689 .01584 L
.15706 .01509 L
.15715 .01476 L
.15724 .01515 L
.15757 .01655 L
.15815 .01885 L
.15846 .01983 L
.15863 .02028 L
.15879 .02064 L
.15894 .02092 L
.15908 .02112 L
.15923 .02129 L
.15932 .02135 L
.1594 .02139 L
Mistroke
.15953 .02142 L
.15966 .02139 L
.1598 .02131 L
.15995 .02116 L
.16008 .02098 L
.16022 .02073 L
.16047 .02016 L
.16104 .01834 L
.16136 .01708 L
.16153 .01637 L
.16171 .01559 L
.1618 .0152 L
.16188 .01483 L
.16204 .01529 L
.16218 .01594 L
.16234 .01662 L
.16295 .01902 L
.16325 .01996 L
.16353 .02064 L
.16366 .02091 L
.16381 .02115 L
.16395 .02131 L
.16408 .02142 L
.16422 .02147 L
.16437 .02147 L
.16453 .0214 L
.16468 .02127 L
.16483 .02106 L
.16499 .02077 L
.16528 .02008 L
.16559 .01913 L
.16594 .01787 L
.16626 .0165 L
.16642 .0158 L
.16657 .01514 L
.16666 .01476 L
.16674 .01506 L
.16693 .01589 L
.16725 .01729 L
.16758 .01858 L
.16789 .01965 L
.1682 .02049 L
.16833 .02079 L
.16848 .02107 L
.16861 .02127 L
.16874 .02141 L
.16888 .02151 L
.16902 .02155 L
.16918 .02153 L
.16933 .02143 L
Mistroke
.16947 .02129 L
.16962 .02108 L
.16978 .02078 L
.16993 .02045 L
.17025 .01952 L
.17084 .0173 L
.17111 .01616 L
.17125 .01551 L
.17139 .0149 L
.17153 .0152 L
.17161 .01555 L
.1717 .01592 L
.17198 .01716 L
.1725 .01919 L
.17278 .02009 L
.17305 .02077 L
.17321 .02109 L
.1733 .02123 L
.17339 .02135 L
.17354 .02151 L
.17369 .0216 L
.17383 .02163 L
.17397 .02159 L
.17411 .02149 L
.17427 .02131 L
.17444 .02104 L
.17463 .02065 L
.17497 .01971 L
.1756 .01733 L
.17592 .01595 L
.17607 .01525 L
.17622 .01483 L
.17636 .01551 L
.17652 .01623 L
.17686 .01771 L
.17743 .0198 L
.17772 .02061 L
.17788 .02098 L
.17803 .02125 L
.17818 .02146 L
.17833 .02161 L
.17849 .02169 L
.17858 .0217 L
.17867 .02169 L
.17882 .02162 L
.17896 .02149 L
.17903 .02139 L
.17912 .02127 L
.17927 .02099 L
.17955 .02031 L
Mistroke
.17985 .01936 L
.1804 .01724 L
.18072 .01577 L
.18081 .01536 L
.18091 .01492 L
.18099 .01489 L
.18108 .0153 L
.18172 .01814 L
.18202 .01929 L
.18234 .02032 L
.1825 .02073 L
.18265 .02106 L
.18279 .02133 L
.18292 .02152 L
.18306 .02167 L
.18321 .02176 L
.18335 .02179 L
.18348 .02176 L
.18363 .02166 L
.18377 .0215 L
.18393 .02126 L
.18409 .02093 L
.18443 .02004 L
.18474 .01896 L
.18503 .01782 L
.18533 .01649 L
.18546 .01591 L
.1856 .01527 L
.18575 .01487 L
.18589 .01552 L
.1864 .01782 L
.18671 .01907 L
.187 .02008 L
.18727 .02082 L
.18742 .02116 L
.18755 .02141 L
.18769 .02161 L
.18784 .02176 L
.18798 .02185 L
.18814 .02187 L
.18828 .02183 L
.18842 .02171 L
.18856 .02155 L
.18869 .02134 L
.189 .02066 L
.18933 .01964 L
.18994 .01721 L
.1901 .01649 L
.19027 .0157 L
.19035 .01531 L
Mistroke
.19043 .01493 L
.19058 .0152 L
.19073 .01593 L
.1909 .01671 L
.19126 .01827 L
.19156 .01946 L
.19189 .02051 L
.19204 .02093 L
.19219 .02127 L
.19234 .02154 L
.19247 .02172 L
.19261 .02187 L
.19276 .02195 L
.1929 .02196 L
.19303 .02192 L
.19319 .0218 L
.19333 .02162 L
.19349 .02136 L
.19365 .021 L
.19396 .02015 L
.19424 .01915 L
.19456 .01786 L
.1949 .01634 L
.19503 .01573 L
.19516 .01507 L
.19532 .01509 L
.19546 .01577 L
.19597 .01811 L
.19628 .01937 L
.19658 .02037 L
.19684 .0211 L
.19699 .02142 L
.19713 .02167 L
.19727 .02186 L
.19741 .02199 L
.19756 .02205 L
.19764 .02206 L
.19772 .02205 L
.19784 .02198 L
.19799 .02185 L
.19813 .02165 L
.19827 .02141 L
.19859 .02063 L
.19887 .0197 L
.19921 .01838 L
.19953 .01698 L
.19981 .01563 L
.19989 .01523 L
.19997 .01485 L
.20012 .01529 L
Mistroke
.2002 .01567 L
.20028 .01607 L
.20043 .01677 L
.20076 .01829 L
.20106 .0195 L
.20138 .02059 L
.20157 .0211 L
.20174 .02149 L
.20191 .02179 L
.20199 .02191 L
.20207 .022 L
.20222 .02211 L
.2023 .02215 L
.20238 .02216 L
.20252 .02213 L
.20267 .02203 L
.20281 .02187 L
.20296 .02164 L
.20322 .02106 L
.20355 .02006 L
.20387 .01888 L
.20415 .01764 L
.20446 .01622 L
.20458 .0156 L
.20472 .01493 L
.20487 .01524 L
.20501 .01593 L
.20552 .01831 L
.20581 .01952 L
.20612 .0206 L
.20638 .02133 L
.20653 .02164 L
.20667 .0219 L
.20683 .02211 L
.20698 .02222 L
.20714 .02227 L
.20723 .02226 L
.20731 .02223 L
.20746 .02211 L
.2076 .02194 L
.20776 .02166 L
.20791 .02133 L
.20819 .02055 L
.20845 .01964 L
.20904 .0171 L
.2092 .01633 L
.20937 .01548 L
.20945 .01509 L
.20953 .01476 L
.20968 .01551 L
Mistroke
.21026 .01829 L
.21056 .01955 L
.21089 .02069 L
.21107 .02123 L
.21124 .02164 L
.21141 .02196 L
.21149 .02209 L
.21157 .02219 L
.2117 .02231 L
.21185 .02238 L
.21199 .02237 L
.21212 .02231 L
.21227 .02217 L
.21242 .02196 L
.21257 .02167 L
.21273 .02128 L
.21307 .02025 L
.21338 .01903 L
.21367 .01776 L
.21397 .01629 L
.2141 .01565 L
.21424 .01496 L
.21439 .01524 L
.21453 .01595 L
.21504 .01842 L
.21535 .01973 L
.21565 .02078 L
.21591 .02153 L
.21606 .02187 L
.2162 .02212 L
.21633 .02231 L
.21648 .02244 L
.21662 .0225 L
.21678 .02248 L
.21692 .0224 L
.21706 .02225 L
.2172 .02203 L
.21733 .02179 L
.21764 .02098 L
.21797 .01981 L
.21858 .0171 L
.21888 .01556 L
.21897 .01513 L
.21906 .01477 L
.21914 .0152 L
.21922 .0156 L
.2199 .0189 L
.2202 .02013 L
.22052 .02123 L
.22067 .02164 L
Mistroke
.22083 .022 L
.22098 .02227 L
.22111 .02245 L
.22126 .02258 L
.22139 .02263 L
.22154 .02261 L
.2217 .02251 L
.22178 .02243 L
.22187 .02231 L
.22203 .02204 L
.22232 .02131 L
.2226 .02039 L
.2229 .0192 L
.22344 .01666 L
.22358 .01591 L
.22373 .01512 L
.22381 .01473 L
.2239 .01519 L
.22405 .01599 L
.22463 .01884 L
.22496 .02023 L
.22531 .02143 L
.22548 .02189 L
.22565 .02224 L
.22579 .02248 L
.22595 .02265 L
.2261 .02275 L
.22623 .02276 L
.22639 .0227 L
.22654 .02256 L
.22668 .02237 L
.2268 .02213 L
.22709 .0214 L
.22741 .02032 L
.2277 .01911 L
.22804 .01751 L
.22819 .01675 L
.22835 .0159 L
.22851 .01506 L
.22865 .01516 L
.22881 .01599 L
.22898 .01687 L
.22933 .01861 L
.22966 .02007 L
.22997 .02121 L
.23013 .0217 L
.2303 .02214 L
.23045 .02244 L
.23052 .02257 L
.23061 .02268 L
Mistroke
.23075 .02283 L
.23089 .0229 L
.23097 .02291 L
.23105 .02289 L
.23119 .02281 L
.23135 .02264 L
.23144 .0225 L
.23152 .02236 L
.2318 .02167 L
.23211 .02067 L
.23279 .01759 L
.23297 .0167 L
.23313 .01582 L
.23328 .01503 L
.23336 .01486 L
.23344 .01527 L
.23399 .01821 L
.23459 .02084 L
.23488 .02181 L
.23505 .02225 L
.23521 .02258 L
.23537 .02283 L
.23545 .02292 L
.23554 .023 L
.23569 .02306 L
.23578 .02305 L
.23586 .02302 L
.23601 .02291 L
.23609 .02281 L
.23618 .02269 L
.23633 .0224 L
.23647 .02207 L
.23679 .02108 L
.23713 .01971 L
.23742 .01832 L
.23774 .01666 L
.23789 .01586 L
.23805 .01499 L
.23819 .01525 L
.23833 .01599 L
.23893 .01913 L
.23923 .02045 L
.2395 .02148 L
.23975 .02223 L
.23988 .02254 L
.24001 .0228 L
.24015 .02301 L
.24028 .02314 L
.24043 .02321 L
.24057 .0232 L
Mistroke
.24071 .02312 L
.24084 .02298 L
.24099 .02275 L
.24115 .02241 L
.24147 .02148 L
.24177 .02035 L
.24234 .01758 L
.24262 .01605 L
.24274 .01537 L
.24287 .01481 L
.24302 .01563 L
.24316 .0164 L
.24346 .01803 L
.24409 .021 L
.24442 .02213 L
.24458 .02257 L
.24476 .02295 L
.24492 .02318 L
.245 .02327 L
.24508 .02333 L
.24523 .02339 L
.24538 .02335 L
.24552 .02325 L
.24566 .02306 L
.2458 .02281 L
.24593 .02252 L
.24623 .02163 L
.24654 .02041 L
.24685 .01895 L
.24718 .01721 L
.24734 .01631 L
.24749 .01544 L
.24763 .01477 L
.24778 .01563 L
.24829 .01849 L
.24884 .02105 L
.24912 .0221 L
.24928 .02255 L
.24944 .02295 L
.24959 .02323 L
.24973 .02341 L
.24987 .02353 L
.25 .02357 L
.25015 .02353 L
.25023 .02347 L
.25031 .02339 L
.25045 .02319 L
.2506 .02289 L
.25087 .02219 L
.25115 .02115 L
Mistroke
.25179 .01809 L
.2521 .01637 L
.25225 .01549 L
.25239 .01476 L
.25252 .01552 L
.25266 .01633 L
.25295 .01799 L
.25346 .02058 L
.25372 .02168 L
.254 .02262 L
.25417 .02305 L
.25431 .02335 L
.25446 .02356 L
.25461 .02371 L
.25476 .02376 L
.25484 .02375 L
.25492 .02372 L
.25506 .0236 L
.25521 .02339 L
.25534 .02312 L
.25547 .02281 L
.25576 .02191 L
.25635 .01926 L
.25666 .01759 L
.25682 .01666 L
.25699 .01564 L
.25707 .01514 L
.25715 .01476 L
.2573 .01564 L
.25758 .01734 L
.25815 .02036 L
.25839 .02148 L
.25865 .02245 L
.25879 .02288 L
.25894 .02327 L
.25908 .02355 L
.2592 .02375 L
.25936 .0239 L
.25943 .02394 L
.25952 .02396 L
.25967 .02393 L
.25981 .02381 L
.2599 .0237 L
.25998 .02358 L
.26013 .02327 L
.26029 .02284 L
.26047 .02226 L
.26109 .01949 L
.26139 .01785 L
.26167 .01619 L
Mistroke
.2618 .01537 L
.26194 .01492 L
.26209 .01587 L
.26223 .01673 L
.26275 .01968 L
.2633 .02222 L
.26345 .02275 L
.26361 .02324 L
.26376 .02361 L
.26391 .02387 L
.26405 .02406 L
.26413 .02413 L
.26421 .02417 L
.2643 .02419 L
.26438 .02417 L
.26454 .02406 L
.26469 .02387 L
.26482 .02362 L
.26497 .02326 L
.26513 .02278 L
.26549 .02139 L
.26583 .01972 L
.26614 .01798 L
.26631 .01696 L
.26647 .01598 L
.2666 .01511 L
.26675 .01526 L
.26684 .0158 L
.26692 .01631 L
.26707 .01725 L
.26763 .02043 L
.26792 .02182 L
.26823 .02302 L
.26841 .02355 L
.26857 .02393 L
.26865 .02407 L
.26874 .0242 L
.26889 .02436 L
.26904 .02442 L
.26918 .02439 L
.26934 .02426 L
.26949 .02404 L
.26962 .02375 L
.26975 .02342 L
.27004 .02245 L
.27033 .02119 L
.27065 .01952 L
.27099 .01751 L
.27114 .01659 L
.27122 .01609 L
Mistroke
.2713 .01555 L
.27146 .01491 L
.27161 .01587 L
.27193 .01792 L
.27228 .01998 L
.27261 .02167 L
.27292 .02297 L
.27308 .02352 L
.27326 .02399 L
.2734 .02429 L
.27356 .02453 L
.27371 .02464 L
.27384 .02467 L
.27399 .02461 L
.27407 .02454 L
.27415 .02444 L
.2743 .02418 L
.27444 .02385 L
.27476 .02283 L
.2751 .02133 L
.27568 .01804 L
.27583 .01707 L
.276 .016 L
.27615 .01498 L
.27629 .01539 L
.27643 .0163 L
.27658 .01727 L
.27685 .01897 L
.27714 .02069 L
.27746 .02226 L
.27772 .02334 L
.27786 .02381 L
.27801 .02423 L
.27815 .02453 L
.27828 .02474 L
.27841 .02487 L
.27853 .02494 L
.27868 .02493 L
.27876 .02487 L
.27884 .0248 L
.27898 .02459 L
.27913 .02428 L
.2794 .02351 L
.27968 .02236 L
.28032 .01889 L
.28063 .01691 L
.28078 .0159 L
.28092 .01495 L
.28105 .01537 L
.28119 .01631 L
Mistroke
.28148 .01825 L
.28199 .0213 L
.28225 .02261 L
.28253 .02376 L
.2827 .02428 L
.28284 .02466 L
.28299 .02494 L
.28314 .02513 L
.28328 .02523 L
.28337 .02524 L
.28345 .02522 L
.28359 .02511 L
.28374 .02489 L
.28387 .02461 L
.284 .02428 L
.28429 .02327 L
.2846 .02184 L
.28488 .02027 L
.28521 .01819 L
.28537 .01711 L
.28552 .0161 L
.28565 .01515 L
.28578 .01518 L
.28591 .01612 L
.28606 .01714 L
.28665 .02095 L
.28693 .02243 L
.28722 .02373 L
.28746 .02458 L
.2876 .02495 L
.28773 .02522 L
.28788 .02543 L
.28796 .0255 L
.28805 .02554 L
.2882 .02554 L
.28834 .02543 L
.28842 .02533 L
.2885 .02519 L
.28865 .02486 L
.28882 .02439 L
.289 .02375 L
.28962 .0206 L
.28991 .0187 L
.29019 .01676 L
.29032 .01581 L
.29046 .0148 L
.29062 .01575 L
.29076 .01677 L
.29128 .02028 L
.29183 .02335 L
Mistroke
.29198 .02401 L
.29214 .02462 L
.29229 .02508 L
.29243 .02543 L
.29258 .02569 L
.29266 .02578 L
.29274 .02585 L
.29282 .02589 L
.29291 .02589 L
.29307 .0258 L
.29321 .02562 L
.29335 .02535 L
.2935 .02496 L
.29366 .02443 L
.29402 .02285 L
.29436 .02093 L
.29466 .0189 L
.29499 .01656 L
.29513 .01553 L
.29528 .01502 L
.29536 .01566 L
.29544 .01624 L
.2956 .01738 L
.29615 .02121 L
.29646 .023 L
.29663 .02382 L
.2968 .02457 L
.29697 .02517 L
.29712 .02561 L
.29727 .02594 L
.29742 .02615 L
.29756 .02626 L
.29771 .02626 L
.29785 .02616 L
.29798 .02597 L
.29813 .02566 L
.2983 .02519 L
.2986 .02402 L
.29891 .0224 L
.29924 .02032 L
.29953 .01829 L
.29968 .01716 L
.29984 .01595 L
.29998 .0149 L
.30013 .01569 L
.30026 .01673 L
.30039 .01769 L
.3009 .02133 L
.30119 .0231 L
.30147 .02449 L
Mistroke
.30162 .02513 L
.30178 .0257 L
.30193 .02612 L
.30207 .0264 L
.30222 .0266 L
.30236 .02668 L
.30249 .02665 L
.30263 .02653 L
.30279 .02629 L
.30287 .0261 L
.30295 .0259 L
.30324 .02487 L
.30351 .02358 L
.3038 .02186 L
.30433 .0181 L
.30448 .01697 L
.30464 .01573 L
.30473 .01501 L
.30481 .01507 L
.30497 .01635 L
.30563 .02137 L
.30593 .02325 L
.30624 .02494 L
.30639 .02556 L
.30655 .02612 L
.30668 .0265 L
.30682 .02682 L
.30698 .02704 L
.30712 .02712 L
.30728 .02709 L
.30737 .02701 L
.30745 .0269 L
.3076 .02661 L
.30776 .02617 L
.30805 .02506 L
.30833 .0236 L
.30863 .02171 L
.30916 .01768 L
.30932 .01642 L
.30946 .01522 L
.30954 .01489 L
.30963 .01562 L
.30978 .01689 L
.31036 .02142 L
.3107 .02364 L
.31105 .02553 L
.31119 .02615 L
.31135 .0267 L
.31144 .02696 L
.31152 .02716 L
Mistroke
.3116 .02732 L
.31168 .02745 L
.31184 .02759 L
.31198 .02761 L
.31212 .02751 L
.31225 .02731 L
.31239 .027 L
.31255 .02653 L
.31286 .0252 L
.31314 .02367 L
.31343 .02169 L
.31396 .01748 L
.31412 .01616 L
.3142 .01543 L
.31428 .01473 L
.31438 .01552 L
.31446 .01627 L
.31463 .01771 L
.31527 .02273 L
.31555 .02456 L
.31584 .02613 L
.31599 .02679 L
.31616 .02737 L
.31632 .02776 L
.31646 .02801 L
.31661 .02814 L
.31669 .02816 L
.31677 .02814 L
.31692 .02799 L
.31707 .02774 L
.31715 .02755 L
.31723 .0273 L
.31738 .02676 L
.31772 .02512 L
.31829 .02122 L
.31862 .01851 L
.31876 .01726 L
.31892 .01588 L
.31907 .01491 L
.31921 .01617 L
.31948 .0186 L
.32008 .02344 L
.32035 .02525 L
.3206 .02664 L
.32087 .02774 L
.32101 .02817 L
.32116 .0285 L
.3213 .0287 L
.32139 .02875 L
.32147 .02876 L
Mistroke
.32162 .02867 L
.32171 .02855 L
.32179 .0284 L
.32193 .02806 L
.32208 .02756 L
.32238 .02617 L
.32272 .02411 L
.32307 .02138 L
.32341 .01847 L
.32355 .01712 L
.32364 .01634 L
.32372 .0156 L
.32387 .01527 L
.32395 .01601 L
.32403 .0168 L
.32437 .01993 L
.32469 .02264 L
.32499 .02491 L
.32527 .02672 L
.32543 .02751 L
.32559 .02821 L
.32574 .02873 L
.32588 .02908 L
.32601 .02931 L
.32614 .02942 L
.32628 .02942 L
.32643 .02929 L
.32657 .02902 L
.3267 .02868 L
.32686 .02814 L
.32702 .02739 L
.32732 .02566 L
.32797 .02054 L
.32827 .01764 L
.32843 .01616 L
.32856 .01479 L
.32868 .01584 L
.32881 .0171 L
.32908 .01969 L
.32964 .02465 L
.32991 .02654 L
.33019 .02818 L
.33036 .02892 L
.3305 .02945 L
.33065 .02985 L
.33079 .03009 L
.33093 .03019 L
.33108 .03016 L
.33122 .03 L
.33135 .02973 L
Mistroke
.3315 .02928 L
.33167 .02862 L
.33197 .027 L
.33228 .02479 L
.33261 .02196 L
.33292 .01896 L
.33321 .01603 L
.33335 .01487 L
.3335 .01643 L
.33381 .01966 L
.33438 .02493 L
.33462 .02682 L
.33488 .02851 L
.33503 .02931 L
.33517 .02991 L
.3353 .03039 L
.33543 .03073 L
.33557 .03096 L
.33572 .03106 L
.33586 .03101 L
.33599 .03085 L
.33614 .0305 L
.33622 .03024 L
.3363 .02995 L
.3366 .02849 L
.33692 .02635 L
.3372 .02397 L
.33753 .02076 L
.33784 .01752 L
.33798 .01601 L
.33811 .01485 L
.33824 .01635 L
.33839 .01798 L
.33899 .02414 L
.33951 .02845 L
.33966 .02942 L
.3398 .03021 L
.33994 .03085 L
.34006 .03132 L
.3402 .03171 L
.34035 .03196 L
.34048 .03205 L
.34062 .03201 L
.34077 .03179 L
.34091 .03144 L
.34106 .03089 L
.34123 .03011 L
.34156 .02799 L
.34187 .02537 L
.34216 .02257 L
Mistroke
.34246 .01929 L
.34273 .01624 L
.34288 .01495 L
.34302 .01661 L
.34353 .02245 L
.34382 .02546 L
.34413 .02825 L
.34441 .03035 L
.34468 .03184 L
.34484 .03245 L
.34492 .03271 L
.345 .0329 L
.34514 .03313 L
.34528 .0332 L
.34536 .03316 L
.34545 .03307 L
.3456 .03277 L
.34569 .0325 L
.34578 .03218 L
.34594 .03142 L
.34623 .02955 L
.34651 .02729 L
.34713 .02074 L
.34738 .01774 L
.34751 .01611 L
.34764 .01504 L
.3478 .01697 L
.34794 .01873 L
.34821 .02209 L
.3485 .02533 L
.34881 .02844 L
.34908 .03074 L
.34936 .03264 L
.34951 .03338 L
.34959 .0337 L
.34968 .03399 L
.34983 .03435 L
.34997 .03452 L
.35012 .03451 L
.35026 .03433 L
.35038 .03402 L
.35052 .03354 L
.35066 .03284 L
.35083 .03187 L
.35116 .0293 L
.35175 .02297 L
.35202 .0196 L
.35216 .01767 L
.3523 .01584 L
.35245 .01559 L
Mistroke
.35252 .01665 L
.35261 .01778 L
.35289 .02156 L
.35341 .02787 L
.3537 .03076 L
.35396 .03298 L
.35412 .03404 L
.35427 .03483 L
.35443 .03549 L
.35452 .03576 L
.35461 .03595 L
.35475 .03611 L
.35489 .03609 L
.35504 .03587 L
.3552 .0354 L
.35529 .03503 L
.35537 .03462 L
.35556 .03349 L
.3559 .03069 L
.35653 .02334 L
.35681 .01961 L
.35696 .01746 L
.3571 .01539 L
.35718 .01522 L
.35726 .0165 L
.35742 .01874 L
.35772 .02303 L
.35802 .02718 L
.35836 .03112 L
.35865 .03397 L
.35881 .03524 L
.35896 .03623 L
.3591 .03695 L
.35925 .03752 L
.35933 .03776 L
.35941 .03791 L
.35955 .03804 L
.35969 .03797 L
.35981 .03773 L
.35995 .0373 L
.3601 .03663 L
.36025 .03573 L
.3604 .03454 L
.36069 .03182 L
.36135 .02339 L
.36167 .01842 L
.36176 .01701 L
.36186 .01549 L
.36195 .01538 L
.36203 .01669 L
Mistroke
.36267 .02675 L
.36297 .03088 L
.3633 .03468 L
.36344 .03615 L
.3636 .03748 L
.36375 .03851 L
.36388 .03927 L
.36403 .03989 L
.36411 .04012 L
.36419 .04029 L
.36433 .04041 L
.36448 .04029 L
.36462 .03996 L
.36476 .03938 L
.3649 .03862 L
.36503 .03775 L
.36531 .03517 L
.36563 .03148 L
.36596 .02676 L
.36625 .02191 L
.36639 .01956 L
.36654 .01696 L
.36668 .01497 L
.36681 .01728 L
.3674 .02756 L
.36769 .03202 L
.36796 .03573 L
.36822 .03875 L
.36847 .04093 L
.3686 .04183 L
.36874 .04257 L
.36888 .04308 L
.36903 .04336 L
.36918 .04336 L
.36927 .04323 L
.36935 .04303 L
.36949 .04247 L
.36964 .04161 L
.36977 .04064 L
.36991 .03938 L
.37016 .03657 L
.37074 .02793 L
.37106 .02204 L
.37123 .01875 L
.37132 .01691 L
.37141 .01517 L
.37156 .01742 L
.37174 .02089 L
.37204 .02687 L
.37234 .03234 L
Mistroke
.37266 .03751 L
.37295 .04149 L
.37323 .04438 L
.37338 .04556 L
.37346 .04606 L
.37354 .0465 L
.37369 .04704 L
.37383 .04727 L
.3739 .04729 L
.37399 .0472 L
.37414 .04681 L
.37423 .04641 L
.37432 .04592 L
.37448 .04472 L
.37478 .04162 L
.37505 .03779 L
.37567 .0263 L
.37592 .02092 L
.37605 .01798 L
.37619 .01484 L
.37634 .01814 L
.37648 .02138 L
.37675 .02764 L
.37735 .03978 L
.37764 .04461 L
.3779 .04817 L
.37804 .04963 L
.37819 .05091 L
.37835 .05184 L
.37843 .0522 L
.37851 .05243 L
.37865 .0526 L
.37877 .05248 L
.37892 .05201 L
.37906 .05124 L
.37921 .05007 L
.37936 .04843 L
.37965 .04455 L
.37998 .03847 L
.38029 .03181 L
.38055 .02526 L
.3807 .02147 L
.38084 .01785 L
.38098 .01558 L
.38106 .01771 L
.38115 .02 L
.38143 .02772 L
.38195 .04097 L
.38224 .04723 L
.3825 .05218 L
Mistroke
.38281 .05652 L
.38297 .05818 L
.38306 .05891 L
.38314 .05944 L
.38329 .06005 L
.38345 .06026 L
.3836 .05999 L
.38373 .05935 L
.38382 .05878 L
.38391 .058 L
.38407 .05617 L
.38438 .05138 L
.38474 .0437 L
.38507 .03493 L
.38534 .02678 L
.38549 .02202 L
.38563 .01737 L
.38571 .01472 L
.3858 .01764 L
.38595 .02279 L
.38625 .03281 L
.3869 .05253 L
.38721 .06036 L
.3875 .06603 L
.38764 .06814 L
.38777 .06974 L
.3879 .07101 L
.38805 .07192 L
.38819 .07231 L
.38833 .07218 L
.38849 .07146 L
.38863 .07021 L
.38878 .06835 L
.38895 .06576 L
.38923 .05955 L
.38954 .0508 L
.38988 .03903 L
.39021 .0262 L
.39037 .01945 L
.39051 .01641 L
.3906 .02003 L
.39068 .02392 L
.39087 .03217 L
.39119 .04642 L
.39179 .07006 L
.39211 .08039 L
.39242 .08771 L
.39257 .09037 L
.39264 .09147 L
.39273 .09246 L
Mistroke
.39282 .09329 L
.3929 .09383 L
.39299 .09411 L
.39307 .09415 L
.3932 .09372 L
.39335 .09247 L
.39351 .09029 L
.39366 .08744 L
.39382 .08337 L
.394 .07808 L
.39431 .06616 L
.39464 .0499 L
.39483 .03972 L
.395 .02942 L
.39516 .02001 L
.39524 .01488 L
.39532 .01999 L
.39561 .0391 L
.39617 .07665 L
.39744 .13958 L
.39758 .14283 L
.39773 .14519 L
.39781 .14594 L
.39789 .14639 L
.39805 .14614 L
.39819 .14466 L
.39834 .14167 L
.39849 .13748 L
.39862 .13244 L
.39895 .11546 L
.39929 .09023 L
.39958 .06267 L
.39974 .04532 L
.3999 .02754 L
.40004 .01965 L
.40019 .04009 L
.40046 .07849 L
.40099 .16138 L
.40219 .36353 L
.40279 .45473 L
.40335 .52493 L
.40363 .55281 L
.40393 .5764 L
.4041 .58665 L
.40427 .59417 L
.40441 .59903 L
.4045 .60099 L
.40457 .60227 L
.40471 .60332 L
.40486 .60262 L
Mistroke
.405 .60022 L
.40513 .59654 L
.40525 .592 L
.40538 .58571 L
.40564 .56901 L
.40592 .545 L
.40622 .5131 L
.40677 .44187 L
.408 .24456 L
.40864 .13859 L
.409 .08491 L
.40917 .06034 L
.40933 .03897 L
.40947 .02111 L
.40962 .02603 L
.40977 .04263 L
.40993 .05936 L
.41025 .08776 L
.41043 .10071 L
.41059 .11116 L
.41074 .11923 L
.41091 .12635 L
.41106 .13137 L
.4112 .1348 L
.41133 .13701 L
.41147 .13831 L
.41162 .13846 L
.41176 .13752 L
.41191 .1354 L
.41199 .13374 L
.41207 .13196 L
.41236 .12297 L
.4127 .10858 L
.41301 .09208 L
.41363 .05485 L
.41391 .03781 L
.41405 .02888 L
.41421 .0195 L
.41435 .01831 L
.41448 .0257 L
.41473 .03929 L
.41528 .06391 L
.41557 .07334 L
.41572 .07729 L
.41588 .0807 L
.41602 .08299 L
.41617 .08479 L
.41631 .08576 L
.41644 .08611 L
.41659 .08585 L
Mistroke
.41667 .0854 L
.41675 .08482 L
.4169 .08321 L
.41704 .08113 L
.41735 .07466 L
.41769 .06525 L
.41827 .04507 L
.41859 .03281 L
.41874 .02672 L
.41888 .02119 L
.41902 .01585 L
.41915 .01855 L
.41929 .02366 L
.41944 .02902 L
.41973 .03881 L
.42004 .04779 L
.42031 .05398 L
.42045 .05672 L
.4206 .0592 L
.42074 .06105 L
.42087 .06237 L
.42099 .06331 L
.42111 .06394 L
.42126 .06423 L
.42135 .06418 L
.42142 .064 L
.42157 .06334 L
.42172 .0622 L
.42185 .0608 L
.42198 .05919 L
.42226 .0545 L
.42286 .0412 L
.42316 .03306 L
.42349 .0237 L
.42364 .01945 L
.4238 .01496 L
.42395 .01864 L
.42409 .02232 L
.42465 .03607 L
.42491 .04129 L
.42519 .04588 L
.42532 .04759 L
.42546 .04911 L
.42559 .05025 L
.42571 .05107 L
.42585 .05177 L
.42593 .05199 L
.42602 .05212 L
.42615 .05209 L
.42631 .05169 L
Mistroke
.42644 .05103 L
.42659 .05001 L
.42685 .04739 L
.42716 .04313 L
.42749 .03752 L
.42808 .02555 L
.42834 .01973 L
.42849 .01646 L
.42863 .01591 L
.42875 .01862 L
.42889 .02148 L
.42914 .02644 L
.42943 .03174 L
.42974 .03651 L
.43 .03978 L
.43014 .04119 L
.43029 .04242 L
.43045 .0434 L
.43059 .04403 L
.43068 .04427 L
.43076 .04441 L
.43092 .04443 L
.43107 .04415 L
.43121 .04365 L
.43136 .04283 L
.43152 .04168 L
.43179 .03902 L
.43205 .03588 L
.43264 .02693 L
.43297 .02124 L
.43313 .01838 L
.43328 .01573 L
.43341 .01609 L
.43355 .01857 L
.43386 .02359 L
.43448 .03224 L
.43465 .03408 L
.43483 .03577 L
.435 .03706 L
.43516 .03797 L
.43532 .03863 L
.43546 .039 L
.43562 .03913 L
.43571 .0391 L
.43579 .03899 L
.43593 .03866 L
.43608 .03807 L
.43623 .03723 L
.43638 .03624 L
.43671 .03326 L
Mistroke
.43702 .02983 L
.43738 .02516 L
.43771 .02043 L
.43786 .01824 L
.438 .01617 L
.43814 .01541 L
.43822 .01654 L
.4383 .01774 L
.43895 .02628 L
.43925 .02948 L
.43957 .03216 L
.43984 .03381 L
.43999 .03447 L
.44013 .0349 L
.44028 .03516 L
.44036 .03521 L
.44045 .03521 L
.4406 .03504 L
.44074 .0347 L
.44082 .03441 L
.44091 .03408 L
.44106 .03332 L
.4414 .03098 L
.44197 .02543 L
.4423 .02162 L
.4426 .01796 L
.44274 .01622 L
.44289 .01509 L
.44303 .01685 L
.44316 .01843 L
.44376 .025 L
.44403 .02743 L
.44429 .02929 L
.44455 .03077 L
.44469 .03135 L
.44484 .03181 L
.44499 .03209 L
.44507 .03218 L
.44515 .03221 L
.44531 .03214 L
.4454 .03201 L
.44548 .03184 L
.44562 .03145 L
.44577 .03087 L
.44607 .02925 L
.4464 .02682 L
.44676 .02365 L
.4471 .02029 L
.44741 .01701 L
.44756 .01537 L
Mistroke
.44764 .01489 L
.44772 .01579 L
.44806 .01931 L
.44836 .02215 L
.44868 .02482 L
.44899 .02695 L
.44928 .02842 L
.44941 .02894 L
.44956 .02938 L
.4497 .02966 L
.44983 .0298 L
.44997 .02983 L
.45012 .02971 L
.45025 .0295 L
.45039 .02915 L
.45054 .02864 L
.4507 .02795 L
.45099 .02635 L
.45156 .02213 L
.45208 .01751 L
.45224 .01607 L
.45232 .01528 L
.4524 .01489 L
.45254 .01618 L
.45269 .01757 L
.45304 .02054 L
.45336 .02295 L
.45364 .02473 L
.45394 .02626 L
.45411 .0269 L
.45426 .02735 L
.45441 .02766 L
.45456 .02785 L
.45471 .0279 L
.4548 .02788 L
.45488 .02781 L
.45496 .02771 L
.45504 .02757 L
.45521 .02716 L
.45536 .02669 L
.45552 .02605 L
.45581 .0246 L
.4565 .01986 L
.45684 .01722 L
.457 .01589 L
.45715 .01476 L
.45728 .01582 L
.45742 .01693 L
.45771 .01915 L
.45803 .02138 L
Mistroke
.45833 .02315 L
.45862 .02453 L
.45877 .02509 L
.45893 .02559 L
.45902 .02581 L
.4591 .02599 L
.45918 .02612 L
.45927 .02622 L
.45942 .02631 L
.4595 .02631 L
.45958 .02628 L
.46427 .02499 L
.46925 .02375 L
.47404 .0228 L
.47866 .02215 L
.47999 .01904 L
.4803 .01772 L
.48064 .0162 L
.48077 .01555 L
.48092 .01486 L
.48101 .01497 L
.48108 .01533 L
.48123 .01603 L
.48177 .01833 L
.48206 .01937 L
.48236 .02028 L
.48251 .02066 L
.48268 .021 L
.48283 .02125 L
.48298 .02141 L
.48313 .02152 L
.48326 .02156 L
.48342 .02154 L
.48357 .02145 L
.48372 .02129 L
.48386 .02109 L
.48413 .02055 L
.48442 .01977 L
.48474 .01873 L
.48526 .01668 L
.4854 .01608 L
.48555 .01542 L
.4857 .01479 L
.48583 .01521 L
.48645 .01777 L
.48677 .01887 L
.48711 .01987 L
.48727 .02022 L
.48743 .02054 L
.48757 .02075 L
Mistroke
.48772 .02093 L
.48786 .02104 L
.48802 .02109 L
.48816 .02108 L
.48829 .02102 L
.48845 .02089 L
.48859 .02071 L
.48872 .02051 L
.48887 .02023 L
.48948 .01856 L
.49 .01664 L
.49028 .01553 L
.49043 .01489 L
.49058 .01512 L
.49066 .01545 L
.49074 .0158 L
.4909 .01643 L
.49121 .01757 L
.49153 .01865 L
.49187 .01959 L
.49204 .01996 L
.4922 .02025 L
.49234 .02046 L
.4925 .02063 L
.49264 .02073 L
.4928 .02078 L
.49293 .02077 L
.49307 .02071 L
.49323 .02058 L
.49338 .0204 L
.49354 .02015 L
.49371 .01982 L
.4943 .01818 L
.49485 .01625 L
.49499 .01567 L
.49515 .01506 L
.49528 .01489 L
.49543 .01546 L
.49605 .01774 L
.49635 .01869 L
.49663 .01942 L
.49696 .02008 L
.49705 .02022 L
.49714 .02034 L
.49722 .02043 L
.49731 .02051 L
.4974 .02056 L
.49748 .0206 L
.49756 .02062 L
.49765 .02062 L
Mistroke
.49773 .0206 L
.49781 .02057 L
.49795 .02047 L
.49809 .02033 L
.49824 .02013 L
.4985 .01963 L
.49882 .01885 L
.49911 .01797 L
.49971 .01582 L
.49986 .01526 L
.50002 .01478 L
.50011 .01513 L
.50019 .01544 L
.50035 .01606 L
.5009 .018 L
.50118 .01886 L
.50149 .01962 L
.50176 .02012 L
.50191 .02033 L
.50205 .02048 L
.50218 .02057 L
.5023 .02061 L
.50244 .02062 L
.50257 .02058 L
.50272 .02048 L
.5028 .0204 L
.50288 .02031 L
.50317 .01984 L
.50344 .01925 L
.50372 .01847 L
.50403 .01747 L
.50436 .01627 L
.50452 .01565 L
.50467 .01506 L
.50481 .0149 L
.50496 .01548 L
.50547 .01741 L
.50601 .01914 L
.5063 .01983 L
.50645 .02013 L
.50662 .02039 L
.50677 .02058 L
.50691 .02069 L
.50704 .02076 L
.50718 .02078 L
.50732 .02075 L
.50741 .0207 L
.50749 .02064 L
.50763 .0205 L
.50778 .02028 L
Mistroke
.50804 .01979 L
.50833 .01907 L
.50892 .01711 L
.50925 .01584 L
.50932 .01553 L
.50941 .01519 L
.50956 .01485 L
.50971 .01546 L
.50984 .01601 L
.51015 .01724 L
.5107 .01912 L
.51097 .01985 L
.51111 .02017 L
.51125 .02046 L
.51138 .02068 L
.51152 .02086 L
.51165 .02098 L
.51177 .02106 L
.51192 .02109 L
.512 .02109 L
.51209 .02106 L
.51224 .02097 L
.51238 .02082 L
.51254 .02059 L
.51269 .02031 L
.51304 .01947 L
.51362 .0175 L
.51391 .0163 L
.51408 .01561 L
.51423 .01495 L
.51437 .01509 L
.51452 .01574 L
.51479 .01687 L
.5153 .01887 L
.5156 .01984 L
.51591 .02065 L
.51604 .02092 L
.51618 .02115 L
.51633 .02135 L
.51647 .02148 L
.51662 .02155 L
.5167 .02156 L
.51678 .02155 L
.51694 .02148 L
.51703 .02141 L
.51711 .02132 L
.51724 .02113 L
.51739 .02086 L
.5177 .02013 L
.51803 .01907 L
Mistroke
.51839 .01769 L
.51872 .01623 L
.51887 .01556 L
.51895 .01517 L
.51903 .0148 L
.51918 .01535 L
.51934 .0161 L
.51968 .01765 L
.52001 .019 L
.5203 .02008 L
.52057 .0209 L
.52086 .02157 L
.52102 .02184 L
.52116 .02202 L
.52131 .02213 L
.52146 .02218 L
.52161 .02215 L
.52169 .0221 L
.52177 .02203 L
.52185 .02194 L
.52193 .02184 L
.5221 .02154 L
.52241 .02079 L
.5227 .01984 L
.52304 .01848 L
.5234 .01681 L
.52354 .01608 L
.5237 .01527 L
.52379 .0148 L
.52388 .01506 L
.52396 .01547 L
.52404 .01591 L
.52464 .01888 L
.52521 .02113 L
.5255 .02199 L
.52566 .02236 L
.52581 .02262 L
.5259 .02274 L
.52598 .02282 L
.52606 .02289 L
.52615 .02293 L
.52631 .02294 L
.52639 .0229 L
.52647 .02285 L
.52662 .02268 L
.52671 .02255 L
.52679 .02241 L
.52707 .02171 L
.52741 .02056 L
.52773 .0192 L
Mistroke
.5283 .01623 L
.52846 .01535 L
.52854 .0149 L
.52863 .01503 L
.52878 .01591 L
.52892 .01672 L
.52948 .0197 L
.53 .02197 L
.53029 .02289 L
.53046 .02329 L
.53061 .02356 L
.53074 .02373 L
.53088 .02384 L
.53102 .02388 L
.53116 .02383 L
.53131 .02369 L
.53139 .02358 L
.53147 .02345 L
.53176 .02276 L
.53192 .02224 L
.53209 .02158 L
.53241 .02014 L
.53271 .01852 L
.53303 .01663 L
.53316 .01581 L
.5333 .01492 L
.53346 .0155 L
.5336 .01642 L
.5342 .02007 L
.53449 .02162 L
.53477 .02285 L
.53502 .02375 L
.53514 .02412 L
.53528 .02445 L
.53541 .02471 L
.53554 .02487 L
.53569 .02498 L
.53583 .02498 L
.53599 .02488 L
.53613 .0247 L
.53626 .02445 L
.5364 .02409 L
.53672 .023 L
.53702 .02165 L
.53758 .01828 L
.53786 .01638 L
.53798 .01552 L
.53812 .01486 L
.53826 .01589 L
.53839 .01686 L
Mistroke
.53869 .01896 L
.53933 .02289 L
.53965 .02442 L
.53983 .02508 L
.53999 .02559 L
.54015 .02594 L
.54024 .02609 L
.54032 .0262 L
.54046 .0263 L
.54061 .0263 L
.54076 .02619 L
.54084 .02608 L
.54092 .02594 L
.54106 .02562 L
.54121 .02517 L
.54147 .02414 L
.54176 .02267 L
.54235 .01873 L
.54251 .0175 L
.54268 .01615 L
.54283 .01498 L
.54298 .01575 L
.54313 .01697 L
.54327 .01808 L
.54358 .02046 L
.54413 .0242 L
.54439 .02563 L
.54453 .02625 L
.54468 .02681 L
.54481 .02721 L
.54495 .02755 L
.54508 .02776 L
.5452 .02787 L
.54535 .0279 L
.54542 .02786 L
.54551 .02778 L
.54566 .02754 L
.5458 .0272 L
.54596 .02665 L
.54611 .02603 L
.54645 .02419 L
.54703 .01993 L
.54733 .01736 L
.54741 .01665 L
.54749 .01588 L
.54765 .01498 L
.5478 .01638 L
.54794 .01767 L
.5482 .02007 L
.54871 .02434 L
Mistroke
.54901 .02635 L
.54928 .02788 L
.54943 .02854 L
.54957 .02903 L
.54972 .02944 L
.5498 .02961 L
.54988 .02972 L
.55003 .02983 L
.55012 .02983 L
.5502 .02978 L
.55034 .02959 L
.55049 .02924 L
.55063 .02881 L
.55075 .02829 L
.55104 .02676 L
.55135 .02459 L
.55164 .0222 L
.55197 .01904 L
.55211 .01755 L
.55219 .01674 L
.55227 .01586 L
.55241 .01503 L
.55254 .0164 L
.55282 .0194 L
.55341 .02526 L
.55369 .02754 L
.55398 .02952 L
.55422 .03082 L
.55436 .03137 L
.55449 .03177 L
.55465 .03208 L
.55472 .03216 L
.55481 .03221 L
.55496 .03215 L
.5551 .03194 L
.55519 .03174 L
.55527 .0315 L
.55542 .03091 L
.55558 .03009 L
.55576 .02898 L
.55638 .02356 L
.55668 .0203 L
.55683 .01859 L
.55696 .01698 L
.55709 .01533 L
.55723 .01585 L
.55738 .01762 L
.55753 .01954 L
.55805 .02564 L
.55833 .02863 L
Mistroke
.55864 .03133 L
.55879 .03241 L
.55894 .03329 L
.55907 .034 L
.5592 .03451 L
.55934 .03491 L
.55949 .03516 L
.55963 .03522 L
.55976 .03511 L
.55991 .0348 L
.56005 .03432 L
.5602 .0336 L
.56037 .0326 L
.5607 .02991 L
.56102 .02662 L
.56131 .02311 L
.56161 .01899 L
.56174 .01717 L
.56187 .01517 L
.56202 .01648 L
.56216 .01856 L
.56268 .02589 L
.56324 .03275 L
.56352 .03543 L
.56368 .03667 L
.56383 .03761 L
.56399 .03836 L
.56407 .03866 L
.56416 .03889 L
.56431 .03911 L
.56439 .03913 L
.56447 .03909 L
.56462 .03882 L
.56475 .03837 L
.56491 .03761 L
.56506 .03665 L
.56539 .0337 L
.5657 .03009 L
.56606 .02496 L
.56639 .0195 L
.56653 .01711 L
.56666 .01479 L
.56681 .01733 L
.56695 .0198 L
.56757 .03034 L
.56786 .03467 L
.56817 .03859 L
.56834 .04045 L
.5685 .04186 L
.56867 .04298 L
Mistroke
.56882 .04376 L
.56896 .04423 L
.56911 .04445 L
.56925 .0444 L
.56938 .04411 L
.56953 .04351 L
.56962 .04303 L
.5697 .04251 L
.57 .03981 L
.57028 .03622 L
.5706 .03125 L
.57094 .02505 L
.57108 .02209 L
.57124 .01874 L
.57138 .01573 L
.57151 .01655 L
.57165 .01957 L
.5718 .02281 L
.57239 .03533 L
.57268 .04065 L
.57296 .04493 L
.5732 .04803 L
.57334 .04941 L
.57347 .05047 L
.57362 .05137 L
.57376 .0519 L
.5739 .05214 L
.57406 .052 L
.5742 .05154 L
.57435 .05071 L
.57449 .04958 L
.57461 .0483 L
.57493 .04406 L
.57526 .03792 L
.57587 .02345 L
.57602 .01945 L
.57618 .01505 L
.57627 .01695 L
.57635 .01931 L
.57652 .02394 L
.57719 .0425 L
.57749 .04958 L
.57782 .056 L
.57797 .05841 L
.57813 .06054 L
.57826 .062 L
.57841 .06319 L
.57857 .06396 L
.57871 .06423 L
.57887 .064 L
Mistroke
.57896 .06364 L
.57904 .06315 L
.57918 .0619 L
.57934 .06001 L
.57963 .0552 L
.57992 .04883 L
.58021 .04051 L
.58049 .03144 L
.58075 .02233 L
.5809 .01655 L
.58105 .0185 L
.5812 .02452 L
.58137 .03112 L
.58195 .05324 L
.58228 .06445 L
.58264 .07436 L
.58294 .0807 L
.58302 .08205 L
.58311 .08329 L
.58327 .08499 L
.58341 .08584 L
.58355 .08611 L
.58371 .08566 L
.58386 .08452 L
.58399 .08283 L
.58412 .0807 L
.58441 .07389 L
.58472 .06378 L
.58506 .04985 L
.58533 .03603 L
.58548 .02807 L
.58564 .01918 L
.58574 .016 L
.58582 .02132 L
.586 .03191 L
.58634 .05325 L
.58698 .09177 L
.58729 .10793 L
.58762 .12234 L
.58778 .12764 L
.58794 .1322 L
.58808 .13518 L
.58823 .1374 L
.58838 .13846 L
.58847 .13851 L
.58855 .13819 L
.5887 .13666 L
.58886 .13366 L
.58899 .12975 L
.58913 .12501 L
Mistroke
.58942 .11022 L
.58975 .08777 L
.59009 .05717 L
.59023 .04252 L
.59038 .02564 L
.59047 .01538 L
.59055 .0237 L
.5907 .04343 L
.59181 .2127 L
.59301 .40884 L
.5936 .49107 L
.59392 .52835 L
.59422 .55713 L
.59447 .57653 L
.5946 .58454 L
.59475 .59168 L
.5949 .59757 L
.59505 .60127 L
.59519 .60309 L
.59533 .60319 L
.59547 .60161 L
.59563 .59794 L
.59577 .59263 L
.59591 .58621 L
.59622 .56574 L
.59654 .53624 L
.59716 .4615 L
.59784 .35844 L
.59842 .26041 L
.59905 .15409 L
.59934 .10794 L
.59965 .06215 L
.59977 .04443 L
.59991 .02622 L
.60006 .02214 L
.6002 .03879 L
.60055 .07607 L
.60089 .10437 L
.60119 .1236 L
.60136 .13186 L
.60152 .13785 L
.60168 .1422 L
.60183 .14489 L
.60196 .14617 L
.6021 .14639 L
.60226 .1453 L
.60234 .14425 L
.60243 .14271 L
.60258 .13908 L
.60272 .13469 L
Mistroke
.60333 .1073 L
.60399 .06658 L
.60429 .04629 L
.60445 .03515 L
.60461 .02483 L
.60474 .01623 L
.60488 .02222 L
.60518 .04029 L
.60575 .0686 L
.60604 .0792 L
.6062 .08405 L
.60635 .08765 L
.60649 .09028 L
.60662 .09214 L
.60675 .09345 L
.6069 .09411 L
.60703 .09406 L
.60717 .09337 L
.60729 .09229 L
.60742 .09058 L
.60758 .08785 L
.60772 .08468 L
.60805 .0755 L
.60865 .05325 L
.60919 .02957 L
.60935 .0226 L
.60949 .0161 L
.60962 .01908 L
.60977 .02513 L
.61041 .04918 L
.61073 .05857 L
.61091 .06294 L
.61108 .06622 L
.61123 .06849 L
.61138 .07037 L
.61147 .07113 L
.61155 .07167 L
.6117 .07226 L
.61184 .07227 L
.61199 .07176 L
.61214 .07066 L
.61229 .06913 L
.61244 .06704 L
.6126 .0643 L
.61289 .05814 L
.61354 .03962 L
.61386 .02909 L
.61402 .02378 L
.61416 .01888 L
.61429 .01499 L
Mistroke
.61443 .01962 L
.61473 .02897 L
.61524 .04327 L
.61552 .04957 L
.61579 .0543 L
.61594 .05639 L
.61611 .05816 L
.61626 .05931 L
.6164 .05997 L
.61653 .06024 L
.61667 .06016 L
.61682 .05963 L
.61696 .05875 L
.6171 .05749 L
.61725 .05575 L
.61753 .05167 L
.61815 .03866 L
.61848 .03008 L
.6188 .02149 L
.61894 .01769 L
.61909 .01573 L
.61916 .0178 L
.61925 .02006 L
.61939 .02395 L
.61995 .03708 L
.62026 .04293 L
.62055 .04732 L
.62068 .04889 L
.62082 .05026 L
.62097 .05141 L
.62111 .05213 L
.62125 .05252 L
.62138 .05259 L
.6215 .05241 L
.62163 .05197 L
.62178 .05112 L
.62191 .05004 L
.62222 .04663 L
.6225 .04238 L
.62277 .03753 L
.62309 .03103 L
.62343 .02351 L
.62357 .02032 L
.62372 .01686 L
.6238 .01489 L
.62388 .01634 L
.62403 .01984 L
.62462 .03201 L
.62492 .03737 L
.62525 .04196 L
Mistroke
.62543 .04386 L
.62559 .04524 L
.62566 .04578 L
.62575 .04628 L
.6259 .04693 L
.62598 .04714 L
.62607 .04727 L
.62616 .04728 L
.62625 .04718 L
.62641 .04673 L
.6265 .04633 L
.62658 .04587 L
.62685 .04368 L
.62701 .04201 L
.62715 .0402 L
.62777 .03045 L
.6283 .02019 L
.62845 .01726 L
.6286 .01526 L
.62873 .01788 L
.62887 .02069 L
.6295 .0318 L
.62985 .03672 L
.63002 .03863 L
.63017 .04012 L
.63031 .04126 L
.63047 .04224 L
.63062 .04293 L
.63071 .04318 L
.63079 .04332 L
.63094 .04338 L
.63107 .0432 L
.63123 .04271 L
.63138 .04198 L
.63153 .04098 L
.63169 .03961 L
.63198 .03646 L
.63253 .02863 L
.63284 .0234 L
.63301 .0204 L
.63317 .01756 L
.63331 .01513 L
.63346 .01689 L
.63354 .01836 L
.63362 .01973 L
.63376 .02224 L
.63428 .03021 L
.63456 .0338 L
.63483 .03654 L
.63498 .03777 L
Mistroke
.63511 .03871 L
.63526 .03951 L
.63534 .03983 L
.63543 .04009 L
.63556 .04035 L
.63569 .0404 L
.63583 .04025 L
.63598 .03985 L
.63613 .03921 L
.63629 .03824 L
.63663 .03549 L
.63693 .03209 L
.63722 .02832 L
.63755 .02342 L
.63786 .01845 L
.63795 .01709 L
.63804 .01565 L
.63814 .01536 L
.63823 .01682 L
.63856 .02198 L
.63887 .02653 L
.63921 .0308 L
.63954 .03405 L
.63969 .03528 L
.63983 .03623 L
.63996 .03693 L
.6401 .03749 L
.64026 .03788 L
.6404 .03804 L
.64054 .03798 L
.6407 .03768 L
.64085 .03717 L
.64099 .0365 L
.64128 .03452 L
.64155 .03208 L
.64215 .02485 L
.64242 .02111 L
.64256 .01907 L
.64271 .01685 L
.64286 .01472 L
.64299 .01663 L
.64324 .02031 L
.64386 .02817 L
.64421 .03164 L
.64437 .03298 L
.64452 .03402 L
.64467 .03483 L
.6448 .0354 L
.64495 .03584 L
.64511 .03609 L
Mistroke
.64526 .03611 L
.64535 .03602 L
.64543 .03588 L
.64558 .03547 L
.64573 .03483 L
.64587 .03409 L
.64602 .03311 L
.64632 .03061 L
.64686 .02472 L
.64716 .02084 L
.64733 .01861 L
.64749 .01647 L
.64764 .01496 L
.64772 .01609 L
.6478 .01712 L
.64808 .02079 L
.64863 .02723 L
.6489 .02979 L
.64915 .0317 L
.64941 .0332 L
.64955 .0338 L
.64969 .0342 L
.64983 .03446 L
.64997 .03454 L
.65012 .03443 L
.6502 .03429 L
.65028 .03411 L
.65043 .03363 L
.65056 .03303 L
.65087 .03114 L
.65117 .02867 L
.65149 .02544 L
.65202 .01919 L
.65217 .01737 L
.65233 .01541 L
.65246 .01569 L
.6526 .01751 L
.65328 .02526 L
.65359 .02814 L
.65375 .02942 L
.65392 .03059 L
.65407 .03148 L
.65424 .03224 L
.65439 .03274 L
.65454 .03305 L
.65468 .03319 L
.65482 .03317 L
.65497 .03296 L
.65512 .0326 L
.65526 .0321 L
Mistroke
.65541 .0314 L
.65568 .02975 L
.656 .02718 L
.65629 .02437 L
.6566 .02108 L
.65676 .01925 L
.65693 .01726 L
.65701 .01626 L
.65709 .01531 L
.65724 .01588 L
.65738 .01751 L
.65753 .01924 L
.6581 .02511 L
.65841 .02773 L
.65869 .02967 L
.65894 .0309 L
.65908 .0314 L
.6592 .03173 L
.65934 .03196 L
.65949 .03205 L
.65963 .03199 L
.65976 .03179 L
.65991 .03141 L
.66005 .0309 L
.66032 .02956 L
.66061 .02762 L
.66092 .02498 L
.66122 .02213 L
.6615 .01921 L
.66175 .01647 L
.66189 .01491 L
.66202 .01595 L
.66264 .02249 L
.66296 .02535 L
.66331 .02792 L
.66345 .02879 L
.66361 .02957 L
.66374 .03012 L
.66389 .03058 L
.66397 .03078 L
.66405 .03091 L
.66421 .03106 L
.66435 .03103 L
.6645 .03085 L
.66464 .03055 L
.66479 .03007 L
.66495 .02941 L
.66509 .02866 L
.66563 .02485 L
.66596 .02191 L
Mistroke
.66627 .01883 L
.66641 .01744 L
.66655 .01594 L
.66671 .01513 L
.66685 .01664 L
.6674 .02207 L
.66792 .02623 L
.66818 .02785 L
.66831 .02853 L
.66846 .02914 L
.66854 .02943 L
.66862 .02965 L
.66877 .02999 L
.66891 .03016 L
.66906 .0302 L
.66921 .03009 L
.66929 .02996 L
.66937 .02979 L
.66953 .02934 L
.6697 .02867 L
.67002 .02702 L
.6703 .02507 L
.67094 .01949 L
.67112 .01778 L
.67122 .01683 L
.67131 .01593 L
.67138 .01516 L
.67147 .01509 L
.67156 .016 L
.67164 .01683 L
.67225 .02245 L
.67258 .02501 L
.67289 .02694 L
.67317 .02822 L
.67332 .02875 L
.67346 .0291 L
.67361 .02934 L
.6737 .02941 L
.67378 .02944 L
.67392 .02938 L
.67408 .02917 L
.67422 .02883 L
.67438 .02832 L
.67467 .02701 L
.67496 .0253 L
.67522 .02341 L
.6758 .0184 L
.67596 .01692 L
.67604 .01612 L
.67613 .01529 L
Mistroke
.67621 .01488 L
.67629 .01568 L
.67644 .01708 L
.67696 .02164 L
.67751 .02558 L
.67767 .02646 L
.67782 .02717 L
.67797 .02774 L
.6781 .02815 L
.67823 .02845 L
.67837 .02866 L
.6785 .02876 L
.67865 .02873 L
.67995 .02321 L
.68026 .02078 L
.68059 .01794 L
.68076 .0165 L
.68091 .01513 L
.68104 .01553 L
.68119 .01686 L
.68173 .02141 L
.6823 .02525 L
.6826 .0267 L
.68277 .02731 L
.68293 .02774 L
.68308 .028 L
.68321 .02813 L
.68337 .02815 L
.68351 .02804 L
.68365 .02783 L
.68378 .02753 L
.68392 .02709 L
.68408 .0265 L
.68439 .02493 L
.68468 .02312 L
.68523 .01883 L
.68537 .01766 L
.68551 .01652 L
.68562 .0155 L
.68575 .01505 L
.6859 .01628 L
.68603 .01741 L
.68632 .01981 L
.68662 .02203 L
.68694 .02414 L
.68725 .02576 L
.6874 .02637 L
.68755 .02684 L
.68762 .02705 L
.68771 .02724 L
Mistroke
.68786 .02748 L
.68794 .02756 L
.68803 .02761 L
.68811 .02761 L
.68819 .02758 L
.68834 .02743 L
.68847 .02718 L
.68862 .0268 L
.68878 .02625 L
.68911 .02477 L
.6894 .02302 L
.68998 .01878 L
.69024 .01671 L
.69037 .01559 L
.69052 .01505 L
.69067 .01634 L
.69082 .01753 L
.69114 .02002 L
.69148 .02243 L
.69181 .02435 L
.69211 .02572 L
.69229 .02631 L
.69237 .02653 L
.69245 .02671 L
.69259 .02696 L
.69273 .02709 L
.69287 .02712 L
.69303 .02703 L
.69318 .02681 L
.69332 .02652 L
.69347 .02606 L
.69362 .02551 L
.69418 .02264 L
.69449 .02051 L
.69483 .01798 L
.69497 .01689 L
.69512 .0157 L
.6952 .01501 L
.69528 .01505 L
.69543 .01627 L
.69601 .02064 L
.69632 .02263 L
.69665 .02438 L
.69682 .02513 L
.69698 .02569 L
.69714 .02613 L
.69729 .02643 L
.69738 .02655 L
.69746 .02663 L
.69762 .02668 L
Mistroke
.69771 .02665 L
.69779 .02659 L
.69788 .02648 L
.69797 .02632 L
.69813 .02595 L
.69828 .02551 L
.69861 .02416 L
.69891 .02253 L
.69919 .02071 L
.6995 .0185 L
.69983 .01601 L
.69992 .01536 L
.70001 .01476 L
.7001 .01551 L
.70019 .01621 L
.70052 .01869 L
.70084 .02084 L
.70118 .02288 L
.7015 .02442 L
.70165 .02501 L
.70179 .02546 L
.70192 .02578 L
.70206 .02604 L
.70221 .02621 L
.70235 .02627 L
.70249 .02623 L
.70264 .02608 L
.7028 .02579 L
.70295 .02543 L
.70356 .02288 L
.7039 .02085 L
.70422 .01871 L
.70452 .01652 L
.70467 .01542 L
.7048 .01502 L
.70494 .01608 L
.7051 .0172 L
.70542 .01947 L
.70597 .02278 L
.70628 .02419 L
.70643 .02473 L
.70657 .02515 L
.70669 .02544 L
.70682 .02567 L
.70697 .02583 L
.7071 .0259 L
.70723 .02587 L
.70737 .02575 L
.70752 .02552 L
.70766 .02521 L
Mistroke
.70796 .02427 L
.70827 .02289 L
.70861 .02098 L
.70893 .01895 L
.7092 .01704 L
.70935 .01595 L
.7095 .01491 L
.70958 .01511 L
.70967 .01575 L
.70982 .01686 L
.71012 .01895 L
.71069 .0223 L
.711 .02374 L
.71115 .02428 L
.71129 .0247 L
.71141 .02502 L
.71155 .02529 L
.71169 .02546 L
.71184 .02555 L
.71197 .02554 L
.71211 .02544 L
.71224 .02526 L
.71236 .02503 L
.71251 .02467 L
.71264 .02426 L
.71294 .02305 L
.71356 .01965 L
.71382 .01795 L
.71409 .01607 L
.71424 .01507 L
.71439 .01546 L
.71453 .01646 L
.71467 .01736 L
.71529 .02124 L
.7156 .02277 L
.71588 .02389 L
.71604 .02437 L
.7162 .02478 L
.71629 .02494 L
.71637 .02506 L
.71646 .02515 L
.71655 .02522 L
.71663 .02524 L
.71672 .02523 L
.71688 .02512 L
.71703 .02492 L
.71717 .02463 L
.71747 .02375 L
.71778 .02245 L
.71813 .02065 L
Mistroke
.71845 .01872 L
.71873 .01691 L
.71888 .01588 L
.71902 .01489 L
.7191 .0151 L
.71919 .0157 L
.71935 .01675 L
.71965 .01872 L
.72022 .0219 L
.7205 .02314 L
.72067 .02372 L
.72082 .02416 L
.72095 .02446 L
.72109 .0247 L
.72122 .02486 L
.72137 .02494 L
.72151 .02493 L
.72164 .02483 L
.72178 .02466 L
.7219 .02443 L
.72204 .02409 L
.72218 .02369 L
.72248 .02252 L
.7231 .01927 L
.72338 .01755 L
.72364 .01585 L
.72378 .01489 L
.72394 .01558 L
.72408 .01652 L
.72421 .01738 L
.72484 .02103 L
.72515 .02246 L
.72543 .02349 L
.72558 .02389 L
.72573 .02424 L
.72588 .02448 L
.72597 .02458 L
.72605 .02464 L
.72613 .02467 L
.72622 .02467 L
.72637 .02459 L
.72646 .0245 L
.72654 .02439 L
.72672 .02403 L
.72688 .02364 L
.72702 .02318 L
.72729 .02213 L
.72789 .01899 L
.72815 .01745 L
.72841 .01573 L
Mistroke
.72857 .01472 L
.72871 .01562 L
.72899 .01736 L
.7296 .02086 L
.72995 .02241 L
.73011 .02301 L
.73027 .02348 L
.73041 .02384 L
.73055 .02409 L
.73069 .02429 L
.73085 .0244 L
.73101 .02441 L
.73109 .02437 L
.73117 .02431 L
.73132 .02412 L
.73147 .02383 L
.73176 .02304 L
.73202 .02205 L
.7323 .02078 L
.7326 .01916 L
.73291 .01735 L
.73308 .0163 L
.73324 .0153 L
.73339 .01506 L
.73355 .01606 L
.73382 .01775 L
.73438 .02079 L
.73469 .02213 L
.73497 .0231 L
.7351 .02343 L
.73521 .0237 L
.73535 .02393 L
.73547 .02408 L
.73561 .02417 L
.73574 .02418 L
.73588 .02412 L
.73603 .02397 L
.73618 .02372 L
.73634 .02335 L
.73668 .0223 L
.73699 .021 L
.73727 .01956 L
.73761 .01768 L
.73792 .01578 L
.73801 .01525 L
.7381 .01473 L
.7382 .01534 L
.73829 .01589 L
.73862 .01787 L
.73918 .0208 L
Mistroke
.73949 .02211 L
.73978 .02302 L
.73994 .02341 L
.74002 .02357 L
.74011 .02372 L
.7402 .02383 L
.74028 .0239 L
.74044 .02396 L
.74059 .02393 L
.74067 .02388 L
.74075 .0238 L
.7409 .02359 L
.74105 .02328 L
.74133 .02249 L
.74164 .02134 L
.7422 .0186 L
.74253 .01669 L
.74267 .01582 L
.74275 .01535 L
.74284 .01484 L
.74298 .01547 L
.74312 .01629 L
.74342 .01803 L
.74398 .02086 L
.74426 .02199 L
.74443 .02252 L
.74457 .02293 L
.7447 .02322 L
.74484 .02346 L
.74498 .02364 L
.74512 .02374 L
.74525 .02376 L
.74539 .02371 L
.7455 .02361 L
.74563 .02344 L
.74579 .02315 L
.74593 .0228 L
.74626 .02175 L
.74686 .01905 L
.74714 .01753 L
.7474 .01602 L
.74754 .01516 L
.7477 .0152 L
.74784 .01604 L
.74798 .0168 L
.74861 .02013 L
.74892 .02144 L
.7492 .02239 L
.74934 .02277 L
.7495 .02311 L
Mistroke
.74958 .02325 L
.74966 .02336 L
.74982 .02351 L
.74997 .02357 L
.75006 .02356 L
.75015 .02352 L
.75023 .02345 L
.75031 .02337 L
.7504 .02324 L
.75049 .02308 L
.75078 .02239 L
.75109 .02135 L
.75165 .0188 L
.75198 .01698 L
.75213 .01615 L
.75221 .0157 L
.75229 .01522 L
.75244 .01506 L
.75258 .01585 L
.75288 .01754 L
.75347 .02047 L
.75377 .02161 L
.75404 .02244 L
.75416 .02274 L
.75428 .02298 L
.75441 .02316 L
.75454 .02331 L
.75468 .02338 L
.75481 .02338 L
.75495 .02331 L
.7551 .02316 L
.75524 .02293 L
.75541 .0226 L
.7557 .02176 L
.75598 .02069 L
.75624 .01953 L
.75684 .01642 L
.75699 .0156 L
.75714 .01472 L
.75723 .01521 L
.75731 .01567 L
.75747 .01657 L
.75802 .01937 L
.7583 .02063 L
.75861 .02174 L
.75876 .02218 L
.7589 .02253 L
.75904 .0228 L
.75917 .02299 L
.75929 .02312 L
Mistroke
.75942 .0232 L
.75955 .02321 L
.75969 .02316 L
.75984 .02302 L
.75999 .0228 L
.76015 .02248 L
.76032 .02205 L
.7606 .02112 L
.76092 .01984 L
.7612 .01848 L
.7615 .01692 L
.76176 .01552 L
.76191 .01472 L
.76204 .01547 L
.76267 .01876 L
.76302 .02034 L
.76334 .02152 L
.76349 .02195 L
.76365 .02234 L
.76379 .02264 L
.76393 .02284 L
.76408 .02299 L
.76416 .02303 L
.76424 .02305 L
.7644 .02303 L
.76448 .02298 L
.76456 .02291 L
.76472 .0227 L
.76487 .02243 L
.76514 .02174 L
.76544 .02074 L
.76575 .01941 L
.76628 .0168 L
.76643 .01603 L
.76658 .01519 L
.76673 .01504 L
.76686 .01576 L
.76749 .01899 L
.76781 .02036 L
.76816 .02157 L
.76832 .02199 L
.76848 .02236 L
.76862 .0226 L
.76878 .02278 L
.76892 .02288 L
.76908 .0229 L
.76923 .02284 L
.76936 .02272 L
.76951 .02251 L
.76966 .02223 L
Mistroke
.76993 .02152 L
.77023 .02052 L
.77055 .0192 L
.77107 .01662 L
.77121 .01586 L
.77137 .01503 L
.77151 .01518 L
.77165 .01588 L
.77228 .01903 L
.7726 .02036 L
.77277 .02096 L
.77295 .02152 L
.7731 .02192 L
.77327 .02227 L
.77342 .02251 L
.77356 .02266 L
.77371 .02275 L
.77384 .02276 L
.77399 .0227 L
.77415 .02256 L
.77429 .02234 L
.77446 .02203 L
.77475 .02125 L
.77503 .02026 L
.7753 .01917 L
.77589 .01627 L
.77604 .01552 L
.77619 .01473 L
.77628 .0152 L
.77636 .01563 L
.77652 .01646 L
.77707 .01907 L
.77735 .02024 L
.77766 .02126 L
.77781 .02167 L
.77795 .022 L
.77809 .02225 L
.77822 .02243 L
.77834 .02255 L
.77847 .02261 L
.7786 .02263 L
.77874 .02258 L
.7789 .02244 L
.77904 .02224 L
.7792 .02194 L
.77937 .02153 L
.77966 .02066 L
.77997 .01946 L
.78026 .0182 L
.78056 .01674 L
Mistroke
.78081 .01543 L
.78096 .01475 L
.78109 .01545 L
.78172 .01852 L
.78208 .01999 L
.7824 .02108 L
.78254 .02149 L
.7827 .02185 L
.78285 .02212 L
.78299 .02231 L
.78313 .02244 L
.78322 .02248 L
.78329 .0225 L
.78345 .02248 L
.78354 .02243 L
.78362 .02236 L
.78377 .02216 L
.78392 .02191 L
.7842 .02126 L
.78449 .02032 L
.78481 .01907 L
.78534 .01662 L
.78548 .0159 L
.78564 .01511 L
.78578 .01506 L
.78592 .01574 L
.78655 .01875 L
.78687 .02004 L
.78722 .02116 L
.78737 .02155 L
.78754 .02189 L
.78768 .02211 L
.78784 .02228 L
.78798 .02236 L
.78814 .02238 L
.78828 .02232 L
.78842 .0222 L
.78857 .022 L
.78872 .02173 L
.78899 .02106 L
.78929 .02012 L
.7896 .01887 L
.78988 .01762 L
.79018 .0162 L
.7903 .0156 L
.79043 .01495 L
.79057 .0152 L
.79071 .01587 L
.79138 .01897 L
.79171 .02022 L
Mistroke
.79201 .02115 L
.79229 .02176 L
.79243 .02198 L
.79258 .02215 L
.79274 .02225 L
.79283 .02227 L
.79291 .02226 L
.79305 .0222 L
.79321 .02206 L
.79335 .02186 L
.79352 .02155 L
.79381 .02081 L
.79436 .01885 L
.79467 .01748 L
.795 .01591 L
.79513 .01524 L
.79528 .01491 L
.79536 .01532 L
.79544 .0157 L
.79559 .01642 L
.79613 .01887 L
.79642 .01996 L
.79672 .02091 L
.79687 .0213 L
.79702 .02159 L
.79716 .02183 L
.79728 .02199 L
.7974 .02209 L
.79753 .02215 L
.79766 .02216 L
.7978 .0221 L
.79796 .02197 L
.79811 .02177 L
.79827 .02148 L
.79844 .02109 L
.79872 .02026 L
.79904 .01912 L
.79932 .01792 L
.79962 .01654 L
.79975 .01595 L
.79988 .01531 L
.80002 .01483 L
.80016 .01549 L
.80079 .01837 L
.80113 .01973 L
.80146 .02077 L
.80161 .02115 L
.80177 .02148 L
.80185 .02163 L
.80194 .02176 L
Mistroke
.80203 .02187 L
.8021 .02194 L
.80225 .02203 L
.8024 .02206 L
.80255 .02201 L
.80268 .02191 L
.80282 .02175 L
.80297 .02151 L
.80323 .02091 L
.80355 .01995 L
.80384 .01888 L
.80445 .01622 L
.80459 .01553 L
.80475 .01478 L
.80484 .01509 L
.80492 .01548 L
.80508 .01624 L
.80563 .01865 L
.80592 .01974 L
.80622 .02068 L
.80649 .02131 L
.80664 .02158 L
.80678 .02177 L
.80691 .02189 L
.80703 .02195 L
.80717 .02196 L
.8073 .02192 L
.80745 .02181 L
.80754 .02171 L
.80761 .02161 L
.80791 .02105 L
.80818 .02033 L
.80846 .01938 L
.80877 .01817 L
.8091 .01672 L
.80926 .01598 L
.80941 .01527 L
.80954 .01481 L
.80969 .01551 L
.8102 .01784 L
.81075 .01991 L
.81104 .02074 L
.81119 .0211 L
.81135 .02141 L
.8115 .02163 L
.81164 .02177 L
.81177 .02185 L
.81191 .02187 L
.81206 .02183 L
.81214 .02178 L
Mistroke
.81222 .02171 L
.81236 .02154 L
.81251 .02129 L
.81277 .02071 L
.81306 .01987 L
.81365 .0176 L
.81398 .01613 L
.81414 .01539 L
.81429 .01474 L
.81443 .01539 L
.81458 .01608 L
.81489 .01747 L
.81544 .0196 L
.81573 .02048 L
.81587 .02084 L
.816 .02112 L
.81612 .02133 L
.81624 .02152 L
.81637 .02166 L
.81651 .02175 L
.81667 .02179 L
.81681 .02175 L
.81689 .02171 L
.81697 .02164 L
.81706 .02154 L
.81714 .02143 L
.81743 .02089 L
.81759 .02049 L
.81774 .02006 L
.81833 .01794 L
.81861 .01672 L
.81887 .01555 L
.81902 .01484 L
.81917 .01526 L
.81932 .01597 L
.81949 .01671 L
.81981 .01811 L
.82016 .01941 L
.82047 .02036 L
.82063 .02076 L
.8208 .02112 L
.82096 .02138 L
.82111 .02155 L
.82125 .02166 L
.82139 .0217 L
.82153 .02169 L
.82168 .02161 L
.82182 .02147 L
.82194 .0213 L
.82209 .02105 L
Mistroke
.82224 .02071 L
.82255 .01985 L
.8232 .01746 L
.8235 .01612 L
.82365 .01544 L
.82379 .0148 L
.82392 .01523 L
.82406 .01586 L
.82435 .01715 L
.82486 .01916 L
.82513 .02001 L
.82541 .02074 L
.82557 .02107 L
.82572 .02131 L
.82587 .02148 L
.82601 .02158 L
.82616 .02163 L
.82625 .02162 L
.82633 .0216 L
.82647 .02151 L
.82662 .02134 L
.82676 .02114 L
.82688 .02091 L
.82717 .02022 L
.82777 .0182 L
.82807 .01694 L
.82823 .01624 L
.8284 .01547 L
.82855 .0148 L
.82864 .01501 L
.82871 .01536 L
.829 .01663 L
.82957 .0189 L
.82981 .01972 L
.83007 .02045 L
.83021 .02076 L
.83036 .02105 L
.8305 .02125 L
.83062 .0214 L
.83078 .02151 L
.83086 .02154 L
.83094 .02155 L
.83109 .02152 L
.83123 .02143 L
.83132 .02135 L
.8314 .02125 L
.83155 .02102 L
.83172 .02069 L
.83189 .02026 L
.83252 .01821 L
Mistroke
.83281 .017 L
.83309 .01579 L
.83321 .01525 L
.83334 .01475 L
.83348 .01538 L
.83361 .01595 L
.83418 .01831 L
.83445 .01926 L
.83473 .02012 L
.8349 .02053 L
.83504 .02084 L
.8352 .0211 L
.83534 .02128 L
.83547 .0214 L
.83561 .02147 L
.8357 .02148 L
.83577 .02148 L
.83592 .02142 L
.83607 .02129 L
.83621 .02111 L
.83637 .02085 L
.83654 .0205 L
.83712 .01877 L
.83765 .01668 L
.8378 .01601 L
.83797 .01528 L
.83811 .01478 L
.83827 .01547 L
.83894 .01826 L
.83924 .01932 L
.83957 .02025 L
.83972 .02062 L
.83987 .0209 L
.84001 .0211 L
.84015 .02127 L
.8403 .02137 L
.84043 .02141 L
.84058 .0214 L
.84074 .02131 L
.84087 .02118 L
.841 .02101 L
.84129 .02047 L
.8416 .01964 L
.84189 .01869 L
.84223 .01741 L
.84254 .01611 L
.84269 .01543 L
.84284 .01478 L
.84299 .01532 L
.84316 .01605 L
Mistroke
.84384 .01874 L
.84415 .01971 L
.84443 .02045 L
.84459 .02077 L
.84477 .02104 L
.84493 .02122 L
.84507 .02131 L
.84523 .02135 L
.84531 .02135 L
.84539 .02132 L
.84554 .02121 L
.84569 .02106 L
.84585 .02081 L
.84601 .02051 L
.84635 .01964 L
.84697 .01747 L
.84725 .0163 L
.84741 .01564 L
.84755 .01501 L
.84768 .01498 L
.84782 .01558 L
.84811 .01682 L
.84863 .01879 L
.84893 .01972 L
.84924 .02049 L
.84937 .02074 L
.84951 .02095 L
.84966 .02113 L
.8498 .02124 L
.84995 .02129 L
.85003 .02129 L
.85011 .02127 L
.85019 .02124 L
.85027 .02118 L
.85036 .0211 L
.85044 .02101 L
.85059 .02079 L
.85073 .02054 L
.85104 .0198 L
.85169 .01762 L
.85202 .01627 L
.85219 .01552 L
.85229 .01511 L
.85238 .01473 L
.85253 .01534 L
.85269 .01603 L
.85297 .01721 L
.85353 .01922 L
.85386 .02012 L
.85415 .02072 L
Mistroke
.85431 .02096 L
.8544 .02106 L
.85449 .02113 L
.85464 .02122 L
.85472 .02123 L
.85481 .02123 L
.85611 .01881 L
.85642 .01769 L
.85675 .01637 L
.85691 .01569 L
.85707 .01504 L
.8572 .01497 L
.85735 .0156 L
.85789 .01778 L
.85846 .01966 L
.85876 .02039 L
.85893 .0207 L
.85909 .02093 L
.85924 .02107 L
.85937 .02115 L
.85953 .02118 L
.85967 .02115 L
.85981 .02107 L
.85994 .02094 L
.86008 .02074 L
.86024 .02047 L
.86055 .01975 L
.86084 .0189 L
.86139 .01685 L
.86167 .01573 L
.86178 .01522 L
.86191 .01475 L
.86205 .01535 L
.86219 .01591 L
.86248 .0171 L
.8631 .01928 L
.86342 .02011 L
.86359 .02047 L
.86375 .02074 L
.86389 .02092 L
.86404 .02105 L
.86412 .0211 L
.8642 .02112 L
.86435 .02113 L
.8645 .02107 L
.86459 .021 L
.86466 .02093 L
.86481 .02075 L
.86496 .0205 L
.86522 .01994 L
Mistroke
.86551 .01914 L
.86611 .01702 L
.86626 .01639 L
.86644 .01569 L
.86651 .01536 L
.8666 .01501 L
.86675 .01505 L
.86689 .01567 L
.86703 .01624 L
.86735 .01749 L
.86763 .01852 L
.8679 .01934 L
.86814 .01999 L
.86841 .02054 L
.86856 .02076 L
.8687 .02092 L
.86883 .02102 L
.86897 .02108 L
.86912 .02108 L
.8692 .02105 L
.86928 .02101 L
.86936 .02094 L
.86944 .02087 L
.86961 .02064 L
.86976 .02039 L
.86992 .02006 L
.87021 .01931 L
.87086 .01706 L
.87103 .01637 L
.87121 .01562 L
.8713 .01526 L
.87139 .01489 L
.87146 .01486 L
.87155 .01521 L
.87215 .01761 L
.87247 .01873 L
.87281 .01972 L
.87297 .02011 L
.87313 .02042 L
.87328 .02066 L
.87342 .02083 L
.87355 .02095 L
.87369 .02102 L
.87383 .02104 L
.87398 .021 L
.87414 .02089 L
.87428 .02073 L
.87444 .0205 L
.87461 .02018 L
.87492 .01941 L
Mistroke
.87521 .01854 L
.87549 .01753 L
.87579 .01637 L
.87604 .01532 L
.87619 .01472 L
.87632 .01527 L
.87695 .01773 L
.8773 .01893 L
.87762 .01981 L
.87777 .02014 L
.87793 .02044 L
.87806 .02065 L
.87821 .02083 L
.87837 .02094 L
.87846 .02098 L
.87854 .021 L
.87869 .02098 L
.87884 .02089 L
.879 .02075 L
.87913 .02056 L
.87944 .01998 L
.87973 .01924 L
.88 .0184 L
.88061 .01613 L
.88077 .01545 L
.88087 .01508 L
.88095 .01472 L
.8811 .01532 L
.88127 .016 L
.8819 .01836 L
.88221 .01932 L
.88249 .02003 L
.88265 .02034 L
.88282 .02061 L
.88291 .02072 L
.883 .02081 L
.88309 .02088 L
.88318 .02093 L
.88326 .02095 L
.88334 .02096 L
.88343 .02094 L
.88351 .02091 L
.88366 .02081 L
.88381 .02065 L
.88504 .01738 L
.88538 .01607 L
.88557 .01532 L
.88566 .01495 L
.88574 .01482 L
.88589 .01542 L
Mistroke
.88605 .01606 L
.88638 .01737 L
.88698 .01931 L
.88714 .01974 L
.88731 .02012 L
.88748 .02042 L
.88763 .02063 L
.88778 .02079 L
.88786 .02085 L
.88795 .02089 L
.88809 .02092 L
.88825 .02089 L
.88839 .0208 L
.88854 .02065 L
.88868 .02046 L
.88881 .02024 L
.88993 .01691 L
.8902 .01584 L
.89034 .01526 L
.89049 .01478 L
.89057 .0151 L
.89066 .01546 L
.89081 .01608 L
.89111 .01724 L
.89144 .01838 L
.89179 .01942 L
.89196 .01983 L
.89212 .02017 L
.89226 .02041 L
.89241 .02063 L
.89256 .02077 L
.89272 .02086 L
.89286 .02088 L
.89299 .02086 L
.89315 .02077 L
.89329 .02063 L
.89346 .0204 L
.89362 .02012 L
.89393 .01939 L
.89423 .01853 L
.89478 .01655 L
.89493 .01596 L
.89509 .01533 L
.89522 .01478 L
.89537 .01526 L
.89601 .01772 L
.89657 .01944 L
.89673 .01983 L
.89688 .02014 L
.89702 .02038 L
Mistroke
.89716 .02058 L
.89729 .02071 L
.89743 .0208 L
.89756 .02085 L
.89767 .02085 L
.89781 .0208 L
.89794 .02071 L
.89809 .02055 L
.89823 .02035 L
.89939 .01713 L
.89972 .01584 L
.8998 .01552 L
.89988 .01519 L
.90003 .01485 L
.90017 .01539 L
.90031 .01598 L
.90062 .01714 L
.90117 .01899 L
.90148 .01978 L
.90163 .02009 L
.90177 .02033 L
.90189 .02051 L
.90203 .02066 L
.90217 .02076 L
.90231 .02082 L
.90244 .02082 L
.90258 .02077 L
.90272 .02067 L
.90284 .02055 L
.90299 .02033 L
.90314 .02008 L
.90341 .01947 L
.90402 .01759 L
.90427 .01665 L
.90454 .01559 L
.90469 .01502 L
.90484 .01504 L
.90498 .0156 L
.90512 .01613 L
.90573 .01835 L
.90604 .01925 L
.90632 .01992 L
.90649 .02024 L
.90664 .02047 L
.90672 .02057 L
.90681 .02065 L
.90691 .02072 L
.90699 .02077 L
.90715 .02079 L
.90723 .02078 L
Mistroke
.90732 .02075 L
.90747 .02065 L
.90761 .0205 L
.90791 .02004 L
.90805 .01972 L
.90822 .01932 L
.90856 .01832 L
.90887 .01723 L
.90917 .01611 L
.90933 .0155 L
.90941 .01516 L
.90949 .01484 L
.90964 .01516 L
.90979 .01579 L
.91007 .01685 L
.91063 .01875 L
.9109 .01949 L
.91115 .02004 L
.91129 .02028 L
.91144 .02049 L
.9116 .02064 L
.91168 .0207 L
.91176 .02074 L
.9119 .02077 L
.91202 .02075 L
.91217 .02067 L
.91231 .02055 L
.91245 .02038 L
.91259 .02015 L
.91286 .0196 L
.91318 .01875 L
.91347 .01781 L
.91378 .01669 L
.91407 .01557 L
.91422 .01499 L
.91437 .01507 L
.91446 .01542 L
.91455 .01575 L
.91471 .01636 L
.91522 .01821 L
.9155 .01906 L
.91577 .01972 L
.91606 .02026 L
.91621 .02047 L
.91629 .02055 L
.91637 .02063 L
.91652 .02071 L
.91666 .02074 L
.9168 .02072 L
.91693 .02065 L
Mistroke
.91708 .02052 L
.91716 .02043 L
.91724 .02031 L
.91754 .01977 L
.91788 .01891 L
.9182 .01791 L
.9185 .01685 L
.91878 .01578 L
.91893 .01516 L
.91902 .01481 L
.9191 .01494 L
.91925 .01551 L
.9194 .0161 L
.91991 .01797 L
.92018 .01881 L
.92047 .01956 L
.92062 .01989 L
.92078 .02019 L
.92093 .02041 L
.92107 .02056 L
.92122 .02066 L
.92135 .02071 L
.9215 .02071 L
.92164 .02066 L
.92178 .02056 L
.92193 .02039 L
.92207 .02018 L
.9222 .01995 L
.92252 .01923 L
.92282 .01837 L
.92313 .01732 L
.92346 .01608 L
.92362 .01545 L
.92377 .01485 L
.92391 .01512 L
.92406 .01569 L
.92458 .01762 L
.92512 .01928 L
.92541 .01993 L
.92558 .02022 L
.92573 .02043 L
.92587 .02057 L
.926 .02065 L
.92614 .0207 L
.92628 .02069 L
.92642 .02063 L
.92657 .02051 L
.92671 .02035 L
.92684 .02016 L
.92714 .01957 L
Mistroke
.92745 .01874 L
.92776 .01776 L
.92809 .01657 L
.92825 .01596 L
.92841 .01537 L
.92854 .01483 L
.92869 .01518 L
.92882 .01568 L
.92896 .01622 L
.92924 .01727 L
.92975 .01891 L
.93004 .01964 L
.9302 .01997 L
.93035 .02022 L
.93049 .02041 L
.93065 .02056 L
.93078 .02065 L
.93091 .02068 L
.93105 .02067 L
.9312 .0206 L
.93133 .0205 L
.93147 .02034 L
.93162 .02011 L
.93178 .01981 L
.93207 .01912 L
.93264 .01734 L
.93289 .01642 L
.93316 .01539 L
.93331 .0148 L
.9334 .01497 L
.93348 .01529 L
.93377 .01642 L
.93412 .01767 L
.93444 .01868 L
.93472 .01942 L
.93502 .02005 L
.93519 .02031 L
.93534 .02049 L
.93549 .0206 L
.93564 .02066 L
.93579 .02066 L
.93588 .02063 L
.93596 .02059 L
.93604 .02053 L
.93612 .02045 L
.93629 .02024 L
.93644 .02 L
.9366 .01968 L
.93689 .01897 L
.93754 .01685 L
Mistroke
.93771 .01621 L
.93789 .0155 L
.93798 .01517 L
.93807 .01482 L
.93815 .01491 L
.93823 .01524 L
.93883 .01748 L
.93915 .01852 L
.93949 .01945 L
.93966 .01981 L
.93981 .02009 L
.93996 .02031 L
.9401 .02047 L
.94023 .02057 L
.94037 .02064 L
.94051 .02065 L
.94066 .02061 L
.94082 .0205 L
.94096 .02035 L
.94112 .02012 L
.94129 .01981 L
.9416 .01908 L
.94189 .01825 L
.94217 .0173 L
.94247 .0162 L
.94273 .01522 L
.94287 .01478 L
.94301 .01531 L
.94363 .01762 L
.94399 .01873 L
.94431 .01956 L
.94445 .01986 L
.94461 .02014 L
.94476 .02035 L
.9449 .02049 L
.94504 .02059 L
.94513 .02062 L
.9452 .02064 L
.94536 .02062 L
.94545 .02058 L
.94553 .02053 L
.94568 .02038 L
.94583 .02019 L
.9461 .0197 L
.9464 .01899 L
.94672 .01804 L
.94724 .01617 L
.94739 .01562 L
.94754 .01503 L
.94769 .01497 L
Mistroke
.94782 .01549 L
.94845 .0178 L
.94877 .01879 L
.94912 .01966 L
.94927 .01996 L
.94944 .02023 L
.94958 .0204 L
.94973 .02054 L
.94988 .02061 L
.95003 .02063 L
.95018 .02058 L
.95032 .0205 L
.95047 .02034 L
.95062 .02014 L
.95089 .01964 L
.95118 .01892 L
.9515 .01796 L
.95202 .0161 L
.95217 .01555 L
.95232 .01495 L
.95247 .01504 L
.9526 .01556 L
.95323 .01785 L
.95355 .01883 L
.9539 .01968 L
.95405 .01998 L
.95422 .02024 L
.95437 .02042 L
.95451 .02054 L
.95466 .0206 L
.95481 .02062 L
.95496 .02057 L
.95509 .02048 L
.95525 .02032 L
.95539 .02012 L
.95566 .01961 L
.95595 .01888 L
.95627 .01793 L
.95679 .01607 L
.95694 .01552 L
.95709 .01492 L
.95724 .01507 L
.95737 .01559 L
.958 .01787 L
.95832 .01884 L
.95866 .01969 L
.95881 .01997 L
.95897 .02022 L
.95911 .0204 L
.95925 .02051 L
Mistroke
.9594 .02059 L
.95948 .02061 L
.95956 .02061 L
.95971 .02057 L
.95986 .02047 L
.96001 .02031 L
.96017 .02009 L
.96046 .01953 L
.96074 .01881 L
.961 .01802 L
.9616 .01591 L
.96174 .01536 L
.96189 .01475 L
.96198 .01502 L
.96207 .01534 L
.96223 .01595 L
.96278 .01794 L
.9633 .01941 L
.96356 .01995 L
.96371 .02019 L
.96384 .02036 L
.96399 .02049 L
.96415 .02058 L
.9643 .02061 L
.96444 .02058 L
.96459 .02049 L
.96473 .02036 L
.96486 .02019 L
.965 .01997 L
.96531 .01931 L
.9656 .01852 L
.96616 .01663 L
.96644 .01559 L
.96656 .01512 L
.96669 .01482 L
.96684 .0154 L
.967 .01599 L
.96733 .0172 L
.9679 .01899 L
.96822 .01975 L
.9684 .02007 L
.96856 .0203 L
.96872 .02046 L
.9688 .02053 L
.96888 .02057 L
.96903 .0206 L
.96918 .02058 L
.96932 .02051 L
.96947 .02038 L
.96963 .02018 L
Mistroke
.96977 .01994 L
.97003 .0194 L
.97031 .01867 L
.97094 .01658 L
.97109 .01602 L
.97125 .01542 L
.97138 .01489 L
.97153 .01511 L
.97167 .01565 L
.97182 .01621 L
.97209 .01719 L
.97239 .01822 L
.97269 .01906 L
.97295 .01968 L
.97309 .01995 L
.97324 .02018 L
.97337 .02036 L
.9735 .02048 L
.97362 .02055 L
.97374 .02059 L
.97389 .02059 L
.97403 .02054 L
.97419 .02042 L
.97428 .02032 L
.97436 .02022 L
.9747 .01962 L
.97502 .01883 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.310298 0.0954019 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02409 -12 -4.5 ]
[-0.0125 .02409 0 4.5 ]
[-0.0125 .11949 -12 -4.5 ]
[-0.0125 .11949 0 4.5 ]
[-0.0125 .2149 -12 -4.5 ]
[-0.0125 .2149 0 4.5 ]
[-0.0125 .3103 -6 -4.5 ]
[-0.0125 .3103 0 4.5 ]
[-0.0125 .4057 -6 -4.5 ]
[-0.0125 .4057 0 4.5 ]
[-0.0125 .5011 -6 -4.5 ]
[-0.0125 .5011 0 4.5 ]
[-0.0125 .5965 -6 -4.5 ]
[-0.0125 .5965 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02409 m
.00625 .02409 L
s
[(-3)] -0.0125 .02409 1 0 Mshowa
0 .11949 m
.00625 .11949 L
s
[(-2)] -0.0125 .11949 1 0 Mshowa
0 .2149 m
.00625 .2149 L
s
[(-1)] -0.0125 .2149 1 0 Mshowa
0 .3103 m
.00625 .3103 L
s
[(0)] -0.0125 .3103 1 0 Mshowa
0 .4057 m
.00625 .4057 L
s
[(1)] -0.0125 .4057 1 0 Mshowa
0 .5011 m
.00625 .5011 L
s
[(2)] -0.0125 .5011 1 0 Mshowa
0 .5965 m
.00625 .5965 L
s
[(3)] -0.0125 .5965 1 0 Mshowa
.125 Mabswid
0 .04317 m
.00375 .04317 L
s
0 .06225 m
.00375 .06225 L
s
0 .08133 m
.00375 .08133 L
s
0 .10041 m
.00375 .10041 L
s
0 .13857 m
.00375 .13857 L
s
0 .15765 m
.00375 .15765 L
s
0 .17674 m
.00375 .17674 L
s
0 .19582 m
.00375 .19582 L
s
0 .23398 m
.00375 .23398 L
s
0 .25306 m
.00375 .25306 L
s
0 .27214 m
.00375 .27214 L
s
0 .29122 m
.00375 .29122 L
s
0 .32938 m
.00375 .32938 L
s
0 .34846 m
.00375 .34846 L
s
0 .36754 m
.00375 .36754 L
s
0 .38662 m
.00375 .38662 L
s
0 .42478 m
.00375 .42478 L
s
0 .44386 m
.00375 .44386 L
s
0 .46294 m
.00375 .46294 L
s
0 .48202 m
.00375 .48202 L
s
0 .52018 m
.00375 .52018 L
s
0 .53926 m
.00375 .53926 L
s
0 .55834 m
.00375 .55834 L
s
0 .57742 m
.00375 .57742 L
s
0 .00501 m
.00375 .00501 L
s
0 .61558 m
.00375 .61558 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02409 m
1 .02409 L
s
.99375 .11949 m
1 .11949 L
s
.99375 .2149 m
1 .2149 L
s
.99375 .3103 m
1 .3103 L
s
.99375 .4057 m
1 .4057 L
s
.99375 .5011 m
1 .5011 L
s
.99375 .5965 m
1 .5965 L
s
.125 Mabswid
.99625 .04317 m
1 .04317 L
s
.99625 .06225 m
1 .06225 L
s
.99625 .08133 m
1 .08133 L
s
.99625 .10041 m
1 .10041 L
s
.99625 .13857 m
1 .13857 L
s
.99625 .15765 m
1 .15765 L
s
.99625 .17674 m
1 .17674 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .23398 m
1 .23398 L
s
.99625 .25306 m
1 .25306 L
s
.99625 .27214 m
1 .27214 L
s
.99625 .29122 m
1 .29122 L
s
.99625 .32938 m
1 .32938 L
s
.99625 .34846 m
1 .34846 L
s
.99625 .36754 m
1 .36754 L
s
.99625 .38662 m
1 .38662 L
s
.99625 .42478 m
1 .42478 L
s
.99625 .44386 m
1 .44386 L
s
.99625 .46294 m
1 .46294 L
s
.99625 .48202 m
1 .48202 L
s
.99625 .52018 m
1 .52018 L
s
.99625 .53926 m
1 .53926 L
s
.99625 .55834 m
1 .55834 L
s
.99625 .57742 m
1 .57742 L
s
.99625 .00501 m
1 .00501 L
s
.99625 .61558 m
1 .61558 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .3103 m
1 .3103 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .46015 m
.02608 .31818 L
.02723 .24586 L
.02787 .2061 L
.02818 .18655 L
.02832 .17796 L
.02847 .16851 L
.02862 .45864 L
.02871 .4534 L
.02878 .44849 L
.02913 .42707 L
.02972 .38963 L
.03089 .31642 L
.03217 .23632 L
.03254 .21325 L
.03289 .19132 L
.03305 .18179 L
.03321 .17164 L
.0333 .16579 L
.03339 .46021 L
.03347 .45488 L
.03355 .44987 L
.03473 .37616 L
.03597 .2983 L
.03703 .23182 L
.03733 .21361 L
.03764 .19409 L
.03779 .18462 L
.03793 .17566 L
.03806 .16761 L
.0382 .45857 L
.03835 .44938 L
.03848 .44096 L
.03878 .42197 L
.03933 .38762 L
.04058 .3093 L
.04182 .23205 L
.04244 .1932 L
.04261 .18256 L
.0427 .17671 L
.04279 .17119 L
.04287 .46576 L
.04296 .46018 L
.04312 .45043 L
.04552 .30039 L
.04672 .22475 L
.04706 .20402 L
.04724 .1926 L
.04741 .18176 L
.04749 .17689 L
Mistroke
.04757 .17171 L
.04766 .46573 L
.04775 .46046 L
.04805 .44126 L
.0493 .36341 L
.05064 .27932 L
.05126 .24068 L
.05159 .21959 L
.05191 .19992 L
.05218 .18311 L
.05233 .17369 L
.05247 .46483 L
.05262 .45544 L
.05278 .44523 L
.05307 .42668 L
.05546 .27712 L
.05604 .24077 L
.05667 .20164 L
.05684 .19071 L
.05694 .18476 L
.05703 .17922 L
.05718 .46913 L
.05727 .46394 L
.05736 .45841 L
.058 .41815 L
.05924 .34063 L
.06058 .25671 L
.06119 .21819 L
.06153 .19714 L
.06169 .18685 L
.06184 .17747 L
.06198 .46857 L
.06211 .46041 L
.0624 .44241 L
.06301 .40421 L
.06417 .33146 L
.06541 .25411 L
.06592 .22234 L
.06618 .20565 L
.06646 .18807 L
.06661 .17871 L
.0667 .47311 L
.06678 .46817 L
.06706 .45017 L
.06763 .41483 L
.0689 .33553 L
.07009 .26059 L
.07062 .22793 L
.0709 .21006 L
.07117 .19332 L
Mistroke
.07131 .18461 L
.07146 .47497 L
.07154 .46964 L
.07162 .46458 L
.07177 .45508 L
.07233 .42005 L
.07349 .34761 L
.07472 .27043 L
.07532 .23292 L
.07562 .21452 L
.07589 .1976 L
.07602 .18962 L
.07613 .18217 L
.07626 .47412 L
.07639 .4656 L
.07694 .43131 L
.0782 .35233 L
.0794 .27756 L
.07992 .245 L
.08047 .21043 L
.08076 .1924 L
.08084 .18746 L
.08092 .18214 L
.08108 .47223 L
.08122 .46331 L
.08137 .45393 L
.08164 .43716 L
.08279 .36504 L
.08402 .28803 L
.08462 .25063 L
.08518 .21535 L
.08543 .19996 L
.08556 .19154 L
.08569 .18367 L
.08582 .47488 L
.08597 .46552 L
.08624 .44906 L
.08749 .37042 L
.08868 .2958 L
.08975 .22882 L
.09005 .21047 L
.09021 .20041 L
.09036 .19094 L
.0905 .4818 L
.09065 .47223 L
.09092 .45556 L
.09333 .30464 L
.09455 .2287 L
.09488 .2079 L
.09506 .19645 L
Mistroke
.09515 .19083 L
.09523 .18563 L
.09531 .48046 L
.09539 .47527 L
.09557 .46433 L
.09587 .44521 L
.09701 .37422 L
.09823 .29782 L
.09882 .26086 L
.09938 .22571 L
.09963 .21044 L
.09976 .20205 L
.09989 .19415 L
.10004 .4845 L
.10017 .47601 L
.10044 .45942 L
.10161 .38576 L
.10286 .30793 L
.10392 .24148 L
.10421 .22327 L
.10437 .21325 L
.10452 .20375 L
.10466 .19492 L
.10482 .48503 L
.10495 .4763 L
.10508 .46822 L
.10733 .3274 L
.10795 .28882 L
.10862 .24722 L
.10892 .22809 L
.10924 .20794 L
.10938 .19963 L
.10952 .19074 L
.10967 .4807 L
.10982 .47163 L
.11105 .39436 L
.11239 .31057 L
.11301 .27215 L
.11366 .23145 L
.11392 .21471 L
.11407 .20548 L
.11421 .19671 L
.11429 .49149 L
.11438 .48611 L
.11453 .47668 L
.11482 .45819 L
.1172 .30947 L
.11788 .26666 L
.11822 .24566 L
.11853 .22636 L
Mistroke
.11881 .20876 L
.11895 .1999 L
.1191 .4899 L
.11926 .48013 L
.11943 .46967 L
.11973 .4508 L
.12096 .37386 L
.12229 .29024 L
.12291 .25193 L
.12324 .23095 L
.1234 .22068 L
.12356 .21128 L
.12369 .20313 L
.12382 .49428 L
.12396 .48568 L
.12411 .47628 L
.12472 .43801 L
.12709 .28976 L
.12777 .24708 L
.12811 .22612 L
.12825 .21693 L
.12842 .20682 L
.12856 .19774 L
.1287 .48897 L
.12884 .48001 L
.12899 .47039 L
.12962 .43125 L
.13084 .35463 L
.13149 .3142 L
.13218 .27119 L
.13277 .23375 L
.13294 .2235 L
.13311 .21243 L
.1332 .20734 L
.13328 .20197 L
.13343 .4921 L
.13357 .48338 L
.13372 .47406 L
.13399 .45726 L
.1346 .4191 L
.13583 .34196 L
.13648 .30132 L
.13717 .25824 L
.13746 .24011 L
.13777 .22061 L
.13786 .21489 L
.13795 .20944 L
.13803 .20455 L
.13811 .49893 L
.13819 .4939 L
Mistroke
.13828 .48854 L
.13843 .47889 L
.1396 .40592 L
.14084 .32825 L
.14149 .28741 L
.14218 .24426 L
.14247 .22601 L
.14264 .21596 L
.14279 .20645 L
.14287 .50078 L
.14297 .49493 L
.14313 .4847 L
.14345 .46466 L
.14462 .39171 L
.14585 .3147 L
.147 .24241 L
.14728 .22473 L
.14744 .21509 L
.14758 .20613 L
.14774 .4961 L
.14782 .49094 L
.14791 .48544 L
.14821 .46674 L
.14954 .38354 L
.15077 .3062 L
.15142 .26548 L
.15178 .24321 L
.15195 .23232 L
.15211 .22238 L
.15226 .21305 L
.1524 .50392 L
.15255 .49458 L
.15271 .48439 L
.15338 .44294 L
.15454 .36997 L
.15577 .29328 L
.15637 .25569 L
.15663 .23921 L
.15692 .22115 L
.157 .21628 L
.15708 .21108 L
.15723 .50141 L
.15732 .49589 L
.1574 .49067 L
.15756 .48089 L
.15825 .43772 L
.15945 .36245 L
.16062 .28936 L
.16126 .24934 L
.16157 .22976 L
Mistroke
.16171 .22119 L
.16186 .21183 L
.16199 .50307 L
.16212 .49521 L
.16237 .47967 L
.16291 .44535 L
.16408 .3724 L
.16535 .29274 L
.16598 .25364 L
.16625 .23649 L
.1664 .2274 L
.16655 .21765 L
.16669 .5085 L
.16682 .50042 L
.16708 .48459 L
.16763 .44994 L
.1688 .37696 L
.16991 .3072 L
.17052 .26897 L
.1711 .23305 L
.17124 .224 L
.17139 .21446 L
.17147 .50918 L
.17156 .50371 L
.17171 .49411 L
.1724 .45142 L
.1736 .37612 L
.17481 .30008 L
.17541 .26272 L
.17567 .24631 L
.17596 .22825 L
.17612 .21829 L
.17627 .50867 L
.17643 .49883 L
.1766 .48824 L
.17728 .44516 L
.17849 .36988 L
.17971 .29352 L
.18004 .27259 L
.1804 .2503 L
.18057 .23947 L
.18073 .22927 L
.18088 .22011 L
.18104 .50993 L
.18119 .50044 L
.18133 .49159 L
.18165 .47149 L
.1823 .4309 L
.18346 .35825 L
.18407 .3204 L
Mistroke
.18472 .27926 L
.18503 .26041 L
.18535 .24041 L
.18548 .23218 L
.18562 .22333 L
.18577 .51332 L
.18592 .5042 L
.18816 .3641 L
.18931 .29176 L
.18963 .27194 L
.18997 .25079 L
.19013 .24051 L
.19029 .23082 L
.19043 .22212 L
.19058 .5124 L
.19074 .50248 L
.19088 .49321 L
.19122 .47212 L
.1919 .4295 L
.19312 .35311 L
.19372 .31546 L
.19438 .27445 L
.19468 .25569 L
.19484 .2454 L
.195 .23572 L
.19514 .22666 L
.1953 .5166 L
.19544 .50771 L
.19557 .49955 L
.19781 .3596 L
.19838 .32396 L
.19899 .28583 L
.19928 .26733 L
.19956 .24984 L
.19981 .23414 L
.19996 .22528 L
.20009 .51681 L
.20023 .50784 L
.20038 .49819 L
.20066 .48075 L
.2013 .44103 L
.20258 .3607 L
.2038 .28446 L
.20413 .26357 L
.20432 .2521 L
.20449 .2413 L
.20465 .2312 L
.20474 .22552 L
.20482 .52 L
.20497 .51073 L
Mistroke
.20513 .50094 L
.2063 .42777 L
.20755 .34933 L
.20819 .30953 L
.20879 .27182 L
.20905 .25541 L
.20933 .23798 L
.20948 .22888 L
.20956 .52342 L
.20964 .51856 L
.20992 .50086 L
.21213 .36251 L
.21332 .28833 L
.21391 .25103 L
.21408 .24081 L
.21417 .2352 L
.21425 .2299 L
.21433 .52467 L
.21442 .51931 L
.21456 .50994 L
.2168 .3703 L
.21794 .29889 L
.21825 .27933 L
.21859 .25831 L
.21875 .24813 L
.2189 .23846 L
.21904 .22979 L
.21919 .52004 L
.21928 .51486 L
.21937 .50926 L
.21953 .4991 L
.21983 .48014 L
.22051 .43765 L
.22173 .36125 L
.22288 .28935 L
.22319 .26965 L
.22337 .25881 L
.22353 .24856 L
.22368 .23902 L
.22377 .23363 L
.22385 .52836 L
.22399 .51957 L
.22414 .51023 L
.22536 .43364 L
.22668 .35118 L
.22728 .31373 L
.22791 .27434 L
.22817 .25808 L
.22831 .24914 L
.22845 .24072 L
Mistroke
.22852 .23592 L
.22861 .53045 L
.22875 .52139 L
.22903 .50369 L
.23124 .36566 L
.23238 .29407 L
.2327 .27445 L
.23287 .26365 L
.23303 .25341 L
.23319 .2439 L
.23327 .23852 L
.23335 .53325 L
.23349 .52447 L
.23364 .51512 L
.23486 .4387 L
.23618 .35624 L
.23678 .31899 L
.2374 .27974 L
.23766 .26354 L
.2378 .25463 L
.23794 .24622 L
.2381 .53598 L
.23824 .52693 L
.23853 .50924 L
.24073 .37137 L
.2419 .29815 L
.24249 .26123 L
.24265 .25111 L
.24274 .24553 L
.24283 .24023 L
.2429 .53503 L
.24299 .52967 L
.24314 .52028 L
.24536 .38111 L
.24601 .34098 L
.24661 .30319 L
.24715 .26927 L
.2473 .25997 L
.24746 .25015 L
.24759 .24177 L
.24774 .53229 L
.24782 .5272 L
.24791 .52167 L
.24807 .51162 L
.24837 .49277 L
.24905 .45042 L
.25027 .37402 L
.2514 .30304 L
.25171 .28359 L
.25205 .26264 L
Mistroke
.2522 .253 L
.25229 .24775 L
.25236 .24286 L
.2525 .53391 L
.25265 .52444 L
.25396 .44287 L
.25519 .3659 L
.25637 .29178 L
.2567 .27147 L
.25687 .26037 L
.25696 .25494 L
.25704 .24998 L
.25718 .54085 L
.25733 .53135 L
.25766 .51117 L
.2599 .3709 L
.26048 .33479 L
.26109 .29637 L
.26139 .27768 L
.26154 .26852 L
.26167 .26011 L
.26179 .25243 L
.26192 .54404 L
.26205 .53591 L
.26219 .527 L
.2635 .44508 L
.2647 .37051 L
.26528 .33415 L
.26591 .29467 L
.2662 .27657 L
.26636 .26667 L
.2665 .25738 L
.26663 .24949 L
.26677 .54071 L
.26692 .53128 L
.26705 .52266 L
.26836 .44078 L
.26958 .36473 L
.27069 .29547 L
.27101 .27552 L
.27116 .26574 L
.27131 .25673 L
.27144 .54824 L
.27158 .53957 L
.27187 .52131 L
.27307 .44589 L
.27437 .365 L
.275 .32525 L
.2756 .28757 L
.27587 .27118 L
Mistroke
.27601 .26219 L
.27614 .25375 L
.27629 .54438 L
.27637 .53956 L
.27645 .53435 L
.27673 .51666 L
.27894 .37838 L
.2801 .30624 L
.28041 .28648 L
.28059 .27561 L
.28075 .26535 L
.2809 .25579 L
.28099 .55011 L
.28107 .54513 L
.28136 .52701 L
.28267 .44481 L
.2839 .36788 L
.28499 .2997 L
.28531 .28007 L
.28546 .27039 L
.28561 .26142 L
.28573 .55303 L
.28587 .5444 L
.28616 .52614 L
.28865 .37049 L
.28926 .33268 L
.2899 .29277 L
.29023 .27189 L
.29032 .26617 L
.29042 .26005 L
.29051 .55398 L
.2906 .54871 L
.29124 .50848 L
.2925 .42939 L
.29367 .35628 L
.29425 .3202 L
.29479 .28635 L
.29506 .26936 L
.29521 .25981 L
.29535 .55077 L
.2955 .54171 L
.29566 .5318 L
.29598 .51185 L
.29729 .42973 L
.29848 .35519 L
.29907 .3186 L
.29938 .29934 L
.2997 .27897 L
.29984 .27037 L
.29999 .26114 L
Mistroke
.30007 .55556 L
.30015 .55073 L
.3003 .54127 L
.30085 .5068 L
.30216 .42473 L
.30338 .34872 L
.30395 .31283 L
.30449 .2791 L
.30462 .27086 L
.30476 .26218 L
.30491 .55238 L
.30505 .54364 L
.30568 .50476 L
.30688 .42916 L
.30818 .3483 L
.30882 .3083 L
.30913 .28864 L
.30927 .28 L
.30942 .27049 L
.30956 .56169 L
.30969 .55372 L
.30996 .53626 L
.31055 .49941 L
.31277 .36099 L
.31337 .32356 L
.31368 .30379 L
.31386 .29293 L
.31402 .28271 L
.31418 .27298 L
.31426 .26751 L
.31434 .56218 L
.31449 .55326 L
.31464 .54383 L
.31521 .50801 L
.31744 .36831 L
.31803 .33161 L
.31859 .29684 L
.31874 .28753 L
.31889 .27764 L
.31898 .27248 L
.31907 .56651 L
.31915 .56133 L
.31923 .55647 L
.31981 .51993 L
.32202 .38169 L
.32321 .30755 L
.3235 .28952 L
.32366 .27962 L
.32381 .27027 L
.32389 .56467 L
Mistroke
.32398 .55891 L
.32414 .54886 L
.32446 .52921 L
.32669 .38968 L
.32783 .31832 L
.32814 .29876 L
.32832 .28799 L
.3284 .28268 L
.32848 .27776 L
.32863 .56799 L
.32871 .56298 L
.3288 .55765 L
.32909 .53953 L
.33163 .38088 L
.33223 .34305 L
.33287 .30313 L
.33303 .29305 L
.3332 .28225 L
.3333 .27605 L
.33339 .57012 L
.33348 .56445 L
.33357 .55908 L
.33421 .51886 L
.33539 .44504 L
.33665 .36672 L
.3372 .33227 L
.33749 .31419 L
.33779 .29518 L
.33795 .28503 L
.33805 .27928 L
.33813 .57365 L
.33828 .56424 L
.33844 .5542 L
.33905 .51604 L
.34128 .3771 L
.34188 .33947 L
.34251 .29969 L
.34268 .28966 L
.34276 .28414 L
.34285 .2789 L
.34295 .57244 L
.34304 .56681 L
.34321 .55578 L
.34386 .51561 L
.34503 .44195 L
.34629 .36364 L
.34684 .32938 L
.34712 .31139 L
.34743 .29243 L
.34751 .28755 L
Mistroke
.34759 .28233 L
.34768 .57632 L
.34777 .57099 L
.34808 .55158 L
.34869 .51348 L
.35091 .37472 L
.35151 .3373 L
.35183 .31683 L
.35214 .29765 L
.35222 .29254 L
.3523 .28768 L
.35239 .58179 L
.35247 .57667 L
.35284 .55388 L
.35348 .51376 L
.35465 .44027 L
.35591 .36197 L
.35622 .34258 L
.35655 .32162 L
.35671 .31199 L
.35687 .30182 L
.35701 .29314 L
.35716 .58334 L
.35731 .57406 L
.35745 .56561 L
.35775 .54661 L
.3583 .51234 L
.36052 .37378 L
.3611 .33751 L
.36142 .31765 L
.36157 .30792 L
.36171 .29901 L
.36184 .2913 L
.36197 .5829 L
.3621 .57476 L
.36224 .56585 L
.36282 .5296 L
.36413 .44762 L
.36533 .37317 L
.36591 .33666 L
.36622 .31744 L
.36639 .30693 L
.36654 .29711 L
.36668 .58824 L
.36683 .57903 L
.36714 .55947 L
.36769 .52506 L
.369 .44314 L
.37022 .36723 L
.37081 .33023 L
Mistroke
.37098 .31958 L
.37114 .30956 L
.37129 .30057 L
.37144 .59057 L
.37153 .58535 L
.3716 .58049 L
.37178 .56946 L
.37214 .54719 L
.37278 .50736 L
.37394 .43477 L
.3752 .35596 L
.37552 .33603 L
.37586 .3149 L
.376 .30621 L
.37615 .29686 L
.37623 .59121 L
.37631 .58631 L
.37647 .57669 L
.37766 .50202 L
.37875 .43435 L
.3799 .3622 L
.38022 .3422 L
.38052 .32335 L
.3808 .30643 L
.38095 .2969 L
.38109 .58784 L
.38122 .57959 L
.38134 .5719 L
.38162 .5544 L
.38219 .51906 L
.38347 .43898 L
.38411 .39958 L
.38469 .36311 L
.38526 .32756 L
.38555 .30961 L
.38563 .30469 L
.38571 .29939 L
.38587 .5895 L
.38602 .57982 L
.38619 .56923 L
.38653 .54789 L
.38714 .50973 L
.38829 .43792 L
.38938 .37012 L
.38998 .33305 L
.39014 .3229 L
.39031 .31214 L
.39046 .30296 L
.39054 .59746 L
.39062 .59257 L
Mistroke
.39175 .52236 L
.39304 .44154 L
.39368 .40172 L
.39427 .36479 L
.39484 .32946 L
.395 .31929 L
.39516 .30971 L
.39529 .60083 L
.39544 .59154 L
.39672 .51199 L
.39787 .43988 L
.39895 .37263 L
.39951 .33804 L
.39967 .32808 L
.39982 .31866 L
.39995 .3102 L
.4001 .60072 L
.40025 .59131 L
.40042 .58093 L
.40076 .55992 L
.40136 .52221 L
.4039 .3638 L
.40644 .20594 L
.40755 .13687 L
.40813 .10036 L
.40876 .0614 L
.40908 .04157 L
.40923 .03184 L
.40938 .02287 L
.40951 .01472 L
.40965 .3058 L
.40978 .29714 L
.40994 .28762 L
.41103 .21933 L
.41229 .14138 L
.41343 .07025 L
.41371 .05284 L
.41401 .03432 L
.41416 .02467 L
.41425 .01917 L
.41433 .31372 L
.41448 .30467 L
.41463 .2949 L
.41578 .22373 L
.41698 .14885 L
.41762 .10923 L
.4183 .06686 L
.41863 .04593 L
.4188 .03564 L
.41895 .02615 L
Mistroke
.41909 .31724 L
.41924 .30811 L
.41955 .28884 L
.42071 .21646 L
.42194 .14025 L
.42261 .09823 L
.42295 .07752 L
.42325 .0583 L
.42354 .04059 L
.4237 .03068 L
.42384 .32142 L
.424 .31154 L
.42417 .30086 L
.42449 .28149 L
.42561 .21151 L
.42675 .14056 L
.42782 .07435 L
.4281 .05669 L
.42837 .03996 L
.42852 .03073 L
.42861 .32522 L
.42868 .3204 L
.42897 .30282 L
.43022 .22466 L
.43154 .14329 L
.43218 .10345 L
.43277 .06693 L
.43304 .04995 L
.43317 .04168 L
.43329 .03416 L
.43342 .32591 L
.43356 .3174 L
.43385 .29939 L
.43502 .22692 L
.43631 .14672 L
.43688 .11152 L
.4375 .07282 L
.43778 .05545 L
.43794 .04589 L
.43808 .0368 L
.43822 .32809 L
.43837 .31891 L
.43863 .30283 L
.43982 .22908 L
.44113 .14753 L
.44176 .10905 L
.44233 .07372 L
.44261 .05597 L
.44276 .04704 L
.44291 .33696 L
Mistroke
.44307 .32711 L
.44324 .31657 L
.44355 .29757 L
.4447 .22625 L
.44602 .14487 L
.4466 .10911 L
.44693 .08878 L
.44724 .06972 L
.44738 .06061 L
.44752 .05194 L
.4476 .04717 L
.44768 .34166 L
.44783 .33252 L
.44847 .29338 L
.4498 .21081 L
.45108 .13221 L
.45168 .09509 L
.45194 .07881 L
.45209 .06957 L
.45223 .06093 L
.45237 .05245 L
.45252 .34307 L
.45267 .33336 L
.45282 .3245 L
.45345 .28538 L
.4546 .21448 L
.45591 .13358 L
.45649 .09802 L
.4568 .07912 L
.45696 .0692 L
.45705 .06379 L
.45713 .05875 L
.45727 .34965 L
.45743 .34001 L
.45771 .32309 L
.45825 .28987 L
.45943 .21701 L
.46064 .14266 L
.46099 .12127 L
.46132 .10106 L
.46161 .08293 L
.46169 .07796 L
.46178 .07269 L
.46193 .36297 L
.46208 .35403 L
.46224 .34428 L
.46253 .32653 L
.46307 .29322 L
.46429 .2183 L
.46543 .14863 L
Mistroke
.46599 .11447 L
.46623 .0995 L
.4665 .08309 L
.46665 .07387 L
.46679 .36498 L
.46694 .35589 L
.4671 .34616 L
.46775 .30658 L
.46888 .23758 L
.47019 .15731 L
.47077 .12205 L
.4711 .10199 L
.47126 .09217 L
.47141 .08318 L
.47155 .37437 L
.47169 .3654 L
.472 .34657 L
.47263 .30803 L
.47397 .22675 L
.47513 .15624 L
.47545 .13694 L
.47579 .11634 L
.47595 .10634 L
.47611 .09691 L
.47625 .38815 L
.4764 .37898 L
.4788 .23351 L
.48001 .16033 L
.48034 .1403 L
.48052 .12926 L
.48069 .1188 L
.48085 .10908 L
.48095 .10359 L
.48103 .39822 L
.48118 .38925 L
.48134 .37971 L
.48258 .30453 L
.48393 .22349 L
.48454 .18627 L
.48488 .16597 L
.4852 .14707 L
.48546 .1309 L
.48561 .12185 L
.48575 .41332 L
.4859 .40429 L
.48607 .39449 L
.48636 .3767 L
.48875 .23309 L
.48933 .19823 L
.48996 .16075 L
Mistroke
.49014 .14974 L
.49032 .13928 L
.49048 .12989 L
.49056 .42429 L
.49065 .41936 L
.49129 .38087 L
.49256 .30464 L
.49376 .23287 L
.49429 .20156 L
.49484 .16848 L
.49498 .16014 L
.49513 .15119 L
.49522 .14606 L
.4953 .44109 L
.49545 .43193 L
.49601 .39858 L
.49831 .26125 L
.49894 .22363 L
.49929 .20302 L
.49961 .18368 L
.49974 .17568 L
.49989 .16726 L
.50004 .45774 L
.50018 .44928 L
.50081 .41162 L
.50196 .34296 L
.50319 .2696 L
.50379 .23397 L
.50408 .21647 L
.50435 .20033 L
.5046 .18566 L
.50472 .17826 L
.50486 .46983 L
.505 .46168 L
.50514 .45291 L
.50541 .43708 L
.50663 .36408 L
.50796 .28445 L
.50857 .248 L
.50891 .228 L
.50922 .20917 L
.50936 .2006 L
.50952 .19156 L
.50959 .48654 L
.50968 .48135 L
.50983 .47223 L
.51039 .43903 L
.51274 .29761 L
.51342 .25684 L
.51376 .23678 L
Mistroke
.5139 .22796 L
.51407 .21824 L
.51421 .20956 L
.51435 .50113 L
.51449 .49254 L
.51464 .48328 L
.51527 .44559 L
.51769 .29966 L
.51828 .26413 L
.5186 .24461 L
.51876 .23503 L
.51891 .2262 L
.51899 .22111 L
.51908 .51544 L
.51917 .51003 L
.51927 .50409 L
.5196 .48428 L
.52024 .44556 L
.52144 .37255 L
.52259 .30325 L
.52322 .26498 L
.52339 .25449 L
.52357 .24333 L
.52373 .23381 L
.52382 .52809 L
.5239 .52299 L
.52511 .44993 L
.52629 .37796 L
.52694 .33866 L
.52754 .30204 L
.52805 .27069 L
.5282 .26166 L
.52834 .25313 L
.52847 .24547 L
.5286 .53687 L
.52874 .52832 L
.5289 .51892 L
.52921 .4999 L
.52977 .46576 L
.53097 .39244 L
.53211 .32271 L
.53274 .28424 L
.53291 .2737 L
.5331 .26246 L
.53319 .257 L
.53327 .25186 L
.53343 .54196 L
.53357 .533 L
.53373 .52354 L
.53401 .50659 L
Mistroke
.53463 .46832 L
.53577 .39822 L
.5364 .35962 L
.537 .32306 L
.53755 .28905 L
.53771 .27973 L
.53787 .26983 L
.53801 .26138 L
.53816 .55177 L
.53829 .54338 L
.53842 .5357 L
.5387 .51837 L
.53921 .48702 L
.5415 .34665 L
.54212 .30816 L
.54247 .28701 L
.54263 .27662 L
.54279 .26705 L
.54294 .55771 L
.54309 .54814 L
.54342 .52795 L
.54399 .49269 L
.54513 .42252 L
.54636 .34713 L
.54695 .3106 L
.54724 .2926 L
.54738 .28385 L
.54751 .27593 L
.54764 .56787 L
.54775 .56056 L
.54801 .54451 L
.54856 .51058 L
.54975 .43764 L
.55099 .36068 L
.55151 .32892 L
.55206 .29494 L
.55222 .2849 L
.55237 .27541 L
.55251 .56661 L
.55266 .55736 L
.55322 .52259 L
.55561 .37471 L
.55619 .33875 L
.55652 .31892 L
.55682 .30005 L
.55699 .28945 L
.55709 .28345 L
.55718 .57759 L
.55734 .56776 L
.55751 .55729 L
Mistroke
.55815 .51747 L
.55939 .4407 L
.56004 .4003 L
.56073 .3576 L
.56133 .32019 L
.5615 .30994 L
.56168 .29894 L
.56176 .29362 L
.56184 .28857 L
.562 .57882 L
.56214 .5701 L
.56229 .56085 L
.56255 .54421 L
.56316 .50655 L
.56429 .43652 L
.56551 .36099 L
.56607 .32625 L
.56637 .30729 L
.56652 .29805 L
.56666 .28965 L
.56678 .5816 L
.5669 .57426 L
.56716 .55812 L
.56771 .52392 L
.56889 .4512 L
.57013 .37415 L
.57064 .34244 L
.57092 .32496 L
.57119 .30836 L
.57134 .29902 L
.57142 .29373 L
.5715 .58854 L
.57164 .57989 L
.57179 .57067 L
.57235 .53567 L
.57359 .45845 L
.57425 .41784 L
.57494 .37498 L
.57554 .33739 L
.57571 .32709 L
.57588 .31606 L
.57597 .31071 L
.57605 .30564 L
.5762 .59587 L
.57635 .58712 L
.5765 .57783 L
.57676 .56115 L
.57737 .52341 L
.5785 .453 L
.57972 .37716 L
Mistroke
.58028 .34226 L
.58059 .32323 L
.58074 .31396 L
.58087 .30555 L
.581 .59746 L
.58112 .5901 L
.58138 .57391 L
.58193 .53966 L
.5831 .46656 L
.58435 .38924 L
.58486 .35739 L
.58514 .33985 L
.58541 .32321 L
.58556 .31383 L
.58564 .30852 L
.58572 .60332 L
.58586 .59465 L
.58601 .58542 L
.58657 .55036 L
.5877 .48017 L
.58892 .40441 L
.58947 .36959 L
.58978 .35058 L
.59006 .33288 L
.59031 .31773 L
.59044 .30925 L
.59057 .60124 L
.5907 .59278 L
.59085 .5836 L
.59112 .56691 L
.59346 .42078 L
.59605 .25981 L
.59723 .18623 L
.5985 .10707 L
.59911 .06876 L
.59942 .04987 L
.5997 .03234 L
.59983 .02419 L
.59995 .01652 L
.60009 .30739 L
.60022 .29937 L
.60079 .26369 L
.60197 .19026 L
.60322 .11268 L
.60373 .08072 L
.60428 .04645 L
.60444 .03635 L
.60459 .02678 L
.60473 .01819 L
.60488 .30856 L
Mistroke
.60502 .29972 L
.60517 .29033 L
.60544 .27347 L
.60658 .20297 L
.60779 .12698 L
.60835 .09203 L
.60894 .05523 L
.60919 .04004 L
.60932 .0317 L
.60945 .02382 L
.6096 .3142 L
.60973 .30573 L
.61 .28917 L
.61117 .21601 L
.61241 .13856 L
.61347 .07243 L
.61376 .05431 L
.61392 .04433 L
.61407 .03485 L
.61422 .02606 L
.61437 .31619 L
.61451 .30748 L
.61464 .29941 L
.61592 .21965 L
.61712 .14462 L
.6182 .07725 L
.61849 .05879 L
.61866 .04871 L
.61881 .03932 L
.61893 .03129 L
.61907 .32241 L
.61923 .31287 L
.61936 .30418 L
.62167 .1602 L
.6223 .12075 L
.62297 .0789 L
.62325 .06169 L
.62355 .04317 L
.62363 .038 L
.62372 .03256 L
.62387 .32256 L
.62402 .31345 L
.62418 .3035 L
.62655 .15552 L
.62723 .11292 L
.62787 .07275 L
.62815 .05522 L
.62831 .04564 L
.62845 .03669 L
.62861 .32672 L
Mistroke
.62869 .32158 L
.62878 .31608 L
.62908 .29736 L
.6303 .22085 L
.63163 .13756 L
.63225 .09943 L
.63258 .07853 L
.63289 .0589 L
.63316 .04225 L
.63331 .03288 L
.63345 .324 L
.63359 .31512 L
.63375 .30539 L
.63406 .28578 L
.63642 .13821 L
.6371 .09572 L
.63744 .07485 L
.63775 .05558 L
.63789 .04654 L
.63803 .03808 L
.63817 .32897 L
.63832 .31926 L
.63895 .28016 L
.6402 .20186 L
.64139 .12748 L
.64191 .09515 L
.64246 .06071 L
.64263 .0505 L
.64278 .04089 L
.64292 .33197 L
.64307 .32264 L
.64363 .28758 L
.64604 .13721 L
.64662 .10065 L
.64725 .06149 L
.64743 .04994 L
.64752 .04426 L
.64761 .03901 L
.64776 .32891 L
.64785 .32373 L
.64793 .31824 L
.64858 .27815 L
.64971 .20745 L
.65093 .13128 L
.65149 .09623 L
.65179 .07713 L
.65208 .05937 L
.6522 .05153 L
.65232 .04414 L
.65246 .33533 L
Mistroke
.65258 .3276 L
.65313 .29319 L
.65431 .21983 L
.65555 .14221 L
.65606 .11025 L
.65661 .07594 L
.65677 .06584 L
.65692 .05626 L
.65706 .04765 L
.65721 .338 L
.65735 .32915 L
.6575 .31973 L
.65777 .3028 L
.65902 .22497 L
.66036 .14095 L
.66098 .10234 L
.66132 .08126 L
.66163 .06163 L
.66177 .05299 L
.6619 .04483 L
.66205 .33514 L
.66219 .32658 L
.6628 .2885 L
.66397 .21544 L
.66521 .13797 L
.66572 .10611 L
.66627 .07183 L
.66643 .06176 L
.66658 .05219 L
.66672 .34331 L
.66687 .33393 L
.66743 .29868 L
.6698 .15041 L
.67049 .10772 L
.67082 .08677 L
.67113 .0675 L
.67127 .05841 L
.67141 .04993 L
.67155 .3408 L
.67171 .33109 L
.67233 .29202 L
.67359 .21325 L
.67479 .13861 L
.67531 .10613 L
.67586 .07161 L
.676 .06295 L
.67615 .05361 L
.67623 .34798 L
.67631 .34308 L
.67646 .33346 L
Mistroke
.67702 .29843 L
.67931 .15577 L
.67993 .11669 L
.68027 .09521 L
.6806 .07493 L
.68075 .06575 L
.6809 .05602 L
.68098 .35066 L
.68107 .34507 L
.68123 .33523 L
.6818 .29941 L
.68415 .1528 L
.68482 .11058 L
.68515 .08978 L
.68532 .07966 L
.68546 .07049 L
.68561 .06151 L
.68574 .35278 L
.68588 .34386 L
.68604 .33422 L
.68667 .29498 L
.68908 .14437 L
.68966 .10775 L
.68998 .08761 L
.69029 .06855 L
.69037 .06331 L
.69046 .05776 L
.69056 .35138 L
.69065 .34575 L
.69098 .32525 L
.69162 .28514 L
.69275 .2143 L
.69397 .13803 L
.69453 .10294 L
.69484 .08381 L
.69499 .07449 L
.69512 .06603 L
.69525 .3579 L
.69536 .3505 L
.69562 .33423 L
.69618 .2998 L
.69735 .22631 L
.69859 .14859 L
.69911 .11658 L
.69965 .08224 L
.69982 .07213 L
.69997 .06254 L
.70011 .35364 L
.70026 .34427 L
.70082 .30905 L
Mistroke
.7032 .16012 L
.70378 .12393 L
.7044 .08487 L
.70458 .07399 L
.70467 .06805 L
.70476 .06253 L
.70492 .35245 L
.705 .34727 L
.70509 .34173 L
.70573 .30145 L
.70697 .22434 L
.70762 .18372 L
.7083 .14067 L
.70891 .10306 L
.70907 .09276 L
.70925 .08168 L
.70933 .07632 L
.70941 .07122 L
.70957 .36137 L
.70971 .35261 L
.70986 .34328 L
.71013 .32649 L
.71073 .28844 L
.71198 .2108 L
.71263 .16997 L
.71332 .12685 L
.71392 .08905 L
.71409 .0787 L
.71418 .073 L
.71426 .0676 L
.71434 .3623 L
.71443 .35684 L
.71458 .34729 L
.71575 .27438 L
.71698 .19739 L
.71814 .12514 L
.71872 .08887 L
.71888 .07893 L
.71896 .07352 L
.71904 .06848 L
.71919 .35926 L
.71934 .3495 L
.72067 .26635 L
.72194 .18691 L
.72256 .1479 L
.72314 .11194 L
.72341 .09505 L
.72366 .07924 L
.72379 .07129 L
.72393 .36247 L
Mistroke
.72408 .353 L
.72422 .34435 L
.72538 .2714 L
.72649 .20184 L
.72768 .12781 L
.72803 .10585 L
.7282 .09508 L
.72836 .08519 L
.7285 .07616 L
.72865 .36635 L
.72881 .35679 L
.72897 .34632 L
.73018 .27105 L
.73139 .19521 L
.73254 .12349 L
.73284 .10426 L
.73301 .09373 L
.73317 .08386 L
.73325 .07873 L
.73334 .37293 L
.73344 .36681 L
.73353 .3612 L
.73386 .34054 L
.73506 .26528 L
.73617 .19602 L
.73735 .12215 L
.7377 .10027 L
.73787 .08954 L
.73803 .07965 L
.73817 .37037 L
.73832 .36085 L
.73864 .34082 L
.73985 .26554 L
.74099 .1941 L
.74162 .15477 L
.74221 .11748 L
.74248 .10069 L
.74263 .09149 L
.74277 .08285 L
.74292 .37326 L
.743 .36832 L
.74308 .36299 L
.74337 .34487 L
.74443 .2789 L
.74568 .20064 L
.74684 .1278 L
.74714 .1089 L
.74743 .09106 L
.74759 .0812 L
.74767 .37534 L
Mistroke
.74776 .37021 L
.74806 .35151 L
.74938 .26834 L
.75047 .20016 L
.75165 .12687 L
.75199 .10532 L
.75216 .0947 L
.75232 .08486 L
.75246 .37567 L
.75261 .3662 L
.75293 .34616 L
.75413 .27088 L
.75538 .19315 L
.75603 .15227 L
.75639 .12995 L
.75672 .10912 L
.75687 .09974 L
.75701 .09086 L
.75709 .08595 L
.75718 .38033 L
.75732 .371 L
.75799 .32951 L
.75915 .25658 L
.76039 .17949 L
.76099 .14175 L
.76154 .10718 L
.76169 .09801 L
.76182 .08948 L
.76197 .3803 L
.76212 .37058 L
.76275 .33148 L
.76408 .2483 L
.76535 .16877 L
.76597 .12971 L
.76625 .11258 L
.76639 .10349 L
.76655 .09374 L
.76669 .38461 L
.76682 .37653 L
.76707 .36072 L
.76762 .32609 L
.76879 .25313 L
.7699 .18348 L
.77051 .14529 L
.77109 .10939 L
.77123 .10035 L
.77138 .09082 L
.77146 .38555 L
.77155 .38009 L
.7717 .3705 L
Mistroke
.77238 .32783 L
.77359 .25254 L
.7748 .17661 L
.7754 .13929 L
.77566 .1229 L
.77595 .10484 L
.77611 .0949 L
.77626 .3853 L
.77641 .37546 L
.77658 .36488 L
.77727 .32182 L
.77847 .24655 L
.77969 .17029 L
.78003 .1494 L
.78038 .12713 L
.78056 .11631 L
.78072 .10611 L
.78086 .09696 L
.78102 .38677 L
.78117 .3773 L
.78132 .36846 L
.78164 .34837 L
.78228 .30781 L
.78345 .23516 L
.78405 .19738 L
.78471 .15628 L
.78501 .13746 L
.78533 .11747 L
.78546 .10925 L
.7856 .1004 L
.78575 .3904 L
.7859 .38127 L
.78814 .24123 L
.78929 .169 L
.78961 .14921 L
.78995 .12806 L
.79011 .1178 L
.79027 .10811 L
.7904 .09941 L
.79056 .3897 L
.79071 .3798 L
.79086 .37053 L
.7912 .34945 L
.79188 .30685 L
.7931 .23046 L
.7937 .19288 L
.79436 .15191 L
.79465 .13317 L
.79482 .12289 L
.79497 .11322 L
Mistroke
.79512 .10417 L
.79527 .39411 L
.79542 .38522 L
.79555 .37706 L
.79778 .23716 L
.79835 .20158 L
.79896 .16349 L
.79925 .14501 L
.79953 .12754 L
.79978 .11184 L
.79993 .10299 L
.80006 .39451 L
.8002 .38556 L
.80035 .37592 L
.80063 .3585 L
.80127 .31879 L
.80255 .23846 L
.80371 .16603 L
.80403 .14619 L
.80436 .12501 L
.80453 .11473 L
.80468 .10504 L
.80482 .39605 L
.80497 .38662 L
.80619 .31069 L
.80752 .22728 L
.80812 .18979 L
.80876 .14957 L
.80907 .13009 L
.80923 .12049 L
.80937 .11161 L
.8095 .10357 L
.80963 .39474 L
.80977 .38616 L
.80992 .37668 L
.81125 .29381 L
.81246 .21776 L
.8136 .14674 L
.81387 .12948 L
.81402 .11999 L
.81417 .11102 L
.81425 .10594 L
.81434 .40013 L
.81449 .39049 L
.81479 .37163 L
.81599 .29673 L
.81731 .21428 L
.8179 .17699 L
.81823 .15643 L
.81854 .1369 L
Mistroke
.81883 .1188 L
.81891 .11384 L
.81899 .10856 L
.81915 .39877 L
.8193 .38942 L
.81944 .38061 L
.8197 .36416 L
.82093 .28694 L
.82224 .2054 L
.82279 .17048 L
.82339 .13308 L
.82357 .12205 L
.82366 .11662 L
.82374 .1116 L
.82389 .40194 L
.82396 .397 L
.82405 .39175 L
.82466 .35345 L
.82689 .21399 L
.82744 .17949 L
.82802 .14319 L
.82832 .12417 L
.82841 .11896 L
.8285 .1134 L
.82858 .40786 L
.82866 .4031 L
.82924 .36662 L
.83144 .22861 L
.83203 .19197 L
.83265 .15319 L
.8329 .13723 L
.83304 .12843 L
.83318 .12009 L
.83333 .40997 L
.83348 .40099 L
.83376 .38341 L
.83497 .30734 L
.83627 .22639 L
.83692 .18584 L
.83753 .1477 L
.83779 .13103 L
.83794 .12193 L
.83807 .11346 L
.83822 .40397 L
.8383 .3991 L
.83838 .3939 L
.83866 .3762 L
.84088 .23728 L
.84211 .16021 L
.84245 .1391 L
Mistroke
.84264 .12754 L
.84273 .12188 L
.84281 .11671 L
.84296 .40721 L
.84312 .39731 L
.84345 .37625 L
.84471 .29744 L
.84588 .22425 L
.84699 .15493 L
.84731 .13497 L
.84746 .12518 L
.84761 .11617 L
.84774 .40767 L
.84788 .39899 L
.84817 .38072 L
.84937 .30525 L
.85067 .22433 L
.8513 .18454 L
.85162 .16496 L
.85191 .14684 L
.85217 .13043 L
.8523 .12214 L
.85245 .4127 L
.85259 .40357 L
.85275 .39371 L
.85304 .37588 L
.85525 .23751 L
.8564 .16531 L
.85672 .14553 L
.85689 .13466 L
.85697 .12932 L
.85705 .12439 L
.85721 .41453 L
.85729 .40949 L
.85737 .40415 L
.85766 .38602 L
.85889 .30927 L
.86021 .22678 L
.86084 .18721 L
.86115 .16771 L
.86144 .14962 L
.8617 .13328 L
.86185 .12415 L
.86198 .4156 L
.86212 .40649 L
.86228 .39665 L
.86257 .37881 L
.86477 .2406 L
.86592 .16871 L
.86624 .14901 L
Mistroke
.86641 .13817 L
.8665 .13284 L
.86657 .12791 L
.86673 .41809 L
.86681 .41306 L
.86689 .40772 L
.86718 .38958 L
.86841 .31299 L
.86972 .2305 L
.87032 .19306 L
.87065 .17264 L
.87095 .15367 L
.87121 .13741 L
.87136 .12831 L
.87149 .41976 L
.87163 .41068 L
.87179 .40085 L
.87208 .38301 L
.87428 .24496 L
.87543 .17337 L
.87574 .15375 L
.87591 .14295 L
.876 .13763 L
.87608 .1327 L
.87623 .42291 L
.87631 .41789 L
.87639 .41255 L
.87668 .39441 L
.8779 .31798 L
.87922 .23549 L
.87982 .19825 L
.88014 .17792 L
.88044 .15899 L
.8807 .14279 L
.88085 .13372 L
.88098 .42518 L
.88112 .41614 L
.88128 .40631 L
.88157 .38848 L
.88377 .25058 L
.88491 .17929 L
.88522 .15976 L
.88539 .14899 L
.88556 .13876 L
.88571 .12928 L
.88579 .42362 L
.88587 .41864 L
.88616 .40051 L
.88747 .31875 L
.8887 .24175 L
Mistroke
.88928 .20554 L
.88989 .1673 L
.89021 .14731 L
.8903 .14183 L
.89039 .13596 L
.89048 .43013 L
.89056 .42508 L
.89118 .3865 L
.89342 .24603 L
.894 .20973 L
.89462 .17117 L
.89487 .15532 L
.895 .147 L
.89514 .13825 L
.8953 .42818 L
.89544 .41922 L
.89572 .40163 L
.89693 .32585 L
.89823 .24491 L
.89887 .20472 L
.89918 .18499 L
.89947 .16679 L
.89974 .15025 L
.89987 .14191 L
.90002 .43246 L
.90017 .42326 L
.90032 .41339 L
.90061 .39555 L
.90282 .25689 L
.90405 .18038 L
.90438 .15942 L
.90456 .14793 L
.90465 .14229 L
.90474 .13711 L
.90482 .4319 L
.9049 .42671 L
.90507 .41577 L
.90538 .39672 L
.90655 .32342 L
.9078 .24496 L
.90844 .20499 L
.90875 .18534 L
.90904 .16718 L
.90931 .15071 L
.90944 .1424 L
.90959 .43295 L
.90973 .42379 L
.90989 .41392 L
.91018 .39609 L
.91239 .25758 L
Mistroke
.91298 .22072 L
.91361 .18139 L
.91379 .16975 L
.91397 .15878 L
.91413 .14892 L
.91421 .14337 L
.9143 .43797 L
.91444 .42869 L
.91461 .41849 L
.91494 .3979 L
.9162 .31862 L
.91736 .24629 L
.91794 .21012 L
.91824 .19103 L
.91856 .17075 L
.91885 .15308 L
.91892 .14824 L
.91901 .14302 L
.91916 .43328 L
.9193 .42454 L
.91945 .41533 L
.91971 .39886 L
.92093 .32257 L
.92223 .24103 L
.92287 .20093 L
.92319 .18122 L
.92348 .16304 L
.92361 .15451 L
.92374 .14653 L
.92387 .43791 L
.92402 .42875 L
.92461 .39186 L
.92682 .25325 L
.92742 .21572 L
.92774 .1959 L
.92808 .17478 L
.92824 .16434 L
.9284 .1545 L
.92854 .14567 L
.9287 .43583 L
.92884 .42674 L
.92899 .41714 L
.92927 .39996 L
.9315 .26007 L
.93265 .18842 L
.93298 .16779 L
.93314 .15764 L
.93329 .14826 L
.93343 .43947 L
.93357 .43044 L
Mistroke
.93387 .41138 L
.93609 .27293 L
.93722 .2021 L
.93753 .18269 L
.9377 .17211 L
.93785 .16227 L
.93799 .15384 L
.93813 .44456 L
.93821 .43942 L
.93829 .43457 L
.93844 .4255 L
.94064 .28746 L
.94182 .21397 L
.94241 .17693 L
.94257 .16678 L
.94266 .16119 L
.94274 .15589 L
.94282 .15097 L
.94291 .44532 L
.94306 .43593 L
.94529 .29659 L
.94593 .25628 L
.94653 .21839 L
.94708 .18436 L
.94723 .17504 L
.94738 .16521 L
.94752 .15682 L
.94766 .44734 L
.94775 .44223 L
.94784 .43667 L
.948 .42659 L
.9483 .40771 L
.94898 .3653 L
.9502 .28887 L
.95133 .21762 L
.95165 .1981 L
.95198 .17711 L
.95214 .16694 L
.9523 .15728 L
.95244 .44832 L
.95259 .43886 L
.95392 .35561 L
.95512 .28012 L
.95571 .24339 L
.95635 .20366 L
.95664 .18542 L
.9568 .17545 L
.95695 .16615 L
.95707 .15821 L
.95721 .44941 L
Mistroke
.95736 .43996 L
.9575 .43134 L
.95881 .34912 L
.96003 .27304 L
.96114 .20319 L
.96141 .18622 L
.96171 .16792 L
.96179 .16282 L
.96187 .15745 L
.96203 .44756 L
.96217 .43855 L
.96233 .4287 L
.96364 .3466 L
.96483 .27199 L
.96542 .23546 L
.96605 .19586 L
.96634 .1777 L
.9665 .16776 L
.96665 .15846 L
.96677 .45026 L
.96691 .44176 L
.9672 .42369 L
.96972 .26555 L
.97031 .22852 L
.97094 .18909 L
.97113 .17739 L
.97122 .17166 L
.97131 .16639 L
.97146 .45622 L
.97155 .45103 L
.97164 .44555 L
.97228 .40544 L
.9747 .2537 L
.97619 .16044 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000U2000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00;?ooool3
o`0001_ooooo1Ol0000Kooooo`?o00006_ooool2o`0001gooooo0ol0000Kooooo`Go00006oooool3
o`0003[ooooo0ol0000Looooo`Go00007?ooool3o`0001[ooooo0_l0000Mooooo`?o00006oooool5
o`0001cooooo0ol0000Iooooo`00:oooool01Ol0003ooooooooooooooooo000001_ooooo00Co0000
oooooooooooo00007?ooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0001gooooo
00?o0000ooooooooool06oooool01?l0003oooooooooool0000Jooooo`05o`000?oooooooooooooo
ool00000>?ooool01Ol0003ooooooooooooooooo000001cooooo00Co0000oooooooooooo00007Ooo
ool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool0
6oooool01?l0003oooooooooool0000Kooooo`05o`000?ooooooooooooooool000006?ooool002Go
oooo1Ol00005ooooo`03o`000?oooooooooo01;ooooo1Ol00003ooooo`03o`000?oooooooooo01Co
oooo1Ol00003ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00007Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<?ooool5o`00
00Gooooo00?o0000ooooooooool04oooool5o`0000?ooooo00?o0000ooooooooool05Oooool5o`00
00?ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Fooooo`00;Oooool2o`00
01kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`04o`000?oooooooooo
o`0001gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`;o0000>oooool2
o`0001oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Hooooo`04o`000?oooooo
ooooo`0001gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Looooo`;o00006Ooo
ool002oooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000001cooooo00?o
0000ooooooooool06?ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo01[ooooo
00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool06Oooool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooooooool06?ooool01?l0
003oooooooooool0000Mooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00
000Oooooo`03o`000?oooooooooo01Kooooo000[ooooo`05o`000?ooooooooooooooool000006_oo
ool01Ol0003ooooooooooooooooo000001_ooooo0_l0000Jooooo`04o`000?ooooooooooo`0001co
oooo0_l0000Looooo`05o`000?ooooooooooooooool000006_ooool01Ol0003ooooooooooooooooo
000003Sooooo00Go0000ooooooooooooooooo`00000Kooooo`05o`000?ooooooooooooooool00000
7?ooool2o`0001[ooooo00Co0000oooooooooooo00007?ooool2o`0001cooooo00Go0000oooooooo
ooooooooo`00000Kooooo`05o`000?ooooooooooooooool000006?ooool002cooooo0ol0000Loooo
o`?o00007Oooool00ol0003oooooooooo`0Iooooo`;o00007_ooool00ol0003oooooooooo`0Koooo
o`?o00007?ooool3o`0003[ooooo0ol0000Mooooo`?o00007_ooool00ol0003oooooooooo`0Ioooo
o`;o00007_ooool00ol0003oooooooooo`0Kooooo`?o00007Oooool3o`0001Wooooo003oooooooWo
oooo003oooooooWooooo003oooooooWooooo000Qoooooloo00009ooooooAo`00013ooooo000Koooo
o`;o00001?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool0000Wooooo`;o000000?oooooo`000?ooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`04o`000?oooooo0000o`00013ooooo000Jooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo
000Jooooo`04o`000?ooooooooooo`0000?ooooo0ol00002ooooodCoo`0000?oooooool00?oo0000
0ooo00001?ooooooo`00oooooooo0005ooooo`03ool00?oooooooooo00Goo`000ooooolCool00005
oooooooo003ooooooooooooo00001?ooool00ooo003oooooool00018ool000?ooooo0_l0000Ooooo
o`?o00001Oooool00ol0003oooooooooo`1Booooo`03ool00?oooooooooo013ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`0>ooooo`006_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00CoooooCOoo0002ooooo`[oo`000ooooolHool000;oooooCOoo0004oooo
o`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo05;ooooo0_oo000Aooooo`03o`000?oooooooooo01;ooooo0_oo001Aooooo`03o`000?oooooo
oooo00kooooo000Jooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?oooom=
ool00003oooooooo003oo`0002Coo`0000?oooooool00?oo0000C?oo0004ooooo`03o`000?oooooo
oooo01Kooooo1Ol00005ooooo`03o`000?oooooooooo00;ooooo0_l0001Cooooo`;oo`004Oooool0
0ol0003oooooooooo`0Booooo`?oo`00Coooool2o`00013ooooo000Jooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool0>?oooolIool00003oooooooo003oo`0000Woo`001oooool0
0ol0003oooooooooo`06ooooo`_oo`0000?oooooool00?oo00005ooo000iooooo`03o`000?oooooo
oooo01kooooo0_l00005ooooo`03o`000?oooooooooo05;ooooo0ooo000@ooooo`03o`000?oooooo
oooo01;ooooo1?oo001?ooooo`03o`000?oooooooooo00kooooo000Kooooo`;o00001?ooool00ol0
003oooooooooo`12ooooo`ooo`0000?oooooool00?oo00001_oo000:ooooo`03o`000?oooooooooo
00Wooooo2?oo00000oooooooo`00ool0000=ool004?ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo05;ooooo1_oo000=ooooo`03o`000?oooooooooo
01;ooooo1_oo00000oooooooo`00ooooo`1:ooooo`03o`000?oooooooooo00kooooo000Qooooo`03
o`000?oooooooooo04Kooooo2ooo00000oooooooo`00ool00005ool000_ooooo00?o0000oooooooo
ool02_ooool7ool00003oooooooo003oo`0000Soo`00B?ooool00ol0003oooooooooo`0Looooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Booooo`Ooo`003?ooool00ol0
003oooooooooo`0Booooo`Woo`0000?oooooool00?ooool0Aoooool00ol0003oooooooooo`0>oooo
o`008Oooool2o`0004Wooooo2Ooo00000oooooooo`00ool00003ool000gooooo00?o0000oooooooo
ool02oooool6ool00003oooooooo003oo`0000Koo`00BOooool2o`0001oooooo0ol00005ooooo`;o
0000Doooool7ool000cooooo00?o0000ooooooooool04_ooool;ool004Oooooo0_l0000@ooooo`00
8Oooool00ol0003oooooooooo`1:ooooo`Ooo`0000?oooooool00?oo00000_oo000>ooooo`03o`00
0?oooooooooo00cooooo1Ooo00000oooooooo`00ool00005ool004_ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1Booooo`Woo`002_ooool00ol0003oooooooooo`0Booooo`koo`00
AOooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1;ooooo`Koo`0000?o
ooooool00?oo00000_oo000>ooooo`03o`000?oooooooooo00cooooo1Ooo00000oooooooo`00ool0
0003ool004gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Booooo`[oo`002Ooo
ool00ol0003oooooooooo`0Boooooa3oo`00@oooool00ol0003oooooooooo`0>ooooo`008Oooool0
0ol0003oooooooooo`1<ooooo`Goo`0000Coooooool00?oo003oo`003oooool00ol0003ooooooooo
o`0=ooooo`Coo`0000?oooooool00?oo00000ooo001=ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0D_ooool:ool000Wooooo00?o0000ooooooooool04_oooolBool00003oooooooo
003ooooo03kooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0C?ooool5
ool00004oooooooo003oo`00ool000oooooo00?o0000ooooooooool03Oooool4ool00003oooooooo
003oo`0000;oo`00C_ooool00ol0003oooooooooo`0Uooooo`;o0000Doooool;ool000Sooooo00?o
0000ooooooooool04_oooolDool00003oooooooo003oo`0003_ooooo0_l0000@ooooo`008Oooool0
0ol0003oooooooooo`1=ooooo`Coo`0000Coooooool00?oo003oo`003oooool00ol0003ooooooooo
o`0>ooooo`?oo`0000?oooooool00?oo00000_oo001>ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0D_ooool;ool000Sooooo00?o0000ooooooooool04_oooolGool00003oooooooo
003ooooo03Wooooo00?o0000ooooooooool03_ooool0027ooooo0_l0001>ooooo`Coo`0000?ooooo
ool00?oo00004?ooool00ol0003oooooooooo`0>ooooo`?oo`0000?oooooool00?oo00000_oo001=
ooooo`;o00009oooool00ol0003oooooooooo`1Booooo`coo`001oooool00ol0003oooooooooo`0B
oooooa_oo`00>?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1>oooo
o`?oo`0000?oooooool00?oo00004?ooool00ol0003oooooooooo`0>ooooo`?oo`0000Coooooool0
0?oo003oo`00Coooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo3Ooo0006
ooooo`03o`000?oooooooooo01;ooooo7?oo000gooooo`03o`000?oooooooooo00kooooo000Qoooo
o`03o`000?oooooooooo04kooooo0ooo00000oooooooo`00ool0000@ooooo`03o`000?oooooooooo
00kooooo0ooo00001?ooooooo`00ool00?oo001?ooooo`03o`000?oooooooooo02Gooooo0_l0001C
ooooo`goo`001_ooool00ol0003oooooooooo`0Boooooakoo`0000?oooooool00?ooool0<Oooool2
o`00013ooooo000Qooooo`03o`000?oooooooooo04kooooo0ooo00000oooooooo`00ool0000@oooo
o`03o`000?oooooooooo00kooooo0ooo00001?ooooooo`00ool00?oo001?ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0D_ooool>ool000Gooooo00?o0000ooooooooool04_oooolR
ool0037ooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0C_ooool3ool0
0003oooooooo003ooooo013ooooo00?o0000ooooooooool03oooool2ool00003oooooooo003oo`00
053ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Booooo`koo`001Oooool00ol0
003oooooooooo`0Booooob?oo`0000?oooooool00?ooool0;Oooool00ol0003oooooooooo`0>oooo
o`008Oooool00ol0003oooooooooo`1>ooooo`?oo`0000?oooooool00?ooool04?ooool00ol0003o
ooooooooo`0?ooooo`;oo`0000?oooooool00?oo0000D?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo05;ooooo3_oo0005ooooo`03o`000?oooooooooo01;ooooo9_oo000]ooooo`03
o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo04oooooo0_oo00000oooooooo`00
ooooo`0@ooooo`03o`000?oooooooooo00oooooo0_oo00000oooooooo`00ool0001@ooooo`03o`00
0?oooooooooo02Gooooo0_l0001Cooooo`ooo`001?ooool00ol0003oooooooooo`0BooooobSoo`00
:_ooool2o`00013ooooo000Qooooo`;o0000D?ooool2ool00003oooooooo003ooooo013ooooo00?o
0000ooooooooool03oooool2ool00003oooooooo003oo`0004oooooo0_l0000Wooooo`03o`000?oo
oooooooo05;ooooo4?oo0003ooooo`03o`000?oooooooooo01;ooooo;Ooo000Vooooo`03o`000?oo
oooooooo00kooooo000Qooooo`03o`000?oooooooooo04oooooo0_oo00000oooooooo`00ooooo`0@
ooooo`03o`000?oooooooooo00oooooo0_oo00000oooooooo`00ool0001@ooooo`03o`000?oooooo
oooo01cooooo1Ol00004ooooo`03o`000?oooooooooo05;ooooo4?oo0003ooooo`03o`000?oooooo
oooo01;ooooo;_oo000Uooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo
04oooooo0_oo00000oooooooo`00ooooo`0@ooooo`03o`000?oooooooooo00oooooo0_oo00000ooo
ooooo`00ool0001@ooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`1Boooooa3oo`000oooool00ol0003oooooooooo`0Boooooc3oo`0000?ooooo
ool00?ooool08?ooool00ol0003oooooooooo`0>ooooo`004oooool5o`0000?ooooo0_l00004oooo
o`03o`000?oooooooooo04oooooo0_oo00000oooooooo`00ooooo`0@ooooo`03o`000?oooooooooo
00oooooo0_oo00000oooooooo`00ool0001@ooooo`03o`000?oooooooooo01Kooooo1Ol00003oooo
o`03o`000?oooooooooo00Cooooo0_l0001Coooooa3oo`000oooool00ol0003oooooooooo`0Boooo
ocCoo`007_ooool2o`00013ooooo000Dooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`1?ooooo`;oo`0000?oooooool00?ooool04?ooool0
0ol0003oooooooooo`0?ooooo`;oo`0000?oooooool00?ooool0D?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0D_oooolAool000;ooooo00?o0000
ooooooooool04_oooolgool001cooooo00?o0000ooooooooool03_ooool001Gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04oooooo0_oo0000
0oooooooo`00ooooo`0@ooooo`03o`000?oooooooooo00oooooo0_oo00000oooooooo`00ooooo`1@
ooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo05;ooooo4_oo00000ooooooo0000ooooo`0CooooocWoo`000_ooool00ooo003ooooooooo
o`0Eooooo`03o`000?oooooooooo00kooooo000Fooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooooooool3o`0004oooooo0_oo00000oooooooo`00ooooo`0@ooooo`03o`00
0?oooooooooo00oooooo0_oo00000oooooooo`00ooooo`1?ooooo`;o00007_ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool0D_oooolBool00003ooooool0003ooooo01?o
oooo??oo000Gooooo`03o`000?oooooooooo00kooooo000Cooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04oooooo0_oo00000ooo
ooooo`00ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0
003oooooooooo`0Mooooo`?o00001Oooool2o`0005?ooooo4_oo00000ooooooo0000ooooo`0Coooo
ockoo`0000?oooooool00?ooool04Oooool2o`00013ooooo000Cooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo04oooooo0_oo0000
0oooooooo`00ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo4_oo00000ooooooo0000ooooo`0C
oooood?oo`004?ooool00ol0003oooooooooo`0>ooooo`005?ooool3o`0000Cooooo0_l00004oooo
o`03o`000?oooooooooo053ooooo00?oo`00oooooooo00004Oooool00ol0003oooooooooo`0@oooo
o`03ool00?ooooooo`00057ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Boooo
oa?oo`0000?o0000ooooooooool04_oooom6ool000gooooo00?o0000ooooooooool03_ooool0027o
oooo00?o0000ooooooooool0D?ooool00ooo003oooooool0000Aooooo`03o`000?oooooooooo013o
oooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;o
oooo4ooo00000ol0003oooooooooo`0AooooodWoo`002oooool00ol0003oooooooooo`0>ooooo`00
8Oooool00ol0003oooooooooo`1@ooooo`03ool00?ooooooo`00017ooooo00?o0000ooooooooool0
4?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Gooooo0_l0001Coooooa?oo`00
00?o0000ooooooooool04Ooooom>ool000Gooooo0_l0000@ooooo`008Oooool2o`00057ooooo00?o
o`00oooooooo00004Oooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00053ooooo0_l0
000Wooooo`03o`000?oooooooooo05;ooooo4ooo00000ol0003oooooooooo`0Aooooodkoo`0000?o
ooooool00?ooool00oooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@
ooooo`03ool00?ooooooo`00017ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001A
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool3ool004cooooo5?oo000C
oooooe3oo`001?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@oooo
o`03ool00?ooooooo`00017ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool6ool004Wooooo5?oo000Coooo
oe3oo`001?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`03
ool00?ooooooo`00017ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03
o`000?oooooooooo02Gooooo0_l00004ooooo`Koo`0000?oooooool00?ooool0A_oooolEool001;o
ooooD?oo0003ooooo`;o00004?ooool0027ooooo00?o0000ooooooooool0D?ooool00ooo003ooooo
ool0000Aooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00?ooooo2Ooo00000oooooooo`00ool00013oooooaGoo`00
4_oooom@ool000Cooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0D?oo
ool00ooo003oooooool0000Aooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOoo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo3Ooo00000oooooooo`00oooo
o`0ooooooaGoo`004_oooom@ool000Cooooo00?o0000ooooooooool03_ooool0027ooooo0_l0001A
ooooo`03ool00?ooooooo`00017ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001@
ooooo`;o00009oooool00ol0003oooooooooo`03ooooo`ooo`000_ooool00ooo003oooooooooo`0k
oooooaKoo`004Ooooom@ool000Cooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000oooo
ooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aoooo
o`03o`000?oooooooooo02Gooooo0_l00004oooooa?oo`00??oooolFool0017oooooD?oo0003oooo
o`;o00004?ooool0027ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000oooooooo
ool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00ooooolDool00003oooooooo003oo`0003Sooooo5_oo000Aoooooe3oo`001?ooool00ol0003o
ooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003ooooo
ooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool07Oooool3o`0000Gooooo
00?o0000ooooooooool00ooooolJool003Gooooo5_oo000Aoooooe3oo`001?ooool00ol0003ooooo
ooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003ooooooooo
o`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo6_oo00000oooooooo`00ool0000boooooaOoo`004?oo
oom@ool000Cooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0D?ooool2
ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooo
oooo01Kooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo0_l00004oooooagoo`0000?ooooo
ool00?ooool0;ooooolGool0013oooooD?oo0003ooooo`;o00004?ooool0027ooooo0_l0001Aoooo
o`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00053ooooo0_l0000Poooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooooolQool002kooooo6?oo000?oooo
oe3oo`001?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;o
o`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo8ooo00000ooooooo
o`00ool0000YoooooaSoo`003ooooom@ool000Cooooo00?o0000ooooooooool03_ooool0027ooooo
00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003ooooo
ool0001Aooooo`03o`000?oooooooooo01gooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo
:Ooo000VoooooaSoo`003ooooom@ool000Cooooo00?o0000ooooooooool03_ooool001Gooooo0ol0
0003ooooo`;o00001?ooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003ooooooooo
o`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`04ooooo`;o00001?ooool[ool002Cooooo6Ooo000>oooooe3oo`000oooool2o`00013ooooo000F
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000005;ooooo
0_oo000Booooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00?ooooo;?oo00000oooooooo`00ooooo`0PoooooaWoo`00
3_oooom@ool000Cooooo00?o0000ooooooooool03_ooool001?ooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool0
4?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0oooool/ool00004oooooooo003oo`00ool001oooooo6_oo000=oooooe3oo`001?ooool00ol0003o
ooooooooo`0>ooooo`004oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00?ooooo0ol0001@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00
053ooooo0_l0000Wooooo`03o`000?oooooooooo00?ooooo<?oo00000oooooooo`00ooooo`0Loooo
oa[oo`003Ooooom@ool000Cooooo00?o0000ooooooooool03_ooool001Cooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo053ooooo0_oo000Boooo
o`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Uoooo
o`;o00001?oooolbool00003oooooooo003ooooo01[ooooo6ooo000<oooooe3oo`000oooool2o`00
013ooooo000Eooooo`;o00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo=Ooo00000oooooooo`00ool0000Goooo
oa_oo`003?oooom@ool000Cooooo00?o0000ooooooooool03_ooool001Kooooo00?o0000oooooooo
ool00_ooool2o`0000Cooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000oooooooo
ool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00oooooljool001Gooooo7?oo000;oooooe3oo`001?ooool00ol0003oooooooooo`0>ooooo`00
8Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool0
0?ooooooo`00057ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03oooooc[oo`00
00?oooooool00?ooool04_oooolMool000[oooooD?oo0004ooooo`03o`000?oooooooooo00kooooo
000Qooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo00?o
o`00oooooooo0000DOooool00ol0003oooooooooo`0Uooooo`;o00001?oooolnool0017ooooo7Ooo
000:oooooe3oo`000oooool2o`00013ooooo000Qooooo`;o0000DOooool2ool001;ooooo00?o0000
ooooooooool04?ooool00ooo003oooooool0001@ooooo`;o00009oooool00ol0003oooooooooo`03
oooood;oo`003OoooolOool000SoooooD?oo0004ooooo`03o`000?oooooooooo00kooooo000Qoooo
o`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo00?oo`00oooo
oooo0000DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo@ooo000<oooo
ob3oo`001ooooom@ool000Cooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000oooooooo
ool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooom5ool000[ooooo8_oo0006oooooe3o
o`001?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`00
4_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool0
9Oooool2o`0000?oooooAooo0008ooooobCoo`001?oooom@ool000?ooooo0_l0000@ooooo`008Ooo
ool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?oo
ooooo`00057ooooo00?o0000ooooooooool07_ooool2o`0000Gooooo00?o0000ooooooooool00_oo
oom8ool00003oooooooo003oo`0000Cooooo9?oo0004oooooe3oo`001?ooool00ol0003ooooooooo
o`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@
ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00;oooooCOoo0002ooooobCoo`001?oooom@ool000Cooooo00?o
0000ooooooooool03_ooool0027ooooo0_l0001Aooooo`;oo`004_ooool00ol0003oooooooooo`0@
ooooo`03ool00?ooooooo`00053ooooo0_l0000Oooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool00_oooom=ool000;ooooo9_oo0002oooooe3oo`001?ooool00ol0003ooooooooo
o`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@
ooooo`;oo`00D_ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000Cooooo1Ol0
001@ool00003o`000?oo003oo`0002Goo`0000?o0000ool00?oo0000C?oo0005o`00013ooooo000Q
ooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo0_oo001B
ooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`02oooooe3oo`0000?oooooool00?oo00009Ooo0002ooooodgoo`001?ooool00ol0003ooooooooo
o`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@
ooooo`;oo`00D_ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool00_oooom@ool000?ooooo9Ooo0004oooood_oo`001?ooool00ol0003ooooooooo
o`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@
ooooo`;oo`00D_ooool00ol0003oooooooooo`0Nooooo`;o00001Oooool00ol0003oooooooooo`02
oooooe3oo`001?oooolTool000KoooooBOoo0004ooooo`03o`000?oooooooooo00kooooo000Qoooo
o`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo0_oo001Boooo
o`03o`000?oooooooooo02Gooooo0_l00003oooooe3oo`001_oooolRool000SoooooAooo0003oooo
o`;o00004?ooool0027ooooo0_l0001Aooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`;o
o`00DOooool2o`0002Oooooo00?o0000ooooooooool00_oooom@ool000Oooooo8Ooo000;oooood?o
o`001Oooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`00
4_ooool00ol0003oooooooooo`0@ooooo`;oo`00D_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00;oooooD?oo0008ooooob3oo`003?ooool00ooo003oooooool0000oool000Gooooo
00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o
0000ooooooooool04?ooool2ool005;ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`02oooooe3oo`002OoooolOool000kooooo00?oo`00oooooooo0000?Ooo0005ooooo`03o`000?oo
oooooooo00kooooo000Qooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooo
oooo013ooooo0_oo001Booooo`03o`000?oooooooooo02Gooooo0_l00003oooooe3oo`002_oooolN
ool0013ooooo?_oo0004ooooo`;o00004?ooool001Cooooo0ol00004ooooo`;o00001?ooool00ol0
003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`;oo`00D_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;oooooD?oo000;oooooagoo`004_ooool00ooo
003oooooool0000iool000Gooooo00?o0000ooooooooool03_ooool001?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0D?ooool2
ool001;ooooo00?o0000ooooooooool04?ooool2ool005;ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`02oooooe3oo`002ooooolMool001Cooooo00?oo`00ooooooooool0=ooo0005
ooooo`03o`000?oooooooooo00kooooo000Cooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00003ooooo`?o0000D?ooool2ool001;ooooo00?o0000ooooooooool04?oo
ool2ool0057ooooo0_l0000Wooooo`03o`000?oooooooooo00;oooooD?oo000;oooooagoo`005ooo
ool2ool00003oooooooo003oo`0003;oo`001Oooool00ol0003oooooooooo`0>ooooo`004oooool4
o`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1@ooooo`;oo`004_oo
ool00ol0003oooooooooo`0@ooooo`;oo`00D_ooool00ol0003oooooooooo`0Uooooo`;o00000ooo
oom@ool000gooooo6ooo000Koooooc?oo`001?ooool2o`00013ooooo000Cooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1@ooooo`;oo`004_oo
ool00ol0003oooooooooo`0@ooooo`;oo`00D_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;oooooD?oo000=oooooa_oo`007?ooool00ooo003oooooool0000_ool000Gooooo00?o
0000ooooooooool03_ooool001Cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo0_oo
001Booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooom@ool000kooooo6_oo
000Pooooobkoo`001Oooool00ol0003oooooooooo`0>ooooo`005Oooool2o`0000Cooooo0_l00004
ooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo0_oo001B
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooom@ool000kooooo6_oo000Q
ooooobgoo`001Oooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@oooo
o`;oo`004_ooool00ol0003oooooooooo`0@ooooo`;oo`00D_ooool00ol0003oooooooooo`0Uoooo
o`;o00000ooooom@ool000kooooo6_oo000Tooooob[oo`001?ooool2o`00013ooooo000Qooooo`;o
0000DOooool2ool001;ooooo00?o0000ooooooooool04?ooool2ool0057ooooo0_l0000Oooooo`?o
00001Oooool00ol0003oooooooooo`02oooooe3oo`003ooooolIool002Oooooo00?oo`00oooooooo
00009?oo0005ooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo053ooooo
0_oo000Booooo`03o`000?oooooooooo013ooooo0_oo001Booooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooooe3oo`003ooooolIool002[ooooo
9?oo0005ooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo053ooooo0_oo
000Booooo`03o`000?oooooooooo013ooooo0_oo001Booooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02oooooe3oo`004?oooolHool002cooooo00?o
o`00oooooooo00007ooo0005ooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooo
oooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo0_oo001Booooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01?ooool2o`0000?oooooD?oo000@oooooaSoo`00;oooool2
ool00003oooooooo003oo`0001[oo`001?ooool2o`00013ooooo000Qooooo`03o`000?oooooooooo
053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo0_oo001Booooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooooe3oo`004?oooolHool0
033ooooo00Coo`00oooooooooooooooo6_oo0005ooooo`03o`000?oooooooooo00kooooo000Qoooo
o`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo0_oo001Boooo
o`03o`000?oooooooooo01gooooo0_l00006ooooo`03o`000?oooooooooo00;oooooD?oo000Aoooo
oaOoo`00=OoooolIool000Gooooo00?o0000ooooooooool03_ooool0027ooooo0_l0001Aooooo`;o
o`004_ooool00ol0003oooooooooo`0@ooooo`;oo`00DOooool2o`00023ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02oooooe3oo`004OoooolGool003Sooooo5_oo0005ooooo`03
o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`00
0?oooooooooo013ooooo0_oo001Booooo`03o`000?oooooooooo02Gooooo0_l00003oooooe3oo`00
4OoooolGool003[ooooo5?oo0004ooooo`;o00004?ooool0027ooooo00?o0000ooooooooool0D?oo
ool2ool001;ooooo00?o0000ooooooooool04?ooool2ool005;ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`02oooooe3oo`004_oooolFool003cooooo00?oo`00oooooooo00003ooo
0005ooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo053ooooo0_oo000B
ooooo`03o`000?oooooooooo013ooooo0_oo001Booooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooom@ool001;ooooo5_oo0011ooooo`goo`001Oooool00ol0003oooooooooo`0>
ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@oooo
o`;oo`00D_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;oooooD?oo000Boooo
oaKoo`00@Oooool01?oo003oooooooooooooool9ool000Gooooo00?o0000ooooooooool03_ooool0
027ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04Oooool00ooo
003oooooooooo`1@ooooo`03o`000?oooooooooo02Gooooo0_l00003oooooe3oo`004ooooolEool0
04Kooooo2?oo0004ooooo`;o00004?ooool0027ooooo0_l0001Aooooo`;oo`004_ooool00ol0003o
ooooooooo`0Aooooo`03ool00?oooooooooo04oooooo0_l0000Wooooo`03o`000?oooooooooo00;o
ooooD?oo000CoooooaGoo`00BOooool2ool00003oooooooo003oo`0000Gooooo00?o0000oooooooo
ool03_ooool0027ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool0
4Oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooom@ool001?ooooo5Ooo001=ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool0027ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04Ooo
ool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
oom@ool001?ooooo5Ooo001Cooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooo
oooo053ooooo0_oo000Booooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0D?ooool0
0ol0003oooooooooo`0Uooooo`;o00001ooooom<ool001?ooooo00?o0000ool00?oo00004_oo001B
ooooo`;o00004?ooool001Cooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`1@oooo
o`;oo`004_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo053ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`09ooooodWoo`004oooool00ol0003oo`00ool0000Bool0
05?ooooo00?o0000ooooooooool03_ooool001?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000
ooooooooool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool02ooooom7ool001?ooooo00?o0000oooooooo00004_oo001Cooooo`03o`000?oooooo
oooo00kooooo000Cooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0003ooooo`?o0000D?ooool2ool001;ooooo00?o0000ooooooooool04Oooool00ooo003ooooooooo
o`1?ooooo`;o00009oooool00ol0003oooooooooo`0@oooood;oo`004oooool00ol0003oooooool0
000Bool005?ooooo00?o0000ooooooooool03_ooool001Cooooo0ol00003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04Ooo
ool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo02Gooooo0_l0000Aooooo`05ool00?oo
ooooo`00ool00?ooool0?Ooo000Cooooo`03o`000?ooooooo`0001;oo`00D_ooool2o`00013ooooo
000Cooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo017ooooo00?oo`00oooooooo
ool0D?ooool00ol0003oooooooooo`0Looooo`Go00001?ooool00ol0003oooooooooo`0Eooooocgo
o`004oooool00ol0003oooooool0000Bool005?ooooo00?o0000ooooooooool03_ooool001?ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@oooo
o`03o`000?oooooooooo01gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0E
ooooo`04ool00?ooooooo`00ooooocWoo`004oooool00ol0003oooooooooo`0Bool005?ooooo00?o
0000ooooooooool03_ooool001Cooooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`1@
ooooo`;oo`004_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo053ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo>?oo000C
ooooo`03o`000?oooooooooo017oo`00E?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0
003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo
053ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`;o00007?ooool00ooo
003oooooool0000dool001?ooooo00?o0000ooooooooool04Ooo001Cooooo`;o00004?ooool0027o
oooo0_l0001Aooooo`;oo`004_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo04oo
oooo0_l0000Nooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Poooo
oc;oo`004oooool01?l0003oooooooooooooool@ool005Cooooo00?o0000ooooooooool03_ooool0
027ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04Oooool00ooo
003oooooooooo`1@ooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo02Cooooo;_oo000Cooooo`04o`000?oooooooooooooooa3oo`00E?oo
ool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool0
0ol0003oooooooooo`0Aooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool07Oooool3
o`0000Gooooo00?o0000ooooooooool09_ooool/ool001?ooooo00Co0000oooooooooooooooo4?oo
001Dooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo053ooooo0_oo000B
ooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0U
ooooo`;o0000:OoooolZool001?ooooo00?o0000ooooooooool00_ooool?ool005?ooooo0_l0000@
ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0Aoooo
o`03ool00?oooooooooo053ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Zoooo
o`03ool00?ooooooo`0002Goo`004oooool00ol0003oooooooooo`02ooooo`ooo`00E?ooool00ol0
003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003o
ooooooooo`0Aooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0]ooooobGoo`004oooool00ol0003oooooooooo`03ooooo`koo`00E?ooool00ol0003o
ooooooooo`0>ooooo`008Oooool2o`0005;ooooo00?oo`00ooooooooool04?ooool00ol0003ooooo
ooooo`0Aooooo`03ool00?oooooooooo04oooooo0_l0000Wooooo`03o`000?oooooooooo02oooooo
0_oo0002oooooaooo`004oooool00ol0003oooooooooo`03ooooo`koo`00E?ooool00ol0003ooooo
ooooo`0>ooooo`008Oooool00ol0003oooooooooo`1Aooooo`03ool00?oooooooooo013ooooo00?o
0000ooooooooool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo02Gooooo0_l0
000doooooaooo`004oooool00ol0003oooooooooo`04ooooo`goo`00Doooool2o`00013ooooo000Q
ooooo`03o`000?oooooooooo057ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0A
ooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0d
oooooagoo`005?ooool00ol0003oooooooooo`05ooooo`coo`00E?ooool00ol0003oooooooooo`0>
ooooo`008Oooool00ol0003oooooooooo`1Aooooo`03ool00?oooooooooo013ooooo00?o0000oooo
ooooool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0=ooooolJool001Cooooo00?o0000ooooooooool01Oooool<ool005Cooooo00?o0000oooo
ooooool03_ooool0027ooooo00?o0000ooooooooool0DOooool00ooo003oooooooooo`0@ooooo`03
o`000?oooooooooo017ooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Wooooo00Coo`00oooooooo003ooooo5?oo000Dooooo`03o`000?oooooooooo
00Kooooo2ooo001Dooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo057o
oooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo053o
oooo00?o0000ooooooooool09Oooool2o`0003kooooo5?oo000Dooooo`03o`000?oooooooooo00Oo
oooo2_oo001Cooooo`;o00004?ooool0027ooooo0_l0001Booooo`03ool00?oooooooooo013ooooo
00?o0000ooooooooool04Oooool00ooo003oooooooooo`1?ooooo`;o00009oooool00ol0003ooooo
ooooo`0ooooooa;oo`005?ooool00ol0003oooooooooo`07ooooo`[oo`00E?ooool00ol0003ooooo
ooooo`0>ooooo`008Oooool00ol0003oooooooooo`1Aooooo`03ool00?oooooooooo013ooooo00?o
0000ooooooooool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0@Oooool@ool001Cooooo00?o0000ooooooooool01oooool00ooo003oooooool0
0007ool005Cooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0DOooool0
0ooo003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0D?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04?ooooo00?oo`00oooooooo00002ooo000D
ooooo`03o`000?oooooooooo00Wooooo2?oo001Dooooo`03o`000?oooooooooo00kooooo000Qoooo
o`03o`000?oooooooooo057ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`03ool00?oooooooooo053ooooo00?o0000ooooooooool09Oooool2o`0004Oooooo2ooo000Doooo
o`03o`000?oooooooooo00Wooooo2?oo001Cooooo`;o00004?ooool000kooooo0ol00004ooooo`;o
00001?ooool2o`0000Cooooo00?o0000ooooooooool0DOooool00ooo003oooooooooo`0@ooooo`03
o`000?oooooooooo017ooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0Mooooo`?o
00001Oooool00ol0003oooooooooo`17ooooo`[oo`005?ooool00ol0003oooooooooo`0<ooooo`Go
o`00E?ooool00ol0003oooooooooo`0>ooooo`003oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1Aoooo
o`03ool00?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@oooo
o`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo04Wooooo2?oo000Dooooo`03o`000?oooooooooo00cooooo1Ooo001Dooooo`03o`000?oooooo
oooo00kooooo000?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00003ooooo`?o0000DOooool00ooo003oooooooooo`0@ooooo`03o`000?oo
oooooooo017ooooo00?oo`00ooooooooool0Coooool2o`0002;ooooo00?o0000ooooooooool00_oo
ool2o`0004oooooo0ooo000Dooooo`03o`000?oooooooooo00gooooo1?oo001Cooooo`;o00004?oo
ool000oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0DOooool00ooo003oooooooooo`0@ooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool07_ooool2o`0000Gooooo00?o0000ooooooooool0
C_ooool3ool001Cooooo00?o0000ooooooooool03_ooool3ool005Cooooo00?o0000ooooooooool0
3_ooool000oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo00oooooo00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0>ooooo`00
3_ooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0001kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`0>ooooo`003oooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool2o`0000Cooooocol0000Oooooo`?o00001Oooool2o`000003ooooool0
003ooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?l0000@ooooo`00oooo
oolHooooom7o00004?ooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {147.312, 0}} -> {-0.0551454, -0.0147182, \
0.00419541, 0.00419541}, {{13.125, 240.125}, {143.75, 3.5}} -> {-4.38632, \
-14.9939, 0.0320523, 0.825438}, {{262.812, 489.812}, {143.75, 3.5}} -> \
{-12.1581, -4.01628, 0.0316988, 0.0503636}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot DTFT as a function of frequency", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g1 = 
        Plot[Abs[
            X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
              2, fs/2}, \ PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[Arg[
            X\[Theta] /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/2, 
            fs/2}, \ PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.00588579 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13243 -12 -4.5 ]
[-0.0125 .13243 0 4.5 ]
[-0.0125 .25015 -12 -4.5 ]
[-0.0125 .25015 0 4.5 ]
[-0.0125 .36786 -12 -4.5 ]
[-0.0125 .36786 0 4.5 ]
[-0.0125 .48558 -12 -4.5 ]
[-0.0125 .48558 0 4.5 ]
[-0.0125 .60329 -18 -4.5 ]
[-0.0125 .60329 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13243 m
.00625 .13243 L
s
[(20)] -0.0125 .13243 1 0 Mshowa
0 .25015 m
.00625 .25015 L
s
[(40)] -0.0125 .25015 1 0 Mshowa
0 .36786 m
.00625 .36786 L
s
[(60)] -0.0125 .36786 1 0 Mshowa
0 .48558 m
.00625 .48558 L
s
[(80)] -0.0125 .48558 1 0 Mshowa
0 .60329 m
.00625 .60329 L
s
[(100)] -0.0125 .60329 1 0 Mshowa
.125 Mabswid
0 .04414 m
.00375 .04414 L
s
0 .07357 m
.00375 .07357 L
s
0 .103 m
.00375 .103 L
s
0 .16186 m
.00375 .16186 L
s
0 .19129 m
.00375 .19129 L
s
0 .22072 m
.00375 .22072 L
s
0 .27958 m
.00375 .27958 L
s
0 .309 m
.00375 .309 L
s
0 .33843 m
.00375 .33843 L
s
0 .39729 m
.00375 .39729 L
s
0 .42672 m
.00375 .42672 L
s
0 .45615 m
.00375 .45615 L
s
0 .51501 m
.00375 .51501 L
s
0 .54444 m
.00375 .54444 L
s
0 .57386 m
.00375 .57386 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13243 m
1 .13243 L
s
.99375 .25015 m
1 .25015 L
s
.99375 .36786 m
1 .36786 L
s
.99375 .48558 m
1 .48558 L
s
.99375 .60329 m
1 .60329 L
s
.125 Mabswid
.99625 .04414 m
1 .04414 L
s
.99625 .07357 m
1 .07357 L
s
.99625 .103 m
1 .103 L
s
.99625 .16186 m
1 .16186 L
s
.99625 .19129 m
1 .19129 L
s
.99625 .22072 m
1 .22072 L
s
.99625 .27958 m
1 .27958 L
s
.99625 .309 m
1 .309 L
s
.99625 .33843 m
1 .33843 L
s
.99625 .39729 m
1 .39729 L
s
.99625 .42672 m
1 .42672 L
s
.99625 .45615 m
1 .45615 L
s
.99625 .51501 m
1 .51501 L
s
.99625 .54444 m
1 .54444 L
s
.99625 .57386 m
1 .57386 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02847 .01511 L
.02964 .01853 L
.02998 .01943 L
.03014 .01978 L
.0303 .02006 L
.03043 .02026 L
.03058 .02043 L
.03073 .02054 L
.03082 .02058 L
.03089 .0206 L
.03098 .0206 L
.03107 .02058 L
.03116 .02055 L
.03124 .0205 L
.03139 .02036 L
.03156 .02014 L
.03175 .01981 L
.03193 .01942 L
.03227 .01852 L
.03289 .0164 L
.03304 .01583 L
.03321 .01521 L
.0333 .01485 L
.03338 .01491 L
.03347 .01524 L
.03355 .01556 L
.03412 .01765 L
.03442 .0186 L
.03474 .01944 L
.03502 .01999 L
.03517 .02023 L
.03532 .0204 L
.03545 .02052 L
.03557 .02058 L
.0357 .02061 L
.03584 .02059 L
.036 .0205 L
.03614 .02038 L
.0363 .02017 L
.03646 .01991 L
.03673 .01933 L
.03703 .01853 L
.03735 .0175 L
.0377 .01625 L
.03786 .01561 L
.03802 .01499 L
.03817 .01499 L
.03832 .0156 L
.03888 .01762 L
Mistroke
.03918 .01858 L
.03946 .01935 L
.03963 .01971 L
.03981 .02004 L
.03997 .02028 L
.04012 .02045 L
.04026 .02055 L
.04041 .02061 L
.04049 .02061 L
.04057 .0206 L
.04072 .02054 L
.0408 .02048 L
.04089 .02039 L
.04105 .0202 L
.04122 .01992 L
.0414 .01954 L
.04205 .01771 L
.04235 .01666 L
.04251 .01607 L
.04267 .01543 L
.04282 .01486 L
.04298 .01519 L
.04312 .01575 L
.04326 .01626 L
.04387 .01837 L
.04419 .01926 L
.04437 .01967 L
.04453 .01999 L
.04469 .02023 L
.04483 .0204 L
.04499 .02054 L
.04507 .02058 L
.04516 .02061 L
.0453 .02061 L
.04543 .02057 L
.04558 .02047 L
.04573 .02031 L
.04587 .02012 L
.04599 .0199 L
.04628 .01928 L
.0468 .01777 L
.04737 .01568 L
.04751 .01515 L
.04766 .01487 L
.04774 .0152 L
.04782 .0155 L
.04797 .01608 L
.04856 .01814 L
.04888 .01907 L
.04918 .01977 L
Mistroke
.04943 .02021 L
.04957 .02039 L
.0497 .02051 L
.04985 .0206 L
.05 .02063 L
.05015 .0206 L
.05028 .02052 L
.05044 .02038 L
.05053 .02027 L
.05061 .02015 L
.05092 .01957 L
.0512 .01887 L
.0515 .01797 L
.0518 .01694 L
.05211 .01575 L
.05221 .01539 L
.0523 .01504 L
.05238 .01473 L
.05246 .01504 L
.05279 .0163 L
.05334 .01821 L
.05362 .01905 L
.05393 .01976 L
.05409 .02006 L
.05426 .02032 L
.05434 .02041 L
.05442 .02049 L
.05457 .02059 L
.05465 .02062 L
.05474 .02064 L
.05489 .02062 L
.05504 .02054 L
.05518 .02042 L
.05532 .02024 L
.05548 .01999 L
.05576 .01939 L
.05641 .01747 L
.05676 .0162 L
.05693 .01554 L
.05709 .01492 L
.05723 .01507 L
.05739 .01567 L
.05771 .01689 L
.05832 .01887 L
.05862 .01963 L
.0588 .01998 L
.05896 .02024 L
.05913 .02045 L
.05923 .02054 L
.05932 .0206 L
Mistroke
.0594 .02063 L
.05948 .02065 L
.05957 .02065 L
.05966 .02063 L
.05982 .02054 L
.05996 .0204 L
.06013 .02019 L
.0603 .01989 L
.06061 .01919 L
.06095 .01821 L
.06125 .01719 L
.06157 .01601 L
.06174 .01538 L
.06189 .01478 L
.06203 .01519 L
.06218 .01577 L
.06274 .01781 L
.06302 .01871 L
.06333 .01952 L
.06348 .01984 L
.06362 .0201 L
.06374 .02029 L
.06388 .02045 L
.06403 .02058 L
.06412 .02063 L
.06419 .02065 L
.06433 .02066 L
.06448 .02062 L
.06456 .02057 L
.06465 .0205 L
.06483 .02029 L
.06499 .02004 L
.06514 .01975 L
.06578 .01799 L
.06637 .01588 L
.06652 .01527 L
.06661 .01494 L
.06669 .01481 L
.06678 .01515 L
.06687 .01553 L
.06704 .01618 L
.06768 .01841 L
.06797 .01923 L
.06828 .01993 L
.06846 .02023 L
.06862 .02044 L
.0687 .02052 L
.06878 .02059 L
.06893 .02066 L
.06908 .02068 L
Mistroke
.06924 .02064 L
.06932 .02059 L
.0694 .02052 L
.06955 .02035 L
.06971 .02013 L
.06985 .01986 L
.07013 .01924 L
.07068 .01754 L
.0712 .01563 L
.07133 .01512 L
.07146 .01486 L
.07162 .01546 L
.07176 .01602 L
.07236 .01816 L
.07265 .01903 L
.07296 .01978 L
.07311 .02007 L
.07325 .0203 L
.07338 .02046 L
.07352 .02059 L
.07367 .02067 L
.07376 .0207 L
.07384 .0207 L
.07392 .02068 L
.074 .02065 L
.07409 .0206 L
.07417 .02053 L
.07433 .02036 L
.07446 .02015 L
.07478 .01952 L
.07508 .01871 L
.07537 .01781 L
.0757 .0166 L
.07585 .01604 L
.07601 .01541 L
.07617 .01478 L
.07632 .01523 L
.07665 .01649 L
.077 .01777 L
.07733 .0188 L
.07762 .01956 L
.07793 .02019 L
.0781 .02043 L
.07825 .02059 L
.07834 .02065 L
.07842 .02069 L
.07851 .02071 L
.07859 .02072 L
.07874 .02069 L
.07889 .02059 L
Mistroke
.07903 .02044 L
.07917 .02027 L
.07949 .01966 L
.07979 .01889 L
.08031 .01718 L
.0806 .0161 L
.08074 .01556 L
.08087 .01506 L
.08101 .01493 L
.08116 .01552 L
.08147 .01674 L
.08203 .01865 L
.08233 .01946 L
.08261 .02007 L
.08275 .0203 L
.0829 .0205 L
.08299 .02058 L
.08307 .02065 L
.08323 .02073 L
.08336 .02074 L
.0835 .02071 L
.08363 .02063 L
.08375 .02051 L
.0839 .02033 L
.08405 .02008 L
.08433 .01948 L
.08497 .01758 L
.08531 .0163 L
.08548 .01564 L
.08564 .01503 L
.08578 .01497 L
.08591 .0155 L
.08621 .01665 L
.08653 .01782 L
.08684 .01879 L
.08713 .01958 L
.08728 .01992 L
.08745 .02022 L
.08758 .02042 L
.08773 .02059 L
.08787 .0207 L
.088 .02075 L
.08807 .02077 L
.08816 .02076 L
.08831 .02071 L
.08846 .0206 L
.08859 .02045 L
.08874 .02023 L
.0889 .01993 L
.08923 .01915 L
Mistroke
.08978 .01739 L
.09009 .01626 L
.09024 .01567 L
.09038 .01511 L
.09051 .01483 L
.09064 .01539 L
.09094 .01653 L
.09145 .01835 L
.09176 .01927 L
.09194 .0197 L
.0921 .02004 L
.09224 .0203 L
.09238 .02049 L
.09253 .02065 L
.09261 .02071 L
.09269 .02075 L
.09277 .02078 L
.09285 .02079 L
.09294 .02078 L
.09302 .02076 L
.09317 .02067 L
.09325 .02059 L
.09333 .0205 L
.09349 .02027 L
.09367 .01994 L
.09403 .01907 L
.09464 .01706 L
.0948 .01645 L
.09497 .01577 L
.09505 .01546 L
.09514 .01512 L
.09529 .01492 L
.09544 .01553 L
.09558 .01609 L
.0959 .01731 L
.09646 .01912 L
.09677 .01989 L
.09692 .02018 L
.09706 .02041 L
.09714 .02052 L
.09723 .02062 L
.09738 .02074 L
.09746 .02079 L
.09755 .02082 L
.09763 .02082 L
.09772 .02081 L
.09787 .02074 L
.09801 .02062 L
.09809 .02053 L
.09818 .02042 L
Mistroke
.09833 .02016 L
.09863 .01952 L
.09891 .01875 L
.09947 .01683 L
.09974 .01576 L
.09986 .01528 L
.09999 .01475 L
.10012 .01519 L
.10025 .01574 L
.10054 .01684 L
.10114 .01891 L
.10145 .01972 L
.10161 .02007 L
.10178 .02037 L
.10193 .02058 L
.10201 .02067 L
.10209 .02074 L
.10224 .02083 L
.10238 .02085 L
.10253 .02082 L
.10268 .02073 L
.10283 .02058 L
.10297 .0204 L
.10323 .01992 L
.10351 .01924 L
.10419 .01697 L
.10436 .01634 L
.10453 .01566 L
.10467 .01507 L
.10476 .01473 L
.10484 .01502 L
.10541 .01728 L
.10574 .01841 L
.10604 .01931 L
.10633 .02002 L
.10648 .0203 L
.10664 .02055 L
.10673 .02065 L
.10681 .02073 L
.10696 .02084 L
.10704 .02087 L
.10713 .02088 L
.10722 .02088 L
.1073 .02085 L
.10746 .02075 L
.10761 .0206 L
.10774 .02042 L
.10788 .02017 L
.1082 .01944 L
.1085 .01858 L
Mistroke
.10906 .01657 L
.1092 .01601 L
.10934 .01548 L
.10946 .01499 L
.10959 .01498 L
.10973 .01553 L
.10985 .01605 L
.11014 .01715 L
.11045 .01827 L
.11074 .01917 L
.11101 .01985 L
.1113 .02042 L
.11145 .02064 L
.11159 .02078 L
.11174 .02088 L
.11182 .02091 L
.1119 .02092 L
.11204 .0209 L
.11217 .02083 L
.11231 .0207 L
.11246 .02051 L
.11271 .02007 L
.11299 .0194 L
.11361 .0174 L
.11395 .01609 L
.11412 .01541 L
.11427 .01477 L
.11442 .01526 L
.11457 .01589 L
.1149 .01717 L
.11547 .01912 L
.11579 .01993 L
.11596 .02029 L
.11612 .02055 L
.11626 .02073 L
.11641 .02086 L
.11649 .02091 L
.11657 .02094 L
.11672 .02095 L
.11679 .02094 L
.11688 .0209 L
.11697 .02084 L
.11705 .02076 L
.1172 .02058 L
.11736 .02032 L
.11773 .0195 L
.11806 .01851 L
.11836 .01746 L
.11868 .01624 L
.11883 .01561 L
Mistroke
.11897 .01502 L
.11911 .01495 L
.11925 .01554 L
.11984 .01786 L
.12016 .01891 L
.12049 .01983 L
.12065 .02019 L
.1208 .02047 L
.12095 .02068 L
.12109 .02083 L
.12121 .02093 L
.12135 .02099 L
.12149 .02099 L
.12164 .02094 L
.12172 .02089 L
.1218 .02081 L
.12195 .02063 L
.12211 .02038 L
.12229 .02002 L
.1229 .01828 L
.12322 .01709 L
.12353 .01587 L
.1237 .01516 L
.1238 .01476 L
.12389 .01504 L
.12421 .01636 L
.1248 .01855 L
.12513 .01954 L
.12529 .01994 L
.12544 .02026 L
.12559 .02054 L
.12573 .02074 L
.12588 .02091 L
.12596 .02097 L
.12604 .02101 L
.12618 .02104 L
.12631 .02102 L
.12645 .02095 L
.1266 .02081 L
.12673 .02065 L
.12687 .02042 L
.12712 .01989 L
.12769 .01818 L
.12801 .01699 L
.12818 .01632 L
.12836 .01558 L
.12852 .01493 L
.12861 .01487 L
.12869 .01522 L
.129 .01647 L
Mistroke
.12961 .01874 L
.12989 .01957 L
.13018 .02027 L
.13034 .02056 L
.13048 .02077 L
.13061 .02092 L
.13075 .02103 L
.13091 .02108 L
.13099 .02108 L
.13107 .02107 L
.13123 .02098 L
.13137 .02085 L
.13145 .02075 L
.13153 .02063 L
.13168 .02036 L
.13197 .01971 L
.13262 .01762 L
.13291 .01649 L
.13318 .01536 L
.13333 .01473 L
.13341 .01506 L
.13349 .01539 L
.13378 .01656 L
.13434 .01866 L
.13458 .01942 L
.13485 .02011 L
.135 .02043 L
.13514 .02068 L
.13528 .02086 L
.13542 .02101 L
.13557 .0211 L
.13571 .02113 L
.13586 .0211 L
.13595 .02106 L
.13603 .021 L
.13617 .02085 L
.1363 .02067 L
.13659 .0201 L
.13685 .01942 L
.13713 .01855 L
.13745 .01737 L
.1378 .01596 L
.13796 .01529 L
.13804 .01494 L
.13813 .01486 L
.13829 .01553 L
.13843 .01615 L
.13905 .01852 L
.13932 .01939 L
.13962 .02017 L
Mistroke
.13976 .02047 L
.13991 .02074 L
.14 .02086 L
.14007 .02095 L
.14022 .02109 L
.14038 .02117 L
.14046 .02118 L
.14054 .02118 L
.14063 .02115 L
.14071 .02111 L
.1408 .02104 L
.14088 .02096 L
.14102 .02077 L
.14118 .02051 L
.14145 .0199 L
.14175 .01904 L
.14207 .01792 L
.14236 .01681 L
.14263 .01568 L
.14278 .01504 L
.14287 .01475 L
.14294 .01509 L
.14323 .0163 L
.14379 .01848 L
.14404 .01929 L
.14431 .02005 L
.14461 .02068 L
.14477 .02093 L
.14492 .02109 L
.14501 .02116 L
.14509 .0212 L
.14524 .02124 L
.14533 .02123 L
.14541 .0212 L
.1455 .02115 L
.14559 .02107 L
.14573 .0209 L
.14588 .02066 L
.14616 .02008 L
.14649 .01915 L
.14679 .01812 L
.14731 .01603 L
.14746 .01542 L
.14761 .01476 L
.14775 .01529 L
.14788 .01585 L
.14843 .01807 L
.14874 .01915 L
.14903 .01999 L
.14932 .02063 L
Mistroke
.14948 .0209 L
.14962 .02108 L
.14977 .02122 L
.14986 .02126 L
.14994 .02129 L
.15009 .02128 L
.15024 .02121 L
.15037 .0211 L
.15051 .02093 L
.15065 .02071 L
.15077 .02047 L
.15105 .01978 L
.15135 .01886 L
.15193 .01665 L
.1521 .01595 L
.15225 .01527 L
.1524 .01478 L
.15255 .01545 L
.15323 .01822 L
.15353 .01928 L
.15386 .0202 L
.15402 .02056 L
.15417 .02084 L
.1543 .02104 L
.15445 .02121 L
.15459 .02131 L
.15473 .02135 L
.15487 .02134 L
.155 .02127 L
.15508 .02121 L
.15516 .02113 L
.15531 .02093 L
.15547 .02065 L
.15565 .02027 L
.15625 .0184 L
.15658 .01714 L
.15689 .01584 L
.15706 .01509 L
.15715 .01476 L
.15724 .01515 L
.15757 .01655 L
.15815 .01885 L
.15846 .01983 L
.15863 .02028 L
.15879 .02064 L
.15894 .02092 L
.15908 .02112 L
.15923 .02129 L
.15932 .02135 L
.1594 .02139 L
Mistroke
.15953 .02142 L
.15966 .02139 L
.1598 .02131 L
.15995 .02116 L
.16008 .02098 L
.16022 .02073 L
.16047 .02016 L
.16104 .01834 L
.16136 .01708 L
.16153 .01637 L
.16171 .01559 L
.1618 .0152 L
.16188 .01483 L
.16204 .01529 L
.16218 .01594 L
.16234 .01662 L
.16295 .01902 L
.16325 .01996 L
.16353 .02064 L
.16366 .02091 L
.16381 .02115 L
.16395 .02131 L
.16408 .02142 L
.16422 .02147 L
.16437 .02147 L
.16453 .0214 L
.16468 .02127 L
.16483 .02106 L
.16499 .02077 L
.16528 .02008 L
.16559 .01913 L
.16594 .01787 L
.16626 .0165 L
.16642 .0158 L
.16657 .01514 L
.16666 .01476 L
.16674 .01506 L
.16693 .01589 L
.16725 .01729 L
.16758 .01858 L
.16789 .01965 L
.1682 .02049 L
.16833 .02079 L
.16848 .02107 L
.16861 .02127 L
.16874 .02141 L
.16888 .02151 L
.16902 .02155 L
.16918 .02153 L
.16933 .02143 L
Mistroke
.16947 .02129 L
.16962 .02108 L
.16978 .02078 L
.16993 .02045 L
.17025 .01952 L
.17084 .0173 L
.17111 .01616 L
.17125 .01551 L
.17139 .0149 L
.17153 .0152 L
.17161 .01555 L
.1717 .01592 L
.17198 .01716 L
.1725 .01919 L
.17278 .02009 L
.17305 .02077 L
.17321 .02109 L
.1733 .02123 L
.17339 .02135 L
.17354 .02151 L
.17369 .0216 L
.17383 .02163 L
.17397 .02159 L
.17411 .02149 L
.17427 .02131 L
.17444 .02104 L
.17463 .02065 L
.17497 .01971 L
.1756 .01733 L
.17592 .01595 L
.17607 .01525 L
.17622 .01483 L
.17636 .01551 L
.17652 .01623 L
.17686 .01771 L
.17743 .0198 L
.17772 .02061 L
.17788 .02098 L
.17803 .02125 L
.17818 .02146 L
.17833 .02161 L
.17849 .02169 L
.17858 .0217 L
.17867 .02169 L
.17882 .02162 L
.17896 .02149 L
.17903 .02139 L
.17912 .02127 L
.17927 .02099 L
.17955 .02031 L
Mistroke
.17985 .01936 L
.1804 .01724 L
.18072 .01577 L
.18081 .01536 L
.18091 .01492 L
.18099 .01489 L
.18108 .0153 L
.18172 .01814 L
.18202 .01929 L
.18234 .02032 L
.1825 .02073 L
.18265 .02106 L
.18279 .02133 L
.18292 .02152 L
.18306 .02167 L
.18321 .02176 L
.18335 .02179 L
.18348 .02176 L
.18363 .02166 L
.18377 .0215 L
.18393 .02126 L
.18409 .02093 L
.18443 .02004 L
.18474 .01896 L
.18503 .01782 L
.18533 .01649 L
.18546 .01591 L
.1856 .01527 L
.18575 .01487 L
.18589 .01552 L
.1864 .01782 L
.18671 .01907 L
.187 .02008 L
.18727 .02082 L
.18742 .02116 L
.18755 .02141 L
.18769 .02161 L
.18784 .02176 L
.18798 .02185 L
.18814 .02187 L
.18828 .02183 L
.18842 .02171 L
.18856 .02155 L
.18869 .02134 L
.189 .02066 L
.18933 .01964 L
.18994 .01721 L
.1901 .01649 L
.19027 .0157 L
.19035 .01531 L
Mistroke
.19043 .01493 L
.19058 .0152 L
.19073 .01593 L
.1909 .01671 L
.19126 .01827 L
.19156 .01946 L
.19189 .02051 L
.19204 .02093 L
.19219 .02127 L
.19234 .02154 L
.19247 .02172 L
.19261 .02187 L
.19276 .02195 L
.1929 .02196 L
.19303 .02192 L
.19319 .0218 L
.19333 .02162 L
.19349 .02136 L
.19365 .021 L
.19396 .02015 L
.19424 .01915 L
.19456 .01786 L
.1949 .01634 L
.19503 .01573 L
.19516 .01507 L
.19532 .01509 L
.19546 .01577 L
.19597 .01811 L
.19628 .01937 L
.19658 .02037 L
.19684 .0211 L
.19699 .02142 L
.19713 .02167 L
.19727 .02186 L
.19741 .02199 L
.19756 .02205 L
.19764 .02206 L
.19772 .02205 L
.19784 .02198 L
.19799 .02185 L
.19813 .02165 L
.19827 .02141 L
.19859 .02063 L
.19887 .0197 L
.19921 .01838 L
.19953 .01698 L
.19981 .01563 L
.19989 .01523 L
.19997 .01485 L
.20012 .01529 L
Mistroke
.2002 .01567 L
.20028 .01607 L
.20043 .01677 L
.20076 .01829 L
.20106 .0195 L
.20138 .02059 L
.20157 .0211 L
.20174 .02149 L
.20191 .02179 L
.20199 .02191 L
.20207 .022 L
.20222 .02211 L
.2023 .02215 L
.20238 .02216 L
.20252 .02213 L
.20267 .02203 L
.20281 .02187 L
.20296 .02164 L
.20322 .02106 L
.20355 .02006 L
.20387 .01888 L
.20415 .01764 L
.20446 .01622 L
.20458 .0156 L
.20472 .01493 L
.20487 .01524 L
.20501 .01593 L
.20552 .01831 L
.20581 .01952 L
.20612 .0206 L
.20638 .02133 L
.20653 .02164 L
.20667 .0219 L
.20683 .02211 L
.20698 .02222 L
.20714 .02227 L
.20723 .02226 L
.20731 .02223 L
.20746 .02211 L
.2076 .02194 L
.20776 .02166 L
.20791 .02133 L
.20819 .02055 L
.20845 .01964 L
.20904 .0171 L
.2092 .01633 L
.20937 .01548 L
.20945 .01509 L
.20953 .01476 L
.20968 .01551 L
Mistroke
.21026 .01829 L
.21056 .01955 L
.21089 .02069 L
.21107 .02123 L
.21124 .02164 L
.21141 .02196 L
.21149 .02209 L
.21157 .02219 L
.2117 .02231 L
.21185 .02238 L
.21199 .02237 L
.21212 .02231 L
.21227 .02217 L
.21242 .02196 L
.21257 .02167 L
.21273 .02128 L
.21307 .02025 L
.21338 .01903 L
.21367 .01776 L
.21397 .01629 L
.2141 .01565 L
.21424 .01496 L
.21439 .01524 L
.21453 .01595 L
.21504 .01842 L
.21535 .01973 L
.21565 .02078 L
.21591 .02153 L
.21606 .02187 L
.2162 .02212 L
.21633 .02231 L
.21648 .02244 L
.21662 .0225 L
.21678 .02248 L
.21692 .0224 L
.21706 .02225 L
.2172 .02203 L
.21733 .02179 L
.21764 .02098 L
.21797 .01981 L
.21858 .0171 L
.21888 .01556 L
.21897 .01513 L
.21906 .01477 L
.21914 .0152 L
.21922 .0156 L
.2199 .0189 L
.2202 .02013 L
.22052 .02123 L
.22067 .02164 L
Mistroke
.22083 .022 L
.22098 .02227 L
.22111 .02245 L
.22126 .02258 L
.22139 .02263 L
.22154 .02261 L
.2217 .02251 L
.22178 .02243 L
.22187 .02231 L
.22203 .02204 L
.22232 .02131 L
.2226 .02039 L
.2229 .0192 L
.22344 .01666 L
.22358 .01591 L
.22373 .01512 L
.22381 .01473 L
.2239 .01519 L
.22405 .01599 L
.22463 .01884 L
.22496 .02023 L
.22531 .02143 L
.22548 .02189 L
.22565 .02224 L
.22579 .02248 L
.22595 .02265 L
.2261 .02275 L
.22623 .02276 L
.22639 .0227 L
.22654 .02256 L
.22668 .02237 L
.2268 .02213 L
.22709 .0214 L
.22741 .02032 L
.2277 .01911 L
.22804 .01751 L
.22819 .01675 L
.22835 .0159 L
.22851 .01506 L
.22865 .01516 L
.22881 .01599 L
.22898 .01687 L
.22933 .01861 L
.22966 .02007 L
.22997 .02121 L
.23013 .0217 L
.2303 .02214 L
.23045 .02244 L
.23052 .02257 L
.23061 .02268 L
Mistroke
.23075 .02283 L
.23089 .0229 L
.23097 .02291 L
.23105 .02289 L
.23119 .02281 L
.23135 .02264 L
.23144 .0225 L
.23152 .02236 L
.2318 .02167 L
.23211 .02067 L
.23279 .01759 L
.23297 .0167 L
.23313 .01582 L
.23328 .01503 L
.23336 .01486 L
.23344 .01527 L
.23399 .01821 L
.23459 .02084 L
.23488 .02181 L
.23505 .02225 L
.23521 .02258 L
.23537 .02283 L
.23545 .02292 L
.23554 .023 L
.23569 .02306 L
.23578 .02305 L
.23586 .02302 L
.23601 .02291 L
.23609 .02281 L
.23618 .02269 L
.23633 .0224 L
.23647 .02207 L
.23679 .02108 L
.23713 .01971 L
.23742 .01832 L
.23774 .01666 L
.23789 .01586 L
.23805 .01499 L
.23819 .01525 L
.23833 .01599 L
.23893 .01913 L
.23923 .02045 L
.2395 .02148 L
.23975 .02223 L
.23988 .02254 L
.24001 .0228 L
.24015 .02301 L
.24028 .02314 L
.24043 .02321 L
.24057 .0232 L
Mistroke
.24071 .02312 L
.24084 .02298 L
.24099 .02275 L
.24115 .02241 L
.24147 .02148 L
.24177 .02035 L
.24234 .01758 L
.24262 .01605 L
.24274 .01537 L
.24287 .01481 L
.24302 .01563 L
.24316 .0164 L
.24346 .01803 L
.24409 .021 L
.24442 .02213 L
.24458 .02257 L
.24476 .02295 L
.24492 .02318 L
.245 .02327 L
.24508 .02333 L
.24523 .02339 L
.24538 .02335 L
.24552 .02325 L
.24566 .02306 L
.2458 .02281 L
.24593 .02252 L
.24623 .02163 L
.24654 .02041 L
.24685 .01895 L
.24718 .01721 L
.24734 .01631 L
.24749 .01544 L
.24763 .01477 L
.24778 .01563 L
.24829 .01849 L
.24884 .02105 L
.24912 .0221 L
.24928 .02255 L
.24944 .02295 L
.24959 .02323 L
.24973 .02341 L
.24987 .02353 L
.25 .02357 L
.25015 .02353 L
.25023 .02347 L
.25031 .02339 L
.25045 .02319 L
.2506 .02289 L
.25087 .02219 L
.25115 .02115 L
Mistroke
.25179 .01809 L
.2521 .01637 L
.25225 .01549 L
.25239 .01476 L
.25252 .01552 L
.25266 .01633 L
.25295 .01799 L
.25346 .02058 L
.25372 .02168 L
.254 .02262 L
.25417 .02305 L
.25431 .02335 L
.25446 .02356 L
.25461 .02371 L
.25476 .02376 L
.25484 .02375 L
.25492 .02372 L
.25506 .0236 L
.25521 .02339 L
.25534 .02312 L
.25547 .02281 L
.25576 .02191 L
.25635 .01926 L
.25666 .01759 L
.25682 .01666 L
.25699 .01564 L
.25707 .01514 L
.25715 .01476 L
.2573 .01564 L
.25758 .01734 L
.25815 .02036 L
.25839 .02148 L
.25865 .02245 L
.25879 .02288 L
.25894 .02327 L
.25908 .02355 L
.2592 .02375 L
.25936 .0239 L
.25943 .02394 L
.25952 .02396 L
.25967 .02393 L
.25981 .02381 L
.2599 .0237 L
.25998 .02358 L
.26013 .02327 L
.26029 .02284 L
.26047 .02226 L
.26109 .01949 L
.26139 .01785 L
.26167 .01619 L
Mistroke
.2618 .01537 L
.26194 .01492 L
.26209 .01587 L
.26223 .01673 L
.26275 .01968 L
.2633 .02222 L
.26345 .02275 L
.26361 .02324 L
.26376 .02361 L
.26391 .02387 L
.26405 .02406 L
.26413 .02413 L
.26421 .02417 L
.2643 .02419 L
.26438 .02417 L
.26454 .02406 L
.26469 .02387 L
.26482 .02362 L
.26497 .02326 L
.26513 .02278 L
.26549 .02139 L
.26583 .01972 L
.26614 .01798 L
.26631 .01696 L
.26647 .01598 L
.2666 .01511 L
.26675 .01526 L
.26684 .0158 L
.26692 .01631 L
.26707 .01725 L
.26763 .02043 L
.26792 .02182 L
.26823 .02302 L
.26841 .02355 L
.26857 .02393 L
.26865 .02407 L
.26874 .0242 L
.26889 .02436 L
.26904 .02442 L
.26918 .02439 L
.26934 .02426 L
.26949 .02404 L
.26962 .02375 L
.26975 .02342 L
.27004 .02245 L
.27033 .02119 L
.27065 .01952 L
.27099 .01751 L
.27114 .01659 L
.27122 .01609 L
Mistroke
.2713 .01555 L
.27146 .01491 L
.27161 .01587 L
.27193 .01792 L
.27228 .01998 L
.27261 .02167 L
.27292 .02297 L
.27308 .02352 L
.27326 .02399 L
.2734 .02429 L
.27356 .02453 L
.27371 .02464 L
.27384 .02467 L
.27399 .02461 L
.27407 .02454 L
.27415 .02444 L
.2743 .02418 L
.27444 .02385 L
.27476 .02283 L
.2751 .02133 L
.27568 .01804 L
.27583 .01707 L
.276 .016 L
.27615 .01498 L
.27629 .01539 L
.27643 .0163 L
.27658 .01727 L
.27685 .01897 L
.27714 .02069 L
.27746 .02226 L
.27772 .02334 L
.27786 .02381 L
.27801 .02423 L
.27815 .02453 L
.27828 .02474 L
.27841 .02487 L
.27853 .02494 L
.27868 .02493 L
.27876 .02487 L
.27884 .0248 L
.27898 .02459 L
.27913 .02428 L
.2794 .02351 L
.27968 .02236 L
.28032 .01889 L
.28063 .01691 L
.28078 .0159 L
.28092 .01495 L
.28105 .01537 L
.28119 .01631 L
Mistroke
.28148 .01825 L
.28199 .0213 L
.28225 .02261 L
.28253 .02376 L
.2827 .02428 L
.28284 .02466 L
.28299 .02494 L
.28314 .02513 L
.28328 .02523 L
.28337 .02524 L
.28345 .02522 L
.28359 .02511 L
.28374 .02489 L
.28387 .02461 L
.284 .02428 L
.28429 .02327 L
.2846 .02184 L
.28488 .02027 L
.28521 .01819 L
.28537 .01711 L
.28552 .0161 L
.28565 .01515 L
.28578 .01518 L
.28591 .01612 L
.28606 .01714 L
.28665 .02095 L
.28693 .02243 L
.28722 .02373 L
.28746 .02458 L
.2876 .02495 L
.28773 .02522 L
.28788 .02543 L
.28796 .0255 L
.28805 .02554 L
.2882 .02554 L
.28834 .02543 L
.28842 .02533 L
.2885 .02519 L
.28865 .02486 L
.28882 .02439 L
.289 .02375 L
.28962 .0206 L
.28991 .0187 L
.29019 .01676 L
.29032 .01581 L
.29046 .0148 L
.29062 .01575 L
.29076 .01677 L
.29128 .02028 L
.29183 .02335 L
Mistroke
.29198 .02401 L
.29214 .02462 L
.29229 .02508 L
.29243 .02543 L
.29258 .02569 L
.29266 .02578 L
.29274 .02585 L
.29282 .02589 L
.29291 .02589 L
.29307 .0258 L
.29321 .02562 L
.29335 .02535 L
.2935 .02496 L
.29366 .02443 L
.29402 .02285 L
.29436 .02093 L
.29466 .0189 L
.29499 .01656 L
.29513 .01553 L
.29528 .01502 L
.29536 .01566 L
.29544 .01624 L
.2956 .01738 L
.29615 .02121 L
.29646 .023 L
.29663 .02382 L
.2968 .02457 L
.29697 .02517 L
.29712 .02561 L
.29727 .02594 L
.29742 .02615 L
.29756 .02626 L
.29771 .02626 L
.29785 .02616 L
.29798 .02597 L
.29813 .02566 L
.2983 .02519 L
.2986 .02402 L
.29891 .0224 L
.29924 .02032 L
.29953 .01829 L
.29968 .01716 L
.29984 .01595 L
.29998 .0149 L
.30013 .01569 L
.30026 .01673 L
.30039 .01769 L
.3009 .02133 L
.30119 .0231 L
.30147 .02449 L
Mistroke
.30162 .02513 L
.30178 .0257 L
.30193 .02612 L
.30207 .0264 L
.30222 .0266 L
.30236 .02668 L
.30249 .02665 L
.30263 .02653 L
.30279 .02629 L
.30287 .0261 L
.30295 .0259 L
.30324 .02487 L
.30351 .02358 L
.3038 .02186 L
.30433 .0181 L
.30448 .01697 L
.30464 .01573 L
.30473 .01501 L
.30481 .01507 L
.30497 .01635 L
.30563 .02137 L
.30593 .02325 L
.30624 .02494 L
.30639 .02556 L
.30655 .02612 L
.30668 .0265 L
.30682 .02682 L
.30698 .02704 L
.30712 .02712 L
.30728 .02709 L
.30737 .02701 L
.30745 .0269 L
.3076 .02661 L
.30776 .02617 L
.30805 .02506 L
.30833 .0236 L
.30863 .02171 L
.30916 .01768 L
.30932 .01642 L
.30946 .01522 L
.30954 .01489 L
.30963 .01562 L
.30978 .01689 L
.31036 .02142 L
.3107 .02364 L
.31105 .02553 L
.31119 .02615 L
.31135 .0267 L
.31144 .02696 L
.31152 .02716 L
Mistroke
.3116 .02732 L
.31168 .02745 L
.31184 .02759 L
.31198 .02761 L
.31212 .02751 L
.31225 .02731 L
.31239 .027 L
.31255 .02653 L
.31286 .0252 L
.31314 .02367 L
.31343 .02169 L
.31396 .01748 L
.31412 .01616 L
.3142 .01543 L
.31428 .01473 L
.31438 .01552 L
.31446 .01627 L
.31463 .01771 L
.31527 .02273 L
.31555 .02456 L
.31584 .02613 L
.31599 .02679 L
.31616 .02737 L
.31632 .02776 L
.31646 .02801 L
.31661 .02814 L
.31669 .02816 L
.31677 .02814 L
.31692 .02799 L
.31707 .02774 L
.31715 .02755 L
.31723 .0273 L
.31738 .02676 L
.31772 .02512 L
.31829 .02122 L
.31862 .01851 L
.31876 .01726 L
.31892 .01588 L
.31907 .01491 L
.31921 .01617 L
.31948 .0186 L
.32008 .02344 L
.32035 .02525 L
.3206 .02664 L
.32087 .02774 L
.32101 .02817 L
.32116 .0285 L
.3213 .0287 L
.32139 .02875 L
.32147 .02876 L
Mistroke
.32162 .02867 L
.32171 .02855 L
.32179 .0284 L
.32193 .02806 L
.32208 .02756 L
.32238 .02617 L
.32272 .02411 L
.32307 .02138 L
.32341 .01847 L
.32355 .01712 L
.32364 .01634 L
.32372 .0156 L
.32387 .01527 L
.32395 .01601 L
.32403 .0168 L
.32437 .01993 L
.32469 .02264 L
.32499 .02491 L
.32527 .02672 L
.32543 .02751 L
.32559 .02821 L
.32574 .02873 L
.32588 .02908 L
.32601 .02931 L
.32614 .02942 L
.32628 .02942 L
.32643 .02929 L
.32657 .02902 L
.3267 .02868 L
.32686 .02814 L
.32702 .02739 L
.32732 .02566 L
.32797 .02054 L
.32827 .01764 L
.32843 .01616 L
.32856 .01479 L
.32868 .01584 L
.32881 .0171 L
.32908 .01969 L
.32964 .02465 L
.32991 .02654 L
.33019 .02818 L
.33036 .02892 L
.3305 .02945 L
.33065 .02985 L
.33079 .03009 L
.33093 .03019 L
.33108 .03016 L
.33122 .03 L
.33135 .02973 L
Mistroke
.3315 .02928 L
.33167 .02862 L
.33197 .027 L
.33228 .02479 L
.33261 .02196 L
.33292 .01896 L
.33321 .01603 L
.33335 .01487 L
.3335 .01643 L
.33381 .01966 L
.33438 .02493 L
.33462 .02682 L
.33488 .02851 L
.33503 .02931 L
.33517 .02991 L
.3353 .03039 L
.33543 .03073 L
.33557 .03096 L
.33572 .03106 L
.33586 .03101 L
.33599 .03085 L
.33614 .0305 L
.33622 .03024 L
.3363 .02995 L
.3366 .02849 L
.33692 .02635 L
.3372 .02397 L
.33753 .02076 L
.33784 .01752 L
.33798 .01601 L
.33811 .01485 L
.33824 .01635 L
.33839 .01798 L
.33899 .02414 L
.33951 .02845 L
.33966 .02942 L
.3398 .03021 L
.33994 .03085 L
.34006 .03132 L
.3402 .03171 L
.34035 .03196 L
.34048 .03205 L
.34062 .03201 L
.34077 .03179 L
.34091 .03144 L
.34106 .03089 L
.34123 .03011 L
.34156 .02799 L
.34187 .02537 L
.34216 .02257 L
Mistroke
.34246 .01929 L
.34273 .01624 L
.34288 .01495 L
.34302 .01661 L
.34353 .02245 L
.34382 .02546 L
.34413 .02825 L
.34441 .03035 L
.34468 .03184 L
.34484 .03245 L
.34492 .03271 L
.345 .0329 L
.34514 .03313 L
.34528 .0332 L
.34536 .03316 L
.34545 .03307 L
.3456 .03277 L
.34569 .0325 L
.34578 .03218 L
.34594 .03142 L
.34623 .02955 L
.34651 .02729 L
.34713 .02074 L
.34738 .01774 L
.34751 .01611 L
.34764 .01504 L
.3478 .01697 L
.34794 .01873 L
.34821 .02209 L
.3485 .02533 L
.34881 .02844 L
.34908 .03074 L
.34936 .03264 L
.34951 .03338 L
.34959 .0337 L
.34968 .03399 L
.34983 .03435 L
.34997 .03452 L
.35012 .03451 L
.35026 .03433 L
.35038 .03402 L
.35052 .03354 L
.35066 .03284 L
.35083 .03187 L
.35116 .0293 L
.35175 .02297 L
.35202 .0196 L
.35216 .01767 L
.3523 .01584 L
.35245 .01559 L
Mistroke
.35252 .01665 L
.35261 .01778 L
.35289 .02156 L
.35341 .02787 L
.3537 .03076 L
.35396 .03298 L
.35412 .03404 L
.35427 .03483 L
.35443 .03549 L
.35452 .03576 L
.35461 .03595 L
.35475 .03611 L
.35489 .03609 L
.35504 .03587 L
.3552 .0354 L
.35529 .03503 L
.35537 .03462 L
.35556 .03349 L
.3559 .03069 L
.35653 .02334 L
.35681 .01961 L
.35696 .01746 L
.3571 .01539 L
.35718 .01522 L
.35726 .0165 L
.35742 .01874 L
.35772 .02303 L
.35802 .02718 L
.35836 .03112 L
.35865 .03397 L
.35881 .03524 L
.35896 .03623 L
.3591 .03695 L
.35925 .03752 L
.35933 .03776 L
.35941 .03791 L
.35955 .03804 L
.35969 .03797 L
.35981 .03773 L
.35995 .0373 L
.3601 .03663 L
.36025 .03573 L
.3604 .03454 L
.36069 .03182 L
.36135 .02339 L
.36167 .01842 L
.36176 .01701 L
.36186 .01549 L
.36195 .01538 L
.36203 .01669 L
Mistroke
.36267 .02675 L
.36297 .03088 L
.3633 .03468 L
.36344 .03615 L
.3636 .03748 L
.36375 .03851 L
.36388 .03927 L
.36403 .03989 L
.36411 .04012 L
.36419 .04029 L
.36433 .04041 L
.36448 .04029 L
.36462 .03996 L
.36476 .03938 L
.3649 .03862 L
.36503 .03775 L
.36531 .03517 L
.36563 .03148 L
.36596 .02676 L
.36625 .02191 L
.36639 .01956 L
.36654 .01696 L
.36668 .01497 L
.36681 .01728 L
.3674 .02756 L
.36769 .03202 L
.36796 .03573 L
.36822 .03875 L
.36847 .04093 L
.3686 .04183 L
.36874 .04257 L
.36888 .04308 L
.36903 .04336 L
.36918 .04336 L
.36927 .04323 L
.36935 .04303 L
.36949 .04247 L
.36964 .04161 L
.36977 .04064 L
.36991 .03938 L
.37016 .03657 L
.37074 .02793 L
.37106 .02204 L
.37123 .01875 L
.37132 .01691 L
.37141 .01517 L
.37156 .01742 L
.37174 .02089 L
.37204 .02687 L
.37234 .03234 L
Mistroke
.37266 .03751 L
.37295 .04149 L
.37323 .04438 L
.37338 .04556 L
.37346 .04606 L
.37354 .0465 L
.37369 .04704 L
.37383 .04727 L
.3739 .04729 L
.37399 .0472 L
.37414 .04681 L
.37423 .04641 L
.37432 .04592 L
.37448 .04472 L
.37478 .04162 L
.37505 .03779 L
.37567 .0263 L
.37592 .02092 L
.37605 .01798 L
.37619 .01484 L
.37634 .01814 L
.37648 .02138 L
.37675 .02764 L
.37735 .03978 L
.37764 .04461 L
.3779 .04817 L
.37804 .04963 L
.37819 .05091 L
.37835 .05184 L
.37843 .0522 L
.37851 .05243 L
.37865 .0526 L
.37877 .05248 L
.37892 .05201 L
.37906 .05124 L
.37921 .05007 L
.37936 .04843 L
.37965 .04455 L
.37998 .03847 L
.38029 .03181 L
.38055 .02526 L
.3807 .02147 L
.38084 .01785 L
.38098 .01558 L
.38106 .01771 L
.38115 .02 L
.38143 .02772 L
.38195 .04097 L
.38224 .04723 L
.3825 .05218 L
Mistroke
.38281 .05652 L
.38297 .05818 L
.38306 .05891 L
.38314 .05944 L
.38329 .06005 L
.38345 .06026 L
.3836 .05999 L
.38373 .05935 L
.38382 .05878 L
.38391 .058 L
.38407 .05617 L
.38438 .05138 L
.38474 .0437 L
.38507 .03493 L
.38534 .02678 L
.38549 .02202 L
.38563 .01737 L
.38571 .01472 L
.3858 .01764 L
.38595 .02279 L
.38625 .03281 L
.3869 .05253 L
.38721 .06036 L
.3875 .06603 L
.38764 .06814 L
.38777 .06974 L
.3879 .07101 L
.38805 .07192 L
.38819 .07231 L
.38833 .07218 L
.38849 .07146 L
.38863 .07021 L
.38878 .06835 L
.38895 .06576 L
.38923 .05955 L
.38954 .0508 L
.38988 .03903 L
.39021 .0262 L
.39037 .01945 L
.39051 .01641 L
.3906 .02003 L
.39068 .02392 L
.39087 .03217 L
.39119 .04642 L
.39179 .07006 L
.39211 .08039 L
.39242 .08771 L
.39257 .09037 L
.39264 .09147 L
.39273 .09246 L
Mistroke
.39282 .09329 L
.3929 .09383 L
.39299 .09411 L
.39307 .09415 L
.3932 .09372 L
.39335 .09247 L
.39351 .09029 L
.39366 .08744 L
.39382 .08337 L
.394 .07808 L
.39431 .06616 L
.39464 .0499 L
.39483 .03972 L
.395 .02942 L
.39516 .02001 L
.39524 .01488 L
.39532 .01999 L
.39561 .0391 L
.39617 .07665 L
.39744 .13958 L
.39758 .14283 L
.39773 .14519 L
.39781 .14594 L
.39789 .14639 L
.39805 .14614 L
.39819 .14466 L
.39834 .14167 L
.39849 .13748 L
.39862 .13244 L
.39895 .11546 L
.39929 .09023 L
.39958 .06267 L
.39974 .04532 L
.3999 .02754 L
.40004 .01965 L
.40019 .04009 L
.40046 .07849 L
.40099 .16138 L
.40219 .36353 L
.40279 .45473 L
.40335 .52493 L
.40363 .55281 L
.40393 .5764 L
.4041 .58665 L
.40427 .59417 L
.40441 .59903 L
.4045 .60099 L
.40457 .60227 L
.40471 .60332 L
.40486 .60262 L
Mistroke
.405 .60022 L
.40513 .59654 L
.40525 .592 L
.40538 .58571 L
.40564 .56901 L
.40592 .545 L
.40622 .5131 L
.40677 .44187 L
.408 .24456 L
.40864 .13859 L
.409 .08491 L
.40917 .06034 L
.40933 .03897 L
.40947 .02111 L
.40962 .02603 L
.40977 .04263 L
.40993 .05936 L
.41025 .08776 L
.41043 .10071 L
.41059 .11116 L
.41074 .11923 L
.41091 .12635 L
.41106 .13137 L
.4112 .1348 L
.41133 .13701 L
.41147 .13831 L
.41162 .13846 L
.41176 .13752 L
.41191 .1354 L
.41199 .13374 L
.41207 .13196 L
.41236 .12297 L
.4127 .10858 L
.41301 .09208 L
.41363 .05485 L
.41391 .03781 L
.41405 .02888 L
.41421 .0195 L
.41435 .01831 L
.41448 .0257 L
.41473 .03929 L
.41528 .06391 L
.41557 .07334 L
.41572 .07729 L
.41588 .0807 L
.41602 .08299 L
.41617 .08479 L
.41631 .08576 L
.41644 .08611 L
.41659 .08585 L
Mistroke
.41667 .0854 L
.41675 .08482 L
.4169 .08321 L
.41704 .08113 L
.41735 .07466 L
.41769 .06525 L
.41827 .04507 L
.41859 .03281 L
.41874 .02672 L
.41888 .02119 L
.41902 .01585 L
.41915 .01855 L
.41929 .02366 L
.41944 .02902 L
.41973 .03881 L
.42004 .04779 L
.42031 .05398 L
.42045 .05672 L
.4206 .0592 L
.42074 .06105 L
.42087 .06237 L
.42099 .06331 L
.42111 .06394 L
.42126 .06423 L
.42135 .06418 L
.42142 .064 L
.42157 .06334 L
.42172 .0622 L
.42185 .0608 L
.42198 .05919 L
.42226 .0545 L
.42286 .0412 L
.42316 .03306 L
.42349 .0237 L
.42364 .01945 L
.4238 .01496 L
.42395 .01864 L
.42409 .02232 L
.42465 .03607 L
.42491 .04129 L
.42519 .04588 L
.42532 .04759 L
.42546 .04911 L
.42559 .05025 L
.42571 .05107 L
.42585 .05177 L
.42593 .05199 L
.42602 .05212 L
.42615 .05209 L
.42631 .05169 L
Mistroke
.42644 .05103 L
.42659 .05001 L
.42685 .04739 L
.42716 .04313 L
.42749 .03752 L
.42808 .02555 L
.42834 .01973 L
.42849 .01646 L
.42863 .01591 L
.42875 .01862 L
.42889 .02148 L
.42914 .02644 L
.42943 .03174 L
.42974 .03651 L
.43 .03978 L
.43014 .04119 L
.43029 .04242 L
.43045 .0434 L
.43059 .04403 L
.43068 .04427 L
.43076 .04441 L
.43092 .04443 L
.43107 .04415 L
.43121 .04365 L
.43136 .04283 L
.43152 .04168 L
.43179 .03902 L
.43205 .03588 L
.43264 .02693 L
.43297 .02124 L
.43313 .01838 L
.43328 .01573 L
.43341 .01609 L
.43355 .01857 L
.43386 .02359 L
.43448 .03224 L
.43465 .03408 L
.43483 .03577 L
.435 .03706 L
.43516 .03797 L
.43532 .03863 L
.43546 .039 L
.43562 .03913 L
.43571 .0391 L
.43579 .03899 L
.43593 .03866 L
.43608 .03807 L
.43623 .03723 L
.43638 .03624 L
.43671 .03326 L
Mistroke
.43702 .02983 L
.43738 .02516 L
.43771 .02043 L
.43786 .01824 L
.438 .01617 L
.43814 .01541 L
.43822 .01654 L
.4383 .01774 L
.43895 .02628 L
.43925 .02948 L
.43957 .03216 L
.43984 .03381 L
.43999 .03447 L
.44013 .0349 L
.44028 .03516 L
.44036 .03521 L
.44045 .03521 L
.4406 .03504 L
.44074 .0347 L
.44082 .03441 L
.44091 .03408 L
.44106 .03332 L
.4414 .03098 L
.44197 .02543 L
.4423 .02162 L
.4426 .01796 L
.44274 .01622 L
.44289 .01509 L
.44303 .01685 L
.44316 .01843 L
.44376 .025 L
.44403 .02743 L
.44429 .02929 L
.44455 .03077 L
.44469 .03135 L
.44484 .03181 L
.44499 .03209 L
.44507 .03218 L
.44515 .03221 L
.44531 .03214 L
.4454 .03201 L
.44548 .03184 L
.44562 .03145 L
.44577 .03087 L
.44607 .02925 L
.4464 .02682 L
.44676 .02365 L
.4471 .02029 L
.44741 .01701 L
.44756 .01537 L
Mistroke
.44764 .01489 L
.44772 .01579 L
.44806 .01931 L
.44836 .02215 L
.44868 .02482 L
.44899 .02695 L
.44928 .02842 L
.44941 .02894 L
.44956 .02938 L
.4497 .02966 L
.44983 .0298 L
.44997 .02983 L
.45012 .02971 L
.45025 .0295 L
.45039 .02915 L
.45054 .02864 L
.4507 .02795 L
.45099 .02635 L
.45156 .02213 L
.45208 .01751 L
.45224 .01607 L
.45232 .01528 L
.4524 .01489 L
.45254 .01618 L
.45269 .01757 L
.45304 .02054 L
.45336 .02295 L
.45364 .02473 L
.45394 .02626 L
.45411 .0269 L
.45426 .02735 L
.45441 .02766 L
.45456 .02785 L
.45471 .0279 L
.4548 .02788 L
.45488 .02781 L
.45496 .02771 L
.45504 .02757 L
.45521 .02716 L
.45536 .02669 L
.45552 .02605 L
.45581 .0246 L
.4565 .01986 L
.45684 .01722 L
.457 .01589 L
.45715 .01476 L
.45728 .01582 L
.45742 .01693 L
.45771 .01915 L
.45803 .02138 L
Mistroke
.45833 .02315 L
.45862 .02453 L
.45877 .02509 L
.45893 .02559 L
.45902 .02581 L
.4591 .02599 L
.45918 .02612 L
.45927 .02622 L
.45942 .02631 L
.4595 .02631 L
.45958 .02628 L
.46427 .02499 L
.46925 .02375 L
.47404 .0228 L
.47866 .02215 L
.47999 .01904 L
.4803 .01772 L
.48064 .0162 L
.48077 .01555 L
.48092 .01486 L
.48101 .01497 L
.48108 .01533 L
.48123 .01603 L
.48177 .01833 L
.48206 .01937 L
.48236 .02028 L
.48251 .02066 L
.48268 .021 L
.48283 .02125 L
.48298 .02141 L
.48313 .02152 L
.48326 .02156 L
.48342 .02154 L
.48357 .02145 L
.48372 .02129 L
.48386 .02109 L
.48413 .02055 L
.48442 .01977 L
.48474 .01873 L
.48526 .01668 L
.4854 .01608 L
.48555 .01542 L
.4857 .01479 L
.48583 .01521 L
.48645 .01777 L
.48677 .01887 L
.48711 .01987 L
.48727 .02022 L
.48743 .02054 L
.48757 .02075 L
Mistroke
.48772 .02093 L
.48786 .02104 L
.48802 .02109 L
.48816 .02108 L
.48829 .02102 L
.48845 .02089 L
.48859 .02071 L
.48872 .02051 L
.48887 .02023 L
.48948 .01856 L
.49 .01664 L
.49028 .01553 L
.49043 .01489 L
.49058 .01512 L
.49066 .01545 L
.49074 .0158 L
.4909 .01643 L
.49121 .01757 L
.49153 .01865 L
.49187 .01959 L
.49204 .01996 L
.4922 .02025 L
.49234 .02046 L
.4925 .02063 L
.49264 .02073 L
.4928 .02078 L
.49293 .02077 L
.49307 .02071 L
.49323 .02058 L
.49338 .0204 L
.49354 .02015 L
.49371 .01982 L
.4943 .01818 L
.49485 .01625 L
.49499 .01567 L
.49515 .01506 L
.49528 .01489 L
.49543 .01546 L
.49605 .01774 L
.49635 .01869 L
.49663 .01942 L
.49696 .02008 L
.49705 .02022 L
.49714 .02034 L
.49722 .02043 L
.49731 .02051 L
.4974 .02056 L
.49748 .0206 L
.49756 .02062 L
.49765 .02062 L
Mistroke
.49773 .0206 L
.49781 .02057 L
.49795 .02047 L
.49809 .02033 L
.49824 .02013 L
.4985 .01963 L
.49882 .01885 L
.49911 .01797 L
.49971 .01582 L
.49986 .01526 L
.50002 .01478 L
.50011 .01513 L
.50019 .01544 L
.50035 .01606 L
.5009 .018 L
.50118 .01886 L
.50149 .01962 L
.50176 .02012 L
.50191 .02033 L
.50205 .02048 L
.50218 .02057 L
.5023 .02061 L
.50244 .02062 L
.50257 .02058 L
.50272 .02048 L
.5028 .0204 L
.50288 .02031 L
.50317 .01984 L
.50344 .01925 L
.50372 .01847 L
.50403 .01747 L
.50436 .01627 L
.50452 .01565 L
.50467 .01506 L
.50481 .0149 L
.50496 .01548 L
.50547 .01741 L
.50601 .01914 L
.5063 .01983 L
.50645 .02013 L
.50662 .02039 L
.50677 .02058 L
.50691 .02069 L
.50704 .02076 L
.50718 .02078 L
.50732 .02075 L
.50741 .0207 L
.50749 .02064 L
.50763 .0205 L
.50778 .02028 L
Mistroke
.50804 .01979 L
.50833 .01907 L
.50892 .01711 L
.50925 .01584 L
.50932 .01553 L
.50941 .01519 L
.50956 .01485 L
.50971 .01546 L
.50984 .01601 L
.51015 .01724 L
.5107 .01912 L
.51097 .01985 L
.51111 .02017 L
.51125 .02046 L
.51138 .02068 L
.51152 .02086 L
.51165 .02098 L
.51177 .02106 L
.51192 .02109 L
.512 .02109 L
.51209 .02106 L
.51224 .02097 L
.51238 .02082 L
.51254 .02059 L
.51269 .02031 L
.51304 .01947 L
.51362 .0175 L
.51391 .0163 L
.51408 .01561 L
.51423 .01495 L
.51437 .01509 L
.51452 .01574 L
.51479 .01687 L
.5153 .01887 L
.5156 .01984 L
.51591 .02065 L
.51604 .02092 L
.51618 .02115 L
.51633 .02135 L
.51647 .02148 L
.51662 .02155 L
.5167 .02156 L
.51678 .02155 L
.51694 .02148 L
.51703 .02141 L
.51711 .02132 L
.51724 .02113 L
.51739 .02086 L
.5177 .02013 L
.51803 .01907 L
Mistroke
.51839 .01769 L
.51872 .01623 L
.51887 .01556 L
.51895 .01517 L
.51903 .0148 L
.51918 .01535 L
.51934 .0161 L
.51968 .01765 L
.52001 .019 L
.5203 .02008 L
.52057 .0209 L
.52086 .02157 L
.52102 .02184 L
.52116 .02202 L
.52131 .02213 L
.52146 .02218 L
.52161 .02215 L
.52169 .0221 L
.52177 .02203 L
.52185 .02194 L
.52193 .02184 L
.5221 .02154 L
.52241 .02079 L
.5227 .01984 L
.52304 .01848 L
.5234 .01681 L
.52354 .01608 L
.5237 .01527 L
.52379 .0148 L
.52388 .01506 L
.52396 .01547 L
.52404 .01591 L
.52464 .01888 L
.52521 .02113 L
.5255 .02199 L
.52566 .02236 L
.52581 .02262 L
.5259 .02274 L
.52598 .02282 L
.52606 .02289 L
.52615 .02293 L
.52631 .02294 L
.52639 .0229 L
.52647 .02285 L
.52662 .02268 L
.52671 .02255 L
.52679 .02241 L
.52707 .02171 L
.52741 .02056 L
.52773 .0192 L
Mistroke
.5283 .01623 L
.52846 .01535 L
.52854 .0149 L
.52863 .01503 L
.52878 .01591 L
.52892 .01672 L
.52948 .0197 L
.53 .02197 L
.53029 .02289 L
.53046 .02329 L
.53061 .02356 L
.53074 .02373 L
.53088 .02384 L
.53102 .02388 L
.53116 .02383 L
.53131 .02369 L
.53139 .02358 L
.53147 .02345 L
.53176 .02276 L
.53192 .02224 L
.53209 .02158 L
.53241 .02014 L
.53271 .01852 L
.53303 .01663 L
.53316 .01581 L
.5333 .01492 L
.53346 .0155 L
.5336 .01642 L
.5342 .02007 L
.53449 .02162 L
.53477 .02285 L
.53502 .02375 L
.53514 .02412 L
.53528 .02445 L
.53541 .02471 L
.53554 .02487 L
.53569 .02498 L
.53583 .02498 L
.53599 .02488 L
.53613 .0247 L
.53626 .02445 L
.5364 .02409 L
.53672 .023 L
.53702 .02165 L
.53758 .01828 L
.53786 .01638 L
.53798 .01552 L
.53812 .01486 L
.53826 .01589 L
.53839 .01686 L
Mistroke
.53869 .01896 L
.53933 .02289 L
.53965 .02442 L
.53983 .02508 L
.53999 .02559 L
.54015 .02594 L
.54024 .02609 L
.54032 .0262 L
.54046 .0263 L
.54061 .0263 L
.54076 .02619 L
.54084 .02608 L
.54092 .02594 L
.54106 .02562 L
.54121 .02517 L
.54147 .02414 L
.54176 .02267 L
.54235 .01873 L
.54251 .0175 L
.54268 .01615 L
.54283 .01498 L
.54298 .01575 L
.54313 .01697 L
.54327 .01808 L
.54358 .02046 L
.54413 .0242 L
.54439 .02563 L
.54453 .02625 L
.54468 .02681 L
.54481 .02721 L
.54495 .02755 L
.54508 .02776 L
.5452 .02787 L
.54535 .0279 L
.54542 .02786 L
.54551 .02778 L
.54566 .02754 L
.5458 .0272 L
.54596 .02665 L
.54611 .02603 L
.54645 .02419 L
.54703 .01993 L
.54733 .01736 L
.54741 .01665 L
.54749 .01588 L
.54765 .01498 L
.5478 .01638 L
.54794 .01767 L
.5482 .02007 L
.54871 .02434 L
Mistroke
.54901 .02635 L
.54928 .02788 L
.54943 .02854 L
.54957 .02903 L
.54972 .02944 L
.5498 .02961 L
.54988 .02972 L
.55003 .02983 L
.55012 .02983 L
.5502 .02978 L
.55034 .02959 L
.55049 .02924 L
.55063 .02881 L
.55075 .02829 L
.55104 .02676 L
.55135 .02459 L
.55164 .0222 L
.55197 .01904 L
.55211 .01755 L
.55219 .01674 L
.55227 .01586 L
.55241 .01503 L
.55254 .0164 L
.55282 .0194 L
.55341 .02526 L
.55369 .02754 L
.55398 .02952 L
.55422 .03082 L
.55436 .03137 L
.55449 .03177 L
.55465 .03208 L
.55472 .03216 L
.55481 .03221 L
.55496 .03215 L
.5551 .03194 L
.55519 .03174 L
.55527 .0315 L
.55542 .03091 L
.55558 .03009 L
.55576 .02898 L
.55638 .02356 L
.55668 .0203 L
.55683 .01859 L
.55696 .01698 L
.55709 .01533 L
.55723 .01585 L
.55738 .01762 L
.55753 .01954 L
.55805 .02564 L
.55833 .02863 L
Mistroke
.55864 .03133 L
.55879 .03241 L
.55894 .03329 L
.55907 .034 L
.5592 .03451 L
.55934 .03491 L
.55949 .03516 L
.55963 .03522 L
.55976 .03511 L
.55991 .0348 L
.56005 .03432 L
.5602 .0336 L
.56037 .0326 L
.5607 .02991 L
.56102 .02662 L
.56131 .02311 L
.56161 .01899 L
.56174 .01717 L
.56187 .01517 L
.56202 .01648 L
.56216 .01856 L
.56268 .02589 L
.56324 .03275 L
.56352 .03543 L
.56368 .03667 L
.56383 .03761 L
.56399 .03836 L
.56407 .03866 L
.56416 .03889 L
.56431 .03911 L
.56439 .03913 L
.56447 .03909 L
.56462 .03882 L
.56475 .03837 L
.56491 .03761 L
.56506 .03665 L
.56539 .0337 L
.5657 .03009 L
.56606 .02496 L
.56639 .0195 L
.56653 .01711 L
.56666 .01479 L
.56681 .01733 L
.56695 .0198 L
.56757 .03034 L
.56786 .03467 L
.56817 .03859 L
.56834 .04045 L
.5685 .04186 L
.56867 .04298 L
Mistroke
.56882 .04376 L
.56896 .04423 L
.56911 .04445 L
.56925 .0444 L
.56938 .04411 L
.56953 .04351 L
.56962 .04303 L
.5697 .04251 L
.57 .03981 L
.57028 .03622 L
.5706 .03125 L
.57094 .02505 L
.57108 .02209 L
.57124 .01874 L
.57138 .01573 L
.57151 .01655 L
.57165 .01957 L
.5718 .02281 L
.57239 .03533 L
.57268 .04065 L
.57296 .04493 L
.5732 .04803 L
.57334 .04941 L
.57347 .05047 L
.57362 .05137 L
.57376 .0519 L
.5739 .05214 L
.57406 .052 L
.5742 .05154 L
.57435 .05071 L
.57449 .04958 L
.57461 .0483 L
.57493 .04406 L
.57526 .03792 L
.57587 .02345 L
.57602 .01945 L
.57618 .01505 L
.57627 .01695 L
.57635 .01931 L
.57652 .02394 L
.57719 .0425 L
.57749 .04958 L
.57782 .056 L
.57797 .05841 L
.57813 .06054 L
.57826 .062 L
.57841 .06319 L
.57857 .06396 L
.57871 .06423 L
.57887 .064 L
Mistroke
.57896 .06364 L
.57904 .06315 L
.57918 .0619 L
.57934 .06001 L
.57963 .0552 L
.57992 .04883 L
.58021 .04051 L
.58049 .03144 L
.58075 .02233 L
.5809 .01655 L
.58105 .0185 L
.5812 .02452 L
.58137 .03112 L
.58195 .05324 L
.58228 .06445 L
.58264 .07436 L
.58294 .0807 L
.58302 .08205 L
.58311 .08329 L
.58327 .08499 L
.58341 .08584 L
.58355 .08611 L
.58371 .08566 L
.58386 .08452 L
.58399 .08283 L
.58412 .0807 L
.58441 .07389 L
.58472 .06378 L
.58506 .04985 L
.58533 .03603 L
.58548 .02807 L
.58564 .01918 L
.58574 .016 L
.58582 .02132 L
.586 .03191 L
.58634 .05325 L
.58698 .09177 L
.58729 .10793 L
.58762 .12234 L
.58778 .12764 L
.58794 .1322 L
.58808 .13518 L
.58823 .1374 L
.58838 .13846 L
.58847 .13851 L
.58855 .13819 L
.5887 .13666 L
.58886 .13366 L
.58899 .12975 L
.58913 .12501 L
Mistroke
.58942 .11022 L
.58975 .08777 L
.59009 .05717 L
.59023 .04252 L
.59038 .02564 L
.59047 .01538 L
.59055 .0237 L
.5907 .04343 L
.59181 .2127 L
.59301 .40884 L
.5936 .49107 L
.59392 .52835 L
.59422 .55713 L
.59447 .57653 L
.5946 .58454 L
.59475 .59168 L
.5949 .59757 L
.59505 .60127 L
.59519 .60309 L
.59533 .60319 L
.59547 .60161 L
.59563 .59794 L
.59577 .59263 L
.59591 .58621 L
.59622 .56574 L
.59654 .53624 L
.59716 .4615 L
.59784 .35844 L
.59842 .26041 L
.59905 .15409 L
.59934 .10794 L
.59965 .06215 L
.59977 .04443 L
.59991 .02622 L
.60006 .02214 L
.6002 .03879 L
.60055 .07607 L
.60089 .10437 L
.60119 .1236 L
.60136 .13186 L
.60152 .13785 L
.60168 .1422 L
.60183 .14489 L
.60196 .14617 L
.6021 .14639 L
.60226 .1453 L
.60234 .14425 L
.60243 .14271 L
.60258 .13908 L
.60272 .13469 L
Mistroke
.60333 .1073 L
.60399 .06658 L
.60429 .04629 L
.60445 .03515 L
.60461 .02483 L
.60474 .01623 L
.60488 .02222 L
.60518 .04029 L
.60575 .0686 L
.60604 .0792 L
.6062 .08405 L
.60635 .08765 L
.60649 .09028 L
.60662 .09214 L
.60675 .09345 L
.6069 .09411 L
.60703 .09406 L
.60717 .09337 L
.60729 .09229 L
.60742 .09058 L
.60758 .08785 L
.60772 .08468 L
.60805 .0755 L
.60865 .05325 L
.60919 .02957 L
.60935 .0226 L
.60949 .0161 L
.60962 .01908 L
.60977 .02513 L
.61041 .04918 L
.61073 .05857 L
.61091 .06294 L
.61108 .06622 L
.61123 .06849 L
.61138 .07037 L
.61147 .07113 L
.61155 .07167 L
.6117 .07226 L
.61184 .07227 L
.61199 .07176 L
.61214 .07066 L
.61229 .06913 L
.61244 .06704 L
.6126 .0643 L
.61289 .05814 L
.61354 .03962 L
.61386 .02909 L
.61402 .02378 L
.61416 .01888 L
.61429 .01499 L
Mistroke
.61443 .01962 L
.61473 .02897 L
.61524 .04327 L
.61552 .04957 L
.61579 .0543 L
.61594 .05639 L
.61611 .05816 L
.61626 .05931 L
.6164 .05997 L
.61653 .06024 L
.61667 .06016 L
.61682 .05963 L
.61696 .05875 L
.6171 .05749 L
.61725 .05575 L
.61753 .05167 L
.61815 .03866 L
.61848 .03008 L
.6188 .02149 L
.61894 .01769 L
.61909 .01573 L
.61916 .0178 L
.61925 .02006 L
.61939 .02395 L
.61995 .03708 L
.62026 .04293 L
.62055 .04732 L
.62068 .04889 L
.62082 .05026 L
.62097 .05141 L
.62111 .05213 L
.62125 .05252 L
.62138 .05259 L
.6215 .05241 L
.62163 .05197 L
.62178 .05112 L
.62191 .05004 L
.62222 .04663 L
.6225 .04238 L
.62277 .03753 L
.62309 .03103 L
.62343 .02351 L
.62357 .02032 L
.62372 .01686 L
.6238 .01489 L
.62388 .01634 L
.62403 .01984 L
.62462 .03201 L
.62492 .03737 L
.62525 .04196 L
Mistroke
.62543 .04386 L
.62559 .04524 L
.62566 .04578 L
.62575 .04628 L
.6259 .04693 L
.62598 .04714 L
.62607 .04727 L
.62616 .04728 L
.62625 .04718 L
.62641 .04673 L
.6265 .04633 L
.62658 .04587 L
.62685 .04368 L
.62701 .04201 L
.62715 .0402 L
.62777 .03045 L
.6283 .02019 L
.62845 .01726 L
.6286 .01526 L
.62873 .01788 L
.62887 .02069 L
.6295 .0318 L
.62985 .03672 L
.63002 .03863 L
.63017 .04012 L
.63031 .04126 L
.63047 .04224 L
.63062 .04293 L
.63071 .04318 L
.63079 .04332 L
.63094 .04338 L
.63107 .0432 L
.63123 .04271 L
.63138 .04198 L
.63153 .04098 L
.63169 .03961 L
.63198 .03646 L
.63253 .02863 L
.63284 .0234 L
.63301 .0204 L
.63317 .01756 L
.63331 .01513 L
.63346 .01689 L
.63354 .01836 L
.63362 .01973 L
.63376 .02224 L
.63428 .03021 L
.63456 .0338 L
.63483 .03654 L
.63498 .03777 L
Mistroke
.63511 .03871 L
.63526 .03951 L
.63534 .03983 L
.63543 .04009 L
.63556 .04035 L
.63569 .0404 L
.63583 .04025 L
.63598 .03985 L
.63613 .03921 L
.63629 .03824 L
.63663 .03549 L
.63693 .03209 L
.63722 .02832 L
.63755 .02342 L
.63786 .01845 L
.63795 .01709 L
.63804 .01565 L
.63814 .01536 L
.63823 .01682 L
.63856 .02198 L
.63887 .02653 L
.63921 .0308 L
.63954 .03405 L
.63969 .03528 L
.63983 .03623 L
.63996 .03693 L
.6401 .03749 L
.64026 .03788 L
.6404 .03804 L
.64054 .03798 L
.6407 .03768 L
.64085 .03717 L
.64099 .0365 L
.64128 .03452 L
.64155 .03208 L
.64215 .02485 L
.64242 .02111 L
.64256 .01907 L
.64271 .01685 L
.64286 .01472 L
.64299 .01663 L
.64324 .02031 L
.64386 .02817 L
.64421 .03164 L
.64437 .03298 L
.64452 .03402 L
.64467 .03483 L
.6448 .0354 L
.64495 .03584 L
.64511 .03609 L
Mistroke
.64526 .03611 L
.64535 .03602 L
.64543 .03588 L
.64558 .03547 L
.64573 .03483 L
.64587 .03409 L
.64602 .03311 L
.64632 .03061 L
.64686 .02472 L
.64716 .02084 L
.64733 .01861 L
.64749 .01647 L
.64764 .01496 L
.64772 .01609 L
.6478 .01712 L
.64808 .02079 L
.64863 .02723 L
.6489 .02979 L
.64915 .0317 L
.64941 .0332 L
.64955 .0338 L
.64969 .0342 L
.64983 .03446 L
.64997 .03454 L
.65012 .03443 L
.6502 .03429 L
.65028 .03411 L
.65043 .03363 L
.65056 .03303 L
.65087 .03114 L
.65117 .02867 L
.65149 .02544 L
.65202 .01919 L
.65217 .01737 L
.65233 .01541 L
.65246 .01569 L
.6526 .01751 L
.65328 .02526 L
.65359 .02814 L
.65375 .02942 L
.65392 .03059 L
.65407 .03148 L
.65424 .03224 L
.65439 .03274 L
.65454 .03305 L
.65468 .03319 L
.65482 .03317 L
.65497 .03296 L
.65512 .0326 L
.65526 .0321 L
Mistroke
.65541 .0314 L
.65568 .02975 L
.656 .02718 L
.65629 .02437 L
.6566 .02108 L
.65676 .01925 L
.65693 .01726 L
.65701 .01626 L
.65709 .01531 L
.65724 .01588 L
.65738 .01751 L
.65753 .01924 L
.6581 .02511 L
.65841 .02773 L
.65869 .02967 L
.65894 .0309 L
.65908 .0314 L
.6592 .03173 L
.65934 .03196 L
.65949 .03205 L
.65963 .03199 L
.65976 .03179 L
.65991 .03141 L
.66005 .0309 L
.66032 .02956 L
.66061 .02762 L
.66092 .02498 L
.66122 .02213 L
.6615 .01921 L
.66175 .01647 L
.66189 .01491 L
.66202 .01595 L
.66264 .02249 L
.66296 .02535 L
.66331 .02792 L
.66345 .02879 L
.66361 .02957 L
.66374 .03012 L
.66389 .03058 L
.66397 .03078 L
.66405 .03091 L
.66421 .03106 L
.66435 .03103 L
.6645 .03085 L
.66464 .03055 L
.66479 .03007 L
.66495 .02941 L
.66509 .02866 L
.66563 .02485 L
.66596 .02191 L
Mistroke
.66627 .01883 L
.66641 .01744 L
.66655 .01594 L
.66671 .01513 L
.66685 .01664 L
.6674 .02207 L
.66792 .02623 L
.66818 .02785 L
.66831 .02853 L
.66846 .02914 L
.66854 .02943 L
.66862 .02965 L
.66877 .02999 L
.66891 .03016 L
.66906 .0302 L
.66921 .03009 L
.66929 .02996 L
.66937 .02979 L
.66953 .02934 L
.6697 .02867 L
.67002 .02702 L
.6703 .02507 L
.67094 .01949 L
.67112 .01778 L
.67122 .01683 L
.67131 .01593 L
.67138 .01516 L
.67147 .01509 L
.67156 .016 L
.67164 .01683 L
.67225 .02245 L
.67258 .02501 L
.67289 .02694 L
.67317 .02822 L
.67332 .02875 L
.67346 .0291 L
.67361 .02934 L
.6737 .02941 L
.67378 .02944 L
.67392 .02938 L
.67408 .02917 L
.67422 .02883 L
.67438 .02832 L
.67467 .02701 L
.67496 .0253 L
.67522 .02341 L
.6758 .0184 L
.67596 .01692 L
.67604 .01612 L
.67613 .01529 L
Mistroke
.67621 .01488 L
.67629 .01568 L
.67644 .01708 L
.67696 .02164 L
.67751 .02558 L
.67767 .02646 L
.67782 .02717 L
.67797 .02774 L
.6781 .02815 L
.67823 .02845 L
.67837 .02866 L
.6785 .02876 L
.67865 .02873 L
.67995 .02321 L
.68026 .02078 L
.68059 .01794 L
.68076 .0165 L
.68091 .01513 L
.68104 .01553 L
.68119 .01686 L
.68173 .02141 L
.6823 .02525 L
.6826 .0267 L
.68277 .02731 L
.68293 .02774 L
.68308 .028 L
.68321 .02813 L
.68337 .02815 L
.68351 .02804 L
.68365 .02783 L
.68378 .02753 L
.68392 .02709 L
.68408 .0265 L
.68439 .02493 L
.68468 .02312 L
.68523 .01883 L
.68537 .01766 L
.68551 .01652 L
.68562 .0155 L
.68575 .01505 L
.6859 .01628 L
.68603 .01741 L
.68632 .01981 L
.68662 .02203 L
.68694 .02414 L
.68725 .02576 L
.6874 .02637 L
.68755 .02684 L
.68762 .02705 L
.68771 .02724 L
Mistroke
.68786 .02748 L
.68794 .02756 L
.68803 .02761 L
.68811 .02761 L
.68819 .02758 L
.68834 .02743 L
.68847 .02718 L
.68862 .0268 L
.68878 .02625 L
.68911 .02477 L
.6894 .02302 L
.68998 .01878 L
.69024 .01671 L
.69037 .01559 L
.69052 .01505 L
.69067 .01634 L
.69082 .01753 L
.69114 .02002 L
.69148 .02243 L
.69181 .02435 L
.69211 .02572 L
.69229 .02631 L
.69237 .02653 L
.69245 .02671 L
.69259 .02696 L
.69273 .02709 L
.69287 .02712 L
.69303 .02703 L
.69318 .02681 L
.69332 .02652 L
.69347 .02606 L
.69362 .02551 L
.69418 .02264 L
.69449 .02051 L
.69483 .01798 L
.69497 .01689 L
.69512 .0157 L
.6952 .01501 L
.69528 .01505 L
.69543 .01627 L
.69601 .02064 L
.69632 .02263 L
.69665 .02438 L
.69682 .02513 L
.69698 .02569 L
.69714 .02613 L
.69729 .02643 L
.69738 .02655 L
.69746 .02663 L
.69762 .02668 L
Mistroke
.69771 .02665 L
.69779 .02659 L
.69788 .02648 L
.69797 .02632 L
.69813 .02595 L
.69828 .02551 L
.69861 .02416 L
.69891 .02253 L
.69919 .02071 L
.6995 .0185 L
.69983 .01601 L
.69992 .01536 L
.70001 .01476 L
.7001 .01551 L
.70019 .01621 L
.70052 .01869 L
.70084 .02084 L
.70118 .02288 L
.7015 .02442 L
.70165 .02501 L
.70179 .02546 L
.70192 .02578 L
.70206 .02604 L
.70221 .02621 L
.70235 .02627 L
.70249 .02623 L
.70264 .02608 L
.7028 .02579 L
.70295 .02543 L
.70356 .02288 L
.7039 .02085 L
.70422 .01871 L
.70452 .01652 L
.70467 .01542 L
.7048 .01502 L
.70494 .01608 L
.7051 .0172 L
.70542 .01947 L
.70597 .02278 L
.70628 .02419 L
.70643 .02473 L
.70657 .02515 L
.70669 .02544 L
.70682 .02567 L
.70697 .02583 L
.7071 .0259 L
.70723 .02587 L
.70737 .02575 L
.70752 .02552 L
.70766 .02521 L
Mistroke
.70796 .02427 L
.70827 .02289 L
.70861 .02098 L
.70893 .01895 L
.7092 .01704 L
.70935 .01595 L
.7095 .01491 L
.70958 .01511 L
.70967 .01575 L
.70982 .01686 L
.71012 .01895 L
.71069 .0223 L
.711 .02374 L
.71115 .02428 L
.71129 .0247 L
.71141 .02502 L
.71155 .02529 L
.71169 .02546 L
.71184 .02555 L
.71197 .02554 L
.71211 .02544 L
.71224 .02526 L
.71236 .02503 L
.71251 .02467 L
.71264 .02426 L
.71294 .02305 L
.71356 .01965 L
.71382 .01795 L
.71409 .01607 L
.71424 .01507 L
.71439 .01546 L
.71453 .01646 L
.71467 .01736 L
.71529 .02124 L
.7156 .02277 L
.71588 .02389 L
.71604 .02437 L
.7162 .02478 L
.71629 .02494 L
.71637 .02506 L
.71646 .02515 L
.71655 .02522 L
.71663 .02524 L
.71672 .02523 L
.71688 .02512 L
.71703 .02492 L
.71717 .02463 L
.71747 .02375 L
.71778 .02245 L
.71813 .02065 L
Mistroke
.71845 .01872 L
.71873 .01691 L
.71888 .01588 L
.71902 .01489 L
.7191 .0151 L
.71919 .0157 L
.71935 .01675 L
.71965 .01872 L
.72022 .0219 L
.7205 .02314 L
.72067 .02372 L
.72082 .02416 L
.72095 .02446 L
.72109 .0247 L
.72122 .02486 L
.72137 .02494 L
.72151 .02493 L
.72164 .02483 L
.72178 .02466 L
.7219 .02443 L
.72204 .02409 L
.72218 .02369 L
.72248 .02252 L
.7231 .01927 L
.72338 .01755 L
.72364 .01585 L
.72378 .01489 L
.72394 .01558 L
.72408 .01652 L
.72421 .01738 L
.72484 .02103 L
.72515 .02246 L
.72543 .02349 L
.72558 .02389 L
.72573 .02424 L
.72588 .02448 L
.72597 .02458 L
.72605 .02464 L
.72613 .02467 L
.72622 .02467 L
.72637 .02459 L
.72646 .0245 L
.72654 .02439 L
.72672 .02403 L
.72688 .02364 L
.72702 .02318 L
.72729 .02213 L
.72789 .01899 L
.72815 .01745 L
.72841 .01573 L
Mistroke
.72857 .01472 L
.72871 .01562 L
.72899 .01736 L
.7296 .02086 L
.72995 .02241 L
.73011 .02301 L
.73027 .02348 L
.73041 .02384 L
.73055 .02409 L
.73069 .02429 L
.73085 .0244 L
.73101 .02441 L
.73109 .02437 L
.73117 .02431 L
.73132 .02412 L
.73147 .02383 L
.73176 .02304 L
.73202 .02205 L
.7323 .02078 L
.7326 .01916 L
.73291 .01735 L
.73308 .0163 L
.73324 .0153 L
.73339 .01506 L
.73355 .01606 L
.73382 .01775 L
.73438 .02079 L
.73469 .02213 L
.73497 .0231 L
.7351 .02343 L
.73521 .0237 L
.73535 .02393 L
.73547 .02408 L
.73561 .02417 L
.73574 .02418 L
.73588 .02412 L
.73603 .02397 L
.73618 .02372 L
.73634 .02335 L
.73668 .0223 L
.73699 .021 L
.73727 .01956 L
.73761 .01768 L
.73792 .01578 L
.73801 .01525 L
.7381 .01473 L
.7382 .01534 L
.73829 .01589 L
.73862 .01787 L
.73918 .0208 L
Mistroke
.73949 .02211 L
.73978 .02302 L
.73994 .02341 L
.74002 .02357 L
.74011 .02372 L
.7402 .02383 L
.74028 .0239 L
.74044 .02396 L
.74059 .02393 L
.74067 .02388 L
.74075 .0238 L
.7409 .02359 L
.74105 .02328 L
.74133 .02249 L
.74164 .02134 L
.7422 .0186 L
.74253 .01669 L
.74267 .01582 L
.74275 .01535 L
.74284 .01484 L
.74298 .01547 L
.74312 .01629 L
.74342 .01803 L
.74398 .02086 L
.74426 .02199 L
.74443 .02252 L
.74457 .02293 L
.7447 .02322 L
.74484 .02346 L
.74498 .02364 L
.74512 .02374 L
.74525 .02376 L
.74539 .02371 L
.7455 .02361 L
.74563 .02344 L
.74579 .02315 L
.74593 .0228 L
.74626 .02175 L
.74686 .01905 L
.74714 .01753 L
.7474 .01602 L
.74754 .01516 L
.7477 .0152 L
.74784 .01604 L
.74798 .0168 L
.74861 .02013 L
.74892 .02144 L
.7492 .02239 L
.74934 .02277 L
.7495 .02311 L
Mistroke
.74958 .02325 L
.74966 .02336 L
.74982 .02351 L
.74997 .02357 L
.75006 .02356 L
.75015 .02352 L
.75023 .02345 L
.75031 .02337 L
.7504 .02324 L
.75049 .02308 L
.75078 .02239 L
.75109 .02135 L
.75165 .0188 L
.75198 .01698 L
.75213 .01615 L
.75221 .0157 L
.75229 .01522 L
.75244 .01506 L
.75258 .01585 L
.75288 .01754 L
.75347 .02047 L
.75377 .02161 L
.75404 .02244 L
.75416 .02274 L
.75428 .02298 L
.75441 .02316 L
.75454 .02331 L
.75468 .02338 L
.75481 .02338 L
.75495 .02331 L
.7551 .02316 L
.75524 .02293 L
.75541 .0226 L
.7557 .02176 L
.75598 .02069 L
.75624 .01953 L
.75684 .01642 L
.75699 .0156 L
.75714 .01472 L
.75723 .01521 L
.75731 .01567 L
.75747 .01657 L
.75802 .01937 L
.7583 .02063 L
.75861 .02174 L
.75876 .02218 L
.7589 .02253 L
.75904 .0228 L
.75917 .02299 L
.75929 .02312 L
Mistroke
.75942 .0232 L
.75955 .02321 L
.75969 .02316 L
.75984 .02302 L
.75999 .0228 L
.76015 .02248 L
.76032 .02205 L
.7606 .02112 L
.76092 .01984 L
.7612 .01848 L
.7615 .01692 L
.76176 .01552 L
.76191 .01472 L
.76204 .01547 L
.76267 .01876 L
.76302 .02034 L
.76334 .02152 L
.76349 .02195 L
.76365 .02234 L
.76379 .02264 L
.76393 .02284 L
.76408 .02299 L
.76416 .02303 L
.76424 .02305 L
.7644 .02303 L
.76448 .02298 L
.76456 .02291 L
.76472 .0227 L
.76487 .02243 L
.76514 .02174 L
.76544 .02074 L
.76575 .01941 L
.76628 .0168 L
.76643 .01603 L
.76658 .01519 L
.76673 .01504 L
.76686 .01576 L
.76749 .01899 L
.76781 .02036 L
.76816 .02157 L
.76832 .02199 L
.76848 .02236 L
.76862 .0226 L
.76878 .02278 L
.76892 .02288 L
.76908 .0229 L
.76923 .02284 L
.76936 .02272 L
.76951 .02251 L
.76966 .02223 L
Mistroke
.76993 .02152 L
.77023 .02052 L
.77055 .0192 L
.77107 .01662 L
.77121 .01586 L
.77137 .01503 L
.77151 .01518 L
.77165 .01588 L
.77228 .01903 L
.7726 .02036 L
.77277 .02096 L
.77295 .02152 L
.7731 .02192 L
.77327 .02227 L
.77342 .02251 L
.77356 .02266 L
.77371 .02275 L
.77384 .02276 L
.77399 .0227 L
.77415 .02256 L
.77429 .02234 L
.77446 .02203 L
.77475 .02125 L
.77503 .02026 L
.7753 .01917 L
.77589 .01627 L
.77604 .01552 L
.77619 .01473 L
.77628 .0152 L
.77636 .01563 L
.77652 .01646 L
.77707 .01907 L
.77735 .02024 L
.77766 .02126 L
.77781 .02167 L
.77795 .022 L
.77809 .02225 L
.77822 .02243 L
.77834 .02255 L
.77847 .02261 L
.7786 .02263 L
.77874 .02258 L
.7789 .02244 L
.77904 .02224 L
.7792 .02194 L
.77937 .02153 L
.77966 .02066 L
.77997 .01946 L
.78026 .0182 L
.78056 .01674 L
Mistroke
.78081 .01543 L
.78096 .01475 L
.78109 .01545 L
.78172 .01852 L
.78208 .01999 L
.7824 .02108 L
.78254 .02149 L
.7827 .02185 L
.78285 .02212 L
.78299 .02231 L
.78313 .02244 L
.78322 .02248 L
.78329 .0225 L
.78345 .02248 L
.78354 .02243 L
.78362 .02236 L
.78377 .02216 L
.78392 .02191 L
.7842 .02126 L
.78449 .02032 L
.78481 .01907 L
.78534 .01662 L
.78548 .0159 L
.78564 .01511 L
.78578 .01506 L
.78592 .01574 L
.78655 .01875 L
.78687 .02004 L
.78722 .02116 L
.78737 .02155 L
.78754 .02189 L
.78768 .02211 L
.78784 .02228 L
.78798 .02236 L
.78814 .02238 L
.78828 .02232 L
.78842 .0222 L
.78857 .022 L
.78872 .02173 L
.78899 .02106 L
.78929 .02012 L
.7896 .01887 L
.78988 .01762 L
.79018 .0162 L
.7903 .0156 L
.79043 .01495 L
.79057 .0152 L
.79071 .01587 L
.79138 .01897 L
.79171 .02022 L
Mistroke
.79201 .02115 L
.79229 .02176 L
.79243 .02198 L
.79258 .02215 L
.79274 .02225 L
.79283 .02227 L
.79291 .02226 L
.79305 .0222 L
.79321 .02206 L
.79335 .02186 L
.79352 .02155 L
.79381 .02081 L
.79436 .01885 L
.79467 .01748 L
.795 .01591 L
.79513 .01524 L
.79528 .01491 L
.79536 .01532 L
.79544 .0157 L
.79559 .01642 L
.79613 .01887 L
.79642 .01996 L
.79672 .02091 L
.79687 .0213 L
.79702 .02159 L
.79716 .02183 L
.79728 .02199 L
.7974 .02209 L
.79753 .02215 L
.79766 .02216 L
.7978 .0221 L
.79796 .02197 L
.79811 .02177 L
.79827 .02148 L
.79844 .02109 L
.79872 .02026 L
.79904 .01912 L
.79932 .01792 L
.79962 .01654 L
.79975 .01595 L
.79988 .01531 L
.80002 .01483 L
.80016 .01549 L
.80079 .01837 L
.80113 .01973 L
.80146 .02077 L
.80161 .02115 L
.80177 .02148 L
.80185 .02163 L
.80194 .02176 L
Mistroke
.80203 .02187 L
.8021 .02194 L
.80225 .02203 L
.8024 .02206 L
.80255 .02201 L
.80268 .02191 L
.80282 .02175 L
.80297 .02151 L
.80323 .02091 L
.80355 .01995 L
.80384 .01888 L
.80445 .01622 L
.80459 .01553 L
.80475 .01478 L
.80484 .01509 L
.80492 .01548 L
.80508 .01624 L
.80563 .01865 L
.80592 .01974 L
.80622 .02068 L
.80649 .02131 L
.80664 .02158 L
.80678 .02177 L
.80691 .02189 L
.80703 .02195 L
.80717 .02196 L
.8073 .02192 L
.80745 .02181 L
.80754 .02171 L
.80761 .02161 L
.80791 .02105 L
.80818 .02033 L
.80846 .01938 L
.80877 .01817 L
.8091 .01672 L
.80926 .01598 L
.80941 .01527 L
.80954 .01481 L
.80969 .01551 L
.8102 .01784 L
.81075 .01991 L
.81104 .02074 L
.81119 .0211 L
.81135 .02141 L
.8115 .02163 L
.81164 .02177 L
.81177 .02185 L
.81191 .02187 L
.81206 .02183 L
.81214 .02178 L
Mistroke
.81222 .02171 L
.81236 .02154 L
.81251 .02129 L
.81277 .02071 L
.81306 .01987 L
.81365 .0176 L
.81398 .01613 L
.81414 .01539 L
.81429 .01474 L
.81443 .01539 L
.81458 .01608 L
.81489 .01747 L
.81544 .0196 L
.81573 .02048 L
.81587 .02084 L
.816 .02112 L
.81612 .02133 L
.81624 .02152 L
.81637 .02166 L
.81651 .02175 L
.81667 .02179 L
.81681 .02175 L
.81689 .02171 L
.81697 .02164 L
.81706 .02154 L
.81714 .02143 L
.81743 .02089 L
.81759 .02049 L
.81774 .02006 L
.81833 .01794 L
.81861 .01672 L
.81887 .01555 L
.81902 .01484 L
.81917 .01526 L
.81932 .01597 L
.81949 .01671 L
.81981 .01811 L
.82016 .01941 L
.82047 .02036 L
.82063 .02076 L
.8208 .02112 L
.82096 .02138 L
.82111 .02155 L
.82125 .02166 L
.82139 .0217 L
.82153 .02169 L
.82168 .02161 L
.82182 .02147 L
.82194 .0213 L
.82209 .02105 L
Mistroke
.82224 .02071 L
.82255 .01985 L
.8232 .01746 L
.8235 .01612 L
.82365 .01544 L
.82379 .0148 L
.82392 .01523 L
.82406 .01586 L
.82435 .01715 L
.82486 .01916 L
.82513 .02001 L
.82541 .02074 L
.82557 .02107 L
.82572 .02131 L
.82587 .02148 L
.82601 .02158 L
.82616 .02163 L
.82625 .02162 L
.82633 .0216 L
.82647 .02151 L
.82662 .02134 L
.82676 .02114 L
.82688 .02091 L
.82717 .02022 L
.82777 .0182 L
.82807 .01694 L
.82823 .01624 L
.8284 .01547 L
.82855 .0148 L
.82864 .01501 L
.82871 .01536 L
.829 .01663 L
.82957 .0189 L
.82981 .01972 L
.83007 .02045 L
.83021 .02076 L
.83036 .02105 L
.8305 .02125 L
.83062 .0214 L
.83078 .02151 L
.83086 .02154 L
.83094 .02155 L
.83109 .02152 L
.83123 .02143 L
.83132 .02135 L
.8314 .02125 L
.83155 .02102 L
.83172 .02069 L
.83189 .02026 L
.83252 .01821 L
Mistroke
.83281 .017 L
.83309 .01579 L
.83321 .01525 L
.83334 .01475 L
.83348 .01538 L
.83361 .01595 L
.83418 .01831 L
.83445 .01926 L
.83473 .02012 L
.8349 .02053 L
.83504 .02084 L
.8352 .0211 L
.83534 .02128 L
.83547 .0214 L
.83561 .02147 L
.8357 .02148 L
.83577 .02148 L
.83592 .02142 L
.83607 .02129 L
.83621 .02111 L
.83637 .02085 L
.83654 .0205 L
.83712 .01877 L
.83765 .01668 L
.8378 .01601 L
.83797 .01528 L
.83811 .01478 L
.83827 .01547 L
.83894 .01826 L
.83924 .01932 L
.83957 .02025 L
.83972 .02062 L
.83987 .0209 L
.84001 .0211 L
.84015 .02127 L
.8403 .02137 L
.84043 .02141 L
.84058 .0214 L
.84074 .02131 L
.84087 .02118 L
.841 .02101 L
.84129 .02047 L
.8416 .01964 L
.84189 .01869 L
.84223 .01741 L
.84254 .01611 L
.84269 .01543 L
.84284 .01478 L
.84299 .01532 L
.84316 .01605 L
Mistroke
.84384 .01874 L
.84415 .01971 L
.84443 .02045 L
.84459 .02077 L
.84477 .02104 L
.84493 .02122 L
.84507 .02131 L
.84523 .02135 L
.84531 .02135 L
.84539 .02132 L
.84554 .02121 L
.84569 .02106 L
.84585 .02081 L
.84601 .02051 L
.84635 .01964 L
.84697 .01747 L
.84725 .0163 L
.84741 .01564 L
.84755 .01501 L
.84768 .01498 L
.84782 .01558 L
.84811 .01682 L
.84863 .01879 L
.84893 .01972 L
.84924 .02049 L
.84937 .02074 L
.84951 .02095 L
.84966 .02113 L
.8498 .02124 L
.84995 .02129 L
.85003 .02129 L
.85011 .02127 L
.85019 .02124 L
.85027 .02118 L
.85036 .0211 L
.85044 .02101 L
.85059 .02079 L
.85073 .02054 L
.85104 .0198 L
.85169 .01762 L
.85202 .01627 L
.85219 .01552 L
.85229 .01511 L
.85238 .01473 L
.85253 .01534 L
.85269 .01603 L
.85297 .01721 L
.85353 .01922 L
.85386 .02012 L
.85415 .02072 L
Mistroke
.85431 .02096 L
.8544 .02106 L
.85449 .02113 L
.85464 .02122 L
.85472 .02123 L
.85481 .02123 L
.85611 .01881 L
.85642 .01769 L
.85675 .01637 L
.85691 .01569 L
.85707 .01504 L
.8572 .01497 L
.85735 .0156 L
.85789 .01778 L
.85846 .01966 L
.85876 .02039 L
.85893 .0207 L
.85909 .02093 L
.85924 .02107 L
.85937 .02115 L
.85953 .02118 L
.85967 .02115 L
.85981 .02107 L
.85994 .02094 L
.86008 .02074 L
.86024 .02047 L
.86055 .01975 L
.86084 .0189 L
.86139 .01685 L
.86167 .01573 L
.86178 .01522 L
.86191 .01475 L
.86205 .01535 L
.86219 .01591 L
.86248 .0171 L
.8631 .01928 L
.86342 .02011 L
.86359 .02047 L
.86375 .02074 L
.86389 .02092 L
.86404 .02105 L
.86412 .0211 L
.8642 .02112 L
.86435 .02113 L
.8645 .02107 L
.86459 .021 L
.86466 .02093 L
.86481 .02075 L
.86496 .0205 L
.86522 .01994 L
Mistroke
.86551 .01914 L
.86611 .01702 L
.86626 .01639 L
.86644 .01569 L
.86651 .01536 L
.8666 .01501 L
.86675 .01505 L
.86689 .01567 L
.86703 .01624 L
.86735 .01749 L
.86763 .01852 L
.8679 .01934 L
.86814 .01999 L
.86841 .02054 L
.86856 .02076 L
.8687 .02092 L
.86883 .02102 L
.86897 .02108 L
.86912 .02108 L
.8692 .02105 L
.86928 .02101 L
.86936 .02094 L
.86944 .02087 L
.86961 .02064 L
.86976 .02039 L
.86992 .02006 L
.87021 .01931 L
.87086 .01706 L
.87103 .01637 L
.87121 .01562 L
.8713 .01526 L
.87139 .01489 L
.87146 .01486 L
.87155 .01521 L
.87215 .01761 L
.87247 .01873 L
.87281 .01972 L
.87297 .02011 L
.87313 .02042 L
.87328 .02066 L
.87342 .02083 L
.87355 .02095 L
.87369 .02102 L
.87383 .02104 L
.87398 .021 L
.87414 .02089 L
.87428 .02073 L
.87444 .0205 L
.87461 .02018 L
.87492 .01941 L
Mistroke
.87521 .01854 L
.87549 .01753 L
.87579 .01637 L
.87604 .01532 L
.87619 .01472 L
.87632 .01527 L
.87695 .01773 L
.8773 .01893 L
.87762 .01981 L
.87777 .02014 L
.87793 .02044 L
.87806 .02065 L
.87821 .02083 L
.87837 .02094 L
.87846 .02098 L
.87854 .021 L
.87869 .02098 L
.87884 .02089 L
.879 .02075 L
.87913 .02056 L
.87944 .01998 L
.87973 .01924 L
.88 .0184 L
.88061 .01613 L
.88077 .01545 L
.88087 .01508 L
.88095 .01472 L
.8811 .01532 L
.88127 .016 L
.8819 .01836 L
.88221 .01932 L
.88249 .02003 L
.88265 .02034 L
.88282 .02061 L
.88291 .02072 L
.883 .02081 L
.88309 .02088 L
.88318 .02093 L
.88326 .02095 L
.88334 .02096 L
.88343 .02094 L
.88351 .02091 L
.88366 .02081 L
.88381 .02065 L
.88504 .01738 L
.88538 .01607 L
.88557 .01532 L
.88566 .01495 L
.88574 .01482 L
.88589 .01542 L
Mistroke
.88605 .01606 L
.88638 .01737 L
.88698 .01931 L
.88714 .01974 L
.88731 .02012 L
.88748 .02042 L
.88763 .02063 L
.88778 .02079 L
.88786 .02085 L
.88795 .02089 L
.88809 .02092 L
.88825 .02089 L
.88839 .0208 L
.88854 .02065 L
.88868 .02046 L
.88881 .02024 L
.88993 .01691 L
.8902 .01584 L
.89034 .01526 L
.89049 .01478 L
.89057 .0151 L
.89066 .01546 L
.89081 .01608 L
.89111 .01724 L
.89144 .01838 L
.89179 .01942 L
.89196 .01983 L
.89212 .02017 L
.89226 .02041 L
.89241 .02063 L
.89256 .02077 L
.89272 .02086 L
.89286 .02088 L
.89299 .02086 L
.89315 .02077 L
.89329 .02063 L
.89346 .0204 L
.89362 .02012 L
.89393 .01939 L
.89423 .01853 L
.89478 .01655 L
.89493 .01596 L
.89509 .01533 L
.89522 .01478 L
.89537 .01526 L
.89601 .01772 L
.89657 .01944 L
.89673 .01983 L
.89688 .02014 L
.89702 .02038 L
Mistroke
.89716 .02058 L
.89729 .02071 L
.89743 .0208 L
.89756 .02085 L
.89767 .02085 L
.89781 .0208 L
.89794 .02071 L
.89809 .02055 L
.89823 .02035 L
.89939 .01713 L
.89972 .01584 L
.8998 .01552 L
.89988 .01519 L
.90003 .01485 L
.90017 .01539 L
.90031 .01598 L
.90062 .01714 L
.90117 .01899 L
.90148 .01978 L
.90163 .02009 L
.90177 .02033 L
.90189 .02051 L
.90203 .02066 L
.90217 .02076 L
.90231 .02082 L
.90244 .02082 L
.90258 .02077 L
.90272 .02067 L
.90284 .02055 L
.90299 .02033 L
.90314 .02008 L
.90341 .01947 L
.90402 .01759 L
.90427 .01665 L
.90454 .01559 L
.90469 .01502 L
.90484 .01504 L
.90498 .0156 L
.90512 .01613 L
.90573 .01835 L
.90604 .01925 L
.90632 .01992 L
.90649 .02024 L
.90664 .02047 L
.90672 .02057 L
.90681 .02065 L
.90691 .02072 L
.90699 .02077 L
.90715 .02079 L
.90723 .02078 L
Mistroke
.90732 .02075 L
.90747 .02065 L
.90761 .0205 L
.90791 .02004 L
.90805 .01972 L
.90822 .01932 L
.90856 .01832 L
.90887 .01723 L
.90917 .01611 L
.90933 .0155 L
.90941 .01516 L
.90949 .01484 L
.90964 .01516 L
.90979 .01579 L
.91007 .01685 L
.91063 .01875 L
.9109 .01949 L
.91115 .02004 L
.91129 .02028 L
.91144 .02049 L
.9116 .02064 L
.91168 .0207 L
.91176 .02074 L
.9119 .02077 L
.91202 .02075 L
.91217 .02067 L
.91231 .02055 L
.91245 .02038 L
.91259 .02015 L
.91286 .0196 L
.91318 .01875 L
.91347 .01781 L
.91378 .01669 L
.91407 .01557 L
.91422 .01499 L
.91437 .01507 L
.91446 .01542 L
.91455 .01575 L
.91471 .01636 L
.91522 .01821 L
.9155 .01906 L
.91577 .01972 L
.91606 .02026 L
.91621 .02047 L
.91629 .02055 L
.91637 .02063 L
.91652 .02071 L
.91666 .02074 L
.9168 .02072 L
.91693 .02065 L
Mistroke
.91708 .02052 L
.91716 .02043 L
.91724 .02031 L
.91754 .01977 L
.91788 .01891 L
.9182 .01791 L
.9185 .01685 L
.91878 .01578 L
.91893 .01516 L
.91902 .01481 L
.9191 .01494 L
.91925 .01551 L
.9194 .0161 L
.91991 .01797 L
.92018 .01881 L
.92047 .01956 L
.92062 .01989 L
.92078 .02019 L
.92093 .02041 L
.92107 .02056 L
.92122 .02066 L
.92135 .02071 L
.9215 .02071 L
.92164 .02066 L
.92178 .02056 L
.92193 .02039 L
.92207 .02018 L
.9222 .01995 L
.92252 .01923 L
.92282 .01837 L
.92313 .01732 L
.92346 .01608 L
.92362 .01545 L
.92377 .01485 L
.92391 .01512 L
.92406 .01569 L
.92458 .01762 L
.92512 .01928 L
.92541 .01993 L
.92558 .02022 L
.92573 .02043 L
.92587 .02057 L
.926 .02065 L
.92614 .0207 L
.92628 .02069 L
.92642 .02063 L
.92657 .02051 L
.92671 .02035 L
.92684 .02016 L
.92714 .01957 L
Mistroke
.92745 .01874 L
.92776 .01776 L
.92809 .01657 L
.92825 .01596 L
.92841 .01537 L
.92854 .01483 L
.92869 .01518 L
.92882 .01568 L
.92896 .01622 L
.92924 .01727 L
.92975 .01891 L
.93004 .01964 L
.9302 .01997 L
.93035 .02022 L
.93049 .02041 L
.93065 .02056 L
.93078 .02065 L
.93091 .02068 L
.93105 .02067 L
.9312 .0206 L
.93133 .0205 L
.93147 .02034 L
.93162 .02011 L
.93178 .01981 L
.93207 .01912 L
.93264 .01734 L
.93289 .01642 L
.93316 .01539 L
.93331 .0148 L
.9334 .01497 L
.93348 .01529 L
.93377 .01642 L
.93412 .01767 L
.93444 .01868 L
.93472 .01942 L
.93502 .02005 L
.93519 .02031 L
.93534 .02049 L
.93549 .0206 L
.93564 .02066 L
.93579 .02066 L
.93588 .02063 L
.93596 .02059 L
.93604 .02053 L
.93612 .02045 L
.93629 .02024 L
.93644 .02 L
.9366 .01968 L
.93689 .01897 L
.93754 .01685 L
Mistroke
.93771 .01621 L
.93789 .0155 L
.93798 .01517 L
.93807 .01482 L
.93815 .01491 L
.93823 .01524 L
.93883 .01748 L
.93915 .01852 L
.93949 .01945 L
.93966 .01981 L
.93981 .02009 L
.93996 .02031 L
.9401 .02047 L
.94023 .02057 L
.94037 .02064 L
.94051 .02065 L
.94066 .02061 L
.94082 .0205 L
.94096 .02035 L
.94112 .02012 L
.94129 .01981 L
.9416 .01908 L
.94189 .01825 L
.94217 .0173 L
.94247 .0162 L
.94273 .01522 L
.94287 .01478 L
.94301 .01531 L
.94363 .01762 L
.94399 .01873 L
.94431 .01956 L
.94445 .01986 L
.94461 .02014 L
.94476 .02035 L
.9449 .02049 L
.94504 .02059 L
.94513 .02062 L
.9452 .02064 L
.94536 .02062 L
.94545 .02058 L
.94553 .02053 L
.94568 .02038 L
.94583 .02019 L
.9461 .0197 L
.9464 .01899 L
.94672 .01804 L
.94724 .01617 L
.94739 .01562 L
.94754 .01503 L
.94769 .01497 L
Mistroke
.94782 .01549 L
.94845 .0178 L
.94877 .01879 L
.94912 .01966 L
.94927 .01996 L
.94944 .02023 L
.94958 .0204 L
.94973 .02054 L
.94988 .02061 L
.95003 .02063 L
.95018 .02058 L
.95032 .0205 L
.95047 .02034 L
.95062 .02014 L
.95089 .01964 L
.95118 .01892 L
.9515 .01796 L
.95202 .0161 L
.95217 .01555 L
.95232 .01495 L
.95247 .01504 L
.9526 .01556 L
.95323 .01785 L
.95355 .01883 L
.9539 .01968 L
.95405 .01998 L
.95422 .02024 L
.95437 .02042 L
.95451 .02054 L
.95466 .0206 L
.95481 .02062 L
.95496 .02057 L
.95509 .02048 L
.95525 .02032 L
.95539 .02012 L
.95566 .01961 L
.95595 .01888 L
.95627 .01793 L
.95679 .01607 L
.95694 .01552 L
.95709 .01492 L
.95724 .01507 L
.95737 .01559 L
.958 .01787 L
.95832 .01884 L
.95866 .01969 L
.95881 .01997 L
.95897 .02022 L
.95911 .0204 L
.95925 .02051 L
Mistroke
.9594 .02059 L
.95948 .02061 L
.95956 .02061 L
.95971 .02057 L
.95986 .02047 L
.96001 .02031 L
.96017 .02009 L
.96046 .01953 L
.96074 .01881 L
.961 .01802 L
.9616 .01591 L
.96174 .01536 L
.96189 .01475 L
.96198 .01502 L
.96207 .01534 L
.96223 .01595 L
.96278 .01794 L
.9633 .01941 L
.96356 .01995 L
.96371 .02019 L
.96384 .02036 L
.96399 .02049 L
.96415 .02058 L
.9643 .02061 L
.96444 .02058 L
.96459 .02049 L
.96473 .02036 L
.96486 .02019 L
.965 .01997 L
.96531 .01931 L
.9656 .01852 L
.96616 .01663 L
.96644 .01559 L
.96656 .01512 L
.96669 .01482 L
.96684 .0154 L
.967 .01599 L
.96733 .0172 L
.9679 .01899 L
.96822 .01975 L
.9684 .02007 L
.96856 .0203 L
.96872 .02046 L
.9688 .02053 L
.96888 .02057 L
.96903 .0206 L
.96918 .02058 L
.96932 .02051 L
.96947 .02038 L
.96963 .02018 L
Mistroke
.96977 .01994 L
.97003 .0194 L
.97031 .01867 L
.97094 .01658 L
.97109 .01602 L
.97125 .01542 L
.97138 .01489 L
.97153 .01511 L
.97167 .01565 L
.97182 .01621 L
.97209 .01719 L
.97239 .01822 L
.97269 .01906 L
.97295 .01968 L
.97309 .01995 L
.97324 .02018 L
.97337 .02036 L
.9735 .02048 L
.97362 .02055 L
.97374 .02059 L
.97389 .02059 L
.97403 .02054 L
.97419 .02042 L
.97428 .02032 L
.97436 .02022 L
.9747 .01962 L
.97502 .01883 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.310298 0.0954019 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02409 -12 -4.5 ]
[-0.0125 .02409 0 4.5 ]
[-0.0125 .11949 -12 -4.5 ]
[-0.0125 .11949 0 4.5 ]
[-0.0125 .2149 -12 -4.5 ]
[-0.0125 .2149 0 4.5 ]
[-0.0125 .3103 -6 -4.5 ]
[-0.0125 .3103 0 4.5 ]
[-0.0125 .4057 -6 -4.5 ]
[-0.0125 .4057 0 4.5 ]
[-0.0125 .5011 -6 -4.5 ]
[-0.0125 .5011 0 4.5 ]
[-0.0125 .5965 -6 -4.5 ]
[-0.0125 .5965 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02409 m
.00625 .02409 L
s
[(-3)] -0.0125 .02409 1 0 Mshowa
0 .11949 m
.00625 .11949 L
s
[(-2)] -0.0125 .11949 1 0 Mshowa
0 .2149 m
.00625 .2149 L
s
[(-1)] -0.0125 .2149 1 0 Mshowa
0 .3103 m
.00625 .3103 L
s
[(0)] -0.0125 .3103 1 0 Mshowa
0 .4057 m
.00625 .4057 L
s
[(1)] -0.0125 .4057 1 0 Mshowa
0 .5011 m
.00625 .5011 L
s
[(2)] -0.0125 .5011 1 0 Mshowa
0 .5965 m
.00625 .5965 L
s
[(3)] -0.0125 .5965 1 0 Mshowa
.125 Mabswid
0 .04317 m
.00375 .04317 L
s
0 .06225 m
.00375 .06225 L
s
0 .08133 m
.00375 .08133 L
s
0 .10041 m
.00375 .10041 L
s
0 .13857 m
.00375 .13857 L
s
0 .15765 m
.00375 .15765 L
s
0 .17674 m
.00375 .17674 L
s
0 .19582 m
.00375 .19582 L
s
0 .23398 m
.00375 .23398 L
s
0 .25306 m
.00375 .25306 L
s
0 .27214 m
.00375 .27214 L
s
0 .29122 m
.00375 .29122 L
s
0 .32938 m
.00375 .32938 L
s
0 .34846 m
.00375 .34846 L
s
0 .36754 m
.00375 .36754 L
s
0 .38662 m
.00375 .38662 L
s
0 .42478 m
.00375 .42478 L
s
0 .44386 m
.00375 .44386 L
s
0 .46294 m
.00375 .46294 L
s
0 .48202 m
.00375 .48202 L
s
0 .52018 m
.00375 .52018 L
s
0 .53926 m
.00375 .53926 L
s
0 .55834 m
.00375 .55834 L
s
0 .57742 m
.00375 .57742 L
s
0 .00501 m
.00375 .00501 L
s
0 .61558 m
.00375 .61558 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02409 m
1 .02409 L
s
.99375 .11949 m
1 .11949 L
s
.99375 .2149 m
1 .2149 L
s
.99375 .3103 m
1 .3103 L
s
.99375 .4057 m
1 .4057 L
s
.99375 .5011 m
1 .5011 L
s
.99375 .5965 m
1 .5965 L
s
.125 Mabswid
.99625 .04317 m
1 .04317 L
s
.99625 .06225 m
1 .06225 L
s
.99625 .08133 m
1 .08133 L
s
.99625 .10041 m
1 .10041 L
s
.99625 .13857 m
1 .13857 L
s
.99625 .15765 m
1 .15765 L
s
.99625 .17674 m
1 .17674 L
s
.99625 .19582 m
1 .19582 L
s
.99625 .23398 m
1 .23398 L
s
.99625 .25306 m
1 .25306 L
s
.99625 .27214 m
1 .27214 L
s
.99625 .29122 m
1 .29122 L
s
.99625 .32938 m
1 .32938 L
s
.99625 .34846 m
1 .34846 L
s
.99625 .36754 m
1 .36754 L
s
.99625 .38662 m
1 .38662 L
s
.99625 .42478 m
1 .42478 L
s
.99625 .44386 m
1 .44386 L
s
.99625 .46294 m
1 .46294 L
s
.99625 .48202 m
1 .48202 L
s
.99625 .52018 m
1 .52018 L
s
.99625 .53926 m
1 .53926 L
s
.99625 .55834 m
1 .55834 L
s
.99625 .57742 m
1 .57742 L
s
.99625 .00501 m
1 .00501 L
s
.99625 .61558 m
1 .61558 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .3103 m
1 .3103 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .46015 m
.02608 .31818 L
.02723 .24586 L
.02787 .2061 L
.02818 .18655 L
.02832 .17796 L
.02847 .16851 L
.02862 .45864 L
.02871 .4534 L
.02878 .44849 L
.02913 .42707 L
.02972 .38963 L
.03089 .31642 L
.03217 .23632 L
.03254 .21325 L
.03289 .19132 L
.03305 .18179 L
.03321 .17164 L
.0333 .16579 L
.03339 .46021 L
.03347 .45488 L
.03355 .44987 L
.03473 .37616 L
.03597 .2983 L
.03703 .23182 L
.03733 .21361 L
.03764 .19409 L
.03779 .18462 L
.03793 .17566 L
.03806 .16761 L
.0382 .45857 L
.03835 .44938 L
.03848 .44096 L
.03878 .42197 L
.03933 .38762 L
.04058 .3093 L
.04182 .23205 L
.04244 .1932 L
.04261 .18256 L
.0427 .17671 L
.04279 .17119 L
.04287 .46576 L
.04296 .46018 L
.04312 .45043 L
.04552 .30039 L
.04672 .22475 L
.04706 .20402 L
.04724 .1926 L
.04741 .18176 L
.04749 .17689 L
Mistroke
.04757 .17171 L
.04766 .46573 L
.04775 .46046 L
.04805 .44126 L
.0493 .36341 L
.05064 .27932 L
.05126 .24068 L
.05159 .21959 L
.05191 .19992 L
.05218 .18311 L
.05233 .17369 L
.05247 .46483 L
.05262 .45544 L
.05278 .44523 L
.05307 .42668 L
.05546 .27712 L
.05604 .24077 L
.05667 .20164 L
.05684 .19071 L
.05694 .18476 L
.05703 .17922 L
.05718 .46913 L
.05727 .46394 L
.05736 .45841 L
.058 .41815 L
.05924 .34063 L
.06058 .25671 L
.06119 .21819 L
.06153 .19714 L
.06169 .18685 L
.06184 .17747 L
.06198 .46857 L
.06211 .46041 L
.0624 .44241 L
.06301 .40421 L
.06417 .33146 L
.06541 .25411 L
.06592 .22234 L
.06618 .20565 L
.06646 .18807 L
.06661 .17871 L
.0667 .47311 L
.06678 .46817 L
.06706 .45017 L
.06763 .41483 L
.0689 .33553 L
.07009 .26059 L
.07062 .22793 L
.0709 .21006 L
.07117 .19332 L
Mistroke
.07131 .18461 L
.07146 .47497 L
.07154 .46964 L
.07162 .46458 L
.07177 .45508 L
.07233 .42005 L
.07349 .34761 L
.07472 .27043 L
.07532 .23292 L
.07562 .21452 L
.07589 .1976 L
.07602 .18962 L
.07613 .18217 L
.07626 .47412 L
.07639 .4656 L
.07694 .43131 L
.0782 .35233 L
.0794 .27756 L
.07992 .245 L
.08047 .21043 L
.08076 .1924 L
.08084 .18746 L
.08092 .18214 L
.08108 .47223 L
.08122 .46331 L
.08137 .45393 L
.08164 .43716 L
.08279 .36504 L
.08402 .28803 L
.08462 .25063 L
.08518 .21535 L
.08543 .19996 L
.08556 .19154 L
.08569 .18367 L
.08582 .47488 L
.08597 .46552 L
.08624 .44906 L
.08749 .37042 L
.08868 .2958 L
.08975 .22882 L
.09005 .21047 L
.09021 .20041 L
.09036 .19094 L
.0905 .4818 L
.09065 .47223 L
.09092 .45556 L
.09333 .30464 L
.09455 .2287 L
.09488 .2079 L
.09506 .19645 L
Mistroke
.09515 .19083 L
.09523 .18563 L
.09531 .48046 L
.09539 .47527 L
.09557 .46433 L
.09587 .44521 L
.09701 .37422 L
.09823 .29782 L
.09882 .26086 L
.09938 .22571 L
.09963 .21044 L
.09976 .20205 L
.09989 .19415 L
.10004 .4845 L
.10017 .47601 L
.10044 .45942 L
.10161 .38576 L
.10286 .30793 L
.10392 .24148 L
.10421 .22327 L
.10437 .21325 L
.10452 .20375 L
.10466 .19492 L
.10482 .48503 L
.10495 .4763 L
.10508 .46822 L
.10733 .3274 L
.10795 .28882 L
.10862 .24722 L
.10892 .22809 L
.10924 .20794 L
.10938 .19963 L
.10952 .19074 L
.10967 .4807 L
.10982 .47163 L
.11105 .39436 L
.11239 .31057 L
.11301 .27215 L
.11366 .23145 L
.11392 .21471 L
.11407 .20548 L
.11421 .19671 L
.11429 .49149 L
.11438 .48611 L
.11453 .47668 L
.11482 .45819 L
.1172 .30947 L
.11788 .26666 L
.11822 .24566 L
.11853 .22636 L
Mistroke
.11881 .20876 L
.11895 .1999 L
.1191 .4899 L
.11926 .48013 L
.11943 .46967 L
.11973 .4508 L
.12096 .37386 L
.12229 .29024 L
.12291 .25193 L
.12324 .23095 L
.1234 .22068 L
.12356 .21128 L
.12369 .20313 L
.12382 .49428 L
.12396 .48568 L
.12411 .47628 L
.12472 .43801 L
.12709 .28976 L
.12777 .24708 L
.12811 .22612 L
.12825 .21693 L
.12842 .20682 L
.12856 .19774 L
.1287 .48897 L
.12884 .48001 L
.12899 .47039 L
.12962 .43125 L
.13084 .35463 L
.13149 .3142 L
.13218 .27119 L
.13277 .23375 L
.13294 .2235 L
.13311 .21243 L
.1332 .20734 L
.13328 .20197 L
.13343 .4921 L
.13357 .48338 L
.13372 .47406 L
.13399 .45726 L
.1346 .4191 L
.13583 .34196 L
.13648 .30132 L
.13717 .25824 L
.13746 .24011 L
.13777 .22061 L
.13786 .21489 L
.13795 .20944 L
.13803 .20455 L
.13811 .49893 L
.13819 .4939 L
Mistroke
.13828 .48854 L
.13843 .47889 L
.1396 .40592 L
.14084 .32825 L
.14149 .28741 L
.14218 .24426 L
.14247 .22601 L
.14264 .21596 L
.14279 .20645 L
.14287 .50078 L
.14297 .49493 L
.14313 .4847 L
.14345 .46466 L
.14462 .39171 L
.14585 .3147 L
.147 .24241 L
.14728 .22473 L
.14744 .21509 L
.14758 .20613 L
.14774 .4961 L
.14782 .49094 L
.14791 .48544 L
.14821 .46674 L
.14954 .38354 L
.15077 .3062 L
.15142 .26548 L
.15178 .24321 L
.15195 .23232 L
.15211 .22238 L
.15226 .21305 L
.1524 .50392 L
.15255 .49458 L
.15271 .48439 L
.15338 .44294 L
.15454 .36997 L
.15577 .29328 L
.15637 .25569 L
.15663 .23921 L
.15692 .22115 L
.157 .21628 L
.15708 .21108 L
.15723 .50141 L
.15732 .49589 L
.1574 .49067 L
.15756 .48089 L
.15825 .43772 L
.15945 .36245 L
.16062 .28936 L
.16126 .24934 L
.16157 .22976 L
Mistroke
.16171 .22119 L
.16186 .21183 L
.16199 .50307 L
.16212 .49521 L
.16237 .47967 L
.16291 .44535 L
.16408 .3724 L
.16535 .29274 L
.16598 .25364 L
.16625 .23649 L
.1664 .2274 L
.16655 .21765 L
.16669 .5085 L
.16682 .50042 L
.16708 .48459 L
.16763 .44994 L
.1688 .37696 L
.16991 .3072 L
.17052 .26897 L
.1711 .23305 L
.17124 .224 L
.17139 .21446 L
.17147 .50918 L
.17156 .50371 L
.17171 .49411 L
.1724 .45142 L
.1736 .37612 L
.17481 .30008 L
.17541 .26272 L
.17567 .24631 L
.17596 .22825 L
.17612 .21829 L
.17627 .50867 L
.17643 .49883 L
.1766 .48824 L
.17728 .44516 L
.17849 .36988 L
.17971 .29352 L
.18004 .27259 L
.1804 .2503 L
.18057 .23947 L
.18073 .22927 L
.18088 .22011 L
.18104 .50993 L
.18119 .50044 L
.18133 .49159 L
.18165 .47149 L
.1823 .4309 L
.18346 .35825 L
.18407 .3204 L
Mistroke
.18472 .27926 L
.18503 .26041 L
.18535 .24041 L
.18548 .23218 L
.18562 .22333 L
.18577 .51332 L
.18592 .5042 L
.18816 .3641 L
.18931 .29176 L
.18963 .27194 L
.18997 .25079 L
.19013 .24051 L
.19029 .23082 L
.19043 .22212 L
.19058 .5124 L
.19074 .50248 L
.19088 .49321 L
.19122 .47212 L
.1919 .4295 L
.19312 .35311 L
.19372 .31546 L
.19438 .27445 L
.19468 .25569 L
.19484 .2454 L
.195 .23572 L
.19514 .22666 L
.1953 .5166 L
.19544 .50771 L
.19557 .49955 L
.19781 .3596 L
.19838 .32396 L
.19899 .28583 L
.19928 .26733 L
.19956 .24984 L
.19981 .23414 L
.19996 .22528 L
.20009 .51681 L
.20023 .50784 L
.20038 .49819 L
.20066 .48075 L
.2013 .44103 L
.20258 .3607 L
.2038 .28446 L
.20413 .26357 L
.20432 .2521 L
.20449 .2413 L
.20465 .2312 L
.20474 .22552 L
.20482 .52 L
.20497 .51073 L
Mistroke
.20513 .50094 L
.2063 .42777 L
.20755 .34933 L
.20819 .30953 L
.20879 .27182 L
.20905 .25541 L
.20933 .23798 L
.20948 .22888 L
.20956 .52342 L
.20964 .51856 L
.20992 .50086 L
.21213 .36251 L
.21332 .28833 L
.21391 .25103 L
.21408 .24081 L
.21417 .2352 L
.21425 .2299 L
.21433 .52467 L
.21442 .51931 L
.21456 .50994 L
.2168 .3703 L
.21794 .29889 L
.21825 .27933 L
.21859 .25831 L
.21875 .24813 L
.2189 .23846 L
.21904 .22979 L
.21919 .52004 L
.21928 .51486 L
.21937 .50926 L
.21953 .4991 L
.21983 .48014 L
.22051 .43765 L
.22173 .36125 L
.22288 .28935 L
.22319 .26965 L
.22337 .25881 L
.22353 .24856 L
.22368 .23902 L
.22377 .23363 L
.22385 .52836 L
.22399 .51957 L
.22414 .51023 L
.22536 .43364 L
.22668 .35118 L
.22728 .31373 L
.22791 .27434 L
.22817 .25808 L
.22831 .24914 L
.22845 .24072 L
Mistroke
.22852 .23592 L
.22861 .53045 L
.22875 .52139 L
.22903 .50369 L
.23124 .36566 L
.23238 .29407 L
.2327 .27445 L
.23287 .26365 L
.23303 .25341 L
.23319 .2439 L
.23327 .23852 L
.23335 .53325 L
.23349 .52447 L
.23364 .51512 L
.23486 .4387 L
.23618 .35624 L
.23678 .31899 L
.2374 .27974 L
.23766 .26354 L
.2378 .25463 L
.23794 .24622 L
.2381 .53598 L
.23824 .52693 L
.23853 .50924 L
.24073 .37137 L
.2419 .29815 L
.24249 .26123 L
.24265 .25111 L
.24274 .24553 L
.24283 .24023 L
.2429 .53503 L
.24299 .52967 L
.24314 .52028 L
.24536 .38111 L
.24601 .34098 L
.24661 .30319 L
.24715 .26927 L
.2473 .25997 L
.24746 .25015 L
.24759 .24177 L
.24774 .53229 L
.24782 .5272 L
.24791 .52167 L
.24807 .51162 L
.24837 .49277 L
.24905 .45042 L
.25027 .37402 L
.2514 .30304 L
.25171 .28359 L
.25205 .26264 L
Mistroke
.2522 .253 L
.25229 .24775 L
.25236 .24286 L
.2525 .53391 L
.25265 .52444 L
.25396 .44287 L
.25519 .3659 L
.25637 .29178 L
.2567 .27147 L
.25687 .26037 L
.25696 .25494 L
.25704 .24998 L
.25718 .54085 L
.25733 .53135 L
.25766 .51117 L
.2599 .3709 L
.26048 .33479 L
.26109 .29637 L
.26139 .27768 L
.26154 .26852 L
.26167 .26011 L
.26179 .25243 L
.26192 .54404 L
.26205 .53591 L
.26219 .527 L
.2635 .44508 L
.2647 .37051 L
.26528 .33415 L
.26591 .29467 L
.2662 .27657 L
.26636 .26667 L
.2665 .25738 L
.26663 .24949 L
.26677 .54071 L
.26692 .53128 L
.26705 .52266 L
.26836 .44078 L
.26958 .36473 L
.27069 .29547 L
.27101 .27552 L
.27116 .26574 L
.27131 .25673 L
.27144 .54824 L
.27158 .53957 L
.27187 .52131 L
.27307 .44589 L
.27437 .365 L
.275 .32525 L
.2756 .28757 L
.27587 .27118 L
Mistroke
.27601 .26219 L
.27614 .25375 L
.27629 .54438 L
.27637 .53956 L
.27645 .53435 L
.27673 .51666 L
.27894 .37838 L
.2801 .30624 L
.28041 .28648 L
.28059 .27561 L
.28075 .26535 L
.2809 .25579 L
.28099 .55011 L
.28107 .54513 L
.28136 .52701 L
.28267 .44481 L
.2839 .36788 L
.28499 .2997 L
.28531 .28007 L
.28546 .27039 L
.28561 .26142 L
.28573 .55303 L
.28587 .5444 L
.28616 .52614 L
.28865 .37049 L
.28926 .33268 L
.2899 .29277 L
.29023 .27189 L
.29032 .26617 L
.29042 .26005 L
.29051 .55398 L
.2906 .54871 L
.29124 .50848 L
.2925 .42939 L
.29367 .35628 L
.29425 .3202 L
.29479 .28635 L
.29506 .26936 L
.29521 .25981 L
.29535 .55077 L
.2955 .54171 L
.29566 .5318 L
.29598 .51185 L
.29729 .42973 L
.29848 .35519 L
.29907 .3186 L
.29938 .29934 L
.2997 .27897 L
.29984 .27037 L
.29999 .26114 L
Mistroke
.30007 .55556 L
.30015 .55073 L
.3003 .54127 L
.30085 .5068 L
.30216 .42473 L
.30338 .34872 L
.30395 .31283 L
.30449 .2791 L
.30462 .27086 L
.30476 .26218 L
.30491 .55238 L
.30505 .54364 L
.30568 .50476 L
.30688 .42916 L
.30818 .3483 L
.30882 .3083 L
.30913 .28864 L
.30927 .28 L
.30942 .27049 L
.30956 .56169 L
.30969 .55372 L
.30996 .53626 L
.31055 .49941 L
.31277 .36099 L
.31337 .32356 L
.31368 .30379 L
.31386 .29293 L
.31402 .28271 L
.31418 .27298 L
.31426 .26751 L
.31434 .56218 L
.31449 .55326 L
.31464 .54383 L
.31521 .50801 L
.31744 .36831 L
.31803 .33161 L
.31859 .29684 L
.31874 .28753 L
.31889 .27764 L
.31898 .27248 L
.31907 .56651 L
.31915 .56133 L
.31923 .55647 L
.31981 .51993 L
.32202 .38169 L
.32321 .30755 L
.3235 .28952 L
.32366 .27962 L
.32381 .27027 L
.32389 .56467 L
Mistroke
.32398 .55891 L
.32414 .54886 L
.32446 .52921 L
.32669 .38968 L
.32783 .31832 L
.32814 .29876 L
.32832 .28799 L
.3284 .28268 L
.32848 .27776 L
.32863 .56799 L
.32871 .56298 L
.3288 .55765 L
.32909 .53953 L
.33163 .38088 L
.33223 .34305 L
.33287 .30313 L
.33303 .29305 L
.3332 .28225 L
.3333 .27605 L
.33339 .57012 L
.33348 .56445 L
.33357 .55908 L
.33421 .51886 L
.33539 .44504 L
.33665 .36672 L
.3372 .33227 L
.33749 .31419 L
.33779 .29518 L
.33795 .28503 L
.33805 .27928 L
.33813 .57365 L
.33828 .56424 L
.33844 .5542 L
.33905 .51604 L
.34128 .3771 L
.34188 .33947 L
.34251 .29969 L
.34268 .28966 L
.34276 .28414 L
.34285 .2789 L
.34295 .57244 L
.34304 .56681 L
.34321 .55578 L
.34386 .51561 L
.34503 .44195 L
.34629 .36364 L
.34684 .32938 L
.34712 .31139 L
.34743 .29243 L
.34751 .28755 L
Mistroke
.34759 .28233 L
.34768 .57632 L
.34777 .57099 L
.34808 .55158 L
.34869 .51348 L
.35091 .37472 L
.35151 .3373 L
.35183 .31683 L
.35214 .29765 L
.35222 .29254 L
.3523 .28768 L
.35239 .58179 L
.35247 .57667 L
.35284 .55388 L
.35348 .51376 L
.35465 .44027 L
.35591 .36197 L
.35622 .34258 L
.35655 .32162 L
.35671 .31199 L
.35687 .30182 L
.35701 .29314 L
.35716 .58334 L
.35731 .57406 L
.35745 .56561 L
.35775 .54661 L
.3583 .51234 L
.36052 .37378 L
.3611 .33751 L
.36142 .31765 L
.36157 .30792 L
.36171 .29901 L
.36184 .2913 L
.36197 .5829 L
.3621 .57476 L
.36224 .56585 L
.36282 .5296 L
.36413 .44762 L
.36533 .37317 L
.36591 .33666 L
.36622 .31744 L
.36639 .30693 L
.36654 .29711 L
.36668 .58824 L
.36683 .57903 L
.36714 .55947 L
.36769 .52506 L
.369 .44314 L
.37022 .36723 L
.37081 .33023 L
Mistroke
.37098 .31958 L
.37114 .30956 L
.37129 .30057 L
.37144 .59057 L
.37153 .58535 L
.3716 .58049 L
.37178 .56946 L
.37214 .54719 L
.37278 .50736 L
.37394 .43477 L
.3752 .35596 L
.37552 .33603 L
.37586 .3149 L
.376 .30621 L
.37615 .29686 L
.37623 .59121 L
.37631 .58631 L
.37647 .57669 L
.37766 .50202 L
.37875 .43435 L
.3799 .3622 L
.38022 .3422 L
.38052 .32335 L
.3808 .30643 L
.38095 .2969 L
.38109 .58784 L
.38122 .57959 L
.38134 .5719 L
.38162 .5544 L
.38219 .51906 L
.38347 .43898 L
.38411 .39958 L
.38469 .36311 L
.38526 .32756 L
.38555 .30961 L
.38563 .30469 L
.38571 .29939 L
.38587 .5895 L
.38602 .57982 L
.38619 .56923 L
.38653 .54789 L
.38714 .50973 L
.38829 .43792 L
.38938 .37012 L
.38998 .33305 L
.39014 .3229 L
.39031 .31214 L
.39046 .30296 L
.39054 .59746 L
.39062 .59257 L
Mistroke
.39175 .52236 L
.39304 .44154 L
.39368 .40172 L
.39427 .36479 L
.39484 .32946 L
.395 .31929 L
.39516 .30971 L
.39529 .60083 L
.39544 .59154 L
.39672 .51199 L
.39787 .43988 L
.39895 .37263 L
.39951 .33804 L
.39967 .32808 L
.39982 .31866 L
.39995 .3102 L
.4001 .60072 L
.40025 .59131 L
.40042 .58093 L
.40076 .55992 L
.40136 .52221 L
.4039 .3638 L
.40644 .20594 L
.40755 .13687 L
.40813 .10036 L
.40876 .0614 L
.40908 .04157 L
.40923 .03184 L
.40938 .02287 L
.40951 .01472 L
.40965 .3058 L
.40978 .29714 L
.40994 .28762 L
.41103 .21933 L
.41229 .14138 L
.41343 .07025 L
.41371 .05284 L
.41401 .03432 L
.41416 .02467 L
.41425 .01917 L
.41433 .31372 L
.41448 .30467 L
.41463 .2949 L
.41578 .22373 L
.41698 .14885 L
.41762 .10923 L
.4183 .06686 L
.41863 .04593 L
.4188 .03564 L
.41895 .02615 L
Mistroke
.41909 .31724 L
.41924 .30811 L
.41955 .28884 L
.42071 .21646 L
.42194 .14025 L
.42261 .09823 L
.42295 .07752 L
.42325 .0583 L
.42354 .04059 L
.4237 .03068 L
.42384 .32142 L
.424 .31154 L
.42417 .30086 L
.42449 .28149 L
.42561 .21151 L
.42675 .14056 L
.42782 .07435 L
.4281 .05669 L
.42837 .03996 L
.42852 .03073 L
.42861 .32522 L
.42868 .3204 L
.42897 .30282 L
.43022 .22466 L
.43154 .14329 L
.43218 .10345 L
.43277 .06693 L
.43304 .04995 L
.43317 .04168 L
.43329 .03416 L
.43342 .32591 L
.43356 .3174 L
.43385 .29939 L
.43502 .22692 L
.43631 .14672 L
.43688 .11152 L
.4375 .07282 L
.43778 .05545 L
.43794 .04589 L
.43808 .0368 L
.43822 .32809 L
.43837 .31891 L
.43863 .30283 L
.43982 .22908 L
.44113 .14753 L
.44176 .10905 L
.44233 .07372 L
.44261 .05597 L
.44276 .04704 L
.44291 .33696 L
Mistroke
.44307 .32711 L
.44324 .31657 L
.44355 .29757 L
.4447 .22625 L
.44602 .14487 L
.4466 .10911 L
.44693 .08878 L
.44724 .06972 L
.44738 .06061 L
.44752 .05194 L
.4476 .04717 L
.44768 .34166 L
.44783 .33252 L
.44847 .29338 L
.4498 .21081 L
.45108 .13221 L
.45168 .09509 L
.45194 .07881 L
.45209 .06957 L
.45223 .06093 L
.45237 .05245 L
.45252 .34307 L
.45267 .33336 L
.45282 .3245 L
.45345 .28538 L
.4546 .21448 L
.45591 .13358 L
.45649 .09802 L
.4568 .07912 L
.45696 .0692 L
.45705 .06379 L
.45713 .05875 L
.45727 .34965 L
.45743 .34001 L
.45771 .32309 L
.45825 .28987 L
.45943 .21701 L
.46064 .14266 L
.46099 .12127 L
.46132 .10106 L
.46161 .08293 L
.46169 .07796 L
.46178 .07269 L
.46193 .36297 L
.46208 .35403 L
.46224 .34428 L
.46253 .32653 L
.46307 .29322 L
.46429 .2183 L
.46543 .14863 L
Mistroke
.46599 .11447 L
.46623 .0995 L
.4665 .08309 L
.46665 .07387 L
.46679 .36498 L
.46694 .35589 L
.4671 .34616 L
.46775 .30658 L
.46888 .23758 L
.47019 .15731 L
.47077 .12205 L
.4711 .10199 L
.47126 .09217 L
.47141 .08318 L
.47155 .37437 L
.47169 .3654 L
.472 .34657 L
.47263 .30803 L
.47397 .22675 L
.47513 .15624 L
.47545 .13694 L
.47579 .11634 L
.47595 .10634 L
.47611 .09691 L
.47625 .38815 L
.4764 .37898 L
.4788 .23351 L
.48001 .16033 L
.48034 .1403 L
.48052 .12926 L
.48069 .1188 L
.48085 .10908 L
.48095 .10359 L
.48103 .39822 L
.48118 .38925 L
.48134 .37971 L
.48258 .30453 L
.48393 .22349 L
.48454 .18627 L
.48488 .16597 L
.4852 .14707 L
.48546 .1309 L
.48561 .12185 L
.48575 .41332 L
.4859 .40429 L
.48607 .39449 L
.48636 .3767 L
.48875 .23309 L
.48933 .19823 L
.48996 .16075 L
Mistroke
.49014 .14974 L
.49032 .13928 L
.49048 .12989 L
.49056 .42429 L
.49065 .41936 L
.49129 .38087 L
.49256 .30464 L
.49376 .23287 L
.49429 .20156 L
.49484 .16848 L
.49498 .16014 L
.49513 .15119 L
.49522 .14606 L
.4953 .44109 L
.49545 .43193 L
.49601 .39858 L
.49831 .26125 L
.49894 .22363 L
.49929 .20302 L
.49961 .18368 L
.49974 .17568 L
.49989 .16726 L
.50004 .45774 L
.50018 .44928 L
.50081 .41162 L
.50196 .34296 L
.50319 .2696 L
.50379 .23397 L
.50408 .21647 L
.50435 .20033 L
.5046 .18566 L
.50472 .17826 L
.50486 .46983 L
.505 .46168 L
.50514 .45291 L
.50541 .43708 L
.50663 .36408 L
.50796 .28445 L
.50857 .248 L
.50891 .228 L
.50922 .20917 L
.50936 .2006 L
.50952 .19156 L
.50959 .48654 L
.50968 .48135 L
.50983 .47223 L
.51039 .43903 L
.51274 .29761 L
.51342 .25684 L
.51376 .23678 L
Mistroke
.5139 .22796 L
.51407 .21824 L
.51421 .20956 L
.51435 .50113 L
.51449 .49254 L
.51464 .48328 L
.51527 .44559 L
.51769 .29966 L
.51828 .26413 L
.5186 .24461 L
.51876 .23503 L
.51891 .2262 L
.51899 .22111 L
.51908 .51544 L
.51917 .51003 L
.51927 .50409 L
.5196 .48428 L
.52024 .44556 L
.52144 .37255 L
.52259 .30325 L
.52322 .26498 L
.52339 .25449 L
.52357 .24333 L
.52373 .23381 L
.52382 .52809 L
.5239 .52299 L
.52511 .44993 L
.52629 .37796 L
.52694 .33866 L
.52754 .30204 L
.52805 .27069 L
.5282 .26166 L
.52834 .25313 L
.52847 .24547 L
.5286 .53687 L
.52874 .52832 L
.5289 .51892 L
.52921 .4999 L
.52977 .46576 L
.53097 .39244 L
.53211 .32271 L
.53274 .28424 L
.53291 .2737 L
.5331 .26246 L
.53319 .257 L
.53327 .25186 L
.53343 .54196 L
.53357 .533 L
.53373 .52354 L
.53401 .50659 L
Mistroke
.53463 .46832 L
.53577 .39822 L
.5364 .35962 L
.537 .32306 L
.53755 .28905 L
.53771 .27973 L
.53787 .26983 L
.53801 .26138 L
.53816 .55177 L
.53829 .54338 L
.53842 .5357 L
.5387 .51837 L
.53921 .48702 L
.5415 .34665 L
.54212 .30816 L
.54247 .28701 L
.54263 .27662 L
.54279 .26705 L
.54294 .55771 L
.54309 .54814 L
.54342 .52795 L
.54399 .49269 L
.54513 .42252 L
.54636 .34713 L
.54695 .3106 L
.54724 .2926 L
.54738 .28385 L
.54751 .27593 L
.54764 .56787 L
.54775 .56056 L
.54801 .54451 L
.54856 .51058 L
.54975 .43764 L
.55099 .36068 L
.55151 .32892 L
.55206 .29494 L
.55222 .2849 L
.55237 .27541 L
.55251 .56661 L
.55266 .55736 L
.55322 .52259 L
.55561 .37471 L
.55619 .33875 L
.55652 .31892 L
.55682 .30005 L
.55699 .28945 L
.55709 .28345 L
.55718 .57759 L
.55734 .56776 L
.55751 .55729 L
Mistroke
.55815 .51747 L
.55939 .4407 L
.56004 .4003 L
.56073 .3576 L
.56133 .32019 L
.5615 .30994 L
.56168 .29894 L
.56176 .29362 L
.56184 .28857 L
.562 .57882 L
.56214 .5701 L
.56229 .56085 L
.56255 .54421 L
.56316 .50655 L
.56429 .43652 L
.56551 .36099 L
.56607 .32625 L
.56637 .30729 L
.56652 .29805 L
.56666 .28965 L
.56678 .5816 L
.5669 .57426 L
.56716 .55812 L
.56771 .52392 L
.56889 .4512 L
.57013 .37415 L
.57064 .34244 L
.57092 .32496 L
.57119 .30836 L
.57134 .29902 L
.57142 .29373 L
.5715 .58854 L
.57164 .57989 L
.57179 .57067 L
.57235 .53567 L
.57359 .45845 L
.57425 .41784 L
.57494 .37498 L
.57554 .33739 L
.57571 .32709 L
.57588 .31606 L
.57597 .31071 L
.57605 .30564 L
.5762 .59587 L
.57635 .58712 L
.5765 .57783 L
.57676 .56115 L
.57737 .52341 L
.5785 .453 L
.57972 .37716 L
Mistroke
.58028 .34226 L
.58059 .32323 L
.58074 .31396 L
.58087 .30555 L
.581 .59746 L
.58112 .5901 L
.58138 .57391 L
.58193 .53966 L
.5831 .46656 L
.58435 .38924 L
.58486 .35739 L
.58514 .33985 L
.58541 .32321 L
.58556 .31383 L
.58564 .30852 L
.58572 .60332 L
.58586 .59465 L
.58601 .58542 L
.58657 .55036 L
.5877 .48017 L
.58892 .40441 L
.58947 .36959 L
.58978 .35058 L
.59006 .33288 L
.59031 .31773 L
.59044 .30925 L
.59057 .60124 L
.5907 .59278 L
.59085 .5836 L
.59112 .56691 L
.59346 .42078 L
.59605 .25981 L
.59723 .18623 L
.5985 .10707 L
.59911 .06876 L
.59942 .04987 L
.5997 .03234 L
.59983 .02419 L
.59995 .01652 L
.60009 .30739 L
.60022 .29937 L
.60079 .26369 L
.60197 .19026 L
.60322 .11268 L
.60373 .08072 L
.60428 .04645 L
.60444 .03635 L
.60459 .02678 L
.60473 .01819 L
.60488 .30856 L
Mistroke
.60502 .29972 L
.60517 .29033 L
.60544 .27347 L
.60658 .20297 L
.60779 .12698 L
.60835 .09203 L
.60894 .05523 L
.60919 .04004 L
.60932 .0317 L
.60945 .02382 L
.6096 .3142 L
.60973 .30573 L
.61 .28917 L
.61117 .21601 L
.61241 .13856 L
.61347 .07243 L
.61376 .05431 L
.61392 .04433 L
.61407 .03485 L
.61422 .02606 L
.61437 .31619 L
.61451 .30748 L
.61464 .29941 L
.61592 .21965 L
.61712 .14462 L
.6182 .07725 L
.61849 .05879 L
.61866 .04871 L
.61881 .03932 L
.61893 .03129 L
.61907 .32241 L
.61923 .31287 L
.61936 .30418 L
.62167 .1602 L
.6223 .12075 L
.62297 .0789 L
.62325 .06169 L
.62355 .04317 L
.62363 .038 L
.62372 .03256 L
.62387 .32256 L
.62402 .31345 L
.62418 .3035 L
.62655 .15552 L
.62723 .11292 L
.62787 .07275 L
.62815 .05522 L
.62831 .04564 L
.62845 .03669 L
.62861 .32672 L
Mistroke
.62869 .32158 L
.62878 .31608 L
.62908 .29736 L
.6303 .22085 L
.63163 .13756 L
.63225 .09943 L
.63258 .07853 L
.63289 .0589 L
.63316 .04225 L
.63331 .03288 L
.63345 .324 L
.63359 .31512 L
.63375 .30539 L
.63406 .28578 L
.63642 .13821 L
.6371 .09572 L
.63744 .07485 L
.63775 .05558 L
.63789 .04654 L
.63803 .03808 L
.63817 .32897 L
.63832 .31926 L
.63895 .28016 L
.6402 .20186 L
.64139 .12748 L
.64191 .09515 L
.64246 .06071 L
.64263 .0505 L
.64278 .04089 L
.64292 .33197 L
.64307 .32264 L
.64363 .28758 L
.64604 .13721 L
.64662 .10065 L
.64725 .06149 L
.64743 .04994 L
.64752 .04426 L
.64761 .03901 L
.64776 .32891 L
.64785 .32373 L
.64793 .31824 L
.64858 .27815 L
.64971 .20745 L
.65093 .13128 L
.65149 .09623 L
.65179 .07713 L
.65208 .05937 L
.6522 .05153 L
.65232 .04414 L
.65246 .33533 L
Mistroke
.65258 .3276 L
.65313 .29319 L
.65431 .21983 L
.65555 .14221 L
.65606 .11025 L
.65661 .07594 L
.65677 .06584 L
.65692 .05626 L
.65706 .04765 L
.65721 .338 L
.65735 .32915 L
.6575 .31973 L
.65777 .3028 L
.65902 .22497 L
.66036 .14095 L
.66098 .10234 L
.66132 .08126 L
.66163 .06163 L
.66177 .05299 L
.6619 .04483 L
.66205 .33514 L
.66219 .32658 L
.6628 .2885 L
.66397 .21544 L
.66521 .13797 L
.66572 .10611 L
.66627 .07183 L
.66643 .06176 L
.66658 .05219 L
.66672 .34331 L
.66687 .33393 L
.66743 .29868 L
.6698 .15041 L
.67049 .10772 L
.67082 .08677 L
.67113 .0675 L
.67127 .05841 L
.67141 .04993 L
.67155 .3408 L
.67171 .33109 L
.67233 .29202 L
.67359 .21325 L
.67479 .13861 L
.67531 .10613 L
.67586 .07161 L
.676 .06295 L
.67615 .05361 L
.67623 .34798 L
.67631 .34308 L
.67646 .33346 L
Mistroke
.67702 .29843 L
.67931 .15577 L
.67993 .11669 L
.68027 .09521 L
.6806 .07493 L
.68075 .06575 L
.6809 .05602 L
.68098 .35066 L
.68107 .34507 L
.68123 .33523 L
.6818 .29941 L
.68415 .1528 L
.68482 .11058 L
.68515 .08978 L
.68532 .07966 L
.68546 .07049 L
.68561 .06151 L
.68574 .35278 L
.68588 .34386 L
.68604 .33422 L
.68667 .29498 L
.68908 .14437 L
.68966 .10775 L
.68998 .08761 L
.69029 .06855 L
.69037 .06331 L
.69046 .05776 L
.69056 .35138 L
.69065 .34575 L
.69098 .32525 L
.69162 .28514 L
.69275 .2143 L
.69397 .13803 L
.69453 .10294 L
.69484 .08381 L
.69499 .07449 L
.69512 .06603 L
.69525 .3579 L
.69536 .3505 L
.69562 .33423 L
.69618 .2998 L
.69735 .22631 L
.69859 .14859 L
.69911 .11658 L
.69965 .08224 L
.69982 .07213 L
.69997 .06254 L
.70011 .35364 L
.70026 .34427 L
.70082 .30905 L
Mistroke
.7032 .16012 L
.70378 .12393 L
.7044 .08487 L
.70458 .07399 L
.70467 .06805 L
.70476 .06253 L
.70492 .35245 L
.705 .34727 L
.70509 .34173 L
.70573 .30145 L
.70697 .22434 L
.70762 .18372 L
.7083 .14067 L
.70891 .10306 L
.70907 .09276 L
.70925 .08168 L
.70933 .07632 L
.70941 .07122 L
.70957 .36137 L
.70971 .35261 L
.70986 .34328 L
.71013 .32649 L
.71073 .28844 L
.71198 .2108 L
.71263 .16997 L
.71332 .12685 L
.71392 .08905 L
.71409 .0787 L
.71418 .073 L
.71426 .0676 L
.71434 .3623 L
.71443 .35684 L
.71458 .34729 L
.71575 .27438 L
.71698 .19739 L
.71814 .12514 L
.71872 .08887 L
.71888 .07893 L
.71896 .07352 L
.71904 .06848 L
.71919 .35926 L
.71934 .3495 L
.72067 .26635 L
.72194 .18691 L
.72256 .1479 L
.72314 .11194 L
.72341 .09505 L
.72366 .07924 L
.72379 .07129 L
.72393 .36247 L
Mistroke
.72408 .353 L
.72422 .34435 L
.72538 .2714 L
.72649 .20184 L
.72768 .12781 L
.72803 .10585 L
.7282 .09508 L
.72836 .08519 L
.7285 .07616 L
.72865 .36635 L
.72881 .35679 L
.72897 .34632 L
.73018 .27105 L
.73139 .19521 L
.73254 .12349 L
.73284 .10426 L
.73301 .09373 L
.73317 .08386 L
.73325 .07873 L
.73334 .37293 L
.73344 .36681 L
.73353 .3612 L
.73386 .34054 L
.73506 .26528 L
.73617 .19602 L
.73735 .12215 L
.7377 .10027 L
.73787 .08954 L
.73803 .07965 L
.73817 .37037 L
.73832 .36085 L
.73864 .34082 L
.73985 .26554 L
.74099 .1941 L
.74162 .15477 L
.74221 .11748 L
.74248 .10069 L
.74263 .09149 L
.74277 .08285 L
.74292 .37326 L
.743 .36832 L
.74308 .36299 L
.74337 .34487 L
.74443 .2789 L
.74568 .20064 L
.74684 .1278 L
.74714 .1089 L
.74743 .09106 L
.74759 .0812 L
.74767 .37534 L
Mistroke
.74776 .37021 L
.74806 .35151 L
.74938 .26834 L
.75047 .20016 L
.75165 .12687 L
.75199 .10532 L
.75216 .0947 L
.75232 .08486 L
.75246 .37567 L
.75261 .3662 L
.75293 .34616 L
.75413 .27088 L
.75538 .19315 L
.75603 .15227 L
.75639 .12995 L
.75672 .10912 L
.75687 .09974 L
.75701 .09086 L
.75709 .08595 L
.75718 .38033 L
.75732 .371 L
.75799 .32951 L
.75915 .25658 L
.76039 .17949 L
.76099 .14175 L
.76154 .10718 L
.76169 .09801 L
.76182 .08948 L
.76197 .3803 L
.76212 .37058 L
.76275 .33148 L
.76408 .2483 L
.76535 .16877 L
.76597 .12971 L
.76625 .11258 L
.76639 .10349 L
.76655 .09374 L
.76669 .38461 L
.76682 .37653 L
.76707 .36072 L
.76762 .32609 L
.76879 .25313 L
.7699 .18348 L
.77051 .14529 L
.77109 .10939 L
.77123 .10035 L
.77138 .09082 L
.77146 .38555 L
.77155 .38009 L
.7717 .3705 L
Mistroke
.77238 .32783 L
.77359 .25254 L
.7748 .17661 L
.7754 .13929 L
.77566 .1229 L
.77595 .10484 L
.77611 .0949 L
.77626 .3853 L
.77641 .37546 L
.77658 .36488 L
.77727 .32182 L
.77847 .24655 L
.77969 .17029 L
.78003 .1494 L
.78038 .12713 L
.78056 .11631 L
.78072 .10611 L
.78086 .09696 L
.78102 .38677 L
.78117 .3773 L
.78132 .36846 L
.78164 .34837 L
.78228 .30781 L
.78345 .23516 L
.78405 .19738 L
.78471 .15628 L
.78501 .13746 L
.78533 .11747 L
.78546 .10925 L
.7856 .1004 L
.78575 .3904 L
.7859 .38127 L
.78814 .24123 L
.78929 .169 L
.78961 .14921 L
.78995 .12806 L
.79011 .1178 L
.79027 .10811 L
.7904 .09941 L
.79056 .3897 L
.79071 .3798 L
.79086 .37053 L
.7912 .34945 L
.79188 .30685 L
.7931 .23046 L
.7937 .19288 L
.79436 .15191 L
.79465 .13317 L
.79482 .12289 L
.79497 .11322 L
Mistroke
.79512 .10417 L
.79527 .39411 L
.79542 .38522 L
.79555 .37706 L
.79778 .23716 L
.79835 .20158 L
.79896 .16349 L
.79925 .14501 L
.79953 .12754 L
.79978 .11184 L
.79993 .10299 L
.80006 .39451 L
.8002 .38556 L
.80035 .37592 L
.80063 .3585 L
.80127 .31879 L
.80255 .23846 L
.80371 .16603 L
.80403 .14619 L
.80436 .12501 L
.80453 .11473 L
.80468 .10504 L
.80482 .39605 L
.80497 .38662 L
.80619 .31069 L
.80752 .22728 L
.80812 .18979 L
.80876 .14957 L
.80907 .13009 L
.80923 .12049 L
.80937 .11161 L
.8095 .10357 L
.80963 .39474 L
.80977 .38616 L
.80992 .37668 L
.81125 .29381 L
.81246 .21776 L
.8136 .14674 L
.81387 .12948 L
.81402 .11999 L
.81417 .11102 L
.81425 .10594 L
.81434 .40013 L
.81449 .39049 L
.81479 .37163 L
.81599 .29673 L
.81731 .21428 L
.8179 .17699 L
.81823 .15643 L
.81854 .1369 L
Mistroke
.81883 .1188 L
.81891 .11384 L
.81899 .10856 L
.81915 .39877 L
.8193 .38942 L
.81944 .38061 L
.8197 .36416 L
.82093 .28694 L
.82224 .2054 L
.82279 .17048 L
.82339 .13308 L
.82357 .12205 L
.82366 .11662 L
.82374 .1116 L
.82389 .40194 L
.82396 .397 L
.82405 .39175 L
.82466 .35345 L
.82689 .21399 L
.82744 .17949 L
.82802 .14319 L
.82832 .12417 L
.82841 .11896 L
.8285 .1134 L
.82858 .40786 L
.82866 .4031 L
.82924 .36662 L
.83144 .22861 L
.83203 .19197 L
.83265 .15319 L
.8329 .13723 L
.83304 .12843 L
.83318 .12009 L
.83333 .40997 L
.83348 .40099 L
.83376 .38341 L
.83497 .30734 L
.83627 .22639 L
.83692 .18584 L
.83753 .1477 L
.83779 .13103 L
.83794 .12193 L
.83807 .11346 L
.83822 .40397 L
.8383 .3991 L
.83838 .3939 L
.83866 .3762 L
.84088 .23728 L
.84211 .16021 L
.84245 .1391 L
Mistroke
.84264 .12754 L
.84273 .12188 L
.84281 .11671 L
.84296 .40721 L
.84312 .39731 L
.84345 .37625 L
.84471 .29744 L
.84588 .22425 L
.84699 .15493 L
.84731 .13497 L
.84746 .12518 L
.84761 .11617 L
.84774 .40767 L
.84788 .39899 L
.84817 .38072 L
.84937 .30525 L
.85067 .22433 L
.8513 .18454 L
.85162 .16496 L
.85191 .14684 L
.85217 .13043 L
.8523 .12214 L
.85245 .4127 L
.85259 .40357 L
.85275 .39371 L
.85304 .37588 L
.85525 .23751 L
.8564 .16531 L
.85672 .14553 L
.85689 .13466 L
.85697 .12932 L
.85705 .12439 L
.85721 .41453 L
.85729 .40949 L
.85737 .40415 L
.85766 .38602 L
.85889 .30927 L
.86021 .22678 L
.86084 .18721 L
.86115 .16771 L
.86144 .14962 L
.8617 .13328 L
.86185 .12415 L
.86198 .4156 L
.86212 .40649 L
.86228 .39665 L
.86257 .37881 L
.86477 .2406 L
.86592 .16871 L
.86624 .14901 L
Mistroke
.86641 .13817 L
.8665 .13284 L
.86657 .12791 L
.86673 .41809 L
.86681 .41306 L
.86689 .40772 L
.86718 .38958 L
.86841 .31299 L
.86972 .2305 L
.87032 .19306 L
.87065 .17264 L
.87095 .15367 L
.87121 .13741 L
.87136 .12831 L
.87149 .41976 L
.87163 .41068 L
.87179 .40085 L
.87208 .38301 L
.87428 .24496 L
.87543 .17337 L
.87574 .15375 L
.87591 .14295 L
.876 .13763 L
.87608 .1327 L
.87623 .42291 L
.87631 .41789 L
.87639 .41255 L
.87668 .39441 L
.8779 .31798 L
.87922 .23549 L
.87982 .19825 L
.88014 .17792 L
.88044 .15899 L
.8807 .14279 L
.88085 .13372 L
.88098 .42518 L
.88112 .41614 L
.88128 .40631 L
.88157 .38848 L
.88377 .25058 L
.88491 .17929 L
.88522 .15976 L
.88539 .14899 L
.88556 .13876 L
.88571 .12928 L
.88579 .42362 L
.88587 .41864 L
.88616 .40051 L
.88747 .31875 L
.8887 .24175 L
Mistroke
.88928 .20554 L
.88989 .1673 L
.89021 .14731 L
.8903 .14183 L
.89039 .13596 L
.89048 .43013 L
.89056 .42508 L
.89118 .3865 L
.89342 .24603 L
.894 .20973 L
.89462 .17117 L
.89487 .15532 L
.895 .147 L
.89514 .13825 L
.8953 .42818 L
.89544 .41922 L
.89572 .40163 L
.89693 .32585 L
.89823 .24491 L
.89887 .20472 L
.89918 .18499 L
.89947 .16679 L
.89974 .15025 L
.89987 .14191 L
.90002 .43246 L
.90017 .42326 L
.90032 .41339 L
.90061 .39555 L
.90282 .25689 L
.90405 .18038 L
.90438 .15942 L
.90456 .14793 L
.90465 .14229 L
.90474 .13711 L
.90482 .4319 L
.9049 .42671 L
.90507 .41577 L
.90538 .39672 L
.90655 .32342 L
.9078 .24496 L
.90844 .20499 L
.90875 .18534 L
.90904 .16718 L
.90931 .15071 L
.90944 .1424 L
.90959 .43295 L
.90973 .42379 L
.90989 .41392 L
.91018 .39609 L
.91239 .25758 L
Mistroke
.91298 .22072 L
.91361 .18139 L
.91379 .16975 L
.91397 .15878 L
.91413 .14892 L
.91421 .14337 L
.9143 .43797 L
.91444 .42869 L
.91461 .41849 L
.91494 .3979 L
.9162 .31862 L
.91736 .24629 L
.91794 .21012 L
.91824 .19103 L
.91856 .17075 L
.91885 .15308 L
.91892 .14824 L
.91901 .14302 L
.91916 .43328 L
.9193 .42454 L
.91945 .41533 L
.91971 .39886 L
.92093 .32257 L
.92223 .24103 L
.92287 .20093 L
.92319 .18122 L
.92348 .16304 L
.92361 .15451 L
.92374 .14653 L
.92387 .43791 L
.92402 .42875 L
.92461 .39186 L
.92682 .25325 L
.92742 .21572 L
.92774 .1959 L
.92808 .17478 L
.92824 .16434 L
.9284 .1545 L
.92854 .14567 L
.9287 .43583 L
.92884 .42674 L
.92899 .41714 L
.92927 .39996 L
.9315 .26007 L
.93265 .18842 L
.93298 .16779 L
.93314 .15764 L
.93329 .14826 L
.93343 .43947 L
.93357 .43044 L
Mistroke
.93387 .41138 L
.93609 .27293 L
.93722 .2021 L
.93753 .18269 L
.9377 .17211 L
.93785 .16227 L
.93799 .15384 L
.93813 .44456 L
.93821 .43942 L
.93829 .43457 L
.93844 .4255 L
.94064 .28746 L
.94182 .21397 L
.94241 .17693 L
.94257 .16678 L
.94266 .16119 L
.94274 .15589 L
.94282 .15097 L
.94291 .44532 L
.94306 .43593 L
.94529 .29659 L
.94593 .25628 L
.94653 .21839 L
.94708 .18436 L
.94723 .17504 L
.94738 .16521 L
.94752 .15682 L
.94766 .44734 L
.94775 .44223 L
.94784 .43667 L
.948 .42659 L
.9483 .40771 L
.94898 .3653 L
.9502 .28887 L
.95133 .21762 L
.95165 .1981 L
.95198 .17711 L
.95214 .16694 L
.9523 .15728 L
.95244 .44832 L
.95259 .43886 L
.95392 .35561 L
.95512 .28012 L
.95571 .24339 L
.95635 .20366 L
.95664 .18542 L
.9568 .17545 L
.95695 .16615 L
.95707 .15821 L
.95721 .44941 L
Mistroke
.95736 .43996 L
.9575 .43134 L
.95881 .34912 L
.96003 .27304 L
.96114 .20319 L
.96141 .18622 L
.96171 .16792 L
.96179 .16282 L
.96187 .15745 L
.96203 .44756 L
.96217 .43855 L
.96233 .4287 L
.96364 .3466 L
.96483 .27199 L
.96542 .23546 L
.96605 .19586 L
.96634 .1777 L
.9665 .16776 L
.96665 .15846 L
.96677 .45026 L
.96691 .44176 L
.9672 .42369 L
.96972 .26555 L
.97031 .22852 L
.97094 .18909 L
.97113 .17739 L
.97122 .17166 L
.97131 .16639 L
.97146 .45622 L
.97155 .45103 L
.97164 .44555 L
.97228 .40544 L
.9747 .2537 L
.97619 .16044 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000U2000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00??ooool3
o`0002;ooooo1Ol0000Qooooo`;o00009?ooool5o`0002Cooooo0ol0001Iooooo`?o00008_ooool5
o`0002;ooooo0_l0000Tooooo`Go00009?ooool3o`0002Sooooo000mooooo`03o`000?oooooooooo
02;ooooo00Co0000oooooooooooo00008?ooool01?l0003oooooooooool0000Tooooo`04o`000?oo
ooooooooo`0002Gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Rooooo`04o`00
0?ooooooooooo`00027ooooo00Co0000oooooooooooo00009?ooool01?l0003oooooooooool0000U
ooooo`03o`000?oooooooooo02Oooooo000dooooo`Go000000?oooooo`000?l000000ol0000Loooo
o`Go00000oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0002Gooooo00?o0000
ooooooooool08_ooool5o`00057ooooo1Ol000000ooooooo0000o`000003o`0001cooooo1Ol00003
ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00009Oooool00ol0003ooooooooo
o`0Rooooo`Go0000:?ooool003[ooooo00Co0000oooooooooooo00009_ooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool08Oooool01?l0003ooooo
ooooool0001Hooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool08?ooool01?l0
003oooooooooool0000Vooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000:Ooo
ool003_ooooo00?o0000ooooool000008oooool01Ol0003ooooooooooooooooo0000023ooooo00Co
0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooool0
0000FOooool00ol0003oooooo`00000Sooooo`05o`000?ooooooooooooooool000008Oooool01?l0
003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooo`00
000Yooooo`00??ooool2o`0002?ooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?oo
ooooooooo`0002?ooooo00Go0000ooooooooooooooooo`00000Tooooo`;o0000F_ooool2o`0002?o
oooo00Go0000ooooooooooooooooo`00000Qooooo`04o`000?ooooooooooo`0002?ooooo00Go0000
ooooooooooooooooo`00000Tooooo`;o0000:Oooool003gooooo00?o0000ooooooooool08_ooool3
o`0002;ooooo0_l0000Uooooo`?o00009_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo02;ooooo0ol0000Sooooo`;o00009Oooool3o`0002Kooooo00?o0000ooooooooool09oooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool0027ooooocol0000Wooooom7o00004?oo
ool001_ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09Oooool2
o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`04o`000?oooooo
ooooooooo`;o00004?ooool001[ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00kooooo000Jooooo`04o`000?ooooooooooo`0000?ooooo0ol0
0002ooooodCoo`0000?oooooool00?oo00000ooo00001?ooooooo`00oooooooo0005ooooo`03ool0
0?oooooooooo00Goo`000ooooolCool00005oooooooo003ooooooooooooo00001?ooool00ooo003o
ooooool00018ool000?ooooo0_l0000Oooooo`?o00001Oooool00ol0003oooooooooo`1Booooo`03
ool00?oooooooooo013ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0>ooooo`00
6_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00CoooooCOoo0002ooooo`[o
o`000ooooolHool000;oooooCOoo0004ooooo`03o`000?oooooooooo01cooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo05;ooooo0_oo000Aooooo`03o`000?oooooooooo
01;ooooo0_oo001Aooooo`03o`000?oooooooooo00kooooo000Jooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool01?oooom=ool00003oooooooo003oo`0002Coo`0000?oooooool0
0?oo0000C?oo0004ooooo`03o`000?oooooooooo01Kooooo1Ol00005ooooo`03o`000?oooooooooo
00;ooooo0_l0001Cooooo`;oo`004Oooool00ol0003oooooooooo`0Booooo`?oo`00Coooool2o`00
013ooooo000Jooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0>?oooolIool0
0003oooooooo003oo`0000Woo`001oooool00ol0003oooooooooo`06ooooo`_oo`0000?oooooool0
0?oo00005ooo000iooooo`03o`000?oooooooooo01kooooo0_l00005ooooo`03o`000?oooooooooo
05;ooooo0ooo000@ooooo`03o`000?oooooooooo01;ooooo1?oo001?ooooo`03o`000?oooooooooo
00kooooo000Kooooo`;o00001?ooool00ol0003oooooooooo`12ooooo`ooo`0000?oooooool00?oo
00001_oo000:ooooo`03o`000?oooooooooo00Wooooo2?oo00000oooooooo`00ool0000=ool004?o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05;o
oooo1_oo000=ooooo`03o`000?oooooooooo01;ooooo1_oo00000oooooooo`00ooooo`1:ooooo`03
o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo04Kooooo2ooo00000oooooooo`00
ool00005ool000_ooooo00?o0000ooooooooool02_ooool7ool00003oooooooo003oo`0000Soo`00
B?ooool00ol0003oooooooooo`0Looooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`1Booooo`Ooo`003?ooool00ol0003oooooooooo`0Booooo`Woo`0000?oooooool00?oo
ool0Aoooool00ol0003oooooooooo`0>ooooo`008Oooool2o`0004Wooooo2Ooo00000oooooooo`00
ool00003ool000gooooo00?o0000ooooooooool02oooool6ool00003oooooooo003oo`0000Koo`00
BOooool2o`0001oooooo0ol00005ooooo`;o0000Doooool7ool000cooooo00?o0000ooooooooool0
4_ooool;ool004Oooooo0_l0000@ooooo`008Oooool00ol0003oooooooooo`1:ooooo`Ooo`0000?o
ooooool00?oo00000_oo000>ooooo`03o`000?oooooooooo00cooooo1Ooo00000oooooooo`00ool0
0005ool004_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Booooo`Woo`002_oo
ool00ol0003oooooooooo`0Booooo`koo`00AOooool00ol0003oooooooooo`0>ooooo`008Oooool0
0ol0003oooooooooo`1;ooooo`Koo`0000?oooooool00?oo00000_oo000>ooooo`03o`000?oooooo
oooo00cooooo1Ooo00000oooooooo`00ool00003ool004gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1Booooo`[oo`002Oooool00ol0003oooooooooo`0Boooooa3oo`00@oooool0
0ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1<ooooo`Goo`0000Coooooool0
0?oo003oo`003oooool00ol0003oooooooooo`0=ooooo`Coo`0000?oooooool00?oo00000ooo001=
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0D_ooool:ool000Wooooo00?o0000
ooooooooool04_oooolBool00003oooooooo003ooooo03kooooo00?o0000ooooooooool03_ooool0
027ooooo00?o0000ooooooooool0C?ooool5ool00004oooooooo003oo`00ool000oooooo00?o0000
ooooooooool03Oooool4ool00003oooooooo003oo`0000;oo`00C_ooool00ol0003oooooooooo`0U
ooooo`;o0000Doooool;ool000Sooooo00?o0000ooooooooool04_oooolDool00003oooooooo003o
o`0003_ooooo0_l0000@ooooo`008Oooool00ol0003oooooooooo`1=ooooo`Coo`0000Coooooool0
0?oo003oo`003oooool00ol0003oooooooooo`0>ooooo`?oo`0000?oooooool00?oo00000_oo001>
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0D_ooool;ool000Sooooo00?o0000
ooooooooool04_oooolGool00003oooooooo003ooooo03Wooooo00?o0000ooooooooool03_ooool0
027ooooo0_l0001>ooooo`Coo`0000?oooooool00?oo00004?ooool00ol0003oooooooooo`0>oooo
o`?oo`0000?oooooool00?oo00000_oo001=ooooo`;o00009oooool00ol0003oooooooooo`1Boooo
o`coo`001oooool00ol0003oooooooooo`0Boooooa_oo`00>?ooool00ol0003oooooooooo`0>oooo
o`008Oooool00ol0003oooooooooo`1>ooooo`?oo`0000?oooooool00?oo00004?ooool00ol0003o
ooooooooo`0>ooooo`?oo`0000Coooooool00?oo003oo`00Coooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo05;ooooo3Ooo0006ooooo`03o`000?oooooooooo01;ooooo7?oo000goooo
o`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo04kooooo0ooo00000ooooooo
o`00ool0000@ooooo`03o`000?oooooooooo00kooooo0ooo00001?ooooooo`00ool00?oo001?oooo
o`03o`000?oooooooooo02Gooooo0_l0001Cooooo`goo`001_ooool00ol0003oooooooooo`0Boooo
oakoo`0000?oooooool00?ooool0<Oooool2o`00013ooooo000Qooooo`03o`000?oooooooooo04ko
oooo0ooo00000oooooooo`00ool0000@ooooo`03o`000?oooooooooo00kooooo0ooo00001?oooooo
o`00ool00?oo001?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0D_ooool>ool0
00Gooooo00?o0000ooooooooool04_oooolRool0037ooooo00?o0000ooooooooool03_ooool0027o
oooo00?o0000ooooooooool0C_ooool3ool00003oooooooo003ooooo013ooooo00?o0000oooooooo
ool03oooool2ool00003oooooooo003oo`00053ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1Booooo`koo`001Oooool00ol0003oooooooooo`0Booooob?oo`0000?oooooool00?oo
ool0;Oooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1>ooooo`?oo`00
00?oooooool00?ooool04?ooool00ol0003oooooooooo`0?ooooo`;oo`0000?oooooool00?oo0000
D?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05;ooooo3_oo0005ooooo`03o`00
0?oooooooooo01;ooooo9_oo000]ooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oo
oooooooo04oooooo0_oo00000oooooooo`00ooooo`0@ooooo`03o`000?oooooooooo00oooooo0_oo
00000oooooooo`00ool0001@ooooo`03o`000?oooooooooo02Gooooo0_l0001Cooooo`ooo`001?oo
ool00ol0003oooooooooo`0BooooobSoo`00:_ooool2o`00013ooooo000Qooooo`;o0000D?ooool2
ool00003oooooooo003ooooo013ooooo00?o0000ooooooooool03oooool2ool00003oooooooo003o
o`0004oooooo0_l0000Wooooo`03o`000?oooooooooo05;ooooo4?oo0003ooooo`03o`000?oooooo
oooo01;ooooo;Ooo000Vooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo
04oooooo0_oo00000oooooooo`00ooooo`0@ooooo`03o`000?oooooooooo00oooooo0_oo00000ooo
ooooo`00ool0001@ooooo`03o`000?oooooooooo01cooooo1Ol00004ooooo`03o`000?oooooooooo
05;ooooo4?oo0003ooooo`03o`000?oooooooooo01;ooooo;_oo000Uooooo`03o`000?oooooooooo
00kooooo000Qooooo`03o`000?oooooooooo04oooooo0_oo00000oooooooo`00ooooo`0@ooooo`03
o`000?oooooooooo00oooooo0_oo00000oooooooo`00ool0001@ooooo`03o`000?oooooooooo01go
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Boooooa3oo`000oooool00ol0
003oooooooooo`0Boooooc3oo`0000?oooooool00?ooool08?ooool00ol0003oooooooooo`0>oooo
o`004oooool5o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04oooooo0_oo00000ooooooo
o`00ooooo`0@ooooo`03o`000?oooooooooo00oooooo0_oo00000oooooooo`00ool0001@ooooo`03
o`000?oooooooooo01Kooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo0_l0001Coooooa3o
o`000oooool00ol0003oooooooooo`0BooooocCoo`007_ooool2o`00013ooooo000Dooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1?oooo
o`;oo`0000?oooooool00?ooool04?ooool00ol0003oooooooooo`0?ooooo`;oo`0000?oooooool0
0?ooool0D?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0D_oooolAool000;ooooo00?o0000ooooooooool04_oooolgool001cooooo00?o0000oooo
ooooool03_ooool001Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo04oooooo0_oo00000oooooooo`00ooooo`0@ooooo`03o`000?oooooooooo
00oooooo0_oo00000oooooooo`00ooooo`1@ooooo`03o`000?oooooooooo01cooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo05;ooooo4_oo00000ooooooo0000ooooo`0C
ooooocWoo`000_ooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo000Foooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooooooool3o`0004oooooo0_oo
00000oooooooo`00ooooo`0@ooooo`03o`000?oooooooooo00oooooo0_oo00000oooooooo`00oooo
o`1?ooooo`;o00007_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
D_oooolBool00003ooooool0003ooooo01?ooooo??oo000Gooooo`03o`000?oooooooooo00kooooo
000Cooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo04oooooo0_oo00000oooooooo`00ooooo`0@ooooo`03o`000?oooooooooo013o
oooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Mooooo`?o00001Oooool2o`0005?o
oooo4_oo00000ooooooo0000ooooo`0Cooooockoo`0000?oooooool00?ooool04Oooool2o`00013o
oooo000Cooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo04oooooo0_oo00000oooooooo`00ooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
05;ooooo4_oo00000ooooooo0000ooooo`0Coooood?oo`004?ooool00ol0003oooooooooo`0>oooo
o`005?ooool3o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo053ooooo00?oo`00oooooooo
00004Oooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1Boooooa?oo`0000?o0000ooooooooool04_oooom6ool000go
oooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0D?ooool00ooo003ooooo
ool0000Aooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo05;ooooo4ooo00000ol0003oooooooooo`0AooooodWoo`00
2oooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`03ool00?oo
ooooo`00017ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oo
oooooooo02Gooooo0_l0001Coooooa?oo`0000?o0000ooooooooool04Ooooom>ool000Gooooo0_l0
000@ooooo`008Oooool2o`00057ooooo00?oo`00oooooooo00004Oooool00ol0003oooooooooo`0@
ooooo`03ool00?ooooooo`00053ooooo0_l0000Wooooo`03o`000?oooooooooo05;ooooo4ooo0000
0ol0003oooooooooo`0Aooooodkoo`0000?oooooool00?ooool00oooool00ol0003oooooooooo`0>
ooooo`008Oooool00ol0003oooooooooo`1@ooooo`03ool00?ooooooo`00017ooooo00?o0000oooo
ooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00oooool3ool004cooooo5?oo000Coooooe3oo`001?ooool00ol0003oooooooooo`0>oooo
o`008Oooool00ol0003oooooooooo`1@ooooo`03ool00?ooooooo`00017ooooo00?o0000oooooooo
ool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00oooool6ool004Wooooo5?oo000Coooooe3oo`001?ooool00ol0003oooooooooo`0>ooooo`00
8Oooool00ol0003oooooooooo`1@ooooo`03ool00?ooooooo`00017ooooo00?o0000ooooooooool0
4?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Gooooo0_l00004ooooo`Koo`00
00?oooooool00?ooool0A_oooolEool001;oooooD?oo0003ooooo`;o00004?ooool0027ooooo00?o
0000ooooooooool0D?ooool00ooo003oooooool0000Aooooo`03o`000?oooooooooo013ooooo00?o
o`00oooooooo0000DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo2Ooo
00000oooooooo`00ool00013oooooaGoo`004_oooom@ool000Cooooo00?o0000ooooooooool03_oo
ool0027ooooo00?o0000ooooooooool0D?ooool00ooo003oooooool0000Aooooo`03o`000?oooooo
oooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00?ooooo3Ooo00000oooooooo`00ooooo`0ooooooaGoo`004_oooom@ool000Cooooo00?o0000
ooooooooool03_ooool0027ooooo0_l0001Aooooo`03ool00?ooooooo`00017ooooo00?o0000oooo
ooooool04?ooool00ooo003oooooool0001@ooooo`;o00009oooool00ol0003oooooooooo`03oooo
o`ooo`000_ooool00ooo003oooooooooo`0koooooaKoo`004Ooooom@ool000Cooooo00?o0000oooo
ooooool03_ooool0027ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000oooooooo
ool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Gooooo0_l00004oooooa?o
o`00??oooolFool0017oooooD?oo0003ooooo`;o00004?ooool0027ooooo00?o0000ooooooooool0
D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00ooooolDool00003oooooooo003oo`0003Sooooo
5_oo000Aoooooe3oo`001?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003ooooooooo
o`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o
0000ooooooooool07Oooool3o`0000Gooooo00?o0000ooooooooool00ooooolJool003Gooooo5_oo
000Aoooooe3oo`001?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@
ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo6_oo0000
0oooooooo`00ool0000boooooaOoo`004?oooom@ool000Cooooo00?o0000ooooooooool03_ooool0
027ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo
003oooooool0001Aooooo`03o`000?oooooooooo01Kooooo1Ol00003ooooo`03o`000?oooooooooo
00Cooooo0_l00004oooooagoo`0000?oooooool00?ooool0;ooooolGool0013oooooD?oo0003oooo
o`;o00004?ooool0027ooooo0_l0001Aooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03
ool00?ooooooo`00053ooooo0_l0000Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00ooooolQool002kooooo6?oo000?oooooe3oo`001?ooool00ol0003oooooooooo`0>ooooo`00
8Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool0
0?ooooooo`00057ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo8ooo00000oooooooo`00ool0000YoooooaSoo`003ooooom@ool000Cooooo
00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o
0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo01gooooo0_l0
0006ooooo`03o`000?oooooooooo00?ooooo:Ooo000VoooooaSoo`003ooooom@ool000Cooooo00?o
0000ooooooooool03_ooool001Gooooo0ol00003ooooo`;o00001?ooool00ol0003oooooooooo`1@
ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`04ooooo`;o00001?ooool[ool002Cooooo6Ooo000>
oooooe3oo`000oooool2o`00013ooooo000Fooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000005;ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo00?o
o`00oooooooo0000DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo;?oo
00000oooooooo`00ooooo`0PoooooaWoo`003_oooom@ool000Cooooo00?o0000ooooooooool03_oo
ool001?ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0D?oo
ool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00oooool/ool00004oooooooo003oo`00ool001oooooo
6_oo000=oooooe3oo`001?ooool00ol0003oooooooooo`0>ooooo`004oooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo0ol0001@ooooo`;oo`004_ooool00ol0003o
ooooooooo`0@ooooo`03ool00?ooooooo`00053ooooo0_l0000Wooooo`03o`000?oooooooooo00?o
oooo<?oo00000oooooooo`00ooooo`0Loooooa[oo`003Ooooom@ool000Cooooo00?o0000oooooooo
ool03_ooool001Cooooo00?o0000ooooool000000oooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo
0000DOooool00ol0003oooooooooo`0Uooooo`;o00001?oooolbool00003oooooooo003ooooo01[o
oooo6ooo000<oooooe3oo`000oooool2o`00013ooooo000Eooooo`;o00000oooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013o
oooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?o
oooo=Ooo00000oooooooo`00ool0000Goooooa_oo`003?oooom@ool000Cooooo00?o0000oooooooo
ool03_ooool001Kooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool0
D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001Aooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00oooooljool001Gooooo7?oo000;oooooe3oo`00
1?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_oo
ool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`03oooooc[oo`0000?oooooool00?ooool04_oooolMool000[oooooD?oo
0004ooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo053ooooo0_oo000B
ooooo`03o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0U
ooooo`;o00001?oooolnool0017ooooo7Ooo000:oooooe3oo`000oooool2o`00013ooooo000Qoooo
o`;o0000DOooool2ool001;ooooo00?o0000ooooooooool04?ooool00ooo003oooooool0001@oooo
o`;o00009oooool00ol0003oooooooooo`03oooood;oo`003OoooolOool000SoooooD?oo0004oooo
o`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03
o`000?oooooooooo013ooooo00?oo`00oooooooo0000DOooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00?ooooo@ooo000<ooooob3oo`001ooooom@ool000Cooooo00?o0000oooooooo
ool03_ooool0027ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool0
4?ooool00ooo003oooooool0001Aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_oooom5ool000[ooooo8_oo0006oooooe3oo`001?ooool00ol0003oooooooooo`0>ooooo`008Ooo
ool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?oo
ooooo`00057ooooo00?o0000ooooooooool09Oooool2o`0000?oooooAooo0008ooooobCoo`001?oo
oom@ool000?ooooo0_l0000@ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool0
0ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000ooooooooool07_ooool2
o`0000Gooooo00?o0000ooooooooool00_oooom8ool00003oooooooo003oo`0000Cooooo9?oo0004
oooooe3oo`001?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@oooo
o`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00057ooooo00?o0000oooo
ooooool07Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;oooooCOoo0002
ooooobCoo`001?oooom@ool000Cooooo00?o0000ooooooooool03_ooool0027ooooo0_l0001Aoooo
o`;oo`004_ooool00ol0003oooooooooo`0@ooooo`03ool00?ooooooo`00053ooooo0_l0000Ooooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oooom=ool000;ooooo9_oo0002
oooooe3oo`001?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@oooo
o`;oo`004_ooool00ol0003oooooooooo`0@ooooo`;oo`00D_ooool00ol0003oooooooooo`0Moooo
o`04o`000?ooooooooooo`0000Cooooo1Ol0001@ool00003o`000?oo003oo`0002Goo`0000?o0000
ool00?oo0000C?oo0005o`00013ooooo000Qooooo`03o`000?oooooooooo053ooooo0_oo000Boooo
o`03o`000?oooooooooo013ooooo0_oo001Booooo`03o`000?oooooooooo01gooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`02oooooe3oo`0000?oooooool00?oo00009Ooo0002
ooooodgoo`001?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@oooo
o`;oo`004_ooool00ol0003oooooooooo`0@ooooo`;oo`00D_ooool00ol0003oooooooooo`0Moooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_oooom@ool000?ooooo9Ooo0004
oooood_oo`001?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@oooo
o`;oo`004_ooool00ol0003oooooooooo`0@ooooo`;oo`00D_ooool00ol0003oooooooooo`0Noooo
o`;o00001Oooool00ol0003oooooooooo`02oooooe3oo`001?oooolTool000KoooooBOoo0004oooo
o`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03
o`000?oooooooooo013ooooo0_oo001Booooo`03o`000?oooooooooo02Gooooo0_l00003oooooe3o
o`001_oooolRool000SoooooAooo0003ooooo`;o00004?ooool0027ooooo0_l0001Aooooo`;oo`00
4_ooool00ol0003oooooooooo`0@ooooo`;oo`00DOooool2o`0002Oooooo00?o0000ooooooooool0
0_oooom@ool000Oooooo8Ooo000;oooood?oo`001Oooool00ol0003oooooooooo`0>ooooo`008Ooo
ool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`;oo`00D_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;oooooD?oo0008ooooob3oo`003?oo
ool00ooo003oooooool0000oool000Gooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000
ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool2ool005;ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02oooooe3oo`002OoooolOool000kooooo00?oo`00
oooooooo0000?Ooo0005ooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo
053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo0_oo001Booooo`03o`000?oooooooooo
02Gooooo0_l00003oooooe3oo`002_oooolNool0013ooooo?_oo0004ooooo`;o00004?ooool001Co
oooo0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003o
ooooooooo`0@ooooo`;oo`00D_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
ooooD?oo000;oooooagoo`004_ooool00ooo003oooooool0000iool000Gooooo00?o0000oooooooo
ool03_ooool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool2ool0
05;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooe3oo`002ooooolMool0
01Cooooo00?oo`00ooooooooool0=ooo0005ooooo`03o`000?oooooooooo00kooooo000Cooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`?o0000D?ooool2
ool001;ooooo00?o0000ooooooooool04?ooool2ool0057ooooo0_l0000Wooooo`03o`000?oooooo
oooo00;oooooD?oo000;oooooagoo`005oooool2ool00003oooooooo003oo`0003;oo`001Oooool0
0ol0003oooooooooo`0>ooooo`004oooool4o`0000?ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`;oo`00D_ooool0
0ol0003oooooooooo`0Uooooo`;o00000ooooom@ool000gooooo6ooo000Koooooc?oo`001?ooool2
o`00013ooooo000Cooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`;oo`00D_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;oooooD?oo000=oooooa_oo`007?ooool0
0ooo003oooooool0000_ool000Gooooo00?o0000ooooooooool03_ooool001Cooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo053ooooo0_oo000B
ooooo`03o`000?oooooooooo013ooooo0_oo001Booooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_oooom@ool000kooooo6_oo000Pooooobkoo`001Oooool00ol0003oooooooooo`0>
ooooo`005Oooool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo053ooooo0_oo000Boooo
o`03o`000?oooooooooo013ooooo0_oo001Booooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool00_oooom@ool000kooooo6_oo000Qooooobgoo`001Oooool00ol0003oooooooooo`0>oooo
o`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`;o
o`00D_ooool00ol0003oooooooooo`0Uooooo`;o00000ooooom@ool000kooooo6_oo000Tooooob[o
o`001?ooool2o`00013ooooo000Qooooo`;o0000DOooool2ool001;ooooo00?o0000ooooooooool0
4?ooool2ool0057ooooo0_l0000Oooooo`?o00001Oooool00ol0003oooooooooo`02oooooe3oo`00
3ooooolIool002Oooooo00?oo`00oooooooo00009?oo0005ooooo`03o`000?oooooooooo00kooooo
000Qooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo0_oo
001Booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02oooooe3oo`003ooooolIool002[ooooo9?oo0005ooooo`03o`000?oooooooooo00kooooo000Q
ooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo0_oo001B
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
oooooe3oo`004?oooolHool002cooooo00?oo`00oooooooo00007ooo0005ooooo`03o`000?oooooo
oooo00kooooo000Qooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo
013ooooo0_oo001Booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool2o`00
00?oooooD?oo000@oooooaSoo`00;oooool2ool00003oooooooo003oo`0001[oo`001?ooool2o`00
013ooooo000Qooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013o
oooo0_oo001Booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02oooooe3oo`004?oooolHool0033ooooo00Coo`00oooooooooooooooo6_oo0005oooo
o`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03
o`000?oooooooooo013ooooo0_oo001Booooo`03o`000?oooooooooo01gooooo0_l00006ooooo`03
o`000?oooooooooo00;oooooD?oo000AoooooaOoo`00=OoooolIool000Gooooo00?o0000oooooooo
ool03_ooool0027ooooo0_l0001Aooooo`;oo`004_ooool00ol0003oooooooooo`0@ooooo`;oo`00
DOooool2o`00023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooooe3oo`00
4OoooolGool003Sooooo5_oo0005ooooo`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oo
oooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo0_oo001Booooo`03o`000?oo
oooooooo02Gooooo0_l00003oooooe3oo`004OoooolGool003[ooooo5?oo0004ooooo`;o00004?oo
ool0027ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04?ooool2
ool005;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooooe3oo`004_oooolF
ool003cooooo00?oo`00oooooooo00003ooo0005ooooo`03o`000?oooooooooo00kooooo000Qoooo
o`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo013ooooo0_oo001Boooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oooom@ool001;ooooo5_oo0011oooo
o`goo`001Oooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;o
o`004_ooool00ol0003oooooooooo`0@ooooo`;oo`00D_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00;oooooD?oo000BoooooaKoo`00@Oooool01?oo003oooooooooooooool9ool0
00Gooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0D?ooool2ool001;o
oooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo02Go
oooo0_l00003oooooe3oo`004ooooolEool004Kooooo2?oo0004ooooo`;o00004?ooool0027ooooo
0_l0001Aooooo`;oo`004_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo04oooooo
0_l0000Wooooo`03o`000?oooooooooo00;oooooD?oo000CoooooaGoo`00BOooool2ool00003oooo
oooo003oo`0000Gooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0D?oo
ool2ool001;ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_oooom@ool001?ooooo5Ooo001=ooooo`03ool00?oo
oooooooo00?ooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0D?ooool2
ool001;ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_oooom@ool001?ooooo5Ooo001Cooooo`03o`000?oooooo
oooo00kooooo000Qooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo
017ooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`;o00001ooooom<ool0
01?ooooo00?o0000ool00?oo00004_oo001Booooo`;o00004?ooool001Cooooo0ol00004ooooo`;o
00001?ooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0Aooooo`03
ool00?oooooooooo053ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09ooooodWo
o`004oooool00ol0003oo`00ool0000Bool005?ooooo00?o0000ooooooooool03_ooool001?ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool0D?ooool2ool001;ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02ooooom7ool001?ooooo00?o0000oooo
oooo00004_oo001Cooooo`03o`000?oooooooooo00kooooo000Cooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00003ooooo`?o0000D?ooool2ool001;ooooo00?o0000
ooooooooool04Oooool00ooo003oooooooooo`1?ooooo`;o00009oooool00ol0003oooooooooo`0@
oooood;oo`004oooool00ol0003oooooool0000Bool005?ooooo00?o0000ooooooooool03_ooool0
01Cooooo0ol00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0D?ooool2
ool001;ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooo
oooo02Gooooo0_l0000Aooooo`05ool00?ooooooo`00ool00?ooool0?Ooo000Cooooo`03o`000?oo
ooooo`0001;oo`00D_ooool2o`00013ooooo000Cooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`00
0?oooooooooo017ooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0Looooo`Go0000
1?ooool00ol0003oooooooooo`0Eooooocgoo`004oooool00ol0003oooooool0000Bool005?ooooo
00?o0000ooooooooool03_ooool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool0D?ooool2ool001;ooooo00?o0000oooooooo
ool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo01gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0Eooooo`04ool00?ooooooo`00ooooocWoo`004oooool0
0ol0003oooooooooo`0Bool005?ooooo00?o0000ooooooooool03_ooool001Cooooo0ol00004oooo
o`;o00001?ooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0Aoooo
o`03ool00?oooooooooo053ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01[ooooo>?oo000Cooooo`03o`000?oooooooooo017oo`00E?ooool00ol0
003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;oo`004_ooool00ol0003o
ooooooooo`0Aooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`03ooooo`;o00007?ooool00ooo003oooooool0000dool001?ooooo00?o0000oooooooo
ool04Ooo001Cooooo`;o00004?ooool0027ooooo0_l0001Aooooo`;oo`004_ooool00ol0003ooooo
ooooo`0Aooooo`03ool00?oooooooooo04oooooo0_l0000Nooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0Poooooc;oo`004oooool01?l0003oooooooooooooool@ool0
05Cooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0D?ooool2ool001;o
oooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo01co
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Cooooo;_oo000Coooo
o`04o`000?oooooooooooooooa3oo`00E?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0
003oooooooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo
053ooooo00?o0000ooooooooool07Oooool3o`0000Gooooo00?o0000ooooooooool09_ooool/ool0
01?ooooo00Co0000oooooooooooooooo4?oo001Dooooo`03o`000?oooooooooo00kooooo000Qoooo
o`03o`000?oooooooooo053ooooo0_oo000Booooo`03o`000?oooooooooo017ooooo00?oo`00oooo
ooooool0D?ooool00ol0003oooooooooo`0Uooooo`;o0000:OoooolZool001?ooooo00?o0000oooo
ooooool00_ooool?ool005?ooooo0_l0000@ooooo`008Oooool00ol0003oooooooooo`1@ooooo`;o
o`004_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo053ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Zooooo`03ool00?ooooooo`0002Goo`004oooool00ol0003o
ooooooooo`02ooooo`ooo`00E?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003ooooo
ooooo`1@ooooo`;oo`004_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo053ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0]ooooobGoo`004oooool00ol0003ooooo
ooooo`03ooooo`koo`00E?ooool00ol0003oooooooooo`0>ooooo`008Oooool2o`0005;ooooo00?o
o`00ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo04oooooo0_l0
000Wooooo`03o`000?oooooooooo02oooooo0_oo0002oooooaooo`004oooool00ol0003ooooooooo
o`03ooooo`koo`00E?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1A
ooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@
ooooo`03o`000?oooooooooo02Gooooo0_l0000doooooaooo`004oooool00ol0003oooooooooo`04
ooooo`goo`00Doooool2o`00013ooooo000Qooooo`03o`000?oooooooooo057ooooo00?oo`00oooo
ooooool04?ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo053ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0doooooagoo`005?ooool00ol0003oooooooooo`05oooo
o`coo`00E?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1Aooooo`03
ool00?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0=ooooolJool001Cooooo00?o0000oooooooo
ool01Oooool<ool005Cooooo00?o0000ooooooooool03_ooool0027ooooo00?o0000ooooooooool0
DOooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0
D?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Wooooo00Coo`00oooooooo003o
oooo5?oo000Dooooo`03o`000?oooooooooo00Kooooo2ooo001Dooooo`03o`000?oooooooooo00ko
oooo000Qooooo`03o`000?oooooooooo057ooooo00?oo`00ooooooooool04?ooool00ol0003ooooo
ooooo`0Aooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool09Oooool2o`0003kooooo
5?oo000Dooooo`03o`000?oooooooooo00Oooooo2_oo001Cooooo`;o00004?ooool0027ooooo0_l0
001Booooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ooo003ooooooooo
o`1?ooooo`;o00009oooool00ol0003oooooooooo`0ooooooa;oo`005?ooool00ol0003ooooooooo
o`07ooooo`[oo`00E?ooool00ol0003oooooooooo`0>ooooo`008Oooool00ol0003oooooooooo`1A
ooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1@
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0@Oooool@ool001Cooooo00?o0000
ooooooooool01oooool00ooo003oooooool00007ool005Cooooo00?o0000ooooooooool03_ooool0
027ooooo00?o0000ooooooooool0DOooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo
017ooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
04?ooooo00?oo`00oooooooo00002ooo000Dooooo`03o`000?oooooooooo00Wooooo2?oo001Doooo
o`03o`000?oooooooooo00kooooo000Qooooo`03o`000?oooooooooo057ooooo00?oo`00oooooooo
ool04?ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo053ooooo00?o0000oooooooo
ool09Oooool2o`0004Oooooo2ooo000Dooooo`03o`000?oooooooooo00Wooooo2?oo001Cooooo`;o
00004?ooool000kooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool0
DOooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0
D?ooool00ol0003oooooooooo`0Mooooo`?o00001Oooool00ol0003oooooooooo`17ooooo`[oo`00
5?ooool00ol0003oooooooooo`0<ooooo`Goo`00E?ooool00ol0003oooooooooo`0>ooooo`003ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`1Aooooo`03ool00?oooooooooo013ooooo00?o0000oooooooo
ool04Oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo01cooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo04Wooooo2?oo000Dooooo`03o`000?oooooooooo
00cooooo1Ooo001Dooooo`03o`000?oooooooooo00kooooo000?ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`?o0000DOooool0
0ooo003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0Coooool2
o`0002;ooooo00?o0000ooooooooool00_ooool2o`0004oooooo0ooo000Dooooo`03o`000?oooooo
oooo00gooooo1?oo001Cooooo`;o00004?ooool000oooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0DOoo
ool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07_oo
ool2o`0000Gooooo00?o0000ooooooooool0C_ooool3ool001Cooooo00?o0000ooooooooool03_oo
ool3ool005Cooooo00?o0000ooooooooool03_ooool000oooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
3oooool00ooo003oooooooooo`1Cooooo`03o`000?oooooooooo00kooooo000>ooooo`;o00001?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Looooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool03_ooool000oo
oooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004oooooloo00007oooool3o`0000Go
oooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool01?l0003o
ooooooooooooool2o`00013ooooo003ooooooaSooooodOl0000@ooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {147.312, 0}} -> {-0.0551454, -0.0147182, \
0.00419541, 0.00419541}, {{13.125, 240.125}, {143.75, 3.5}} -> {-6.98103, \
-14.9939, 0.0510127, 0.825438}, {{262.812, 489.812}, {143.75, 3.5}} -> \
{-19.3502, -4.01628, 0.0504502, 0.0503636}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example #2a: sum of cosines (homework #2, problem 7 example)", \
"Subsection"],

Cell[CellGroupData[{

Cell["Continuous-time signal", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := 1 + 2  Cos[2  \[Pi]\ t] + 4  Cos[4  \[Pi]\ t];\)\), "\n", 
    \(\(Plot[x[t], {t, 0, 5}, \ PlotStyle \[Rule] {Blue}, \ 
        Frame \[Rule] True, Axes \[Rule] {True, False}, \ 
        AspectRatio \[Rule] 1/3, ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.105916 0.0313544 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04321 -12 -4.5 ]
[-0.0125 .04321 0 4.5 ]
[-0.0125 .10592 -6 -4.5 ]
[-0.0125 .10592 0 4.5 ]
[-0.0125 .16862 -6 -4.5 ]
[-0.0125 .16862 0 4.5 ]
[-0.0125 .23133 -6 -4.5 ]
[-0.0125 .23133 0 4.5 ]
[-0.0125 .29404 -6 -4.5 ]
[-0.0125 .29404 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(1)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(2)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(3)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(4)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04321 m
.00625 .04321 L
s
[(-2)] -0.0125 .04321 1 0 Mshowa
0 .10592 m
.00625 .10592 L
s
[(0)] -0.0125 .10592 1 0 Mshowa
0 .16862 m
.00625 .16862 L
s
[(2)] -0.0125 .16862 1 0 Mshowa
0 .23133 m
.00625 .23133 L
s
[(4)] -0.0125 .23133 1 0 Mshowa
0 .29404 m
.00625 .29404 L
s
[(6)] -0.0125 .29404 1 0 Mshowa
.125 Mabswid
0 .05888 m
.00375 .05888 L
s
0 .07456 m
.00375 .07456 L
s
0 .09024 m
.00375 .09024 L
s
0 .12159 m
.00375 .12159 L
s
0 .13727 m
.00375 .13727 L
s
0 .15295 m
.00375 .15295 L
s
0 .1843 m
.00375 .1843 L
s
0 .19998 m
.00375 .19998 L
s
0 .21566 m
.00375 .21566 L
s
0 .24701 m
.00375 .24701 L
s
0 .26269 m
.00375 .26269 L
s
0 .27837 m
.00375 .27837 L
s
0 .02753 m
.00375 .02753 L
s
0 .01185 m
.00375 .01185 L
s
0 .30972 m
.00375 .30972 L
s
0 .3254 m
.00375 .3254 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.0619 .32958 m
.0619 .33333 L
s
.1 .32958 m
.1 .33333 L
s
.1381 .32958 m
.1381 .33333 L
s
.17619 .32958 m
.17619 .33333 L
s
.25238 .32958 m
.25238 .33333 L
s
.29048 .32958 m
.29048 .33333 L
s
.32857 .32958 m
.32857 .33333 L
s
.36667 .32958 m
.36667 .33333 L
s
.44286 .32958 m
.44286 .33333 L
s
.48095 .32958 m
.48095 .33333 L
s
.51905 .32958 m
.51905 .33333 L
s
.55714 .32958 m
.55714 .33333 L
s
.63333 .32958 m
.63333 .33333 L
s
.67143 .32958 m
.67143 .33333 L
s
.70952 .32958 m
.70952 .33333 L
s
.74762 .32958 m
.74762 .33333 L
s
.82381 .32958 m
.82381 .33333 L
s
.8619 .32958 m
.8619 .33333 L
s
.9 .32958 m
.9 .33333 L
s
.9381 .32958 m
.9381 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .04321 m
1 .04321 L
s
.99375 .10592 m
1 .10592 L
s
.99375 .16862 m
1 .16862 L
s
.99375 .23133 m
1 .23133 L
s
.99375 .29404 m
1 .29404 L
s
.125 Mabswid
.99625 .05888 m
1 .05888 L
s
.99625 .07456 m
1 .07456 L
s
.99625 .09024 m
1 .09024 L
s
.99625 .12159 m
1 .12159 L
s
.99625 .13727 m
1 .13727 L
s
.99625 .15295 m
1 .15295 L
s
.99625 .1843 m
1 .1843 L
s
.99625 .19998 m
1 .19998 L
s
.99625 .21566 m
1 .21566 L
s
.99625 .24701 m
1 .24701 L
s
.99625 .26269 m
1 .26269 L
s
.99625 .27837 m
1 .27837 L
s
.99625 .02753 m
1 .02753 L
s
.99625 .01185 m
1 .01185 L
s
.99625 .30972 m
1 .30972 L
s
.99625 .3254 m
1 .3254 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .10592 m
1 .10592 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .3254 m
.02499 .32497 L
.02605 .32385 L
.02729 .32169 L
.02846 .31881 L
.03053 .31173 L
.03279 .30131 L
.0379 .26836 L
.04262 .22893 L
.05285 .13087 L
.05786 .08595 L
.06244 .05156 L
.06469 .03789 L
.06713 .02571 L
.06847 .02033 L
.06972 .01618 L
.07091 .013 L
.07218 .01046 L
.0729 .0094 L
.07357 .00868 L
.0743 .00817 L
.07507 .00794 L
.07637 .00828 L
.07711 .00888 L
.0778 .00969 L
.07909 .01185 L
.08026 .01453 L
.0829 .02291 L
.08567 .03486 L
.08823 .04833 L
.09403 .08476 L
.09911 .11932 L
.10458 .15406 L
.10703 .16743 L
.1096 .17942 L
.1118 .1877 L
.11306 .19154 L
.11421 .19443 L
.11537 .19677 L
.11647 .1984 L
.11763 .1995 L
.11889 .19997 L
.11999 .19977 L
.12115 .19892 L
.12215 .19769 L
.12324 .1958 L
.12462 .19266 L
.12593 .18889 L
.12838 .17992 L
.13389 .15188 L
Mistroke
.14385 .08622 L
.1488 .0545 L
.15346 .03007 L
.15604 .0199 L
.15749 .01544 L
.15883 .01222 L
.15996 .01017 L
.16119 .00868 L
.16249 .00797 L
.16369 .00812 L
.16484 .00898 L
.16608 .01074 L
.16726 .01317 L
.16834 .01608 L
.1704 .02333 L
.17258 .03342 L
.1771 .06159 L
.18209 .10192 L
.19154 .19194 L
.19669 .23971 L
.20148 .2777 L
.20421 .29524 L
.20668 .30799 L
.208 .31344 L
.20944 .31823 L
.21022 .32035 L
.21095 .32199 L
.21163 .32324 L
.21237 .32427 L
.21357 .32524 L
.21468 .32535 L
.21536 .32504 L
.21601 .32449 L
.21722 .32276 L
.21849 .31999 L
.21967 .31657 L
.22235 .30587 L
.22476 .29293 L
.22697 .27858 L
.23196 .23903 L
.24099 .1534 L
.24614 .10494 L
.25165 .06028 L
.25433 .04272 L
.25685 .02916 L
.25912 .01972 L
.2604 .01558 L
.26158 .01255 L
.26267 .01043 L
.26384 .00888 L
Mistroke
.26494 .00809 L
.26595 .00795 L
.26713 .00847 L
.26841 .00988 L
.26963 .01198 L
.27076 .01459 L
.27323 .02237 L
.27547 .03166 L
.28048 .05876 L
.29126 .13047 L
.29599 .15935 L
.29849 .1723 L
.30117 .18378 L
.30248 .18835 L
.30371 .19201 L
.30491 .19494 L
.30602 .19706 L
.30707 .19854 L
.30819 .19955 L
.30931 .19997 L
.31054 .19973 L
.31182 .19872 L
.313 .19711 L
.31429 .19461 L
.31564 .19116 L
.31793 .18357 L
.32043 .17289 L
.33122 .10735 L
.33645 .07213 L
.34126 .04327 L
.34367 .03127 L
.34631 .02059 L
.3476 .01649 L
.34898 .01293 L
.34974 .01136 L
.35043 .01018 L
.35113 .00924 L
.35179 .00858 L
.35299 .00797 L
.35426 .00816 L
.35546 .00915 L
.35655 .01072 L
.35783 .01341 L
.35922 .01732 L
.36173 .02701 L
.36398 .03843 L
.36645 .05371 L
.37142 .09198 L
.38032 .17549 L
.38514 .22155 L
Mistroke
.39038 .26612 L
.39278 .28336 L
.39532 .29884 L
.39749 .30946 L
.39872 .31433 L
.39989 .31816 L
.40057 .32003 L
.40131 .32175 L
.40261 .32398 L
.40335 .32478 L
.40413 .32528 L
.40487 .32539 L
.40554 .32521 L
.40686 .32405 L
.40759 .32294 L
.40827 .32162 L
.40952 .31848 L
.41085 .31417 L
.4133 .30353 L
.4156 .29071 L
.42082 .25276 L
.42985 .16913 L
.43945 .08075 L
.44445 .04485 L
.4473 .0293 L
.4486 .02353 L
.44997 .0184 L
.45114 .01483 L
.45242 .01177 L
.45358 .00976 L
.45466 .00856 L
.45594 .00795 L
.45711 .00816 L
.45775 .00859 L
.45845 .0093 L
.45972 .01123 L
.46104 .01409 L
.46227 .01752 L
.46508 .02785 L
.46782 .0409 L
.47076 .05757 L
.48095 .12526 L
.48634 .15866 L
.48899 .17244 L
.49146 .18306 L
.49368 .1906 L
.49482 .19365 L
.49605 .19628 L
.49676 .19748 L
.49741 .19838 L
Mistroke
.49868 .19957 L
.49984 .19997 L
.50107 .19971 L
.50229 .19873 L
.50298 .19787 L
.50362 .19687 L
.50479 .19455 L
.50604 .19141 L
.50819 .18439 L
.51056 .17451 L
.51581 .14605 L
.52073 .11394 L
.5295 .056 L
.5319 .04238 L
.53446 .02983 L
.53668 .02099 L
.53784 .01717 L
.53908 .01381 L
.53974 .01231 L
.54046 .01091 L
.54173 .00909 L
.54303 .0081 L
.54424 .00798 L
.54542 .00863 L
.5465 .00988 L
.54775 .01212 L
.54893 .01503 L
.5515 .02396 L
.55389 .03531 L
.55929 .07078 L
.5778 .24111 L
.58242 .27767 L
.58485 .29344 L
.58741 .30696 L
.58966 .31593 L
.59093 .31973 L
.59212 .32241 L
.59321 .32413 L
.5942 .32507 L
.59535 .32539 L
.59644 .32496 L
.59762 .32365 L
.59893 .32123 L
.59959 .31963 L
.60029 .31762 L
.60157 .31324 L
.60405 .30218 L
.60631 .28926 L
.6118 .24852 L
.61703 .20114 L
Mistroke
.62662 .10923 L
.63188 .06554 L
.63446 .04775 L
.63684 .03398 L
.63909 .02347 L
.64147 .01524 L
.64271 .01217 L
.64386 .01005 L
.64513 .00857 L
.64584 .00812 L
.64648 .00794 L
.6476 .00817 L
.64863 .00897 L
.64977 .01049 L
.65097 .01282 L
.653 .01829 L
.65523 .02646 L
.66545 .08467 L
.67102 .12257 L
.67621 .1552 L
.68065 .17779 L
.68313 .18738 L
.68539 .19387 L
.68668 .19656 L
.68787 .19836 L
.68918 .19958 L
.68984 .19988 L
.69056 .19998 L
.69177 .19958 L
.69308 .19836 L
.69431 .19649 L
.69544 .19416 L
.69783 .18736 L
.70037 .17752 L
.70494 .15411 L
.71529 .08612 L
.72039 .05356 L
.72288 .03972 L
.72518 .02878 L
.72723 .02071 L
.72948 .01398 L
.73065 .01143 L
.73175 .00966 L
.7329 .00845 L
.73413 .00794 L
.73536 .00824 L
.73605 .00877 L
.73671 .00951 L
.73802 .0117 L
.73876 .01335 L
Mistroke
.73944 .01512 L
.74195 .02383 L
.74434 .03515 L
.74963 .06976 L
.75542 .11914 L
.76598 .22043 L
.77096 .26326 L
.77555 .29477 L
.77792 .30709 L
.78041 .31684 L
.78171 .32049 L
.78292 .323 L
.78361 .32404 L
.78425 .32474 L
.78498 .32523 L
.78567 .3254 L
.78682 .32502 L
.78804 .32374 L
.78909 .32192 L
.79024 .31916 L
.79147 .31533 L
.7928 .31023 L
.79521 .29854 L
.80053 .26274 L
.80614 .21402 L
.81617 .11762 L
.82108 .07534 L
.82571 .04301 L
.82827 .02922 L
.82962 .02328 L
.83104 .01801 L
.83225 .01443 L
.83357 .01138 L
.83477 .00944 L
.8359 .00835 L
.83703 .00794 L
.83827 .00828 L
.83944 .00934 L
.84052 .01096 L
.84159 .01314 L
.84257 .0156 L
.84475 .0227 L
.8471 .03261 L
.84965 .0456 L
.85426 .07362 L
.86458 .14261 L
.86962 .17088 L
.87183 .18074 L
.87422 .18934 L
.87551 .19299 L
Mistroke
.87671 .19571 L
.87785 .1977 L
.87907 .19913 L
.88034 .19989 L
.88154 .1999 L
.88285 .19912 L
.88359 .19832 L
.88427 .19737 L
.8856 .19487 L
.88683 .19184 L
.88964 .1825 L
.89237 .17044 L
.89529 .15482 L
.90555 .08761 L
.91094 .05308 L
.9139 .037 L
.91666 .02463 L
.91907 .01637 L
.92042 .0129 L
.92165 .0105 L
.92235 .00949 L
.923 .00877 L
.92372 .00823 L
.92447 .00796 L
.9252 .00798 L
.92588 .00826 L
.92715 .00946 L
.92833 .01136 L
.92957 .01419 L
.9318 .02134 L
.93419 .03193 L
.93681 .04679 L
.97619 .3254 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00:Oooool2o`0005Cooooo0ol0001Cooooo`Go0000Doooool3o`0005Gooooo0ol0001Coooo
o`?o00006_ooool002Sooooo00Co0000oooooooooooo0000E?ooool00ol0003oooooooooo`1Coooo
o`04o`000?ooooooooooo`0005;ooooo00Go0000ooooooooooooooooo`00001Eooooo`03o`000?oo
oooooooo057ooooo00Go0000ooooooooooooooooo`00000Iooooo`00:?ooool01?l0003ooooooooo
ool0001Dooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
ooooo`1@ooooo`Go0000E_ooool00ol0003oooooooooo`0Gooooo`00:?ooool01?l0003ooooooooo
ool0001Dooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0Doooool2o`0005?ooooo
00Co0000oooooooooooo0000Eoooool00ol0003oooooooooo`0Gooooo`00:?ooool01?l0003ooooo
ooooool0001Dooooo`03o`000?oooooooooo05;ooooo00Go0000ooooooooooooooooo`00001Foooo
o`03o`000?oooooooooo057ooooo00?o0000ooooool00000Doooool4o`0001[ooooo000Xooooo`04
o`000?ooooooooooo`0005?ooooo0_l0001Dooooo`05o`000?ooooooooooooooool00000D_ooool0
1Ol0003ooooooooooooooooo000005Cooooo0_l0001Cooooo`03o`000?oooooooooo01_ooooo000Y
ooooo`;o0000EOooool00ol0003oooooooooo`1Cooooo`?o0000E?ooool3o`0005Kooooo00?o0000
ooooooooool0DOooool5o`0001Wooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo
003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo000Ooooooooo0000
bol0000?ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`03
o`000?oooooooooo01oooooo0ol00?lUooooo`?o003o;?ooool2o`00obKooooo0ol00?l/ooooo`?o
003o9Oooool3o`00obcooooo0ol00?lUooooo`?o003o;?ooool3o`00obGooooo0_l00?lQooooo`03
o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01kooooo0_l00?l00ooooooo003o
ooooo`0Sooooo`04o`00ooooooooooooo`00ob_ooooo00Co003ooooooooooooo003o9?ooool01?l0
0?ooooooooooool00?l/ooooo`03o`00oooooooo003o02Cooooo00Co003ooooooooooooo003o;?oo
ool00ol00?ooooooo`00o`0Tooooo`;o003o00?oooooo`00ooooool0:_ooool2o`00o`03ooooool0
0?oooooo02?ooooo0_l00?l00ooooooo003oooooo`0Oooooo`03o`000?oooooooooo00gooooo000O
ooooo`?o00007_ooool01?l00?ooooooooooool00?lTooooo`05o`00ooooooooooooooooool00?l0
:_ooool01Ol00?oooooooooooooooooo003o02?ooooo00Go003oooooooooooooooooo`00o`0Zoooo
o`04o`00ooooooooooooo`00obCooooo00Go003oooooooooooooooooo`00o`0Zooooo`05o`00oooo
ooooooooooooool00?l08oooool01Ol00?oooooooooooooooooo003o02[ooooo00Go003ooooooooo
ooooooooo`00o`0Sooooo`04o`00ooooooooooooo`00oaoooooo0_l0000?ooooo`007oooool00ol0
003oooooooooo`0Nooooo`05o`00ooooooooooooooooool00?l08_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Q
ooooo`05o`00ooooooooooooooooool00?l0:Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo027ooooo00Go003oooooooooooooooooo`00o`0Yooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool08Oooool01Ol00?oooooooooooooooooo003o02[ooooo00Go003ooooooooo
ooooooooo`00o`0Sooooo`05o`00ooooooooooooooooool00?l07oooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool08?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool09oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool08?ooool01Ol00?oooooooooooooooooo003o02Wooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07Oooool0
0ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
02Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
01oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
02Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool07?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003o
ooooooooo`0Mooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Uooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0Nooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07?ooool00ol0003o
ooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Looooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Kooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool09Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01kooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool07?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooooooo
o`0Looooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Nooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Nooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07?ooool00ol0003ooooooooo
o`0=ooooo`007oooool3o`0001cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0J
ooooo`;o00003oooool001oooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Toooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo02Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Toooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo01_ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooooooo
ool07?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool08oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01_ooooo00?o0000oooooooo
ool03Oooool001oooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Tooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo02?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Tooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01_ooooo00?o0000ooooooooool03Oooool001Cooooo1Ol00006ooooo`03o`000?oo
oooooooo01_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Rooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo02?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Kooooo`03o`000?oo
oooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool06ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01_ooooo00?o0000ooooooooool03Ooo
ool000kooooo1Ol00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06_ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool03Oooool0
01Oooooo00?o0000ooooooooool01Oooool4o`0001[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Iooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool06_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0Gooooo`Co00003oooool001Cooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo01_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Ioooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo01[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Qoooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo027ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Joooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Joooo
o`03o`000?oooooooooo00gooooo000Dooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0Jooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool06Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Iooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool06_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Iooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool06_ooool00ol0
003oooooooooo`0=ooooo`005Oooool3o`0000Oooooo00?o0000ooooooooool06_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool06Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Jooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool06Oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool03Oooool001oooooo
00?o0000ooooooooool06_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo023ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool08Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool06Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01[ooooo
00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool06_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool08?ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0Pooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000
ooooooooool06_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool05oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool08?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool06?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01[ooooo00?o0000
ooooooooool03Oooool001oooooo0ol0000Jooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool07oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool06?ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo01[ooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`00
0?oooooooooo01Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo01oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Iooooo`03o`00
0?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07_oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooo
oooo01Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo01Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo01kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo01Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooo
oooo00gooooo000Oooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0Nooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0Iooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Wo
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01ko
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00go
oooo000Oooooo`?o00006Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo
0_l0000?ooooo`007oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool06?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0H
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`0Hooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool06?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Hooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo01Cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0=ooooo`00
7oooool00ol0003oooooooooo`0Hooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
6?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Hooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0=ooooo`007oooool3
o`0001Sooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Fooooo`;o00003oooool0
01oooooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
01Oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool06?ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`0Looooo`03o`00oooooooooooo00kooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00oooooo00?o003oooooooooool07?ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03Oooool001oooooo
00?o0000ooooooooool06?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01_ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01Oooooo
00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool05oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`0Jooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04oooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00oooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03Oooool001Kooooo0_l00007
ooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0G
ooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool05oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01Oooooo00?o0000
ooooooooool03Oooool001Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0G
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool05_ooool00ol0003oooooooooo`0=
ooooo`005Oooool01?l0003oooooooooool00006oooooa[o000000?o003oo`000?l000004?l00000
0ol00?oo0000o`00000Ao`000003o`00ool0003o0000013o000000?o003oo`000?l000006_l00000
0ol00?oo0000o`00000@o`000003o`00ool0003o0000017o000000?o003oo`000?l000004?l00000
0ol00?oo0000o`00000Jo`000003o`00ool0003o0000013o000000?o003oo`000?l000004Ol00000
0ol00?oo0000o`00000@o`000003o`00ool0003o000001[o000000?o003oo`000?l000004?l00000
0ol00?oo0000o`00000Ao`000003o`00ool0003o000000oo000000?o003oo`000?l000006ol00000
0ol00?oo0000o`00000@o`000003o`00ool0003o0000017o000000?o003oo`000?l000004?l00000
0ol00?oo0000o`00000Go`0000oooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool05oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Kooooo00?o0000
ooooooooool03Oooool001Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0G
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool05_ooool00ol0003oooooooooo`0=
ooooo`005_ooool2o`0000Oooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Joooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo01[ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Ioooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo01Kooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooooooo
ool05oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Wooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Kooooo00?o0000oooooooo
ool03Oooool001oooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo017ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo017ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo01Kooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool05ooo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool03Ooo
ool001oooooo0ol0000Fooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06Oooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05?ooool2
o`0000oooooo000Oooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06?ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0Hooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06Oooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo00kooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`0Eooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Ko
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01So
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06?ooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo00kooooo00?o003oooooooooool04oooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`0Cooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06Oooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo00kooooo00?o003oooooooooool04oooool00ol00?oooooo
ooooo`0Eooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Kooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool06?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00gooooo000O
ooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0C
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0H
ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0C
ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0C
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0E
ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Kooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo00gooooo000Oooooo`?o
00005_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool05?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool05?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool06?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool05?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01?ooooo0_l0000?ooooo`00
7oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
5?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Eooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0=ooooo`007oooool0
0ol0003oooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
01Oooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003o
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Fooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol0003o
ooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool04oooool00ol0003oooooooooo`0=ooooo`007oooool3o`0001Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool05oooool00ol00?ooooooooooo`0Booooo`;o00003oooool001oooooo00?o0000
ooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01?ooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooooooo01?ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooooooo
ool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Kooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01?ooooo00?o0000oooooooo
ool03Oooool001oooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Dooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo01Kooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo01?ooooo00?o0000ooooooooool03Oooool001Cooooo1Ol00006ooooo`03o`000?oo
oooooooo01Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Cooooo`03o`000?oo
oooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool05?oo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool03Ooo
ool001Kooooo00?o0000ooooooooool01_ooool4o`0001?ooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06Oooool0
0ol00?ooooooooooo`0?ooooo`Co00003oooool001Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Hooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool06Oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool05?ooool00ol0
0?ooooooooooo`0Hooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06?ooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Gooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool06?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04_ooool00ol0
003oooooooooo`0=ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool05?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Wooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool06Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01;ooooo00?o0000oooo
ooooool03Oooool001Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
01Cooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01Wooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo
00gooooo000Eooooo`?o00001oooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo01So
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01?o
oooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01So
oooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Wo
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Wo
oooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooo
ooooo`0Dooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Iooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool06_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`0Iooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool00ol00?oooooo
ooooo`0Cooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Iooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool06_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool04_ooool00ol0003ooooo
ooooo`0=ooooo`007oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo01Wooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Wooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool06Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Wooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01_ooooo00?o
003oooooooooool04Oooool00ol0003oooooooooo`0=ooooo`007oooool3o`0001?ooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0@ooooo`;o00003oooool001oooooo00?o0000oooo
ooooool04oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01[ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Wooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01[ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo017ooooo00?o0000oooo
ooooool03Oooool001oooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`0Jooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Jooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo01Wooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Jooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Cooooo`03
o`00oooooooooooo01_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Kooooo`03
o`00oooooooooooo017ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0
4oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
6_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool0
3Oooool001oooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo017ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool04oooool0
0ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l07_ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo01gooooo00Go003oooooooooooooooooo`00o`0Nooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Mooooo`03o`00
oooooooooooo017ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool04ooo
ool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l07_ooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo01gooooo00Co003ooooooooooooo003o7oooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo01cooooo00Co003ooooooooooooo003o7oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo01gooooo00Go003oooooooooooooooooo`00o`0N
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool07?ooool01?l00?ooooooooooool0
0?lQooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000
ooooooooool04oooool00ol00?ooooooooooo`0Mooooo`?o003o7oooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo01kooooo0ol00?lOooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool07Oooool3o`00oaoooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0N
ooooo`?o003o7oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo0_l00?l0
0ooooooo003oooooo`0Pooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03Oooool0
01oooooo0ol0000Booooo`03o`00oooooooooooo01oooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo01kooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo01kooooo00?o003oooooooooool08?ooool00ol0
0?ooooooooooo`0?ooooo`;o00003oooool001oooooo00?o0000ooooooooool04_ooool00ol00?oo
ooooooooo`10ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0@?ooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`10ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0@_ooool00ol00?oo
ooooooooo`0@ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01;ooooo
00?o003oooooooooool0@Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo043ooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool0@?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo04;ooooo
00?o003oooooooooool04?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooooooo
o`0Booooo`03o`00oooooooooooo047ooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`11ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0@?ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`12ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000
ooooooooool04_ooool00ol00?ooooooooooo`11ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool0@Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo043ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool0@_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00gooooo000Ooooo
o`03o`000?oooooooooo01;ooooo00?o003oooooooooool0@Oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo04;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`11oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool0@Oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo04?ooooo00?o003oooooooooool03oooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo047ooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool0@Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04;ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00oooooo00?o0000oooooooo
ool03Oooool001oooooo0ol0000Booooo`03o`00oooooooooooo047ooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
@Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04;ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00kooooo0_l0000?ooooo`007ooo
ool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo047ooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`12ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0@Ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04;ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00oooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool0@_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo047ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooo
oooo00gooooo000Oooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool0@_ooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo04;ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`12ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0@_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool03oooool00ol0
003oooooooooo`0=ooooo`005_ooool3o`0000Kooooo00?o0000ooooooooool04Oooool00ol00?oo
ooooooooo`12ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0@_ooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo04;ooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`12ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0A?ooool00ol00?oo
ooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool0@_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04;ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool0AOooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
000Dooooo`Go00001_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo04?ooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool0@_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04?ooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo00kooooo00?o
0000ooooooooool03Oooool001Cooooo00Co0000oooooooooooo00001oooool4o`00013ooooo00?o
003oooooooooool0@oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo04Cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool0@oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo04Gooooo00?o
003oooooooooool02oooool4o`0000oooooo000Eooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool04Oooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool0A?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo04?ooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool0AOooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00gooooo000Foooo
o`;o00001oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo04?ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool0@oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo04?ooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo00kooooo00?o0000oooo
ooooool03Oooool001Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03
o`00oooooooooooo04?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`14ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo04Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`15ooooo`03
o`00oooooooooooo00kooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0
4?ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
A?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
A_ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oo
oooooooo013ooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo04Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`13ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool0AOooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo04Oooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0=ooooo`007oooool0
0ol0003oooooooooo`0@ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`15ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0A?ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo04Gooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`17ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool03Oooool0
01oooooo0ol0000@ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`15ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0A?ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo04Gooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`17ooooo`03o`00oooooooooooo00cooooo0_l0000?ooooo`007oooool00ol0003o
ooooooooo`0@ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`16ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0A?ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo04Gooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`17ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool03Oooool001oooooo
00?o0000ooooooooool04?ooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool0A_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo04Gooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0Aoooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
000Oooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0AOooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo04Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`15ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0AOooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`007oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo04Gooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0AOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo04Gooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00gooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`15oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool0A_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo04Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`17oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool0BOooool00ol00?ooooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00oooooo00?o003ooooooooo
ool0A_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo04Oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool0Aoooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04Wooooo00?o003ooooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`007oooool3o`0000oooooo00?o003oooooooooool0
A_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
Aoooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool0
2oooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool0A_oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0Aooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooo
oooo04Kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`17ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool0A_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo04Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`19ooooo`03o`00oooooooo
oooo00cooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool03oooool00ol0
0?ooooooooooo`16ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0B?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo04Kooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`17ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0BOooool00ol0
0?ooooooooooo`0<ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00oo
oooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo04So
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`17ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04Wo
oooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooo
ooooo`0?ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`18ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0B?ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`1;ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool03Oooool001oooooo00?o
0000ooooooooool03_ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool0B?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo04Sooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`19ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool0Boooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000O
ooooo`?o00003_ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo04Sooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`19ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool0Boooool00ol00?ooooooooooo`0:ooooo`;o00003oooool001oooooo00?o0000oooo
ooooool03_ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool0BOooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo04Sooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`19ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool0Boooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000Oooooo`03
o`000?oooooooooo00kooooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo04Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`18ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool0BOooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo04_ooooo00?o003oooooooooool02oooool00ol0003oooooooooo`0=ooooo`00
7oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`19ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
BOooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo04[ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`1;ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool0
3Oooool001oooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`1:ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool0B_ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo04[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`1:ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool0Boooool00ol00?ooooooooooo`0;ooooo`03o`000?oo
oooooooo00gooooo000Eooooo`?o00001oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooo
oooo04[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`1:ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool0B_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo04_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`1<ooooo`03o`00oooooooo
oooo00[ooooo00?o0000ooooooooool03Oooool001Cooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0B_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo04[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`1;
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0Boooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo04cooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`0=
ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool03Oooool0
0ol00?ooooooooooo`1;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0Boooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04_ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`1;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0COooool0
0ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00gooooo000Dooooo`Co00001oooool4o`00
00cooooo00?o003oooooooooool0Boooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
04_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`1;ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool0Boooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
04gooooo00?o003oooooooooool01oooool4o`0000oooooo000Dooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`1<ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool0Boooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04_o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1<ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool0COooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00go
oooo000Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol00?oooooo
ooooo`1<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0Boooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo04cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`1<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0COooool00ol00?oooooo
ooooo`0:ooooo`03o`000?oooooooooo00gooooo000Fooooo`;o00001oooool00ol0003ooooooooo
o`0<ooooo`03o`00oooooooooooo04cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`1<ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0COooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo04cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`1=ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000
ooooooooool03?ooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0C?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool0C_ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00gooooo000Ooooo
o`03o`000?oooooooooo00cooooo00?o003oooooooooool0COooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo04gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1=oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0COooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo04oooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo04kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool0COooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo00Wooooo00?o0000oooooooo
ool03Oooool001oooooo0ol0000;ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
C_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo00Sooooo0_l0000?ooooo`007ooo
ool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0Cooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo04oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0D?ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooo
oooo00gooooo000Oooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0D?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`1?ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Coooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool02Oooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo053o
oooo00Go003oooooooooooooooooo`00o`1Booooo`05o`00ooooooooooooooooool00?l0D_ooool0
1Ol00?oooooooooooooooooo003o05;ooooo00Go003oooooooooooooooooo`00o`1Dooooo`03o`00
oooooooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02_oo
ool00ol00?ooooooooooo`1@ooooo`;o003o0_ooool00ol00?ooooooooooo`1Aooooo`04o`00oooo
ooooooooo`00oe;ooooo00Go003oooooooooooooooooo`00o`1Booooo`05o`00oooooooooooooooo
ool00?l0E?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`03
o`000?oooooooooo00Wooooo00?o003oooooooooool0D_ooool01?l00?ooooooo`00ool00?mCoooo
o`04o`00oooooooo003oo`00oe?ooooo00?o003oooooool00?l0E?ooool00ol00?ooooooo`00o`1E
ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo0ol00008oooo
o`;o003oEOooool2o`00oeGooooo0_l00?mEooooo`;o003oEOooool2o`00oeGooooo00?o003ooooo
ooooool01oooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo05Cooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03Oooool001ooooooool0003;o`0000oooooo0000
\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-0.491105, -4.40503, 0.0114913, \
0.069809}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampled sequence (fs = 10Hz)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := 1 + 2  Cos[2  \[Pi]\ t] + 4  Cos[4  \[Pi]\ t];\)\), "\n", 
    \(xd = \ sampler[x, fs = 10]; \ 
    If[OddQ[Length[xd]], \ xd\  = \ Drop[xd, \(-1\)]];\), "\n", 
    \(\(DiscreteListPlot2[xd, \ Blue, \ Frame \[Rule] True, 
        Axes \[Rule] {True, False}, \ AspectRatio \[Rule] 1/3, 
        ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0194363 0.0998844 0.0322161 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21817 -0.0125 -6 -9 ]
[.21817 -0.0125 6 0 ]
[.41254 -0.0125 -6 -9 ]
[.41254 -0.0125 6 0 ]
[.6069 -0.0125 -6 -9 ]
[.6069 -0.0125 6 0 ]
[.80126 -0.0125 -6 -9 ]
[.80126 -0.0125 6 0 ]
[.99563 -0.0125 -6 -9 ]
[.99563 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03545 -12 -4.5 ]
[-0.0125 .03545 0 4.5 ]
[-0.0125 .09988 -6 -4.5 ]
[-0.0125 .09988 0 4.5 ]
[-0.0125 .16432 -6 -4.5 ]
[-0.0125 .16432 0 4.5 ]
[-0.0125 .22875 -6 -4.5 ]
[-0.0125 .22875 0 4.5 ]
[-0.0125 .29318 -6 -4.5 ]
[-0.0125 .29318 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21817 0 m
.21817 .00625 L
s
[(10)] .21817 -0.0125 0 1 Mshowa
.41254 0 m
.41254 .00625 L
s
[(20)] .41254 -0.0125 0 1 Mshowa
.6069 0 m
.6069 .00625 L
s
[(30)] .6069 -0.0125 0 1 Mshowa
.80126 0 m
.80126 .00625 L
s
[(40)] .80126 -0.0125 0 1 Mshowa
.99563 0 m
.99563 .00625 L
s
[(50)] .99563 -0.0125 0 1 Mshowa
.125 Mabswid
.06268 0 m
.06268 .00375 L
s
.10155 0 m
.10155 .00375 L
s
.14043 0 m
.14043 .00375 L
s
.1793 0 m
.1793 .00375 L
s
.25705 0 m
.25705 .00375 L
s
.29592 0 m
.29592 .00375 L
s
.33479 0 m
.33479 .00375 L
s
.37366 0 m
.37366 .00375 L
s
.45141 0 m
.45141 .00375 L
s
.49028 0 m
.49028 .00375 L
s
.52915 0 m
.52915 .00375 L
s
.56803 0 m
.56803 .00375 L
s
.64577 0 m
.64577 .00375 L
s
.68465 0 m
.68465 .00375 L
s
.72352 0 m
.72352 .00375 L
s
.76239 0 m
.76239 .00375 L
s
.84014 0 m
.84014 .00375 L
s
.87901 0 m
.87901 .00375 L
s
.91788 0 m
.91788 .00375 L
s
.95675 0 m
.95675 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03545 m
.00625 .03545 L
s
[(-2)] -0.0125 .03545 1 0 Mshowa
0 .09988 m
.00625 .09988 L
s
[(0)] -0.0125 .09988 1 0 Mshowa
0 .16432 m
.00625 .16432 L
s
[(2)] -0.0125 .16432 1 0 Mshowa
0 .22875 m
.00625 .22875 L
s
[(4)] -0.0125 .22875 1 0 Mshowa
0 .29318 m
.00625 .29318 L
s
[(6)] -0.0125 .29318 1 0 Mshowa
.125 Mabswid
0 .05156 m
.00375 .05156 L
s
0 .06767 m
.00375 .06767 L
s
0 .08378 m
.00375 .08378 L
s
0 .11599 m
.00375 .11599 L
s
0 .1321 m
.00375 .1321 L
s
0 .14821 m
.00375 .14821 L
s
0 .18042 m
.00375 .18042 L
s
0 .19653 m
.00375 .19653 L
s
0 .21264 m
.00375 .21264 L
s
0 .24486 m
.00375 .24486 L
s
0 .26096 m
.00375 .26096 L
s
0 .27707 m
.00375 .27707 L
s
0 .01934 m
.00375 .01934 L
s
0 .00324 m
.00375 .00324 L
s
0 .30929 m
.00375 .30929 L
s
0 .3254 m
.00375 .3254 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21817 .32708 m
.21817 .33333 L
s
.41254 .32708 m
.41254 .33333 L
s
.6069 .32708 m
.6069 .33333 L
s
.80126 .32708 m
.80126 .33333 L
s
.99563 .32708 m
.99563 .33333 L
s
.125 Mabswid
.06268 .32958 m
.06268 .33333 L
s
.10155 .32958 m
.10155 .33333 L
s
.14043 .32958 m
.14043 .33333 L
s
.1793 .32958 m
.1793 .33333 L
s
.25705 .32958 m
.25705 .33333 L
s
.29592 .32958 m
.29592 .33333 L
s
.33479 .32958 m
.33479 .33333 L
s
.37366 .32958 m
.37366 .33333 L
s
.45141 .32958 m
.45141 .33333 L
s
.49028 .32958 m
.49028 .33333 L
s
.52915 .32958 m
.52915 .33333 L
s
.56803 .32958 m
.56803 .33333 L
s
.64577 .32958 m
.64577 .33333 L
s
.68465 .32958 m
.68465 .33333 L
s
.72352 .32958 m
.72352 .33333 L
s
.76239 .32958 m
.76239 .33333 L
s
.84014 .32958 m
.84014 .33333 L
s
.87901 .32958 m
.87901 .33333 L
s
.91788 .32958 m
.91788 .33333 L
s
.95675 .32958 m
.95675 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .03545 m
1 .03545 L
s
.99375 .09988 m
1 .09988 L
s
.99375 .16432 m
1 .16432 L
s
.99375 .22875 m
1 .22875 L
s
.99375 .29318 m
1 .29318 L
s
.125 Mabswid
.99625 .05156 m
1 .05156 L
s
.99625 .06767 m
1 .06767 L
s
.99625 .08378 m
1 .08378 L
s
.99625 .11599 m
1 .11599 L
s
.99625 .1321 m
1 .1321 L
s
.99625 .14821 m
1 .14821 L
s
.99625 .18042 m
1 .18042 L
s
.99625 .19653 m
1 .19653 L
s
.99625 .21264 m
1 .21264 L
s
.99625 .24486 m
1 .24486 L
s
.99625 .26096 m
1 .26096 L
s
.99625 .27707 m
1 .27707 L
s
.99625 .01934 m
1 .01934 L
s
.99625 .00324 m
1 .00324 L
s
.99625 .30929 m
1 .30929 L
s
.99625 .3254 m
1 .3254 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .09988 m
1 .09988 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .09988 m
.02381 .3254 L
s
.04325 .09988 m
.04325 .22405 L
s
.06268 .09988 m
.06268 .04776 L
s
.08212 .09988 m
.08212 .00794 L
s
.10155 .09988 m
.10155 .1198 L
s
.12099 .09988 m
.12099 .19653 L
s
.14043 .09988 m
.14043 .1198 L
s
.15986 .09988 m
.15986 .00794 L
s
.1793 .09988 m
.1793 .04776 L
s
.19874 .09988 m
.19874 .22405 L
s
.21817 .09988 m
.21817 .3254 L
s
.23761 .09988 m
.23761 .22405 L
s
.25705 .09988 m
.25705 .04776 L
s
.27648 .09988 m
.27648 .00794 L
s
.29592 .09988 m
.29592 .1198 L
s
.31535 .09988 m
.31535 .19653 L
s
.33479 .09988 m
.33479 .1198 L
s
.35423 .09988 m
.35423 .00794 L
s
.37366 .09988 m
.37366 .04776 L
s
.3931 .09988 m
.3931 .22405 L
s
.41254 .09988 m
.41254 .3254 L
s
.43197 .09988 m
.43197 .22405 L
s
.45141 .09988 m
.45141 .04776 L
s
.47085 .09988 m
.47085 .00794 L
s
.49028 .09988 m
.49028 .1198 L
s
.50972 .09988 m
.50972 .19653 L
s
.52915 .09988 m
.52915 .1198 L
s
.54859 .09988 m
.54859 .00794 L
s
.56803 .09988 m
.56803 .04776 L
s
.58746 .09988 m
.58746 .22405 L
s
.6069 .09988 m
.6069 .3254 L
s
.62634 .09988 m
.62634 .22405 L
s
.64577 .09988 m
.64577 .04776 L
s
.66521 .09988 m
.66521 .00794 L
s
.68465 .09988 m
.68465 .1198 L
s
.70408 .09988 m
.70408 .19653 L
s
.72352 .09988 m
.72352 .1198 L
s
.74295 .09988 m
.74295 .00794 L
s
.76239 .09988 m
.76239 .04776 L
s
.78183 .09988 m
.78183 .22405 L
s
.80126 .09988 m
.80126 .3254 L
s
.8207 .09988 m
.8207 .22405 L
s
.84014 .09988 m
.84014 .04776 L
s
.85957 .09988 m
.85957 .00794 L
s
.87901 .09988 m
.87901 .1198 L
s
.89845 .09988 m
.89845 .19653 L
s
.91788 .09988 m
.91788 .1198 L
s
.93732 .09988 m
.93732 .00794 L
s
.95675 .09988 m
.95675 .04776 L
s
.97619 .09988 m
.97619 .22405 L
s
.005 w
.02381 .3254 Mdot
.04325 .22405 Mdot
.06268 .04776 Mdot
.08212 .00794 Mdot
.10155 .1198 Mdot
.12099 .19653 Mdot
.14043 .1198 Mdot
.15986 .00794 Mdot
.1793 .04776 Mdot
.19874 .22405 Mdot
.21817 .3254 Mdot
.23761 .22405 Mdot
.25705 .04776 Mdot
.27648 .00794 Mdot
.29592 .1198 Mdot
.31535 .19653 Mdot
.33479 .1198 Mdot
.35423 .00794 Mdot
.37366 .04776 Mdot
.3931 .22405 Mdot
.41254 .3254 Mdot
.43197 .22405 Mdot
.45141 .04776 Mdot
.47085 .00794 Mdot
.49028 .1198 Mdot
.50972 .19653 Mdot
.52915 .1198 Mdot
.54859 .00794 Mdot
.56803 .04776 Mdot
.58746 .22405 Mdot
.6069 .3254 Mdot
.62634 .22405 Mdot
.64577 .04776 Mdot
.66521 .00794 Mdot
.68465 .1198 Mdot
.70408 .19653 Mdot
.72352 .1198 Mdot
.74295 .00794 Mdot
.76239 .04776 Mdot
.78183 .22405 Mdot
.80126 .3254 Mdot
.8207 .22405 Mdot
.84014 .04776 Mdot
.85957 .00794 Mdot
.87901 .1198 Mdot
.89845 .19653 Mdot
.91788 .1198 Mdot
.93732 .00794 Mdot
.95675 .04776 Mdot
.97619 .22405 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`009oooool2o`0005?ooooo0ol00004ooooo`;o0000Coooool5o`0000?ooooo0_l0001@oooo
o`?o00001?ooool2o`00053ooooo0ol00003ooooo`;o0000D?ooool3o`0000Cooooo0_l0000@oooo
o`009_ooool01?l0003oooooooooool0001Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo0000Coooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0004kooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00053ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo04cooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000oooooo000Vooooo`04o`000?ooooooooooo`0005?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0001@ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo0000D_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo04_ooooo1Ol00002ooooo`04o`000?ooooooooooo`0005;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0=ooooo`009_ooool01?l0003oooooooooool0001Cooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo0000DOooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool0C_ooool2o`0000?ooooo00Co0000oooooooooooo0000COooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0005;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0=ooooo`009_ooool01?l0003oooooooooool0001Cooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000C_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo0000D_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooool000000oooool01?l0003oooooooooool0001>ooooo`Co
00000oooool01?l0003oooooooooool0000?ooooo`009_ooool01?l0003oooooooooool0001Boooo
o`;o00001?ooool01?l0003oooooooooool0001>ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool0001>ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0001?ooooo`;o00000oooool01?l0003oooooooooool0001>ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00003oooool002Oooooo0_l0001Dooooo`03o`000?oooooo
oooo00?ooooo0_l0001@ooooo`?o00001?ooool2o`00053ooooo0ol00004ooooo`;o0000DOooool0
0ol0003oooooooooo`02ooooo`;o0000Coooool5o`0000?ooooo0_l0000@ooooo`00oooooooioooo
o`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00oooooooiooooo`007Oooooooo`000<_o00004Oooool001gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooo0000017ooooo000Mooooo`?o00002?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`?o00004Oooool001gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Gooooo`;o003o8_ooool2o`00oaWooooo00?o0000ooooooooool05oooool2o`00
ob;ooooo0_l00?lIooooo`03o`000?oooooooooo01Oooooo0_l00?lQooooo`;o003o6_ooool00ol0
003oooooooooo`0Gooooo`;o003o8Oooool2o`00oaWooooo00?o0000ooooooooool06?ooool2o`00
ob7ooooo0_l00?lIooooo`03o`000?oooooo0000017ooooo000Mooooo`03o`000?oooooooooo02;o
oooo0_l00?lRooooo`;o003o<oooool2o`00ob;ooooo0_l00?lcooooo`;o003o8Oooool2o`00ocCo
oooo0_l00?lQooooo`;o003o=?ooool2o`00ob7ooooo0_l00?lKooooo`03o`000?oooooooooo00oo
oooo000Mooooo`03o`000?oooooooooo02?ooooo00?o003oooooooooool08?ooool00ol00?oooooo
ooooo`0cooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0<oooool00ol00?oooooo
ooooo`0Pooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`0booooo`03o`00oooooooooooo027ooooo00?o003oooooooooool06Oooool00ol0003ooooo
ooooo`0?ooooo`007Oooool00ol0003oooooooooo`0Sooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool0<oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo03?ooooo00?o
003oooooooooool08?ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo027ooooo00?o
003oooooooooool0<_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo01Wooooo00?o
0000ooooooooool03oooool001gooooo00?o0000ooooooooool08oooool00ol00?ooooooooooo`0P
ooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0c
ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`0Q
ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0I
ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo02?ooooo00?o003ooooo
ooooool08?ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool0<oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo03;ooooo00?o003ooooo
ooooool08Oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo027ooooo00?o003ooooo
ooooool06Oooool00ol0003oooooooooo`0?ooooo`007Oooool3o`0002?ooooo00?o003ooooooooo
ool08?ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo023ooooo00?o003ooooooooo
ool0<oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo03;ooooo00?o003ooooooooo
ool08Oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo027ooooo00?o003ooooooooo
ool06?ooool2o`00017ooooo000Mooooo`03o`000?oooooooooo02?ooooo00?o003oooooooooool0
8?ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0
<oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool0
8Oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo027ooooo00?o003oooooooooool0
6Oooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`0Sooooo`03o`00oooo
oooooooo023ooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`0Pooooo`03o`00oooo
oooooooo03?ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0booooo`03o`00oooo
oooooooo027ooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooo
oooooooo01Wooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool08oooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool08?ooool0
0ol00?ooooooooooo`0cooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0<_ooool0
0ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool08Oooool0
0ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo
02?ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo
023ooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
03;ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo
027ooooo00?o003oooooooooool06Oooool00ol0003oooooooooo`0?ooooo`004_ooool5o`0000Ko
oooo00?o0000ooooooooool08oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo03?o
oooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo023o
oooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo03;o
oooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00oo
oooo000Cooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool08oooool00ol00?oo
ooooooooo`0Pooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool08?ooool00ol00?oo
ooooooooo`0cooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0<_ooool00ol00?oo
ooooooooo`0Qooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool08Oooool00ol00?oo
ooooooooo`0Iooooo`03o`000?oooooooooo00oooooo000<ooooo`Go00000oooool00ol0003ooooo
ooooo`06ooooo`Co00008_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo03?ooooo
00?o003oooooooooool08?ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo023ooooo
00?o003oooooooooool0<_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo03;ooooo
00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Fooooo`Co00004Oooool001Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool0<oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo03?ooooo00?o
003oooooooooool08?ooool00ol00?ooooooooooo`0booooo`03o`00oooooooooooo027ooooo00?o
003oooooooooool0<_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo01Wooooo00?o
0000ooooooooool03oooool001;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo02?ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0cooooo`03o`00oooo
oooooooo023ooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`0Pooooo`03o`00oooo
oooooooo03;ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0booooo`03o`00oooo
oooooooo027ooooo00?o003oooooooooool06Oooool00ol0003oooooooooo`0?ooooo`004_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool08oooool00ol00?oooooooooo
o`0Pooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool08?ooool00ol00?oooooooooo
o`0cooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0<_ooool00ol00?oooooooooo
o`0Qooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool08Oooool00ol00?oooooooooo
o`0Iooooo`03o`000?oooooooooo00oooooo000Cooooo`?o00001oooool00ol0003oooooooooo`0S
ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`0P
ooooo`03o`00oooooooooooo03?ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0b
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`0Q
ooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool03oooool001gooooo00?o0000oooo
ooooool08oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo03?ooooo00?o003ooooo
ooooool08?ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool0<_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo03;ooooo00?o003ooooo
ooooool08Oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00oooooo000Mooooo`03
o`000?oooooooooo01Wooooo0_l00?l8ooooo`03o`00oooooooooooo023ooooo00?o003ooooooooo
ool01_ooool2o`00ob7ooooo0_l00?l8ooooo`03o`00oooooooooooo023ooooo00?o003ooooooooo
ool01_ooool2o`00ob7ooooo0_l00?l8ooooo`03o`00oooooooooooo023ooooo00?o003ooooooooo
ool01Oooool2o`00ob;ooooo0_l00?l7ooooo`03o`00oooooooooooo027ooooo00?o003ooooooooo
ool01Oooool2o`00ob;ooooo0_l00?l7ooooo`03o`00oooooooooooo027ooooo00?o003ooooooooo
ool01Oooool2o`00oa;ooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool0
6Oooool2o`00o`Sooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`;o003o
8Oooool2o`00o`Sooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`;o003o
8Oooool2o`00o`Sooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`05ooooo`;o003o
8_ooool2o`00o`Oooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`05ooooo`;o003o
8_ooool2o`00o`Oooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`05ooooo`;o003o
4_ooool00ol0003oooooooooo`0?ooooo`007Oooool3o`0001[ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0?ooooo`;o00004Oooool001gooooo00?o0000ooooooooool06_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03oooool0
01gooooo00?o0000ooooooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
013ooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool06_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03oooool001gooooo
00?o0000ooooooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo013ooooo
00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool06_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03oooool001gooooo00?o0000
ooooooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo013ooooo00?o0000
ooooooooool03oooool001gooooo0ol0000Jooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03oooool2o`00017ooooo000Mooooo`03o`000?oooooooooo01[ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`00
0?oooooooooo01[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo01[ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooo
oooo01[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooo
oooo00oooooo000Mooooo`03o`000?oooooooooo01[ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0@ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo01[o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00oo
oooo000Mooooo`?o00006_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00oooooo
0_l0000Aooooo`007Oooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool04?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`0J
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0P
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0P
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Q
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0?
ooooo`007Oooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool04?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`0Jooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0?ooooo`00
5?ooool2o`0000Oooooo00?o0000ooooooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo013ooooo00?o0000ooooooooool03oooool001?ooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
8?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
8Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
8Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
4?ooool00ol0003oooooooooo`0?ooooo`004oooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo01[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo000Cooooo`04o`000?ooooooooooo`0000Kooooo2ol000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000
o`000005o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001Ol000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001Ol000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Go000000?o003oo`000?l000001_l000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000
o`000005o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000
o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol00?oo0000
o`000005o`000003o`00ool0003o000000Wo00004Oooool001?ooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00oooooo000Cooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`005?oo
ool2o`0000Oooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`007Oooool0
0ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo
00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
00Sooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool02?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`0?ooooo`007Oooool3o`0000Sooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Gooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Gooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Gooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Gooooo`03o`00oooooooooooo00Oooooo0_l0000Aooooo`007Oooool00ol0003ooooooooo
o`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool00ol00?oooooooooo
o`08ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Gooooo`;o003o2?ooool00ol00?ooooooooooo`05
ooooo`;o003o6Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool05oooool2o`00o`Oooooo00?o003oooooooooool01_ooool2o`00oaWooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Oooooo0_l00?l7
ooooo`03o`00oooooooooooo00Kooooo0_l00?lIooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Gooooo`;o003o1oooool00ol00?ooooooooooo`05
ooooo`;o003o6_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool05oooool2o`00o`Sooooo00?o003oooooooooool01Oooool2o`00oaWooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`08oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool2o`00o`Sooooo00?o003ooooo
ooooool01Oooool2o`00oaWooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01Oooooo0_l00?l7ooooo`03o`00oooooooooooo00Kooooo0_l00?lIoooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Goooo
o`;o003o1oooool00ol00?ooooooooooo`06ooooo`;o003o6Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool05oooool2o`00o`Oooooo00?o003ooooo
ooooool01Oooool2o`00oa[ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01Oooooo0_l00?l8ooooo`03o`00oooooooooooo00Gooooo0_l00?lIoooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03oooool001gooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003ooooooooo
ool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003ooooooooo
ool08Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool08Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Sooooo00?o0000oooooooo
ool03oooool001gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo023ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo00Sooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool08?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?oo
ool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool08Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Ooo
ool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03ooo
ool001gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo027ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooo
oooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo023ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooo
oooo00Sooooo00?o0000ooooooooool03oooool001gooooo0ol00008ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
023ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo
023ooooo00?o003oooooooooool01oooool2o`00017ooooo000Mooooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo023o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023o
oooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027o
oooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00oo
oooo000Mooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Qooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?oooooo
ooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool08?ooool00ol00?oooooo
ooooo`08ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o
003oooooooooool08?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00oooooo000M
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Q
ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Q
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0P
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`08
ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003ooooo
ooooool08?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00oooooo000Mooooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03
o`00oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo023ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03
o`00oooooooooooo027ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo027ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`08ooooo`03
o`000?oooooooooo00oooooo000Mooooo`?o00002?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo023ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo00Oooooo0_l0000Aooooo`007Oooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooo
oooooooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo023ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooo
oooooooo023ooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`007Oooool0
0ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool08Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool0
0ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02?ooool0
0ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
023ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo
023ooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003o
ooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?oo
ooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool08Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?oo
ooooooooo`0Qooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Qooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`0?ooooo`004_ooool5o`0000Kooooo00?o0000ooooooooool02?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool08?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?oooooo
ooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`0Pooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03oooool001?ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo
00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo023ooooo
00?o003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`005?ooool00ol0003ooooooooo
o`06ooooo`Co00001oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o
003oooooooooool08?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool08Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Gooooo1?l0
000Aooooo`005Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo023ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003o
ooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool08?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00oooooo000Boooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`08ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooo
oooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo023ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo
oooo023ooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`004_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Q
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0P
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0P
ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03oooool001?ooooo0ol00007oooo
o`03o`000?oooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qoooo
o`03o`00oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo023ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Qoooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Poooo
o`03o`00oooooooooooo027ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo027ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo023ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003ooooooooo
ool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003ooooooooo
ool08?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00
oooooooooooo023ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo023ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`08ooooo`03o`00
0?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool08Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?oo
ool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool08?oo
ool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00oooooo000Mooooo`?o00002?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool08?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool0
0ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool08Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Oooooo0_l0000Aooooo`007Oooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol0
0?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool08Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02?ooool00ol0
003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023o
oooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo023o
oooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003ooooo
ooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool08Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?oooooo
ooooo`0Qooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Qooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`0?ooooo`007Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool08Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`08
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0P
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0P
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`0Q
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Q
ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?
ooooo`007Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool08Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo027ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool08Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool08?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool02?ooool00ol0003oooooooooo`0?ooooo`007Oooool3o`0000Sooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Pooooo`;o003o8_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool08?ooool2o`00ob;ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo023ooooo0_l00?lRooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Oooooo`;o
003o8oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool08?ooool2o`00ob;ooooo00?o003oooooooooool01oooool2o`00017ooooo000Mooooo`03o`00
0?oooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Pooooo`;o003o
8_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
8?ooool2o`00ob;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo023ooooo0_l00?lRooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0Oooooo`;o003o8oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08?ooool2o`00ob;ooooo00?o003oooooooooool0
2?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`08ooooo`03o`000?oo
oooooooo00oooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03oooool0
01gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
04Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
04Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003o
ooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?oo
ooooooooo`08ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Sooooo
00?o0000ooooooooool03oooool001gooooo0ol00008ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool0A?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool0A?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool0A?ooool00ol00?ooooooooooo`07ooooo`;o00004Oooool001gooooo00?o0000
ooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04Cooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`08oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00Sooooo00?o0000oooooooo
ool03oooool001gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo04Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo04Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo04Cooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`005?oo
ool3o`0000Kooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`06ooooo`;o003oAOoo
ool2o`00o`Oooooo00?o003oooooooooool01Oooool2o`00odGooooo0_l00?l8ooooo`03o`00oooo
oooooooo00Gooooo0_l00?m5ooooo`;o003o2?ooool00ol00?ooooooooooo`05ooooo`;o003oAOoo
ool2o`00o`Oooooo00?o003oooooooooool01_ooool2o`00odGooooo0_l00?l9ooooo`03o`000?oo
oooooooo00oooooo000Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol00?ooooooooooo`06ooooo`;o003oAOooool2o`00o`Oooooo00?o003oooooooooool01Oooool2
o`00odGooooo0_l00?l8ooooo`03o`00oooooooooooo00Gooooo0_l00?m5ooooo`;o003o2?ooool0
0ol00?ooooooooooo`05ooooo`;o003oAOooool2o`00o`Oooooo00?o003oooooooooool01_ooool2
o`00odGooooo0_l00?l9ooooo`03o`000?oooooooooo00oooooo000Booooo`Go00001_ooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol0
0?ooooooooooo`1Fooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0F?ooool00ol0
003oooooooooo`0?ooooo`004_ooool01?l0003oooooooooool00007ooooo`Co00001oooool00ol0
0?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol0
0?ooooooooooo`1Eooooo`03o`00oooooooooooo05Gooooo1?l0000Aooooo`004oooool00ol0003o
ooooo`000007ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0E_ooool00ol00?oo
ooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0EOooool00ol00?oo
ooooooooo`1Hooooo`03o`000?oooooooooo00oooooo000Dooooo`;o00001oooool00ol0003ooooo
ooooo`08ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol00?oooooo
ooooo`1Fooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0F?ooool00ol0003ooooo
ooooo`0?ooooo`005Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o
003oooooooooool0EOooool00ol00?ooooooooooo`1Hooooo`03o`000?oooooooooo00oooooo000M
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1F
ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1H
ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o003ooooo
ooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003ooooo
ooooool0EOooool00ol00?ooooooooooo`1Hooooo`03o`000?oooooooooo00oooooo000Mooooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03
o`00oooooooooooo05Kooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1Hooooo`03
o`000?oooooooooo00oooooo000Mooooo`?o00002?ooool00ol00?ooooooooooo`1Fooooo`03o`00
oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Eooooo`03o`00
oooooooooooo05Oooooo0_l0000Aooooo`007Oooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooooooo05Kooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03o`00oooo
oooooooo05Gooooo00?o003oooooooooool0F?ooool00ol0003oooooooooo`0?ooooo`007Oooool0
0ol0003oooooooooo`08ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_ooool0
0ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0F?ooool0
0ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo
05Kooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo
05Gooooo00?o003oooooooooool0F?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003o
ooooooooo`08ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol00?oo
ooooooooo`1Fooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0F?ooool00ol0003o
ooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo05Kooooo
00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Gooooo
00?o003oooooooooool0F?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003ooooooooo
o`08ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol00?oooooooooo
o`1Fooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0F?ooool00ol0003ooooooooo
o`0?ooooo`007Oooool3o`0000Sooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1F
ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1G
ooooo`;o00004Oooool001gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`1Foooo
o`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Eoooo
o`03o`00oooooooooooo05Sooooo00?o0000ooooooooool03oooool001gooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003ooooooooo
ool0E_ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Sooooo00?o0000oooooooo
ool03oooool001gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`1Fooooo`03o`00
oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Eooooo`03o`00
oooooooooooo05Sooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_oo
ool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool03ooo
ool001gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooo
oooo05Kooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooo
oooo05Sooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool02?ooool00ol0
0?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol0
0?ooooooooooo`1Eooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool03oooool001go
oooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Ko
oooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05So
oooo00?o0000ooooooooool03oooool001gooooo0ol00008ooooo`03o`00oooooooooooo05Kooooo
00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Gooooo
00?o003oooooooooool0Eoooool2o`00017ooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o
003oooooooooool0EOooool00ol00?ooooooooooo`1Hooooo`03o`000?oooooooooo00oooooo000M
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1F
ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1H
ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo00Sooooo00?o003ooooo
ooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003ooooo
ooooool0EOooool00ol00?ooooooooooo`1Hooooo`03o`000?oooooooooo00oooooo000Mooooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03
o`00oooooooooooo05Kooooo00?o003oooooooooool0EOooool00ol00?ooooooooooo`1Hooooo`03
o`000?oooooooooo00oooooo000Cooooo`?o00001oooool00ol0003oooooooooo`08ooooo`03o`00
oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03o`00
oooooooooooo05Gooooo00?o003oooooooooool0F?ooool00ol0003oooooooooo`0?ooooo`004_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool02?ooool00ol00?oooooo
ooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol00?oooooo
ooooo`1Eooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool03oooool001;ooooo00Go
0000ooooooooooooooooo`000006ooooo`Co00001oooool00ol00?ooooooooooo`1Fooooo`03o`00
oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Eooooo`03o`00
oooooooooooo05Gooooo1?l0000Aooooo`004_ooool4o`0000Oooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_oo
ool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool03ooo
ool001;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00oooooooo
oooo05Kooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooo
oooo05Gooooo00?o003oooooooooool0F?ooool00ol0003oooooooooo`0?ooooo`004oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0E_ooool00ol0
0?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0EOooool00ol0
0?ooooooooooo`1Hooooo`03o`000?oooooooooo00oooooo000Dooooo`;o00001oooool00ol0003o
ooooooooo`08ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol00?oo
ooooooooo`1Fooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0F?ooool00ol0003o
ooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo05Kooooo
00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Gooooo
00?o003oooooooooool0F?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003ooooooooo
o`08ooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol00?oooooooooo
o`1Fooooo`03o`00oooooooooooo05Gooooo00?o003oooooooooool0F?ooool00ol0003ooooooooo
o`0?ooooo`007Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo05Kooooo00?o003o
ooooooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Gooooo00?o003o
ooooooooool0F?ooool00ol0003oooooooooo`0?ooooo`007Oooool3o`0000Sooooo00?o003ooooo
ooooool0E_ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003ooooo
ooooool0EOooool00ol00?ooooooooooo`1Gooooo`;o00004Oooool001gooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003ooooooooo
ool0E_ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Sooooo00?o0000oooooooo
ool03oooool001gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`1Fooooo`03o`00
oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Eooooo`03o`00
oooooooooooo05Sooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_oo
ool00ol00?ooooooooooo`1Eooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool03ooo
ool001gooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`1Fooooo`03o`00oooooooo
oooo05Kooooo00?o003oooooooooool0E_ooool00ol00?ooooooooooo`1Eooooo`03o`00oooooooo
oooo05Sooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool02?ooool00ol0
0?ooooooooooo`1Fooooo`03o`00oooooooooooo05Kooooo00?o003oooooooooool0E_ooool00ol0
0?ooooooooooo`1Eooooo`03o`00oooooooooooo05Sooooo00?o0000ooooooooool03oooool001go
oooo00?o0000ooooooooool02?ooool2o`00oeKooooo0_l00?mGooooo`;o003oEoooool2o`00oeOo
oooo0_l00?mIooooo`03o`000?oooooooooo00oooooo000Mooooo`?o00002?ooool2o`00oeKooooo
0_l00?mGooooo`;o003oEoooool2o`00oeOooooo0_l00?mHooooo`;o00004Oooool001gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool0E_ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooool000004Oooool001gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooo0000017ooooo000Moooooooo0000bol0000Aooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-4.59445, -4.09998, 0.112615, \
0.0679418}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DTFT", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X\[Theta]\  = DTFT[xd, \[Theta]];\)\), "\[IndentingNewLine]", 
    \(X\[Theta]\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`7 + \((\@5 + 
            1\/2\ \((1 + \@5)\))\)\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((\(-1\) + \@5)\))\)\ \[ExponentialE]\^\(\(-2\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((1 - \@5)\))\)\ \[ExponentialE]\^\(\(-3\)\ \[ImaginaryI]\ \
\[Theta]\) + \((\@5 + 
            1\/2\ \((\(-1\) - \@5)\))\)\ \[ExponentialE]\^\(\(-4\)\ \
\[ImaginaryI]\ \[Theta]\) + 
      3\ \[ExponentialE]\^\(\(-5\)\ \[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((\(-1\) - \@5)\))\)\ \[ExponentialE]\^\(\(-6\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((1 - \@5)\))\)\ \[ExponentialE]\^\(\(-7\)\ \[ImaginaryI]\ \
\[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((\(-1\) + \@5)\))\)\ \[ExponentialE]\^\(\(-8\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((1 + \@5)\))\)\ \[ExponentialE]\^\(\(-9\)\ \[ImaginaryI]\ \
\[Theta]\) + 
      7\ \[ExponentialE]\^\(\(-10\)\ \[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((1 + \@5)\))\)\ \[ExponentialE]\^\(\(-11\)\ \[ImaginaryI]\
\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((\(-1\) + \@5)\))\)\ \[ExponentialE]\^\(\(-12\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((1 - \@5)\))\)\ \[ExponentialE]\^\(\(-13\)\ \[ImaginaryI]\
\ \[Theta]\) + \((\@5 + 
            1\/2\ \((\(-1\) - \@5)\))\)\ \[ExponentialE]\^\(\(-14\)\ \
\[ImaginaryI]\ \[Theta]\) + 
      3\ \[ExponentialE]\^\(\(-15\)\ \[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((\(-1\) - \@5)\))\)\ \[ExponentialE]\^\(\(-16\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((1 - \@5)\))\)\ \[ExponentialE]\^\(\(-17\)\ \[ImaginaryI]\
\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((\(-1\) + \@5)\))\)\ \[ExponentialE]\^\(\(-18\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((1 + \@5)\))\)\ \[ExponentialE]\^\(\(-19\)\ \[ImaginaryI]\
\ \[Theta]\) + 
      7\ \[ExponentialE]\^\(\(-20\)\ \[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((1 + \@5)\))\)\ \[ExponentialE]\^\(\(-21\)\ \[ImaginaryI]\
\ \[Theta]\) + \((\(-\@5\) + 
            
            1\/2\ \((\(-1\) + \@5)\))\)\ \[ExponentialE]\^\(\(-22\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((1 - \@5)\))\)\ \[ExponentialE]\^\(\(-23\)\ \[ImaginaryI]\
\ \[Theta]\) + \((\@5 + 
            1\/2\ \((\(-1\) - \@5)\))\)\ \[ExponentialE]\^\(\(-24\)\ \
\[ImaginaryI]\ \[Theta]\) + 
      3\ \[ExponentialE]\^\(\(-25\)\ \[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((\(-1\) - \@5)\))\)\ \[ExponentialE]\^\(\(-26\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((1 - \@5)\))\)\ \[ExponentialE]\^\(\(-27\)\ \[ImaginaryI]\
\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((\(-1\) + \@5)\))\)\ \[ExponentialE]\^\(\(-28\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((1 + \@5)\))\)\ \[ExponentialE]\^\(\(-29\)\ \[ImaginaryI]\
\ \[Theta]\) + 
      7\ \[ExponentialE]\^\(\(-30\)\ \[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((1 + \@5)\))\)\ \[ExponentialE]\^\(\(-31\)\ \[ImaginaryI]\
\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((\(-1\) + \@5)\))\)\ \[ExponentialE]\^\(\(-32\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((1 - \@5)\))\)\ \[ExponentialE]\^\(\(-33\)\ \[ImaginaryI]\
\ \[Theta]\) + \((\@5 + 
            1\/2\ \((\(-1\) - \@5)\))\)\ \[ExponentialE]\^\(\(-34\)\ \
\[ImaginaryI]\ \[Theta]\) + 
      3\ \[ExponentialE]\^\(\(-35\)\ \[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((\(-1\) - \@5)\))\)\ \[ExponentialE]\^\(\(-36\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((1 - \@5)\))\)\ \[ExponentialE]\^\(\(-37\)\ \[ImaginaryI]\
\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((\(-1\) + \@5)\))\)\ \[ExponentialE]\^\(\(-38\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((1 + \@5)\))\)\ \[ExponentialE]\^\(\(-39\)\ \[ImaginaryI]\
\ \[Theta]\) + 
      7\ \[ExponentialE]\^\(\(-40\)\ \[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((1 + \@5)\))\)\ \[ExponentialE]\^\(\(-41\)\ \[ImaginaryI]\
\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((\(-1\) + \@5)\))\)\ \[ExponentialE]\^\(\(-42\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((1 - \@5)\))\)\ \[ExponentialE]\^\(\(-43\)\ \[ImaginaryI]\
\ \[Theta]\) + \((\@5 + 
            1\/2\ \((\(-1\) - \@5)\))\)\ \[ExponentialE]\^\(\(-44\)\ \
\[ImaginaryI]\ \[Theta]\) + 
      3\ \[ExponentialE]\^\(\(-45\)\ \[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((\(-1\) - \@5)\))\)\ \[ExponentialE]\^\(\(-46\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((1 - \@5)\))\)\ \[ExponentialE]\^\(\(-47\)\ \[ImaginaryI]\
\ \[Theta]\) + \((\(-\@5\) + 
            1\/2\ \((\(-1\) + \@5)\))\)\ \[ExponentialE]\^\(\(-48\)\ \
\[ImaginaryI]\ \[Theta]\) + \((\@5 + 
            1\/2\ \((1 + \@5)\))\)\ \[ExponentialE]\^\(\(-49\)\ \[ImaginaryI]\
\ \[Theta]\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X\[Theta]\  = \ 
        X\[Theta]\  // \ Simplify;\)\), "\[IndentingNewLine]", 
    \(X\[Theta]\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\/2\ \[ExponentialE]\^\(\(-49\)\ \[ImaginaryI]\ \
\[Theta]\)\ \((1 + 3\ \@5 - 
          2\ \((1 + 
                2\ \@5)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) + \
\((3 + \@5)\)\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \[Theta]\) - 
          4\ \[ExponentialE]\^\(3\ \[ImaginaryI]\ \[Theta]\) + 
          10\ \[ExponentialE]\^\(4\ \[ImaginaryI]\ \[Theta]\) + \((\(-11\) + \
\@5)\)\ \[ExponentialE]\^\(5\ \[ImaginaryI]\ \[Theta]\) - 
          4\ \((\(-3\) + \@5)\)\ \[ExponentialE]\^\(6\ \[ImaginaryI]\ \
\[Theta]\) + \((\(-13\) + 
                3\ \@5)\)\ \[ExponentialE]\^\(7\ \[ImaginaryI]\ \[Theta]\) + 
          14\ \[ExponentialE]\^\(8\ \[ImaginaryI]\ \[Theta]\))\)\ \((1 + \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(10\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(11\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(20\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(21\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(30\ \[ImaginaryI]\ \[Theta]\) \
+ \[ExponentialE]\^\(31\ \[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(40\ \
\[ImaginaryI]\ \[Theta]\) + \[ExponentialE]\^\(41\ \[ImaginaryI]\ \[Theta]\))\
\)\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plots of DTFT", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g1 = 
        Plot[Abs[X\[Theta]], {\[Theta], \(-\[Pi]\), \[Pi]}, \ 
          PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[Arg[X\[Theta]], {\[Theta], \(-\[Pi]\), \[Pi]}, \ 
          PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(ga = 
        Show[GraphicsArray[{{g1, g2}}], ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.0147151 0.00585664 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13185 -12 -4.5 ]
[-0.0125 .13185 0 4.5 ]
[-0.0125 .24898 -12 -4.5 ]
[-0.0125 .24898 0 4.5 ]
[-0.0125 .36611 -12 -4.5 ]
[-0.0125 .36611 0 4.5 ]
[-0.0125 .48325 -12 -4.5 ]
[-0.0125 .48325 0 4.5 ]
[-0.0125 .60038 -18 -4.5 ]
[-0.0125 .60038 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13185 m
.00625 .13185 L
s
[(20)] -0.0125 .13185 1 0 Mshowa
0 .24898 m
.00625 .24898 L
s
[(40)] -0.0125 .24898 1 0 Mshowa
0 .36611 m
.00625 .36611 L
s
[(60)] -0.0125 .36611 1 0 Mshowa
0 .48325 m
.00625 .48325 L
s
[(80)] -0.0125 .48325 1 0 Mshowa
0 .60038 m
.00625 .60038 L
s
[(100)] -0.0125 .60038 1 0 Mshowa
.125 Mabswid
0 .044 m
.00375 .044 L
s
0 .07328 m
.00375 .07328 L
s
0 .10256 m
.00375 .10256 L
s
0 .16113 m
.00375 .16113 L
s
0 .19041 m
.00375 .19041 L
s
0 .2197 m
.00375 .2197 L
s
0 .27826 m
.00375 .27826 L
s
0 .30755 m
.00375 .30755 L
s
0 .33683 m
.00375 .33683 L
s
0 .3954 m
.00375 .3954 L
s
0 .42468 m
.00375 .42468 L
s
0 .45396 m
.00375 .45396 L
s
0 .51253 m
.00375 .51253 L
s
0 .54181 m
.00375 .54181 L
s
0 .5711 m
.00375 .5711 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13185 m
1 .13185 L
s
.99375 .24898 m
1 .24898 L
s
.99375 .36611 m
1 .36611 L
s
.99375 .48325 m
1 .48325 L
s
.99375 .60038 m
1 .60038 L
s
.125 Mabswid
.99625 .044 m
1 .044 L
s
.99625 .07328 m
1 .07328 L
s
.99625 .10256 m
1 .10256 L
s
.99625 .16113 m
1 .16113 L
s
.99625 .19041 m
1 .19041 L
s
.99625 .2197 m
1 .2197 L
s
.99625 .27826 m
1 .27826 L
s
.99625 .30755 m
1 .30755 L
s
.99625 .33683 m
1 .33683 L
s
.99625 .3954 m
1 .3954 L
s
.99625 .42468 m
1 .42468 L
s
.99625 .45396 m
1 .45396 L
s
.99625 .51253 m
1 .51253 L
s
.99625 .54181 m
1 .54181 L
s
.99625 .5711 m
1 .5711 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02608 .0297 L
.02847 .04322 L
.02972 .04867 L
.03089 .05246 L
.03124 .05331 L
.03157 .05401 L
.03186 .05454 L
.03218 .055 L
.03234 .05519 L
.03252 .05537 L
.03269 .05551 L
.03284 .05561 L
.03292 .05565 L
.03301 .05569 L
.03311 .05572 L
.03321 .05574 L
.03329 .05575 L
.03338 .05575 L
.03347 .05574 L
.03355 .05572 L
.0337 .05568 L
.03383 .05561 L
.03398 .05552 L
.03414 .05539 L
.03446 .05505 L
.03476 .05463 L
.03533 .05356 L
.03587 .05222 L
.03707 .04821 L
.03838 .04235 L
.04072 .0289 L
.04196 .02076 L
.0423 .01847 L
.04249 .01722 L
.04266 .01605 L
.04281 .01504 L
.04297 .01546 L
.04306 .01607 L
.04314 .01665 L
.0433 .01773 L
.04574 .03359 L
.04804 .04581 L
.04921 .05045 L
.04985 .05244 L
.05045 .05392 L
.05096 .05488 L
.05125 .05529 L
.05151 .05559 L
.05165 .05572 L
Mistroke
.0518 .05583 L
.05188 .05589 L
.05196 .05593 L
.05211 .05599 L
.05225 .05602 L
.0524 .05604 L
.05254 .05603 L
.05268 .056 L
.05283 .05593 L
.05297 .05585 L
.05324 .05564 L
.05354 .05532 L
.05385 .05486 L
.05442 .05376 L
.05495 .05244 L
.05616 .04834 L
.05744 .04253 L
.05982 .02868 L
.06087 .0218 L
.06142 .01806 L
.06157 .01698 L
.06172 .01595 L
.06186 .01503 L
.062 .01539 L
.06215 .01642 L
.06231 .0175 L
.06259 .01944 L
.06314 .02316 L
.06434 .03101 L
.06556 .03834 L
.06686 .04515 L
.0681 .05035 L
.06922 .05381 L
.06977 .055 L
.07005 .05551 L
.07036 .05594 L
.07062 .05623 L
.07077 .05635 L
.07092 .05646 L
.07106 .05654 L
.07118 .05659 L
.07131 .05662 L
.07143 .05663 L
.07158 .05662 L
.07167 .05661 L
.07174 .05659 L
.07189 .05653 L
.07204 .05644 L
.0723 .05624 L
.07258 .05592 L
Mistroke
.07289 .05548 L
.07322 .05489 L
.07381 .05352 L
.07497 .04981 L
.07603 .04528 L
.07832 .03248 L
.07963 .02387 L
.08025 .01962 L
.08052 .01773 L
.08067 .01666 L
.08082 .01565 L
.08096 .01474 L
.0811 .01577 L
.08141 .01788 L
.08204 .02228 L
.08319 .03004 L
.08572 .04486 L
.08695 .05035 L
.0876 .05267 L
.08829 .05467 L
.08889 .056 L
.08923 .05658 L
.08955 .057 L
.08969 .05715 L
.08984 .05728 L
.08997 .05738 L
.09011 .05746 L
.09026 .05752 L
.0904 .05755 L
.09048 .05756 L
.09056 .05756 L
.09071 .05754 L
.09085 .0575 L
.091 .05743 L
.09114 .05734 L
.09127 .05723 L
.09159 .0569 L
.09189 .05648 L
.09248 .05535 L
.09313 .05367 L
.09428 .04957 L
.09535 .04463 L
.09763 .03122 L
.09882 .02308 L
.09947 .01847 L
.09964 .01731 L
.09979 .0162 L
.09993 .01521 L
.10008 .0153 L
.10016 .01587 L
Mistroke
.10024 .01646 L
.10039 .01753 L
.10073 .01991 L
.10143 .0249 L
.10267 .03332 L
.10384 .04061 L
.10511 .0474 L
.10634 .05268 L
.10746 .05618 L
.108 .05736 L
.10831 .05788 L
.10859 .05827 L
.10873 .05843 L
.10886 .05855 L
.10899 .05865 L
.10911 .05873 L
.10925 .0588 L
.10938 .05884 L
.10952 .05886 L
.10967 .05886 L
.10982 .05883 L
.10997 .05878 L
.11005 .05874 L
.11013 .05869 L
.1103 .05856 L
.11061 .05825 L
.1109 .05784 L
.11144 .05683 L
.11202 .05536 L
.11333 .05068 L
.11454 .04487 L
.11702 .02944 L
.11764 .02506 L
.11822 .02081 L
.11875 .01693 L
.11889 .01587 L
.11904 .01474 L
.11918 .01566 L
.11932 .01672 L
.12154 .03277 L
.12278 .04088 L
.12391 .04738 L
.12503 .05273 L
.12563 .05505 L
.12626 .0571 L
.12661 .05805 L
.12693 .05878 L
.12725 .05941 L
.12755 .05987 L
.12785 .06023 L
Mistroke
.12801 .06037 L
.12818 .06049 L
.12833 .06056 L
.12847 .06061 L
.12862 .06063 L
.1287 .06063 L
.12878 .06062 L
.12892 .06059 L
.12905 .06053 L
.1292 .06045 L
.12936 .06032 L
.12968 .05998 L
.12997 .05955 L
.13051 .05849 L
.13108 .057 L
.13228 .05264 L
.13359 .04617 L
.13615 .02944 L
.13674 .02507 L
.13737 .02034 L
.13762 .01837 L
.1379 .01624 L
.13806 .01501 L
.1382 .01553 L
.13835 .01666 L
.13848 .01773 L
.13965 .02667 L
.14091 .03591 L
.1432 .05024 L
.14436 .05577 L
.145 .05819 L
.14559 .06003 L
.1461 .06126 L
.14636 .06176 L
.14665 .06221 L
.14694 .06257 L
.14711 .06272 L
.14726 .06283 L
.1474 .0629 L
.14753 .06294 L
.14767 .06297 L
.14781 .06297 L
.14795 .06294 L
.1481 .06288 L
.14824 .0628 L
.14837 .0627 L
.14869 .06237 L
.14898 .06193 L
.14958 .06073 L
.15022 .05892 L
Mistroke
.15138 .05443 L
.15245 .04894 L
.15472 .03393 L
.15591 .02472 L
.15656 .01947 L
.15688 .01688 L
.15702 .01574 L
.15717 .01492 L
.15733 .01623 L
.15748 .01746 L
.15781 .02018 L
.15851 .0259 L
.15975 .03562 L
.16091 .04399 L
.16218 .05205 L
.16341 .05834 L
.16398 .06064 L
.16457 .06265 L
.16487 .06351 L
.16521 .06431 L
.16551 .06492 L
.16579 .06536 L
.16595 .06556 L
.16612 .06574 L
.16621 .06583 L
.1663 .06589 L
.16639 .06595 L
.16647 .06599 L
.16662 .06604 L
.16669 .06606 L
.16678 .06607 L
.16687 .06606 L
.16695 .06605 L
.1671 .066 L
.16725 .06592 L
.16742 .0658 L
.16757 .06565 L
.16771 .06549 L
.16826 .06457 L
.16855 .06394 L
.16886 .06311 L
.1695 .06104 L
.17065 .05599 L
.17172 .04991 L
.17397 .03362 L
.17516 .02371 L
.17576 .01852 L
.17592 .01708 L
.17601 .01629 L
.1761 .01553 L
Mistroke
.17618 .01483 L
.17626 .01536 L
.17642 .0167 L
.17775 .02836 L
.17898 .03867 L
.18026 .04838 L
.18141 .05601 L
.18263 .06252 L
.18319 .06489 L
.18378 .06694 L
.18408 .06781 L
.18441 .06861 L
.18472 .0692 L
.185 .06963 L
.18515 .06982 L
.18532 .06998 L
.18542 .07005 L
.18551 .07011 L
.18559 .07015 L
.18568 .07018 L
.18583 .07021 L
.18598 .07021 L
.18606 .07019 L
.18614 .07016 L
.18622 .07013 L
.18631 .07007 L
.18646 .06996 L
.18662 .0698 L
.18691 .06941 L
.1872 .06891 L
.18746 .06833 L
.18806 .06666 L
.18869 .06432 L
.18974 .05921 L
.1909 .05198 L
.19221 .04214 L
.19344 .0315 L
.19455 .02122 L
.19486 .01834 L
.19503 .01674 L
.19518 .01524 L
.19533 .0156 L
.19549 .01712 L
.19577 .01978 L
.198 .04062 L
.19926 .05128 L
.20045 .05992 L
.20161 .06685 L
.2022 .06972 L
.20285 .07225 L
Mistroke
.20321 .07336 L
.20354 .07422 L
.20385 .07488 L
.20401 .07515 L
.20418 .0754 L
.20434 .07559 L
.20448 .07572 L
.20462 .07582 L
.20476 .07588 L
.20492 .07592 L
.20506 .07592 L
.20515 .0759 L
.20522 .07587 L
.20531 .07583 L
.20539 .07578 L
.20553 .07566 L
.20568 .0755 L
.20595 .07513 L
.20627 .07452 L
.20657 .07381 L
.20721 .0718 L
.20781 .06929 L
.20888 .06351 L
.21004 .05543 L
.21137 .0442 L
.21262 .03217 L
.21374 .02056 L
.21404 .01729 L
.2142 .01564 L
.21429 .01473 L
.21437 .0156 L
.21495 .02182 L
.21742 .0475 L
.21968 .06698 L
.22084 .07458 L
.22145 .07776 L
.22209 .08048 L
.22266 .08225 L
.22298 .08301 L
.22314 .0833 L
.22328 .08355 L
.22341 .08373 L
.22356 .08389 L
.22369 .084 L
.22381 .08408 L
.22395 .08414 L
.22409 .08415 L
.22424 .08413 L
.22438 .08407 L
.22452 .08398 L
Mistroke
.22467 .08383 L
.22494 .08347 L
.22526 .08285 L
.22556 .08212 L
.22619 .07997 L
.2268 .07724 L
.22787 .07087 L
.22903 .06183 L
.23137 .03822 L
.23201 .03081 L
.2327 .02253 L
.23301 .01865 L
.23319 .01652 L
.23327 .01548 L
.23335 .0149 L
.23349 .0166 L
.23363 .01843 L
.23395 .02231 L
.23641 .05215 L
.23868 .07549 L
.2398 .08443 L
.24038 .08816 L
.24099 .09148 L
.24132 .09292 L
.24161 .09405 L
.24191 .09501 L
.24219 .09574 L
.24251 .09637 L
.24268 .09661 L
.24277 .09671 L
.24286 .0968 L
.24295 .09687 L
.24304 .09691 L
.24311 .09694 L
.2432 .09696 L
.24334 .09695 L
.2435 .09688 L
.24366 .09676 L
.24381 .0966 L
.24397 .09637 L
.24414 .09606 L
.24442 .0954 L
.24474 .09445 L
.24532 .09214 L
.24586 .08929 L
.24707 .08066 L
.24838 .06813 L
.25076 .03845 L
.25141 .02917 L
.25176 .02393 L
Mistroke
.2521 .01892 L
.25225 .01663 L
.25233 .01547 L
.25242 .01524 L
.25251 .01662 L
.25259 .01792 L
.25276 .0204 L
.25335 .02946 L
.25585 .06657 L
.25814 .09503 L
.25929 .10596 L
.25989 .11056 L
.26054 .11449 L
.2611 .11705 L
.26142 .11813 L
.26157 .11854 L
.26173 .1189 L
.26186 .11916 L
.262 .11938 L
.26213 .11953 L
.26225 .11964 L
.2624 .1197 L
.26253 .11971 L
.26268 .11966 L
.26282 .11955 L
.26296 .11939 L
.26311 .11915 L
.26338 .11857 L
.2637 .1176 L
.26399 .11645 L
.26463 .1131 L
.26523 .10885 L
.2663 .09889 L
.26746 .08461 L
.26878 .06442 L
.27003 .04225 L
.27057 .0318 L
.27115 .02037 L
.2713 .01743 L
.27145 .01518 L
.27154 .01701 L
.27162 .01868 L
.27178 .02197 L
.27236 .03407 L
.27481 .08528 L
.27708 .12757 L
.27818 .14429 L
.27939 .15884 L
.28001 .16452 L
.2806 .16858 L
Mistroke
.28092 .17026 L
.28122 .17143 L
.28138 .17191 L
.28155 .17231 L
.28163 .17247 L
.28172 .17261 L
.28181 .17271 L
.28189 .17277 L
.28203 .17281 L
.28217 .17278 L
.28232 .17265 L
.28248 .1724 L
.28255 .17224 L
.28264 .17203 L
.2828 .17156 L
.28309 .17039 L
.28337 .16893 L
.28367 .16698 L
.2842 .16248 L
.28488 .15487 L
.28552 .14577 L
.28671 .12378 L
.28894 .06613 L
.28954 .04683 L
.28988 .03563 L
.2902 .02468 L
.29034 .01962 L
.29049 .01526 L
.29057 .01812 L
.29066 .02131 L
.29081 .02698 L
.29137 .04823 L
.29378 .14857 L
.29632 .26274 L
.29886 .37429 L
.30118 .46494 L
.30233 .50316 L
.30358 .53874 L
.30475 .56554 L
.30586 .58449 L
.30645 .59206 L
.30677 .59527 L
.3071 .59808 L
.30738 .59999 L
.30753 .60082 L
.30769 .60158 L
.30783 .60216 L
.30797 .60259 L
.3081 .60292 L
.30823 .60314 L
Mistroke
.30837 .60329 L
.30845 .60332 L
.30853 .60331 L
.30869 .60321 L
.30877 .60309 L
.30886 .60294 L
.30899 .60262 L
.30914 .60215 L
.30944 .60085 L
.30977 .59885 L
.31012 .59608 L
.31075 .58945 L
.3114 .58066 L
.31199 .57076 L
.31333 .54242 L
.31576 .4727 L
.32051 .29438 L
.32507 .11972 L
.32628 .07977 L
.32742 .04541 L
.32805 .02813 L
.32822 .02361 L
.3284 .0189 L
.32849 .01665 L
.32858 .01488 L
.32873 .01873 L
.32994 .0455 L
.33112 .06698 L
.33236 .08445 L
.33343 .09523 L
.33403 .0997 L
.33459 .10283 L
.33491 .10416 L
.3352 .10513 L
.33552 .10592 L
.33568 .1062 L
.33576 .10632 L
.33585 .10643 L
.33601 .10656 L
.33615 .10663 L
.3363 .10663 L
.33639 .10661 L
.33647 .10657 L
.33662 .10646 L
.33675 .10631 L
.3369 .10609 L
.33705 .10582 L
.33732 .10518 L
.33761 .10433 L
.33812 .10233 L
Mistroke
.33868 .09958 L
.33929 .09589 L
.34164 .07655 L
.34416 .05053 L
.34538 .03742 L
.34603 .03062 L
.34671 .02357 L
.34731 .01766 L
.34748 .01607 L
.34757 .01519 L
.34765 .01504 L
.34781 .01651 L
.34797 .01803 L
.34914 .0282 L
.35029 .03694 L
.35152 .04471 L
.35268 .05045 L
.35373 .0543 L
.35431 .05586 L
.35463 .05654 L
.35493 .05708 L
.35521 .05748 L
.35546 .05777 L
.35574 .05801 L
.35589 .05811 L
.35604 .05817 L
.3562 .05822 L
.35634 .05824 L
.35642 .05824 L
.35651 .05823 L
.35666 .05819 L
.35681 .05814 L
.35696 .05806 L
.35724 .05785 L
.35756 .0575 L
.35786 .05709 L
.35855 .05581 L
.35915 .05433 L
.35981 .05235 L
.361 .04784 L
.36324 .03669 L
.36562 .02185 L
.3662 .01792 L
.36636 .01682 L
.36653 .01567 L
.36667 .01475 L
.36683 .01584 L
.36751 .02067 L
.36816 .02525 L
.37072 .04317 L
Mistroke
.37305 .05743 L
.37421 .06314 L
.37482 .06564 L
.37547 .06785 L
.37604 .06937 L
.37634 .07002 L
.37666 .07057 L
.37681 .07079 L
.37696 .07096 L
.3771 .0711 L
.37723 .0712 L
.37735 .07128 L
.37748 .07133 L
.37763 .07136 L
.37776 .07136 L
.3779 .07133 L
.37804 .07127 L
.37819 .07118 L
.37835 .07103 L
.37852 .07084 L
.37867 .07061 L
.37897 .07007 L
.37951 .06873 L
.38009 .0667 L
.38072 .0638 L
.38139 .05991 L
.3826 .0508 L
.38373 .03974 L
.38433 .03298 L
.38495 .02517 L
.38522 .02164 L
.3855 .01773 L
.38559 .01655 L
.38567 .01542 L
.38581 .01614 L
.38595 .01818 L
.3861 .02042 L
.38716 .03711 L
.3921 .13243 L
.39456 .18356 L
.39686 .22798 L
.39921 .26596 L
.40036 .2808 L
.40143 .29185 L
.40199 .29651 L
.40261 .30073 L
.40323 .30397 L
.40357 .30531 L
.40389 .30629 L
.40416 .3069 L
Mistroke
.4043 .30714 L
.40445 .30734 L
.40458 .30745 L
.40471 .30753 L
.40484 .30756 L
.40496 .30754 L
.40511 .30746 L
.40525 .30734 L
.4054 .30714 L
.40556 .30687 L
.40583 .30625 L
.40612 .30534 L
.40675 .30263 L
.40735 .29909 L
.40847 .28998 L
.40967 .27677 L
.41098 .25873 L
.41589 .16763 L
.42061 .0701 L
.42185 .04697 L
.42251 .03558 L
.4232 .02421 L
.42349 .01963 L
.42365 .01716 L
.4238 .01486 L
.42389 .01585 L
.42398 .01723 L
.42414 .01961 L
.42446 .02413 L
.42563 .03907 L
.42686 .0521 L
.42802 .06168 L
.42922 .06892 L
.42986 .07164 L
.43019 .07275 L
.43055 .07372 L
.43086 .07438 L
.43115 .07484 L
.43129 .075 L
.43144 .07515 L
.43158 .07525 L
.43171 .07531 L
.43186 .07535 L
.432 .07536 L
.43215 .07532 L
.43224 .07529 L
.43232 .07524 L
.43248 .07513 L
.43265 .07495 L
.43297 .07452 L
Mistroke
.4333 .07389 L
.43361 .07319 L
.43429 .07115 L
.43551 .06604 L
.43784 .05228 L
.44036 .03386 L
.4416 .02423 L
.44221 .01957 L
.44248 .01756 L
.44262 .0165 L
.44277 .01539 L
.44292 .01521 L
.44307 .01628 L
.44335 .01837 L
.44398 .02285 L
.44531 .03173 L
.44644 .03845 L
.44766 .04462 L
.44881 .04926 L
.44987 .05249 L
.45046 .05382 L
.45076 .05436 L
.45109 .05485 L
.45128 .05508 L
.45145 .05526 L
.45161 .0554 L
.45179 .05553 L
.45195 .05561 L
.45209 .05567 L
.45225 .0557 L
.45234 .05571 L
.45242 .05571 L
.45257 .0557 L
.45273 .05565 L
.45286 .0556 L
.45302 .05551 L
.45318 .0554 L
.45335 .05524 L
.45366 .05489 L
.45428 .0539 L
.45484 .05266 L
.45602 .04906 L
.45712 .04456 L
.45962 .03072 L
.46089 .02213 L
.46119 .01996 L
.46151 .01763 L
.46164 .01666 L
.46178 .01561 L
.46194 .01498 L
Mistroke
.46209 .01607 L
.46316 .02429 L
.46433 .03331 L
.46671 .05096 L
.46797 .05915 L
.4693 .06646 L
.46998 .06944 L
.47061 .07175 L
.47118 .07338 L
.47147 .07405 L
.47179 .07464 L
.47194 .07485 L
.47209 .07505 L
.47223 .07519 L
.47238 .07531 L
.47246 .07536 L
.47254 .0754 L
.4727 .07545 L
.47284 .07546 L
.47299 .07543 L
.47312 .07538 L
.47326 .07528 L
.4734 .07517 L
.47352 .07504 L
.4738 .07463 L
.4741 .07405 L
.4747 .07238 L
.47525 .07028 L
.47589 .06715 L
.47648 .0635 L
.47755 .0553 L
.4787 .04396 L
.47994 .02896 L
.48025 .02477 L
.48055 .02063 L
.48081 .01679 L
.48096 .01486 L
.4811 .01695 L
.48168 .02608 L
.48231 .03645 L
.48364 .06024 L
.48837 .15659 L
.49292 .24433 L
.49525 .27794 L
.49656 .29178 L
.49714 .2966 L
.49776 .30081 L
.49808 .30258 L
.49838 .304 L
.49867 .30516 L
Mistroke
.49894 .30603 L
.4992 .30668 L
.49933 .30694 L
.49947 .30716 L
.49961 .30734 L
.49974 .30746 L
.4999 .30753 L
.50004 .30754 L
.50019 .3075 L
.50028 .30744 L
.50036 .30737 L
.50051 .3072 L
.50065 .30697 L
.50097 .30627 L
.50132 .30519 L
.50163 .30397 L
.50195 .30241 L
.50254 .29892 L
.50368 .28957 L
.5049 .27607 L
.50712 .24375 L
.51211 .14659 L
.5146 .09462 L
.51691 .05009 L
.51807 .03009 L
.51835 .0256 L
.51864 .02101 L
.51888 .01718 L
.51902 .01506 L
.51915 .01631 L
.51929 .01833 L
.51942 .02014 L
.5197 .0241 L
.52029 .03193 L
.52154 .04649 L
.52266 .05708 L
.52385 .06563 L
.52447 .06902 L
.52516 .07189 L
.52546 .07288 L
.52578 .07376 L
.52608 .07442 L
.52636 .07488 L
.52652 .07508 L
.52666 .07523 L
.52679 .07533 L
.52694 .0754 L
.52709 .07545 L
.52717 .07546 L
.52726 .07546 L
Mistroke
.52741 .07542 L
.52755 .07535 L
.52769 .07525 L
.52783 .07513 L
.52808 .07482 L
.52836 .07438 L
.52865 .07378 L
.52929 .07208 L
.52996 .06971 L
.53116 .06414 L
.53351 .04943 L
.53572 .03297 L
.53697 .0233 L
.53758 .01857 L
.53774 .0174 L
.53788 .0163 L
.53801 .01532 L
.53816 .01517 L
.53829 .01614 L
.53843 .01717 L
.53867 .01898 L
.53922 .02292 L
.54039 .03078 L
.54153 .03768 L
.54276 .04401 L
.5439 .0488 L
.54497 .05217 L
.54556 .05358 L
.54619 .05469 L
.54652 .05511 L
.54683 .0554 L
.547 .05552 L
.54716 .05561 L
.54725 .05565 L
.54734 .05568 L
.54744 .0557 L
.54753 .05571 L
.54768 .05571 L
.54776 .0557 L
.54784 .05568 L
.54799 .05564 L
.54814 .05557 L
.54828 .05548 L
.54841 .05539 L
.5487 .0551 L
.54901 .0547 L
.5493 .05425 L
.54995 .05292 L
.55053 .0514 L
.55114 .04943 L
Mistroke
.55225 .04502 L
.55475 .03139 L
.55599 .02308 L
.55664 .01841 L
.55697 .016 L
.55706 .01533 L
.55716 .01482 L
.55725 .0155 L
.55733 .01612 L
.5586 .02579 L
.55976 .03477 L
.56226 .05299 L
.56336 .05996 L
.56457 .06646 L
.56513 .06895 L
.56573 .07122 L
.56625 .07282 L
.56682 .07414 L
.56713 .07467 L
.56742 .07503 L
.56758 .07518 L
.56773 .07527 L
.56781 .07531 L
.5679 .07534 L
.56798 .07535 L
.56806 .07536 L
.5682 .07534 L
.56832 .0753 L
.56846 .07522 L
.56861 .0751 L
.56877 .07494 L
.56892 .07474 L
.5692 .07427 L
.56951 .07357 L
.56981 .07275 L
.57036 .07079 L
.57095 .06804 L
.5716 .06432 L
.57275 .0556 L
.57382 .04531 L
.57492 .0324 L
.57552 .02436 L
.57582 .02017 L
.57595 .01828 L
.57609 .01616 L
.57625 .01562 L
.57634 .01692 L
.57642 .01815 L
.57677 .02365 L
.57738 .03372 L
Mistroke
.57859 .05497 L
.58326 .14983 L
.58564 .19887 L
.58824 .24642 L
.58944 .26489 L
.59072 .2814 L
.59193 .29354 L
.59245 .29767 L
.59302 .3014 L
.59361 .30432 L
.59393 .30553 L
.59423 .30641 L
.59438 .30674 L
.59451 .307 L
.59464 .3072 L
.59477 .30736 L
.59491 .30748 L
.59505 .30754 L
.59519 .30756 L
.59534 .30751 L
.5955 .30739 L
.59558 .3073 L
.59567 .30719 L
.59597 .30664 L
.59614 .30623 L
.59632 .3057 L
.59664 .30453 L
.59728 .30141 L
.59786 .29764 L
.59906 .2871 L
.60017 .27433 L
.60268 .23621 L
.60743 .1423 L
.612 .05163 L
.6132 .03123 L
.61379 .02197 L
.61394 .01973 L
.61408 .01766 L
.61421 .01583 L
.61434 .01555 L
.6145 .01779 L
.61465 .01982 L
.61497 .02419 L
.61566 .03281 L
.61686 .04584 L
.61804 .05596 L
.61914 .06304 L
.61977 .0661 L
.62034 .06826 L
.62066 .0692 L
Mistroke
.62101 .07002 L
.62133 .07062 L
.62148 .07083 L
.62163 .07101 L
.62177 .07115 L
.62192 .07125 L
.62206 .07132 L
.62219 .07136 L
.62235 .07137 L
.62248 .07134 L
.62256 .07132 L
.62264 .07128 L
.6228 .07118 L
.62293 .07107 L
.62307 .07092 L
.62336 .07053 L
.62389 .06954 L
.62451 .06791 L
.62517 .06565 L
.62637 .06041 L
.62893 .04547 L
.63011 .03751 L
.63136 .0287 L
.6325 .0206 L
.63281 .01839 L
.63297 .01723 L
.63315 .01602 L
.6333 .01496 L
.63338 .01507 L
.63346 .01562 L
.63376 .01764 L
.63598 .03209 L
.63823 .04439 L
.63942 .04956 L
.64068 .05386 L
.64132 .05551 L
.64166 .05623 L
.64202 .0569 L
.64235 .05739 L
.64266 .05774 L
.6428 .05788 L
.64296 .05801 L
.64311 .0581 L
.64325 .05816 L
.64341 .05821 L
.64349 .05823 L
.64357 .05824 L
.64372 .05823 L
.64387 .0582 L
.64401 .05816 L
Mistroke
.64414 .05809 L
.64428 .058 L
.64443 .05788 L
.64477 .05752 L
.64508 .05705 L
.64568 .05587 L
.64624 .0544 L
.64685 .05236 L
.64808 .04687 L
.64923 .04018 L
.65031 .03258 L
.65149 .02283 L
.65209 .01744 L
.65225 .01592 L
.65235 .01506 L
.65243 .01516 L
.65251 .0159 L
.65259 .01671 L
.65274 .01819 L
.65497 .04122 L
.65733 .06622 L
.65857 .07854 L
.65991 .09011 L
.66057 .09494 L
.6612 .09887 L
.6618 .10201 L
.6621 .10327 L
.66237 .10425 L
.66262 .10504 L
.6629 .10572 L
.66305 .10601 L
.66319 .10624 L
.66333 .10641 L
.66347 .10653 L
.66361 .10661 L
.66376 .10664 L
.66391 .10661 L
.66404 .10653 L
.66419 .10638 L
.66428 .10626 L
.66436 .10614 L
.66467 .10551 L
.66496 .10464 L
.66523 .10363 L
.66583 .10057 L
.66639 .09671 L
.66692 .0921 L
.66811 .07841 L
.66941 .05796 L
.67 .04682 L
Mistroke
.67063 .03344 L
.67092 .02685 L
.67108 .02312 L
.67123 .01957 L
.67136 .01648 L
.67149 .01632 L
.67164 .02013 L
.67178 .02367 L
.67311 .06079 L
.67431 .09884 L
.67911 .27925 L
.68374 .4557 L
.68612 .52846 L
.68732 .55719 L
.68797 .57002 L
.68865 .58141 L
.68923 .5893 L
.68954 .59279 L
.68987 .59597 L
.69017 .59841 L
.69045 .60021 L
.69072 .60161 L
.69086 .60214 L
.69098 .60255 L
.69113 .60291 L
.69121 .60306 L
.69129 .60318 L
.69138 .60327 L
.69146 .60331 L
.69161 .6033 L
.69176 .60317 L
.69189 .60294 L
.69203 .60259 L
.69219 .60208 L
.69236 .60138 L
.69254 .60044 L
.69288 .59827 L
.6935 .59259 L
.69409 .58522 L
.69465 .57666 L
.69591 .55136 L
.69713 .51935 L
.69845 .47784 L
.70344 .27331 L
.70594 .16078 L
.70704 .11304 L
.70825 .06307 L
.70881 .04129 L
.7091 .03021 L
.70926 .02429 L
Mistroke
.70941 .01885 L
.70954 .01533 L
.70968 .02034 L
.70998 .03071 L
.7105 .04817 L
.71288 .11479 L
.71412 .13978 L
.71477 .15013 L
.71546 .15895 L
.71606 .16487 L
.71638 .16734 L
.71672 .16947 L
.71704 .17096 L
.71732 .17194 L
.71746 .17228 L
.71761 .17255 L
.71776 .17272 L
.71789 .1728 L
.71803 .17281 L
.71818 .17272 L
.71831 .17257 L
.71845 .17233 L
.7186 .17198 L
.71876 .17151 L
.71905 .17039 L
.71934 .16892 L
.71962 .16724 L
.72014 .16331 L
.72133 .15081 L
.72262 .13244 L
.72496 .08975 L
.72621 .06417 L
.7269 .04973 L
.72755 .03598 L
.72816 .02319 L
.72833 .01973 L
.72842 .01783 L
.72851 .01606 L
.72859 .01503 L
.72867 .01682 L
.72883 .01992 L
.73 .04278 L
.73229 .08112 L
.73344 .09596 L
.7347 .10831 L
.73533 .11287 L
.73568 .11489 L
.73601 .11648 L
.73632 .11767 L
.73648 .11819 L
Mistroke
.73665 .11866 L
.7368 .11898 L
.73696 .11927 L
.7371 .11947 L
.73724 .1196 L
.73738 .11969 L
.73753 .11971 L
.73768 .11967 L
.73781 .11959 L
.73796 .11943 L
.73805 .11931 L
.73813 .11919 L
.73843 .11854 L
.73871 .1177 L
.73903 .11651 L
.73967 .1133 L
.74023 .10969 L
.74083 .105 L
.74191 .09459 L
.74446 .06215 L
.74563 .04488 L
.74689 .02587 L
.7472 .02112 L
.74736 .01864 L
.74745 .01728 L
.74753 .01602 L
.74768 .01569 L
.74776 .0169 L
.74785 .01819 L
.74814 .02254 L
.74928 .03895 L
.7515 .06685 L
.75273 .07899 L
.75338 .08423 L
.75407 .08884 L
.75467 .09205 L
.75498 .09343 L
.75533 .09466 L
.75564 .09556 L
.75593 .09619 L
.75607 .09643 L
.7562 .09662 L
.75634 .09677 L
.75649 .09688 L
.75665 .09695 L
.75673 .09696 L
.75681 .09696 L
.75696 .09691 L
.7571 .09683 L
.75719 .09675 L
Mistroke
.75727 .09667 L
.75742 .09647 L
.75777 .09584 L
.75806 .09508 L
.75834 .09422 L
.75897 .09167 L
.76005 .08541 L
.76121 .07645 L
.76356 .05256 L
.76461 .04015 L
.76576 .02598 L
.76606 .0223 L
.76637 .01836 L
.76653 .01645 L
.76667 .01477 L
.7668 .01638 L
.76694 .01813 L
.76819 .03311 L
.77042 .05686 L
.77166 .06742 L
.77282 .07517 L
.7734 .07821 L
.77402 .08079 L
.77438 .08194 L
.77472 .08281 L
.77502 .08341 L
.77519 .08367 L
.77535 .08386 L
.77551 .084 L
.77559 .08405 L
.77567 .0841 L
.77582 .08415 L
.77597 .08415 L
.77605 .08414 L
.77613 .08411 L
.77629 .08402 L
.77637 .08396 L
.77645 .08388 L
.77663 .08367 L
.77691 .08323 L
.77721 .08258 L
.77783 .08074 L
.77839 .07852 L
.77899 .07555 L
.78008 .06876 L
.7825 .04828 L
.78373 .03588 L
.7844 .02876 L
.78504 .02194 L
.78533 .01881 L
Mistroke
.78549 .01711 L
.78564 .01551 L
.78572 .01475 L
.7858 .01564 L
.78598 .01753 L
.78629 .02084 L
.78742 .03256 L
.78964 .05287 L
.79086 .06185 L
.79151 .06579 L
.7922 .06931 L
.79286 .07202 L
.79345 .07387 L
.79374 .07456 L
.79406 .07514 L
.7942 .07535 L
.79435 .07554 L
.79449 .07568 L
.79462 .07579 L
.79477 .07587 L
.79485 .0759 L
.79493 .07592 L
.79507 .07592 L
.79522 .07589 L
.79536 .07583 L
.7955 .07573 L
.79564 .07561 L
.79577 .07547 L
.79607 .07502 L
.7964 .07437 L
.797 .07275 L
.79755 .07074 L
.79814 .06811 L
.79921 .06215 L
.80179 .04247 L
.80297 .03175 L
.80362 .02565 L
.80422 .01988 L
.80451 .01713 L
.80465 .01578 L
.80478 .0149 L
.80493 .01633 L
.80509 .01788 L
.80538 .02059 L
.80664 .0323 L
.80887 .05041 L
.80996 .05749 L
.81112 .06352 L
.81179 .06615 L
.8124 .068 L
Mistroke
.81271 .06871 L
.81299 .06925 L
.81328 .06969 L
.81344 .06987 L
.81361 .07002 L
.81376 .07011 L
.81384 .07015 L
.81392 .07018 L
.81408 .07021 L
.81417 .07021 L
.81425 .0702 L
.8144 .07016 L
.81455 .07007 L
.8147 .06996 L
.81484 .06982 L
.81518 .06936 L
.81549 .06881 L
.81618 .06706 L
.81678 .06499 L
.81743 .06221 L
.81861 .05587 L
.82102 .03863 L
.82225 .02837 L
.82292 .0225 L
.82325 .01959 L
.82356 .01689 L
.82371 .01558 L
.82385 .01508 L
.824 .01635 L
.82416 .01776 L
.8248 .02337 L
.82593 .03284 L
.82815 .04905 L
.82934 .0559 L
.82998 .05896 L
.83059 .06134 L
.83114 .06313 L
.83165 .0644 L
.83192 .06493 L
.83222 .06539 L
.83238 .06559 L
.83253 .06575 L
.83267 .06587 L
.83282 .06596 L
.83297 .06603 L
.83311 .06606 L
.83325 .06606 L
.83338 .06604 L
.83352 .06599 L
.83368 .06591 L
Mistroke
.83384 .06578 L
.83399 .06563 L
.83426 .06528 L
.83452 .06486 L
.83509 .06362 L
.83566 .06191 L
.8363 .05956 L
.83758 .0534 L
.83994 .03795 L
.84125 .02779 L
.84183 .02314 L
.84216 .02046 L
.84246 .01795 L
.84261 .01673 L
.84275 .01558 L
.84283 .01495 L
.84291 .01518 L
.84306 .01639 L
.8437 .02155 L
.84503 .03205 L
.84631 .0412 L
.84746 .04844 L
.8486 .05434 L
.8492 .05688 L
.84984 .05911 L
.85016 .06006 L
.85052 .06095 L
.85084 .06163 L
.85114 .06213 L
.85145 .06252 L
.85161 .06269 L
.85177 .06281 L
.85192 .06289 L
.85206 .06294 L
.85221 .06297 L
.85237 .06296 L
.8525 .06294 L
.85265 .06288 L
.85281 .06278 L
.85296 .06267 L
.85322 .06239 L
.8535 .06199 L
.85414 .06072 L
.85472 .05913 L
.85585 .05488 L
.85692 .0496 L
.85913 .03562 L
.86039 .0264 L
.861 .02171 L
.86156 .01737 L
Mistroke
.8617 .01631 L
.86185 .01517 L
.86193 .01491 L
.86201 .0155 L
.86216 .01665 L
.86272 .02099 L
.86396 .03026 L
.86528 .03936 L
.8665 .04664 L
.86761 .05215 L
.86883 .05672 L
.86946 .05843 L
.87005 .05959 L
.87037 .06005 L
.87067 .06035 L
.87084 .06047 L
.87092 .06052 L
.87101 .06056 L
.87109 .06059 L
.87118 .06062 L
.87134 .06063 L
.87149 .06062 L
.87164 .06058 L
.8718 .0605 L
.87188 .06045 L
.87196 .06039 L
.87227 .0601 L
.87256 .05971 L
.8731 .05873 L
.87368 .05728 L
.87431 .05526 L
.87499 .05263 L
.87619 .04681 L
.87859 .03189 L
.87963 .02444 L
.88019 .02039 L
.88049 .01816 L
.88077 .01605 L
.88092 .01499 L
.88107 .01559 L
.88115 .01621 L
.88124 .01686 L
.8814 .01802 L
.88198 .02228 L
.88312 .03041 L
.88434 .03841 L
.88565 .04585 L
.88689 .05161 L
.88802 .05549 L
.88857 .05685 L
Mistroke
.88886 .05743 L
.88916 .05794 L
.88943 .05829 L
.88957 .05844 L
.88972 .05858 L
.88986 .05869 L
.88999 .05876 L
.89012 .05881 L
.89024 .05885 L
.89039 .05887 L
.89047 .05886 L
.89055 .05885 L
.8907 .05882 L
.89085 .05875 L
.89098 .05867 L
.89111 .05857 L
.8914 .05828 L
.89171 .05786 L
.89199 .05737 L
.89263 .05595 L
.89318 .05437 L
.89377 .05229 L
.89485 .04762 L
.89724 .03392 L
.89846 .02568 L
.8991 .02117 L
.89945 .01868 L
.89962 .01746 L
.89977 .01635 L
.89992 .01531 L
.90006 .01511 L
.9002 .01615 L
.90036 .01728 L
.901 .02183 L
.90212 .02957 L
.90433 .04297 L
.90547 .04853 L
.90673 .05323 L
.90736 .05498 L
.90771 .05576 L
.90804 .05637 L
.90835 .05682 L
.90851 .05702 L
.90868 .05719 L
.90883 .05731 L
.90899 .05742 L
.90913 .05749 L
.90927 .05753 L
.90941 .05756 L
.90956 .05755 L
Mistroke
.9097 .05753 L
.90983 .05748 L
.90998 .05741 L
.91015 .05729 L
.91045 .057 L
.91076 .05659 L
.9111 .05603 L
.9117 .05472 L
.91276 .05145 L
.91393 .04656 L
.91627 .03351 L
.91757 .02492 L
.91821 .02055 L
.91879 .01654 L
.91893 .01552 L
.91909 .01501 L
.91924 .01605 L
.91938 .01701 L
.92 .02136 L
.92133 .03027 L
.92259 .03796 L
.92376 .04424 L
.92495 .04948 L
.92603 .05309 L
.92665 .05461 L
.92723 .05566 L
.92755 .05608 L
.92785 .05636 L
.928 .05647 L
.92817 .05656 L
.92826 .05659 L
.92835 .05661 L
.92844 .05663 L
.92852 .05663 L
.92867 .05662 L
.92882 .05659 L
.92895 .05653 L
.92909 .05646 L
.92925 .05634 L
.92941 .0562 L
.9297 .05586 L
.93023 .05502 L
.9308 .05374 L
.93142 .05198 L
.93209 .04965 L
.9333 .04439 L
.93568 .03087 L
.93694 .02261 L
.93727 .02036 L
.93763 .01791 L
Mistroke
.93779 .01679 L
.93797 .0156 L
.93812 .01485 L
.9382 .01543 L
.93828 .01596 L
.93958 .02481 L
.94077 .03241 L
.94307 .04504 L
.94434 .0502 L
.94496 .05218 L
.94553 .05366 L
.94605 .0547 L
.94632 .05512 L
.94661 .05549 L
.94676 .05564 L
.94689 .05576 L
.94703 .05586 L
.94716 .05593 L
.9473 .05599 L
.94746 .05603 L
.94761 .05604 L
.94769 .05603 L
.94777 .05602 L
.94792 .05598 L
.94805 .05592 L
.9482 .05583 L
.94836 .05571 L
.94868 .05538 L
.94898 .05497 L
.94955 .05392 L
.95009 .0526 L
.95129 .04862 L
.9526 .04279 L
.95494 .02938 L
.95618 .02125 L
.95652 .01896 L
.95687 .01654 L
.95702 .01553 L
.95718 .01497 L
.95727 .01558 L
.95735 .01614 L
.95751 .01724 L
.95995 .0331 L
.96225 .04535 L
.96345 .05013 L
.96402 .05192 L
.96456 .05331 L
.96514 .05446 L
.96544 .05493 L
.96578 .05531 L
Mistroke
.96594 .05546 L
.96612 .05559 L
.9662 .05563 L
.96629 .05567 L
.96645 .05572 L
.96653 .05574 L
.96662 .05575 L
.96677 .05574 L
.96692 .05571 L
.96706 .05566 L
.96722 .05557 L
.96736 .05547 L
.96763 .05522 L
.96792 .05486 L
.96824 .05436 L
.96881 .0532 L
.96934 .05182 L
.97055 .04761 L
.97183 .04173 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.309973 0.100045 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00984 -12 -4.5 ]
[-0.0125 .00984 0 4.5 ]
[-0.0125 .10988 -12 -4.5 ]
[-0.0125 .10988 0 4.5 ]
[-0.0125 .20993 -12 -4.5 ]
[-0.0125 .20993 0 4.5 ]
[-0.0125 .30997 -6 -4.5 ]
[-0.0125 .30997 0 4.5 ]
[-0.0125 .41002 -6 -4.5 ]
[-0.0125 .41002 0 4.5 ]
[-0.0125 .51006 -6 -4.5 ]
[-0.0125 .51006 0 4.5 ]
[-0.0125 .61011 -6 -4.5 ]
[-0.0125 .61011 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00984 m
.00625 .00984 L
s
[(-3)] -0.0125 .00984 1 0 Mshowa
0 .10988 m
.00625 .10988 L
s
[(-2)] -0.0125 .10988 1 0 Mshowa
0 .20993 m
.00625 .20993 L
s
[(-1)] -0.0125 .20993 1 0 Mshowa
0 .30997 m
.00625 .30997 L
s
[(0)] -0.0125 .30997 1 0 Mshowa
0 .41002 m
.00625 .41002 L
s
[(1)] -0.0125 .41002 1 0 Mshowa
0 .51006 m
.00625 .51006 L
s
[(2)] -0.0125 .51006 1 0 Mshowa
0 .61011 m
.00625 .61011 L
s
[(3)] -0.0125 .61011 1 0 Mshowa
.125 Mabswid
0 .02985 m
.00375 .02985 L
s
0 .04986 m
.00375 .04986 L
s
0 .06986 m
.00375 .06986 L
s
0 .08987 m
.00375 .08987 L
s
0 .12989 m
.00375 .12989 L
s
0 .1499 m
.00375 .1499 L
s
0 .16991 m
.00375 .16991 L
s
0 .18992 m
.00375 .18992 L
s
0 .22994 m
.00375 .22994 L
s
0 .24995 m
.00375 .24995 L
s
0 .26996 m
.00375 .26996 L
s
0 .28996 m
.00375 .28996 L
s
0 .32998 m
.00375 .32998 L
s
0 .34999 m
.00375 .34999 L
s
0 .37 m
.00375 .37 L
s
0 .39001 m
.00375 .39001 L
s
0 .43003 m
.00375 .43003 L
s
0 .45004 m
.00375 .45004 L
s
0 .47005 m
.00375 .47005 L
s
0 .49006 m
.00375 .49006 L
s
0 .53007 m
.00375 .53007 L
s
0 .55008 m
.00375 .55008 L
s
0 .57009 m
.00375 .57009 L
s
0 .5901 m
.00375 .5901 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00984 m
1 .00984 L
s
.99375 .10988 m
1 .10988 L
s
.99375 .20993 m
1 .20993 L
s
.99375 .30997 m
1 .30997 L
s
.99375 .41002 m
1 .41002 L
s
.99375 .51006 m
1 .51006 L
s
.99375 .61011 m
1 .61011 L
s
.125 Mabswid
.99625 .02985 m
1 .02985 L
s
.99625 .04986 m
1 .04986 L
s
.99625 .06986 m
1 .06986 L
s
.99625 .08987 m
1 .08987 L
s
.99625 .12989 m
1 .12989 L
s
.99625 .1499 m
1 .1499 L
s
.99625 .16991 m
1 .16991 L
s
.99625 .18992 m
1 .18992 L
s
.99625 .22994 m
1 .22994 L
s
.99625 .24995 m
1 .24995 L
s
.99625 .26996 m
1 .26996 L
s
.99625 .28996 m
1 .28996 L
s
.99625 .32998 m
1 .32998 L
s
.99625 .34999 m
1 .34999 L
s
.99625 .37 m
1 .37 L
s
.99625 .39001 m
1 .39001 L
s
.99625 .43003 m
1 .43003 L
s
.99625 .45004 m
1 .45004 L
s
.99625 .47005 m
1 .47005 L
s
.99625 .49006 m
1 .49006 L
s
.99625 .53007 m
1 .53007 L
s
.99625 .55008 m
1 .55008 L
s
.99625 .57009 m
1 .57009 L
s
.99625 .5901 m
1 .5901 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30997 m
1 .30997 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .46712 m
.02847 .39229 L
.03355 .31067 L
.03602 .27099 L
.03832 .23402 L
.04054 .1984 L
.04118 .18815 L
.04178 .17845 L
.04232 .16975 L
.04247 .16737 L
.04263 .16484 L
.04276 .16268 L
.04291 .47461 L
.04307 .47211 L
.04321 .46979 L
.04354 .46454 L
.04414 .45497 L
.04525 .43701 L
.04777 .39657 L
.05249 .32078 L
.0549 .28209 L
.05751 .24024 L
.05873 .22059 L
.06002 .19982 L
.06113 .1821 L
.06143 .17724 L
.0616 .17457 L
.06175 .17204 L
.0619 .16968 L
.06206 .48142 L
.0622 .4791 L
.06234 .47694 L
.06707 .40089 L
.07163 .32779 L
.07416 .28717 L
.07647 .24993 L
.07875 .21344 L
.07989 .19509 L
.0802 .19006 L
.08054 .18469 L
.0807 .18208 L
.08085 .17962 L
.08099 .49171 L
.08114 .48932 L
.08608 .41009 L
.09083 .33379 L
.0954 .26044 L
.09774 .22279 L
.09842 .21195 L
.09906 .20166 L
Mistroke
.09963 .19242 L
.09979 .18989 L
.09988 .1885 L
.09996 .18719 L
.10012 .49895 L
.10026 .49665 L
.10492 .42193 L
.10987 .34246 L
.11234 .30286 L
.11464 .26594 L
.11685 .2304 L
.11749 .22017 L
.11809 .21049 L
.11864 .20179 L
.11878 .19941 L
.11894 .19689 L
.11908 .50903 L
.11922 .50666 L
.12408 .42876 L
.12875 .35381 L
.13112 .31573 L
.13372 .27413 L
.13492 .25488 L
.1362 .23435 L
.13682 .22437 L
.13741 .21497 L
.13766 .21087 L
.13793 .20653 L
.13808 .20426 L
.13823 .51607 L
.13837 .51381 L
.1385 .51169 L
.14319 .43651 L
.14818 .3566 L
.15067 .31663 L
.15298 .27963 L
.15522 .24375 L
.15635 .22563 L
.15666 .22066 L
.15682 .21805 L
.15699 .2153 L
.15714 .21289 L
.15723 .52582 L
.15731 .52455 L
.1576 .51991 L
.1623 .44451 L
.1673 .3644 L
.16981 .32426 L
.17212 .28723 L
.17437 .25119 L
Mistroke
.17551 .23302 L
.17582 .22804 L
.17599 .22529 L
.17607 .22394 L
.17615 .22269 L
.1763 .53457 L
.17638 .53329 L
.17647 .53193 L
.17676 .52731 L
.18177 .447 L
.18661 .36963 L
.19126 .29521 L
.19367 .25672 L
.19425 .24736 L
.19488 .23734 L
.19506 .23438 L
.19515 .23293 L
.19524 .23158 L
.19539 .54337 L
.19548 .54205 L
.19557 .54064 L
.19621 .53038 L
.20076 .45756 L
.20561 .38003 L
.21028 .30546 L
.2127 .26683 L
.21329 .25745 L
.21392 .24742 L
.2141 .24446 L
.21419 .243 L
.21428 .24166 L
.21443 .55345 L
.21452 .55212 L
.21461 .55073 L
.21525 .5405 L
.21982 .46754 L
.22469 .3899 L
.22937 .31522 L
.23059 .29573 L
.23193 .2745 L
.23254 .26479 L
.23287 .25946 L
.23303 .25685 L
.23318 .25445 L
.23333 .25217 L
.23348 .56407 L
.23363 .56165 L
.2338 .559 L
.23435 .55018 L
.23923 .47243 L
Mistroke
.24394 .39766 L
.24633 .35957 L
.24893 .31824 L
.25015 .29895 L
.25081 .28839 L
.25144 .2785 L
.25197 .27009 L
.25212 .26767 L
.25226 .26537 L
.25239 .5776 L
.25254 .57535 L
.25375 .55612 L
.25865 .47841 L
.26336 .40369 L
.26577 .36559 L
.26838 .3244 L
.2696 .30507 L
.27027 .29452 L
.27089 .28466 L
.27117 .28034 L
.2713 .27822 L
.27143 .27625 L
.27157 .5883 L
.27172 .58584 L
.272 .58154 L
.27321 .56242 L
.27794 .48781 L
.28249 .41623 L
.28502 .37653 L
.28734 .34017 L
.28852 .32174 L
.28961 .3046 L
.29017 .29596 L
.29032 .29347 L
.29047 .29113 L
.29061 .60332 L
.29076 .60103 L
.29201 .5815 L
.29694 .50457 L
.30169 .4308 L
.30626 .36021 L
.31112 .28549 L
.3158 .21411 L
.32078 .13895 L
.32327 .10173 L
.32557 .06746 L
.32672 .05046 L
.32781 .03453 L
.3281 .03025 L
.32841 .02573 L
Mistroke
.32848 .02459 L
.32857 .02337 L
.32866 .33634 L
.32874 .33509 L
.32905 .33055 L
.33018 .31408 L
.33518 .24239 L
.33999 .1754 L
.34461 .11353 L
.34585 .09756 L
.347 .08281 L
.34729 .07923 L
.34744 .07729 L
.34758 .07549 L
.34774 .38783 L
.34782 .3868 L
.34791 .3857 L
.34821 .38197 L
.34954 .36556 L
.35455 .30661 L
.35937 .25379 L
.36402 .20495 L
.36526 .19189 L
.36587 .18547 L
.36613 .18266 L
.36642 .17959 L
.36657 .17793 L
.36672 .49069 L
.36686 .48922 L
.367 .48765 L
.36763 .48092 L
.36896 .46646 L
.37351 .41498 L
.37835 .35639 L
.38301 .29673 L
.38426 .28028 L
.38487 .2722 L
.38513 .26866 L
.38542 .26481 L
.38558 .26272 L
.38572 .57508 L
.38586 .57323 L
.38601 .57127 L
.38664 .56284 L
.38797 .54487 L
.39253 .48221 L
.39739 .41427 L
.40207 .34821 L
.40704 .27767 L
.41183 .20979 L
Mistroke
.41644 .14489 L
.41901 .10894 L
.42134 .07659 L
.42251 .06047 L
.42312 .05203 L
.42346 .04742 L
.42362 .04518 L
.42377 .04313 L
.42391 .3555 L
.42404 .35368 L
.42434 .34965 L
.42496 .34114 L
.42606 .32623 L
.43068 .26427 L
.4356 .20021 L
.43804 .16918 L
.44034 .14054 L
.44141 .12737 L
.44199 .12022 L
.44253 .1136 L
.44268 .11182 L
.44281 .11013 L
.44297 .4225 L
.44312 .42074 L
.44376 .41293 L
.44489 .3993 L
.44953 .34408 L
.45447 .28592 L
.45692 .25682 L
.45922 .22934 L
.46035 .2157 L
.46091 .20894 L
.46142 .20266 L
.46171 .19916 L
.46179 .19815 L
.46187 .1972 L
.46202 .50973 L
.46209 .50876 L
.46218 .50775 L
.46233 .50593 L
.46266 .50181 L
.46379 .48787 L
.46838 .43011 L
.47326 .36662 L
.47796 .30376 L
.47919 .28706 L
.47984 .27822 L
.48019 .27337 L
.48053 .26881 L
.48068 .26678 L
Mistroke
.48082 .26485 L
.48089 .26379 L
.48098 .57693 L
.48113 .57489 L
.48179 .5658 L
.48296 .54973 L
.48785 .48157 L
.49257 .41523 L
.49758 .34428 L
.50241 .27576 L
.50706 .20996 L
.512 .14041 L
.51446 .10605 L
.51676 .07416 L
.51789 .05853 L
.51845 .05085 L
.5187 .04748 L
.51883 .04569 L
.51897 .04376 L
.51912 .35603 L
.51925 .35412 L
.51956 .34994 L
.52021 .34112 L
.52134 .32574 L
.52629 .25922 L
.53107 .19692 L
.53566 .13885 L
.53688 .12381 L
.53748 .11646 L
.53774 .11324 L
.53788 .11154 L
.53803 .1097 L
.53819 .42206 L
.53833 .42024 L
.53866 .41626 L
.53935 .40788 L
.54055 .39334 L
.54553 .33409 L
.55032 .27763 L
.55274 .24899 L
.55493 .22281 L
.55552 .21573 L
.55615 .20806 L
.55644 .20452 L
.55675 .20078 L
.55688 .19924 L
.55702 .19758 L
.55716 .51007 L
.5573 .50837 L
.55983 .47727 L
Mistroke
.56483 .41426 L
.56963 .35148 L
.57183 .32215 L
.57309 .3053 L
.57426 .28939 L
.57541 .27374 L
.57572 .26944 L
.5759 .26709 L
.57598 .26595 L
.57606 .26491 L
.57619 .57734 L
.57634 .57534 L
.57665 .5711 L
.57918 .53616 L
.58401 .46884 L
.58865 .40339 L
.59359 .33339 L
.59834 .26593 L
.60292 .20138 L
.60778 .13339 L
.61003 .10247 L
.61247 .06917 L
.61311 .06048 L
.61347 .05574 L
.6138 .05128 L
.61411 .04712 L
.61419 .04598 L
.61428 .04478 L
.61436 .35806 L
.61444 .35694 L
.61503 .34915 L
.61745 .3172 L
.62234 .25504 L
.62704 .19862 L
.62944 .1713 L
.6307 .15727 L
.63204 .14265 L
.63261 .13645 L
.63293 .13305 L
.63308 .13138 L
.63323 .12983 L
.63331 .12895 L
.6334 .44232 L
.63349 .44129 L
.63358 .44035 L
.63391 .43691 L
.63454 .43018 L
.63685 .40587 L
.64168 .35485 L
.64633 .30332 L
Mistroke
.64869 .27578 L
.64994 .26077 L
.65063 .25239 L
.65128 .24437 L
.65189 .23671 L
.65206 .2346 L
.65216 .23344 L
.65224 .23235 L
.6524 .54472 L
.65248 .5437 L
.65256 .5426 L
.65374 .52769 L
.65604 .49786 L
.661 .431 L
.66578 .36401 L
.66819 .32949 L
.66924 .31431 L
.67037 .29776 L
.67068 .29328 L
.67101 .28852 L
.67114 .28657 L
.67128 .28446 L
.67144 .59645 L
.67159 .59429 L
.67274 .57743 L
.67526 .54008 L
.68024 .46565 L
.68504 .39309 L
.68965 .32267 L
.69456 .24719 L
.69928 .17409 L
.7043 .09605 L
.70682 .05674 L
.70793 .03948 L
.70851 .03034 L
.70884 .02531 L
.70914 .02055 L
.70928 .01832 L
.70943 .01595 L
.70951 .01472 L
.7096 .32766 L
.70975 .32526 L
.71031 .31652 L
.7114 .29941 L
.71379 .26196 L
.71865 .18575 L
.72332 .11223 L
.72569 .07482 L
.72695 .05503 L
.72764 .04416 L
Mistroke
.72798 .03882 L
.72812 .03648 L
.72829 .0339 L
.72844 .03143 L
.72859 .34341 L
.72875 .34097 L
.72891 .33835 L
.72959 .32768 L
.73077 .30904 L
.73307 .27262 L
.73806 .19376 L
.74286 .11769 L
.74505 .0829 L
.7463 .06307 L
.74691 .05335 L
.74718 .04909 L
.74732 .04684 L
.74748 .04443 L
.74763 .35633 L
.74776 .35415 L
.74803 .34988 L
.74862 .34055 L
.74986 .32093 L
.75239 .2807 L
.75721 .20412 L
.76184 .13039 L
.76424 .09228 L
.76544 .07306 L
.76577 .06779 L
.76613 .06213 L
.7663 .05939 L
.76647 .05678 L
.76661 .05444 L
.7667 .36742 L
.76677 .36619 L
.77149 .29097 L
.77651 .21099 L
.77903 .17082 L
.78134 .13387 L
.78361 .09777 L
.78475 .07959 L
.78506 .07461 L
.78539 .06927 L
.78555 .06668 L
.78571 .06423 L
.78585 .37633 L
.786 .37394 L
.79092 .29536 L
.79565 .21968 L
.80021 .14688 L
Mistroke
.80254 .10956 L
.80318 .09933 L
.80385 .08857 L
.80443 .07938 L
.80459 .07686 L
.80467 .07548 L
.80476 .07417 L
.80491 .38594 L
.80506 .38363 L
.8097 .3094 L
.81464 .23041 L
.81709 .1911 L
.81939 .15433 L
.82159 .11905 L
.82223 .10888 L
.82283 .09924 L
.82337 .09058 L
.82352 .08821 L
.82368 .08569 L
.82383 .39761 L
.82396 .39545 L
.8288 .31795 L
.83346 .24335 L
.83582 .20549 L
.83841 .16399 L
.8396 .14488 L
.84088 .12443 L
.8415 .11451 L
.84209 .10512 L
.84234 .10104 L
.84261 .0967 L
.84275 .09444 L
.84291 .40625 L
.84305 .40398 L
.84318 .40185 L
.84786 .32694 L
.85283 .24728 L
.85531 .20749 L
.85761 .17053 L
.85984 .1348 L
.86048 .12452 L
.86109 .11482 L
.86135 .11059 L
.86163 .10612 L
.86178 .10378 L
.86186 .10245 L
.86194 .41552 L
.86207 .41334 L
.86222 .411 L
.8672 .33103 L
Mistroke
.87201 .25398 L
.87663 .17986 L
.87901 .14162 L
.88021 .12231 L
.88054 .11702 L
.88072 .11424 L
.88081 .11272 L
.8809 .11131 L
.88098 .42437 L
.88106 .42304 L
.88124 .42022 L
.88154 .41528 L
.88655 .33501 L
.89137 .25766 L
.896 .18324 L
.8984 .14479 L
.89898 .13544 L
.89961 .1254 L
.89979 .12244 L
.89988 .12099 L
.89997 .11964 L
.90012 .43142 L
.90021 .43009 L
.90029 .42868 L
.90094 .41836 L
.90596 .33779 L
.91079 .26015 L
.91545 .18544 L
.91669 .16544 L
.91785 .14678 L
.91844 .13738 L
.91861 .13468 L
.91877 .13212 L
.91891 .12982 L
.91907 .44162 L
.91922 .43906 L
.9194 .43624 L
.91976 .43053 L
.92039 .42028 L
.92525 .34236 L
.92992 .26737 L
.93229 .22927 L
.93488 .18763 L
.93608 .16837 L
.93674 .1578 L
.93736 .14782 L
.93764 .14329 L
.9378 .14082 L
.93794 .13851 L
.9381 .45031 L
Mistroke
.93818 .44898 L
.93827 .44756 L
.93857 .44273 L
.93967 .42512 L
.94465 .3451 L
.94945 .26802 L
.95407 .19388 L
.95529 .17417 L
.95645 .15565 L
.95673 .15112 L
.95688 .14866 L
.95702 .14636 L
.95718 .45816 L
.95726 .45684 L
.95735 .45543 L
.95765 .45063 L
.95898 .42928 L
.96398 .349 L
.96879 .27165 L
.97343 .19723 L
.97619 .15282 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000U2000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00;?ooool3
o`0001_ooooo1Ol0000Kooooo`?o00006_ooool2o`0001gooooo0ol0000Kooooo`Go00006oooool3
o`0003cooooo0ol0000Kooooo`Go00006oooool3o`0001[ooooo0_l0000Looooo`?o00006oooool5
o`0001_ooooo0ol0000Kooooo`00:oooool01Ol0003ooooooooooooooooo000001_ooooo00Co0000
oooooooooooo00007?ooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0001gooooo
00?o0000ooooooooool06oooool01?l0003oooooooooool0000Jooooo`05o`000?oooooooooooooo
ool00000>_ooool01Ol0003ooooooooooooooooo000001_ooooo00Co0000oooooooooooo00007?oo
ool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool0
6oooool01?l0003oooooooooool0000Jooooo`05o`000?ooooooooooooooool000006_ooool002Go
oooo1Ol00005ooooo`03o`000?oooooooooo01;ooooo1Ol00003ooooo`03o`000?oooooooooo01Co
oooo1Ol00003ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00007Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<_ooool5o`00
00Gooooo00?o0000ooooooooool04_ooool5o`0000?ooooo00?o0000ooooooooool05?ooool5o`00
00?ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000Looooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Hooooo`00;Oooool2o`00
01kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`04o`000?oooooooooo
o`0001gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`;o0000?Oooool2
o`0001kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`04o`000?oooooo
ooooo`0001cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`;o00006ooo
ool002oooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000001cooooo00?o
0000ooooooooool06?ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo01[ooooo
00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool06?ooool01Ol0003ooooooooooooooooo000001cooooo00?o0000ooooooooool06?ooool01?l0
003oooooooooool0000Looooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00
000Nooooo`03o`000?oooooooooo01Sooooo000[ooooo`05o`000?ooooooooooooooool000006_oo
ool01Ol0003ooooooooooooooooo000001_ooooo0_l0000Jooooo`04o`000?ooooooooooo`0001co
oooo0_l0000Looooo`05o`000?ooooooooooooooool000006_ooool01Ol0003ooooooooooooooooo
000003[ooooo00Go0000ooooooooooooooooo`00000Jooooo`05o`000?ooooooooooooooool00000
6oooool2o`0001[ooooo00Co0000oooooooooooo00006oooool2o`0001cooooo00Go0000oooooooo
ooooooooo`00000Jooooo`05o`000?ooooooooooooooool000006_ooool002cooooo0ol0000Loooo
o`?o00007Oooool00ol0003oooooooooo`0Iooooo`;o00007_ooool00ol0003oooooooooo`0Koooo
o`?o00007?ooool3o`0003cooooo0ol0000Looooo`?o00007Oooool00ol0003oooooooooo`0Ioooo
o`;o00007Oooool00ol0003oooooooooo`0Kooooo`?o00007?ooool3o`0001_ooooo003oooooooWo
oooo003oooooooWooooo003oooooooWooooo000Qooooom3o00008Oooool3o`0000CooooocOl0000B
ooooo`006oooool2o`0000Cooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000008?ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
01;ooooo000Jooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo1Ol00005ooooo`04o`000?oooooooooo
ooooo`?o00001_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`05ooooo`;o00004_ooool001[ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`0booooo`03ool00?oooooooooo013ooooo00?oo`00
ooooooooool07?ooool00ol0003oooooooooo`0Iooooo`05ool00?oooooooooooooooooo00009_oo
ool00ooo003oooooooooo`0Nooooo`03o`000?oooooooooo023ooooo0_l00004ooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool0:?ooool00ooo003oooooooooo`0hooooo`03o`000?oo
oooooooo013ooooo000Jooooo`04o`000?ooooooooooo`0000?ooooo0_l00003ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo0_oo0002
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00007ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo00Goo`00oooo
ooooooooooooo`000003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000Oooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00001oooool00ooo003oooooooooo`02ool000;ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00ol0000Tooooo`05o`000?oooooo
ooooooooool00000IOooool00ol0003oooooooooo`0Xooooo`03ool00?oooooooooo03Sooooo00?o
0000ooooooooool04?ooool001[ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`02ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00007ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000Oooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool01Ooo
003ooooooooooooooooo000000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00001oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00007ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;o
o`000_ooool2ool000?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0Nooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`10ooooo`03ool00?oooooooooo
023ooooo00?o0000ooooooooool0:?ooool00ooo003oooooooooo`0hooooo`03o`000?oooooooooo
013ooooo000Jooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ooo
003oooooooooo`02ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Oooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001oooool00ooo
003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ol0003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool00_oo0003ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003ooooo
ooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`02
ooooo`03o`000?oooooooooo01oooooo0ol00004ooooo`;o0000@Oooool00ooo003oooooooooo`0P
ooooo`03o`000?oooooooooo02Oooooo0_oo000iooooo`;o00004_ooool001_ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo
00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00001oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`00
1_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Co0000oooooooooooo
oooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000Oooooo00?oo`00oooo
ooooool00_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`04ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0@?ooool00ooo003oooooooooo`0Pooooo`03o`000?oooooooooo02Oooooo0_oo0002oooo
o`;oo`00=_ooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`03ooooo`0:
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001oooool00ooo
003oooooooooo`02ool000;ooooo00Coo`00oooooooo003ooooo0_oo0006ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool01?l0003oooooooooooooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;oo`000_oo
ool2ool000?ooooo00?oo`00ooooooooool01?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00005oooooooo003oooooool00?ooool0
0_oo0002ooooo`04ool00?ooooooo`00ooooo`;oo`000_ooool01?oo003oooooool00?ooool2ool0
00;ooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`10ooooo`03ool00?oooooooooo023ooooo00?o0000ooooooooool09oooool2ool0
00;ooooo0_oo000fooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo00?o
oooo01Koo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_oo0002ooooo`04ool00?ooooooo`00
ooooo`;oo`001_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Co0000
oooooooooooooooo0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`000_ooool00ooo003ooooo
ooooo`05ooooo`07ool00?ooooooooooool00?ooooooo`00ooooo`02ool000;ooooo0_oo0006oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`0001koooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo0005ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0@?ooool00ooo003o
ooooooooo`0@ooooo`;oo`003_ooool01Ol0003oooooooooooooooooo`0001;ooooo00?oo`00oooo
ooooool04?ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo037ooooo00?o0000oooo
ooooool04?ooool0027ooooo0_l00004ooooo`0Jool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`05ooooo`0;ool00?oo
ooooooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0006ooooo`;oo`000_ooool0
1?oo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`04o`000?ooooooooooooooo`;oo`00
00Soooooool00?ooooooo`00oooooooo003oooooool000;ooooo0_oo0005ooooo`;oo`000_ooool0
1?oo003oooooool00?ooool2ool000;ooooo0_oo0006ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0001_oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0005ooooo`;o0000:?ooool2o`00047o
oooo00?oo`00ooooooooool04?ooool2ool000kooooo00Go0000ooooooooooooooooool0000Boooo
o`03ool00?oooooooooo013ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0`oooo
o`;o00004_ooool0027ooooo00?o0000ooooooooool00oooool3ool0000Aoooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0002
ooooo`06ool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool00004oooo
oooo003oooooool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00001oooool01Ooo
003ooooooooooooo003ooooo00;oo`000_ooool01?oo003oooooool00?oo0006ooooo`;oo`000_oo
ool01_oo003oooooool00?oo003oooooool000;ooooo0_oo0002ooooo`04o`000?oooooooooooooo
o`;oo`0000?oooooool00?ooool00ooo00001?ooooooo`00ooooooooool2ool000Gooooo0_oo0002
ooooo`04ool00?ooooooo`00ooooo`;oo`000_ooool2ool000Kooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0000Goooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool00_oo0002ooooo`;oo`000_ooool2ool000Kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`10ooooo`03ool00?oooooooooo013ooooo0_oo000>ooooo`05o`000?oo
oooooooooooooooo00004_ooool00ooo003oooooooooo`0@ooooo`;oo`000_ooool2ool000;ooooo
00Goo`00ooooooooooooooooool0000_ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`00
0?oooooooooo00Cooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`04ool00?ooooooo`00ool0
00;ooooo0_oo00002?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool01Ooo003ooooo
ooooooooooooo`0000Oooooo00Goo`00ooooooooooooo`00ooooo`02ool000;ooooo00Coo`00oooo
oooo003oo`001_ooool2ool000;ooooo00Koo`00oooooooo003oo`00oooooooo0002ooooo`;oo`00
0_ooool01?l0003oooooooooooooool2ool00004oooooooo003oooooooooo`;oo`0000Koooooool0
0?ooooooo`00oooooooo0005ooooo`04ool00?ooooooo`00ool000;ooooo0ooo00000oooooooo`00
ooooo`02ool000Kooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
00ooooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool00ooo00000oooooooo`00ool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo043ooooo00?oo`00oooooooo
ool04?ooool2ool000kooooo00Go0000ooooooooooooooooool0000Booooo`03ool00?oooooooooo
013ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0002oooooo00?o0000
ooooooooool04?ooool0027ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`02ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Coo`00oooooooo003ooooo0_oo0000
1_ooooooo`00oooooooo003oooooool000;ooooo00Goo`00ooooooooooooooooool00007ooooo`;o
o`0000?oooooool00?ooool01?ooool01?oo003oooooool00?oo0006ooooo`04ool00?ooooooo`00
ool000Kooooo00Coo`00oooooooo003oo`000_ooool01?l0003oooooooooooooool2ool00003oooo
oooo003ooooo00Cooooo00Goo`00oooooooo003oooooool00005ooooo`04ool00?ooooooo`00ool0
00Kooooo00Coo`00oooooooo003oo`001_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool0000;oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00ooo0002oooo
o`;oo`000_ooool01Ooo003oooooooooooooooooo`0001Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`10ooooo`03ool00?oooooooooo013ooooo0_oo000>ooooo`05o`000?oooooo
oooooooooooo00004_ooool00ooo003oooooooooo`0@ooooo`;oo`000_ooool2ool000;ooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo02Wooooo00?o0000ooooooooool0
4?ooool0027ooooo00?o0000ooooooooool07oooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool00006oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo00?oo`00oooooooo
ool01Oooool2ool00003oooooooo003ooooo00Cooooo1?oo0006ooooo`04ool00?ooooooo`00ool0
00Kooooo1?oo0002ooooo`04o`000?ooooooooooooooo`;oo`0000?oooooool00?ooool01Oooool2
ool00003oooooooo003ooooo00Cooooo00Coo`00oooooooo003oo`001_ooool01?oo003oooooool0
0?oo0006ooooo`;oo`000_ooool2ool000;ooooo0_oo00002_ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0Pooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0@?ooool00ooo003oooooooooo`0@ooooo`;oo`003_oo
ool00ol0003oooooooooo`02ool001;ooooo00?oo`00ooooooooool04?ooool2ool000;ooooo0_oo
0002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Yooooo`03o`00
0?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo02?ooooo0_oo0002ooooo`;oo`000_oo
ool2ool00006oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo00?oo`00oooooooo
ool01Oooool2ool00003oooooooo003ooooo00Gooooo00?oo`00oooooooo00001_ooool01?oo003o
ooooool00?oo0006ooooo`;oo`0000Goooooool00?ooooooooooo`000003ooooo`Coo`001_ooool2
ool00003oooooooo003ooooo00Cooooo00Coo`00oooooooo003oo`001_ooool01?oo003oooooool0
0?oo0006ooooo`;oo`000_ooool2ool000;ooooo0_oo00001_ooooooo`00oooooooo003oooooool0
00;ooooo0_oo0002ooooo`;oo`009Oooool00ol0003oooooooooo`0Vooooo`;o0000@Oooool00ooo
003oooooooooo`0@ooooo`;oo`003_ooool00ol0003oooooooooo`02ool001;ooooo00?oo`00oooo
ooooool04?ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0002Kooooo0_l0000Booooo`008Oooool2o`0002Sooooo0_oo0002
ooooo`;oo`0000Koooooool00?ooooooo`00oooooooo0002ooooo`;oo`000_ooool00ooo003ooooo
ooooo`05ooooo`;oo`0000?oooooool00?ooool01oooool00ooo003oooooooooo`04ooooo`04ool0
0?ooooooo`00ool000Kooooo0_oo00001Oooooooo`00oooooooooooo000000;ooooo00Coo`00oooo
ooooooooo`001oooool2ool00003oooooooo003ooooo00Cooooo00?oo`00ooooooooool01oooool0
1?oo003oooooool00?oo0006ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?ooooooo`00oooo
ooooool2ool000;ooooo0_oo000Xooooo`;o0000:?ooool00ol0003oooooooooo`10ooooo`05ool0
0?oooooooooooooooooo00003_ooool2ool000kooooo00?o0000ooooooooool00_oo000Booooo`03
ool00?oooooooooo013ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool0000Wooooo`03o`000?oooooooooo013ooooo000Qoooo
o`03o`000?oooooooooo02_ooooo0_oo00002_ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo0002ooooo`03ool00?oooooooooo00Gooooo0_oo00000oooooooo`00ooooo`07ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool02_ooool01?oo003oooooooooool00002oooo
o`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`07oooo
o`04ool00?ooooooo`00ool000Kooooo0_oo0002ooooo`;oo`0000Koooooool00?ooooooo`00oooo
oooo0002ooooo`;oo`00;Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo043ooooo
00Goo`00ooooooooooooooooool0000>ooooo`;oo`003_ooool00ol0003oooooooooo`02ool001;o
oooo00?oo`00ooooooooool04?ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0002Oooooo00?o0000ooooooooool04?ooool0
027ooooo00?o0000ooooooooool0:oooool2ool000;ooooo0_oo00001_ooooooo`00oooooooo003o
ooooool000;ooooo00?oo`00ooooooooool01Oooool2ool00003oooooooo003ooooo00Oooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`0:ooooo`04ool00?ooooooooooo`0000;ooooo
00?oo`00ooooooooool02oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Oooooo
00Coo`00oooooooo003oo`001_ooool2ool000;ooooo0_oo00001?ooooooo`00ooooooooool2ool0
00;ooooo0_oo000]ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0?oooool2ool0
00?ooooo00?oo`00ooooooooool03?ooool2ool000kooooo00?o0000ooooooooool00_oo000Aoooo
o`;oo`004_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool08Oooool00ol0003ooooooooo
o`0@ooooo`008Oooool00ol0003oooooooooo`0_ooooo`;oo`0000Koooooool00?ooooooo`00oooo
oooo0002ooooo`03ool00?oooooooooo00Gooooo0ooo000:ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool02_ooool01?oo003oooooooooool00002ooooo`03ool00?oooooooooo00_o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`07ooooo`04ool00?ooooooo`00ool0
00Kooooo0_oo0002ooooo`04ool00?ooooooo`00ool000;ooooo0_oo000aooooo`03o`000?oooooo
oooo02Kooooo0_l00010ooooo`;oo`000oooool00ooo003oooooooooo`0<ooooo`;oo`003_ooool0
0ol0003oooooooooo`02ool0017ooooo0_oo000Booooo`;oo`000_ooool2ool000;ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`0Pooooo`;o00004_ooool0027ooooo00?o0000ooooooooool0;oooool2ool00006oooooooo
003oooooool00?ooooooo`000_ooool00ooo003oooooooooo`05ooooo`?oo`002_ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00Coo`00oooooooooooo00000_ooool00ooo
003oooooooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01oooool01?oo
003oooooool00?oo0006ooooo`;oo`000_ooool01?oo003oooooool00?oo0002ooooo`;oo`00<Ooo
ool00ol0003oooooooooo`0Nooooo`Go00000oooool00ol0003oooooooooo`0oooooo`;oo`000ooo
ool00ooo003oooooooooo`0<ooooo`;oo`003_ooool00ol0003oooooooooo`02ool0017ooooo0_oo
000Booooo`;oo`0000Coooooool00?ooooooo`000_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00007oooool0
0ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0booooo`09ool00?ooooooo`00
oooooooo003oooooool00?ooooooo`0000Kooooo0ooo000:ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool02_ooool01?oo003oooooooooool00002ooooo`03ool00?oooooooooo00_o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`08ooooo`?oo`001_ooool2ool000;o
oooo00Coo`00oooooooo003oo`00=Oooool00ol0003oooooooooo`0Oooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool0?oooool2ool000?ooooo00?oo`00ooooooooool03?ooool2
ool000kooooo00?o0000ooooooooool00_oo000Aooooo`;oo`004_ooool2ool00005oooooooo003o
ooooool00?ooool00_oo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`000?oooooooooo
013ooooo000Qooooo`;o0000=?ooool2ool00006oooooooo003oooooool00?ooooooo`001Oooool0
1?oo003oooooool00?oo000:ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02_oo
ool01?oo003oooooooooool00002ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`08ooooo`03ool00?ooooooo`0000Kooooo0_oo0002ooooo`04ool0
0?ooooooo`00ool003Cooooo0_l0000Jooooo`Go00000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03oooooo0_oo0002ooooo`;oo`003_ooool2ool000kooooo00?o0000oooooooo
ool00_oo000Aooooo`;oo`004_ooool2ool00005oooooooo003oooooool00?ooool00_oo0003oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool0000Kooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oo
oooooooo03?ooooo0_oo00001_ooooooo`00oooooooo003oooooool000Gooooo00?oo`00oooooooo
ool02oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00Coo`00oooooooo
oooo00000_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool02_ooool00ooo003oooooooooo`04ooooo`;oo`000_ooool01?oo003oooooool00?oo000e
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool3o`0003oooooo0_oo0002
ooooo`;oo`003_ooool2ool000;ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`02
ool000?ooooo00?oo`00ooooooooool02oooool2ool001;ooooo0_oo00001Oooooooo`00oooooooo
003ooooo00;oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Doooo
o`;o00004_ooool0027ooooo00?o0000ooooooooool0<oooool2ool00006oooooooo003oooooool0
0?ooooooo`001Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool02oooool00ooo003oooooo`000002ooooo`03ool00?oooooooooo00cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo0_oo0000
1?ooooooo`00ooooooooool2ool003Gooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool0?oooool2ool000;ooooo0_oo000>ooooo`;oo`00
0_ooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo00;oo`000oooool00ooo003ooooo
ooooo`0;ooooo`;oo`004_ooool2ool00005oooooooo003oooooool00?ooool00_oo0002ooooo`;o
o`000oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0003ooooo`05ool00?oooooooooo
oooooooo00000_ooool2ool001Oooooo00?o0000ooooooooool04?ooool001?ooooo1Ol00003oooo
o`;o00001?ooool00ol0003oooooooooo`0cooooo`;oo`0000Koooooool00?ooooooo`00oooooooo
0005ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`0;ooooo`03ool00?oooooo000000;ooooo00?oo`00ooooooooool03?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool01?ooool2ool00004oooooooo
003oooooooooo`;oo`00=Oooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`0oooooo`;oo`000_ooool2ool000kooooo0_oo0002ooooo`03
ool00?oooooooooo00Wooooo00?o0000ooooooooool00_oo0003ooooo`03ool00?oooooooooo00_o
oooo0_oo000Booooo`;oo`0000Goooooool00?ooooooo`00ooooo`02ool000;ooooo0_oo0002oooo
o`;oo`000oooool00ooo003oooooooooo`02ool000?ooooo00Goo`00ooooooooooooooooool00002
ooooo`;oo`000_ooool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo000Doooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0fooooo`05ool00?ooooooo`00oooooooo00001Oooool00ooo003oooooooooo`0;ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool03?ooool00ooo003oooooo`000002ooooo`03ool0
0?oooooooooo00cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0:ooooo`03ool0
0?oooooooooo00Cooooo0_oo00000oooooooo`00ooooo`0hooooo`03o`000?oooooooooo01oooooo
0ol00004ooooo`03o`000?oooooooooo03oooooo0_oo0002ooooo`;oo`003_ooool2ool000;ooooo
00?oo`00ooooooooool02Oooool01Ol0003oooooool00?ooooooo`0000?ooooo00?oo`00oooooooo
ool02oooool2ool001;ooooo0_oo00001Oooooooo`00oooooooo003ooooo00;oo`000_ooool2ool0
00;ooooo0_oo0003ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo000Eooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0foooo
o`05ool00?ooooooo`00oooooooo00001Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool03?ooool00ooo003oooooo`000002ooooo`03ool00?oooooo
oooo00cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooo
oooo00Cooooo00Coo`00oooooooo003oo`00>Oooool00ol0003oooooooooo`0Vooooo`;o0000@?oo
ool2ool000;ooooo0_oo000=ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool02Ooo
ool01Ol0003oooooool00?ooooooo`0000?ooooo00?oo`00ooooooooool02oooool2ool000?ooooo
00?oo`00ooooooooool03?ooool2ool00005oooooooo003oooooool00?ooool00_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool01Ooo003oooooooooooooooooo`0000oooooo0_l0000Booooo`005_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l0000gooooo`05ool00?oooooo
o`00oooooooo00001Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool03?ooool00ooo003oooooo`000002ooooo`03ool00?oooooooooo00cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo00Co
o`00oooooooo003oo`00=oooool3o`0002Sooooo00?o0000ooooooooool0?oooool2ool000;ooooo
0_oo000=ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool02Oooool01Ol0003ooooo
ool00?ooooooo`0000;ooooo0_oo000=ooooo`;oo`000oooool00ooo003oooooooooo`0<ooooo`;o
o`0000Goooooool00?ooooooo`00ooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000Coooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo03Oooooo0_oo00000oooooooo`00ooooo`04ooooo`03ool00?oooooooooo00_ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooo000000;ooooo00?o
o`00ooooooooool03?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00[ooooo00?o
o`00ooooooooool01?ooool01?oo003oooooool00?oo000iooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool0?oooool2ool000;ooooo0_oo000=ooooo`03ool00?ooooooo`0000;ooooo
00?oo`00ooooooooool02Oooool01Ol0003oooooool00?ooooooo`0000;ooooo0_oo000=ooooo`;o
o`000oooool00ooo003oooooooooo`0;ooooo`08ool00?ooooooo`00oooooooo003oooooool00?oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`0:ooooo`03o`000?oooooooooo013ooooo000Cooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo03Oooooo0_oo00000ooooooo
o`00ooooo`04ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0<ooooo`03ool00?oooooo000000;ooooo00?oo`00ooooooooool03?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool01?ooool01?oo003o
ooooool00?oo000iooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0?oooool2ool0
0004oooooooo003oooooool000gooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`09
ooooo`05o`000?ooooooo`00oooooooo00000_ooool2ool000gooooo0_oo0003ooooo`03ool00?oo
oooooooo00_ooooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00002?oo
ool00ol0003oooooooooo`0@ooooo`005?ooool3o`0000Cooooo0_l00004ooooo`03o`000?oooooo
oooo03Oooooo0_oo00000oooooooo`00ooooo`04ooooo`03ool00?oooooooooo00_ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooo000000;ooooo00?oo`00
ooooooooool03?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00[ooooo00?oo`00
ooooooooool01?ooool01?oo003oooooool00?oo000iooooo`03o`000?oooooooooo02Kooooo0_l0
0010ooooo`;oo`0000Coooooool00?ooooooo`003Oooool00ooo003oooooool00002ooooo`03ool0
0?oooooooooo00Wooooo00Go0000oooooooo003oooooool00002ooooo`;oo`003Oooool2ool000?o
oooo00?oo`00ooooooooool02oooool02?oo003oooooool00?ooooooo`00oooooooo003ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`04ool00?ooooooooooooooo`;o00004_ooool0027ooooo00?o0000oooooooo
ool0=oooool2ool00003oooooooo003ooooo00Cooooo00?oo`00ooooooooool02oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooool000000_ooool00ooo003o
ooooooooo`0<ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02_ooool00ooo003o
ooooooooo`04ooooo`04ool00?ooooooo`00ool003Wooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0oooooo`;oo`0000Coooooool00?ooooooo`003Oooool00ooo003oooooool00002
ooooo`03ool00?oooooooooo00Wooooo00Go0000oooooooo003oooooool00002ooooo`;oo`003Ooo
ool2ool000?ooooo00?oo`00ooooooooool02oooool02?oo003oooooool00?ooooooo`00oooooooo
003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool04?oo
ool0027ooooo00?o0000ooooooooool0=oooool2ool00003oooooooo003ooooo00Cooooo00?oo`00
ooooooooool02oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00cooooo00?oo`00
ooooool000000_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool02_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooo`00ool003Wooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo03Kooooo0_oo
00001?ooooooo`00oooooooo000=ooooo`04ool00?ooooooo`00ooooo`;oo`002oooool01Ol0003o
ooooool00?ooooooo`0000;ooooo0_oo000=ooooo`;oo`000oooool00ooo003oooooooooo`0;oooo
o`06ool00?ooooooo`00oooooooo003ooooo0_oo00001?ooooooo`00ooooooooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o0000>?ooool2ool00003
oooooooo003ooooo00Cooooo00?oo`00ooooooooool03?ooool01Ooo003oooooooooooooooooo`00
00kooooo00?oo`00ooooool000000_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooo`00
ool003Sooooo0_l0000Xooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0=_ooool2
ool00004oooooooo003oooooool000gooooo00Coo`00oooooooo003ooooo0_oo000;ooooo`05o`00
0?ooooooo`00oooooooo00000_ooool2ool000gooooo0_oo0002ooooo`;oo`003Oooool01_oo003o
ooooool00?ooooooo`00ooooo`;oo`0000Coooooool00?oooooooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool00_ooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0gooooo`;oo`00
00?oooooool00?ooool01?ooool00ooo003oooooooooo`0<ooooo`05ool00?oooooooooooooooooo
00003_ooool00ooo003oooooo`000002ooooo`03ool00?oooooooooo00cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooooooo
003oo`00>Oooool00ol0003oooooooooo`0Vooooo`;o00001oooool01Ooo003ooooooooooooooooo
o`0003Cooooo0_oo00001?ooooooo`00oooooooo000=ooooo`04ool00?ooooooo`00ooooo`;oo`00
2oooool02Ol0003oooooool00?ooooooo`00oooooooo003oooooool0000<ooooo`03ool00?oooooo
o`0000;ooooo0_oo000=ooooo`06ool00?ooooooo`00oooooooo003ooooo0_oo00001_ooooooo`00
oooooooo003oooooool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool01?oo003oooooooooooooool2o`0001;ooooo000Qooooo`03o`000?oo
oooooooo03Oooooo0_oo00000oooooooo`00ooooo`04ooooo`03ool00?oooooooooo00cooooo00Go
o`00ooooooooooooooooool0000>ooooo`03ool00?oooooo000000;ooooo00?oo`00ooooooooool0
3?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0
1?ooool01?oo003oooooool00?oo000iooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool01_ooool01Ooo003oooooooooooooooooo`0003Cooooo0_oo00001?ooooooo`00oooooooo000=
ooooo`04ool00?ooooooo`00ooooo`;oo`002oooool02Ol0003oooooool00?ooooooo`00oooooooo
003oooooool0000<ooooo`03ool00?ooooooo`0000;ooooo0_oo000=ooooo`06ool00?ooooooo`00
oooooooo003ooooo0_oo00001_ooooooo`00oooooooo003oooooool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool00ooo003oooooooooo`03
ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo03[ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0<ooooo`05ool00?oooooooooooooooooo00003_ooool0
0ooo003oooooo`000002ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0>_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00Goo`00ooooooooooooooooool0
0003ooooo`03ool00?oooooooooo02gooooo00Ooo`00oooooooo003oooooool00?ooooooo`0000?o
oooo00?oo`00ooooooooool01_ooool01Ooo003ooooooooooooo003ooooo00;oo`002oooool02Ol0
003oo`00ooooooooooooo`00oooooooo003oooooool0000<ooooo`03ool00?ooooooo`0000;ooooo
0_oo000=ooooo`06ool00?ooooooo`00oooooooo003ooooo0_oo00001_ooooooo`00oooooooo003o
ooooool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`00
0?oooooooooo03[ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0<ooooo`05ool0
0?oooooooooooooooooo00003_ooool00ooo003oooooo`000002ooooo`03ool00?oooooooooo00co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool0>_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Ko
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000:oooool0
1ooo003oooooool00?ooooooo`00oooooooo00000oooool00ooo003oooooooooo`06ooooo`05ool0
0?ooooooooooool00?ooool00_oo000;ooooo`09o`000?oo003ooooooooooooo003oooooool00?oo
ooooo`0000cooooo00?oo`00oooooooo00000_ooool2ool000gooooo00Koo`00oooooooo003ooooo
ool00?ooool2ool00006oooooooo003oooooool00?ooooooo`000_ooool2ool00004oooooooo003o
ooooool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00oooooooo
ool00oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0jooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool03?ooool01Ooo003oooooooooooooooooo`0000ko
oooo00?oo`00ooooool000000_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo03[o
oooo00?o0000ooooooooool09_ooool2o`0000Oooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo0000:oooool01ooo003oooooool00?ooooooo`00oooooooo0000
0oooool00ooo003oooooooooo`06ooooo`05ool00?ooooooooooool00?ooool00_oo000;ooooo`09
o`000?oo003ooooooooooooo003oooooool00?ooooooo`0000cooooo00?oo`00oooooooo00000_oo
ool2ool000gooooo00Koo`00oooooooo003oooooool00?ooool2ool00006oooooooo003oooooool0
0?ooooooo`000_ooool2ool00004oooooooo003oooooool000;ooooo0_oo00001?ooooooo`00oooo
oooo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo00;oo`000_ooool00ooo003oooooooooo`02ooooo`;o00004_ooool0027ooooo
0_l0000kooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03?ooool01Ooo003ooooo
ooooooooooooo`0000kooooo00?oo`00ooooool000000_ooool00ooo003oooooooooo`0<ooooo`05
ool00?oooooooooooooooooo00003_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
03Wooooo0_l0000Xooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool00_oo0002oooo
o`;oo`000oooool01?oo003ooooooooooooo000Xooooo`07ool00?ooooooo`00oooooooo003ooooo
ool00003ooooo`03ool00?oooooooooo00Kooooo00Goo`00ooooooooooooo`00ooooo`02ool000?o
oooo00?oo`00ooooooooool01Oooool02Ol0003oo`00ooooooooooooo`00oooooooo003oooooool0
000<ooooo`03ool00?ooooooo`0000;ooooo0_oo000=ooooo`06ool00?ooooooo`00oooooooo003o
oooo0_oo00003_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`000_ooool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`;oo`00
0_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`03
ool00?oooooooooo00?ooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0
>_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00cooooo00Goo`00oooooooooooo
ooooool0000>ooooo`03ool00?oooooo000000;ooooo00?oo`00ooooooooool03?ooool01Ooo003o
ooooooooooooooooo`0000kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0joooo
o`03o`000?oooooooooo01oooooo0ol00004ooooo`03o`000?oooooooooo00Gooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo02Kooooo00Ooo`00oooo
oooo003oooooool00?ooooooo`0000;ooooo0_oo0008ooooo`05ool00?ooooooooooool00?ooool0
0_oo0003ooooo`03ool00?oooooooooo00Gooooo00Wo0000ool00?ooooooooooool00?ooooooo`00
oooooooo00000oooool00ooo003oooooooooo`06ooooo`03ool00?ooooooo`0000;ooooo0_oo000=
ooooo`06ool00?ooooooo`00oooooooo003ooooo0_oo00003_ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool00008oooooooo003oooooool0
0?ooooooo`00oooooooo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool0
4?ooool0027ooooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00cooooo00Goo`00ooooooooooooooooool0000>ooooo`05ool00?oooooo0000oooooooo
00003oooool01Ooo003oooooooooooooooooo`0000kooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0jooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo
003oooooooooooooooooo`0002Cooooo00Ooo`00oooooooo003oooooool00?ooooooo`0000;ooooo
0_oo0008ooooo`05ool00?ooooooooooool00?ooool00_oo0003ooooo`03ool00?oooooooooo00Go
oooo00Wo0000ool00?ooooooooooool00?ooooooo`00oooooooo00000oooool00ooo003ooooooooo
o`06ooooo`03ool00?ooooooo`0000;ooooo0_oo000=ooooo`06ool00?ooooooo`00oooooooo003o
oooo0_oo00003_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`000_ooool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`;oo`00
0_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`03
ool00?oooooooooo00?ooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0
>_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00cooooo00Goo`00oooooooooooo
ooooool0000?ooooo`04ool00?l0003oooooool000oooooo00Goo`00ooooooooooooooooool0000>
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0>_ooool00ol0003oooooooooo`0H
ooooo`Go00000oooool00ol0003oooooooooo`03ooooo`?o00001Oooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool0000Tooooo`07ool00?oo
ooooo`00oooooooo003oooooool00002ooooo`;oo`002?ooool01Ooo003ooooooooooooo003ooooo
00;oo`000oooool00ooo003oooooooooo`05ooooo`09o`000?oo003ooooooooooooo003oooooool0
0?ooooooo`0000;ooooo0_oo0008ooooo`03ool00?ooooooo`0000;ooooo0_oo000=ooooo`06ool0
0?ooooooo`00oooooooo003ooooo0_oo00003_ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`000_ooool2ool00008oooooooo003oooooool00?ooooooo`00
oooooooo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002oooo
o`;oo`000_ooool00ooo003oooooooooo`02ooooo`;o00004_ooool0027ooooo00?o0000oooooooo
ool0>_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00gooooo00Goo`00oooooooo
ooooooooool0000?ooooo`04ool00?l0003oooooool000oooooo00Goo`00ooooooooooooooooool0
000>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0>_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo01kooooo00Coo`00oooooooo003oo`000_ooool00ooo003oooooooooo`02ool000So
oooo00Goo`00ooooooooooooo`00ooooo`02ool000?ooooo00?oo`00ooooooooool01Oooool02Ol0
003oo`00ooooooooooooo`00oooooooo003oooooool00002ooooo`;oo`002?ooool00ooo003ooooo
ool00002ooooo`;oo`003?ooool01ooo003ooooooooooooo003oooooool00?ooool00_oo00006_oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo00Go
o`00ooooooooooooooooool00002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool0
0oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0jooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool03Oooool01?oo003ooooooooooooo000@ooooo`04ool0
0?l0003oooooool000oooooo00Goo`00ooooooooooooooooool0000>ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool0>_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo01kooooo00Coo`00
oooooooo003oo`000_ooool00ooo003oooooooooo`02ool000Sooooo00Goo`00ooooooooooooo`00
ooooo`02ool000?ooooo00?oo`00ooooooooool01Oooool02Ol0003oo`00ooooooooooooo`00oooo
oooo003oooooool00002ooooo`;oo`002?ooool00ooo003oooooool00002ooooo`;oo`003?ooool0
1ooo003ooooooooooooo003oooooool00?ooool00_oo00007_ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool000;ooooo00Goo`00oooooooooooooooo
ool00002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ol0003ooooo
ooooo`0@ooooo`008Oooool2o`0003_ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0=ooooo`04ool00?ooooooooooool0013ooooo00Coo`00o`000?ooooooo`003oooool01Ooo003o
ooooooooooooooooo`0000kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0joooo
o`;o00008Oooool2o`0000Gooooo00?o0000ooooooooool01Oooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00007?ooool01?oo003oooooool00?oo0002ooooo`03ool00?oooooooooo00;oo`00
2?ooool01Ooo003ooooooooooooo003ooooo00;oo`000oooool00ooo003oooooooooo`05ooooo`09
o`000?oo003ooooooooooooo003oooooool00?ooooooo`0000;ooooo0_oo0008ooooo`03ool00?oo
ooooo`0000;ooooo0_oo000<ooooo`07ool00?ooooooooooool00?ooooooo`00ooooo`02ool0000O
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool0
0oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0jooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool03Oooool01?oo003ooooooooooooo000@ooooo`04ool0
0?l0003oooooool0013ooooo00Coo`00ooooooooooooo`003_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03oooo
o`;o00001_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`0Fooooo`04ool00?ooooooo`00ool000;ooooo00?oo`00ooooooooool00_oo0008ooooo`05ool0
0?ooooooooooool00?ooool00_oo0003ooooo`03ool00?oooooooooo00Gooooo00Co0000ool00?oo
oooooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`002?ooool01ooo003oooooool00?oooooo
o`00oooooooo00003?ooool00ooo003oooooooooo`02ool000;ooooo0_oo00007oooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00;ooooo0_l0000B
ooooo`008Oooool00ol0003oooooooooo`0jooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool03Oooool01?oo003ooooooooooooo000@ooooo`04ool00?l0003oooooool0013ooooo00Co
o`00ooooooooooooo`003_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03_ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo01Kooooo00Coo`00oooooooo003oo`000_ooool0
1Ooo003oooooool00?ooooooo`0000Sooooo00?oo`00ooooooooool00_oo00000oooooooo`00oooo
o`02ooooo`03ool00?oooooooooo00Gooooo00Co0000ool00?oooooooooo0_oo0002ooooo`03ool0
0?oooooooooo00;oo`001oooool02?oo003ooooooooooooo003oooooool00?ooooooo`000oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00;oo`000_ooool2ool0000Ooooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ol0
003oooooooooo`0@ooooo`005Oooool3o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo03[o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0=ooooo`04ool00?ooooooooooool0
013ooooo00Coo`00o`000?ooooooo`004?ooool01?oo003ooooooooooooo000>ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00Gooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool0000Dooooo`04ool00?ooooooo`00ool000;ooooo00Goo`00oooooooo003oooooool0
0008ooooo`03ool00?oooooooooo00;oo`0000?oooooool00?ooool00_ooool00ooo003ooooooooo
o`05ooooo`04o`000?oo003oooooooooo`;oo`000_ooool00ooo003oooooooooo`02ool000Oooooo
00Soo`00ooooooooooooo`00oooooooo003oooooool000?ooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`02ool000;ooooo027oo`00ooooooooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo00000oooooooo`00ooooo`05ooooo`03o`000?oooooooooo013ooooo000Foooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000003cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0=ooooo`04ool00?ooooooooooool0013ooooo
00Coo`00o`000?ooooooo`004?ooool01?oo003ooooooooooooo000>ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Gooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool0000Dooooo`04ool00?ooooooo`00ool000;ooooo00Goo`00oooooooo003oooooool00008oooo
o`03ool00?oooooooooo00;oo`0000?oooooool00?ooool00_ooool00ooo003oooooooooo`05oooo
o`04o`000?oo003oooooooooo`;oo`000_ooool00ooo003oooooooooo`02ool000Oooooo00Soo`00
ooooooooooooo`00oooooooo003oooooool000?ooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`02ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`0Jool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool00003oooooooo003ooooo00Gooooo00?o0000ooooooooool04?ooool001?ooooo1Ol00002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00gooooo00Coo`00ooooooooooooo`004?ooool01?oo003o0000oooo
oooo000@ooooo`04ool00?ooooooooooool000kooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0kooooo`03o`000?oooooooooo02Kooooo0_l00006ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00005?ooool01?oo003oooooool0
0?oo0002ooooo`05ool00?ooooooo`00oooooooo00001oooool01?oo003oooooooooooooool2ool0
0004oooooooo003oooooooooo`;oo`001oooool01?l0003oo`00ooooooooool2ool000;ooooo00?o
o`00ooooooooool00_oo0007ooooo`08ool00?ooooooooooool00?ooooooo`00oooooooo0003oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo
00;oo`000_ooool06_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00000oooooooo`00ooooo`04ooooo`;o00004_oo
ool001?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`;o0000
>oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo0000
4?ooool01?oo003o0000oooooooo000@ooooo`04ool00?ooooooooooool000kooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0iooooo`?o0000:?ooool00ol0003oooooooooo`05oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00;oo`000_ooool01Ooo003ooooo
ool00?ooooooo`0000Oooooo00Coo`00oooooooooooooooo0_oo00001?ooooooo`00ooooooooool2
ool000Oooooo00Co0000ool00?oooooooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`001ooo
ool02?oo003ooooooooooooo003oooooool00?ooooooo`000oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002oooo
o`0Fool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`0000?oooooool00?ooool01Oooool00ol0003oooooooooo`0@ooooo`005?ooool00ol0003o
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0>_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo00004?ooool01?oo
003o0000oooooooo000@ooooo`04ool00?ooooooooooool000kooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Ooo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`02ool000;ooooo00Goo`00oooo
oooo003oooooool00007ooooo`04ool00?ooooooooooooooo`;oo`0000Coooooool00?oooooooooo
0_oo0007ooooo`04o`000?oo003oooooooooo`;oo`000_ooool00ooo003oooooooooo`02ool000Oo
oooo00Soo`00ooooooooooooo`00oooooooo003oooooool000?ooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`02ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo01;oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
0003oooooooo003ooooo00Gooooo00?o0000ooooooooool04?ooool001Gooooo0_l00003ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00kooooo00?oo`00oooooooo00004?ooool01?oo003o0000oooooooo000@
ooooo`03ool00?ooooooo`0000oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0k
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool2ool00004oooooooo003o
ooooool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo
0_oo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`02ool000;ooooo00Goo`00oooo
oooo003oooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool2ool00004oooooooo
003oooooooooo`;oo`000oooool01_oo003ooooooooooooooooo0000ool000;ooooo0_oo0002oooo
o`03ool00?oooooooooo00;oo`000_ooool2ool000?ooooo00Soo`00ooooooooooooo`00oooooooo
003oooooool000?ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`02ool000;ooooo
00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo01;oo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00003oooooooo003ooooo00Gooooo00?o0000
ooooooooool04?ooool001Kooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000oooo
ooooool0>_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?oo`00oooo
oooo00004?ooool00ooo003o0000ool0000Aooooo`03ool00?ooooooo`0000oooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo02Kooooo0_l00006oooo
o`;oo`0000Coooooool00?ooooooo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooo
oooo00;oo`000_ooool2ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00;oo`00
0_ooool01Ooo003oooooool00?ooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`;oo`0000Coooooool00?oooooooooo0_oo0003ooooo`06ool00?ooooooooooooooool0003oo`00
0_ooool2ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`;oo`000oooool02?oo003o
oooooooooooo003oooooool00?ooooooo`000_ooool2ool000Sooooo00?oo`00ooooooooool00_oo
0002ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`0Bool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00000oooooooo`00ooooo`04oooo
o`;o00004_ooool0027ooooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00kooooo00?oo`00oooooooo00004?ooool00ooo003o0000ool0000Aooooo`03
ool00?ooooooo`0000oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0kooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool2ool00008oooooooo003oooooool0
0?ooooooo`00oooooooo0002ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo
0002ooooo`;oo`000oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0003ooooo`03ool0
0?oooooooooo00Wooooo00?oo`00ooooooooool00_oo0002ooooo`05ool00?ooooooo`00oooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo0_oo00001?ooooooo`00ooooooooool2
ool000?ooooo00Koo`00ooooooooooooooooo`000?oo0002ooooo`;oo`000_ooool01Ooo003ooooo
ool00?ooooooo`0000;ooooo0_oo0003ooooo`08ool00?ooooooooooool00?ooooooo`00oooooooo
0002ooooo`;oo`002?ooool00ooo003oooooooooo`02ool000;ooooo00?oo`00ooooooooool00_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`0>ool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool00003oooooooo003ooooo00Gooooo00?o0000ooooooooool04?ooool0027ooooo00?o
0000ooooooooool0>_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o
o`00oooooooo00004?ooool00ooo003o0000ool0000Aooooo`03ool00?ooooooo`0000oooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool01Oooool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo0002oooo
o`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00;oo`000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0003
ooooo`04ool00?ooooooooooooooo`;oo`0000Coooooool00?oooooooooo0_oo0003ooooo`06ool0
0?ooooooooooooooool0003oo`000_ooool2ool000;ooooo00Goo`00oooooooo003oooooool00002
ooooo`;oo`000oooool02?oo003ooooooooooooo003oooooool00?ooooooo`000_ooool2ool000So
oooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool03_oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00000ooo
ooooo`00ooooo`05ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o0000>oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo00004?ooool00ooo003o
0000ool0000Aooooo`03ool00?ooooooo`0000oooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0jooooo`;o0000:?ooool00ol0003oooooooooo`05ooooo`;oo`0000Soooooool00?oo
ooooo`00oooooooo003oooooool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`02ool000;ooooo0_oo
0002ooooo`03ool00?oooooooooo00Kooooo00Coo`00ooooooooooooo`000oooool2ool000;ooooo
00?oo`00ooooooooool00_oo0003ooooo`04ool00?ooooooooooooooo`;oo`0000Coooooool00?oo
oooooooo0_oo0003ooooo`06ool00?ooooooooooooooool0003oo`000_ooool2ool000;ooooo00Go
o`00oooooooo003oooooool00002ooooo`;oo`000oooool02?oo003ooooooooooooo003oooooool0
0?ooooooo`000_ooool2ool000?ooooo00?oo`00ooooooooool00_ooool01?oo003ooooooooooooo
0003ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00[oo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo00000oooooooo`00ooooo`05ooooo`03o`000?oooooo
oooo013ooooo000Qooooo`03o`000?oooooooooo03[ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`0>ooooo`03ool00?ooooooo`00013ooooo00?oo`00o`000?oo00004Oooool00ooo
003oooooool0000?ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0>oooool00ol0
003oooooooooo`0Vooooo`;o00001_ooool2ool00008oooooooo003oooooool00?ooooooo`00oooo
oooo0002ooooo`;oo`0000?oooooool00?oo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool0
1_ooool01?oo003ooooooooooooo0003ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000?o
oooo00Coo`00oooooooooooooooo0_oo00001?ooooooo`00ooooooooool2ool000?ooooo00Koo`00
ooooooooooooooooo`000?oo0002ooooo`;oo`000_ooool01Ooo003oooooool00?ooooooo`0000;o
oooo0_oo0003ooooo`03ool00?oooooooooo00;oo`000_ooool00ooo003oooooooooo`02ool000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`0:ool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`0000?oooooool00?ooool01?ooool2o`0001;ooooo000Qooooo`03o`000?oooooooooo03[o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`;oo`004_ooool2ool0017o
oooo00?oo`00oooooooo00003oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`0;ool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo00000_ooool2ool00003oooooooo003oo`0000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`05ool00?oooooooooooooooooo00001?ooool01?oo003ooooooooooooo0003oooo
o`;oo`000_ooool00ooo003oooooooooo`02ool000?ooooo00Coo`00oooooooooooooooo0_oo0000
1?ooooooo`00ooooooooool2ool000?ooooo00Koo`00ooooooooooooooooo`000?oo0002ooooo`;o
o`000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0003ooooo`03ool00?oooooooooo
00;oo`000_ooool00ooo003oooooooooo`02ool000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01_oo003oooooool00?ooooooo`00ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?ooool01Oooool00ol0003o
ooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0jooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool03_ooool2ool001;ooooo0_oo000Aooooo`03ool00?ooooooo`0000oooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo
0_l00004ooooo`03o`000?oooooooooo00Cooooo013oo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo
003oooooooooooooooooo`0000Cooooo00Coo`00ooooooooooooo`000oooool2ool000;ooooo00?o
o`00ooooooooool00_oo0003ooooo`05ool00?oooooooooooooooooo00000_ooool00ooo003ooooo
ooooo`02ool000?ooooo00Koo`00ooooooooooooooooo`000?oo0002ooooo`09ool00?oooooooooo
oooooooo003oooooool00?ooooooo`0000;ooooo0_oo0003ooooo`03ool00?oooooooooo00;oo`00
0_ooool00ooo003oooooooooo`02ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?ooooooo`00ooooooooool2
ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?ooool01Oooool00ol0003oooooooooo`0@
ooooo`008Oooool00ol0003oooooooooo`0jooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool03_ooool2ool001;ooooo0_oo000Aooooo`03ool00?ooooooo`0000oooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`04ooooo`0@ool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
00Goo`00ooooooooooooooooool00004ooooo`04ool00?ooooooooooool000?ooooo0_oo0002oooo
o`03ool00?oooooooooo00;oo`000oooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00
ooooooooool00_oo0003ooooo`06ool00?ooooooooooooooool0003oo`000_ooool02Ooo003ooooo
ooooooooooooo`00oooooooo003oooooool00002ooooo`;oo`000_ooool01?oo003ooooooooooooo
ool2ool000;ooooo00?oo`00ooooooooool00_oo0003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Koooooool00?oo
ooooo`00oooooooo0002ooooo`;oo`000_ooool2ool00003oooooooo003ooooo00Gooooo00?o0000
ooooooooool04?ooool0027ooooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00kooooo0_oo000Booooo`;oo`004_ooool00ooo003oooooooooo`0>oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0>oooool00ol0003oooooooooo`0Ooooo
o`04o`000?ooooooooooo`0000?ooooo1ol000004?oo003o0000ool00?l0003oo`00o`000?oo003o
0000ool00?l0003oo`00o`000?oo003o0000ool00?l00002ool000;o00000_oo0002o`0000;oo`00
0_l00002ool000;o00000_oo0002o`0000;oo`000_l00002ool000;o00000_oo0002o`000005ool0
0?l0003o0000o`000?oo00001?l000001?oo003o0000o`000?oo0003o`0000;oo`000_l000000ooo
003o0000o`000002ool000?o000000Goo`00o`000?l0003o0000ool00002o`000003ool00?l0003o
000000;oo`000ol000000ooo003o0000o`000002o`000004ool00?l0003o0000ool000?o00000_oo
0002o`000003ool00?l0003o000000;oo`000_l000001?oo003o0000o`000?l00002ool000;o0000
00?oo`00o`000?l000000_oo0002o`0000;oo`000ol000001Ooo003o0000o`000?l0003oo`0000?o
000000?oo`00o`000?l000000_oo0002o`0000;oo`000_l00002ool000;o00000_oo0002o`0000;o
o`000_l00002ool000;o00000_oo0002o`0000;oo`0000[o0000ool00?l0003oo`00o`000?oo003o
0000ool00?l0003oo`000_l00002ool00003o`000?oo003o000000Ko00004_ooool0027ooooo0_l0
000kooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03oooool00ooo003ooooooooo
o`0@ooooo`;oo`004_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool0>_ooool2o`00027ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`04ooooo`0@ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00004
ooooo`04ool00?ooooooooooool000?ooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`000ooo
ool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00ooooooooool00_oo0003ooooo`05ool0
0?oooooooooooooooooo00000oooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00oooo
ooooool00_oo0002ooooo`04ool00?ooooooooooooooo`;oo`000_ooool00ooo003oooooooooo`02
ool000;ooooo0_oo0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo00003Oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool00_oo0007ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooo
oooo03[ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Rooooo`03o`000?oooooo
oooo02;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0kooooo`03o`000?oooooo
oooo01oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`0@ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00004ooooo`04ool00?oooooooooo
ool000?ooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`000_ooool00ooo003oooooooooo`02
ooooo`08ool00?ooooooooooool00?ooooooo`00oooooooo0003ooooo`05ool00?oooooooooooooo
oooo00000oooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00ooooooooool00_oo0002
ooooo`04ool00?ooooooooooooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo
0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo00003Oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool0
0_oo0007ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo03[ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`0@ool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo00Goo`00ooooooooooooooooool00004ooooo`04ool00?ooooooooooool000?ooooo0_oo
0002ooooo`03ool00?oooooooooo00;oo`000_ooool00ooo003oooooooooo`02ooooo`08ool00?oo
ooooooooool00?ooooooo`00oooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool0
1?oo003oooooooooooooool2ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`04ool00?oo
ooooooooooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0003ooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00003Ooooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0007ooooo`03
o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo03_ooooo00Goo`00oooooooooooo
ooooool0000Tooooo`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0kooooo`03o`000?oooooooooo023ooooo0_l00004ooooo`;o00001Oooool04?oo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`000_ooool00ooo003ooooo
ooooo`02ooooo`08ool00?ooooooooooool00?ooooooo`00oooooooo0003ooooo`05ool00?oooooo
oooooooooooo00000oooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00ooooooooool0
0_oo0002ooooo`04ool00?ooooooooooooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;o
oooo0_oo0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo00003Oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooool00_oo0006ooooo`;o00004_ooool0027ooooo00?o0000ooooooooool0>oooool01Ooo003o
ooooooooooooooooo`0002Cooooo00?o0000ooooooooool08_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo03_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04oooo
o`0@ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool2ool000;ooooo00Goo`00oooooooo003oooooool00002oooo
o`03ool00?oooooooooo00;ooooo00Soo`00ooooooooooooo`00oooooooo003oooooool000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooooooo`;oo`000_ooool00ooo
003oooooooooo`02ool000;ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`05ool00?oooooo
o`00oooooooo00000_ooool2ool000?ooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`02ool000;ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool0000=oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00ooooo`02ool000Oooooo00?o0000ooooooooool04?ooool0027ooooo00?o
0000ooooooooool0>oooool01Ooo003oooooooooooooooooo`0002Cooooo00?o0000ooooooooool0
8_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03_ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`04ooooo`0@ool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`0000Coooooool00?ooooooo`000_ooool2
ool000;ooooo0_oo00001?ooooooo`00oooooooo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooooooo`02oooo
o`08ool00?ooooooooooool00?ooooooo`00oooooooo0002ooooo`;oo`000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`000_ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00oooooooo003oooooool00002ooooo`;oo`000oooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;oo`000_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000go
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00;oo`001ooo
ool00ol0003oooooooooo`0@ooooo`008Oooool2o`0003cooooo00Goo`00ooooooooooooooooool0
000Tooooo`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0jooooo`;o0000:?ooool00ol0003oooooooooo`04ooooo`0@ool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`0000Soooooool00?oo
ooooo`00oooooooo003oooooool000;ooooo0_oo00001?ooooooo`00oooooooo0002ooooo`;oo`00
0_ooool2ool00004oooooooo003oooooool000;ooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo00Gooooo00Woo`00ooooooooooooooooool00?ooooooo`00oooooooo0000
0_ooool00ooo003oooooooooo`02ooooo`08ool00?ooooooooooool00?ooooooo`00oooooooo0002
ooooo`;oo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo0_oo0002ooooo`05ool00?oo
ooooo`00oooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
003oooooool00002ooooo`;oo`000oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`0000goooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003ooooo00;oo`001oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0
003oooooooooo`0kooooo`05ool00?oooooooooooooooooo00009?ooool00ol0003oooooooooo`0R
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0>oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Cooooo013oo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo0_oo00005?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_oo
ool2ool00005oooooooo003oooooool00?ooool00_oo0003ooooo`05ool00?oooooooooooooooooo
00001oooool02Ooo003oooooooooooooooooo`00oooooooo003oooooool00002ooooo`03ool00?oo
oooooooo00;ooooo00Soo`00ooooooooooooo`00oooooooo003oooooool000;ooooo0_oo0003oooo
o`05ool00?oooooooooooooooooo00000oooool2ool000;ooooo00Goo`00oooooooo003oooooool0
0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooool00?ooooooo`0000;o
oooo0_oo0003ooooo`03ool00?oooooooooo00Sooooo0_oo0002ooooo`05ool00?oooooooooooooo
oooo00000oooool01?oo003oooooooooooooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool0000=oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02
ool000Oooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0>oooool01Ooo
003oooooooooooooooooo`0002Cooooo00?o0000ooooooooool08_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo03_ooooo00?o0000ooooooooool09_ooool2o`0000Gooooo013oo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
0_oo00005?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`000_ooool2ool00005oooooooo003oooooool00?ooool0
0_oo0003ooooo`05ool00?oooooooooooooooooo00001oooool02Ooo003oooooooooooooooooo`00
oooooooo003oooooool00002ooooo`03ool00?oooooooooo00;ooooo00Soo`00ooooooooooooo`00
oooooooo003oooooool000;ooooo0_oo0003ooooo`05ool00?oooooooooooooooooo00000oooool2
ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0003ooooo`03ool00?oooooooooo00So
oooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003oooooooooooooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0000=oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooo`02ool000Kooooo0_l0000Booooo`008Oooool00ol0
003oooooooooo`0kooooo`05ool00?oooooooooooooooooo00009?ooool00ol0003oooooooooo`0R
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0>oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00?ooooo017oo`00ooooooooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool0000Moooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0003ooooo`05ool00?oooooo
oooooooooooo00001oooool02Ooo003oooooooooooooooooo`00oooooooo003oooooool00002oooo
o`03ool00?oooooooooo00;ooooo00Soo`00ooooooooooooo`00oooooooo003oooooool000;ooooo
0_oo0003ooooo`05ool00?oooooooooooooooooo00000oooool2ool000;ooooo00Goo`00oooooooo
003oooooool00002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooool00?oo
ooooo`0000;ooooo0_oo0003ooooo`03ool00?oooooooooo00Sooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool0000=oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00ooooo`02ool000Oooooo00?o0000ooooooooool04?ooool001Cooooo0ol00004ooooo`;o0000
1?ooool00ol0003oooooooooo`0kooooo`05ool00?oooooooooooooooooo00009?ooool00ol0003o
ooooooooo`0Rooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0>oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`0:
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`0001goooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool000;ooooo0_oo0003
ooooo`03ool00?oooooooooo00Gooooo00Woo`00ooooooooooooooooool00?ooooooo`00oooooooo
00000_ooool00ooo003oooooooooo`05ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool0
00?ooooo00?oo`00ooooooooool01Oooool2ool000;ooooo00Goo`00oooooooo003oooooool00002
ooooo`03ool00?oooooooooo00Gooooo00Goo`00oooooooo003oooooool00002ooooo`;oo`000_oo
ool00ooo003oooooooooo`0=ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo0_oo0002ooooo`;oo`000_ooool2ool0000=oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool000Oooooo00?o0000oooooooo
ool04?ooool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0>oooool01Ooo003oooooooooooooooooo`0002Cooooo00?o0000
ooooooooool08_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03_ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`000_ooool2
ool000;ooooo00Koo`00oooooooo003oooooool00?ooool2ool0000Moooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`000oooool0
0ooo003oooooooooo`05ooooo`09ool00?oooooooooooooooooo003oooooool00?ooooooo`0000;o
oooo00?oo`00ooooooooool01Oooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0003oooo
o`03ool00?oooooooooo00Gooooo00Woo`00ooooooooooooooooool00?ooooooo`00oooooooo0000
0_ooool00ooo003oooooooooo`05ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000;o
oooo00?oo`00ooooooooool03Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2ool0000=oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool000Oooooo00?o
0000ooooooooool04?ooool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000?ooooo0_l0000looooo`05ool00?oooooooooooooooooo00009?ooool00ol0003o
ooooooooo`0Rooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0>Oooool3o`0002So
oooo0_l00004ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo00Koo`00oooooooo
003oooooool00?ooool2ool0000Moooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooool00_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`05ooooo`09
ool00?oooooooooooooooooo003oooooool00?ooooooo`0000;ooooo00?oo`00ooooooooool01Ooo
ool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0003ooooo`03ool00?oooooooooo00Gooooo
00_oo`00ooooooooooooooooool00?ooooooo`00oooooooo003oooooool00008ooooo`05ool00?oo
ooooo`00oooooooo00000_ooool2ool000;ooooo00?oo`00ooooooooool04Oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`;oo`000_ooool2ool0
000=oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool0
00Kooooo0_l0000Booooo`004oooool4o`0000?ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`0kooooo`05ool00?oooooooooooooooooo00009?ooool00ol0003oooooooooo`0S
ooooo`05ool00?oooooooooooooooooo0000?Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo027o
o`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool00_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`05ooooo`09ool00?oo
oooooooooooooooo003oooooool00?ooooooo`0000;ooooo00?oo`00ooooooooool01Oooool2ool0
00;ooooo00?oo`00ooooooooool00_oo0003ooooo`03ool00?oooooooooo00Gooooo00_oo`00oooo
ooooooooooooool00?ooooooo`00oooooooo003oooooool00008ooooo`05ool00?ooooooo`00oooo
oooo00000_ooool2ool000;ooooo00?oo`00ooooooooool04Oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0_ooool03?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`00
1oooool00ol0003oooooooooo`0@ooooo`004oooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0>oooool01Ooo003oooooooooooooooooo`0002Co
oooo00?o0000ooooooooool08oooool01Ooo003oooooooooooooooooo`0003gooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`0Qool00?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo00;oo`000_ooool2ool000?ooooo00?oo`00oooo
ooooool01Oooool02Ooo003oooooooooooooooooo`00oooooooo003oooooool00002ooooo`03ool0
0?oooooooooo00Gooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`000_ooool00ooo003o0000
ooooo`06ooooo`0;ool00?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo00002?oo
ool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0002ooooo`03ool00?oooooooooo01Gooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`02ool000;ooooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`00
1oooool00ol0003oooooooooo`0@ooooo`005?ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0>oooool01Ooo003oooooooooooooooooo`0002Co
oooo00?o0000ooooooooool08oooool01?oo003ooooooooooooo000nooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool0000Ooooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ooooo`02ool000;ooooo0_oo0003ooooo`03ool00?oooooooooo00Go
oooo00_oo`00ooooooooooooooooool00?ooooooo`00oooooooo003oooooool00008ooooo`;oo`00
0_ooool00ooo003oooooooooo`02ool000;ooooo00?oo`00o`000?ooool01_ooool01?oo003ooooo
ooooooooool2ool000;ooooo00?oo`00oooooooo00002?ooool2ool000;ooooo00?oo`00oooooooo
ool00_oo0002ooooo`03ool00?oooooooooo01Gooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002
ooooo`04ool00?ooooooo`00ooooo`;oo`001oooool00ol0003oooooooooo`0@ooooo`005Oooool2
o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo03_ooooo00Coo`00ooooooooooooo`009Ooo
ool00ol0003oooooooooo`0Sooooo`04ool00?ooooooooooool003kooooo00?o0000ooooooooool0
9_ooool2o`0000Cooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo00007oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool00_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`09ooooo`;oo`000_oo
ool00ooo003oooooool00008ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo00?o
o`00o`000?ooool01_ooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00oooooooo0000
2?ooool2ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo01Wooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`05ooooo`;o00004_ooool0027o
oooo00?o0000ooooooooool0>oooool01?oo003ooooooooooooo000Uooooo`03o`000?oooooooooo
02?ooooo00Coo`00ooooooooooooo`00?_ooool00ol0003oooooooooo`0Oooooo`?o00001?ooool0
0ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`0000?oooooool00?oo00000_ooool06_oo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003ooooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`09ooooo`;oo`00
0_ooool00ooo003oooooool00008ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo
00?oo`00o`000?ooool01_ooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00oooooooo
00002?ooool2ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo01Wo
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooo
oooo013ooooo000Qooooo`;o0000??ooool01?oo003ooooooooooooo000Uooooo`03o`000?oooooo
oooo02?ooooo00Coo`00ooooooooooooo`00?Oooool2o`0002;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`0000?oooooool00?oo00000_ooool2ool000;ooooo01Koo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0:ooooo`;oo`000_oo
ool00ooo003oooooool00008ooooo`;oo`000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo
00?oo`00o`000?ooool01_ooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00oooooooo
00002?ooool2ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?oooooooooo
01gooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool04?ooool0
027ooooo00?o0000ooooooooool0>oooool01?oo003ooooooooooooo000Uooooo`03o`000?oooooo
oooo02?ooooo00Coo`00ooooooooooooo`00?_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool00003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000_oo
ool04_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool02_ooool2ool0
00;ooooo00?oo`00oooooooo00002?ooool2ool000;ooooo00Goo`00oooooooo003oooooool00002
ooooo`03ool00?l0003ooooo00Kooooo00Coo`00oooooooooooooooo0_oo0002ooooo`03ool00?oo
ooooo`0000Sooooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003ooooo
ooooo`0Mooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;o
oooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo013o
oooo000Qooooo`03o`000?oooooooooo03_ooooo00Coo`00ooooooooooooo`009Oooool00ol0003o
ooooooooo`0Sooooo`04ool00?ooooooooooool003kooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`03ooooo`?o00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool00003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo00koo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool02_ooool2ool000;ooooo00?oo`00
oooooooo00002?ooool2ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?l0
003ooooo00Kooooo00Coo`00oooooooooooooooo0_oo0002ooooo`03ool00?ooooooo`0000Sooooo
0_oo0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooooooo`0Qooooo`05
ool00?oooooooooooooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo
003oooooooooo`05ooooo`;o00004_ooool0027ooooo00?o0000ooooooooool0>oooool01?oo003o
oooooooooooo000Uooooo`03o`000?oooooooooo02?ooooo00Coo`00ooooooooooooo`00?_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00003oooooooo003o
o`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00koo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?o
o`00ooooooooool02_ooool2ool000;ooooo00?oo`00oooooooo00002?ooool2ool000;ooooo00Go
o`00oooooooo003oooooool00002ooooo`03ool00?l0003ooooo00Kooooo00Coo`00oooooooooooo
oooo0_oo0002ooooo`03ool00?ooooooo`0000Sooooo0_oo0002ooooo`05ool00?ooooooo`00oooo
oooo00000_ooool00ooo003oooooooooo`0Qooooo`05ool00?oooooooooooooooooo00000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooo
oooo013ooooo000Qooooo`03o`000?oooooooooo03_ooooo00Coo`00ooooooooooooo`009Oooool0
0ol0003oooooooooo`0Sooooo`04ool00?ooooooooooool003kooooo00?o0000ooooooooool07ooo
ool2o`0000Gooooo00?o0000ooooooooool00oooool01?oo003ooooooooooooo0003ooooo`;oo`00
0_ooool2ool000;ooooo0_oo00000oooooooo`00ool00002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool02_oo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00[ooooo0_oo0002ooooo`03ool00?oo
ooooo`0000Sooooo00Woo`00ooooooooooooooooool00?ooooooo`00oooooooo00000_ooool00ooo
003o0000ooooo`06ooooo`04ool00?ooooooooooooooo`;oo`000_ooool00ooo003oooooool00008
ooooo`09ool00?oooooooooooooooooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo
ool09Oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003o
ooooooooo`06ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo03_ooooo
00Coo`00ooooooooooooo`009Oooool00ol0003oooooooooo`0Sooooo`04ool00?ooooooooooool0
03kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00Coo`00ooooooooooooo`000oooool2ool000;ooooo0_oo0002ooooo`;oo`0000?ooooo
ool00?oo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00[oo`00
oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool00ooo
003oooooooooo`0:ooooo`;oo`000_ooool00ooo003oooooool0000<ooooo`05ool00?ooooooo`00
oooooooo00000_ooool00ooo003o0000ooooo`0:ooooo`;oo`000_ooool00ooo003oooooool00008
ooooo`09ool00?oooooooooooooooooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo
ool09Oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003o
ooooooooo`06ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o0000??ooool01?oo003ooooo
oooooooo000Uooooo`03o`000?oooooooooo02?ooooo00Coo`00ooooooooooooo`00?Oooool2o`00
02Sooooo0_l00003ooooo`05ool00?oooooooooooooooooo00000oooool2ool000;ooooo0_oo0002
ooooo`;oo`0000?oooooool00?oo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`06ool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`00
0_ooool00ooo003oooooooooo`0:ooooo`;oo`000_ooool00ooo003oooooool0000<ooooo`05ool0
0?ooooooo`00oooooooo00000_ooool00ooo003o0000ooooo`0:ooooo`;oo`000_ooool00ooo003o
ooooool00008ooooo`0;ool00?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo0000
:oooool2ool000;ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`03ool00?oooooooooo00Go
oooo0_l0000Booooo`008Oooool00ol0003oooooooooo`0kooooo`04ool00?ooooooooooool002Go
oooo00?o0000ooooooooool08oooool01?oo003ooooooooooooo000nooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo0_oo0002
ooooo`;oo`000_ooool2ool00003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Koo`00oooooooo003oooooool0
0?ooool2ool000;ooooo00?oo`00ooooooooool02_ooool2ool000;ooooo00?oo`00oooooooo0000
3?ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00o`000?ooool02_ooool2ool000;o
oooo00?oo`00oooooooo00002?ooool02ooo003oooooooooooooooooo`00oooooooo003oooooool0
0?ooooooo`0002oooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00Ko
oooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0>oooool01?oo003ooooo
oooooooo000Uooooo`03o`000?oooooooooo02?ooooo00Coo`00ooooooooooooo`00?_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2ool00003oooooooo003oo`0000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Ko
o`00oooooooo003oooooool00?ooool2ool000;ooooo00?oo`00ooooooooool02_ooool2ool000;o
oooo00?oo`00oooooooo00003?ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00o`00
0?ooool02_ooool2ool000;ooooo0_oo0009ooooo`0;ool00?oooooooooooooooooo003oooooool0
0?ooooooo`00oooooooo0000;oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool01_ooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0kooooo`04
ool00?ooooooooooool002Gooooo00?o0000ooooooooool08oooool01?oo003ooooooooooooo000n
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`0000?oooooool00?oo0000
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo00Coo`00oooooooo003oo`000_ooool00ooo003oooooooooo`0:ooooo`07
ool00?oooooooooooooooooo003oooooool0000<ooooo`05ool00?ooooooo`00oooooooo00000_oo
ool00ooo003o0000ooooo`0:ooooo`;oo`000_ooool2ool000gooooo00Ooo`00oooooooo003ooooo
ool00?ooooooo`0003?ooooo00Goo`00ooooooooooooooooool00008ooooo`03o`000?oooooooooo
013ooooo000Qooooo`03o`000?oooooooooo03_ooooo00Coo`00ooooooooooooo`009Oooool00ol0
003oooooooooo`0Sooooo`04ool00?ooooooooooool003kooooo00?o0000ooooooooool09_ooool2
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooooooo`;oo`00
0_ooool2ool00003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`04ool00?ooooooo`00ool000;o
oooo00?oo`00ooooooooool02_ooool01?oo003oooooooooooooool2ool000gooooo00Woo`00oooo
oooo003oooooool00?ooooooo`00ooooool000002oooool01?oo003oooooooooooooool2ool000go
oooo00Ooo`00oooooooo003oooooool00?ooooooo`0003?ooooo00Goo`00ooooooooooooooooool0
0007ooooo`;o00004_ooool0027ooooo00?o0000ooooooooool0>oooool01?oo003ooooooooooooo
000Uooooo`03o`000?oooooooooo02?ooooo00Coo`00ooooooooooooo`00?_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool2ool00003oooooooo003oo`0000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`0000Goooooool00?ooooooooooool0000<ooooo`04ool00?ooooooooooooooo`;oo`003Ooo
ool02Ooo003oooooool00?ooooooo`00oooooooo003oooooo`00000;ooooo`04ool00?oooooooooo
ooooo`;oo`003Oooool01ooo003oooooool00?ooooooo`00oooooooo0000=oooool00ooo003ooooo
ooooo`06ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o0000??ooool01?oo003ooooooooo
oooo000Uooooo`03o`000?oooooooooo02?ooooo00Coo`00ooooooooooooo`00?Oooool2o`0002So
oooo00?o0000ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0000
1Oooooooo`00ooooooooooooo`0000cooooo00Coo`00oooooooooooooooo0_oo000=ooooo`09ool0
0?ooooooo`00oooooooo003oooooool00?oooooo000000_ooooo00Coo`00oooooooooooooooo0_oo
000=ooooo`07ool00?ooooooo`00oooooooo003oooooool0000gooooo`03ool00?oooooooooo00Ko
oooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0>oooool01?oo003ooooo
oooooooo000Uooooo`03o`000?oooooooooo02?ooooo00Coo`00ooooooooooooo`00?_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`0000Goooooool00?ooooooooooool0000<ooooo`04ool00?ooooooooooooooo`;o
o`003Oooool2ool000;ooooo00Goo`00oooooooo003oooooo`00000;ooooo`04ool00?oooooooooo
ooooo`;oo`003Oooool01ooo003oooooool00?ooooooo`00oooooooo0000@?ooool00ol0003ooooo
ooooo`0@ooooo`008Oooool00ol0003oooooooooo`0kooooo`04ool00?ooooooooooool002Gooooo
00?o0000ooooooooool08oooool01?oo003ooooooooooooo000nooooo`03o`000?oooooooooo02Ko
oooo0_l00007ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00004oooooooo003oooooool000gooooo00Co
o`00oooooooooooooooo0_oo000=ooooo`;oo`000_ooool01Ooo003oooooool00?oooooo000000_o
oooo00Coo`00oooooooooooooooo0_oo000=ooooo`;oo`000_ooool00ooo003oooooool0000ooooo
o`;o00004_ooool0027ooooo00?o0000ooooooooool0>oooool01?oo003ooooooooooooo000Uoooo
o`03o`000?oooooooooo02?ooooo00Coo`00ooooooooooooo`00?_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Kooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000_ooool2ool000;ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?oooooo
o`00oooooooo000=ooooo`04ool00?ooooooooooooooo`;oo`003Oooool2ool000;ooooo00Goo`00
oooooooo003oooooo`00000;ooooo`04ool00?ooooooooooooooo`;oo`003Oooool2ool000;ooooo
00?oo`00oooooooo0000@?ooool00ol0003oooooooooo`0@ooooo`005?ooool3o`0000Cooooo0_l0
0004ooooo`03o`000?oooooooooo03_ooooo00Coo`00ooooooooooooo`009Oooool00ol0003ooooo
ooooo`0Sooooo`04ool00?ooooooooooool003kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0:ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool0
00;ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?ooooooo`00oooooooo000=ooooo`04ool00?oo
ooooooooooooo`;oo`003Oooool2ool000;ooooo00Goo`00oooooooo003oooooo`00000;ooooo`04
ool00?ooooooooooooooo`;oo`003Oooool2ool000;ooooo00?oo`00oooooooo0000@?ooool00ol0
003oooooooooo`0@ooooo`004oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`0kooooo`04ool00?ooooooooooool002Gooooo00?o
0000ooooooooool08oooool01?oo003ooooooooooooo000nooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool03_ooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`05
ool00?oooooooooooooooooo00000oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`003Oooool01?oo003ooooooooooooo
ool2ool000gooooo0_oo0002ooooo`05ool00?ooooooo`00ooooool000002oooool01?oo003ooooo
ooooooooool2ool000gooooo0_oo0002ooooo`03ool00?ooooooo`00043ooooo00?o0000oooooooo
ool04?ooool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00?ooooo0_l0000looooo`04ool00?ooooooooooool002Gooooo00?o0000ooooooooool08oooool0
1?oo003ooooooooooooo000looooo`?o0000:?ooool2o`0000oooooo00Goo`00oooooooooooooooo
ool00002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooo
oooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Coooooool0
0?ooooooo`003Oooool01?oo003oooooooooooooool2ool000gooooo0_oo0002ooooo`05ool00?oo
ooooo`00ooooool000002oooool01?oo003oooooooooooooool2ool000gooooo0_oo0002ooooo`03
ool00?ooooooo`0003oooooo0_l0000Booooo`005?ooool3o`0000?ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`0looooo`03ool00?ooooooo`0002Gooooo00?o0000oooooooo
ool08oooool01?oo003ooooooooooooo000nooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04_ooool00ooo003oooooooooo`02ool000;ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool00004oooooooo003oooooool0017ooooo0_oo000=ooooo`;oo`000_ooool01Ooo003ooooo
ool00?oooooo000000_ooooo00Coo`00oooooooooooooooo0_oo000=ooooo`;oo`000_ooool00ooo
003oooooool00010ooooo`03o`000?oooooooooo013ooooo000Cooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo03cooooo00?oo`00
oooooooo00009Oooool00ol0003oooooooooo`0Sooooo`04ool00?ooooooooooool003kooooo00?o
0000ooooooooool07_ooool5o`0000?ooooo00?o0000ooooooooool04_ooool00ooo003ooooooooo
o`02ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00004oooooooo003oooooool0
017ooooo0_oo000=ooooo`09ool00?oooooooooooooooooo003oooooool00?oooooo000000_ooooo
00Coo`00oooooooooooooooo0_oo000=ooooo`;oo`000_ooool00ooo003oooooool00010ooooo`03
o`000?oooooooooo013ooooo000Cooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo03cooooo00?oo`00oooooooo00009Oooool00ol0
003oooooooooo`0Tooooo`03ool00?ooooooo`0003kooooo00?o0000ooooooooool07oooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo01Gooooo0_oo0002ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooo
oooo0_oo0002ooooo`;oo`000_ooool2ool00004oooooooo003oooooool0017ooooo0_oo000=oooo
o`09ool00?oooooooooooooooooo003oooooool00?oooooo000000_ooooo00Goo`00oooooooooooo
ooooool0000>ooooo`;oo`000_ooool2ool0047ooooo00?o0000ooooooooool04?ooool001Cooooo
0ol00004ooooo`;o00001?ooool00ol0003oooooooooo`0looooo`03ool00?ooooooo`0002Gooooo
00?o0000ooooooooool09?ooool00ooo003oooooool0000nooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool00oooool3o`0001Gooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo0_oo0002
ooooo`;oo`000_ooool2ool00004oooooooo003oooooool0017ooooo0_oo000=ooooo`09ool00?oo
oooooooooooooooo003oooooool00?oooooo000000_ooooo00Goo`00ooooooooooooooooool0000>
ooooo`;oo`000_ooool2ool0043ooooo0_l0000Booooo`008Oooool00ol0003oooooooooo`0loooo
o`03ool00?ooooooo`0002Gooooo00?o0000ooooooooool09?ooool00ooo003oooooool0000noooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Ioooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`;oo`000_ooool2ool00004oooooooo003oooooool0017o
oooo00?oo`00ooooooooool04?ooool01Ooo003oooooool00?oooooo000000oooooo00?oo`00oooo
ooooool03?ooool2ool000;ooooo0_oo0011ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o
0000?Oooool00ooo003oooooool0000Uooooo`03o`000?oooooooooo02Cooooo00?oo`00oooooooo
0000?Oooool2o`00023ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
01gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000ooo
ool01?oo003oooooooooooooool2ool000;ooooo0_oo00001?ooooooo`00oooooooo000Aooooo`03
ool00?oooooooooo013ooooo0_oo0002ooooo`03o`000?oooooooooo00gooooo00?oo`00oooooooo
ool03?ooool01?oo003oooooooooooooool2ool0047ooooo00?o0000ooooooooool04?ooool0027o
oooo00?o0000ooooooooool0??ooool00ooo003oooooool0000Uooooo`03o`000?oooooooooo02Co
oooo00?oo`00oooooooo0000?_ooool00ol0003oooooooooo`0Nooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0Mooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`;oo`00
00Coooooool00?ooooooo`004Oooool00ooo003oooooooooo`0@ooooo`;oo`000_ooool00ol0003o
ooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00Coo`00oooooooooooooooo0_oo0011oooo
o`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo03cooooo00?oo`00oooooooo
00009Oooool00ol0003oooooooooo`0Tooooo`03ool00?ooooooo`0003kooooo00?o0000oooooooo
ool07oooool3o`0000Cooooo0_l0000Rooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?oo
ooooo`00017ooooo00?oo`00ooooooooool04?ooool2ool000;ooooo00?o0000ooooooooool03Ooo
ool00ooo003oooooooooo`0<ooooo`04ool00?ooooooooooooooo`;oo`00@?ooool2o`0001;ooooo
000Qooooo`03o`000?oooooooooo03cooooo00?oo`00oooooooo00009Oooool00ol0003ooooooooo
o`0Tooooo`03ool00?ooooooo`0003kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Qooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?ooooooo`00017ooooo00?oo`00oooo
ooooool04?ooool2ool000;ooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`0<oooo
o`04ool00?ooooooooooooooo`;oo`00@Oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0
003oooooooooo`0looooo`03ool00?ooooooo`0002Gooooo00?o0000ooooooooool09?ooool00ooo
003oooooool0000nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09Oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`06ool00?oo
ooooooooool00?ooooooo`004Oooool00ooo003oooooooooo`0@ooooo`;oo`000_ooool00ol0003o
ooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00Coo`00oooooooooooooooo0_oo0011oooo
o`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo03cooooo00?oo`00oooooooo
00009Oooool00ol0003oooooooooo`0Tooooo`03ool00?ooooooo`0003kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0Uooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Koo`00ooooooooooooo`00oooooooo000Aooooo`03ool0
0?oooooooooo013ooooo0_oo0002ooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0
3?ooool01?oo003oooooooooooooool2ool0047ooooo00?o0000ooooooooool04?ooool0027ooooo
0_l0000mooooo`03ool00?ooooooo`0002Gooooo00?o0000ooooooooool09?ooool00ooo003ooooo
ool0000mooooo`;o0000:?ooool2o`0002[ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000_ooool2ool001;ooooo00?oo`00ooooooooool04?ooool2ool0
00;ooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`0@ooooo`;oo`00@?ooool2o`00
01;ooooo000Qooooo`03o`000?oooooooooo03cooooo00?oo`00oooooooo00009Oooool00ol0003o
ooooooooo`0Tooooo`03ool00?ooooooo`0003kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Yooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000;ooooo0_oo000Booooo`03ool00?oooooooooo013ooooo0_oo0002ooooo`03o`000?oooooo
oooo00gooooo00?oo`00ooooooooool04?ooool2ool0047ooooo00?o0000ooooooooool04?ooool0
027ooooo00?o0000ooooooooool0??ooool00ooo003oooooool0000Uooooo`03o`000?oooooooooo
02Cooooo00?oo`00oooooooo0000?_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
02gooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;oo`004_ooool0
0ooo003oooooooooo`0@ooooo`05ool00?ooooooooooooooool000003oooool00ooo003ooooooooo
o`0@ooooo`;oo`00@Oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0l
ooooo`03ool00?ooooooo`0002Gooooo00?o0000ooooooooool09?ooool00ooo003oooooool0000n
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0;Oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool00_oo000Booooo`03ool00?oooooooooo013ooooo00Go
o`00ooooooooooooooooo`00000?ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0
@?ooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0looooo`03ool00?oo
ooooo`0002Gooooo00?o0000ooooooooool09?ooool00ooo003oooooool0000nooooo`03o`000?oo
oooooooo02Kooooo0_l0000booooo`05ool00?oooooooooooooooooo00000_ooool2ool001;ooooo
00?oo`00ooooooooool04?ooool01Ooo003ooooooooooooooooo000000oooooo00?oo`00oooooooo
ool04?ooool00ooo003oooooooooo`0oooooo`;o00004_ooool0027ooooo00?o0000ooooooooool0
??ooool00ooo003oooooool0000Uooooo`03o`000?oooooooooo02Cooooo00?oo`00oooooooo0000
?_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo037ooooo00Goo`00oooooooooooo
ooooool00002ooooo`;oo`004_ooool00ooo003oooooooooo`0@ooooo`05ool00?oooooooooooooo
ool000003oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo043ooooo00?o0000oooo
ooooool04?ooool0027ooooo0_l0000mooooo`03ool00?ooooooo`0002Gooooo00?o0000oooooooo
ool09?ooool00ooo003oooooool0000mooooo`;o0000:?ooool00ol0003oooooooooo`0aooooo`05
ool00?oooooooooooooooooo00000_ooool2ool002Gooooo00Goo`00ooooooooooooooooo`00000?
ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0@?ooool00ol0003oooooooooo`0@
ooooo`008Oooool00ol0003oooooooooo`0looooo`03ool00?ooooooo`0002Gooooo00?o0000oooo
ooooool09?ooool00ooo003oooooool0000nooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0=Oooool00ooo003oooooooooo`02ool002Wooooo00?o0000ooooooooool08?ooool00ooo
003oooooooooo`10ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo03co
oooo0_oo000Vooooo`03o`000?oooooooooo02Cooooo00?oo`00oooooooo0000?_ooool00ol0003o
ooooooooo`0Vooooo`;o0000=_ooool00ooo003oooooooooo`02ool002Wooooo00?o0000oooooooo
ool08?ooool00ooo003oooooooooo`0oooooo`;o00004_ooool0027ooooo00?o0000ooooooooool0
??ooool2ool002Kooooo00?o0000ooooooooool09?ooool2ool003oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0hooooo`;oo`00:Oooool00ol0003oooooooooo`0Pooooo`03ool0
0?oooooooooo043ooooo00?o0000ooooooooool04?ooool000kooooo0ol00004ooooo`;o00001?oo
ool2o`0000Cooooo00?o0000ooooooooool0??ooool2ool002Kooooo00?o0000ooooooooool09?oo
ool2ool003oooooo00?o0000ooooooooool07oooool3o`0000Cooooo00?o0000ooooooooool0>?oo
ool00ooo003oooooooooo`0Xooooo`03o`000?oooooooooo023ooooo00?oo`00ooooooooool0@?oo
ool00ol0003oooooooooo`0@ooooo`003oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0looooo`;oo`00
9_ooool00ol0003oooooooooo`0Tooooo`;oo`00?oooool00ol0003oooooooooo`0Nooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo02So
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0@ooooo`003oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool2o`00
03kooooo00?oo`00ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo
03_ooooo0ol0000Tooooo`04o`000?ooooooooooooooo`?o0000Hoooool00ol0003oooooooooo`1R
ooooo`;o00004_ooool000oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0?Oooool00ooo003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Gooooo00?oo`00ooooooooool0?Oooool00ol0003ooooooooo
o`0Pooooo`;o00001?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00004_ooool000oooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooooooocOl0000B
ooooo`003_ooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo0000023ooooo00Go0000ooooooooooooooooo`00003Rooooo`003oooool00ol0003o
ooooooooo`03ooooo`;o00001?ooool2o`0000Coooood?l0000Qooooo`?o0000hoooool00?oooooo
nOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {147.312, 0}} -> {-0.0551454, -0.0147182, \
0.00419541, 0.00419541}, {{13.125, 240.125}, {143.75, 3.5}} -> {-4.37656, \
-15.1756, 0.0319803, 0.827684}, {{262.812, 489.812}, {143.75, 3.5}} -> \
{-12.4289, -3.84012, 0.0324072, 0.0490995}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot DTFT as a function of frequency", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g1 = 
        Plot[Abs[
            X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/
              2, fs/2}, \ PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[Arg[
            X\[Theta] /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-fs\)/2, 
            fs/2}, \ PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(ga2 = 
        Show[GraphicsArray[{{g1, g2}}], ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.00585664 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13185 -12 -4.5 ]
[-0.0125 .13185 0 4.5 ]
[-0.0125 .24898 -12 -4.5 ]
[-0.0125 .24898 0 4.5 ]
[-0.0125 .36611 -12 -4.5 ]
[-0.0125 .36611 0 4.5 ]
[-0.0125 .48325 -12 -4.5 ]
[-0.0125 .48325 0 4.5 ]
[-0.0125 .60038 -18 -4.5 ]
[-0.0125 .60038 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13185 m
.00625 .13185 L
s
[(20)] -0.0125 .13185 1 0 Mshowa
0 .24898 m
.00625 .24898 L
s
[(40)] -0.0125 .24898 1 0 Mshowa
0 .36611 m
.00625 .36611 L
s
[(60)] -0.0125 .36611 1 0 Mshowa
0 .48325 m
.00625 .48325 L
s
[(80)] -0.0125 .48325 1 0 Mshowa
0 .60038 m
.00625 .60038 L
s
[(100)] -0.0125 .60038 1 0 Mshowa
.125 Mabswid
0 .044 m
.00375 .044 L
s
0 .07328 m
.00375 .07328 L
s
0 .10256 m
.00375 .10256 L
s
0 .16113 m
.00375 .16113 L
s
0 .19041 m
.00375 .19041 L
s
0 .2197 m
.00375 .2197 L
s
0 .27826 m
.00375 .27826 L
s
0 .30755 m
.00375 .30755 L
s
0 .33683 m
.00375 .33683 L
s
0 .3954 m
.00375 .3954 L
s
0 .42468 m
.00375 .42468 L
s
0 .45396 m
.00375 .45396 L
s
0 .51253 m
.00375 .51253 L
s
0 .54181 m
.00375 .54181 L
s
0 .5711 m
.00375 .5711 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13185 m
1 .13185 L
s
.99375 .24898 m
1 .24898 L
s
.99375 .36611 m
1 .36611 L
s
.99375 .48325 m
1 .48325 L
s
.99375 .60038 m
1 .60038 L
s
.125 Mabswid
.99625 .044 m
1 .044 L
s
.99625 .07328 m
1 .07328 L
s
.99625 .10256 m
1 .10256 L
s
.99625 .16113 m
1 .16113 L
s
.99625 .19041 m
1 .19041 L
s
.99625 .2197 m
1 .2197 L
s
.99625 .27826 m
1 .27826 L
s
.99625 .30755 m
1 .30755 L
s
.99625 .33683 m
1 .33683 L
s
.99625 .3954 m
1 .3954 L
s
.99625 .42468 m
1 .42468 L
s
.99625 .45396 m
1 .45396 L
s
.99625 .51253 m
1 .51253 L
s
.99625 .54181 m
1 .54181 L
s
.99625 .5711 m
1 .5711 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02608 .0297 L
.02847 .04322 L
.02972 .04867 L
.03089 .05246 L
.03124 .05331 L
.03157 .05401 L
.03186 .05454 L
.03218 .055 L
.03234 .05519 L
.03252 .05537 L
.03269 .05551 L
.03284 .05561 L
.03292 .05565 L
.03301 .05569 L
.03311 .05572 L
.03321 .05574 L
.03329 .05575 L
.03338 .05575 L
.03347 .05574 L
.03355 .05572 L
.0337 .05568 L
.03383 .05561 L
.03398 .05552 L
.03414 .05539 L
.03446 .05505 L
.03476 .05463 L
.03533 .05356 L
.03587 .05222 L
.03707 .04821 L
.03838 .04235 L
.04072 .0289 L
.04196 .02076 L
.0423 .01847 L
.04249 .01722 L
.04266 .01605 L
.04281 .01504 L
.04297 .01546 L
.04306 .01607 L
.04314 .01665 L
.0433 .01773 L
.04574 .03359 L
.04804 .04581 L
.04921 .05045 L
.04985 .05244 L
.05045 .05392 L
.05096 .05488 L
.05125 .05529 L
.05151 .05559 L
.05165 .05572 L
Mistroke
.0518 .05583 L
.05188 .05589 L
.05196 .05593 L
.05211 .05599 L
.05225 .05602 L
.0524 .05604 L
.05254 .05603 L
.05268 .056 L
.05283 .05593 L
.05297 .05585 L
.05324 .05564 L
.05354 .05532 L
.05385 .05486 L
.05442 .05376 L
.05495 .05244 L
.05616 .04834 L
.05744 .04253 L
.05982 .02868 L
.06087 .0218 L
.06142 .01806 L
.06157 .01698 L
.06172 .01595 L
.06186 .01503 L
.062 .01539 L
.06215 .01642 L
.06231 .0175 L
.06259 .01944 L
.06314 .02316 L
.06434 .03101 L
.06556 .03834 L
.06686 .04515 L
.0681 .05035 L
.06922 .05381 L
.06977 .055 L
.07005 .05551 L
.07036 .05594 L
.07062 .05623 L
.07077 .05635 L
.07092 .05646 L
.07106 .05654 L
.07118 .05659 L
.07131 .05662 L
.07143 .05663 L
.07158 .05662 L
.07167 .05661 L
.07174 .05659 L
.07189 .05653 L
.07204 .05644 L
.0723 .05624 L
.07258 .05592 L
Mistroke
.07289 .05548 L
.07322 .05489 L
.07381 .05352 L
.07497 .04981 L
.07603 .04528 L
.07832 .03248 L
.07963 .02387 L
.08025 .01962 L
.08052 .01773 L
.08067 .01666 L
.08082 .01565 L
.08096 .01474 L
.0811 .01577 L
.08141 .01788 L
.08204 .02228 L
.08319 .03004 L
.08572 .04486 L
.08695 .05035 L
.0876 .05267 L
.08829 .05467 L
.08889 .056 L
.08923 .05658 L
.08955 .057 L
.08969 .05715 L
.08984 .05728 L
.08997 .05738 L
.09011 .05746 L
.09026 .05752 L
.0904 .05755 L
.09048 .05756 L
.09056 .05756 L
.09071 .05754 L
.09085 .0575 L
.091 .05743 L
.09114 .05734 L
.09127 .05723 L
.09159 .0569 L
.09189 .05648 L
.09248 .05535 L
.09313 .05367 L
.09428 .04957 L
.09535 .04463 L
.09763 .03122 L
.09882 .02308 L
.09947 .01847 L
.09964 .01731 L
.09979 .0162 L
.09993 .01521 L
.10008 .0153 L
.10016 .01587 L
Mistroke
.10024 .01646 L
.10039 .01753 L
.10073 .01991 L
.10143 .0249 L
.10267 .03332 L
.10384 .04061 L
.10511 .0474 L
.10634 .05268 L
.10746 .05618 L
.108 .05736 L
.10831 .05788 L
.10859 .05827 L
.10873 .05843 L
.10886 .05855 L
.10899 .05865 L
.10911 .05873 L
.10925 .0588 L
.10938 .05884 L
.10952 .05886 L
.10967 .05886 L
.10982 .05883 L
.10997 .05878 L
.11005 .05874 L
.11013 .05869 L
.1103 .05856 L
.11061 .05825 L
.1109 .05784 L
.11144 .05683 L
.11202 .05536 L
.11333 .05068 L
.11454 .04487 L
.11702 .02944 L
.11764 .02506 L
.11822 .02081 L
.11875 .01693 L
.11889 .01587 L
.11904 .01474 L
.11918 .01566 L
.11932 .01672 L
.12154 .03277 L
.12278 .04088 L
.12391 .04738 L
.12503 .05273 L
.12563 .05505 L
.12626 .0571 L
.12661 .05805 L
.12693 .05878 L
.12725 .05941 L
.12755 .05987 L
.12785 .06023 L
Mistroke
.12801 .06037 L
.12818 .06049 L
.12833 .06056 L
.12847 .06061 L
.12862 .06063 L
.1287 .06063 L
.12878 .06062 L
.12892 .06059 L
.12905 .06053 L
.1292 .06045 L
.12936 .06032 L
.12968 .05998 L
.12997 .05955 L
.13051 .05849 L
.13108 .057 L
.13228 .05264 L
.13359 .04617 L
.13615 .02944 L
.13674 .02507 L
.13737 .02034 L
.13762 .01837 L
.1379 .01624 L
.13806 .01501 L
.1382 .01553 L
.13835 .01666 L
.13848 .01773 L
.13965 .02667 L
.14091 .03591 L
.1432 .05024 L
.14436 .05577 L
.145 .05819 L
.14559 .06003 L
.1461 .06126 L
.14636 .06176 L
.14665 .06221 L
.14694 .06257 L
.14711 .06272 L
.14726 .06283 L
.1474 .0629 L
.14753 .06294 L
.14767 .06297 L
.14781 .06297 L
.14795 .06294 L
.1481 .06288 L
.14824 .0628 L
.14837 .0627 L
.14869 .06237 L
.14898 .06193 L
.14958 .06073 L
.15022 .05892 L
Mistroke
.15138 .05443 L
.15245 .04894 L
.15472 .03393 L
.15591 .02472 L
.15656 .01947 L
.15688 .01688 L
.15702 .01574 L
.15717 .01492 L
.15733 .01623 L
.15748 .01746 L
.15781 .02018 L
.15851 .0259 L
.15975 .03562 L
.16091 .04399 L
.16218 .05205 L
.16341 .05834 L
.16398 .06064 L
.16457 .06265 L
.16487 .06351 L
.16521 .06431 L
.16551 .06492 L
.16579 .06536 L
.16595 .06556 L
.16612 .06574 L
.16621 .06583 L
.1663 .06589 L
.16639 .06595 L
.16647 .06599 L
.16662 .06604 L
.16669 .06606 L
.16678 .06607 L
.16687 .06606 L
.16695 .06605 L
.1671 .066 L
.16725 .06592 L
.16742 .0658 L
.16757 .06565 L
.16771 .06549 L
.16826 .06457 L
.16855 .06394 L
.16886 .06311 L
.1695 .06104 L
.17065 .05599 L
.17172 .04991 L
.17397 .03362 L
.17516 .02371 L
.17576 .01852 L
.17592 .01708 L
.17601 .01629 L
.1761 .01553 L
Mistroke
.17618 .01483 L
.17626 .01536 L
.17642 .0167 L
.17775 .02836 L
.17898 .03867 L
.18026 .04838 L
.18141 .05601 L
.18263 .06252 L
.18319 .06489 L
.18378 .06694 L
.18408 .06781 L
.18441 .06861 L
.18472 .0692 L
.185 .06963 L
.18515 .06982 L
.18532 .06998 L
.18542 .07005 L
.18551 .07011 L
.18559 .07015 L
.18568 .07018 L
.18583 .07021 L
.18598 .07021 L
.18606 .07019 L
.18614 .07016 L
.18622 .07013 L
.18631 .07007 L
.18646 .06996 L
.18662 .0698 L
.18691 .06941 L
.1872 .06891 L
.18746 .06833 L
.18806 .06666 L
.18869 .06432 L
.18974 .05921 L
.1909 .05198 L
.19221 .04214 L
.19344 .0315 L
.19455 .02122 L
.19486 .01834 L
.19503 .01674 L
.19518 .01524 L
.19533 .0156 L
.19549 .01712 L
.19577 .01978 L
.198 .04062 L
.19926 .05128 L
.20045 .05992 L
.20161 .06685 L
.2022 .06972 L
.20285 .07225 L
Mistroke
.20321 .07336 L
.20354 .07422 L
.20385 .07488 L
.20401 .07515 L
.20418 .0754 L
.20434 .07559 L
.20448 .07572 L
.20462 .07582 L
.20476 .07588 L
.20492 .07592 L
.20506 .07592 L
.20515 .0759 L
.20522 .07587 L
.20531 .07583 L
.20539 .07578 L
.20553 .07566 L
.20568 .0755 L
.20595 .07513 L
.20627 .07452 L
.20657 .07381 L
.20721 .0718 L
.20781 .06929 L
.20888 .06351 L
.21004 .05543 L
.21137 .0442 L
.21262 .03217 L
.21374 .02056 L
.21404 .01729 L
.2142 .01564 L
.21429 .01473 L
.21437 .0156 L
.21495 .02182 L
.21742 .0475 L
.21968 .06698 L
.22084 .07458 L
.22145 .07776 L
.22209 .08048 L
.22266 .08225 L
.22298 .08301 L
.22314 .0833 L
.22328 .08355 L
.22341 .08373 L
.22356 .08389 L
.22369 .084 L
.22381 .08408 L
.22395 .08414 L
.22409 .08415 L
.22424 .08413 L
.22438 .08407 L
.22452 .08398 L
Mistroke
.22467 .08383 L
.22494 .08347 L
.22526 .08285 L
.22556 .08212 L
.22619 .07997 L
.2268 .07724 L
.22787 .07087 L
.22903 .06183 L
.23137 .03822 L
.23201 .03081 L
.2327 .02253 L
.23301 .01865 L
.23319 .01652 L
.23327 .01548 L
.23335 .0149 L
.23349 .0166 L
.23363 .01843 L
.23395 .02231 L
.23641 .05215 L
.23868 .07549 L
.2398 .08443 L
.24038 .08816 L
.24099 .09148 L
.24132 .09292 L
.24161 .09405 L
.24191 .09501 L
.24219 .09574 L
.24251 .09637 L
.24268 .09661 L
.24277 .09671 L
.24286 .0968 L
.24295 .09687 L
.24304 .09691 L
.24311 .09694 L
.2432 .09696 L
.24334 .09695 L
.2435 .09688 L
.24366 .09676 L
.24381 .0966 L
.24397 .09637 L
.24414 .09606 L
.24442 .0954 L
.24474 .09445 L
.24532 .09214 L
.24586 .08929 L
.24707 .08066 L
.24838 .06813 L
.25076 .03845 L
.25141 .02917 L
.25176 .02393 L
Mistroke
.2521 .01892 L
.25225 .01663 L
.25233 .01547 L
.25242 .01524 L
.25251 .01662 L
.25259 .01792 L
.25276 .0204 L
.25335 .02946 L
.25585 .06657 L
.25814 .09503 L
.25929 .10596 L
.25989 .11056 L
.26054 .11449 L
.2611 .11705 L
.26142 .11813 L
.26157 .11854 L
.26173 .1189 L
.26186 .11916 L
.262 .11938 L
.26213 .11953 L
.26225 .11964 L
.2624 .1197 L
.26253 .11971 L
.26268 .11966 L
.26282 .11955 L
.26296 .11939 L
.26311 .11915 L
.26338 .11857 L
.2637 .1176 L
.26399 .11645 L
.26463 .1131 L
.26523 .10885 L
.2663 .09889 L
.26746 .08461 L
.26878 .06442 L
.27003 .04225 L
.27057 .0318 L
.27115 .02037 L
.2713 .01743 L
.27145 .01518 L
.27154 .01701 L
.27162 .01868 L
.27178 .02197 L
.27236 .03407 L
.27481 .08528 L
.27708 .12757 L
.27818 .14429 L
.27939 .15884 L
.28001 .16452 L
.2806 .16858 L
Mistroke
.28092 .17026 L
.28122 .17143 L
.28138 .17191 L
.28155 .17231 L
.28163 .17247 L
.28172 .17261 L
.28181 .17271 L
.28189 .17277 L
.28203 .17281 L
.28217 .17278 L
.28232 .17265 L
.28248 .1724 L
.28255 .17224 L
.28264 .17203 L
.2828 .17156 L
.28309 .17039 L
.28337 .16893 L
.28367 .16698 L
.2842 .16248 L
.28488 .15487 L
.28552 .14577 L
.28671 .12378 L
.28894 .06613 L
.28954 .04683 L
.28988 .03563 L
.2902 .02468 L
.29034 .01962 L
.29049 .01526 L
.29057 .01812 L
.29066 .02131 L
.29081 .02698 L
.29137 .04823 L
.29378 .14857 L
.29632 .26274 L
.29886 .37429 L
.30118 .46494 L
.30233 .50316 L
.30358 .53874 L
.30475 .56554 L
.30586 .58449 L
.30645 .59206 L
.30677 .59527 L
.3071 .59808 L
.30738 .59999 L
.30753 .60082 L
.30769 .60158 L
.30783 .60216 L
.30797 .60259 L
.3081 .60292 L
.30823 .60314 L
Mistroke
.30837 .60329 L
.30845 .60332 L
.30853 .60331 L
.30869 .60321 L
.30877 .60309 L
.30886 .60294 L
.30899 .60262 L
.30914 .60215 L
.30944 .60085 L
.30977 .59885 L
.31012 .59608 L
.31075 .58945 L
.3114 .58066 L
.31199 .57076 L
.31333 .54242 L
.31576 .4727 L
.32051 .29438 L
.32507 .11972 L
.32628 .07977 L
.32742 .04541 L
.32805 .02813 L
.32822 .02361 L
.3284 .0189 L
.32849 .01665 L
.32858 .01488 L
.32873 .01873 L
.32994 .0455 L
.33112 .06698 L
.33236 .08445 L
.33343 .09523 L
.33403 .0997 L
.33459 .10283 L
.33491 .10416 L
.3352 .10513 L
.33552 .10592 L
.33568 .1062 L
.33576 .10632 L
.33585 .10643 L
.33601 .10656 L
.33615 .10663 L
.3363 .10663 L
.33639 .10661 L
.33647 .10657 L
.33662 .10646 L
.33675 .10631 L
.3369 .10609 L
.33705 .10582 L
.33732 .10518 L
.33761 .10433 L
.33812 .10233 L
Mistroke
.33868 .09958 L
.33929 .09589 L
.34164 .07655 L
.34416 .05053 L
.34538 .03742 L
.34603 .03062 L
.34671 .02357 L
.34731 .01766 L
.34748 .01607 L
.34757 .01519 L
.34765 .01504 L
.34781 .01651 L
.34797 .01803 L
.34914 .0282 L
.35029 .03694 L
.35152 .04471 L
.35268 .05045 L
.35373 .0543 L
.35431 .05586 L
.35463 .05654 L
.35493 .05708 L
.35521 .05748 L
.35546 .05777 L
.35574 .05801 L
.35589 .05811 L
.35604 .05817 L
.3562 .05822 L
.35634 .05824 L
.35642 .05824 L
.35651 .05823 L
.35666 .05819 L
.35681 .05814 L
.35696 .05806 L
.35724 .05785 L
.35756 .0575 L
.35786 .05709 L
.35855 .05581 L
.35915 .05433 L
.35981 .05235 L
.361 .04784 L
.36324 .03669 L
.36562 .02185 L
.3662 .01792 L
.36636 .01682 L
.36653 .01567 L
.36667 .01475 L
.36683 .01584 L
.36751 .02067 L
.36816 .02525 L
.37072 .04317 L
Mistroke
.37305 .05743 L
.37421 .06314 L
.37482 .06564 L
.37547 .06785 L
.37604 .06937 L
.37634 .07002 L
.37666 .07057 L
.37681 .07079 L
.37696 .07096 L
.3771 .0711 L
.37723 .0712 L
.37735 .07128 L
.37748 .07133 L
.37763 .07136 L
.37776 .07136 L
.3779 .07133 L
.37804 .07127 L
.37819 .07118 L
.37835 .07103 L
.37852 .07084 L
.37867 .07061 L
.37897 .07007 L
.37951 .06873 L
.38009 .0667 L
.38072 .0638 L
.38139 .05991 L
.3826 .0508 L
.38373 .03974 L
.38433 .03298 L
.38495 .02517 L
.38522 .02164 L
.3855 .01773 L
.38559 .01655 L
.38567 .01542 L
.38581 .01614 L
.38595 .01818 L
.3861 .02042 L
.38716 .03711 L
.3921 .13243 L
.39456 .18356 L
.39686 .22798 L
.39921 .26596 L
.40036 .2808 L
.40143 .29185 L
.40199 .29651 L
.40261 .30073 L
.40323 .30397 L
.40357 .30531 L
.40389 .30629 L
.40416 .3069 L
Mistroke
.4043 .30714 L
.40445 .30734 L
.40458 .30745 L
.40471 .30753 L
.40484 .30756 L
.40496 .30754 L
.40511 .30746 L
.40525 .30734 L
.4054 .30714 L
.40556 .30687 L
.40583 .30625 L
.40612 .30534 L
.40675 .30263 L
.40735 .29909 L
.40847 .28998 L
.40967 .27677 L
.41098 .25873 L
.41589 .16763 L
.42061 .0701 L
.42185 .04697 L
.42251 .03558 L
.4232 .02421 L
.42349 .01963 L
.42365 .01716 L
.4238 .01486 L
.42389 .01585 L
.42398 .01723 L
.42414 .01961 L
.42446 .02413 L
.42563 .03907 L
.42686 .0521 L
.42802 .06168 L
.42922 .06892 L
.42986 .07164 L
.43019 .07275 L
.43055 .07372 L
.43086 .07438 L
.43115 .07484 L
.43129 .075 L
.43144 .07515 L
.43158 .07525 L
.43171 .07531 L
.43186 .07535 L
.432 .07536 L
.43215 .07532 L
.43224 .07529 L
.43232 .07524 L
.43248 .07513 L
.43265 .07495 L
.43297 .07452 L
Mistroke
.4333 .07389 L
.43361 .07319 L
.43429 .07115 L
.43551 .06604 L
.43784 .05228 L
.44036 .03386 L
.4416 .02423 L
.44221 .01957 L
.44248 .01756 L
.44262 .0165 L
.44277 .01539 L
.44292 .01521 L
.44307 .01628 L
.44335 .01837 L
.44398 .02285 L
.44531 .03173 L
.44644 .03845 L
.44766 .04462 L
.44881 .04926 L
.44987 .05249 L
.45046 .05382 L
.45076 .05436 L
.45109 .05485 L
.45128 .05508 L
.45145 .05526 L
.45161 .0554 L
.45179 .05553 L
.45195 .05561 L
.45209 .05567 L
.45225 .0557 L
.45234 .05571 L
.45242 .05571 L
.45257 .0557 L
.45273 .05565 L
.45286 .0556 L
.45302 .05551 L
.45318 .0554 L
.45335 .05524 L
.45366 .05489 L
.45428 .0539 L
.45484 .05266 L
.45602 .04906 L
.45712 .04456 L
.45962 .03072 L
.46089 .02213 L
.46119 .01996 L
.46151 .01763 L
.46164 .01666 L
.46178 .01561 L
.46194 .01498 L
Mistroke
.46209 .01607 L
.46316 .02429 L
.46433 .03331 L
.46671 .05096 L
.46797 .05915 L
.4693 .06646 L
.46998 .06944 L
.47061 .07175 L
.47118 .07338 L
.47147 .07405 L
.47179 .07464 L
.47194 .07485 L
.47209 .07505 L
.47223 .07519 L
.47238 .07531 L
.47246 .07536 L
.47254 .0754 L
.4727 .07545 L
.47284 .07546 L
.47299 .07543 L
.47312 .07538 L
.47326 .07528 L
.4734 .07517 L
.47352 .07504 L
.4738 .07463 L
.4741 .07405 L
.4747 .07238 L
.47525 .07028 L
.47589 .06715 L
.47648 .0635 L
.47755 .0553 L
.4787 .04396 L
.47994 .02896 L
.48025 .02477 L
.48055 .02063 L
.48081 .01679 L
.48096 .01486 L
.4811 .01695 L
.48168 .02608 L
.48231 .03645 L
.48364 .06024 L
.48837 .15659 L
.49292 .24433 L
.49525 .27794 L
.49656 .29178 L
.49714 .2966 L
.49776 .30081 L
.49808 .30258 L
.49838 .304 L
.49867 .30516 L
Mistroke
.49894 .30603 L
.4992 .30668 L
.49933 .30694 L
.49947 .30716 L
.49961 .30734 L
.49974 .30746 L
.4999 .30753 L
.50004 .30754 L
.50019 .3075 L
.50028 .30744 L
.50036 .30737 L
.50051 .3072 L
.50065 .30697 L
.50097 .30627 L
.50132 .30519 L
.50163 .30397 L
.50195 .30241 L
.50254 .29892 L
.50368 .28957 L
.5049 .27607 L
.50712 .24375 L
.51211 .14659 L
.5146 .09462 L
.51691 .05009 L
.51807 .03009 L
.51835 .0256 L
.51864 .02101 L
.51888 .01718 L
.51902 .01506 L
.51915 .01631 L
.51929 .01833 L
.51942 .02014 L
.5197 .0241 L
.52029 .03193 L
.52154 .04649 L
.52266 .05708 L
.52385 .06563 L
.52447 .06902 L
.52516 .07189 L
.52546 .07288 L
.52578 .07376 L
.52608 .07442 L
.52636 .07488 L
.52652 .07508 L
.52666 .07523 L
.52679 .07533 L
.52694 .0754 L
.52709 .07545 L
.52717 .07546 L
.52726 .07546 L
Mistroke
.52741 .07542 L
.52755 .07535 L
.52769 .07525 L
.52783 .07513 L
.52808 .07482 L
.52836 .07438 L
.52865 .07378 L
.52929 .07208 L
.52996 .06971 L
.53116 .06414 L
.53351 .04943 L
.53572 .03297 L
.53697 .0233 L
.53758 .01857 L
.53774 .0174 L
.53788 .0163 L
.53801 .01532 L
.53816 .01517 L
.53829 .01614 L
.53843 .01717 L
.53867 .01898 L
.53922 .02292 L
.54039 .03078 L
.54153 .03768 L
.54276 .04401 L
.5439 .0488 L
.54497 .05217 L
.54556 .05358 L
.54619 .05469 L
.54652 .05511 L
.54683 .0554 L
.547 .05552 L
.54716 .05561 L
.54725 .05565 L
.54734 .05568 L
.54744 .0557 L
.54753 .05571 L
.54768 .05571 L
.54776 .0557 L
.54784 .05568 L
.54799 .05564 L
.54814 .05557 L
.54828 .05548 L
.54841 .05539 L
.5487 .0551 L
.54901 .0547 L
.5493 .05425 L
.54995 .05292 L
.55053 .0514 L
.55114 .04943 L
Mistroke
.55225 .04502 L
.55475 .03139 L
.55599 .02308 L
.55664 .01841 L
.55697 .016 L
.55706 .01533 L
.55716 .01482 L
.55725 .0155 L
.55733 .01612 L
.5586 .02579 L
.55976 .03477 L
.56226 .05299 L
.56336 .05996 L
.56457 .06646 L
.56513 .06895 L
.56573 .07122 L
.56625 .07282 L
.56682 .07414 L
.56713 .07467 L
.56742 .07503 L
.56758 .07518 L
.56773 .07527 L
.56781 .07531 L
.5679 .07534 L
.56798 .07535 L
.56806 .07536 L
.5682 .07534 L
.56832 .0753 L
.56846 .07522 L
.56861 .0751 L
.56877 .07494 L
.56892 .07474 L
.5692 .07427 L
.56951 .07357 L
.56981 .07275 L
.57036 .07079 L
.57095 .06804 L
.5716 .06432 L
.57275 .0556 L
.57382 .04531 L
.57492 .0324 L
.57552 .02436 L
.57582 .02017 L
.57595 .01828 L
.57609 .01616 L
.57625 .01562 L
.57634 .01692 L
.57642 .01815 L
.57677 .02365 L
.57738 .03372 L
Mistroke
.57859 .05497 L
.58326 .14983 L
.58564 .19887 L
.58824 .24642 L
.58944 .26489 L
.59072 .2814 L
.59193 .29354 L
.59245 .29767 L
.59302 .3014 L
.59361 .30432 L
.59393 .30553 L
.59423 .30641 L
.59438 .30674 L
.59451 .307 L
.59464 .3072 L
.59477 .30736 L
.59491 .30748 L
.59505 .30754 L
.59519 .30756 L
.59534 .30751 L
.5955 .30739 L
.59558 .3073 L
.59567 .30719 L
.59597 .30664 L
.59614 .30623 L
.59632 .3057 L
.59664 .30453 L
.59728 .30141 L
.59786 .29764 L
.59906 .2871 L
.60017 .27433 L
.60268 .23621 L
.60743 .1423 L
.612 .05163 L
.6132 .03123 L
.61379 .02197 L
.61394 .01973 L
.61408 .01766 L
.61421 .01583 L
.61434 .01555 L
.6145 .01779 L
.61465 .01982 L
.61497 .02419 L
.61566 .03281 L
.61686 .04584 L
.61804 .05596 L
.61914 .06304 L
.61977 .0661 L
.62034 .06826 L
.62066 .0692 L
Mistroke
.62101 .07002 L
.62133 .07062 L
.62148 .07083 L
.62163 .07101 L
.62177 .07115 L
.62192 .07125 L
.62206 .07132 L
.62219 .07136 L
.62235 .07137 L
.62248 .07134 L
.62256 .07132 L
.62264 .07128 L
.6228 .07118 L
.62293 .07107 L
.62307 .07092 L
.62336 .07053 L
.62389 .06954 L
.62451 .06791 L
.62517 .06565 L
.62637 .06041 L
.62893 .04547 L
.63011 .03751 L
.63136 .0287 L
.6325 .0206 L
.63281 .01839 L
.63297 .01723 L
.63315 .01602 L
.6333 .01496 L
.63338 .01507 L
.63346 .01562 L
.63376 .01764 L
.63598 .03209 L
.63823 .04439 L
.63942 .04956 L
.64068 .05386 L
.64132 .05551 L
.64166 .05623 L
.64202 .0569 L
.64235 .05739 L
.64266 .05774 L
.6428 .05788 L
.64296 .05801 L
.64311 .0581 L
.64325 .05816 L
.64341 .05821 L
.64349 .05823 L
.64357 .05824 L
.64372 .05823 L
.64387 .0582 L
.64401 .05816 L
Mistroke
.64414 .05809 L
.64428 .058 L
.64443 .05788 L
.64477 .05752 L
.64508 .05705 L
.64568 .05587 L
.64624 .0544 L
.64685 .05236 L
.64808 .04687 L
.64923 .04018 L
.65031 .03258 L
.65149 .02283 L
.65209 .01744 L
.65225 .01592 L
.65235 .01506 L
.65243 .01516 L
.65251 .0159 L
.65259 .01671 L
.65274 .01819 L
.65497 .04122 L
.65733 .06622 L
.65857 .07854 L
.65991 .09011 L
.66057 .09494 L
.6612 .09887 L
.6618 .10201 L
.6621 .10327 L
.66237 .10425 L
.66262 .10504 L
.6629 .10572 L
.66305 .10601 L
.66319 .10624 L
.66333 .10641 L
.66347 .10653 L
.66361 .10661 L
.66376 .10664 L
.66391 .10661 L
.66404 .10653 L
.66419 .10638 L
.66428 .10626 L
.66436 .10614 L
.66467 .10551 L
.66496 .10464 L
.66523 .10363 L
.66583 .10057 L
.66639 .09671 L
.66692 .0921 L
.66811 .07841 L
.66941 .05796 L
.67 .04682 L
Mistroke
.67063 .03344 L
.67092 .02685 L
.67108 .02312 L
.67123 .01957 L
.67136 .01648 L
.67149 .01632 L
.67164 .02013 L
.67178 .02367 L
.67311 .06079 L
.67431 .09884 L
.67911 .27925 L
.68374 .4557 L
.68612 .52846 L
.68732 .55719 L
.68797 .57002 L
.68865 .58141 L
.68923 .5893 L
.68954 .59279 L
.68987 .59597 L
.69017 .59841 L
.69045 .60021 L
.69072 .60161 L
.69086 .60214 L
.69098 .60255 L
.69113 .60291 L
.69121 .60306 L
.69129 .60318 L
.69138 .60327 L
.69146 .60331 L
.69161 .6033 L
.69176 .60317 L
.69189 .60294 L
.69203 .60259 L
.69219 .60208 L
.69236 .60138 L
.69254 .60044 L
.69288 .59827 L
.6935 .59259 L
.69409 .58522 L
.69465 .57666 L
.69591 .55136 L
.69713 .51935 L
.69845 .47784 L
.70344 .27331 L
.70594 .16078 L
.70704 .11304 L
.70825 .06307 L
.70881 .04129 L
.7091 .03021 L
.70926 .02429 L
Mistroke
.70941 .01885 L
.70954 .01533 L
.70968 .02034 L
.70998 .03071 L
.7105 .04817 L
.71288 .11479 L
.71412 .13978 L
.71477 .15013 L
.71546 .15895 L
.71606 .16487 L
.71638 .16734 L
.71672 .16947 L
.71704 .17096 L
.71732 .17194 L
.71746 .17228 L
.71761 .17255 L
.71776 .17272 L
.71789 .1728 L
.71803 .17281 L
.71818 .17272 L
.71831 .17257 L
.71845 .17233 L
.7186 .17198 L
.71876 .17151 L
.71905 .17039 L
.71934 .16892 L
.71962 .16724 L
.72014 .16331 L
.72133 .15081 L
.72262 .13244 L
.72496 .08975 L
.72621 .06417 L
.7269 .04973 L
.72755 .03598 L
.72816 .02319 L
.72833 .01973 L
.72842 .01783 L
.72851 .01606 L
.72859 .01503 L
.72867 .01682 L
.72883 .01992 L
.73 .04278 L
.73229 .08112 L
.73344 .09596 L
.7347 .10831 L
.73533 .11287 L
.73568 .11489 L
.73601 .11648 L
.73632 .11767 L
.73648 .11819 L
Mistroke
.73665 .11866 L
.7368 .11898 L
.73696 .11927 L
.7371 .11947 L
.73724 .1196 L
.73738 .11969 L
.73753 .11971 L
.73768 .11967 L
.73781 .11959 L
.73796 .11943 L
.73805 .11931 L
.73813 .11919 L
.73843 .11854 L
.73871 .1177 L
.73903 .11651 L
.73967 .1133 L
.74023 .10969 L
.74083 .105 L
.74191 .09459 L
.74446 .06215 L
.74563 .04488 L
.74689 .02587 L
.7472 .02112 L
.74736 .01864 L
.74745 .01728 L
.74753 .01602 L
.74768 .01569 L
.74776 .0169 L
.74785 .01819 L
.74814 .02254 L
.74928 .03895 L
.7515 .06685 L
.75273 .07899 L
.75338 .08423 L
.75407 .08884 L
.75467 .09205 L
.75498 .09343 L
.75533 .09466 L
.75564 .09556 L
.75593 .09619 L
.75607 .09643 L
.7562 .09662 L
.75634 .09677 L
.75649 .09688 L
.75665 .09695 L
.75673 .09696 L
.75681 .09696 L
.75696 .09691 L
.7571 .09683 L
.75719 .09675 L
Mistroke
.75727 .09667 L
.75742 .09647 L
.75777 .09584 L
.75806 .09508 L
.75834 .09422 L
.75897 .09167 L
.76005 .08541 L
.76121 .07645 L
.76356 .05256 L
.76461 .04015 L
.76576 .02598 L
.76606 .0223 L
.76637 .01836 L
.76653 .01645 L
.76667 .01477 L
.7668 .01638 L
.76694 .01813 L
.76819 .03311 L
.77042 .05686 L
.77166 .06742 L
.77282 .07517 L
.7734 .07821 L
.77402 .08079 L
.77438 .08194 L
.77472 .08281 L
.77502 .08341 L
.77519 .08367 L
.77535 .08386 L
.77551 .084 L
.77559 .08405 L
.77567 .0841 L
.77582 .08415 L
.77597 .08415 L
.77605 .08414 L
.77613 .08411 L
.77629 .08402 L
.77637 .08396 L
.77645 .08388 L
.77663 .08367 L
.77691 .08323 L
.77721 .08258 L
.77783 .08074 L
.77839 .07852 L
.77899 .07555 L
.78008 .06876 L
.7825 .04828 L
.78373 .03588 L
.7844 .02876 L
.78504 .02194 L
.78533 .01881 L
Mistroke
.78549 .01711 L
.78564 .01551 L
.78572 .01475 L
.7858 .01564 L
.78598 .01753 L
.78629 .02084 L
.78742 .03256 L
.78964 .05287 L
.79086 .06185 L
.79151 .06579 L
.7922 .06931 L
.79286 .07202 L
.79345 .07387 L
.79374 .07456 L
.79406 .07514 L
.7942 .07535 L
.79435 .07554 L
.79449 .07568 L
.79462 .07579 L
.79477 .07587 L
.79485 .0759 L
.79493 .07592 L
.79507 .07592 L
.79522 .07589 L
.79536 .07583 L
.7955 .07573 L
.79564 .07561 L
.79577 .07547 L
.79607 .07502 L
.7964 .07437 L
.797 .07275 L
.79755 .07074 L
.79814 .06811 L
.79921 .06215 L
.80179 .04247 L
.80297 .03175 L
.80362 .02565 L
.80422 .01988 L
.80451 .01713 L
.80465 .01578 L
.80478 .0149 L
.80493 .01633 L
.80509 .01788 L
.80538 .02059 L
.80664 .0323 L
.80887 .05041 L
.80996 .05749 L
.81112 .06352 L
.81179 .06615 L
.8124 .068 L
Mistroke
.81271 .06871 L
.81299 .06925 L
.81328 .06969 L
.81344 .06987 L
.81361 .07002 L
.81376 .07011 L
.81384 .07015 L
.81392 .07018 L
.81408 .07021 L
.81417 .07021 L
.81425 .0702 L
.8144 .07016 L
.81455 .07007 L
.8147 .06996 L
.81484 .06982 L
.81518 .06936 L
.81549 .06881 L
.81618 .06706 L
.81678 .06499 L
.81743 .06221 L
.81861 .05587 L
.82102 .03863 L
.82225 .02837 L
.82292 .0225 L
.82325 .01959 L
.82356 .01689 L
.82371 .01558 L
.82385 .01508 L
.824 .01635 L
.82416 .01776 L
.8248 .02337 L
.82593 .03284 L
.82815 .04905 L
.82934 .0559 L
.82998 .05896 L
.83059 .06134 L
.83114 .06313 L
.83165 .0644 L
.83192 .06493 L
.83222 .06539 L
.83238 .06559 L
.83253 .06575 L
.83267 .06587 L
.83282 .06596 L
.83297 .06603 L
.83311 .06606 L
.83325 .06606 L
.83338 .06604 L
.83352 .06599 L
.83368 .06591 L
Mistroke
.83384 .06578 L
.83399 .06563 L
.83426 .06528 L
.83452 .06486 L
.83509 .06362 L
.83566 .06191 L
.8363 .05956 L
.83758 .0534 L
.83994 .03795 L
.84125 .02779 L
.84183 .02314 L
.84216 .02046 L
.84246 .01795 L
.84261 .01673 L
.84275 .01558 L
.84283 .01495 L
.84291 .01518 L
.84306 .01639 L
.8437 .02155 L
.84503 .03205 L
.84631 .0412 L
.84746 .04844 L
.8486 .05434 L
.8492 .05688 L
.84984 .05911 L
.85016 .06006 L
.85052 .06095 L
.85084 .06163 L
.85114 .06213 L
.85145 .06252 L
.85161 .06269 L
.85177 .06281 L
.85192 .06289 L
.85206 .06294 L
.85221 .06297 L
.85237 .06296 L
.8525 .06294 L
.85265 .06288 L
.85281 .06278 L
.85296 .06267 L
.85322 .06239 L
.8535 .06199 L
.85414 .06072 L
.85472 .05913 L
.85585 .05488 L
.85692 .0496 L
.85913 .03562 L
.86039 .0264 L
.861 .02171 L
.86156 .01737 L
Mistroke
.8617 .01631 L
.86185 .01517 L
.86193 .01491 L
.86201 .0155 L
.86216 .01665 L
.86272 .02099 L
.86396 .03026 L
.86528 .03936 L
.8665 .04664 L
.86761 .05215 L
.86883 .05672 L
.86946 .05843 L
.87005 .05959 L
.87037 .06005 L
.87067 .06035 L
.87084 .06047 L
.87092 .06052 L
.87101 .06056 L
.87109 .06059 L
.87118 .06062 L
.87134 .06063 L
.87149 .06062 L
.87164 .06058 L
.8718 .0605 L
.87188 .06045 L
.87196 .06039 L
.87227 .0601 L
.87256 .05971 L
.8731 .05873 L
.87368 .05728 L
.87431 .05526 L
.87499 .05263 L
.87619 .04681 L
.87859 .03189 L
.87963 .02444 L
.88019 .02039 L
.88049 .01816 L
.88077 .01605 L
.88092 .01499 L
.88107 .01559 L
.88115 .01621 L
.88124 .01686 L
.8814 .01802 L
.88198 .02228 L
.88312 .03041 L
.88434 .03841 L
.88565 .04585 L
.88689 .05161 L
.88802 .05549 L
.88857 .05685 L
Mistroke
.88886 .05743 L
.88916 .05794 L
.88943 .05829 L
.88957 .05844 L
.88972 .05858 L
.88986 .05869 L
.88999 .05876 L
.89012 .05881 L
.89024 .05885 L
.89039 .05887 L
.89047 .05886 L
.89055 .05885 L
.8907 .05882 L
.89085 .05875 L
.89098 .05867 L
.89111 .05857 L
.8914 .05828 L
.89171 .05786 L
.89199 .05737 L
.89263 .05595 L
.89318 .05437 L
.89377 .05229 L
.89485 .04762 L
.89724 .03392 L
.89846 .02568 L
.8991 .02117 L
.89945 .01868 L
.89962 .01746 L
.89977 .01635 L
.89992 .01531 L
.90006 .01511 L
.9002 .01615 L
.90036 .01728 L
.901 .02183 L
.90212 .02957 L
.90433 .04297 L
.90547 .04853 L
.90673 .05323 L
.90736 .05498 L
.90771 .05576 L
.90804 .05637 L
.90835 .05682 L
.90851 .05702 L
.90868 .05719 L
.90883 .05731 L
.90899 .05742 L
.90913 .05749 L
.90927 .05753 L
.90941 .05756 L
.90956 .05755 L
Mistroke
.9097 .05753 L
.90983 .05748 L
.90998 .05741 L
.91015 .05729 L
.91045 .057 L
.91076 .05659 L
.9111 .05603 L
.9117 .05472 L
.91276 .05145 L
.91393 .04656 L
.91627 .03351 L
.91757 .02492 L
.91821 .02055 L
.91879 .01654 L
.91893 .01552 L
.91909 .01501 L
.91924 .01605 L
.91938 .01701 L
.92 .02136 L
.92133 .03027 L
.92259 .03796 L
.92376 .04424 L
.92495 .04948 L
.92603 .05309 L
.92665 .05461 L
.92723 .05566 L
.92755 .05608 L
.92785 .05636 L
.928 .05647 L
.92817 .05656 L
.92826 .05659 L
.92835 .05661 L
.92844 .05663 L
.92852 .05663 L
.92867 .05662 L
.92882 .05659 L
.92895 .05653 L
.92909 .05646 L
.92925 .05634 L
.92941 .0562 L
.9297 .05586 L
.93023 .05502 L
.9308 .05374 L
.93142 .05198 L
.93209 .04965 L
.9333 .04439 L
.93568 .03087 L
.93694 .02261 L
.93727 .02036 L
.93763 .01791 L
Mistroke
.93779 .01679 L
.93797 .0156 L
.93812 .01485 L
.9382 .01543 L
.93828 .01596 L
.93958 .02481 L
.94077 .03241 L
.94307 .04504 L
.94434 .0502 L
.94496 .05218 L
.94553 .05366 L
.94605 .0547 L
.94632 .05512 L
.94661 .05549 L
.94676 .05564 L
.94689 .05576 L
.94703 .05586 L
.94716 .05593 L
.9473 .05599 L
.94746 .05603 L
.94761 .05604 L
.94769 .05603 L
.94777 .05602 L
.94792 .05598 L
.94805 .05592 L
.9482 .05583 L
.94836 .05571 L
.94868 .05538 L
.94898 .05497 L
.94955 .05392 L
.95009 .0526 L
.95129 .04862 L
.9526 .04279 L
.95494 .02938 L
.95618 .02125 L
.95652 .01896 L
.95687 .01654 L
.95702 .01553 L
.95718 .01497 L
.95727 .01558 L
.95735 .01614 L
.95751 .01724 L
.95995 .0331 L
.96225 .04535 L
.96345 .05013 L
.96402 .05192 L
.96456 .05331 L
.96514 .05446 L
.96544 .05493 L
.96578 .05531 L
Mistroke
.96594 .05546 L
.96612 .05559 L
.9662 .05563 L
.96629 .05567 L
.96645 .05572 L
.96653 .05574 L
.96662 .05575 L
.96677 .05574 L
.96692 .05571 L
.96706 .05566 L
.96722 .05557 L
.96736 .05547 L
.96763 .05522 L
.96792 .05486 L
.96824 .05436 L
.96881 .0532 L
.96934 .05182 L
.97055 .04761 L
.97183 .04173 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309973 0.100045 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00984 -12 -4.5 ]
[-0.0125 .00984 0 4.5 ]
[-0.0125 .10988 -12 -4.5 ]
[-0.0125 .10988 0 4.5 ]
[-0.0125 .20993 -12 -4.5 ]
[-0.0125 .20993 0 4.5 ]
[-0.0125 .30997 -6 -4.5 ]
[-0.0125 .30997 0 4.5 ]
[-0.0125 .41002 -6 -4.5 ]
[-0.0125 .41002 0 4.5 ]
[-0.0125 .51006 -6 -4.5 ]
[-0.0125 .51006 0 4.5 ]
[-0.0125 .61011 -6 -4.5 ]
[-0.0125 .61011 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00984 m
.00625 .00984 L
s
[(-3)] -0.0125 .00984 1 0 Mshowa
0 .10988 m
.00625 .10988 L
s
[(-2)] -0.0125 .10988 1 0 Mshowa
0 .20993 m
.00625 .20993 L
s
[(-1)] -0.0125 .20993 1 0 Mshowa
0 .30997 m
.00625 .30997 L
s
[(0)] -0.0125 .30997 1 0 Mshowa
0 .41002 m
.00625 .41002 L
s
[(1)] -0.0125 .41002 1 0 Mshowa
0 .51006 m
.00625 .51006 L
s
[(2)] -0.0125 .51006 1 0 Mshowa
0 .61011 m
.00625 .61011 L
s
[(3)] -0.0125 .61011 1 0 Mshowa
.125 Mabswid
0 .02985 m
.00375 .02985 L
s
0 .04986 m
.00375 .04986 L
s
0 .06986 m
.00375 .06986 L
s
0 .08987 m
.00375 .08987 L
s
0 .12989 m
.00375 .12989 L
s
0 .1499 m
.00375 .1499 L
s
0 .16991 m
.00375 .16991 L
s
0 .18992 m
.00375 .18992 L
s
0 .22994 m
.00375 .22994 L
s
0 .24995 m
.00375 .24995 L
s
0 .26996 m
.00375 .26996 L
s
0 .28996 m
.00375 .28996 L
s
0 .32998 m
.00375 .32998 L
s
0 .34999 m
.00375 .34999 L
s
0 .37 m
.00375 .37 L
s
0 .39001 m
.00375 .39001 L
s
0 .43003 m
.00375 .43003 L
s
0 .45004 m
.00375 .45004 L
s
0 .47005 m
.00375 .47005 L
s
0 .49006 m
.00375 .49006 L
s
0 .53007 m
.00375 .53007 L
s
0 .55008 m
.00375 .55008 L
s
0 .57009 m
.00375 .57009 L
s
0 .5901 m
.00375 .5901 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00984 m
1 .00984 L
s
.99375 .10988 m
1 .10988 L
s
.99375 .20993 m
1 .20993 L
s
.99375 .30997 m
1 .30997 L
s
.99375 .41002 m
1 .41002 L
s
.99375 .51006 m
1 .51006 L
s
.99375 .61011 m
1 .61011 L
s
.125 Mabswid
.99625 .02985 m
1 .02985 L
s
.99625 .04986 m
1 .04986 L
s
.99625 .06986 m
1 .06986 L
s
.99625 .08987 m
1 .08987 L
s
.99625 .12989 m
1 .12989 L
s
.99625 .1499 m
1 .1499 L
s
.99625 .16991 m
1 .16991 L
s
.99625 .18992 m
1 .18992 L
s
.99625 .22994 m
1 .22994 L
s
.99625 .24995 m
1 .24995 L
s
.99625 .26996 m
1 .26996 L
s
.99625 .28996 m
1 .28996 L
s
.99625 .32998 m
1 .32998 L
s
.99625 .34999 m
1 .34999 L
s
.99625 .37 m
1 .37 L
s
.99625 .39001 m
1 .39001 L
s
.99625 .43003 m
1 .43003 L
s
.99625 .45004 m
1 .45004 L
s
.99625 .47005 m
1 .47005 L
s
.99625 .49006 m
1 .49006 L
s
.99625 .53007 m
1 .53007 L
s
.99625 .55008 m
1 .55008 L
s
.99625 .57009 m
1 .57009 L
s
.99625 .5901 m
1 .5901 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30997 m
1 .30997 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .46712 m
.02847 .39229 L
.03355 .31067 L
.03602 .27099 L
.03832 .23402 L
.04054 .1984 L
.04118 .18815 L
.04178 .17845 L
.04232 .16975 L
.04247 .16737 L
.04263 .16484 L
.04276 .16268 L
.04291 .47461 L
.04307 .47211 L
.04321 .46979 L
.04354 .46454 L
.04414 .45497 L
.04525 .43701 L
.04777 .39657 L
.05249 .32078 L
.0549 .28209 L
.05751 .24024 L
.05873 .22059 L
.06002 .19982 L
.06113 .1821 L
.06143 .17724 L
.0616 .17457 L
.06175 .17204 L
.0619 .16968 L
.06206 .48142 L
.0622 .4791 L
.06234 .47694 L
.06707 .40089 L
.07163 .32779 L
.07416 .28717 L
.07647 .24993 L
.07875 .21344 L
.07989 .19509 L
.0802 .19006 L
.08054 .18469 L
.0807 .18208 L
.08085 .17962 L
.08099 .49171 L
.08114 .48932 L
.08608 .41009 L
.09083 .33379 L
.0954 .26044 L
.09774 .22279 L
.09842 .21195 L
.09906 .20166 L
Mistroke
.09963 .19242 L
.09979 .18989 L
.09988 .1885 L
.09996 .18719 L
.10012 .49895 L
.10026 .49665 L
.10492 .42193 L
.10987 .34246 L
.11234 .30286 L
.11464 .26594 L
.11685 .2304 L
.11749 .22017 L
.11809 .21049 L
.11864 .20179 L
.11878 .19941 L
.11894 .19689 L
.11908 .50903 L
.11922 .50666 L
.12408 .42876 L
.12875 .35381 L
.13112 .31573 L
.13372 .27413 L
.13492 .25488 L
.1362 .23435 L
.13682 .22437 L
.13741 .21497 L
.13766 .21087 L
.13793 .20653 L
.13808 .20426 L
.13823 .51607 L
.13837 .51381 L
.1385 .51169 L
.14319 .43651 L
.14818 .3566 L
.15067 .31663 L
.15298 .27963 L
.15522 .24375 L
.15635 .22563 L
.15666 .22066 L
.15682 .21805 L
.15699 .2153 L
.15714 .21289 L
.15723 .52582 L
.15731 .52455 L
.1576 .51991 L
.1623 .44451 L
.1673 .3644 L
.16981 .32426 L
.17212 .28723 L
.17437 .25119 L
Mistroke
.17551 .23302 L
.17582 .22804 L
.17599 .22529 L
.17607 .22394 L
.17615 .22269 L
.1763 .53457 L
.17638 .53329 L
.17647 .53193 L
.17676 .52731 L
.18177 .447 L
.18661 .36963 L
.19126 .29521 L
.19367 .25672 L
.19425 .24736 L
.19488 .23734 L
.19506 .23438 L
.19515 .23293 L
.19524 .23158 L
.19539 .54337 L
.19548 .54205 L
.19557 .54064 L
.19621 .53038 L
.20076 .45756 L
.20561 .38003 L
.21028 .30546 L
.2127 .26683 L
.21329 .25745 L
.21392 .24742 L
.2141 .24446 L
.21419 .243 L
.21428 .24166 L
.21443 .55345 L
.21452 .55212 L
.21461 .55073 L
.21525 .5405 L
.21982 .46754 L
.22469 .3899 L
.22937 .31522 L
.23059 .29573 L
.23193 .2745 L
.23254 .26479 L
.23287 .25946 L
.23303 .25685 L
.23318 .25445 L
.23333 .25217 L
.23348 .56407 L
.23363 .56165 L
.2338 .559 L
.23435 .55018 L
.23923 .47243 L
Mistroke
.24394 .39766 L
.24633 .35957 L
.24893 .31824 L
.25015 .29895 L
.25081 .28839 L
.25144 .2785 L
.25197 .27009 L
.25212 .26767 L
.25226 .26537 L
.25239 .5776 L
.25254 .57535 L
.25375 .55612 L
.25865 .47841 L
.26336 .40369 L
.26577 .36559 L
.26838 .3244 L
.2696 .30507 L
.27027 .29452 L
.27089 .28466 L
.27117 .28034 L
.2713 .27822 L
.27143 .27625 L
.27157 .5883 L
.27172 .58584 L
.272 .58154 L
.27321 .56242 L
.27794 .48781 L
.28249 .41623 L
.28502 .37653 L
.28734 .34017 L
.28852 .32174 L
.28961 .3046 L
.29017 .29596 L
.29032 .29347 L
.29047 .29113 L
.29061 .60332 L
.29076 .60103 L
.29201 .5815 L
.29694 .50457 L
.30169 .4308 L
.30626 .36021 L
.31112 .28549 L
.3158 .21411 L
.32078 .13895 L
.32327 .10173 L
.32557 .06746 L
.32672 .05046 L
.32781 .03453 L
.3281 .03025 L
.32841 .02573 L
Mistroke
.32848 .02459 L
.32857 .02337 L
.32866 .33634 L
.32874 .33509 L
.32905 .33055 L
.33018 .31408 L
.33518 .24239 L
.33999 .1754 L
.34461 .11353 L
.34585 .09756 L
.347 .08281 L
.34729 .07923 L
.34744 .07729 L
.34758 .07549 L
.34774 .38783 L
.34782 .3868 L
.34791 .3857 L
.34821 .38197 L
.34954 .36556 L
.35455 .30661 L
.35937 .25379 L
.36402 .20495 L
.36526 .19189 L
.36587 .18547 L
.36613 .18266 L
.36642 .17959 L
.36657 .17793 L
.36672 .49069 L
.36686 .48922 L
.367 .48765 L
.36763 .48092 L
.36896 .46646 L
.37351 .41498 L
.37835 .35639 L
.38301 .29673 L
.38426 .28028 L
.38487 .2722 L
.38513 .26866 L
.38542 .26481 L
.38558 .26272 L
.38572 .57508 L
.38586 .57323 L
.38601 .57127 L
.38664 .56284 L
.38797 .54487 L
.39253 .48221 L
.39739 .41427 L
.40207 .34821 L
.40704 .27767 L
.41183 .20979 L
Mistroke
.41644 .14489 L
.41901 .10894 L
.42134 .07659 L
.42251 .06047 L
.42312 .05203 L
.42346 .04742 L
.42362 .04518 L
.42377 .04313 L
.42391 .3555 L
.42404 .35368 L
.42434 .34965 L
.42496 .34114 L
.42606 .32623 L
.43068 .26427 L
.4356 .20021 L
.43804 .16918 L
.44034 .14054 L
.44141 .12737 L
.44199 .12022 L
.44253 .1136 L
.44268 .11182 L
.44281 .11013 L
.44297 .4225 L
.44312 .42074 L
.44376 .41293 L
.44489 .3993 L
.44953 .34408 L
.45447 .28592 L
.45692 .25682 L
.45922 .22934 L
.46035 .2157 L
.46091 .20894 L
.46142 .20266 L
.46171 .19916 L
.46179 .19815 L
.46187 .1972 L
.46202 .50973 L
.46209 .50876 L
.46218 .50775 L
.46233 .50593 L
.46266 .50181 L
.46379 .48787 L
.46838 .43011 L
.47326 .36662 L
.47796 .30376 L
.47919 .28706 L
.47984 .27822 L
.48019 .27337 L
.48053 .26881 L
.48068 .26678 L
Mistroke
.48082 .26485 L
.48089 .26379 L
.48098 .57693 L
.48113 .57489 L
.48179 .5658 L
.48296 .54973 L
.48785 .48157 L
.49257 .41523 L
.49758 .34428 L
.50241 .27576 L
.50706 .20996 L
.512 .14041 L
.51446 .10605 L
.51676 .07416 L
.51789 .05853 L
.51845 .05085 L
.5187 .04748 L
.51883 .04569 L
.51897 .04376 L
.51912 .35603 L
.51925 .35412 L
.51956 .34994 L
.52021 .34112 L
.52134 .32574 L
.52629 .25922 L
.53107 .19692 L
.53566 .13885 L
.53688 .12381 L
.53748 .11646 L
.53774 .11324 L
.53788 .11154 L
.53803 .1097 L
.53819 .42206 L
.53833 .42024 L
.53866 .41626 L
.53935 .40788 L
.54055 .39334 L
.54553 .33409 L
.55032 .27763 L
.55274 .24899 L
.55493 .22281 L
.55552 .21573 L
.55615 .20806 L
.55644 .20452 L
.55675 .20078 L
.55688 .19924 L
.55702 .19758 L
.55716 .51007 L
.5573 .50837 L
.55983 .47727 L
Mistroke
.56483 .41426 L
.56963 .35148 L
.57183 .32215 L
.57309 .3053 L
.57426 .28939 L
.57541 .27374 L
.57572 .26944 L
.5759 .26709 L
.57598 .26595 L
.57606 .26491 L
.57619 .57734 L
.57634 .57534 L
.57665 .5711 L
.57918 .53616 L
.58401 .46884 L
.58865 .40339 L
.59359 .33339 L
.59834 .26593 L
.60292 .20138 L
.60778 .13339 L
.61003 .10247 L
.61247 .06917 L
.61311 .06048 L
.61347 .05574 L
.6138 .05128 L
.61411 .04712 L
.61419 .04598 L
.61428 .04478 L
.61436 .35806 L
.61444 .35694 L
.61503 .34915 L
.61745 .3172 L
.62234 .25504 L
.62704 .19862 L
.62944 .1713 L
.6307 .15727 L
.63204 .14265 L
.63261 .13645 L
.63293 .13305 L
.63308 .13138 L
.63323 .12983 L
.63331 .12895 L
.6334 .44232 L
.63349 .44129 L
.63358 .44035 L
.63391 .43691 L
.63454 .43018 L
.63685 .40587 L
.64168 .35485 L
.64633 .30332 L
Mistroke
.64869 .27578 L
.64994 .26077 L
.65063 .25239 L
.65128 .24437 L
.65189 .23671 L
.65206 .2346 L
.65216 .23344 L
.65224 .23235 L
.6524 .54472 L
.65248 .5437 L
.65256 .5426 L
.65374 .52769 L
.65604 .49786 L
.661 .431 L
.66578 .36401 L
.66819 .32949 L
.66924 .31431 L
.67037 .29776 L
.67068 .29328 L
.67101 .28852 L
.67114 .28657 L
.67128 .28446 L
.67144 .59645 L
.67159 .59429 L
.67274 .57743 L
.67526 .54008 L
.68024 .46565 L
.68504 .39309 L
.68965 .32267 L
.69456 .24719 L
.69928 .17409 L
.7043 .09605 L
.70682 .05674 L
.70793 .03948 L
.70851 .03034 L
.70884 .02531 L
.70914 .02055 L
.70928 .01832 L
.70943 .01595 L
.70951 .01472 L
.7096 .32766 L
.70975 .32526 L
.71031 .31652 L
.7114 .29941 L
.71379 .26196 L
.71865 .18575 L
.72332 .11223 L
.72569 .07482 L
.72695 .05503 L
.72764 .04416 L
Mistroke
.72798 .03882 L
.72812 .03648 L
.72829 .0339 L
.72844 .03143 L
.72859 .34341 L
.72875 .34097 L
.72891 .33835 L
.72959 .32768 L
.73077 .30904 L
.73307 .27262 L
.73806 .19376 L
.74286 .11769 L
.74505 .0829 L
.7463 .06307 L
.74691 .05335 L
.74718 .04909 L
.74732 .04684 L
.74748 .04443 L
.74763 .35633 L
.74776 .35415 L
.74803 .34988 L
.74862 .34055 L
.74986 .32093 L
.75239 .2807 L
.75721 .20412 L
.76184 .13039 L
.76424 .09228 L
.76544 .07306 L
.76577 .06779 L
.76613 .06213 L
.7663 .05939 L
.76647 .05678 L
.76661 .05444 L
.7667 .36742 L
.76677 .36619 L
.77149 .29097 L
.77651 .21099 L
.77903 .17082 L
.78134 .13387 L
.78361 .09777 L
.78475 .07959 L
.78506 .07461 L
.78539 .06927 L
.78555 .06668 L
.78571 .06423 L
.78585 .37633 L
.786 .37394 L
.79092 .29536 L
.79565 .21968 L
.80021 .14688 L
Mistroke
.80254 .10956 L
.80318 .09933 L
.80385 .08857 L
.80443 .07938 L
.80459 .07686 L
.80467 .07548 L
.80476 .07417 L
.80491 .38594 L
.80506 .38363 L
.8097 .3094 L
.81464 .23041 L
.81709 .1911 L
.81939 .15433 L
.82159 .11905 L
.82223 .10888 L
.82283 .09924 L
.82337 .09058 L
.82352 .08821 L
.82368 .08569 L
.82383 .39761 L
.82396 .39545 L
.8288 .31795 L
.83346 .24335 L
.83582 .20549 L
.83841 .16399 L
.8396 .14488 L
.84088 .12443 L
.8415 .11451 L
.84209 .10512 L
.84234 .10104 L
.84261 .0967 L
.84275 .09444 L
.84291 .40625 L
.84305 .40398 L
.84318 .40185 L
.84786 .32694 L
.85283 .24728 L
.85531 .20749 L
.85761 .17053 L
.85984 .1348 L
.86048 .12452 L
.86109 .11482 L
.86135 .11059 L
.86163 .10612 L
.86178 .10378 L
.86186 .10245 L
.86194 .41552 L
.86207 .41334 L
.86222 .411 L
.8672 .33103 L
Mistroke
.87201 .25398 L
.87663 .17986 L
.87901 .14162 L
.88021 .12231 L
.88054 .11702 L
.88072 .11424 L
.88081 .11272 L
.8809 .11131 L
.88098 .42437 L
.88106 .42304 L
.88124 .42022 L
.88154 .41528 L
.88655 .33501 L
.89137 .25766 L
.896 .18324 L
.8984 .14479 L
.89898 .13544 L
.89961 .1254 L
.89979 .12244 L
.89988 .12099 L
.89997 .11964 L
.90012 .43142 L
.90021 .43009 L
.90029 .42868 L
.90094 .41836 L
.90596 .33779 L
.91079 .26015 L
.91545 .18544 L
.91669 .16544 L
.91785 .14678 L
.91844 .13738 L
.91861 .13468 L
.91877 .13212 L
.91891 .12982 L
.91907 .44162 L
.91922 .43906 L
.9194 .43624 L
.91976 .43053 L
.92039 .42028 L
.92525 .34236 L
.92992 .26737 L
.93229 .22927 L
.93488 .18763 L
.93608 .16837 L
.93674 .1578 L
.93736 .14782 L
.93764 .14329 L
.9378 .14082 L
.93794 .13851 L
.9381 .45031 L
Mistroke
.93818 .44898 L
.93827 .44756 L
.93857 .44273 L
.93967 .42512 L
.94465 .3451 L
.94945 .26802 L
.95407 .19388 L
.95529 .17417 L
.95645 .15565 L
.95673 .15112 L
.95688 .14866 L
.95702 .14636 L
.95718 .45816 L
.95726 .45684 L
.95735 .45543 L
.95765 .45063 L
.95898 .42928 L
.96398 .349 L
.96879 .27165 L
.97343 .19723 L
.97619 .15282 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000U2000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00??ooool3
o`0002;ooooo1Ol0000Qooooo`;o00009?ooool5o`0002Cooooo0ol0001Jooooo`?o00008_ooool5
o`00027ooooo0_l0000Sooooo`Go00009?ooool3o`0002Wooooo000mooooo`03o`000?oooooooooo
02;ooooo00Co0000oooooooooooo00008?ooool01?l0003oooooooooool0000Tooooo`04o`000?oo
ooooooooo`0002Gooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Rooooo`04o`00
0?ooooooooooo`00023ooooo00Co0000oooooooooooo00008oooool01?l0003oooooooooool0000U
ooooo`03o`000?oooooooooo02Sooooo000dooooo`Go000000?oooooo`000?l000000ol0000Loooo
o`Go00000oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0002Gooooo00?o0000
ooooooooool08_ooool5o`0005;ooooo1Ol000000ooooooo0000o`000003o`0001cooooo1Ol00003
ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00009?ooool00ol0003ooooooooo
o`0Rooooo`Go0000:Oooool003[ooooo00Co0000oooooooooooo00009_ooool00ol0003ooooooooo
o`0Oooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool08Oooool01?l0003ooooo
ooooool0001Iooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool07oooool01?l0
003oooooooooool0000Uooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000:_oo
ool003_ooooo00?o0000ooooool000008oooool01Ol0003ooooooooooooooooo0000023ooooo00Co
0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooool0
0000F_ooool00ol0003oooooo`00000Sooooo`05o`000?ooooooooooooooool000008?ooool01?l0
003oooooooooool0000Rooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooo`00
000Zooooo`00??ooool2o`0002?ooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?oo
ooooooooo`0002?ooooo00Go0000ooooooooooooooooo`00000Tooooo`;o0000Foooool2o`0002?o
oooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0002;ooooo00Go0000
ooooooooooooooooo`00000Tooooo`;o0000:_ooool003gooooo00?o0000ooooooooool08_ooool3
o`0002;ooooo0_l0000Uooooo`?o00009_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo
oooo02;ooooo0ol0000Rooooo`;o00009?ooool3o`0002Kooooo00?o0000ooooooooool0:?ooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool0027oooood?l0000Qooooo`?o00001?oo
ooo=o`0001;ooooo000Kooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04?ooool001[ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Hooooo`Go00001Oooool01?l0003oooooooooooooool3o`0001Gooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Dooooo`;o00004_ooool001[ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0booooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0
7?ooool00ol0003oooooooooo`0Iooooo`05ool00?oooooooooooooooooo00009_ooool00ooo003o
ooooooooo`0Nooooo`03o`000?oooooooooo023ooooo0_l00004ooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool0:?ooool00ooo003oooooooooo`0hooooo`03o`000?oooooooooo013o
oooo000Jooooo`04o`000?ooooooooooo`0000?ooooo0_l00003ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool01Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0007ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo00Goo`00oooooooooooooooo
o`000003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00Oooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001ooo
ool00ooo003oooooooooo`02ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool00ol0000Tooooo`05o`000?ooooooooooooooool0
0000IOooool00ol0003oooooooooo`0Xooooo`03ool00?oooooooooo03Sooooo00?o0000oooooooo
ool04?ooool001[ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00007ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000Oooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool01Ooo003ooooooooo
oooooooo000000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00001oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0007ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;oo`000_ooool2
ool000?ooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0Nooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`10ooooo`03ool00?oooooooooo023ooooo00?o
0000ooooooooool0:?ooool00ooo003oooooooooo`0hooooo`03o`000?oooooooooo013ooooo000J
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ooo003ooooooooo
o`02ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000Oooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003ooooooooo
o`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ol0003oooooooooooooooooo`0000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool00_oo0003ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003oooooooooo`02ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`02ool000;ooooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`02ooooo`03o`00
0?oooooooooo01oooooo0ol00004ooooo`;o0000@Oooool00ooo003oooooooooo`0Pooooo`03o`00
0?oooooooooo02Oooooo0_oo000iooooo`;o00004_ooool001_ooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo00;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00001oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`001_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Co0000oooooooooooooooo0_oo0002
ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000Oooooo00?oo`00ooooooooool00_oo
0002ooooo`;oo`000oooool00ooo003oooooooooo`04ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?o
o`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0@?oo
ool00ooo003oooooooooo`0Pooooo`03o`000?oooooooooo02Oooooo0_oo0002ooooo`;oo`00=_oo
ool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`03ooooo`0:ool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003ooooooooo
o`02ool000;ooooo00Coo`00oooooooo003ooooo0_oo0006ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool01?l0003oooooooooooooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000?o
oooo00?oo`00ooooooooool01?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool00005oooooooo003oooooool00?ooool00_oo0002oooo
o`04ool00?ooooooo`00ooooo`;oo`000_ooool01?oo003oooooool00?ooool2ool000;ooooo0_oo
0002ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`10ooooo`03ool00?oooooooooo023ooooo00?o0000ooooooooool09oooool2ool000;ooooo0_oo
000fooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo00?ooooo01Koo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool00_oo0002ooooo`04ool00?ooooooo`00ooooo`;oo`00
1_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Co0000oooooooooooo
oooo0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`000_ooool00ooo003oooooooooo`05oooo
o`07ool00?ooooooooooool00?ooooooo`00ooooo`02ool000;ooooo0_oo0006ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0001ko
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0005
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0@?ooool00ooo003oooooooooo`0@
ooooo`;oo`003_ooool01Ol0003oooooooooooooooooo`0001;ooooo00?oo`00ooooooooool04?oo
ool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo037ooooo00?o0000ooooooooool04?oo
ool0027ooooo0_l00004ooooo`0Jool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003oooooooooo`05ooooo`0;ool00?ooooooooooool0
0?ooooooo`00oooooooo003oooooool00?ooool00_oo0006ooooo`;oo`000_ooool01?oo003ooooo
ool00?ooool2ool000;ooooo0_oo0002ooooo`04o`000?ooooooooooooooo`;oo`0000Soooooool0
0?ooooooo`00oooooooo003oooooool000;ooooo0_oo0005ooooo`;oo`000_ooool01?oo003ooooo
ool00?ooool2ool000;ooooo0_oo0006ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0001_oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooool00_oo0005ooooo`;o0000:?ooool2o`00047ooooo00?oo`00
ooooooooool04?ooool2ool000kooooo00Go0000ooooooooooooooooool0000Booooo`03ool00?oo
oooooooo013ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0`ooooo`;o00004_oo
ool0027ooooo00?o0000ooooooooool00oooool3ool0000Aoooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0002ooooo`06ool0
0?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool00004oooooooo003ooooo
ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00001oooool01Ooo003ooooooooo
oooo003ooooo00;oo`000_ooool01?oo003oooooool00?oo0006ooooo`;oo`000_ooool01_oo003o
ooooool00?oo003oooooool000;ooooo0_oo0002ooooo`04o`000?ooooooooooooooo`;oo`0000?o
ooooool00?ooool00ooo00001?ooooooo`00ooooooooool2ool000Gooooo0_oo0002ooooo`04ool0
0?ooooooo`00ooooo`;oo`000_ooool2ool000Kooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool0000Goooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool00_oo0002ooooo`;oo`000_ooool2ool000Kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`10ooooo`03ool00?oooooooooo013ooooo0_oo000>ooooo`05o`000?oooooooooooooo
oooo00004_ooool00ooo003oooooooooo`0@ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooo
ooooooooooooool0000_ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo
00Cooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`04ool00?ooooooo`00ool000;ooooo0_oo
00002?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool01Ooo003ooooooooooooooooo
o`0000Oooooo00Goo`00ooooooooooooo`00ooooo`02ool000;ooooo00Coo`00oooooooo003oo`00
1_ooool2ool000;ooooo00Koo`00oooooooo003oo`00oooooooo0002ooooo`;oo`000_ooool01?l0
003oooooooooooooool2ool00004oooooooo003oooooooooo`;oo`0000Koooooool00?ooooooo`00
oooooooo0005ooooo`04ool00?ooooooo`00ool000;ooooo0ooo00000oooooooo`00ooooo`02ool0
00Kooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000ooooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00ooo0000
0oooooooo`00ool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`001_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo043ooooo00?oo`00ooooooooool04?ooool2
ool000kooooo00Go0000ooooooooooooooooool0000Booooo`03ool00?oooooooooo013ooooo0_oo
0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0002oooooo00?o0000ooooooooool0
4?ooool0027ooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`02ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo00Coo`00oooooooo003ooooo0_oo00001_ooooooo`00
oooooooo003oooooool000;ooooo00Goo`00ooooooooooooooooool00007ooooo`;oo`0000?ooooo
ool00?ooool01?ooool01?oo003oooooool00?oo0006ooooo`04ool00?ooooooo`00ool000Kooooo
00Coo`00oooooooo003oo`000_ooool01?l0003oooooooooooooool2ool00003oooooooo003ooooo
00Cooooo00Goo`00oooooooo003oooooool00005ooooo`04ool00?ooooooo`00ool000Kooooo00Co
o`00oooooooo003oo`001_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0000;oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00ooo0002ooooo`;oo`000_oo
ool01Ooo003oooooooooooooooooo`0001Kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`10ooooo`03ool00?oooooooooo013ooooo0_oo000>ooooo`05o`000?oooooooooooooooooo
00004_ooool00ooo003oooooooooo`0@ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo02Wooooo00?o0000ooooooooool04?ooool0027o
oooo00?o0000ooooooooool07oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00006
oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo00?oo`00ooooooooool01Oooool2
ool00003oooooooo003ooooo00Cooooo1?oo0006ooooo`04ool00?ooooooo`00ool000Kooooo1?oo
0002ooooo`04o`000?ooooooooooooooo`;oo`0000?oooooool00?ooool01Oooool2ool00003oooo
oooo003ooooo00Cooooo00Coo`00oooooooo003oo`001_ooool01?oo003oooooool00?oo0006oooo
o`;oo`000_ooool2ool000;ooooo0_oo00002_ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0Pooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0@?ooool00ooo003oooooooooo`0@ooooo`;oo`003_ooool00ol0003o
ooooooooo`02ool001;ooooo00?oo`00ooooooooool04?ooool2ool000;ooooo0_oo0002ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Yooooo`03o`000?oooooooooo
013ooooo000Qooooo`03o`000?oooooooooo02?ooooo0_oo0002ooooo`;oo`000_ooool2ool00006
oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo00?oo`00ooooooooool01Oooool2
ool00003oooooooo003ooooo00Gooooo00?oo`00oooooooo00001_ooool01?oo003oooooool00?oo
0006ooooo`;oo`0000Goooooool00?ooooooooooo`000003ooooo`Coo`001_ooool2ool00003oooo
oooo003ooooo00Cooooo00Coo`00oooooooo003oo`001_ooool01?oo003oooooool00?oo0006oooo
o`;oo`000_ooool2ool000;ooooo0_oo00001_ooooooo`00oooooooo003oooooool000;ooooo0_oo
0002ooooo`;oo`009Oooool00ol0003oooooooooo`0Vooooo`;o0000@Oooool00ooo003ooooooooo
o`0@ooooo`;oo`003_ooool00ol0003oooooooooo`02ool001;ooooo00?oo`00ooooooooool04?oo
ool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0002Kooooo0_l0000Booooo`008Oooool2o`0002Sooooo0_oo0002ooooo`;oo`00
00Koooooool00?ooooooo`00oooooooo0002ooooo`;oo`000_ooool00ooo003oooooooooo`05oooo
o`;oo`0000?oooooool00?ooool01oooool00ooo003oooooooooo`04ooooo`04ool00?ooooooo`00
ool000Kooooo0_oo00001Oooooooo`00oooooooooooo000000;ooooo00Coo`00ooooooooooooo`00
1oooool2ool00003oooooooo003ooooo00Cooooo00?oo`00ooooooooool01oooool01?oo003ooooo
ool00?oo0006ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?ooooooo`00ooooooooool2ool0
00;ooooo0_oo000Xooooo`;o0000:?ooool00ol0003oooooooooo`10ooooo`05ool00?oooooooooo
oooooooo00003_ooool2ool000kooooo00?o0000ooooooooool00_oo000Booooo`03ool00?oooooo
oooo013ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool0000Wooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oo
oooooooo02_ooooo0_oo00002_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0002
ooooo`03ool00?oooooooooo00Gooooo0_oo00000oooooooo`00ooooo`07ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool02_ooool01?oo003oooooooooool00002ooooo`03ool00?oo
oooooooo00_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`07ooooo`04ool00?oo
ooooo`00ool000Kooooo0_oo0002ooooo`;oo`0000Koooooool00?ooooooo`00oooooooo0002oooo
o`;oo`00;Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo043ooooo00Goo`00oooo
ooooooooooooool0000>ooooo`;oo`003_ooool00ol0003oooooooooo`02ool001;ooooo00?oo`00
ooooooooool04?ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0002Oooooo00?o0000ooooooooool04?ooool0027ooooo00?o
0000ooooooooool0:oooool2ool000;ooooo0_oo00001_ooooooo`00oooooooo003oooooool000;o
oooo00?oo`00ooooooooool01Oooool2ool00003oooooooo003ooooo00Oooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`0:ooooo`04ool00?ooooooooooo`0000;ooooo00?oo`00oooo
ooooool02oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Oooooo00Coo`00oooo
oooo003oo`001_ooool2ool000;ooooo0_oo00001?ooooooo`00ooooooooool2ool000;ooooo0_oo
000]ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0?oooool2ool000?ooooo00?o
o`00ooooooooool03?ooool2ool000kooooo00?o0000ooooooooool00_oo000Aooooo`;oo`004_oo
ool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool08Oooool00ol0003oooooooooo`0@ooooo`00
8Oooool00ol0003oooooooooo`0_ooooo`;oo`0000Koooooool00?ooooooo`00oooooooo0002oooo
o`03ool00?oooooooooo00Gooooo0ooo000:ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool02_ooool01?oo003oooooooooool00002ooooo`03ool00?oooooooooo00_ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`07ooooo`04ool00?ooooooo`00ool000Kooooo0_oo
0002ooooo`04ool00?ooooooo`00ool000;ooooo0_oo000aooooo`03o`000?oooooooooo02Kooooo
0_l00010ooooo`;oo`000oooool00ooo003oooooooooo`0<ooooo`;oo`003_ooool00ol0003ooooo
ooooo`02ool0017ooooo0_oo000Booooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Poooo
o`;o00004_ooool0027ooooo00?o0000ooooooooool0;oooool2ool00006oooooooo003oooooool0
0?ooooooo`000_ooool00ooo003oooooooooo`05ooooo`?oo`002_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00[ooooo00Coo`00oooooooooooo00000_ooool00ooo003ooooooooo
o`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01oooool01?oo003oooooool0
0?oo0006ooooo`;oo`000_ooool01?oo003oooooool00?oo0002ooooo`;oo`00<Oooool00ol0003o
ooooooooo`0Nooooo`Go00000oooool00ol0003oooooooooo`0oooooo`;oo`000oooool00ooo003o
ooooooooo`0<ooooo`;oo`003_ooool00ol0003oooooooooo`02ool0017ooooo0_oo000Booooo`;o
o`0000Coooooool00?ooooooo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00007oooool00ol0003ooooo
ooooo`0@ooooo`008Oooool00ol0003oooooooooo`0booooo`09ool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`0000Kooooo0ooo000:ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool02_ooool01?oo003oooooooooool00002ooooo`03ool00?oooooooooo00_ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`08ooooo`?oo`001_ooool2ool000;ooooo00Coo`00
oooooooo003oo`00=Oooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool0?oooool2ool000?ooooo00?oo`00ooooooooool03?ooool2ool000kooooo
00?o0000ooooooooool00_oo000Aooooo`;oo`004_ooool2ool00005oooooooo003oooooool00?oo
ool00_oo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool0000Kooooo`03o`000?oooooooooo013ooooo000Q
ooooo`;o0000=?ooool2ool00006oooooooo003oooooool00?ooooooo`001Oooool01?oo003ooooo
ool00?oo000:ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool01?oo003o
ooooooooool00002ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`08ooooo`03ool00?ooooooo`0000Kooooo0_oo0002ooooo`04ool00?ooooooo`00
ool003Cooooo0_l0000Jooooo`Go00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03oooooo0_oo0002ooooo`;oo`003_ooool2ool000kooooo00?o0000ooooooooool00_oo000A
ooooo`;oo`004_ooool2ool00005oooooooo003oooooool00?ooool00_oo0003ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool0000Kooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo03?o
oooo0_oo00001_ooooooo`00oooooooo003oooooool000Gooooo00?oo`00ooooooooool02oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00[ooooo00Coo`00oooooooooooo00000_oo
ool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02_oo
ool00ooo003oooooooooo`04ooooo`;oo`000_ooool01?oo003oooooool00?oo000eooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool00_ooool3o`0003oooooo0_oo0002ooooo`;oo`00
3_ooool2ool000;ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`02ool000?ooooo
00?oo`00ooooooooool02oooool2ool001;ooooo0_oo00001Oooooooo`00oooooooo003ooooo00;o
o`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Dooooo`;o00004_oo
ool0027ooooo00?o0000ooooooooool0<oooool2ool00006oooooooo003oooooool00?ooooooo`00
1Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
2oooool00ooo003oooooo`000002ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo0_oo00001?ooooooo`00
ooooooooool2ool003Gooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0?oooool2ool000;ooooo0_oo000>ooooo`;oo`000_ooool00ooo
003oooooooooo`09ooooo`03o`000?oooooooooo00;oo`000oooool00ooo003oooooooooo`0;oooo
o`;oo`004_ooool2ool00005oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`000oooool0
1Ooo003oooooooooooooooooo`0000;ooooo0_oo0003ooooo`05ool00?oooooooooooooooooo0000
0_ooool2ool001Oooooo00?o0000ooooooooool04?ooool001?ooooo1Ol00003ooooo`;o00001?oo
ool00ol0003oooooooooo`0cooooo`;oo`0000Koooooool00?ooooooo`00oooooooo0005ooooo`03
ool00?oooooooooo00_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0;ooooo`03
ool00?oooooo000000;ooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00[ooooo00?oo`00ooooooooool01?ooool2ool00004oooooooo003ooooooooo
o`;oo`00=Oooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`0oooooo`;oo`000_ooool2ool000kooooo0_oo0002ooooo`03ool00?oooooo
oooo00Wooooo00?o0000ooooooooool00_oo0003ooooo`03ool00?oooooooooo00_ooooo0_oo000B
ooooo`;oo`0000Goooooool00?ooooooo`00ooooo`02ool000;ooooo0_oo0002ooooo`;oo`000ooo
ool00ooo003oooooooooo`02ool000?ooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`00
0_ooool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo000Dooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0fooooo`05
ool00?ooooooo`00oooooooo00001Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool03?ooool00ooo003oooooo`000002ooooo`03ool00?oooooooooo
00cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo
00Cooooo0_oo00000oooooooo`00ooooo`0hooooo`03o`000?oooooooooo01oooooo0ol00004oooo
o`03o`000?oooooooooo03oooooo0_oo0002ooooo`;oo`003_ooool2ool000;ooooo00?oo`00oooo
ooooool02Oooool01Ol0003oooooool00?ooooooo`0000?ooooo00?oo`00ooooooooool02oooool2
ool001;ooooo0_oo00001Oooooooo`00oooooooo003ooooo00;oo`000_ooool2ool000;ooooo0_oo
0003ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo000Eooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0fooooo`05ool00?oo
ooooo`00oooooooo00001Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool03?ooool00ooo003oooooo`000002ooooo`03ool00?oooooooooo00cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo
00Coo`00oooooooo003oo`00>Oooool00ol0003oooooooooo`0Vooooo`;o0000@?ooool2ool000;o
oooo0_oo000=ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool02Oooool01Ol0003o
ooooool00?ooooooo`0000?ooooo00?oo`00ooooooooool02oooool2ool000?ooooo00?oo`00oooo
ooooool03?ooool2ool00005oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool0
1Ooo003oooooooooooooooooo`0000oooooo0_l0000Booooo`005_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooooooo0_l0000gooooo`05ool00?ooooooo`00oooooooo
00001Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool03?ooool00ooo003oooooo`000002ooooo`03ool00?oooooooooo00cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooooooo
003oo`00=oooool3o`0002Sooooo00?o0000ooooooooool0?oooool2ool000;ooooo0_oo000=oooo
o`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool02Oooool01Ol0003oooooool00?oooooo
o`0000;ooooo0_oo000=ooooo`;oo`000oooool00ooo003oooooooooo`0<ooooo`;oo`0000Gooooo
ool00?ooooooo`00ooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo0000
0oooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000Cooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo03Oo
oooo0_oo00000oooooooo`00ooooo`04ooooo`03ool00?oooooooooo00_ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooo000000;ooooo00?oo`00oooooooo
ool03?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00[ooooo00?oo`00oooooooo
ool01?ooool01?oo003oooooool00?oo000iooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0?oooool2ool000;ooooo0_oo000=ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooo
ooooool02Oooool01Ol0003oooooool00?ooooooo`0000;ooooo0_oo000=ooooo`;oo`000oooool0
0ooo003oooooooooo`0;ooooo`08ool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0:oooo
o`03o`000?oooooooooo013ooooo000Cooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo03Oooooo0_oo00000oooooooo`00ooooo`04
ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0<
ooooo`03ool00?oooooo000000;ooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool01?ooool01?oo003oooooool00?oo
000iooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0?oooool2ool00004oooooooo
003oooooool000gooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`09ooooo`05o`00
0?ooooooo`00oooooooo00000_ooool2ool000gooooo0_oo0003ooooo`03ool00?oooooooooo00_o
oooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00002?ooool00ol0003o
ooooooooo`0@ooooo`005?ooool3o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo03Oooooo
0_oo00000oooooooo`00ooooo`04ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooo000000;ooooo00?oo`00ooooooooool0
3?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0
1?ooool01?oo003oooooool00?oo000iooooo`03o`000?oooooooooo02Kooooo0_l00010ooooo`;o
o`0000Coooooool00?ooooooo`003Oooool00ooo003oooooool00002ooooo`03ool00?oooooooooo
00Wooooo00Go0000oooooooo003oooooool00002ooooo`;oo`003Oooool2ool000?ooooo00?oo`00
ooooooooool02oooool02?oo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`04ool00?ooooooooooooooo`;o00004_ooool0027ooooo00?o0000ooooooooool0=oooool2
ool00003oooooooo003ooooo00Cooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooool000000_ooool00ooo003oooooooooo`0<
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`04
ooooo`04ool00?ooooooo`00ool003Wooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0oooooo`;oo`0000Coooooool00?ooooooo`003Oooool00ooo003oooooool00002ooooo`03ool0
0?oooooooooo00Wooooo00Go0000oooooooo003oooooool00002ooooo`;oo`003Oooool2ool000?o
oooo00?oo`00ooooooooool02oooool02?oo003oooooool00?ooooooo`00oooooooo003ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0027ooooo
00?o0000ooooooooool0=oooool2ool00003oooooooo003ooooo00Cooooo00?oo`00ooooooooool0
2oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooool00000
0_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
2_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooo`00ool003Wooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo03Kooooo0_oo00001?oooooo
o`00oooooooo000=ooooo`04ool00?ooooooo`00ooooo`;oo`002oooool01Ol0003oooooool00?oo
ooooo`0000;ooooo0_oo000=ooooo`;oo`000oooool00ooo003oooooooooo`0;ooooo`06ool00?oo
ooooo`00oooooooo003ooooo0_oo00001?ooooooo`00ooooooooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`02ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o0000>?ooool2ool00003oooooooo003o
oooo00Cooooo00?oo`00ooooooooool03?ooool01Ooo003oooooooooooooooooo`0000kooooo00?o
o`00ooooool000000_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool02_ooool00ooo003oooooooooo`04ooooo`04ool00?ooooooo`00ool003Sooooo
0_l0000Xooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0=_ooool2ool00004oooo
oooo003oooooool000gooooo00Coo`00oooooooo003ooooo0_oo000;ooooo`05o`000?ooooooo`00
oooooooo00000_ooool2ool000gooooo0_oo0002ooooo`;oo`003Oooool01_oo003oooooool00?oo
ooooo`00ooooo`;oo`0000Coooooool00?oooooooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_ooool0
0ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0gooooo`;oo`0000?oooooool0
0?ooool01?ooool00ooo003oooooooooo`0<ooooo`05ool00?oooooooooooooooooo00003_ooool0
0ooo003oooooo`000002ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooooooo003oo`00>Ooo
ool00ol0003oooooooooo`0Vooooo`;o00001oooool01Ooo003oooooooooooooooooo`0003Cooooo
0_oo00001?ooooooo`00oooooooo000=ooooo`04ool00?ooooooo`00ooooo`;oo`002oooool02Ol0
003oooooool00?ooooooo`00oooooooo003oooooool0000<ooooo`03ool00?ooooooo`0000;ooooo
0_oo000=ooooo`06ool00?ooooooo`00oooooooo003ooooo0_oo00001_ooooooo`00oooooooo003o
ooooool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool01?oo003oooooooooooooool2o`0001;ooooo000Qooooo`03o`000?oooooooooo03Oo
oooo0_oo00000oooooooo`00ooooo`04ooooo`03ool00?oooooooooo00cooooo00Goo`00oooooooo
ooooooooool0000>ooooo`03ool00?oooooo000000;ooooo00?oo`00ooooooooool03?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool01?ooool01?oo
003oooooool00?oo000iooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool0
1Ooo003oooooooooooooooooo`0003Cooooo0_oo00001?ooooooo`00oooooooo000=ooooo`04ool0
0?ooooooo`00ooooo`;oo`002oooool02Ol0003oooooool00?ooooooo`00oooooooo003oooooool0
000<ooooo`03ool00?ooooooo`0000;ooooo0_oo000=ooooo`06ool00?ooooooo`00oooooooo003o
oooo0_oo00001_ooooooo`00oooooooo003oooooool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000_ooool00ooo003oooooooooo`03ooooo`03o`00
0?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo03[ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`0<ooooo`05ool00?oooooooooooooooooo00003_ooool00ooo003ooooo
o`000002ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0>_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00Kooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo02gooooo00Ooo`00oooooooo003oooooool00?ooooooo`0000?ooooo00?oo`00
ooooooooool01_ooool01Ooo003ooooooooooooo003ooooo00;oo`002oooool02Ol0003oo`00oooo
ooooooooo`00oooooooo003oooooool0000<ooooo`03ool00?ooooooo`0000;ooooo0_oo000=oooo
o`06ool00?ooooooo`00oooooooo003ooooo0_oo00001_ooooooo`00oooooooo003oooooool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool0
0ooo003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo
03[ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0<ooooo`05ool00?oooooooooo
oooooooo00003_ooool00ooo003oooooo`000002ooooo`03ool00?oooooooooo00cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool0>_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000:oooool01ooo003ooooo
ool00?ooooooo`00oooooooo00000oooool00ooo003oooooooooo`06ooooo`05ool00?oooooooooo
ool00?ooool00_oo000;ooooo`09o`000?oo003ooooooooooooo003oooooool00?ooooooo`0000co
oooo00?oo`00oooooooo00000_ooool2ool000gooooo00Koo`00oooooooo003oooooool00?ooool2
ool00006oooooooo003oooooool00?ooooooo`000_ooool2ool00004oooooooo003oooooool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00ooooooooool00oooool0
0ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0jooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool03?ooool01Ooo003oooooooooooooooooo`0000kooooo00?oo`00
ooooool000000_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool02_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo03[ooooo00?o0000
ooooooooool09_ooool2o`0000Oooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo0000:oooool01ooo003oooooool00?ooooooo`00oooooooo00000oooool00ooo
003oooooooooo`06ooooo`05ool00?ooooooooooool00?ooool00_oo000;ooooo`09o`000?oo003o
oooooooooooo003oooooool00?ooooooo`0000cooooo00?oo`00oooooooo00000_ooool2ool000go
oooo00Koo`00oooooooo003oooooool00?ooool2ool00006oooooooo003oooooool00?ooooooo`00
0_ooool2ool00004oooooooo003oooooool000;ooooo0_oo00001?ooooooo`00oooooooo0002oooo
o`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00;oo`000_ooool00ooo003oooooooooo`02ooooo`;o00004_ooool0027ooooo0_l0000koooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03?ooool01Ooo003ooooooooooooooooo
o`0000kooooo00?oo`00ooooool000000_ooool00ooo003oooooooooo`0<ooooo`05ool00?oooooo
oooooooooooo00003_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo03Wooooo0_l0
000Xooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000ooo
ool01?oo003ooooooooooooo000Xooooo`07ool00?ooooooo`00oooooooo003oooooool00003oooo
o`03ool00?oooooooooo00Kooooo00Goo`00ooooooooooooo`00ooooo`02ool000?ooooo00?oo`00
ooooooooool01Oooool02Ol0003oo`00ooooooooooooo`00oooooooo003oooooool0000<ooooo`03
ool00?ooooooo`0000;ooooo0_oo000=ooooo`06ool00?ooooooo`00oooooooo003ooooo0_oo0000
3_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_oo
ool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`;oo`000_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooo
oooo00?ooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0>_ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00cooooo00Goo`00ooooooooooooooooool0000>
ooooo`03ool00?oooooo000000;ooooo00?oo`00ooooooooool03?ooool01Ooo003ooooooooooooo
ooooo`0000kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0jooooo`03o`000?oo
oooooooo01oooooo0ol00004ooooo`03o`000?oooooooooo00Gooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo02Kooooo00Ooo`00oooooooo003ooooo
ool00?ooooooo`0000;ooooo0_oo0008ooooo`05ool00?ooooooooooool00?ooool00_oo0003oooo
o`03ool00?oooooooooo00Gooooo00Wo0000ool00?ooooooooooool00?ooooooo`00oooooooo0000
0oooool00ooo003oooooooooo`06ooooo`03ool00?ooooooo`0000;ooooo0_oo000=ooooo`06ool0
0?ooooooo`00oooooooo003ooooo0_oo00003_ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`000_ooool2ool00008oooooooo003oooooool00?ooooooo`00
oooooooo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool00_oo0002ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool04?ooool0027o
oooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00co
oooo00Goo`00ooooooooooooooooool0000>ooooo`05ool00?oooooo0000oooooooo00003oooool0
1Ooo003oooooooooooooooooo`0000kooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`0jooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003ooooooooo
ooooooooo`0002Cooooo00Ooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo0008oooo
o`05ool00?ooooooooooool00?ooool00_oo0003ooooo`03ool00?oooooooooo00Gooooo00Wo0000
ool00?ooooooooooool00?ooooooo`00oooooooo00000oooool00ooo003oooooooooo`06ooooo`03
ool00?ooooooo`0000;ooooo0_oo000=ooooo`06ool00?ooooooo`00oooooooo003ooooo0_oo0000
3_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_oo
ool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`;oo`000_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooo
oooo00?ooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0>_ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00cooooo00Goo`00ooooooooooooooooool0000?
ooooo`04ool00?l0003oooooool000oooooo00Goo`00ooooooooooooooooool0000>ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool0>_ooool00ol0003oooooooooo`0Hooooo`Go0000
0oooool00ol0003oooooooooo`03ooooo`?o00001Oooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo00Goo`00ooooooooooooooooool0000Tooooo`07ool00?ooooooo`00oooo
oooo003oooooool00002ooooo`;oo`002?ooool01Ooo003ooooooooooooo003ooooo00;oo`000ooo
ool00ooo003oooooooooo`05ooooo`09o`000?oo003ooooooooooooo003oooooool00?ooooooo`00
00;ooooo0_oo0008ooooo`03ool00?ooooooo`0000;ooooo0_oo000=ooooo`06ool00?ooooooo`00
oooooooo003ooooo0_oo00003_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`000_ooool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo0002
ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_oo
ool00ooo003oooooooooo`02ooooo`;o00004_ooool0027ooooo00?o0000ooooooooool0>_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00gooooo00Goo`00ooooooooooooooooool0
000?ooooo`04ool00?l0003oooooool000oooooo00Goo`00ooooooooooooooooool0000>ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool0>_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
01kooooo00Coo`00oooooooo003oo`000_ooool00ooo003oooooooooo`02ool000Sooooo00Goo`00
ooooooooooooo`00ooooo`02ool000?ooooo00?oo`00ooooooooool01Oooool02Ol0003oo`00oooo
ooooooooo`00oooooooo003oooooool00002ooooo`;oo`002?ooool00ooo003oooooool00002oooo
o`;oo`003?ooool01ooo003ooooooooooooo003oooooool00?ooool00_oo00006_ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool000;ooooo00Goo`00oooooooo
ooooooooool00002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ol0
003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0jooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool03Oooool01?oo003ooooooooooooo000@ooooo`04ool00?l0003ooooo
ool000oooooo00Goo`00ooooooooooooooooool0000>ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool0>_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo01kooooo00Coo`00oooooooo003o
o`000_ooool00ooo003oooooooooo`02ool000Sooooo00Goo`00ooooooooooooo`00ooooo`02ool0
00?ooooo00?oo`00ooooooooool01Oooool02Ol0003oo`00ooooooooooooo`00oooooooo003ooooo
ool00002ooooo`;oo`002?ooool00ooo003oooooool00002ooooo`;oo`003?ooool01ooo003ooooo
oooooooo003oooooool00?ooool00_oo00007_ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool000;ooooo00Goo`00ooooooooooooooooool00002oooo
o`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0@oooo
o`008Oooool2o`0003_ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0=ooooo`04
ool00?ooooooooooool0013ooooo00Coo`00o`000?ooooooo`003oooool01Ooo003ooooooooooooo
ooooo`0000kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0jooooo`;o00008Ooo
ool2o`0000Gooooo00?o0000ooooooooool01Oooool2ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00007?ooool01?oo003oooooool00?oo0002ooooo`03ool00?oooooooooo00;oo`002?ooool01Ooo
003ooooooooooooo003ooooo00;oo`000oooool00ooo003oooooooooo`05ooooo`09o`000?oo003o
oooooooooooo003oooooool00?ooooooo`0000;ooooo0_oo0008ooooo`03ool00?ooooooo`0000;o
oooo0_oo000<ooooo`07ool00?ooooooooooool00?ooooooo`00ooooo`02ool0000Ooooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ol0
003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0jooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool03Oooool01?oo003ooooooooooooo000@ooooo`04ool00?l0003ooooo
ool0013ooooo00Coo`00ooooooooooooo`003_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`;o00001_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Fooooo`04
ool00?ooooooo`00ool000;ooooo00?oo`00ooooooooool00_oo0008ooooo`05ool00?oooooooooo
ool00?ooool00_oo0003ooooo`03ool00?oooooooooo00Gooooo00Co0000ool00?oooooooooo0_oo
0002ooooo`03ool00?oooooooooo00;oo`002?ooool01ooo003oooooool00?ooooooo`00oooooooo
00003?ooool00ooo003oooooooooo`02ool000;ooooo0_oo00007oooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00;ooooo0_l0000Booooo`008Ooo
ool00ol0003oooooooooo`0jooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03Ooo
ool01?oo003ooooooooooooo000@ooooo`04ool00?l0003oooooool0013ooooo00Coo`00oooooooo
ooooo`003_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03_ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`05ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`03ool00?oooooooooo01Kooooo00Coo`00oooooooo003oo`000_ooool01Ooo003ooooo
ool00?ooooooo`0000Sooooo00?oo`00ooooooooool00_oo00000oooooooo`00ooooo`02ooooo`03
ool00?oooooooooo00Gooooo00Co0000ool00?oooooooooo0_oo0002ooooo`03ool00?oooooooooo
00;oo`001oooool02?oo003ooooooooooooo003oooooool00?ooooooo`000oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00;oo`000_ooool2ool0000Ooooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ol0003ooooooooo
o`0@ooooo`005Oooool3o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo03[ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0=ooooo`04ool00?ooooooooooool0013ooooo00Co
o`00o`000?ooooooo`004?ooool01?oo003ooooooooooooo000>ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Go
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
000Dooooo`04ool00?ooooooo`00ool000;ooooo00Goo`00oooooooo003oooooool00008ooooo`03
ool00?oooooooooo00;oo`0000?oooooool00?ooool00_ooool00ooo003oooooooooo`05ooooo`04
o`000?oo003oooooooooo`;oo`000_ooool00ooo003oooooooooo`02ool000Oooooo00Soo`00oooo
ooooooooo`00oooooooo003oooooool000?ooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`02ool000;ooooo027oo`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo00000oooooooo`00ooooo`05ooooo`03o`000?oooooooooo013ooooo000Fooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000003cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0=ooooo`04ool00?ooooooooooool0013ooooo00Coo`00o`00
0?ooooooo`004?ooool01?oo003ooooooooooooo000>ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000Doooo
o`04ool00?ooooooo`00ool000;ooooo00Goo`00oooooooo003oooooool00008ooooo`03ool00?oo
oooooooo00;oo`0000?oooooool00?ooool00_ooool00ooo003oooooooooo`05ooooo`04o`000?oo
003oooooooooo`;oo`000_ooool00ooo003oooooooooo`02ool000Oooooo00Soo`00oooooooooooo
o`00oooooooo003oooooool000?ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`02
ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`0Jool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00003oooo
oooo003ooooo00Gooooo00?o0000ooooooooool04?ooool001?ooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00gooooo00Coo`00ooooooooooooo`004?ooool01?oo003o0000oooooooo000@oooo
o`04ool00?ooooooooooool000kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0k
ooooo`03o`000?oooooooooo02Kooooo0_l00006ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00005?ooool01?oo003oooooool00?oo0002oooo
o`05ool00?ooooooo`00oooooooo00001oooool01?oo003oooooooooooooool2ool00004oooooooo
003oooooooooo`;oo`001oooool01?l0003oo`00ooooooooool2ool000;ooooo00?oo`00oooooooo
ool00_oo0007ooooo`08ool00?ooooooooooool00?ooooooo`00oooooooo0003ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo00;oo`000_oo
ool06_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo00000oooooooo`00ooooo`04ooooo`;o00004_ooool001?ooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`;o0000>oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo00004?ooool01?oo
003o0000oooooooo000@ooooo`04ool00?ooooooooooool000kooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0iooooo`?o0000:?ooool00ol0003oooooooooo`05ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`0=ooooo`03ool00?oooooooooo00;oo`000_ooool01Ooo003oooooool00?oooooo
o`0000Oooooo00Coo`00oooooooooooooooo0_oo00001?ooooooo`00ooooooooool2ool000Oooooo
00Co0000ool00?oooooooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`001oooool02?oo003o
oooooooooooo003oooooool00?ooooooo`000oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`0Fool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000?o
ooooool00?ooool01Oooool00ol0003oooooooooo`0@ooooo`005?ooool00ol0003oooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0>_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo00004?ooool01?oo003o0000oooo
oooo000@ooooo`04ool00?ooooooooooool000kooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool03Oooool00ooo003oooooooooo`02ool000;ooooo00Goo`00oooooooo003ooooo
ool00007ooooo`04ool00?ooooooooooooooo`;oo`0000Coooooool00?oooooooooo0_oo0007oooo
o`04o`000?oo003oooooooooo`;oo`000_ooool00ooo003oooooooooo`02ool000Oooooo00Soo`00
ooooooooooooo`00oooooooo003oooooool000?ooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`02ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;o
oooo01;oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00003oooooooo
003ooooo00Gooooo00?o0000ooooooooool04?ooool001Gooooo0_l00003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00kooooo00?oo`00oooooooo00004?ooool01?oo003o0000oooooooo000@ooooo`03ool0
0?ooooooo`0000oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0kooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool01Oooool2ool00004oooooooo003oooooool000;o
oooo0_oo0002ooooo`;oo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0003oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`02ool000;ooooo00Goo`00oooooooo003ooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool2ool00004oooooooo003ooooooooo
o`;oo`000oooool01_oo003ooooooooooooooooo0000ool000;ooooo0_oo0002ooooo`03ool00?oo
oooooooo00;oo`000_ooool2ool000?ooooo00Soo`00ooooooooooooo`00oooooooo003oooooool0
00?ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`02ool000;ooooo00?oo`00oooo
ooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo01;oo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool00003oooooooo003ooooo00Gooooo00?o0000ooooooooool0
4?ooool001Kooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool0>_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo00004?oo
ool00ooo003o0000ool0000Aooooo`03ool00?ooooooo`0000oooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo02Kooooo0_l00006ooooo`;oo`0000Co
ooooool00?ooooooo`000_ooool2ool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`00
0_ooool2ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00;oo`000_ooool01Ooo
003oooooool00?ooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`;oo`0000Co
ooooool00?oooooooooo0_oo0003ooooo`06ool00?ooooooooooooooool0003oo`000_ooool2ool0
00;ooooo00Goo`00oooooooo003oooooool00002ooooo`;oo`000oooool02?oo003ooooooooooooo
003oooooool00?ooooooo`000_ooool2ool000Sooooo00?oo`00ooooooooool00_oo0002ooooo`03
ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`0Bool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00000oooooooo`00ooooo`04ooooo`;o00004_oo
ool0027ooooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00kooooo00?oo`00oooooooo00004?ooool00ooo003o0000ool0000Aooooo`03ool00?oooooo
o`0000oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0kooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool01Oooool2ool00008oooooooo003oooooool00?ooooooo`00
oooooooo0002ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;o
o`000oooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0003ooooo`03ool00?oooooooooo
00Wooooo00?oo`00ooooooooool00_oo0002ooooo`05ool00?ooooooo`00oooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo0_oo00001?ooooooo`00ooooooooool2ool000?ooooo
00Koo`00ooooooooooooooooo`000?oo0002ooooo`;oo`000_ooool01Ooo003oooooool00?oooooo
o`0000;ooooo0_oo0003ooooo`08ool00?ooooooooooool00?ooooooo`00oooooooo0002ooooo`;o
o`002?ooool00ooo003oooooooooo`02ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`0>ool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
0003oooooooo003ooooo00Gooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000oooooooo
ool0>_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo
00004?ooool00ooo003o0000ool0000Aooooo`03ool00?ooooooo`0000oooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool01Oooool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`;oo`000_oo
ool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000?ooooo00?o
o`00ooooooooool00_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00;oo`000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0003ooooo`04ool0
0?ooooooooooooooo`;oo`0000Coooooool00?oooooooooo0_oo0003ooooo`06ool00?oooooooooo
ooooool0003oo`000_ooool2ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`;oo`00
0oooool02?oo003ooooooooooooo003oooooool00?ooooooo`000_ooool2ool000Sooooo00?oo`00
ooooooooool00_oo0002ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool03_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00000oooooooo`00oooo
o`05ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o0000>oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo00004?ooool00ooo003o0000ool0000A
ooooo`03ool00?ooooooo`0000oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0j
ooooo`;o0000:?ooool00ol0003oooooooooo`05ooooo`;oo`0000Soooooool00?ooooooo`00oooo
oooo003oooooool000;ooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`03
ool00?oooooooooo00Kooooo00Coo`00ooooooooooooo`000oooool2ool000;ooooo00?oo`00oooo
ooooool00_oo0003ooooo`04ool00?ooooooooooooooo`;oo`0000Coooooool00?oooooooooo0_oo
0003ooooo`06ool00?ooooooooooooooool0003oo`000_ooool2ool000;ooooo00Goo`00oooooooo
003oooooool00002ooooo`;oo`000oooool02?oo003ooooooooooooo003oooooool00?ooooooo`00
0_ooool2ool000?ooooo00?oo`00ooooooooool00_ooool01?oo003ooooooooooooo0003ooooo`03
ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo00[oo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo00000oooooooo`00ooooo`05ooooo`03o`000?oooooooooo013ooooo
000Qooooo`03o`000?oooooooooo03[ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0>ooooo`03ool00?ooooooo`00013ooooo00?oo`00o`000?oo00004Oooool00ooo003oooooool0
000?ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0>oooool00ol0003ooooooooo
o`0Vooooo`;o00001_ooool2ool00008oooooooo003oooooool00?ooooooo`00oooooooo0002oooo
o`;oo`0000?oooooool00?oo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool01_ooool01?oo
003ooooooooooooo0003ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000?ooooo00Coo`00
oooooooooooooooo0_oo00001?ooooooo`00ooooooooool2ool000?ooooo00Koo`00oooooooooooo
ooooo`000?oo0002ooooo`;oo`000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0003
ooooo`03ool00?oooooooooo00;oo`000_ooool00ooo003oooooooooo`02ool000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`0:ool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000?o
ooooool00?ooool01?ooool2o`0001;ooooo000Qooooo`03o`000?oooooooooo03[ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`;oo`004_ooool2ool0017ooooo00?oo`00
oooooooo00003oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03_ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`04ooooo`0;ool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00000_ooool2ool00003oooooooo003oo`0000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`05ool00?oooooooooooooooooo00001?ooool01?oo003ooooooooooooo0003ooooo`;oo`000_oo
ool00ooo003oooooooooo`02ool000?ooooo00Coo`00oooooooooooooooo0_oo00001?ooooooo`00
ooooooooool2ool000?ooooo00Koo`00ooooooooooooooooo`000?oo0002ooooo`;oo`000_ooool0
1Ooo003oooooool00?ooooooo`0000;ooooo0_oo0003ooooo`03ool00?oooooooooo00;oo`000_oo
ool00ooo003oooooooooo`02ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo0002ooooo`;oo`000_ooool01_oo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?ooool01Oooool00ol0003oooooooooo`0@
ooooo`008Oooool00ol0003oooooooooo`0jooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool03_ooool2ool001;ooooo0_oo000Aooooo`03ool00?ooooooo`0000oooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo0_l00004oooo
o`03o`000?oooooooooo00Cooooo013oo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool01Ooo003ooooooooo
ooooooooo`0000Cooooo00Coo`00ooooooooooooo`000oooool2ool000;ooooo00?oo`00oooooooo
ool00_oo0003ooooo`05ool00?oooooooooooooooooo00000_ooool00ooo003oooooooooo`02ool0
00?ooooo00Koo`00ooooooooooooooooo`000?oo0002ooooo`09ool00?oooooooooooooooooo003o
ooooool00?ooooooo`0000;ooooo0_oo0003ooooo`03ool00?oooooooooo00;oo`000_ooool00ooo
003oooooooooo`02ool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?ooooooo`00ooooooooool2ool000;ooooo
0_oo0002ooooo`;oo`0000?oooooool00?ooool01Oooool00ol0003oooooooooo`0@ooooo`008Ooo
ool00ol0003oooooooooo`0jooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03_oo
ool2ool001;ooooo0_oo000Aooooo`03ool00?ooooooo`0000oooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`04ooooo`0@ool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00oooo
ooooooooooooool00004ooooo`04ool00?ooooooooooool000?ooooo0_oo0002ooooo`03ool00?oo
oooooooo00;oo`000oooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00ooooooooool0
0_oo0003ooooo`06ool00?ooooooooooooooool0003oo`000_ooool02Ooo003ooooooooooooooooo
o`00oooooooo003oooooool00002ooooo`;oo`000_ooool01?oo003oooooooooooooool2ool000;o
oooo00?oo`00ooooooooool00_oo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002
ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Koooooool00?ooooooo`00oooo
oooo0002ooooo`;oo`000_ooool2ool00003oooooooo003ooooo00Gooooo00?o0000ooooooooool0
4?ooool0027ooooo00?o0000ooooooooool0>_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00kooooo0_oo000Booooo`;oo`004_ooool00ooo003oooooooooo`0>ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool0>oooool00ol0003oooooooooo`0Oooooo`04o`000?oo
ooooooooo`0000?ooooo1ol000004?oo003o0000ool00?l0003oo`00o`000?oo003o0000ool00?l0
003oo`00o`000?oo003o0000ool00?l00002ool000;o00000_oo0002o`0000;oo`000_l00002ool0
00;o00000_oo0002o`0000;oo`000_l00002ool000;o00000_oo0002o`000005ool00?l0003o0000
o`000?oo00001?l000001?oo003o0000o`000?oo0003o`0000;oo`000_l000000ooo003o0000o`00
0002ool000?o000000Goo`00o`000?l0003o0000ool00002o`000003ool00?l0003o000000;oo`00
0ol000000ooo003o0000o`000002o`000004ool00?l0003o0000ool000?o00000_oo0002o`000003
ool00?l0003o000000;oo`000_l000001?oo003o0000o`000?l00002ool000;o000000?oo`00o`00
0?l000000_oo0002o`0000;oo`000ol000001Ooo003o0000o`000?l0003oo`0000?o000000?oo`00
o`000?l000000_oo0002o`0000;oo`000_l00002ool000;o00000_oo0002o`0000;oo`000_l00002
ool000;o00000_oo0002o`0000;oo`0000[o0000ool00?l0003oo`00o`000?oo003o0000ool00?l0
003oo`000_l00002ool00003o`000?oo003o000000Ko00004_ooool0027ooooo0_l0000kooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0@ooooo`;o
o`004_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool0>_ooool2o`00027ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04oooo
o`0@ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00004ooooo`04ool0
0?ooooooooooool000?ooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`000oooool01Ooo003o
ooooooooooooooooo`0000;ooooo00?oo`00ooooooooool00_oo0003ooooo`05ool00?oooooooooo
oooooooo00000oooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00ooooooooool00_oo
0002ooooo`04ool00?ooooooooooooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo
0_oo0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;o
oooo0_oo00003Oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool00_oo0007ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo03[ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`0@ool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo00Goo`00ooooooooooooooooool00004ooooo`04ool00?ooooooooooool000?ooooo
0_oo0002ooooo`03ool00?oooooooooo00;oo`000_ooool00ooo003oooooooooo`02ooooo`08ool0
0?ooooooooooool00?ooooooo`00oooooooo0003ooooo`05ool00?oooooooooooooooooo00000ooo
ool01?oo003oooooooooooooool2ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`04ool0
0?ooooooooooooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0003ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00003Ooo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0007oooo
o`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo03[ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo02;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`04ooooo`0@ool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Go
o`00ooooooooooooooooool00004ooooo`04ool00?ooooooooooool000?ooooo0_oo0002ooooo`03
ool00?oooooooooo00;oo`000_ooool00ooo003oooooooooo`02ooooo`08ool00?ooooooooooool0
0?ooooooo`00oooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooo
ooooooooool2ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`04ool00?oooooooooooooo
o`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0003ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00003Oooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0007ooooo`03o`000?oooooo
oooo013ooooo000Qooooo`03o`000?oooooooooo03_ooooo00Goo`00ooooooooooooooooool0000T
ooooo`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0k
ooooo`03o`000?oooooooooo023ooooo0_l00004ooooo`;o00001Oooool04?oo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00?ooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`000_ooool00ooo003oooooooooo`02oooo
o`08ool00?ooooooooooool00?ooooooo`00oooooooo0003ooooo`05ool00?oooooooooooooooooo
00000oooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00ooooooooool00_oo0002oooo
o`04ool00?ooooooooooooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo0_oo0003
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
00003Oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo
0006ooooo`;o00004_ooool0027ooooo00?o0000ooooooooool0>oooool01Ooo003ooooooooooooo
ooooo`0002Cooooo00?o0000ooooooooool08_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo03_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`0@ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool2ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?oo
oooooooo00;ooooo00Soo`00ooooooooooooo`00oooooooo003oooooool000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`04ool00?ooooooooooooooo`;oo`000_ooool00ooo003ooooooooo
o`02ool000;ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo
00000_ooool2ool000?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ool000;o
oooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool0000=oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00ooooo`02ool000Oooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000oooooooo
ool0>oooool01Ooo003oooooooooooooooooo`0002Cooooo00?o0000ooooooooool08_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo03_ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`04ooooo`0@ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ooooo`;oo`0000Coooooool00?ooooooo`000_ooool2ool000;ooooo
0_oo00001?ooooooo`00oooooooo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo0_oo0002
ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooooooo`02ooooo`08ool00?oo
ooooooooool00?ooooooo`00oooooooo0002ooooo`;oo`000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`000_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00oooooooo003oooooool00002ooooo`;oo`000oooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00;oo`000_ooool01Ooo003oooooooooooooooooo`0000?o
oooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000goooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00;oo`001oooool00ol0003o
ooooooooo`0@ooooo`008Oooool2o`0003cooooo00Goo`00ooooooooooooooooool0000Tooooo`03
o`000?oooooooooo02;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0jooooo`;o
0000:?ooool00ol0003oooooooooo`04ooooo`0@ool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`0000Soooooool00?ooooooo`00oooo
oooo003oooooool000;ooooo0_oo00001?ooooooo`00oooooooo0002ooooo`;oo`000_ooool2ool0
0004oooooooo003oooooool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo00Gooooo00Woo`00ooooooooooooooooool00?ooooooo`00oooooooo00000_ooool00ooo
003oooooooooo`02ooooo`08ool00?ooooooooooool00?ooooooo`00oooooooo0002ooooo`;oo`00
0oooool01Ooo003oooooooooooooooooo`0000?ooooo0_oo0002ooooo`05ool00?ooooooo`00oooo
oooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo003oooooool0
0002ooooo`;oo`000oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;oo`000_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`0000goooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003ooooo00;oo`001oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003ooooooooo
o`0kooooo`05ool00?oooooooooooooooooo00009?ooool00ol0003oooooooooo`0Rooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00Cooooo013oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003ooooo0_oo00005?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool2ool00005
oooooooo003oooooool00?ooool00_oo0003ooooo`05ool00?oooooooooooooooooo00001oooool0
2Ooo003oooooooooooooooooo`00oooooooo003oooooool00002ooooo`03ool00?oooooooooo00;o
oooo00Soo`00ooooooooooooo`00oooooooo003oooooool000;ooooo0_oo0003ooooo`05ool00?oo
oooooooooooooooo00000oooool2ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0003
ooooo`03ool00?oooooooooo00Sooooo0_oo0002ooooo`05ool00?oooooooooooooooooo00000ooo
ool01?oo003oooooooooooooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0000=oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool000Oooooo
00?o0000ooooooooool04?ooool0027ooooo00?o0000ooooooooool0>oooool01Ooo003ooooooooo
ooooooooo`0002Cooooo00?o0000ooooooooool08_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo03_ooooo00?o0000ooooooooool09_ooool2o`0000Gooooo013oo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo00005?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`000_ooool2ool00005oooooooo003oooooool00?ooool00_oo0003oooo
o`05ool00?oooooooooooooooooo00001oooool02Ooo003oooooooooooooooooo`00oooooooo003o
ooooool00002ooooo`03ool00?oooooooooo00;ooooo00Soo`00ooooooooooooo`00oooooooo003o
ooooool000;ooooo0_oo0003ooooo`05ool00?oooooooooooooooooo00000oooool2ool000;ooooo
00Goo`00oooooooo003oooooool00002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooool00?ooooooo`0000;ooooo0_oo0003ooooo`03ool00?oooooooooo00Sooooo0_oo0002
ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003oooooooooooooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool0000=oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00ooooo`02ool000Kooooo0_l0000Booooo`008Oooool00ol0003ooooooooo
o`0kooooo`05ool00?oooooooooooooooooo00009?ooool00ol0003oooooooooo`0Rooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00?ooooo017oo`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00ooooo`02ool0000Moooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooool00_oo0003ooooo`05ool00?oooooooooooooooooo
00001oooool02Ooo003oooooooooooooooooo`00oooooooo003oooooool00002ooooo`03ool00?oo
oooooooo00;ooooo00Soo`00ooooooooooooo`00oooooooo003oooooool000;ooooo0_oo0003oooo
o`05ool00?oooooooooooooooooo00000oooool2ool000;ooooo00Goo`00oooooooo003oooooool0
0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooool00?ooooooo`0000;o
oooo0_oo0003ooooo`03ool00?oooooooooo00Sooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2
ool0000=oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02
ool000Oooooo00?o0000ooooooooool04?ooool001Cooooo0ol00004ooooo`;o00001?ooool00ol0
003oooooooooo`0kooooo`05ool00?oooooooooooooooooo00009?ooool00ol0003oooooooooo`0R
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0>oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`0:ool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`0001goooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool000;ooooo0_oo0003ooooo`03ool0
0?oooooooooo00Gooooo00Woo`00ooooooooooooooooool00?ooooooo`00oooooooo00000_ooool0
0ooo003oooooooooo`05ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000?ooooo00?o
o`00ooooooooool01Oooool2ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool0
0?oooooooooo00Gooooo00Goo`00oooooooo003oooooool00002ooooo`;oo`000_ooool00ooo003o
ooooooooo`0=ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo0_oo0002ooooo`;oo`000_ooool2ool0000=oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooo`02ool000Oooooo00?o0000ooooooooool04?ooool0
01?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool0>oooool01Ooo003oooooooooooooooooo`0002Cooooo00?o0000ooooooooool0
8_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03_ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo
00Koo`00oooooooo003oooooool00?ooool2ool0000Moooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooool00_oo0002ooooo`;oo`000oooool00ooo003ooooo
ooooo`05ooooo`09ool00?oooooooooooooooooo003oooooool00?ooooooo`0000;ooooo00?oo`00
ooooooooool01Oooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0003ooooo`03ool00?oo
oooooooo00Gooooo00Woo`00ooooooooooooooooool00?ooooooo`00oooooooo00000_ooool00ooo
003oooooooooo`05ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000;ooooo00?oo`00
ooooooooool03Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2ool0000=oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool000Oooooo00?o0000oooooooo
ool04?ooool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00?ooooo0_l0000looooo`05ool00?oooooooooooooooooo00009?ooool00ol0003oooooooooo`0R
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0>Oooool3o`0002Sooooo0_l00004
ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo00Koo`00oooooooo003oooooool0
0?ooool2ool0000Moooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooool00_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`05ooooo`09ool00?oooooo
oooooooooooo003oooooool00?ooooooo`0000;ooooo00?oo`00ooooooooool01Oooool01Ooo003o
ooooool00?ooooooo`0000;ooooo0_oo0003ooooo`03ool00?oooooooooo00Gooooo00_oo`00oooo
ooooooooooooool00?ooooooo`00oooooooo003oooooool00008ooooo`05ool00?ooooooo`00oooo
oooo00000_ooool2ool000;ooooo00?oo`00ooooooooool04Oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`;oo`000_ooool2ool0000=oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool000Kooooo0_l0
000Booooo`004oooool4o`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0kooooo`05ool00?oooooooooooooooooo00009?ooool00ol0003oooooooooo`0Sooooo`05ool0
0?oooooooooooooooooo0000?Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?o
oooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo027oo`00oooooooo
003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool00_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`05ooooo`09ool00?oooooooooooooo
oooo003oooooool00?ooooooo`0000;ooooo00?oo`00ooooooooool01Oooool2ool000;ooooo00?o
o`00ooooooooool00_oo0003ooooo`03ool00?oooooooooo00Gooooo00_oo`00oooooooooooooooo
ool00?ooooooo`00oooooooo003oooooool00008ooooo`05ool00?ooooooo`00oooooooo00000_oo
ool2ool000;ooooo00?oo`00ooooooooool04Oooool01Ooo003oooooooooooooooooo`0000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool03?oo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`001oooool00ol0
003oooooooooo`0@ooooo`004oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0>oooool01Ooo003oooooooooooooooooo`0002Cooooo00?o0000
ooooooooool08oooool01Ooo003oooooooooooooooooo`0003gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`0Qool00?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003ooooo00;oo`000_ooool2ool000?ooooo00?oo`00ooooooooool01Ooo
ool02Ooo003oooooooooooooooooo`00oooooooo003oooooool00002ooooo`03ool00?oooooooooo
00Gooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`000_ooool00ooo003o0000ooooo`06oooo
o`0;ool00?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo00002?ooool01Ooo003o
ooooool00?ooooooo`0000;ooooo0_oo0002ooooo`03ool00?oooooooooo01Gooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`02ool000;ooooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`001oooool00ol0
003oooooooooo`0@ooooo`005?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0>oooool01Ooo003oooooooooooooooooo`0002Cooooo00?o0000
ooooooooool08oooool01?oo003ooooooooooooo000nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool00oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool0000Ooooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00ooooo`02ool000;ooooo0_oo0003ooooo`03ool00?oooooooooo00Gooooo00_oo`00
ooooooooooooooooool00?ooooooo`00oooooooo003oooooool00008ooooo`;oo`000_ooool00ooo
003oooooooooo`02ool000;ooooo00?oo`00o`000?ooool01_ooool01?oo003oooooooooooooool2
ool000;ooooo00?oo`00oooooooo00002?ooool2ool000;ooooo00?oo`00ooooooooool00_oo0002
ooooo`03ool00?oooooooooo01Gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`04ool0
0?ooooooo`00ooooo`;oo`001oooool00ol0003oooooooooo`0@ooooo`005Oooool2o`0000Cooooo
0_l00004ooooo`03o`000?oooooooooo03_ooooo00Coo`00ooooooooooooo`009Oooool00ol0003o
ooooooooo`0Sooooo`04ool00?ooooooooooool003kooooo00?o0000ooooooooool09_ooool2o`00
00Cooooo00?oo`00ooooooooool00_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00007ooo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool00_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`09ooooo`;oo`000_ooool00ooo003o
ooooool00008ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo00?oo`00o`000?oo
ool01_ooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00oooooooo00002?ooool2ool0
00;ooooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo01Wooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`000_ooool00ooo003oooooooooo`05ooooo`;o00004_ooool0027ooooo00?o0000
ooooooooool0>oooool01?oo003ooooooooooooo000Uooooo`03o`000?oooooooooo02?ooooo00Co
o`00ooooooooooooo`00?_ooool00ol0003oooooooooo`0Oooooo`?o00001?ooool00ol0003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
00?oooooool00?oo00000_ooool06_oo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003ooooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`09ooooo`;oo`000_ooool00ooo
003oooooool00008ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000;ooooo00?oo`00o`00
0?ooool01_ooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00oooooooo00002?ooool2
ool000;ooooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo01Wooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo
000Qooooo`;o0000??ooool01?oo003ooooooooooooo000Uooooo`03o`000?oooooooooo02?ooooo
00Coo`00ooooooooooooo`00?Oooool2o`0002;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`0000?oooooool00?oo00000_ooool2ool000;ooooo01Koo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
oooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`0:ooooo`;oo`000_ooool00ooo003o
ooooool00008ooooo`;oo`000_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00o`00
0?ooool01_ooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00oooooooo00002?ooool2
ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?oooooooooo01gooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool04?ooool0027ooooo00?o
0000ooooooooool0>oooool01?oo003ooooooooooooo000Uooooo`03o`000?oooooooooo02?ooooo
00Coo`00ooooooooooooo`00?_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool00003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000_ooool04_oo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00ooooooooool02_ooool2ool000;ooooo00?o
o`00oooooooo00002?ooool2ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool0
0?l0003ooooo00Kooooo00Coo`00oooooooooooooooo0_oo0002ooooo`03ool00?ooooooo`0000So
oooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooooooo`0Moooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002
ooooo`;oo`000_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo000Qoooo
o`03o`000?oooooooooo03_ooooo00Coo`00ooooooooooooo`009Oooool00ol0003oooooooooo`0S
ooooo`04ool00?ooooooooooool003kooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`03ooooo`?o00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool00003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00ko
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`00
0_ooool2ool000;ooooo00?oo`00ooooooooool02_ooool2ool000;ooooo00?oo`00oooooooo0000
2?ooool2ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?l0003ooooo00Ko
oooo00Coo`00oooooooooooooooo0_oo0002ooooo`03ool00?ooooooo`0000Sooooo0_oo0002oooo
o`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooooooo`0Qooooo`05ool00?oooooo
oooooooooooo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003ooooooooo
o`05ooooo`;o00004_ooool0027ooooo00?o0000ooooooooool0>oooool01?oo003ooooooooooooo
000Uooooo`03o`000?oooooooooo02?ooooo00Coo`00ooooooooooooo`00?_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ooo003ooooo
ooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00003oooooooo003oo`0000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00koo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooo`;oo`000_ooool2ool000;ooooo00?oo`00oooooooo
ool02_ooool2ool000;ooooo00?oo`00oooooooo00002?ooool2ool000;ooooo00Goo`00oooooooo
003oooooool00002ooooo`03ool00?l0003ooooo00Kooooo00Coo`00oooooooooooooooo0_oo0002
ooooo`03ool00?ooooooo`0000Sooooo0_oo0002ooooo`05ool00?ooooooo`00oooooooo00000_oo
ool00ooo003oooooooooo`0Qooooo`05ool00?oooooooooooooooooo00000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo
000Qooooo`03o`000?oooooooooo03_ooooo00Coo`00ooooooooooooo`009Oooool00ol0003ooooo
ooooo`0Sooooo`04ool00?ooooooooooool003kooooo00?o0000ooooooooool07oooool2o`0000Go
oooo00?o0000ooooooooool00oooool01?oo003ooooooooooooo0003ooooo`;oo`000_ooool2ool0
00;ooooo0_oo00000oooooooo`00ool00002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool02_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool000;o
oooo0_oo0002ooooo`03ool00?oooooooooo00[ooooo0_oo0002ooooo`03ool00?ooooooo`0000So
oooo00Woo`00ooooooooooooooooool00?ooooooo`00oooooooo00000_ooool00ooo003o0000oooo
o`06ooooo`04ool00?ooooooooooooooo`;oo`000_ooool00ooo003oooooool00008ooooo`09ool0
0?oooooooooooooooooo003oooooool00?ooooooo`0000;ooooo00?oo`00ooooooooool09Oooool0
0ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`06
ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo03_ooooo00Coo`00oooo
ooooooooo`009Oooool00ol0003oooooooooo`0Sooooo`04ool00?ooooooooooool003kooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co
o`00ooooooooooooo`000oooool2ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo0000
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00[oo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool00ooo003ooooooooo
o`0:ooooo`;oo`000_ooool00ooo003oooooool0000<ooooo`05ool00?ooooooo`00oooooooo0000
0_ooool00ooo003o0000ooooo`0:ooooo`;oo`000_ooool00ooo003oooooool00008ooooo`09ool0
0?oooooooooooooooooo003oooooool00?ooooooo`0000;ooooo00?oo`00ooooooooool09Oooool0
0ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000_ooool00ooo003oooooooooo`06
ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o0000??ooool01?oo003ooooooooooooo000U
ooooo`03o`000?oooooooooo02?ooooo00Coo`00ooooooooooooo`00?Oooool2o`0002Sooooo0_l0
0003ooooo`05ool00?oooooooooooooooooo00000oooool2ool000;ooooo0_oo0002ooooo`;oo`00
00?oooooool00?oo00000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`06ool00?ooooooo`00oooooooo003ooooo0_oo0002ooooo`;oo`000_ooool00ooo
003oooooooooo`0:ooooo`;oo`000_ooool00ooo003oooooool0000<ooooo`05ool00?ooooooo`00
oooooooo00000_ooool00ooo003o0000ooooo`0:ooooo`;oo`000_ooool00ooo003oooooool00008
ooooo`0;ool00?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo0000:oooool2ool0
00;ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`03ool00?oooooooooo00Gooooo0_l0000B
ooooo`008Oooool00ol0003oooooooooo`0kooooo`04ool00?ooooooooooool002Gooooo00?o0000
ooooooooool08oooool01?oo003ooooooooooooo000nooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo0_oo0002ooooo`;oo`00
0_ooool2ool00003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Koo`00oooooooo003oooooool00?ooool2ool0
00;ooooo00?oo`00ooooooooool02_ooool2ool000;ooooo00?oo`00oooooooo00003?ooool01Ooo
003oooooool00?ooooooo`0000;ooooo00?oo`00o`000?ooool02_ooool2ool000;ooooo00?oo`00
oooooooo00002?ooool02ooo003oooooooooooooooooo`00oooooooo003oooooool00?ooooooo`00
02oooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00Kooooo00?o0000
ooooooooool04?ooool0027ooooo00?o0000ooooooooool0>oooool01?oo003ooooooooooooo000U
ooooo`03o`000?oooooooooo02?ooooo00Coo`00ooooooooooooo`00?_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool0
0?ooooooooooooooo`;oo`000_ooool2ool00003oooooooo003oo`0000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo00Koo`00oooooooo
003oooooool00?ooool2ool000;ooooo00?oo`00ooooooooool02_ooool2ool000;ooooo00?oo`00
oooooooo00003?ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00o`000?ooool02_oo
ool2ool000;ooooo0_oo0009ooooo`0;ool00?oooooooooooooooooo003oooooool00?ooooooo`00
oooooooo0000;oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool01_oo
ool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0kooooo`04ool00?oooooo
ooooool002Gooooo00?o0000ooooooooool08oooool01?oo003ooooooooooooo000nooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`0000?oooooool00?oo00000_ooool2ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool0
00;ooooo00Coo`00oooooooo003oo`000_ooool00ooo003oooooooooo`0:ooooo`07ool00?oooooo
oooooooooooo003oooooool0000<ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003o
0000ooooo`0:ooooo`;oo`000_ooool2ool000gooooo00Ooo`00oooooooo003oooooool00?oooooo
o`0003?ooooo00Goo`00ooooooooooooooooool00008ooooo`03o`000?oooooooooo013ooooo000Q
ooooo`03o`000?oooooooooo03_ooooo00Coo`00ooooooooooooo`009Oooool00ol0003ooooooooo
o`0Sooooo`04ool00?ooooooooooool003kooooo00?o0000ooooooooool09_ooool2o`0000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooooooo`;oo`000_ooool2ool0
0003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002oooo
o`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`04ool00?ooooooo`00ool000;ooooo00?oo`00
ooooooooool02_ooool01?oo003oooooooooooooool2ool000gooooo00Woo`00oooooooo003ooooo
ool00?ooooooo`00ooooool000002oooool01?oo003oooooooooooooool2ool000gooooo00Ooo`00
oooooooo003oooooool00?ooooooo`0003?ooooo00Goo`00ooooooooooooooooool00007ooooo`;o
00004_ooool0027ooooo00?o0000ooooooooool0>oooool01?oo003ooooooooooooo000Uooooo`03
o`000?oooooooooo02?ooooo00Coo`00ooooooooooooo`00?_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool2ool00003oooooooo003oo`0000;ooooo0_oo0002ooooo`;oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Go
ooooool00?ooooooooooool0000<ooooo`04ool00?ooooooooooooooo`;oo`003Oooool02Ooo003o
ooooool00?ooooooo`00oooooooo003oooooo`00000;ooooo`04ool00?ooooooooooooooo`;oo`00
3Oooool01ooo003oooooool00?ooooooo`00oooooooo0000=oooool00ooo003oooooooooo`06oooo
o`03o`000?oooooooooo013ooooo000Qooooo`;o0000??ooool01?oo003ooooooooooooo000Uoooo
o`03o`000?oooooooooo02?ooooo00Coo`00ooooooooooooo`00?Oooool2o`0002Sooooo00?o0000
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001Oooooooo`00
ooooooooooooo`0000cooooo00Coo`00oooooooooooooooo0_oo000=ooooo`09ool00?ooooooo`00
oooooooo003oooooool00?oooooo000000_ooooo00Coo`00oooooooooooooooo0_oo000=ooooo`07
ool00?ooooooo`00oooooooo003oooooool0000gooooo`03ool00?oooooooooo00Kooooo00?o0000
ooooooooool04?ooool0027ooooo00?o0000ooooooooool0>oooool01?oo003ooooooooooooo000U
ooooo`03o`000?oooooooooo02?ooooo00Coo`00ooooooooooooo`00?_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;o
o`0000Goooooool00?ooooooooooool0000<ooooo`04ool00?ooooooooooooooo`;oo`003Oooool2
ool000;ooooo00Goo`00oooooooo003oooooo`00000;ooooo`04ool00?ooooooooooooooo`;oo`00
3Oooool01ooo003oooooool00?ooooooo`00oooooooo0000@?ooool00ol0003oooooooooo`0@oooo
o`008Oooool00ol0003oooooooooo`0kooooo`04ool00?ooooooooooool002Gooooo00?o0000oooo
ooooool08oooool01?oo003ooooooooooooo000nooooo`03o`000?oooooooooo02Kooooo0_l00007
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0_oo0002ooooo`;oo`000_ooool2ool00004oooooooo003oooooool000gooooo00Coo`00oooooooo
oooooooo0_oo000=ooooo`;oo`000_ooool01Ooo003oooooool00?oooooo000000_ooooo00Coo`00
oooooooooooooooo0_oo000=ooooo`;oo`000_ooool00ooo003oooooool0000oooooo`;o00004_oo
ool0027ooooo00?o0000ooooooooool0>oooool01?oo003ooooooooooooo000Uooooo`03o`000?oo
oooooooo02?ooooo00Coo`00ooooooooooooo`00?_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00Kooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000_ooool2ool000;ooooo00Coo`00oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo00001?ooooooo`00oooooooo
000=ooooo`04ool00?ooooooooooooooo`;oo`003Oooool2ool000;ooooo00Goo`00oooooooo003o
ooooo`00000;ooooo`04ool00?ooooooooooooooo`;oo`003Oooool2ool000;ooooo00?oo`00oooo
oooo0000@?ooool00ol0003oooooooooo`0@ooooo`005?ooool3o`0000Cooooo0_l00004ooooo`03
o`000?oooooooooo03_ooooo00Coo`00ooooooooooooo`009Oooool00ol0003oooooooooo`0Soooo
o`04ool00?ooooooooooool003kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`02ool000;ooooo00Co
o`00oooooooooooooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool2ool000;ooooo0_oo00001?ooooooo`00oooooooo000=ooooo`04ool00?oooooooooooooo
o`;oo`003Oooool2ool000;ooooo00Goo`00oooooooo003oooooo`00000;ooooo`04ool00?oooooo
ooooooooo`;oo`003Oooool2ool000;ooooo00?oo`00oooooooo0000@?ooool00ol0003ooooooooo
o`0@ooooo`004oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`0kooooo`04ool00?ooooooooooool002Gooooo00?o0000oooooooo
ool08oooool01?oo003ooooooooooooo000nooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool03_ooool01Ooo003oooooooooooooooooo`0000;ooooo0_oo0002ooooo`05ool00?oooooo
oooooooooooo00000oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo0_oo
0002ooooo`;oo`0000Coooooool00?ooooooo`003Oooool01?oo003oooooooooooooool2ool000go
oooo0_oo0002ooooo`05ool00?ooooooo`00ooooool000002oooool01?oo003oooooooooooooool2
ool000gooooo0_oo0002ooooo`03ool00?ooooooo`00043ooooo00?o0000ooooooooool04?ooool0
01?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo0_l0
000looooo`04ool00?ooooooooooool002Gooooo00?o0000ooooooooool08oooool01?oo003ooooo
oooooooo000looooo`?o0000:?ooool2o`0000oooooo00Goo`00ooooooooooooooooool00002oooo
o`;oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooooooo0_oo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`;oo`0000Coooooool00?ooooooo`00
3Oooool01?oo003oooooooooooooool2ool000gooooo0_oo0002ooooo`05ool00?ooooooo`00oooo
ool000002oooool01?oo003oooooooooooooool2ool000gooooo0_oo0002ooooo`03ool00?oooooo
o`0003oooooo0_l0000Booooo`005?ooool3o`0000?ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`0looooo`03ool00?ooooooo`0002Gooooo00?o0000ooooooooool08oooool0
1?oo003ooooooooooooo000nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04_oo
ool00ooo003oooooooooo`02ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00004
oooooooo003oooooool0017ooooo0_oo000=ooooo`;oo`000_ooool01Ooo003oooooool00?oooooo
000000_ooooo00Coo`00oooooooooooooooo0_oo000=ooooo`;oo`000_ooool00ooo003oooooool0
0010ooooo`03o`000?oooooooooo013ooooo000Cooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo03cooooo00?oo`00oooooooo0000
9Oooool00ol0003oooooooooo`0Sooooo`04ool00?ooooooooooool003kooooo00?o0000oooooooo
ool07_ooool5o`0000?ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`02ool000;o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool2
ool000;ooooo0_oo0002ooooo`;oo`000_ooool2ool00004oooooooo003oooooool0017ooooo0_oo
000=ooooo`09ool00?oooooooooooooooooo003oooooool00?oooooo000000_ooooo00Coo`00oooo
oooooooooooo0_oo000=ooooo`;oo`000_ooool00ooo003oooooool00010ooooo`03o`000?oooooo
oooo013ooooo000Cooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo03cooooo00?oo`00oooooooo00009Oooool00ol0003ooooooooo
o`0Tooooo`03ool00?ooooooo`0003kooooo00?o0000ooooooooool07oooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo01Gooooo0_oo0002ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooooooo0_oo0002
ooooo`;oo`000_ooool2ool00004oooooooo003oooooool0017ooooo0_oo000=ooooo`09ool00?oo
oooooooooooooooo003oooooool00?oooooo000000_ooooo00Goo`00ooooooooooooooooool0000>
ooooo`;oo`000_ooool2ool0047ooooo00?o0000ooooooooool04?ooool001Cooooo0ol00004oooo
o`;o00001?ooool00ol0003oooooooooo`0looooo`03ool00?ooooooo`0002Gooooo00?o0000oooo
ooooool09?ooool00ooo003oooooool0000nooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool00oooool3o`0001Gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo0_oo0002ooooo`;oo`00
0_ooool2ool00004oooooooo003oooooool0017ooooo0_oo000=ooooo`09ool00?oooooooooooooo
oooo003oooooool00?oooooo000000_ooooo00Goo`00ooooooooooooooooool0000>ooooo`;oo`00
0_ooool2ool0043ooooo0_l0000Booooo`008Oooool00ol0003oooooooooo`0looooo`03ool00?oo
ooooo`0002Gooooo00?o0000ooooooooool09?ooool00ooo003oooooool0000nooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00003ooooo`;oo`000_ooool2ool00004oooooooo003oooooool0017ooooo00?oo`00
ooooooooool04?ooool01Ooo003oooooool00?oooooo000000oooooo00?oo`00ooooooooool03?oo
ool2ool000;ooooo0_oo0011ooooo`03o`000?oooooooooo013ooooo000Qooooo`;o0000?Oooool0
0ooo003oooooool0000Uooooo`03o`000?oooooooooo02Cooooo00?oo`00oooooooo0000?Oooool2
o`00023ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01gooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003o
ooooooooooooool2ool000;ooooo0_oo00001?ooooooo`00oooooooo000Aooooo`03ool00?oooooo
oooo013ooooo0_oo0002ooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool03?ooool0
1?oo003oooooooooooooool2ool0047ooooo00?o0000ooooooooool04?ooool0027ooooo00?o0000
ooooooooool0??ooool00ooo003oooooool0000Uooooo`03o`000?oooooooooo02Cooooo00?oo`00
oooooooo0000?_ooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`0Mooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`;oo`0000Coooooool0
0?ooooooo`004Oooool00ooo003oooooooooo`0@ooooo`;oo`000_ooool00ol0003oooooooooo`0=
ooooo`03ool00?oooooooooo00cooooo00Coo`00oooooooooooooooo0_oo0011ooooo`03o`000?oo
oooooooo013ooooo000Qooooo`03o`000?oooooooooo03cooooo00?oo`00oooooooo00009Oooool0
0ol0003oooooooooo`0Tooooo`03ool00?ooooooo`0003kooooo00?o0000ooooooooool07oooool3
o`0000Cooooo0_l0000Rooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?ooooooo`00017o
oooo00?oo`00ooooooooool04?ooool2ool000;ooooo00?o0000ooooooooool03Oooool00ooo003o
ooooooooo`0<ooooo`04ool00?ooooooooooooooo`;oo`00@?ooool2o`0001;ooooo000Qooooo`03
o`000?oooooooooo03cooooo00?oo`00oooooooo00009Oooool00ol0003oooooooooo`0Tooooo`03
ool00?ooooooo`0003kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Qooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00002ooooo`03ool00?ooooooo`00017ooooo00?oo`00ooooooooool04?oo
ool2ool000;ooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`0<ooooo`04ool00?oo
ooooooooooooo`;oo`00@Oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003ooooooooo
o`0looooo`03ool00?ooooooo`0002Gooooo00?o0000ooooooooool09?ooool00ooo003oooooool0
000nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09Oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`06ool00?ooooooooooool0
0?ooooooo`004Oooool00ooo003oooooooooo`0@ooooo`;oo`000_ooool00ol0003oooooooooo`0=
ooooo`03ool00?oooooooooo00cooooo00Coo`00oooooooooooooooo0_oo0011ooooo`03o`000?oo
oooooooo013ooooo000Qooooo`03o`000?oooooooooo03cooooo00?oo`00oooooooo00009Oooool0
0ol0003oooooooooo`0Tooooo`03ool00?ooooooo`0003kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Uooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Koo`00ooooooooooooo`00oooooooo000Aooooo`03ool00?oooooooooo
013ooooo0_oo0002ooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool03?ooool01?oo
003oooooooooooooool2ool0047ooooo00?o0000ooooooooool04?ooool0027ooooo0_l0000moooo
o`03ool00?ooooooo`0002Gooooo00?o0000ooooooooool09?ooool00ooo003oooooool0000moooo
o`;o0000:?ooool2o`0002[ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000_ooool2ool001;ooooo00?oo`00ooooooooool04?ooool2ool000;ooooo00?o
0000ooooooooool03Oooool00ooo003oooooooooo`0@ooooo`;oo`00@?ooool2o`0001;ooooo000Q
ooooo`03o`000?oooooooooo03cooooo00?oo`00oooooooo00009Oooool00ol0003oooooooooo`0T
ooooo`03ool00?ooooooo`0003kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Y
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo
0_oo000Booooo`03ool00?oooooooooo013ooooo0_oo0002ooooo`03o`000?oooooooooo00gooooo
00?oo`00ooooooooool04?ooool2ool0047ooooo00?o0000ooooooooool04?ooool0027ooooo00?o
0000ooooooooool0??ooool00ooo003oooooool0000Uooooo`03o`000?oooooooooo02Cooooo00?o
o`00oooooooo0000?_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02gooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00;oo`004_ooool00ooo003ooooo
ooooo`0@ooooo`05ool00?ooooooooooooooool000003oooool00ooo003oooooooooo`0@ooooo`;o
o`00@Oooool00ol0003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0looooo`03ool0
0?ooooooo`0002Gooooo00?o0000ooooooooool09?ooool00ooo003oooooool0000nooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0;Oooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool00_oo000Booooo`03ool00?oooooooooo013ooooo00Goo`00oooooooo
ooooooooo`00000?ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0@?ooool00ol0
003oooooooooo`0@ooooo`008Oooool00ol0003oooooooooo`0looooo`03ool00?ooooooo`0002Go
oooo00?o0000ooooooooool09?ooool00ooo003oooooool0000nooooo`03o`000?oooooooooo02Ko
oooo0_l0000booooo`05ool00?oooooooooooooooooo00000_ooool2ool001;ooooo00?oo`00oooo
ooooool04?ooool01Ooo003ooooooooooooooooo000000oooooo00?oo`00ooooooooool04?ooool0
0ooo003oooooooooo`0oooooo`;o00004_ooool0027ooooo00?o0000ooooooooool0??ooool00ooo
003oooooool0000Uooooo`03o`000?oooooooooo02Cooooo00?oo`00oooooooo0000?_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo037ooooo00Goo`00ooooooooooooooooool00002
ooooo`;oo`004_ooool00ooo003oooooooooo`0@ooooo`05ool00?ooooooooooooooool000003ooo
ool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo043ooooo00?o0000ooooooooool04?oo
ool0027ooooo0_l0000mooooo`03ool00?ooooooo`0002Gooooo00?o0000ooooooooool09?ooool0
0ooo003oooooool0000mooooo`;o0000:?ooool00ol0003oooooooooo`0aooooo`05ool00?oooooo
oooooooooooo00000_ooool2ool002Gooooo00Goo`00ooooooooooooooooo`00000?ooooo`03ool0
0?oooooooooo013ooooo00?oo`00ooooooooool0@?ooool00ol0003oooooooooo`0@ooooo`008Ooo
ool00ol0003oooooooooo`0looooo`03ool00?ooooooo`0002Gooooo00?o0000ooooooooool09?oo
ool00ooo003oooooool0000nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=Ooo
ool00ooo003oooooooooo`02ool002Wooooo00?o0000ooooooooool08?ooool00ooo003ooooooooo
o`10ooooo`03o`000?oooooooooo013ooooo000Qooooo`03o`000?oooooooooo03cooooo0_oo000V
ooooo`03o`000?oooooooooo02Cooooo00?oo`00oooooooo0000?_ooool00ol0003oooooooooo`0V
ooooo`;o0000=_ooool00ooo003oooooooooo`02ool002Wooooo00?o0000ooooooooool08?ooool0
0ooo003oooooooooo`0oooooo`;o00004_ooool0027ooooo00?o0000ooooooooool0??ooool2ool0
02Kooooo00?o0000ooooooooool09?ooool2ool003oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0hooooo`;oo`00:Oooool00ol0003oooooooooo`0Pooooo`03ool00?oooooooooo
043ooooo00?o0000ooooooooool04?ooool000kooooo0ol00004ooooo`;o00001?ooool2o`0000Co
oooo00?o0000ooooooooool0??ooool2ool002Kooooo00?o0000ooooooooool09?ooool2ool003oo
oooo00?o0000ooooooooool07oooool3o`0000Cooooo00?o0000ooooooooool0>?ooool00ooo003o
ooooooooo`0Xooooo`03o`000?oooooooooo023ooooo00?oo`00ooooooooool0@?ooool00ol0003o
ooooooooo`0@ooooo`003oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0looooo`;oo`009_ooool00ol0
003oooooooooo`0Tooooo`;oo`00?oooool00ol0003oooooooooo`0Nooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo02Sooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0@ooooo`003oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool2o`0003kooooo00?o
o`00ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo03_ooooo0ol0
000Tooooo`04o`000?ooooooooooooooo`?o0000Hoooool00ol0003oooooooooo`1Rooooo`;o0000
4_ooool000oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool0?Oooool00ooo003oooooooooo`0Tooooo`03
o`000?oooooooooo02Gooooo00?oo`00ooooooooool0?Oooool00ol0003oooooooooo`0Pooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo000?ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Roooo
o`04o`000?ooooooooooooooolgo00004_ooool000kooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01kooooo00Go0000ooooooooooooooooo`00003Rooooo`003oooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool2o`0000Coooood?l0000Qooooo`?o0000hoooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {147.312, 0}} -> {-0.0551454, -0.0147182, \
0.00419541, 0.00419541}, {{13.125, 240.125}, {143.75, 3.5}} -> {-6.96551, \
-15.1756, 0.0508982, 0.827684}, {{262.812, 489.812}, {143.75, 3.5}} -> \
{-19.7812, -3.84012, 0.0515777, 0.0490995}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plot more than one period of the DTFT as a function of \
frequency\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Abs[X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-2.5\) 
            fs, 2.5  fs}, \ PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
        AspectRatio \[Rule] 1/3, PlotPoints \[Rule] 400, \ 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0190476 0.00793646 0.00315874 [
[.11905 -0.0125 -9 -9 ]
[.11905 -0.0125 9 0 ]
[.30952 -0.0125 -9 -9 ]
[.30952 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -6 -9 ]
[.69048 -0.0125 6 0 ]
[.88095 -0.0125 -6 -9 ]
[.88095 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -6 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .07111 -12 -4.5 ]
[-0.0125 .07111 0 4.5 ]
[-0.0125 .13429 -12 -4.5 ]
[-0.0125 .13429 0 4.5 ]
[-0.0125 .19746 -12 -4.5 ]
[-0.0125 .19746 0 4.5 ]
[-0.0125 .26064 -12 -4.5 ]
[-0.0125 .26064 0 4.5 ]
[-0.0125 .32381 -18 -4.5 ]
[-0.0125 .32381 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-20)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-10)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(10)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(20)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.15714 0 m
.15714 .00375 L
s
.19524 0 m
.19524 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.27143 0 m
.27143 .00375 L
s
.34762 0 m
.34762 .00375 L
s
.38571 0 m
.38571 .00375 L
s
.42381 0 m
.42381 .00375 L
s
.4619 0 m
.4619 .00375 L
s
.5381 0 m
.5381 .00375 L
s
.57619 0 m
.57619 .00375 L
s
.61429 0 m
.61429 .00375 L
s
.65238 0 m
.65238 .00375 L
s
.72857 0 m
.72857 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.80476 0 m
.80476 .00375 L
s
.84286 0 m
.84286 .00375 L
s
.08095 0 m
.08095 .00375 L
s
.04286 0 m
.04286 .00375 L
s
.00476 0 m
.00476 .00375 L
s
.91905 0 m
.91905 .00375 L
s
.95714 0 m
.95714 .00375 L
s
.99524 0 m
.99524 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(0)] -0.0125 .00794 1 0 Mshowa
0 .07111 m
.00625 .07111 L
s
[(20)] -0.0125 .07111 1 0 Mshowa
0 .13429 m
.00625 .13429 L
s
[(40)] -0.0125 .13429 1 0 Mshowa
0 .19746 m
.00625 .19746 L
s
[(60)] -0.0125 .19746 1 0 Mshowa
0 .26064 m
.00625 .26064 L
s
[(80)] -0.0125 .26064 1 0 Mshowa
0 .32381 m
.00625 .32381 L
s
[(100)] -0.0125 .32381 1 0 Mshowa
.125 Mabswid
0 .02373 m
.00375 .02373 L
s
0 .03952 m
.00375 .03952 L
s
0 .05532 m
.00375 .05532 L
s
0 .0869 m
.00375 .0869 L
s
0 .1027 m
.00375 .1027 L
s
0 .11849 m
.00375 .11849 L
s
0 .15008 m
.00375 .15008 L
s
0 .16587 m
.00375 .16587 L
s
0 .18167 m
.00375 .18167 L
s
0 .21325 m
.00375 .21325 L
s
0 .22905 m
.00375 .22905 L
s
0 .24484 m
.00375 .24484 L
s
0 .27643 m
.00375 .27643 L
s
0 .29222 m
.00375 .29222 L
s
0 .30802 m
.00375 .30802 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.11905 .32708 m
.11905 .33333 L
s
.30952 .32708 m
.30952 .33333 L
s
.5 .32708 m
.5 .33333 L
s
.69048 .32708 m
.69048 .33333 L
s
.88095 .32708 m
.88095 .33333 L
s
.125 Mabswid
.15714 .32958 m
.15714 .33333 L
s
.19524 .32958 m
.19524 .33333 L
s
.23333 .32958 m
.23333 .33333 L
s
.27143 .32958 m
.27143 .33333 L
s
.34762 .32958 m
.34762 .33333 L
s
.38571 .32958 m
.38571 .33333 L
s
.42381 .32958 m
.42381 .33333 L
s
.4619 .32958 m
.4619 .33333 L
s
.5381 .32958 m
.5381 .33333 L
s
.57619 .32958 m
.57619 .33333 L
s
.61429 .32958 m
.61429 .33333 L
s
.65238 .32958 m
.65238 .33333 L
s
.72857 .32958 m
.72857 .33333 L
s
.76667 .32958 m
.76667 .33333 L
s
.80476 .32958 m
.80476 .33333 L
s
.84286 .32958 m
.84286 .33333 L
s
.08095 .32958 m
.08095 .33333 L
s
.04286 .32958 m
.04286 .33333 L
s
.00476 .32958 m
.00476 .33333 L
s
.91905 .32958 m
.91905 .33333 L
s
.95714 .32958 m
.95714 .33333 L
s
.99524 .32958 m
.99524 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .07111 m
1 .07111 L
s
.99375 .13429 m
1 .13429 L
s
.99375 .19746 m
1 .19746 L
s
.99375 .26064 m
1 .26064 L
s
.99375 .32381 m
1 .32381 L
s
.125 Mabswid
.99625 .02373 m
1 .02373 L
s
.99625 .03952 m
1 .03952 L
s
.99625 .05532 m
1 .05532 L
s
.99625 .0869 m
1 .0869 L
s
.99625 .1027 m
1 .1027 L
s
.99625 .11849 m
1 .11849 L
s
.99625 .15008 m
1 .15008 L
s
.99625 .16587 m
1 .16587 L
s
.99625 .18167 m
1 .18167 L
s
.99625 .21325 m
1 .21325 L
s
.99625 .22905 m
1 .22905 L
s
.99625 .24484 m
1 .24484 L
s
.99625 .27643 m
1 .27643 L
s
.99625 .29222 m
1 .29222 L
s
.99625 .30802 m
1 .30802 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
.5 0 m
.5 .33333 L
s
1 0 0 r
.5 Mabswid
.02381 .00794 m
.02435 .01746 L
.02466 .02219 L
.02494 .02571 L
.02508 .02713 L
.02524 .02838 L
.02532 .02893 L
.0254 .02934 L
.02548 .02965 L
.02552 .02978 L
.02556 .02988 L
.02563 .03001 L
.0257 .03007 L
.02577 .03005 L
.02583 .02997 L
.02591 .02979 L
.02598 .02956 L
.02605 .02922 L
.02613 .02877 L
.0263 .02751 L
.02646 .026 L
.02682 .02153 L
.02713 .01672 L
.02729 .01391 L
.02746 .01079 L
.02754 .00931 L
.02762 .00798 L
.02769 .00924 L
.02777 .01062 L
.02805 .01564 L
.02837 .02081 L
.02867 .02486 L
.02894 .02766 L
.02909 .02881 L
.02923 .02957 L
.02931 .02986 L
.02938 .03005 L
.02946 .03018 L
.0295 .03022 L
.02954 .03022 L
.02962 .03016 L
.02966 .03009 L
.0297 .02999 L
.02978 .02975 L
.02986 .02941 L
.03001 .0285 L
.03017 .02719 L
.03046 .02396 L
.0308 .01898 L
.03112 .01356 L
Mistroke
.03127 .0108 L
.03135 .00943 L
.03142 .00817 L
.0315 .00917 L
.03154 .00994 L
.03158 .01075 L
.03173 .01347 L
.03207 .01935 L
.03239 .02403 L
.03267 .02722 L
.03283 .02857 L
.03297 .02951 L
.03305 .02991 L
.03313 .0302 L
.03317 .03031 L
.03321 .03041 L
.03325 .03049 L
.0333 .03053 L
.03337 .03054 L
.03344 .03046 L
.03352 .03029 L
.03356 .03017 L
.0336 .03001 L
.03376 .02922 L
.03384 .02869 L
.03392 .028 L
.0341 .02626 L
.03426 .02429 L
.03456 .01996 L
.03488 .01449 L
.03505 .01154 L
.03513 .01006 L
.0352 .00868 L
.03527 .00845 L
.03534 .00978 L
.03549 .01257 L
.03605 .02213 L
.03632 .02587 L
.03647 .02748 L
.03662 .02888 L
.03676 .02983 L
.03683 .03022 L
.0369 .03056 L
.03698 .0308 L
.03704 .03094 L
.0371 .03102 L
.03716 .03104 L
.03724 .03099 L
.03731 .03084 L
.03735 .03073 L
Mistroke
.0374 .03058 L
.03747 .03025 L
.03762 .02934 L
.03776 .02824 L
.03809 .02452 L
.0384 .01983 L
.0387 .01462 L
.03884 .01189 L
.03898 .00933 L
.03905 .008 L
.03909 .00874 L
.03913 .00954 L
.0393 .01275 L
.03959 .01813 L
.03987 .02269 L
.04016 .02675 L
.04031 .02833 L
.04044 .02957 L
.04056 .03046 L
.04063 .03084 L
.0407 .03117 L
.04077 .03144 L
.04084 .03162 L
.04091 .03172 L
.04099 .03174 L
.04106 .03168 L
.04113 .03153 L
.0412 .03131 L
.04126 .03104 L
.04142 .03012 L
.04158 .02871 L
.04189 .02516 L
.04249 .01516 L
.04265 .01197 L
.04275 .01017 L
.04279 .00928 L
.04283 .00845 L
.04287 .00819 L
.04291 .00902 L
.043 .01076 L
.04315 .01378 L
.04345 .01936 L
.04377 .02464 L
.04391 .02672 L
.04407 .02861 L
.0442 .02998 L
.04435 .03116 L
.04443 .03171 L
.04451 .0321 L
.04459 .0324 L
Mistroke
.04466 .03259 L
.04471 .03266 L
.04475 .03269 L
.04479 .0327 L
.04483 .03268 L
.04488 .03262 L
.04492 .03252 L
.04497 .03239 L
.04501 .03224 L
.04509 .0319 L
.04516 .03149 L
.04532 .03026 L
.04546 .02885 L
.04561 .02703 L
.04623 .01678 L
.0464 .01342 L
.04649 .01153 L
.04658 .00974 L
.04665 .0082 L
.04673 .00933 L
.04678 .01027 L
.04682 .01116 L
.0469 .01282 L
.04749 .02402 L
.04779 .02846 L
.04796 .03049 L
.04811 .03197 L
.04826 .03298 L
.04833 .03336 L
.04841 .03367 L
.04845 .03379 L
.04849 .03387 L
.04854 .03393 L
.04858 .03396 L
.04865 .03393 L
.04869 .03387 L
.04873 .03379 L
.0488 .03358 L
.04887 .03331 L
.04894 .03292 L
.04901 .03241 L
.04917 .03107 L
.04931 .0295 L
.04958 .02569 L
.04988 .02048 L
.05014 .01526 L
.05027 .01235 L
.05035 .01073 L
.05042 .0092 L
.05046 .00835 L
Mistroke
.0505 .00843 L
.05054 .00944 L
.05059 .01036 L
.05074 .01373 L
.05104 .02008 L
.05133 .02559 L
.0516 .02983 L
.05175 .03171 L
.05191 .03339 L
.05199 .03404 L
.05208 .03462 L
.05213 .03489 L
.05217 .0351 L
.05221 .03526 L
.05225 .03541 L
.05233 .03557 L
.0524 .03563 L
.05244 .03562 L
.05248 .03559 L
.05255 .03544 L
.05263 .03517 L
.0527 .03482 L
.05278 .03432 L
.05287 .03367 L
.05302 .03217 L
.05316 .03038 L
.05343 .02617 L
.05375 .02005 L
.05405 .01357 L
.05418 .0105 L
.05424 .00898 L
.0543 .0083 L
.05436 .00977 L
.05443 .01136 L
.05457 .01471 L
.05515 .02701 L
.05543 .03178 L
.05559 .03389 L
.05574 .0355 L
.05587 .03663 L
.05595 .03712 L
.05602 .03746 L
.05608 .03767 L
.05615 .03781 L
.05622 .03787 L
.05628 .03783 L
.05636 .03768 L
.0564 .03754 L
.05644 .03738 L
.05652 .03699 L
Mistroke
.0566 .03646 L
.05675 .03511 L
.05688 .03351 L
.05722 .02827 L
.05753 .02186 L
.05783 .01464 L
.05798 .01089 L
.05805 .00923 L
.05812 .00846 L
.05819 .01036 L
.05826 .01216 L
.05841 .01608 L
.05874 .024 L
.05902 .03004 L
.05931 .03525 L
.05944 .03695 L
.05957 .03847 L
.05964 .03919 L
.05971 .03974 L
.05978 .04016 L
.05985 .04052 L
.05992 .04079 L
.06 .04093 L
.06007 .04094 L
.06013 .04086 L
.0602 .04066 L
.06028 .04031 L
.06036 .03981 L
.06044 .0392 L
.06058 .03778 L
.0607 .03613 L
.06099 .03129 L
.06129 .02455 L
.06162 .01587 L
.06178 .01159 L
.06182 .01034 L
.06186 .00915 L
.06194 .00894 L
.06201 .01106 L
.06208 .013 L
.06223 .01735 L
.06278 .03174 L
.06309 .03808 L
.06323 .04048 L
.06337 .04231 L
.06352 .04394 L
.06361 .04456 L
.06365 .04481 L
.0637 .04503 L
.06377 .04528 L
Mistroke
.06385 .04538 L
.06389 .04538 L
.06393 .04533 L
.06401 .04512 L
.06408 .04479 L
.06416 .04429 L
.0643 .04302 L
.06446 .0409 L
.06461 .03842 L
.0649 .03216 L
.06521 .02385 L
.06548 .01563 L
.06556 .01314 L
.06563 .01074 L
.0657 .00857 L
.06577 .00969 L
.06584 .01229 L
.06593 .01506 L
.06608 .01998 L
.06636 .02917 L
.06671 .03878 L
.06685 .04236 L
.06702 .04573 L
.06715 .04799 L
.06729 .04991 L
.06737 .05074 L
.06744 .05134 L
.06751 .0518 L
.06758 .0521 L
.06766 .05227 L
.06773 .05227 L
.0678 .05213 L
.06787 .05182 L
.06795 .05131 L
.06804 .05055 L
.06819 .04863 L
.06833 .04626 L
.06848 .04304 L
.06876 .03561 L
.06902 .02742 L
.06929 .01734 L
.06937 .01416 L
.06945 .01074 L
.06953 .0081 L
.06957 .00979 L
.06961 .01138 L
.06991 .02375 L
.07047 .04497 L
.07079 .05442 L
.07094 .05796 L
Mistroke
.07108 .0606 L
.07116 .06178 L
.07124 .06285 L
.07133 .06367 L
.07137 .06401 L
.07142 .06426 L
.07146 .06442 L
.0715 .06452 L
.07157 .06455 L
.07165 .06436 L
.07169 .06414 L
.07173 .06387 L
.07286 .03208 L
.07317 .01668 L
.07325 .01266 L
.07329 .01042 L
.07333 .00827 L
.07337 .01016 L
.07342 .01252 L
.0735 .01717 L
.07408 .05 L
.07438 .06507 L
.0747 .07844 L
.07488 .08447 L
.07505 .08868 L
.07513 .09025 L
.07521 .09159 L
.07525 .09207 L
.0753 .09249 L
.07537 .093 L
.07545 .0932 L
.07551 .0931 L
.07555 .09293 L
.07559 .09264 L
.07567 .09186 L
.07574 .09082 L
.07581 .08939 L
.07595 .08596 L
.0761 .08057 L
.07625 .07416 L
.07658 .05471 L
.07688 .03182 L
.07704 .01784 L
.07708 .0136 L
.07713 .00951 L
.07717 .0101 L
.07721 .01422 L
.07751 .0468 L
.0778 .07966 L
.07891 .21247 L
Mistroke
.07949 .26908 L
.07981 .29377 L
.08011 .3108 L
.08028 .31738 L
.08036 .31991 L
.08043 .32183 L
.0805 .32321 L
.08057 .32432 L
.08065 .32504 L
.08069 .32527 L
.08072 .32538 L
.08076 .32538 L
.0808 .32526 L
.08085 .325 L
.08089 .32462 L
.08096 .32366 L
.08104 .3222 L
.08113 .31993 L
.08122 .31726 L
.08138 .31089 L
.08166 .29601 L
.08196 .27449 L
.08258 .21836 L
.08369 .1009 L
.08401 .06979 L
.0843 .04286 L
.08457 .02141 L
.08465 .01603 L
.08472 .01056 L
.0848 .01024 L
.08486 .01449 L
.08517 .03169 L
.08534 .03894 L
.08551 .04524 L
.08566 .04965 L
.08574 .05157 L
.08583 .05332 L
.08591 .05465 L
.08598 .05563 L
.08605 .0564 L
.08612 .05694 L
.08619 .0573 L
.08626 .05749 L
.08633 .05749 L
.0864 .05734 L
.08647 .05701 L
.08655 .05647 L
.08663 .05571 L
.0867 .05483 L
.087 .04992 L
Mistroke
.08732 .04269 L
.0879 .02674 L
.08815 .01943 L
.08843 .01169 L
.0885 .0097 L
.08855 .00861 L
.08858 .00824 L
.08866 .01011 L
.08873 .01183 L
.08905 .01877 L
.08937 .02434 L
.08955 .02679 L
.08971 .02859 L
.08986 .02978 L
.08999 .0306 L
.09007 .03094 L
.09014 .03117 L
.09022 .03133 L
.09026 .03138 L
.0903 .03141 L
.09034 .03141 L
.09038 .03138 L
.09046 .03128 L
.0905 .03119 L
.09054 .03108 L
.09063 .03076 L
.0907 .03044 L
.09077 .03001 L
.09093 .02892 L
.09124 .02589 L
.09154 .02211 L
.0921 .01316 L
.09225 .01044 L
.09229 .00964 L
.09233 .00888 L
.09241 .00843 L
.09248 .0098 L
.09255 .01106 L
.0927 .01395 L
.09335 .0261 L
.09363 .03063 L
.09379 .03281 L
.09394 .0346 L
.09407 .03601 L
.09415 .03663 L
.09422 .03721 L
.09429 .03761 L
.09436 .03797 L
.09442 .03822 L
.09448 .03838 L
Mistroke
.09456 .03848 L
.09464 .03847 L
.09468 .03841 L
.09472 .03831 L
.0948 .03802 L
.09487 .0376 L
.09495 .03708 L
.09508 .03578 L
.09524 .03364 L
.09539 .03111 L
.09573 .02331 L
.09601 .01458 L
.09609 .01171 L
.09617 .00884 L
.09624 .00972 L
.09631 .01277 L
.09686 .03822 L
.0981 .10654 L
.09871 .13625 L
.09901 .14782 L
.09929 .15617 L
.09944 .1598 L
.0996 .16274 L
.09969 .16389 L
.09977 .16473 L
.09981 .1651 L
.09985 .16539 L
.0999 .16564 L
.09995 .16579 L
.10002 .16588 L
.1001 .16576 L
.10016 .16549 L
.10024 .165 L
.10031 .16427 L
.1004 .16324 L
.10055 .16074 L
.1007 .15742 L
.10086 .15303 L
.10115 .14307 L
.10182 .11263 L
.10303 .04542 L
.10333 .02981 L
.10364 .0149 L
.10372 .01145 L
.10377 .00961 L
.10381 .00797 L
.10386 .00993 L
.1039 .01167 L
.10399 .01494 L
.10431 .02526 L
Mistroke
.10446 .02909 L
.10461 .03256 L
.10475 .03505 L
.10489 .0372 L
.10498 .03817 L
.10505 .03892 L
.10512 .03953 L
.10519 .03998 L
.10527 .04034 L
.10531 .04047 L
.10536 .04057 L
.1054 .04063 L
.10545 .04064 L
.10548 .04062 L
.10553 .04055 L
.1056 .04035 L
.10567 .04007 L
.10575 .03963 L
.10582 .0391 L
.10595 .03793 L
.1061 .03632 L
.10642 .03161 L
.10672 .02623 L
.10704 .01995 L
.10733 .01378 L
.1075 .01038 L
.10754 .00946 L
.10759 .0085 L
.10763 .00819 L
.10768 .00908 L
.10799 .01497 L
.1083 .02023 L
.1086 .02432 L
.10887 .02712 L
.10902 .02831 L
.10916 .02914 L
.10923 .02946 L
.10931 .02973 L
.10938 .02991 L
.10945 .03001 L
.10953 .03005 L
.10957 .03004 L
.10961 .03 L
.10969 .02987 L
.10973 .02976 L
.10977 .02963 L
.10986 .0293 L
.10993 .02891 L
.11011 .02775 L
.11026 .0264 L
Mistroke
.11042 .02466 L
.11099 .01627 L
.11115 .01331 L
.11131 .01033 L
.11138 .009 L
.11145 .00832 L
.11153 .00992 L
.1116 .01143 L
.11217 .02331 L
.1127 .03287 L
.11297 .03667 L
.11311 .03817 L
.11326 .03944 L
.11334 .03994 L
.11342 .04029 L
.11346 .04044 L
.1135 .04057 L
.11358 .04069 L
.11365 .04068 L
.11373 .04053 L
.1138 .0403 L
.11387 .03992 L
.11394 .03941 L
.11401 .03881 L
.11414 .03735 L
.11428 .03529 L
.11444 .03246 L
.11471 .02583 L
.11497 .01794 L
.11512 .01263 L
.11519 .00976 L
.11523 .00807 L
.11527 .00942 L
.11545 .0168 L
.1156 .02411 L
.1162 .05525 L
.11732 .11703 L
.11762 .13145 L
.11795 .14486 L
.11826 .15482 L
.11841 .15853 L
.11855 .16134 L
.11867 .1633 L
.11873 .16409 L
.1188 .1648 L
.11888 .16534 L
.11895 .16571 L
.11902 .16586 L
.11909 .16584 L
.11916 .16563 L
Mistroke
.11923 .16524 L
.1193 .16473 L
.11937 .16402 L
.11952 .16181 L
.11966 .15904 L
.11994 .1516 L
.12025 .14094 L
.12079 .11603 L
.12203 .04747 L
.12233 .03202 L
.12264 .01705 L
.12274 .01296 L
.12278 .01102 L
.12282 .00928 L
.1229 .00975 L
.12294 .01136 L
.12299 .01301 L
.12331 .02371 L
.12361 .03137 L
.12375 .03422 L
.12388 .03642 L
.12396 .03747 L
.12404 .03843 L
.12411 .03909 L
.12419 .03969 L
.12427 .04018 L
.12432 .04038 L
.12436 .04052 L
.12444 .04067 L
.12448 .0407 L
.12452 .04069 L
.12459 .04057 L
.12467 .04035 L
.12473 .04005 L
.1248 .03964 L
.12496 .03837 L
.12511 .03682 L
.12538 .03317 L
.12566 .02838 L
.12626 .01637 L
.12643 .01276 L
.12652 .01099 L
.1266 .00938 L
.12667 .00795 L
.12674 .00946 L
.1269 .01257 L
.12746 .02193 L
.12762 .02397 L
.12778 .02586 L
.12793 .02723 L
Mistroke
.12808 .02843 L
.12815 .02886 L
.12823 .02925 L
.12829 .02952 L
.12836 .02975 L
.12844 .02994 L
.12852 .03003 L
.12859 .03004 L
.12866 .02999 L
.12872 .02989 L
.12878 .02974 L
.12884 .02953 L
.12891 .02923 L
.12906 .02843 L
.12919 .02746 L
.12947 .02457 L
.12978 .02044 L
.13004 .01613 L
.13033 .01085 L
.13041 .00918 L
.13046 .00832 L
.1305 .0085 L
.13054 .00932 L
.13059 .0102 L
.13067 .0118 L
.13098 .01839 L
.13158 .02992 L
.13187 .03464 L
.13204 .03675 L
.13219 .03836 L
.13227 .03909 L
.13235 .03965 L
.13244 .04013 L
.13249 .04032 L
.13253 .04047 L
.13261 .04062 L
.13269 .04064 L
.13273 .04059 L
.13277 .04051 L
.13281 .04038 L
.13285 .04022 L
.13292 .03985 L
.133 .0393 L
.13316 .03776 L
.1333 .03578 L
.13344 .03344 L
.13374 .02644 L
.1339 .02186 L
.13406 .01629 L
.13415 .01319 L
Mistroke
.13419 .0116 L
.13423 .01011 L
.1343 .00865 L
.13438 .0119 L
.13467 .02522 L
.13534 .06033 L
.13597 .09577 L
.13655 .12621 L
.1371 .14874 L
.13726 .15369 L
.1374 .15765 L
.13754 .16055 L
.13768 .16304 L
.13776 .16405 L
.13784 .16479 L
.13791 .16537 L
.13796 .1656 L
.13799 .16575 L
.13806 .16588 L
.13814 .1658 L
.13821 .16554 L
.13828 .16512 L
.13832 .16478 L
.13837 .16435 L
.13845 .1634 L
.13859 .161 L
.13877 .15722 L
.13893 .15286 L
.13951 .13059 L
.14006 .1031 L
.1407 .06744 L
.1413 .03493 L
.14159 .02131 L
.14174 .01448 L
.14182 .01132 L
.14189 .00853 L
.14197 .01023 L
.142 .0117 L
.14205 .0132 L
.14222 .01899 L
.14253 .02737 L
.14266 .03028 L
.1428 .03288 L
.14293 .03472 L
.14306 .03628 L
.14314 .03703 L
.14322 .03758 L
.14329 .03798 L
.14337 .03828 L
.14343 .03843 L
Mistroke
.1435 .03849 L
.14357 .03845 L
.14364 .03831 L
.14368 .03818 L
.14372 .03803 L
.1438 .03767 L
.14396 .03654 L
.1441 .03522 L
.14425 .03348 L
.14492 .02305 L
.14522 .01733 L
.14539 .01412 L
.14555 .01112 L
.14561 .00982 L
.14568 .00859 L
.14575 .00869 L
.14582 .00995 L
.14613 .01534 L
.14671 .02411 L
.147 .02744 L
.14717 .02894 L
.14732 .03002 L
.14746 .03072 L
.14753 .03098 L
.1476 .0312 L
.14767 .03134 L
.14775 .03141 L
.14783 .03139 L
.1479 .03129 L
.14797 .03113 L
.14803 .03092 L
.1481 .03061 L
.14817 .0302 L
.1483 .02932 L
.14843 .02807 L
.14875 .02406 L
.14905 .01884 L
.14932 .013 L
.14945 .0097 L
.14953 .00814 L
.14961 .01005 L
.14992 .01865 L
.15021 .02699 L
.15052 .03591 L
.15086 .04483 L
.15101 .04818 L
.15117 .05132 L
.1513 .0536 L
.15145 .05553 L
.15154 .05639 L
Mistroke
.15158 .05669 L
.15162 .05697 L
.1517 .05734 L
.15174 .05745 L
.15178 .05751 L
.15185 .05746 L
.15192 .05724 L
.152 .05677 L
.15207 .0561 L
.15214 .05526 L
.15221 .05433 L
.15235 .05163 L
.15248 .04833 L
.15261 .04452 L
.15289 .03336 L
.15303 .02611 L
.15319 .01725 L
.15327 .01231 L
.15334 .00851 L
.15341 .01315 L
.15348 .01842 L
.15376 .04021 L
.15439 .09939 L
.15499 .16343 L
.15565 .23247 L
.15595 .25961 L
.15627 .28477 L
.15657 .30365 L
.1567 .31029 L
.15684 .31611 L
.15692 .31877 L
.157 .32082 L
.15707 .32251 L
.15714 .32374 L
.15722 .32474 L
.15726 .32509 L
.1573 .32531 L
.15738 .32537 L
.15742 .32522 L
.15746 .32496 L
.1575 .32458 L
.15754 .32403 L
.15762 .32267 L
.1577 .3209 L
.15777 .31887 L
.15793 .31289 L
.15811 .30448 L
.15843 .28342 L
.15873 .25855 L
.1594 .18773 L
Mistroke
.16003 .11192 L
.16033 .07514 L
.16061 .04329 L
.16075 .02871 L
.16082 .02129 L
.16089 .01365 L
.16096 .00871 L
.16103 .01563 L
.16116 .02722 L
.16147 .05153 L
.16175 .06915 L
.1619 .07652 L
.16206 .08304 L
.16215 .08592 L
.16223 .08816 L
.16231 .09001 L
.16239 .09137 L
.16246 .09229 L
.16254 .09293 L
.16261 .09319 L
.16268 .09316 L
.16275 .09285 L
.16283 .09218 L
.16287 .09171 L
.16291 .09112 L
.16299 .08982 L
.16418 .04062 L
.16451 .02216 L
.16467 .01286 L
.16472 .01034 L
.16477 .00822 L
.16481 .01074 L
.16486 .01302 L
.16518 .0295 L
.16548 .04265 L
.16575 .05212 L
.16589 .056 L
.16604 .05941 L
.16612 .06098 L
.1662 .06218 L
.16627 .06309 L
.16631 .06348 L
.16635 .06382 L
.16643 .06427 L
.16649 .0645 L
.16657 .06456 L
.16664 .0644 L
.16672 .06402 L
.16676 .06371 L
.1668 .06338 L
Mistroke
.16695 .06165 L
.16703 .06036 L
.16712 .05873 L
.16727 .05515 L
.16787 .03604 L
.16815 .0252 L
.1683 .01899 L
.16845 .01306 L
.16853 .00972 L
.16857 .00803 L
.16862 .00976 L
.16877 .01593 L
.16907 .02722 L
.16939 .03734 L
.16969 .04473 L
.16984 .04755 L
.17 .04988 L
.17009 .05081 L
.17013 .05123 L
.17018 .05155 L
.17026 .05199 L
.1703 .05214 L
.17034 .05224 L
.17042 .05229 L
.17046 .05224 L
.1705 .05215 L
.17054 .052 L
.17058 .05182 L
.17066 .05126 L
.17074 .05063 L
.17081 .04976 L
.17096 .04776 L
.17113 .04476 L
.17131 .04085 L
.17163 .0323 L
.17196 .0221 L
.17212 .0168 L
.17226 .01186 L
.17233 .00952 L
.1724 .00852 L
.17247 .01077 L
.17254 .01321 L
.17284 .02258 L
.17314 .03093 L
.1733 .03471 L
.17347 .03816 L
.17362 .04066 L
.17378 .04283 L
.17385 .04357 L
.17393 .04423 L
Mistroke
.174 .04472 L
.17407 .04505 L
.17414 .04528 L
.17421 .04538 L
.17428 .04536 L
.17434 .04523 L
.17442 .04495 L
.17446 .04474 L
.1745 .0445 L
.17464 .04329 L
.17477 .04183 L
.17491 .03983 L
.17519 .03463 L
.17547 .02791 L
.17579 .0195 L
.17593 .01542 L
.17601 .01315 L
.17608 .01101 L
.17615 .00919 L
.17621 .00863 L
.17629 .01079 L
.17636 .01274 L
.17668 .02144 L
.17702 .02939 L
.1773 .03476 L
.17747 .03711 L
.17762 .03882 L
.17769 .0395 L
.17777 .04008 L
.17784 .04046 L
.17792 .04075 L
.17796 .04086 L
.178 .04092 L
.17805 .04095 L
.17809 .04093 L
.17817 .0408 L
.17821 .04067 L
.17825 .04052 L
.17833 .04011 L
.1784 .0396 L
.17854 .03836 L
.17869 .03659 L
.17885 .03423 L
.17943 .02235 L
.17971 .01542 L
.17983 .01228 L
.1799 .01061 L
.17996 .00884 L
.18004 .00899 L
.18011 .01078 L
Mistroke
.18025 .01427 L
.18055 .02152 L
.18082 .02706 L
.1811 .03195 L
.18126 .0341 L
.1814 .03567 L
.18154 .03678 L
.18161 .0372 L
.18169 .03754 L
.18174 .03768 L
.18178 .03778 L
.18185 .03787 L
.1819 .03786 L
.18194 .03782 L
.18198 .03774 L
.18203 .03762 L
.18211 .03731 L
.18218 .03692 L
.18234 .03565 L
.1825 .03399 L
.18264 .03207 L
.18297 .02658 L
.18325 .0208 L
.18357 .0137 L
.1837 .01053 L
.18378 .00875 L
.18384 .00877 L
.18391 .0102 L
.18397 .01176 L
.18411 .01486 L
.18468 .02653 L
.18483 .02898 L
.185 .03125 L
.18514 .03288 L
.18522 .03362 L
.1853 .03421 L
.18537 .03469 L
.18544 .03504 L
.18551 .03534 L
.18559 .03554 L
.18566 .03562 L
.18573 .03562 L
.1858 .03552 L
.18586 .03535 L
.18594 .03504 L
.18602 .03458 L
.18618 .0334 L
.18633 .03186 L
.18647 .03013 L
.18712 .01876 L
Mistroke
.1874 .01272 L
.18748 .01093 L
.18756 .00922 L
.18763 .00818 L
.18771 .00984 L
.18825 .02117 L
.18857 .02651 L
.18874 .02892 L
.1889 .03078 L
.18903 .03205 L
.18918 .03306 L
.18926 .03345 L
.18931 .03362 L
.18935 .03375 L
.18942 .0339 L
.1895 .03396 L
.18957 .03392 L
.18961 .03386 L
.18965 .03376 L
.18973 .03351 L
.1898 .03319 L
.18988 .0327 L
.18996 .03215 L
.19013 .03059 L
.19044 .0267 L
.19073 .02193 L
.19099 .01703 L
.19126 .01141 L
.19134 .00971 L
.19142 .0081 L
.19149 .00922 L
.19156 .01077 L
.19185 .01643 L
.19212 .02154 L
.19242 .02618 L
.19259 .02836 L
.19274 .02999 L
.19282 .03064 L
.1929 .03125 L
.19297 .0317 L
.19305 .0321 L
.19313 .0324 L
.1932 .03259 L
.19324 .03266 L
.19329 .03269 L
.19333 .0327 L
.19337 .03268 L
.19341 .03262 L
.19345 .03254 L
.1935 .03242 L
Mistroke
.19354 .03227 L
.19362 .03192 L
.19371 .03143 L
.19386 .03026 L
.19402 .02863 L
.19432 .02482 L
.19489 .01492 L
.19505 .0117 L
.19513 .01009 L
.1952 .0086 L
.19527 .00863 L
.19534 .01006 L
.1955 .01305 L
.19578 .0183 L
.19607 .02319 L
.19634 .02691 L
.1966 .0295 L
.19673 .03046 L
.1968 .03085 L
.19687 .0312 L
.19695 .03148 L
.19702 .03166 L
.19709 .03174 L
.19716 .03174 L
.19723 .03166 L
.1973 .03151 L
.19738 .03126 L
.19746 .03089 L
.19762 .02983 L
.19777 .02852 L
.19804 .0254 L
.19833 .02103 L
.19859 .01659 L
.19887 .01138 L
.19895 .00982 L
.19899 .00897 L
.19904 .00817 L
.19911 .00912 L
.19915 .00987 L
.19919 .01066 L
.19949 .01628 L
.19976 .02086 L
.20005 .02509 L
.20023 .02716 L
.20039 .02871 L
.20055 .02984 L
.20063 .03027 L
.20067 .03046 L
.20071 .03064 L
.20079 .03087 L
Mistroke
.20086 .03099 L
.20094 .03104 L
.20098 .03103 L
.20102 .03099 L
.2011 .03085 L
.20117 .03065 L
.20124 .03034 L
.20132 .02996 L
.20145 .02908 L
.20159 .02785 L
.20185 .02492 L
.20215 .02061 L
.20242 .01602 L
.20258 .01317 L
.20266 .01157 L
.20274 .01005 L
.20281 .00876 L
.20289 .00852 L
.20293 .00927 L
.20297 .01006 L
.20305 .01148 L
.20335 .01693 L
.20363 .0215 L
.20393 .02551 L
.2042 .02824 L
.20428 .02882 L
.20436 .02935 L
.20443 .02973 L
.20451 .03007 L
.20455 .03021 L
.20459 .03033 L
.20463 .03043 L
.20467 .03049 L
.20472 .03053 L
.20476 .03054 L
.20483 .0305 L
.20487 .03044 L
.20491 .03036 L
.20498 .03015 L
.20506 .02984 L
.20514 .0294 L
.2053 .02834 L
.20543 .02709 L
.20576 .02329 L
.2061 .01814 L
.20639 .01304 L
.20653 .01041 L
.2066 .00925 L
.20667 .00795 L
.20674 .00929 L
Mistroke
.20682 .01074 L
.20699 .01376 L
.20728 .01873 L
.20755 .02283 L
.20769 .02469 L
.20785 .02639 L
.20798 .02765 L
.20812 .02875 L
.20819 .02914 L
.20826 .0295 L
.20832 .02976 L
.20838 .02996 L
.20845 .03013 L
.20849 .03018 L
.20854 .03022 L
.20858 .03022 L
.20862 .0302 L
.2087 .03009 L
.20877 .0299 L
.20884 .02965 L
.20892 .02931 L
.209 .02885 L
.20918 .02747 L
.20935 .02578 L
.20966 .02173 L
.20995 .01731 L
.21025 .01211 L
.21032 .01074 L
.2104 .00927 L
.21045 .00842 L
.21049 .00823 L
.21053 .00901 L
.21057 .00974 L
.21088 .01512 L
.21146 .02399 L
.21175 .02718 L
.21192 .0285 L
.21199 .02896 L
.21208 .02938 L
.21215 .02966 L
.21221 .02986 L
.21228 .02999 L
.21236 .03006 L
.21242 .03005 L
.21249 .02998 L
.21255 .02986 L
.21261 .02967 L
.21268 .02939 L
.21276 .02901 L
.21291 .02799 L
Mistroke
.21305 .02675 L
.21319 .02536 L
.21381 .01634 L
.21396 .01375 L
.21412 .01091 L
.21419 .00972 L
.21426 .00844 L
.21434 .00885 L
.21441 .01017 L
.21494 .01934 L
.21524 .02365 L
.21539 .02541 L
.21552 .0268 L
.21566 .02795 L
.2158 .02893 L
.21588 .02935 L
.21595 .02965 L
.21602 .02986 L
.2161 .03 L
.21617 .03006 L
.21622 .03006 L
.21625 .03004 L
.21633 .02993 L
.2164 .02975 L
.21644 .02961 L
.21648 .02944 L
.21656 .02907 L
.21673 .02794 L
.21689 .02647 L
.21707 .0245 L
.21739 .02005 L
.21771 .01493 L
.21786 .01224 L
.218 .00973 L
.21807 .00849 L
.21814 .00874 L
.21821 .01002 L
.21827 .01119 L
.21857 .01641 L
.21887 .02116 L
.2192 .02548 L
.21935 .02707 L
.21951 .02844 L
.21959 .02894 L
.21967 .02938 L
.21974 .02972 L
.21981 .02995 L
.21989 .03013 L
.21993 .03019 L
.21997 .03022 L
Mistroke
.22005 .03021 L
.22012 .03011 L
.22017 .03003 L
.22021 .0299 L
.2203 .02956 L
.22039 .02913 L
.22047 .02863 L
.22077 .02597 L
.22093 .02397 L
.22109 .02183 L
.2214 .01692 L
.22154 .01457 L
.22169 .01195 L
.22176 .01066 L
.22183 .00929 L
.2219 .00811 L
.22197 .00905 L
.22223 .01383 L
.2228 .02311 L
.22295 .02508 L
.22312 .02691 L
.22326 .02824 L
.22334 .02885 L
.22342 .02934 L
.22349 .02973 L
.22356 .03003 L
.22363 .03028 L
.22371 .03046 L
.22378 .03053 L
.22385 .03054 L
.22392 .03047 L
.22398 .03034 L
.22406 .0301 L
.22414 .02973 L
.2243 .02878 L
.22445 .02753 L
.22459 .02611 L
.22524 .01665 L
.22552 .01156 L
.2256 .01005 L
.22568 .0086 L
.22575 .00858 L
.22582 .00999 L
.22637 .01974 L
.22668 .02439 L
.22685 .02651 L
.22702 .02816 L
.22715 .02929 L
.2273 .0302 L
.22738 .03056 L
Mistroke
.22742 .03071 L
.22746 .03083 L
.22753 .03097 L
.22761 .03104 L
.22769 .03101 L
.22773 .03097 L
.22777 .03089 L
.22785 .03067 L
.22792 .0304 L
.228 .02997 L
.22808 .02949 L
.22825 .02811 L
.22855 .02464 L
.22884 .02034 L
.2291 .01589 L
.22938 .01074 L
.22942 .00999 L
.22946 .00917 L
.22954 .00819 L
.22961 .00963 L
.22968 .01096 L
.22996 .01623 L
.23024 .02113 L
.23055 .0256 L
.2307 .0274 L
.23083 .02884 L
.23096 .02989 L
.2311 .03079 L
.23117 .03117 L
.23125 .03144 L
.23132 .03163 L
.23137 .0317 L
.23141 .03174 L
.23147 .03174 L
.23154 .03166 L
.23162 .03149 L
.23169 .03125 L
.23178 .03085 L
.23186 .03037 L
.232 .02922 L
.23217 .02762 L
.23234 .02549 L
.23264 .02101 L
.23296 .01529 L
.23311 .0123 L
.23319 .0108 L
.23326 .00939 L
.23332 .00811 L
.23339 .00912 L
.23354 .01199 L
Mistroke
.23414 .02303 L
.23446 .02754 L
.23463 .02954 L
.2348 .03101 L
.23487 .03149 L
.23495 .03192 L
.23502 .03224 L
.23508 .03246 L
.23516 .03263 L
.2352 .03268 L
.23524 .0327 L
.23532 .03267 L
.23539 .03254 L
.23547 .03232 L
.23555 .03199 L
.23562 .03158 L
.23569 .03113 L
.23586 .02971 L
.23602 .02797 L
.23655 .0198 L
.23683 .01445 L
.23697 .01147 L
.23705 .00981 L
.23713 .00825 L
.23721 .00928 L
.23725 .01016 L
.23729 .0111 L
.23745 .01427 L
.23775 .02018 L
.23802 .02489 L
.23831 .02909 L
.23849 .03105 L
.23857 .03176 L
.23865 .03244 L
.23873 .03293 L
.23881 .03336 L
.23885 .03354 L
.23889 .03369 L
.23893 .03379 L
.23897 .03388 L
.23904 .03396 L
.23912 .03394 L
.23919 .03383 L
.23926 .03364 L
.23934 .03333 L
.23942 .03287 L
.23957 .03173 L
.23972 .03033 L
.23987 .02848 L
.24014 .02431 L
Mistroke
.24044 .01878 L
.24077 .01195 L
.24085 .01008 L
.2409 .00905 L
.24095 .00808 L
.24099 .0087 L
.24103 .00969 L
.24111 .0114 L
.24143 .01833 L
.24174 .02443 L
.24204 .0292 L
.24231 .03264 L
.24247 .03403 L
.24254 .03451 L
.24261 .03493 L
.24265 .03511 L
.24269 .03528 L
.24276 .0355 L
.24281 .03558 L
.24285 .03562 L
.24289 .03563 L
.24293 .03561 L
.24301 .03549 L
.24305 .03537 L
.24309 .03524 L
.24316 .03491 L
.24324 .03446 L
.2434 .03313 L
.24358 .03116 L
.2439 .02631 L
.24421 .02033 L
.24451 .01393 L
.24465 .01064 L
.24472 .009 L
.24478 .0084 L
.24486 .01015 L
.24494 .01206 L
.24508 .01536 L
.24538 .02203 L
.2457 .02848 L
.24586 .03101 L
.24602 .03335 L
.24616 .03501 L
.24632 .03641 L
.2464 .03699 L
.24648 .0374 L
.24653 .03757 L
.24657 .03769 L
.24661 .0378 L
.24666 .03785 L
Mistroke
.24674 .03786 L
.24681 .03775 L
.24689 .03751 L
.24693 .03734 L
.24697 .03712 L
.24712 .03607 L
.24721 .03529 L
.24728 .03446 L
.24746 .03215 L
.24762 .02954 L
.24792 .02376 L
.24824 .01637 L
.24839 .0126 L
.24847 .0105 L
.24855 .00852 L
.24861 .00906 L
.24869 .01088 L
.24883 .01473 L
.2494 .02807 L
.2497 .03378 L
.24986 .0362 L
.25002 .03827 L
.25017 .03961 L
.25025 .04017 L
.25033 .04056 L
.2504 .0408 L
.25047 .04092 L
.25054 .04094 L
.25062 .04084 L
.25069 .04063 L
.25075 .04034 L
.25082 .0399 L
.25089 .03938 L
.25102 .03819 L
.25115 .03653 L
.25145 .03149 L
.25173 .02544 L
.25201 .01829 L
.25217 .01402 L
.25224 .01187 L
.25231 .00984 L
.25238 .00794 L
.25245 .00997 L
.2526 .01427 L
.25286 .02164 L
.25314 .02907 L
.25345 .03595 L
.25363 .03918 L
.25379 .0416 L
.25394 .04338 L
Mistroke
.25402 .04408 L
.2541 .04467 L
.25418 .04507 L
.25425 .04529 L
.25429 .04536 L
.25433 .04539 L
.25438 .04537 L
.25442 .04531 L
.25449 .04509 L
.25456 .04476 L
.25464 .04423 L
.25472 .04357 L
.25486 .042 L
.25499 .04012 L
.25528 .03448 L
.2556 .02639 L
.25589 .01774 L
.25605 .01257 L
.25609 .01113 L
.25614 .00959 L
.25618 .00827 L
.25622 .00906 L
.2563 .01169 L
.25639 .01452 L
.25654 .01959 L
.25715 .03801 L
.25732 .04209 L
.2575 .04577 L
.25765 .04835 L
.25773 .04946 L
.25782 .05044 L
.25789 .05112 L
.25793 .05142 L
.25797 .0517 L
.25805 .05205 L
.25811 .05224 L
.25819 .05229 L
.25826 .05218 L
.25832 .05195 L
.25839 .05156 L
.25847 .05096 L
.25855 .0501 L
.25872 .04772 L
.25888 .04478 L
.25903 .04141 L
.25933 .03291 L
.25965 .02156 L
.2598 .01583 L
.25988 .01259 L
.25996 .00949 L
Mistroke
.26003 .00932 L
.26011 .01251 L
.26025 .0181 L
.26082 .04069 L
.26111 .04995 L
.26136 .05673 L
.2615 .05967 L
.26164 .06186 L
.26171 .06274 L
.26178 .06349 L
.26182 .0638 L
.26186 .06409 L
.26194 .06443 L
.26198 .06453 L
.26202 .06457 L
.26209 .06447 L
.26213 .06432 L
.26217 .06412 L
.26221 .06384 L
.26226 .06346 L
.26234 .06257 L
.26242 .06148 L
.26256 .05884 L
.26272 .05515 L
.26288 .05031 L
.26317 .0394 L
.26352 .0234 L
.26367 .01559 L
.26375 .01132 L
.26379 .00913 L
.26383 .00919 L
.26391 .01355 L
.26398 .01768 L
.26412 .02566 L
.2644 .0413 L
.26472 .05828 L
.26501 .07193 L
.26527 .08172 L
.2654 .08569 L
.26554 .08907 L
.26562 .09047 L
.26568 .0915 L
.26575 .0923 L
.26582 .09283 L
.26589 .09316 L
.26596 .09318 L
.26603 .0929 L
.26607 .09263 L
.26611 .09223 L
.26619 .09121 L
Mistroke
.26626 .08994 L
.26643 .08588 L
.26657 .08093 L
.26672 .07424 L
.26702 .05748 L
.26728 .03797 L
.26743 .02515 L
.26752 .01767 L
.26759 .01039 L
.26763 .00939 L
.26768 .01366 L
.26777 .02297 L
.26793 .04011 L
.26854 .11124 L
.26912 .18122 L
.26973 .24801 L
.27005 .27653 L
.27022 .28936 L
.27041 .30117 L
.27057 .31002 L
.27073 .31642 L
.27087 .32096 L
.27095 .32265 L
.27099 .32343 L
.27103 .32403 L
.27111 .32491 L
.27115 .3252 L
.27119 .32536 L
.27126 .32533 L
.2713 .32514 L
.27134 .32485 L
.27142 .32401 L
.27148 .32292 L
.27156 .32127 L
.27163 .31933 L
.27179 .31378 L
.27194 .30713 L
.27227 .28709 L
.27283 .24078 L
.27343 .1802 L
.27405 .11367 L
.27437 .08044 L
.27472 .04838 L
.27502 .02359 L
.2751 .01743 L
.27515 .01416 L
.27519 .01115 L
.27523 .00843 L
.27527 .01033 L
.27535 .01517 L
Mistroke
.27565 .03168 L
.2758 .03824 L
.27593 .04337 L
.27606 .04757 L
.2762 .05127 L
.27628 .05292 L
.27636 .05421 L
.27642 .05523 L
.2765 .05612 L
.27654 .05653 L
.27658 .05684 L
.27666 .05727 L
.27673 .05748 L
.2768 .0575 L
.27688 .05731 L
.27696 .05695 L
.277 .05666 L
.27704 .05634 L
.27712 .05547 L
.27729 .05331 L
.27744 .05073 L
.27777 .04325 L
.27839 .02628 L
.27867 .01826 L
.27881 .01416 L
.27889 .01199 L
.27897 .01001 L
.27903 .0083 L
.2791 .00934 L
.27918 .01125 L
.27925 .01293 L
.27951 .01856 L
.27982 .02396 L
.27998 .02623 L
.28015 .02818 L
.2803 .02951 L
.28038 .03007 L
.28046 .03056 L
.28054 .03091 L
.28061 .03115 L
.28068 .03131 L
.28075 .03139 L
.28083 .0314 L
.28087 .03138 L
.28091 .03133 L
.28098 .03118 L
.28105 .03095 L
.28112 .03068 L
.28118 .03037 L
.28133 .02949 L
Mistroke
.28163 .02688 L
.28194 .02307 L
.28222 .019 L
.28252 .01409 L
.28264 .01193 L
.28277 .00954 L
.28285 .00814 L
.28292 .00903 L
.28298 .01028 L
.28305 .0116 L
.28366 .0232 L
.28401 .02908 L
.28433 .03361 L
.28447 .03525 L
.28461 .03652 L
.28468 .0371 L
.28477 .03762 L
.28484 .03799 L
.28491 .03825 L
.28498 .03843 L
.28505 .03849 L
.28513 .03844 L
.28518 .03836 L
.28522 .03825 L
.28526 .03809 L
.2853 .03791 L
.28538 .03739 L
.28546 .03678 L
.28554 .03598 L
.28568 .03419 L
.28583 .03175 L
.2861 .02596 L
.28642 .01687 L
.2865 .01421 L
.28657 .01156 L
.28664 .00907 L
.28671 .00962 L
.28677 .01221 L
.28684 .01504 L
.28696 .02036 L
.28723 .03323 L
.28781 .06385 L
.28842 .09804 L
.289 .12782 L
.28952 .14889 L
.28966 .15337 L
.28981 .15744 L
.28995 .16056 L
.29008 .16281 L
.29016 .1638 L
Mistroke
.29024 .16466 L
.29032 .1653 L
.29036 .16555 L
.2904 .16572 L
.29048 .16587 L
.29054 .16583 L
.29062 .16557 L
.2907 .16511 L
.29076 .16453 L
.29084 .16373 L
.29096 .16183 L
.2911 .15916 L
.29125 .15545 L
.29156 .14555 L
.2919 .13184 L
.29251 .10114 L
.29371 .03427 L
.29401 .01998 L
.29409 .01616 L
.29417 .01268 L
.29424 .00967 L
.29432 .00934 L
.29436 .01096 L
.29441 .01269 L
.2945 .01604 L
.29466 .02154 L
.29482 .02602 L
.29498 .03023 L
.29515 .03364 L
.2953 .03619 L
.29544 .03807 L
.29552 .03883 L
.2956 .03949 L
.29567 .04 L
.29575 .04034 L
.29582 .04054 L
.29589 .04064 L
.29595 .04063 L
.29602 .04053 L
.29608 .04033 L
.29615 .04002 L
.29624 .03952 L
.29632 .03895 L
.29649 .03725 L
.29681 .03296 L
.29741 .02203 L
.29769 .01627 L
.29784 .01306 L
.29792 .01149 L
.29799 .01004 L
Mistroke
.29806 .0087 L
.29813 .00858 L
.29821 .01012 L
.29828 .01149 L
.29854 .01626 L
.29884 .02118 L
.299 .0234 L
.29917 .02543 L
.29932 .02692 L
.29949 .02824 L
.29956 .02871 L
.29964 .02913 L
.29971 .02946 L
.29978 .0297 L
.29985 .02989 L
.29989 .02996 L
.29993 .03001 L
.29997 .03004 L
.30002 .03005 L
.30009 .02999 L
.30017 .02986 L
.30023 .02968 L
.30031 .0294 L
.30039 .02903 L
.30057 .02787 L
.30074 .02639 L
.30105 .02269 L
.30163 .01322 L
.30179 .01018 L
.30183 .00941 L
.30187 .00859 L
.30192 .0082 L
.30196 .00907 L
.30226 .01533 L
.30287 .0276 L
.30319 .03311 L
.30337 .03564 L
.30354 .03763 L
.30369 .0391 L
.30378 .03973 L
.30386 .04018 L
.30393 .04045 L
.30401 .04064 L
.30409 .0407 L
.30416 .04063 L
.30424 .04044 L
.30431 .04013 L
.30437 .03975 L
.30444 .03922 L
.3046 .0376 L
Mistroke
.30474 .03555 L
.30501 .03042 L
.30529 .02307 L
.30543 .01844 L
.30559 .01279 L
.30566 .01012 L
.30573 .00873 L
.3058 .01165 L
.30587 .01439 L
.30651 .04586 L
.30711 .07936 L
.30767 .11033 L
.30826 .13845 L
.30857 .1499 L
.30874 .15484 L
.30891 .15918 L
.30908 .16225 L
.30922 .16424 L
.3093 .16493 L
.30937 .16546 L
.30945 .16576 L
.30951 .16587 L
.30959 .16579 L
.30963 .16566 L
.30967 .16546 L
.30975 .16494 L
.30982 .16426 L
.30991 .16323 L
.30998 .16208 L
.31015 .15875 L
.31046 .15033 L
.31075 .13975 L
.31187 .08314 L
.31246 .0504 L
.31278 .03353 L
.31307 .01909 L
.3132 .0133 L
.31327 .01058 L
.31333 .00813 L
.3134 .01045 L
.31347 .01328 L
.3136 .01793 L
.3139 .02709 L
.31418 .03344 L
.31433 .03599 L
.31449 .03808 L
.31457 .03892 L
.31465 .03955 L
.31473 .04008 L
.31478 .04031 L
Mistroke
.31482 .04047 L
.3149 .04065 L
.31497 .0407 L
.31504 .04063 L
.31508 .04054 L
.31513 .04041 L
.3152 .0401 L
.31528 .03965 L
.31542 .03856 L
.31555 .03717 L
.3157 .03533 L
.316 .03072 L
.31654 .02048 L
.31685 .01387 L
.31701 .01063 L
.31708 .00922 L
.31715 .00818 L
.31722 .00953 L
.31729 .01077 L
.31742 .01341 L
.31772 .01852 L
.31803 .02313 L
.31832 .02651 L
.31849 .02791 L
.31857 .02852 L
.31866 .02905 L
.31875 .02944 L
.31883 .02972 L
.3189 .02991 L
.31898 .03001 L
.31905 .03005 L
.31912 .03001 L
.31919 .0299 L
.31926 .02974 L
.31933 .02948 L
.31942 .02911 L
.31957 .0282 L
.31972 .02694 L
.31989 .02527 L
.32019 .02145 L
.32044 .01747 L
.32072 .01256 L
.32079 .0111 L
.32087 .00953 L
.32094 .00817 L
.32102 .00922 L
.32109 .01067 L
.32116 .01222 L
.3213 .01505 L
.32192 .02747 L
Mistroke
.32224 .03304 L
.32242 .03558 L
.32258 .03756 L
.32273 .03893 L
.3228 .03949 L
.32289 .03998 L
.32293 .0402 L
.32297 .04036 L
.32301 .04049 L
.32306 .04058 L
.32313 .04064 L
.32318 .04063 L
.32322 .04057 L
.32329 .04039 L
.32336 .04007 L
.32343 .03968 L
.3235 .03915 L
.32365 .03753 L
.3238 .03546 L
.3241 .02937 L
.32443 .02008 L
.32458 .01491 L
.32466 .01185 L
.32474 .00884 L
.32481 .00971 L
.32488 .01268 L
.32503 .01934 L
.32614 .07894 L
.32675 .11255 L
.32707 .12847 L
.32742 .14304 L
.32774 .15406 L
.3279 .15809 L
.32804 .16109 L
.32819 .1634 L
.32826 .16431 L
.32834 .16505 L
.32841 .16551 L
.32848 .16577 L
.32855 .16588 L
.32862 .16579 L
.3287 .1655 L
.32874 .16524 L
.32878 .16495 L
.32886 .16418 L
.32894 .16311 L
.3291 .16051 L
.32924 .15742 L
.32956 .14784 L
.3299 .13448 L
Mistroke
.33111 .07091 L
.33169 .0396 L
.332 .02407 L
.33216 .01709 L
.33223 .01418 L
.3323 .01109 L
.33237 .00832 L
.33244 .01005 L
.33258 .01516 L
.33288 .0243 L
.33313 .03022 L
.33328 .03284 L
.33341 .03477 L
.33356 .03651 L
.33364 .03723 L
.33372 .03776 L
.3338 .03811 L
.33386 .03834 L
.33394 .03847 L
.33402 .03848 L
.3341 .03837 L
.33414 .03825 L
.33418 .03811 L
.33426 .03775 L
.33433 .0373 L
.3345 .03598 L
.33468 .03406 L
.33499 .0299 L
.33531 .02454 L
.33561 .01897 L
.33589 .01366 L
.33603 .011 L
.3361 .00961 L
.33618 .00813 L
.33625 .00914 L
.33632 .0104 L
.33646 .0128 L
.33675 .01778 L
.33706 .02253 L
.33736 .02621 L
.33749 .02755 L
.33763 .02882 L
.33776 .02974 L
.33789 .03051 L
.33796 .03084 L
.33803 .03108 L
.3381 .03125 L
.33816 .03136 L
.33823 .03141 L
.33831 .03138 L
Mistroke
.33838 .03129 L
.33844 .03114 L
.33851 .03089 L
.33859 .03054 L
.33875 .02954 L
.3389 .02818 L
.33906 .02629 L
.33936 .02181 L
.33966 .01599 L
.33981 .01268 L
.33987 .01114 L
.33994 .0094 L
.34001 .00808 L
.34006 .00962 L
.3402 .0131 L
.34047 .02081 L
.3411 .03861 L
.3414 .04634 L
.34155 .04957 L
.34169 .05212 L
.34181 .05407 L
.34195 .05573 L
.34202 .05643 L
.34209 .05693 L
.34215 .05726 L
.34222 .05747 L
.34229 .05751 L
.34237 .05736 L
.34244 .05704 L
.3425 .05658 L
.34257 .05583 L
.34266 .05477 L
.3428 .05212 L
.34294 .04872 L
.3431 .04406 L
.34337 .03296 L
.34353 .02493 L
.34362 .02006 L
.3437 .01522 L
.34377 .01085 L
.34384 .00993 L
.34388 .01283 L
.34392 .01564 L
.34399 .02108 L
.34526 .14118 L
.34636 .25408 L
.34666 .27896 L
.34699 .30057 L
.34715 .30882 L
.3473 .31519 L
Mistroke
.34743 .31964 L
.3475 .3216 L
.34758 .32307 L
.34764 .32416 L
.34772 .32496 L
.34776 .32522 L
.3478 .32537 L
.34788 .32531 L
.34796 .32479 L
.34803 .3239 L
.34807 .3232 L
.34811 .32245 L
.3482 .32037 L
.34834 .31579 L
.34849 .30918 L
.34877 .29303 L
.34909 .26855 L
.34943 .2366 L
.35004 .16837 L
.3506 .0996 L
.35092 .06267 L
.35107 .04528 L
.35121 .02979 L
.35135 .01604 L
.35142 .00866 L
.35149 .01369 L
.35179 .03987 L
.35204 .05808 L
.35231 .07383 L
.35247 .08053 L
.35261 .0855 L
.35276 .0894 L
.35284 .09098 L
.35292 .09205 L
.35299 .09273 L
.35305 .09309 L
.35313 .0932 L
.3532 .093 L
.35327 .09256 L
.35333 .09192 L
.3534 .091 L
.35347 .08973 L
.35362 .08627 L
.35379 .08128 L
.35413 .06797 L
.35472 .03691 L
.35488 .02827 L
.35504 .01887 L
.35512 .01459 L
.35516 .01226 L
Mistroke
.3552 .0101 L
.35527 .00955 L
.35534 .01364 L
.3559 .04064 L
.35622 .05207 L
.35637 .05628 L
.35651 .05943 L
.35667 .06213 L
.35676 .06316 L
.3568 .06358 L
.35685 .06394 L
.35689 .06422 L
.35693 .0644 L
.35697 .06451 L
.35701 .06456 L
.35709 .0645 L
.35716 .0642 L
.35724 .06368 L
.35732 .06299 L
.3574 .06202 L
.35748 .06075 L
.35778 .05442 L
.35805 .04667 L
.35834 .03638 L
.35865 .02409 L
.35882 .01736 L
.35891 .01368 L
.35895 .01189 L
.35899 .01026 L
.35906 .00861 L
.35914 .01177 L
.35931 .01831 L
.3596 .02892 L
.35989 .03803 L
.36005 .04219 L
.3602 .04548 L
.36034 .04797 L
.36047 .04976 L
.36053 .05052 L
.36061 .0512 L
.36068 .05173 L
.36076 .05208 L
.36083 .05227 L
.36091 .05228 L
.36099 .05211 L
.36103 .05194 L
.36107 .05172 L
.36115 .05119 L
.36123 .0504 L
.36141 .0482 L
Mistroke
.36156 .04565 L
.36172 .04233 L
.36201 .03501 L
.36231 .0261 L
.36262 .01577 L
.3627 .0131 L
.36279 .01023 L
.36284 .00859 L
.36288 .00878 L
.36293 .01028 L
.36297 .01169 L
.36329 .02182 L
.36357 .02972 L
.36387 .03666 L
.36404 .03983 L
.3642 .04211 L
.36427 .04301 L
.36435 .04382 L
.36443 .04443 L
.3645 .04486 L
.36458 .04517 L
.36465 .04534 L
.36472 .04539 L
.36476 .04535 L
.3648 .04528 L
.36486 .04508 L
.36493 .04474 L
.36501 .04426 L
.36507 .04369 L
.36523 .04197 L
.36538 .0399 L
.3657 .03374 L
.36602 .0261 L
.36636 .01679 L
.36652 .01205 L
.36656 .01092 L
.36661 .00972 L
.36668 .00831 L
.36675 .01022 L
.36682 .0123 L
.36697 .01652 L
.36752 .02996 L
.36768 .03303 L
.36783 .03552 L
.36796 .0374 L
.36811 .03898 L
.36819 .03969 L
.36827 .04019 L
.36835 .04057 L
.36842 .04081 L
Mistroke
.36846 .04089 L
.3685 .04094 L
.36858 .04092 L
.36862 .04085 L
.36866 .04075 L
.36871 .0406 L
.36875 .04039 L
.36883 .03994 L
.36892 .0393 L
.36907 .03777 L
.36922 .03584 L
.36936 .0337 L
.36994 .02162 L
.37022 .01466 L
.37035 .01112 L
.37042 .00938 L
.37048 .00806 L
.37055 .00992 L
.37063 .01189 L
.37079 .01597 L
.37108 .02264 L
.37139 .02891 L
.37156 .03174 L
.37172 .03394 L
.37186 .03547 L
.37201 .03671 L
.37209 .03721 L
.37214 .03741 L
.37217 .03756 L
.37225 .03776 L
.37232 .03786 L
.37239 .03785 L
.37245 .03776 L
.37252 .03757 L
.37259 .03726 L
.37267 .03685 L
.37274 .03631 L
.37288 .03507 L
.37303 .03332 L
.37319 .03104 L
.37348 .02601 L
.37382 .01886 L
.37397 .01546 L
.37413 .0116 L
.37421 .00984 L
.37425 .00886 L
.37429 .00794 L
.37436 .00972 L
.37443 .01134 L
.37475 .0185 L
Mistroke
.37509 .0254 L
.37526 .02825 L
.37541 .03047 L
.37555 .03213 L
.3757 .03358 L
.37578 .03422 L
.37585 .0347 L
.37592 .03507 L
.37599 .03536 L
.37607 .03555 L
.37611 .03561 L
.37615 .03563 L
.37623 .0356 L
.3763 .03547 L
.37634 .03535 L
.37638 .0352 L
.37645 .03484 L
.37654 .03434 L
.37663 .03365 L
.37692 .03043 L
.37724 .02564 L
.37779 .01459 L
.37794 .01131 L
.37803 .00948 L
.3781 .00811 L
.37818 .00972 L
.37825 .01144 L
.37839 .0144 L
.37873 .02121 L
.37905 .0266 L
.37932 .03023 L
.37948 .03176 L
.37962 .03282 L
.3797 .03327 L
.37977 .03359 L
.37981 .03371 L
.37985 .03382 L
.3799 .03391 L
.37994 .03395 L
.38002 .03395 L
.38009 .03386 L
.38016 .03366 L
.3802 .03352 L
.38025 .03334 L
.38033 .03288 L
.38041 .03233 L
.38056 .03103 L
.3809 .02686 L
.38119 .0221 L
.38151 .01606 L
Mistroke
.38165 .01318 L
.38173 .01157 L
.3818 .01003 L
.38187 .00859 L
.38195 .00885 L
.38202 .01026 L
.38208 .01157 L
.38241 .01809 L
.38271 .02332 L
.38302 .02783 L
.38317 .02945 L
.38332 .03082 L
.3834 .03138 L
.38348 .03189 L
.38356 .03224 L
.38363 .03248 L
.38368 .03259 L
.38372 .03265 L
.38379 .0327 L
.38384 .03268 L
.38388 .03264 L
.38392 .03256 L
.38397 .03244 L
.38404 .03219 L
.38411 .03184 L
.38426 .03086 L
.3844 .02963 L
.38453 .02824 L
.38514 .01903 L
.38542 .01387 L
.38555 .01122 L
.38561 .01004 L
.38567 .00875 L
.38574 .00851 L
.38582 .00998 L
.38597 .01303 L
.38624 .0181 L
.38656 .02331 L
.38685 .02729 L
.38698 .02867 L
.38712 .02986 L
.3872 .03043 L
.38727 .03085 L
.38734 .03117 L
.38741 .03145 L
.38749 .03164 L
.38753 .03171 L
.38757 .03174 L
.38765 .03174 L
.38772 .03164 L
Mistroke
.38777 .03154 L
.38781 .0314 L
.3879 .03106 L
.38798 .03061 L
.38806 .03011 L
.38836 .02737 L
.3885 .02554 L
.38867 .02323 L
.38898 .01812 L
.38928 .01266 L
.38941 .01019 L
.38948 .00883 L
.38954 .00833 L
.38962 .00986 L
.3897 .01123 L
.38984 .01388 L
.39044 .02387 L
.3906 .026 L
.39078 .02789 L
.39093 .02917 L
.39101 .02976 L
.39109 .0302 L
.39116 .03054 L
.39124 .0308 L
.39132 .03097 L
.39136 .03102 L
.39141 .03104 L
.39148 .03101 L
.39155 .03091 L
.39162 .03071 L
.3917 .03041 L
.39177 .03008 L
.39184 .02965 L
.39197 .02869 L
.39226 .02568 L
.39258 .02127 L
.39292 .01563 L
.39306 .01312 L
.39321 .01035 L
.39325 .00953 L
.39329 .00875 L
.39337 .0086 L
.39344 .00997 L
.39352 .01146 L
.39414 .02192 L
.3943 .02424 L
.39448 .02637 L
.39465 .028 L
.3948 .02916 L
.39488 .02961 L
Mistroke
.39496 .02999 L
.39504 .03027 L
.39509 .03039 L
.39513 .03047 L
.39521 .03054 L
.39528 .03052 L
.39532 .03048 L
.39536 .03041 L
.39544 .03021 L
.39551 .02995 L
.39559 .02959 L
.39574 .02859 L
.39588 .02737 L
.39602 .02598 L
.39661 .01752 L
.39676 .01483 L
.39693 .01183 L
.39701 .01035 L
.39709 .00894 L
.39716 .0082 L
.39723 .00957 L
.39776 .0189 L
.39806 .02333 L
.39821 .02517 L
.39835 .02663 L
.39848 .02783 L
.39862 .02888 L
.3987 .02933 L
.39877 .02967 L
.39884 .02991 L
.39892 .0301 L
.39896 .03017 L
.399 .03021 L
.39904 .03022 L
.39908 .03021 L
.39916 .03012 L
.3992 .03003 L
.39924 .02992 L
.39932 .02965 L
.39939 .02933 L
.39954 .02837 L
.3997 .027 L
.39985 .02544 L
.40019 .02096 L
.40049 .01621 L
.40065 .01337 L
.40081 .01057 L
.40088 .00929 L
.40095 .00796 L
.401 .00874 L
Mistroke
.40104 .00946 L
.40111 .01085 L
.40139 .01576 L
.40193 .02398 L
.40224 .02729 L
.40233 .02799 L
.40241 .02862 L
.40249 .02907 L
.40257 .02947 L
.40265 .02975 L
.40272 .02993 L
.40279 .03004 L
.40286 .03007 L
.40294 .03002 L
.40301 .02989 L
.40309 .02965 L
.40318 .0293 L
.40332 .02847 L
.40347 .02725 L
.40375 .0243 L
.40404 .0203 L
.40436 .01514 L
.4045 .01267 L
.40457 .01135 L
.40465 .00993 L
.40472 .00868 L
.4048 .00856 L
.40486 .00981 L
.40493 .01097 L
.40545 .01976 L
.40573 .02382 L
.40601 .02686 L
.40616 .02814 L
.40624 .02869 L
.40632 .02917 L
.4064 .02953 L
.40647 .02978 L
.40654 .02995 L
.40661 .03004 L
.40668 .03007 L
.40672 .03004 L
.40676 .03 L
.40684 .02984 L
.40688 .02972 L
.40692 .02958 L
.40707 .02885 L
.40721 .02787 L
.40737 .02641 L
.40752 .02477 L
.40786 .02014 L
Mistroke
.40814 .0156 L
.40829 .01303 L
.40844 .01025 L
.40851 .00905 L
.40858 .0081 L
.40866 .00951 L
.40873 .01081 L
.40899 .01543 L
.40932 .02085 L
.40964 .02508 L
.40992 .02791 L
.41 .0285 L
.41008 .02903 L
.41016 .02944 L
.41023 .02975 L
.4103 .02998 L
.41034 .03008 L
.41038 .03015 L
.41045 .03022 L
.41053 .03021 L
.41059 .03013 L
.41067 .02996 L
.41074 .02973 L
.4108 .02946 L
.41094 .02864 L
.4111 .02741 L
.41141 .024 L
.41168 .02015 L
.41198 .01528 L
.41211 .01289 L
.41225 .01028 L
.41231 .00919 L
.41238 .00802 L
.41245 .00914 L
.41251 .01034 L
.41313 .02093 L
.4134 .02466 L
.41369 .02781 L
.41377 .02851 L
.41386 .02915 L
.41394 .02961 L
.41403 .03 L
.41407 .03017 L
.41411 .0303 L
.41415 .03039 L
.41419 .03047 L
.41427 .03054 L
.41431 .03054 L
.41435 .03052 L
.41443 .03041 L
Mistroke
.4145 .03022 L
.41457 .02997 L
.41464 .02963 L
.4148 .0286 L
.41495 .02731 L
.41523 .02413 L
.41553 .01975 L
.41579 .01535 L
.41593 .01288 L
.41607 .01016 L
.41612 .00933 L
.41616 .00855 L
.41624 .00879 L
.41631 .01016 L
.41639 .01163 L
.41672 .01761 L
.41703 .02252 L
.41731 .02629 L
.41745 .02779 L
.41759 .02897 L
.41766 .02951 L
.41774 .03001 L
.41781 .03038 L
.41788 .03065 L
.41792 .03078 L
.41796 .03089 L
.41804 .03101 L
.41808 .03104 L
.41813 .03104 L
.41816 .03102 L
.41821 .03096 L
.41828 .0308 L
.41832 .03067 L
.41836 .03052 L
.41851 .02978 L
.41859 .02924 L
.41867 .02857 L
.41882 .02713 L
.41916 .02282 L
.41948 .01764 L
.41962 .01512 L
.41977 .01226 L
.41985 .01088 L
.41992 .00939 L
.42 .00798 L
.42006 .00918 L
.42034 .01444 L
.42063 .01967 L
.42095 .02458 L
.42109 .02647 L
Mistroke
.42124 .02818 L
.42138 .02949 L
.42152 .03045 L
.42164 .03112 L
.42171 .03139 L
.42177 .03157 L
.42184 .0317 L
.42191 .03175 L
.42198 .03171 L
.42205 .03161 L
.42212 .03142 L
.42219 .03113 L
.42226 .03082 L
.42233 .0304 L
.42248 .0292 L
.42263 .02777 L
.42289 .02445 L
.42317 .02004 L
.42351 .01394 L
.42367 .01073 L
.42374 .0093 L
.42382 .00816 L
.42389 .00958 L
.42396 .0109 L
.4241 .01378 L
.42441 .01954 L
.42471 .02449 L
.42487 .02672 L
.42504 .02876 L
.4252 .03035 L
.42534 .03145 L
.42542 .03187 L
.42549 .03222 L
.42556 .03247 L
.42563 .03261 L
.42569 .03269 L
.42576 .03269 L
.42583 .03262 L
.42589 .03249 L
.42596 .03227 L
.42603 .03193 L
.42617 .03108 L
.42632 .02986 L
.42647 .02822 L
.42674 .02448 L
.42731 .01431 L
.42746 .01115 L
.42755 .0094 L
.42763 .00811 L
.42769 .00951 L
Mistroke
.42777 .01101 L
.42792 .01414 L
.4282 .01964 L
.42849 .02482 L
.42876 .02878 L
.42902 .03156 L
.42916 .03267 L
.42924 .03314 L
.42931 .03348 L
.42939 .03375 L
.42944 .03386 L
.42948 .03392 L
.42955 .03396 L
.42959 .03394 L
.42964 .03389 L
.42968 .03381 L
.42972 .03369 L
.4298 .03338 L
.42989 .03294 L
.42998 .0323 L
.43015 .0308 L
.4303 .029 L
.43089 .01944 L
.43119 .01312 L
.43135 .00975 L
.43139 .00882 L
.43143 .00806 L
.43148 .00901 L
.43152 .00988 L
.43184 .01702 L
.43215 .0231 L
.43243 .02802 L
.43258 .03021 L
.43274 .03217 L
.4329 .03368 L
.43304 .03469 L
.43311 .03505 L
.43318 .03534 L
.43325 .03553 L
.43332 .03562 L
.43338 .03563 L
.43344 .03557 L
.43351 .03542 L
.43358 .03517 L
.43366 .0348 L
.43373 .03436 L
.43386 .03328 L
.434 .03178 L
.43414 .03007 L
.43444 .02517 L
Mistroke
.43477 .01875 L
.43491 .01565 L
.43506 .01212 L
.43513 .0106 L
.43519 .00896 L
.43526 .00847 L
.43532 .00988 L
.43559 .01629 L
.43617 .02826 L
.43646 .03286 L
.43661 .03466 L
.43677 .03621 L
.43684 .03673 L
.43691 .03714 L
.43698 .0375 L
.43705 .03772 L
.43712 .03784 L
.43718 .03787 L
.43725 .03781 L
.43732 .03765 L
.43736 .03751 L
.43741 .03733 L
.43749 .0369 L
.43757 .03631 L
.43766 .0355 L
.43783 .03364 L
.43798 .03147 L
.43857 .01973 L
.43888 .01234 L
.43896 .01023 L
.439 .00906 L
.43905 .00797 L
.43912 .00985 L
.4392 .01199 L
.4398 .02652 L
.44008 .03208 L
.44034 .03629 L
.44048 .03808 L
.44056 .03886 L
.44064 .03956 L
.44072 .04008 L
.44078 .04045 L
.44085 .04072 L
.44092 .04088 L
.44099 .04095 L
.44106 .0409 L
.44113 .04074 L
.4412 .04049 L
.44127 .04008 L
.44135 .0395 L
Mistroke
.4415 .03806 L
.44166 .03605 L
.44183 .03338 L
.44212 .02736 L
.44238 .0212 L
.44265 .01379 L
.44273 .01163 L
.44277 .01044 L
.44281 .00933 L
.44288 .00852 L
.44295 .01069 L
.44323 .01879 L
.44354 .027 L
.44387 .03473 L
.44402 .0377 L
.44418 .04038 L
.44432 .04227 L
.44439 .04313 L
.44446 .04383 L
.44453 .04437 L
.44461 .04483 L
.44468 .04513 L
.44474 .04531 L
.4448 .04539 L
.44486 .04536 L
.44493 .04522 L
.445 .04498 L
.44507 .04459 L
.44514 .04404 L
.44528 .0427 L
.44542 .04076 L
.44558 .03806 L
.44619 .02324 L
.44633 .01888 L
.44648 .01401 L
.44655 .01196 L
.44661 .00973 L
.44669 .00861 L
.44676 .01095 L
.44707 .02145 L
.44742 .03214 L
.44773 .04047 L
.44788 .04388 L
.44802 .04653 L
.44815 .04866 L
.44829 .05044 L
.44837 .05118 L
.44845 .05169 L
.44852 .05204 L
.44859 .05225 L
Mistroke
.44867 .05229 L
.44871 .05224 L
.44875 .05215 L
.44882 .05184 L
.44889 .0514 L
.44897 .05069 L
.44905 .04986 L
.44922 .04734 L
.44939 .0441 L
.44954 .04037 L
.44984 .03182 L
.45015 .02082 L
.45031 .01443 L
.45036 .0127 L
.45041 .01081 L
.45045 .009 L
.45049 .00855 L
.45057 .01173 L
.45065 .01511 L
.4508 .02109 L
.45108 .03248 L
.4514 .0442 L
.4517 .05335 L
.45196 .05923 L
.4521 .06164 L
.45216 .06249 L
.45223 .06324 L
.45231 .06387 L
.45237 .06428 L
.45242 .06444 L
.45246 .06453 L
.45253 .06454 L
.4526 .06436 L
.45267 .06401 L
.45274 .06343 L
.45281 .06261 L
.45297 .06027 L
.45311 .05721 L
.45338 .0494 L
.45368 .03821 L
.454 .0233 L
.45414 .01588 L
.45421 .01211 L
.45427 .00861 L
.45434 .011 L
.45441 .01507 L
.45457 .02384 L
.4551 .05327 L
.45538 .06732 L
.45569 .07973 L
Mistroke
.45584 .0845 L
.45598 .08814 L
.4561 .09061 L
.45617 .09166 L
.45624 .09239 L
.45631 .09293 L
.45639 .09319 L
.45646 .09313 L
.45652 .09281 L
.4566 .0921 L
.45665 .09154 L
.45669 .09091 L
.45684 .08762 L
.45693 .08522 L
.457 .08256 L
.45715 .07655 L
.45748 .05826 L
.45776 .03768 L
.45792 .02396 L
.45799 .01756 L
.45807 .01035 L
.45811 .00955 L
.45815 .01334 L
.45823 .02097 L
.45839 .03856 L
.45869 .0725 L
.4598 .20541 L
.46034 .26088 L
.46063 .28437 L
.46093 .30383 L
.46109 .31179 L
.46117 .31528 L
.46126 .31844 L
.46135 .32085 L
.46142 .32259 L
.4615 .32392 L
.46157 .32479 L
.46164 .32528 L
.46172 .32538 L
.46178 .32512 L
.46186 .32446 L
.46193 .32334 L
.46202 .32165 L
.46217 .31735 L
.46232 .31137 L
.46249 .30333 L
.46278 .28484 L
.46344 .22757 L
.46403 .16694 L
.46465 .10013 L
Mistroke
.46495 .07066 L
.46526 .04234 L
.46553 .02095 L
.4656 .01559 L
.46568 .01011 L
.46576 .01068 L
.46582 .01495 L
.46609 .03009 L
.46624 .0367 L
.46639 .04267 L
.46652 .04703 L
.46667 .05091 L
.4668 .05364 L
.46692 .05551 L
.467 .05634 L
.46704 .05669 L
.46708 .05697 L
.46715 .05734 L
.46722 .0575 L
.46726 .05751 L
.4673 .05747 L
.46738 .05723 L
.46742 .05702 L
.46746 .05677 L
.46755 .05603 L
.4677 .05426 L
.46783 .05214 L
.46814 .04587 L
.46868 .03159 L
.46926 .01513 L
.46939 .0114 L
.46946 .0095 L
.46954 .00832 L
.46958 .00933 L
.46962 .01042 L
.4697 .01229 L
.46985 .01573 L
.47014 .02145 L
.4704 .02556 L
.47055 .02743 L
.47072 .02904 L
.47081 .02975 L
.47089 .03029 L
.47097 .03072 L
.47105 .03103 L
.47112 .03123 L
.47119 .03136 L
.47123 .0314 L
.47127 .03141 L
.47134 .03138 L
Mistroke
.47142 .03126 L
.47149 .03108 L
.47157 .0308 L
.47165 .03042 L
.47181 .02945 L
.47198 .0281 L
.47227 .02494 L
.47262 .02021 L
.47294 .01498 L
.47309 .01245 L
.47322 .00998 L
.4733 .00858 L
.47334 .00808 L
.47338 .00882 L
.47352 .01154 L
.47416 .02353 L
.47444 .02833 L
.47474 .03276 L
.47488 .03454 L
.47502 .03597 L
.47515 .03701 L
.47521 .03745 L
.47528 .03784 L
.47533 .03804 L
.47537 .03819 L
.47545 .0384 L
.47552 .03849 L
.47559 .03846 L
.47563 .0384 L
.47568 .03829 L
.47575 .038 L
.4758 .03776 L
.47584 .03749 L
.47593 .03686 L
.47608 .03531 L
.47621 .03339 L
.47652 .0273 L
.4768 .01976 L
.47695 .01503 L
.47703 .01223 L
.4771 .00949 L
.47717 .00891 L
.47724 .01171 L
.47739 .01798 L
.47765 .03004 L
.47888 .0975 L
.4795 .12906 L
.47982 .1428 L
.48 .14916 L
.48017 .15428 L
Mistroke
.48032 .15831 L
.48047 .16127 L
.48063 .16372 L
.48071 .16468 L
.48076 .16506 L
.4808 .16533 L
.48087 .16569 L
.48094 .16587 L
.48101 .16585 L
.48108 .16567 L
.48115 .16527 L
.48122 .16471 L
.4813 .16389 L
.48138 .1628 L
.48153 .16008 L
.48168 .15677 L
.48195 .14871 L
.48256 .12314 L
.48367 .06272 L
.48425 .0314 L
.48454 .01738 L
.48462 .01382 L
.48466 .01201 L
.48471 .01014 L
.48475 .00853 L
.48479 .00906 L
.48486 .01197 L
.48514 .02161 L
.48544 .02975 L
.48558 .03288 L
.48572 .03534 L
.48584 .03714 L
.48597 .03865 L
.48605 .03932 L
.48612 .03981 L
.48619 .04019 L
.48625 .04044 L
.48633 .04061 L
.4864 .04064 L
.48648 .04056 L
.48652 .04047 L
.48656 .04033 L
.48664 .03997 L
.48671 .03953 L
.48688 .03818 L
.48702 .0366 L
.48718 .03458 L
.48771 .02556 L
.48829 .01372 L
.48844 .01058 L
Mistroke
.48848 .00973 L
.48853 .00883 L
.48861 .00863 L
.48868 .01008 L
.48875 .01142 L
.48891 .01436 L
.48947 .02322 L
.48963 .02519 L
.48978 .02677 L
.48992 .02795 L
.49007 .02892 L
.49016 .02934 L
.49024 .02964 L
.49031 .02986 L
.49039 .02999 L
.49043 .03003 L
.49047 .03005 L
.49055 .03001 L
.49059 .02996 L
.49063 .02988 L
.49068 .02977 L
.49073 .02963 L
.4908 .02934 L
.49088 .02894 L
.49104 .02786 L
.4912 .02655 L
.49134 .02506 L
.49169 .02045 L
.492 .01516 L
.49215 .01245 L
.49229 .0098 L
.49236 .00843 L
.49243 .00893 L
.49247 .00979 L
.49251 .0106 L
.49259 .01214 L
.49321 .02504 L
.49352 .03061 L
.4938 .03501 L
.49395 .03697 L
.49409 .03844 L
.49425 .03967 L
.49429 .03992 L
.49434 .04015 L
.49438 .04032 L
.49442 .04047 L
.49449 .04065 L
.49456 .0407 L
.49463 .04064 L
.4947 .04049 L
Mistroke
.49477 .04022 L
.49484 .0398 L
.49492 .03921 L
.49499 .03853 L
.49513 .03691 L
.49525 .03503 L
.49553 .02939 L
.49582 .02133 L
.49598 .01602 L
.49605 .0132 L
.49613 .0105 L
.49619 .00806 L
.49625 .01047 L
.49639 .01634 L
.49668 .03 L
.49793 .09862 L
.4985 .12813 L
.49882 .14167 L
.49912 .15205 L
.4994 .1593 L
.49955 .16225 L
.49963 .16335 L
.4997 .16421 L
.49976 .16483 L
.49982 .16528 L
.49988 .16563 L
.49995 .16583 L
.50002 .16587 L
.50009 .16572 L
.50016 .16541 L
.50022 .16496 L
.50029 .1643 L
.50037 .16341 L
.5005 .16132 L
.50064 .1584 L
.5008 .15441 L
.50134 .13492 L
.50199 .10331 L
.50258 .06987 L
.50322 .03537 L
.50353 .02021 L
.50366 .0141 L
.50373 .01101 L
.50381 .00806 L
.50388 .01083 L
.50395 .01326 L
.50407 .01775 L
.50435 .02622 L
.50449 .02984 L
.50465 .03319 L
Mistroke
.50479 .03578 L
.50493 .03767 L
.50508 .03925 L
.50516 .03984 L
.50521 .04008 L
.50525 .0403 L
.50532 .04055 L
.50539 .04068 L
.50544 .0407 L
.50548 .04068 L
.50555 .04056 L
.50562 .04035 L
.50569 .04001 L
.50575 .03965 L
.50582 .03917 L
.50597 .03779 L
.50611 .03616 L
.50672 .02628 L
.50706 .01949 L
.50738 .01292 L
.50745 .01149 L
.50752 .00995 L
.50759 .00852 L
.50766 .00866 L
.50773 .01016 L
.50781 .01172 L
.50795 .01437 L
.50828 .01989 L
.50858 .02413 L
.50887 .02719 L
.50904 .02844 L
.50919 .02928 L
.50927 .02962 L
.50935 .02985 L
.5094 .02994 L
.50944 .03 L
.50948 .03004 L
.50953 .03005 L
.50957 .03003 L
.50961 .02999 L
.50968 .02987 L
.50973 .02976 L
.50976 .02964 L
.50985 .0293 L
.51001 .02842 L
.51015 .02732 L
.51048 .02386 L
.51077 .0198 L
.51108 .01463 L
.51121 .01217 L
Mistroke
.51128 .01077 L
.51135 .00942 L
.51142 .00814 L
.51149 .00915 L
.51155 .01045 L
.51161 .01166 L
.5122 .02372 L
.5125 .02947 L
.51283 .03474 L
.51298 .0367 L
.51314 .03839 L
.51328 .03949 L
.51336 .03996 L
.51343 .04029 L
.5135 .04051 L
.51358 .04063 L
.51365 .04063 L
.51371 .04053 L
.51377 .04035 L
.51384 .04006 L
.51391 .03965 L
.51397 .03916 L
.51412 .03767 L
.51425 .03583 L
.51455 .03 L
.51484 .02229 L
.51499 .01718 L
.51507 .01445 L
.51514 .0118 L
.51521 .0092 L
.51528 .00954 L
.51535 .01253 L
.51543 .01594 L
.51569 .02818 L
.51693 .0966 L
.51753 .12769 L
.51783 .14055 L
.5181 .15046 L
.51842 .15901 L
.51858 .1622 L
.51867 .16356 L
.51876 .16452 L
.51884 .16519 L
.51891 .1656 L
.51899 .16584 L
.51902 .16588 L
.51907 .16585 L
.51914 .16565 L
.51922 .16522 L
.51929 .16462 L
Mistroke
.51936 .16389 L
.5195 .16189 L
.51965 .15891 L
.51996 .15053 L
.52024 .14022 L
.52051 .12865 L
.52176 .06146 L
.52235 .03022 L
.52265 .01649 L
.52273 .01303 L
.52277 .01119 L
.52282 .0095 L
.52286 .00796 L
.5229 .00955 L
.52297 .0123 L
.52326 .02149 L
.52355 .02905 L
.52381 .03371 L
.52395 .03564 L
.52409 .03698 L
.52416 .03754 L
.5242 .03779 L
.52424 .03799 L
.52431 .03826 L
.52439 .03844 L
.52443 .03848 L
.52447 .03849 L
.52455 .03842 L
.52459 .03833 L
.52463 .03822 L
.52471 .03785 L
.52479 .03741 L
.52487 .03691 L
.525 .03573 L
.52531 .03211 L
.52584 .02348 L
.52614 .01791 L
.52643 .01253 L
.52649 .01124 L
.52657 .00984 L
.52663 .00853 L
.5267 .00855 L
.52677 .00993 L
.52685 .01138 L
.52699 .01389 L
.52762 .02359 L
.52778 .02561 L
.52796 .02751 L
.52812 .0289 L
.52828 .03005 L
Mistroke
.52835 .03045 L
.52843 .03081 L
.52848 .03097 L
.52852 .0311 L
.5286 .03129 L
.52867 .03139 L
.52874 .03141 L
.52882 .03135 L
.52888 .03122 L
.52896 .03101 L
.52903 .03071 L
.52916 .02996 L
.52931 .02884 L
.52946 .02723 L
.52975 .02336 L
.53001 .01866 L
.53017 .01528 L
.53032 .01177 L
.53039 .01016 L
.53046 .00839 L
.53054 .00947 L
.53061 .01135 L
.53125 .02951 L
.53181 .04482 L
.53198 .04851 L
.53213 .05155 L
.53227 .05386 L
.53235 .05491 L
.53242 .05574 L
.53249 .0564 L
.53257 .05695 L
.53264 .05729 L
.5327 .05747 L
.53276 .05751 L
.53282 .05742 L
.53289 .05717 L
.53295 .05677 L
.53303 .0561 L
.5331 .05526 L
.53323 .05314 L
.53337 .05001 L
.53353 .04559 L
.53382 .03423 L
.53409 .01998 L
.53417 .01514 L
.53425 .01026 L
.53432 .01021 L
.53439 .01546 L
.53472 .0408 L
.53598 .16788 L
Mistroke
.53659 .23104 L
.53717 .28078 L
.53748 .30156 L
.53766 .31064 L
.53783 .31717 L
.53797 .32124 L
.53804 .32295 L
.53812 .32414 L
.5382 .32497 L
.53827 .32535 L
.53831 .3254 L
.53835 .32532 L
.53843 .32484 L
.5385 .32398 L
.53857 .32284 L
.53864 .32122 L
.53872 .31908 L
.53885 .31449 L
.53899 .30807 L
.53931 .28849 L
.53961 .26447 L
.54088 .12425 L
.54118 .08752 L
.54151 .04935 L
.54166 .03284 L
.54174 .02414 L
.54182 .01623 L
.54189 .00969 L
.54196 .013 L
.54204 .0203 L
.54211 .02672 L
.54238 .04881 L
.54268 .06809 L
.54282 .07512 L
.54296 .08135 L
.5431 .08601 L
.54323 .08922 L
.5433 .09065 L
.54337 .0917 L
.54344 .09253 L
.54352 .09305 L
.54356 .09317 L
.5436 .0932 L
.54368 .09298 L
.54376 .09244 L
.54383 .09165 L
.5439 .09068 L
.54396 .08956 L
.5441 .08632 L
.54438 .07707 L
Mistroke
.5447 .06344 L
.54499 .04869 L
.5453 .03121 L
.54547 .02139 L
.54556 .0166 L
.54564 .01221 L
.54571 .0082 L
.54579 .01185 L
.54595 .02037 L
.54623 .03404 L
.54649 .04504 L
.54678 .05437 L
.54694 .05836 L
.54708 .06115 L
.54715 .06221 L
.54723 .06313 L
.5473 .0638 L
.54737 .06423 L
.54741 .0644 L
.54746 .06452 L
.5475 .06457 L
.54754 .06454 L
.54761 .06435 L
.54769 .06393 L
.54773 .06362 L
.54777 .06323 L
.54785 .06236 L
.54802 .05961 L
.54818 .05635 L
.54834 .05213 L
.54864 .04288 L
.54898 .03005 L
.54915 .02328 L
.5493 .01696 L
.54937 .01416 L
.54945 .01111 L
.54952 .00824 L
.54958 .01028 L
.54988 .02192 L
.55021 .03335 L
.55052 .04187 L
.55066 .04513 L
.55082 .04804 L
.55098 .05022 L
.55107 .05108 L
.55111 .0514 L
.55115 .05168 L
.55123 .05206 L
.5513 .05226 L
.55137 .05229 L
Mistroke
.55144 .05218 L
.55151 .05192 L
.55159 .05145 L
.55167 .05078 L
.55175 .04997 L
.55189 .04814 L
.55203 .0457 L
.55229 .04013 L
.55287 .02337 L
.55301 .01873 L
.55316 .0136 L
.55323 .01124 L
.55331 .00875 L
.55337 .00925 L
.55344 .01156 L
.55376 .02174 L
.55406 .02994 L
.55433 .03635 L
.55448 .03923 L
.55463 .04148 L
.55476 .04312 L
.55483 .04381 L
.55491 .04441 L
.55498 .04484 L
.55504 .04512 L
.5551 .0453 L
.55516 .04538 L
.55523 .04536 L
.55531 .04519 L
.55538 .04491 L
.55544 .04454 L
.55552 .04398 L
.5556 .04322 L
.55575 .04143 L
.55607 .03597 L
.55637 .02929 L
.55691 .01466 L
.55704 .01087 L
.55712 .00874 L
.55718 .00908 L
.55726 .01124 L
.55734 .01349 L
.55748 .01751 L
.55778 .0251 L
.55806 .03122 L
.55821 .03405 L
.55838 .03662 L
.55853 .03845 L
.5586 .03911 L
.55867 .03971 L
Mistroke
.55874 .04017 L
.5588 .0405 L
.55887 .04074 L
.55893 .04088 L
.559 .04095 L
.55906 .04091 L
.55913 .04076 L
.55921 .04048 L
.55928 .04013 L
.55935 .03964 L
.55948 .03848 L
.55964 .03665 L
.55978 .03457 L
.56037 .02271 L
.56065 .01577 L
.56079 .01222 L
.56085 .01065 L
.56091 .00891 L
.56099 .00886 L
.56107 .01085 L
.56123 .01499 L
.56152 .02178 L
.56185 .02852 L
.56201 .03128 L
.56216 .03345 L
.56231 .03523 L
.56245 .03646 L
.56253 .037 L
.56261 .03738 L
.56268 .03767 L
.56273 .03778 L
.56277 .03784 L
.56284 .03787 L
.5629 .03781 L
.56297 .03766 L
.56304 .03739 L
.56312 .037 L
.56319 .03652 L
.56333 .03534 L
.56348 .03365 L
.56364 .03142 L
.56393 .02646 L
.56427 .01937 L
.56442 .01598 L
.56458 .01216 L
.56465 .01053 L
.56473 .00879 L
.5648 .00873 L
.56486 .01022 L
.56515 .01685 L
Mistroke
.56544 .02296 L
.56576 .02852 L
.5659 .03058 L
.56605 .0324 L
.56618 .03365 L
.56625 .03423 L
.56632 .03468 L
.56639 .03502 L
.56645 .03531 L
.56653 .03551 L
.5666 .03562 L
.56666 .03563 L
.56673 .03555 L
.5668 .0354 L
.56686 .0352 L
.56693 .03486 L
.567 .03445 L
.56715 .03324 L
.5673 .03167 L
.56746 .0296 L
.56802 .01989 L
.56818 .01654 L
.56835 .01275 L
.56843 .01098 L
.56848 .01 L
.56852 .00909 L
.56859 .00839 L
.56863 .00924 L
.56867 .01016 L
.56927 .02236 L
.56958 .02749 L
.56974 .02948 L
.56988 .03105 L
.56996 .0318 L
.57005 .03249 L
.57012 .03296 L
.5702 .03338 L
.57024 .03355 L
.57028 .03371 L
.57033 .03383 L
.57038 .03391 L
.57042 .03395 L
.57046 .03396 L
.57054 .0339 L
.57061 .03375 L
.57069 .03349 L
.57077 .03312 L
.57084 .03266 L
.57097 .03162 L
.57112 .03019 L
Mistroke
.57145 .02581 L
.57175 .02068 L
.57203 .01514 L
.57219 .01193 L
.57227 .01033 L
.57234 .00884 L
.5724 .00843 L
.57248 .00991 L
.57262 .01298 L
.57289 .01812 L
.57317 .02316 L
.57348 .0276 L
.57365 .02958 L
.57382 .03099 L
.57389 .03152 L
.57398 .03199 L
.57402 .03216 L
.57406 .03232 L
.57413 .03254 L
.57421 .03267 L
.57425 .0327 L
.57429 .0327 L
.57433 .03267 L
.57437 .03262 L
.57441 .03253 L
.57445 .03241 L
.57453 .03214 L
.5746 .03181 L
.57475 .03078 L
.57491 .02939 L
.57508 .02745 L
.57542 .02244 L
.57572 .01712 L
.57588 .01409 L
.57605 .01081 L
.57612 .00939 L
.57619 .00799 L
.57624 .00886 L
.57628 .00965 L
.57635 .01118 L
.57663 .01658 L
.57693 .02167 L
.57724 .02616 L
.5775 .02905 L
.57765 .03025 L
.57779 .03106 L
.57787 .03138 L
.57791 .03151 L
.57795 .03161 L
.57803 .03172 L
Mistroke
.57811 .03174 L
.57818 .03168 L
.57824 .03154 L
.57832 .03131 L
.57839 .03097 L
.57847 .03053 L
.57856 .02994 L
.57873 .02843 L
.57904 .02472 L
.57933 .02027 L
.57965 .01468 L
.57979 .01196 L
.57987 .01044 L
.57994 .00901 L
.58001 .00808 L
.58008 .00938 L
.58022 .01214 L
.58056 .01839 L
.58088 .02336 L
.58103 .02534 L
.58119 .0272 L
.58134 .02865 L
.58148 .02969 L
.58155 .03012 L
.58163 .0305 L
.58171 .03078 L
.58176 .03089 L
.5818 .03097 L
.58187 .03104 L
.58194 .03102 L
.58198 .03098 L
.58202 .03091 L
.5821 .03072 L
.58217 .03047 L
.58224 .03011 L
.58239 .02914 L
.58253 .02795 L
.58266 .02659 L
.58328 .01768 L
.58344 .01483 L
.58361 .01165 L
.5837 .01008 L
.58378 .00858 L
.58385 .00863 L
.58392 .01008 L
.5845 .02025 L
.58481 .02464 L
.58498 .02659 L
.58514 .02809 L
.58527 .02909 L
Mistroke
.58534 .02951 L
.58541 .02988 L
.58546 .03006 L
.58549 .0302 L
.58557 .0304 L
.58564 .03051 L
.58572 .03054 L
.58579 .0305 L
.58586 .03036 L
.58593 .03016 L
.586 .0299 L
.58612 .02925 L
.58625 .02832 L
.58655 .02532 L
.58682 .02167 L
.58712 .01699 L
.58727 .0143 L
.58743 .01133 L
.5875 .01009 L
.58757 .00875 L
.58762 .00798 L
.58765 .0086 L
.58773 .00998 L
.588 .01489 L
.58854 .02331 L
.58882 .02666 L
.58898 .02809 L
.58913 .02908 L
.5892 .02943 L
.58927 .02974 L
.58934 .02998 L
.58941 .03014 L
.58948 .03021 L
.58954 .03022 L
.58961 .03017 L
.58968 .03003 L
.58972 .02992 L
.58976 .02978 L
.58984 .02945 L
.58992 .02901 L
.59001 .0284 L
.59033 .02543 L
.59064 .02143 L
.59093 .01689 L
.59107 .01435 L
.59123 .01154 L
.59131 .01014 L
.59138 .00882 L
.59145 .00824 L
.59152 .00953 L
Mistroke
.59181 .01485 L
.59214 .02017 L
.59242 .02408 L
.59257 .02587 L
.59272 .02728 L
.59285 .02834 L
.59297 .02909 L
.59304 .02943 L
.59311 .02968 L
.59318 .02988 L
.59325 .03002 L
.59329 .03005 L
.59333 .03007 L
.5934 .03003 L
.59348 .02989 L
.59353 .02978 L
.59357 .02964 L
.59372 .02897 L
.5938 .02846 L
.59387 .02791 L
.59416 .0251 L
.59444 .02153 L
.59473 .01696 L
.59504 .01154 L
.59512 .01012 L
.59516 .00938 L
.5952 .00859 L
.59525 .00816 L
.59529 .00896 L
.59538 .01054 L
.5957 .01611 L
.59599 .02083 L
.59627 .02459 L
.59643 .0263 L
.59659 .02783 L
.59667 .02838 L
.59675 .02888 L
.59682 .02928 L
.59689 .02957 L
.59695 .02979 L
.59702 .02995 L
.59708 .03004 L
.59716 .03007 L
.59722 .03002 L
.59729 .02991 L
.59735 .02974 L
.59741 .02953 L
.59756 .02881 L
.59771 .0277 L
.59799 .02489 L
Mistroke
.59829 .02088 L
.59861 .01571 L
.59877 .01298 L
.59892 .01032 L
.59898 .00915 L
.59905 .00797 L
.59912 .00934 L
.59919 .0106 L
.5998 .02084 L
.60011 .02507 L
.60028 .02685 L
.60046 .0284 L
.60054 .02892 L
.60062 .02939 L
.6007 .02974 L
.60077 .02997 L
.60085 .03013 L
.60093 .03022 L
.601 .03021 L
.60107 .03012 L
.60114 .02997 L
.6012 .02977 L
.60127 .02949 L
.60134 .0291 L
.60149 .02808 L
.60163 .02688 L
.60194 .02331 L
.60227 .01829 L
.60259 .01285 L
.60266 .01149 L
.60274 .01004 L
.60281 .0088 L
.60288 .00844 L
.60295 .0097 L
.60303 .01104 L
.60316 .01342 L
.60345 .01849 L
.60375 .02304 L
.60407 .02694 L
.60425 .02852 L
.60433 .02907 L
.60441 .02959 L
.60449 .02997 L
.60457 .03024 L
.60461 .03036 L
.60465 .03044 L
.60469 .0305 L
.60474 .03054 L
.60481 .03053 L
.60489 .03044 L
Mistroke
.60496 .03027 L
.60502 .03005 L
.6051 .0297 L
.60519 .02922 L
.60534 .0281 L
.60563 .02502 L
.60591 .02122 L
.60624 .0158 L
.60654 .01034 L
.60661 .00897 L
.60669 .00836 L
.60673 .00913 L
.60677 .00996 L
.60685 .01144 L
.60715 .01684 L
.60747 .02205 L
.60781 .0265 L
.60795 .02796 L
.6081 .02923 L
.60818 .02981 L
.60826 .03025 L
.60834 .03059 L
.60841 .03083 L
.60848 .03097 L
.60855 .03104 L
.60862 .03103 L
.60868 .03096 L
.60875 .03081 L
.60883 .03055 L
.60891 .03022 L
.60897 .02985 L
.60913 .0287 L
.60928 .0273 L
.60962 .02309 L
.60991 .01843 L
.61006 .01571 L
.61023 .0127 L
.61037 .00996 L
.61041 .0092 L
.61045 .00839 L
.61053 .00895 L
.6106 .01039 L
.61067 .01174 L
.61081 .01423 L
.61135 .02348 L
.61166 .0275 L
.6118 .029 L
.61194 .03012 L
.61209 .03101 L
.61217 .03134 L
Mistroke
.61221 .03149 L
.61226 .03159 L
.6123 .03167 L
.61234 .03172 L
.61238 .03175 L
.61243 .03174 L
.61247 .0317 L
.61251 .03164 L
.61259 .03145 L
.61266 .03119 L
.61273 .03083 L
.61287 .02996 L
.61303 .02856 L
.61317 .02697 L
.6138 .01744 L
.61407 .01225 L
.61414 .01077 L
.61422 .00919 L
.61429 .00804 L
.61437 .00954 L
.61491 .01989 L
.6152 .02473 L
.61536 .02698 L
.61551 .02878 L
.61565 .03017 L
.61578 .03118 L
.61585 .03162 L
.61592 .03201 L
.616 .03233 L
.61607 .03254 L
.61615 .03267 L
.61622 .0327 L
.61626 .03267 L
.6163 .03263 L
.61635 .03254 L
.61639 .03243 L
.61647 .03212 L
.61655 .03173 L
.61672 .03048 L
.61688 .02901 L
.61702 .02738 L
.61733 .02282 L
.61762 .01756 L
.61778 .01442 L
.61793 .01137 L
.618 .01 L
.61806 .00871 L
.61813 .00867 L
.6182 .01003 L
.61849 .016 L
Mistroke
.61878 .02158 L
.61909 .02668 L
.61925 .02889 L
.61943 .03091 L
.61959 .03232 L
.61967 .03286 L
.61974 .03326 L
.61981 .03358 L
.61986 .03372 L
.61989 .03382 L
.61996 .03393 L
.62004 .03396 L
.62008 .03394 L
.62012 .03388 L
.62016 .03378 L
.62021 .03366 L
.62028 .03336 L
.62036 .03293 L
.62052 .03176 L
.62067 .03027 L
.62096 .02654 L
.62149 .01695 L
.62163 .01392 L
.62171 .01228 L
.62179 .01053 L
.62186 .00898 L
.62193 .0086 L
.622 .01015 L
.62207 .01159 L
.62265 .02359 L
.62297 .02898 L
.62311 .03091 L
.62327 .03266 L
.62341 .03395 L
.62347 .03441 L
.62354 .03483 L
.6236 .03512 L
.62367 .03537 L
.62374 .03554 L
.6238 .03562 L
.62388 .03562 L
.62392 .03557 L
.62396 .0355 L
.62403 .03529 L
.6241 .03497 L
.62418 .03455 L
.62424 .03407 L
.62437 .03293 L
.62466 .0295 L
.62496 .02437 L
Mistroke
.62526 .01829 L
.62543 .01462 L
.62558 .01101 L
.62565 .00937 L
.62573 .00826 L
.62577 .00918 L
.62581 .01019 L
.62588 .01198 L
.62616 .01833 L
.6267 .02915 L
.62699 .03358 L
.62714 .03527 L
.62723 .03605 L
.6273 .03665 L
.62737 .03707 L
.62744 .03743 L
.62752 .03769 L
.62759 .03783 L
.62766 .03787 L
.62773 .0378 L
.62779 .03767 L
.62786 .03743 L
.6279 .03724 L
.62794 .037 L
.62802 .03647 L
.62817 .03513 L
.62835 .03304 L
.62851 .03062 L
.6288 .02521 L
.62912 .01818 L
.62926 .0146 L
.62934 .01259 L
.62942 .01069 L
.62948 .00905 L
.62955 .00858 L
.62962 .01054 L
.62969 .01232 L
.63024 .02562 L
.63054 .03188 L
.6307 .03463 L
.63087 .03706 L
.63102 .03873 L
.6311 .03943 L
.63119 .04004 L
.63126 .04047 L
.63133 .04074 L
.63141 .0409 L
.63147 .04095 L
.63155 .04088 L
.63159 .04079 L
Mistroke
.63163 .04066 L
.6317 .04035 L
.63178 .0399 L
.63191 .03882 L
.63205 .03721 L
.63237 .03216 L
.63267 .02585 L
.63294 .01895 L
.6332 .01177 L
.63327 .00979 L
.63334 .00821 L
.63338 .00933 L
.63342 .01055 L
.6335 .01272 L
.63377 .02049 L
.63407 .02835 L
.63438 .03546 L
.63464 .04024 L
.6348 .04231 L
.63494 .04378 L
.63501 .0444 L
.63506 .04467 L
.6351 .04491 L
.63514 .04508 L
.63518 .04522 L
.63525 .04537 L
.63533 .04538 L
.6354 .04524 L
.63548 .04497 L
.63554 .0446 L
.63562 .04399 L
.6357 .04328 L
.63587 .04112 L
.63603 .03863 L
.63619 .03541 L
.63681 .01873 L
.63698 .0133 L
.63703 .01184 L
.63707 .01026 L
.63712 .00875 L
.63716 .00849 L
.63724 .01112 L
.63731 .01362 L
.63748 .01921 L
.63807 .03712 L
.63837 .04415 L
.63854 .04729 L
.63869 .04958 L
.63877 .05045 L
.63884 .05111 L
Mistroke
.63892 .05164 L
.63895 .05186 L
.639 .05205 L
.63907 .05225 L
.63914 .05229 L
.6392 .0522 L
.63927 .05196 L
.63935 .05154 L
.63939 .05123 L
.63943 .05089 L
.6396 .04893 L
.63974 .04659 L
.63989 .04343 L
.64019 .0356 L
.64047 .02635 L
.64061 .02158 L
.64075 .01616 L
.64081 .01359 L
.64088 .01085 L
.64094 .00848 L
.641 .01001 L
.64107 .01283 L
.64115 .01587 L
.64128 .02132 L
.64158 .03347 L
.6419 .04493 L
.6422 .05389 L
.64233 .05716 L
.64248 .06004 L
.64255 .06127 L
.64263 .06242 L
.64271 .06326 L
.64278 .06385 L
.64285 .06426 L
.64291 .06449 L
.64298 .06457 L
.64305 .06445 L
.64312 .06418 L
.64318 .06371 L
.64325 .0631 L
.64331 .06241 L
.64345 .06022 L
.6436 .05695 L
.64391 .04771 L
.6442 .03631 L
.64447 .02364 L
.64463 .01521 L
.64467 .01313 L
.64471 .0109 L
.64478 .00903 L
Mistroke
.64485 .01268 L
.64492 .01675 L
.64507 .02527 L
.64572 .06056 L
.64601 .074 L
.64618 .08012 L
.64633 .0849 L
.64647 .08844 L
.64659 .09085 L
.64666 .09186 L
.64673 .09256 L
.6468 .09303 L
.64688 .09321 L
.64696 .09303 L
.64703 .09255 L
.64708 .09213 L
.64711 .09165 L
.6472 .09026 L
.64728 .0885 L
.64737 .08611 L
.64754 .08046 L
.64769 .07376 L
.64785 .06508 L
.64814 .04561 L
.64829 .03304 L
.64838 .02563 L
.64846 .0184 L
.64853 .01197 L
.6486 .01102 L
.64864 .01518 L
.64868 .01918 L
.64876 .02684 L
.64943 .10364 L
.65002 .17511 L
.65064 .244 L
.65092 .26941 L
.65121 .29212 L
.65138 .30269 L
.65154 .31068 L
.6517 .31701 L
.65177 .31952 L
.65184 .32141 L
.65191 .32281 L
.65198 .32398 L
.65205 .32484 L
.65212 .32529 L
.65218 .32539 L
.65225 .32517 L
.65231 .32471 L
.65237 .32391 L
Mistroke
.65245 .3226 L
.65252 .32105 L
.65267 .31634 L
.65282 .31053 L
.65295 .30379 L
.65353 .26313 L
.65415 .20431 L
.65526 .08718 L
.65582 .03554 L
.65598 .02333 L
.65606 .01707 L
.65614 .01152 L
.6562 .00889 L
.65628 .01353 L
.65643 .02258 L
.65672 .03719 L
.65687 .04288 L
.657 .04726 L
.65712 .05048 L
.65726 .05329 L
.65739 .05537 L
.65746 .05621 L
.65753 .0568 L
.6576 .05724 L
.65764 .0574 L
.65768 .05748 L
.65776 .0575 L
.65783 .05734 L
.65787 .05717 L
.65791 .05694 L
.65798 .05639 L
.65806 .05561 L
.65815 .05453 L
.65846 .04929 L
.65875 .04272 L
.65928 .02801 L
.65956 .01987 L
.65986 .01155 L
.65994 .00956 L
.65998 .00847 L
.66002 .00839 L
.66006 .00948 L
.66011 .0106 L
.66019 .0126 L
.66049 .01912 L
.66078 .02408 L
.66094 .02635 L
.66109 .02805 L
.66123 .02937 L
.66137 .03031 L
Mistroke
.66144 .0307 L
.66151 .03098 L
.66159 .03121 L
.66163 .03129 L
.66167 .03136 L
.66174 .03141 L
.6618 .03139 L
.66188 .0313 L
.66195 .03114 L
.66201 .03094 L
.66207 .0307 L
.66221 .02998 L
.66235 .02897 L
.66248 .02782 L
.66278 .02454 L
.66333 .01657 L
.66348 .01399 L
.66364 .01111 L
.66372 .00968 L
.66379 .0083 L
.66386 .00882 L
.66393 .01019 L
.66423 .01601 L
.66456 .02226 L
.66513 .03163 L
.66529 .03368 L
.66546 .03555 L
.66561 .03693 L
.66569 .03745 L
.66576 .03783 L
.66584 .03817 L
.66588 .0383 L
.66592 .0384 L
.66599 .03848 L
.66607 .03846 L
.66611 .0384 L
.66615 .03829 L
.6662 .03813 L
.66624 .03793 L
.66632 .03747 L
.66641 .03682 L
.66657 .03505 L
.66673 .03275 L
.66702 .02675 L
.6673 .01912 L
.66746 .01387 L
.66753 .01138 L
.6676 .00852 L
.66768 .01027 L
.66776 .01349 L
Mistroke
.66792 .02066 L
.66822 .03494 L
.66933 .09574 L
.66994 .12717 L
.67023 .14019 L
.67051 .15018 L
.67083 .15887 L
.67099 .16211 L
.67108 .16337 L
.67117 .16447 L
.67125 .16515 L
.67132 .16558 L
.67136 .16574 L
.6714 .16584 L
.67148 .16586 L
.67155 .16567 L
.67163 .16526 L
.6717 .16466 L
.67177 .16396 L
.67191 .16194 L
.67206 .15893 L
.67237 .15046 L
.67266 .14001 L
.67293 .12834 L
.67357 .09492 L
.67418 .06042 L
.67477 .02903 L
.67493 .02128 L
.6751 .01359 L
.67517 .0106 L
.67525 .00837 L
.67529 .01009 L
.67533 .01162 L
.67541 .01453 L
.67568 .02357 L
.67598 .03127 L
.67612 .03401 L
.67626 .0364 L
.6764 .03816 L
.67653 .03933 L
.6766 .03984 L
.67667 .0402 L
.67674 .04047 L
.67682 .04062 L
.67686 .04064 L
.6769 .04063 L
.67698 .0405 L
.67706 .04024 L
.67713 .0399 L
.67726 .03904 L
Mistroke
.6774 .03775 L
.67768 .03418 L
.67833 .02272 L
.67862 .01678 L
.67877 .01359 L
.67886 .01185 L
.67894 .01021 L
.67901 .00865 L
.67906 .0081 L
.6791 .00889 L
.67924 .01174 L
.67953 .01691 L
.67982 .02157 L
.68015 .02566 L
.68028 .02698 L
.68043 .02815 L
.68056 .029 L
.68062 .0293 L
.68069 .02956 L
.68076 .02979 L
.68083 .02994 L
.68087 .03 L
.68091 .03003 L
.68098 .03004 L
.68105 .02998 L
.68112 .02987 L
.68119 .02968 L
.68126 .0294 L
.6814 .02866 L
.68156 .02758 L
.68172 .02606 L
.68188 .02435 L
.68218 .02024 L
.68246 .01557 L
.68271 .01092 L
.68277 .00958 L
.68285 .00815 L
.68291 .00897 L
.68298 .01034 L
.68355 .02218 L
.68411 .03263 L
.68428 .03506 L
.68443 .03702 L
.68457 .03847 L
.68472 .03964 L
.6848 .04009 L
.68484 .04028 L
.68488 .04044 L
.68496 .04064 L
.68503 .0407 L
Mistroke
.68508 .04068 L
.68513 .04061 L
.68517 .0405 L
.68521 .04036 L
.68529 .03997 L
.68537 .0394 L
.68545 .0387 L
.68554 .03778 L
.68569 .03563 L
.68598 .02996 L
.68628 .02187 L
.68642 .0172 L
.68655 .01234 L
.68663 .00939 L
.68667 .0082 L
.68671 .00983 L
.68686 .01603 L
.68718 .03141 L
.68845 .10119 L
.68899 .12877 L
.68929 .14155 L
.68958 .15154 L
.68974 .15609 L
.68991 .16012 L
.68999 .16157 L
.69007 .16288 L
.69015 .1639 L
.69022 .16466 L
.6903 .16528 L
.69034 .16552 L
.69038 .1657 L
.69045 .16586 L
.69049 .16587 L
.69053 .16582 L
.6906 .16557 L
.69067 .16519 L
.69075 .16455 L
.69082 .16375 L
.69096 .16163 L
.69109 .15901 L
.6914 .15081 L
.6917 .14015 L
.69202 .12614 L
.69312 .06628 L
.69375 .03254 L
.6939 .02483 L
.69405 .01795 L
.69418 .01213 L
.69426 .00901 L
.69433 .00963 L
Mistroke
.6944 .01224 L
.69447 .015 L
.69462 .02015 L
.69493 .02905 L
.6951 .03272 L
.69528 .03588 L
.69536 .03712 L
.69544 .03812 L
.69552 .03893 L
.6956 .03954 L
.69567 .04003 L
.69571 .04023 L
.69575 .04041 L
.69583 .04061 L
.6959 .0407 L
.69597 .04067 L
.69604 .04052 L
.69611 .04028 L
.69618 .03997 L
.69625 .03949 L
.69633 .03893 L
.69649 .03733 L
.69679 .03336 L
.69733 .02375 L
.69763 .01767 L
.6979 .01199 L
.69803 .00928 L
.6981 .00811 L
.69817 .00949 L
.69846 .01498 L
.69878 .0203 L
.69907 .02427 L
.6992 .02576 L
.69934 .02714 L
.69947 .02812 L
.6996 .02898 L
.69968 .02934 L
.69975 .02961 L
.69982 .02983 L
.6999 .02998 L
.69997 .03004 L
.70004 .03004 L
.7001 .02997 L
.70017 .02984 L
.70024 .02963 L
.70031 .02937 L
.70046 .02857 L
.7006 .02762 L
.70074 .02636 L
.70103 .02292 L
Mistroke
.70136 .01804 L
.70167 .01242 L
.70177 .01068 L
.70181 .00981 L
.70185 .00899 L
.70193 .00843 L
.70197 .00925 L
.70201 .01013 L
.70262 .02269 L
.70319 .03297 L
.70335 .03533 L
.70351 .03724 L
.70365 .03862 L
.70372 .03926 L
.7038 .03975 L
.70387 .04012 L
.70394 .04042 L
.70401 .04058 L
.70407 .04064 L
.70414 .04061 L
.70422 .04046 L
.7043 .04016 L
.70437 .03974 L
.70444 .03924 L
.7045 .03865 L
.70462 .03727 L
.70476 .03535 L
.7049 .03276 L
.70519 .02581 L
.70546 .01729 L
.70561 .01199 L
.70568 .00913 L
.70573 .00842 L
.70577 .01001 L
.70593 .01732 L
.70609 .02452 L
.70735 .09346 L
.70799 .12662 L
.7083 .14026 L
.70858 .15064 L
.70884 .15792 L
.70898 .16074 L
.70912 .16315 L
.7092 .16411 L
.70927 .16481 L
.7093 .16512 L
.70935 .1654 L
.70942 .16575 L
.70949 .16588 L
.70957 .16581 L
Mistroke
.70964 .16556 L
.7097 .16517 L
.70977 .16455 L
.70984 .1638 L
.71 .16148 L
.71015 .15842 L
.71031 .15431 L
.71086 .13413 L
.71152 .10147 L
.71212 .06805 L
.71267 .03781 L
.71298 .02292 L
.71313 .01625 L
.7132 .01347 L
.71327 .01054 L
.71334 .00833 L
.71342 .01107 L
.71358 .01666 L
.71392 .02645 L
.71407 .02984 L
.71423 .03282 L
.71438 .03504 L
.71452 .03656 L
.71459 .03718 L
.71466 .03765 L
.71473 .03804 L
.71481 .03832 L
.71485 .03841 L
.71489 .03847 L
.71497 .03848 L
.71505 .03836 L
.71512 .03816 L
.71519 .03788 L
.71525 .03754 L
.71539 .03654 L
.71553 .03525 L
.71567 .03357 L
.71633 .02337 L
.71662 .01799 L
.71678 .01494 L
.71693 .01206 L
.717 .01068 L
.71707 .00923 L
.71711 .00848 L
.71716 .00822 L
.71723 .00965 L
.71752 .01468 L
.71806 .02317 L
.71837 .02687 L
.71854 .02849 L
Mistroke
.71871 .02973 L
.71886 .03058 L
.71894 .03094 L
.71902 .03118 L
.71909 .03133 L
.71916 .0314 L
.71924 .0314 L
.71931 .03132 L
.71938 .03118 L
.71945 .03093 L
.71952 .03063 L
.71959 .03028 L
.71975 .02914 L
.7199 .02771 L
.72019 .02378 L
.72052 .01797 L
.7208 .01176 L
.72087 .0101 L
.72094 .00826 L
.72098 .00869 L
.72102 .00969 L
.7211 .0117 L
.72163 .02682 L
.72218 .04211 L
.72248 .04913 L
.72263 .05196 L
.72277 .05413 L
.72285 .05514 L
.72293 .05606 L
.72302 .05677 L
.72306 .05706 L
.72311 .05727 L
.72319 .05748 L
.72326 .0575 L
.7233 .05743 L
.72334 .05729 L
.72341 .05687 L
.72349 .05626 L
.72357 .05536 L
.72365 .05414 L
.72373 .05273 L
.72387 .04956 L
.72402 .04518 L
.72431 .03343 L
.72459 .01881 L
.72467 .01382 L
.72475 .00883 L
.72482 .01175 L
.72489 .0171 L
.72522 .04281 L
Mistroke
.72649 .17085 L
.7271 .23443 L
.72768 .2836 L
.72797 .30218 L
.72812 .30978 L
.72828 .31645 L
.72837 .31943 L
.72846 .32166 L
.72854 .32332 L
.72859 .32404 L
.72863 .32456 L
.72871 .3252 L
.72875 .32537 L
.72879 .32539 L
.72887 .32512 L
.72895 .32439 L
.72902 .32329 L
.7291 .32166 L
.72924 .31748 L
.72938 .31196 L
.72952 .30561 L
.72981 .28697 L
.73013 .26132 L
.73123 .13952 L
.73179 .07152 L
.73209 .03806 L
.73217 .02969 L
.73225 .02099 L
.73233 .01318 L
.7324 .00984 L
.73247 .01637 L
.73254 .0232 L
.73267 .03447 L
.73297 .05693 L
.73325 .07289 L
.7335 .08355 L
.73365 .08794 L
.73372 .08955 L
.73378 .09078 L
.73386 .09188 L
.73389 .09232 L
.73394 .0927 L
.73401 .09312 L
.73408 .0932 L
.73415 .093 L
.73422 .09258 L
.73429 .09185 L
.73436 .09079 L
.73449 .08836 L
.73463 .08483 L
Mistroke
.73494 .07396 L
.73527 .05872 L
.73587 .02595 L
.73603 .01716 L
.73611 .0124 L
.73619 .00799 L
.73626 .01157 L
.73633 .01548 L
.73648 .02349 L
.73681 .03865 L
.73699 .04569 L
.73715 .05133 L
.73731 .05587 L
.73745 .05919 L
.73761 .06196 L
.7377 .06306 L
.73774 .06346 L
.73778 .06382 L
.73785 .06426 L
.73793 .06452 L
.738 .06456 L
.73806 .06444 L
.73814 .06409 L
.73821 .06359 L
.73829 .0628 L
.73836 .06184 L
.73946 .03009 L
.73976 .01794 L
.73984 .01456 L
.73993 .011 L
.74 .00798 L
.74004 .00959 L
.74008 .01117 L
.74039 .02304 L
.74067 .03266 L
.74094 .04061 L
.74109 .04405 L
.74124 .04708 L
.74132 .04837 L
.7414 .04958 L
.74148 .0505 L
.74156 .05117 L
.74163 .0517 L
.74167 .05192 L
.74171 .05208 L
.74178 .05226 L
.74185 .05228 L
.74189 .05223 L
.74194 .05211 L
.74198 .05194 L
Mistroke
.74202 .05174 L
.74209 .05125 L
.74217 .05056 L
.74233 .04859 L
.74251 .04566 L
.74282 .03866 L
.74312 .03049 L
.74342 .02098 L
.74358 .01571 L
.74366 .01279 L
.74375 .01005 L
.74382 .00819 L
.74389 .01072 L
.74406 .016 L
.74434 .02474 L
.74463 .03229 L
.74492 .03862 L
.74505 .04068 L
.74518 .04248 L
.74526 .04332 L
.74532 .04396 L
.74539 .04446 L
.74546 .04488 L
.74553 .04518 L
.7456 .04534 L
.74564 .04538 L
.74568 .04538 L
.74575 .04528 L
.74583 .04503 L
.7459 .04466 L
.74598 .04412 L
.74606 .04338 L
.74621 .04165 L
.74635 .03957 L
.74661 .03463 L
.74722 .01932 L
.74737 .01511 L
.74753 .01053 L
.74758 .00918 L
.74762 .00797 L
.74766 .00911 L
.7477 .01035 L
.74786 .01493 L
.74817 .02303 L
.74849 .03042 L
.74877 .03538 L
.74893 .03755 L
.749 .03835 L
.74908 .03911 L
.74915 .03972 L
Mistroke
.74922 .04018 L
.74929 .04052 L
.74936 .04077 L
.74942 .04091 L
.74949 .04095 L
.74955 .0409 L
.74961 .04076 L
.74968 .0405 L
.74976 .0401 L
.74984 .03954 L
.74991 .03891 L
.75019 .03557 L
.75034 .03307 L
.75049 .0304 L
.75082 .02333 L
.7511 .0164 L
.75125 .01255 L
.75133 .01051 L
.75137 .0094 L
.75141 .00836 L
.75148 .0093 L
.75156 .01125 L
.75169 .01462 L
.75195 .0209 L
.75225 .02722 L
.75253 .03195 L
.75267 .03392 L
.75283 .03565 L
.75291 .03632 L
.75299 .0369 L
.75304 .03717 L
.75308 .03737 L
.75312 .03753 L
.75316 .03767 L
.75324 .03783 L
.75331 .03787 L
.75335 .03784 L
.75339 .03778 L
.75347 .03759 L
.75354 .03729 L
.75361 .03692 L
.75376 .03577 L
.75389 .0344 L
.75402 .03284 L
.7543 .02836 L
.75488 .01644 L
.75502 .01303 L
.7551 .01114 L
.75518 .00936 L
.75522 .00843 L
Mistroke
.75526 .00844 L
.75531 .00954 L
.75535 .01054 L
.75551 .0142 L
.75579 .02045 L
.7561 .0264 L
.75638 .0307 L
.75652 .03233 L
.75665 .03357 L
.75672 .03414 L
.75679 .03465 L
.75685 .03499 L
.75692 .03528 L
.757 .0355 L
.75708 .03562 L
.75715 .03562 L
.75722 .03553 L
.75729 .03533 L
.75733 .03519 L
.75738 .03501 L
.75752 .03412 L
.7576 .03347 L
.75769 .03263 L
.75785 .0308 L
.75816 .02617 L
.75844 .02091 L
.75872 .01507 L
.75886 .01208 L
.75898 .00933 L
.75905 .00804 L
.75912 .00946 L
.75926 .01254 L
.75956 .01878 L
.75986 .02433 L
.76014 .02859 L
.76029 .03044 L
.76043 .03181 L
.76059 .03294 L
.76068 .03339 L
.76072 .03357 L
.76076 .0337 L
.76083 .03387 L
.76089 .03395 L
.76096 .03396 L
.76103 .03387 L
.7611 .03371 L
.76117 .03347 L
.76123 .0332 L
.76129 .03284 L
.76143 .03177 L
Mistroke
.76159 .03025 L
.76187 .02664 L
.76248 .01572 L
.76265 .01229 L
.76274 .01038 L
.76279 .00944 L
.76283 .00858 L
.7629 .00883 L
.76298 .01047 L
.76315 .0139 L
.76345 .01975 L
.76377 .02512 L
.76393 .0273 L
.76408 .02905 L
.76421 .03034 L
.76429 .03095 L
.76436 .03144 L
.76443 .03186 L
.7645 .03218 L
.76457 .03243 L
.76464 .03261 L
.76471 .03269 L
.76478 .03269 L
.76484 .03262 L
.7649 .03249 L
.76498 .03223 L
.76505 .0319 L
.76519 .03106 L
.76534 .02982 L
.7655 .02813 L
.76609 .01911 L
.7664 .01316 L
.76649 .01137 L
.76658 .00966 L
.76666 .00812 L
.7667 .00862 L
.76674 .00942 L
.76736 .02102 L
.76766 .02551 L
.76794 .02874 L
.76808 .02995 L
.76824 .03091 L
.76828 .03111 L
.76832 .0313 L
.76836 .03144 L
.7684 .03156 L
.76845 .03165 L
.76848 .0317 L
.76856 .03175 L
.7686 .03174 L
Mistroke
.76864 .03169 L
.76872 .03154 L
.76876 .03141 L
.7688 .03127 L
.76889 .03084 L
.76905 .02985 L
.76921 .02839 L
.76953 .02457 L
.76982 .02003 L
.77014 .01439 L
.77031 .01121 L
.77039 .00951 L
.77044 .00858 L
.77049 .00816 L
.77056 .00961 L
.77065 .01119 L
.77079 .01392 L
.77107 .01898 L
.7714 .02398 L
.7717 .02756 L
.77184 .0289 L
.772 .02998 L
.77208 .03039 L
.77216 .03069 L
.7722 .03082 L
.77224 .03091 L
.77229 .03099 L
.77233 .03103 L
.7724 .03104 L
.77248 .03095 L
.77255 .03079 L
.77262 .03058 L
.77269 .03024 L
.77278 .02977 L
.77293 .02866 L
.77321 .02575 L
.77351 .02164 L
.77378 .01713 L
.77404 .01245 L
.77419 .00977 L
.77423 .00903 L
.77427 .00825 L
.77434 .00903 L
.77441 .01028 L
.77447 .01145 L
.77462 .01407 L
.77494 .01955 L
.77523 .02386 L
.77549 .0269 L
.77562 .02813 L
Mistroke
.77576 .02917 L
.77583 .02961 L
.7759 .02993 L
.77597 .03019 L
.77603 .03037 L
.77611 .0305 L
.77618 .03054 L
.77625 .03051 L
.77629 .03046 L
.77633 .03038 L
.77641 .03015 L
.77648 .02987 L
.77656 .02946 L
.77665 .02893 L
.77694 .02626 L
.77724 .02257 L
.7775 .0185 L
.77781 .0131 L
.77798 .01011 L
.77802 .00938 L
.77806 .00859 L
.77811 .00814 L
.77815 .00895 L
.77847 .01471 L
.77876 .01958 L
.77906 .02387 L
.77937 .02735 L
.77954 .02866 L
.77963 .02923 L
.77972 .02965 L
.77976 .02981 L
.7798 .02994 L
.77987 .03011 L
.77995 .03021 L
.78 .03022 L
.78004 .03021 L
.78012 .03011 L
.78016 .03002 L
.7802 .02991 L
.78027 .02965 L
.78035 .02929 L
.78048 .02847 L
.78063 .02728 L
.78095 .02369 L
.78125 .01933 L
.78155 .01429 L
.78171 .01145 L
.7818 .00987 L
.78184 .00909 L
.78188 .00838 L
Mistroke
.78195 .00879 L
.78203 .01018 L
.78219 .0131 L
.78248 .018 L
.78276 .02227 L
.78302 .02555 L
.78316 .02701 L
.78329 .0281 L
.78344 .02904 L
.78352 .02943 L
.78359 .02972 L
.78366 .02991 L
.78374 .03003 L
.78381 .03007 L
.78387 .03004 L
.78395 .02992 L
.78399 .02982 L
.78403 .02971 L
.7841 .02943 L
.78418 .02905 L
.78434 .02794 L
.7845 .02655 L
.7848 .02313 L
.78533 .0149 L
.78547 .01235 L
.78555 .01092 L
.78563 .00955 L
.7857 .00827 L
.78577 .009 L
.78584 .01026 L
.78591 .01142 L
.78649 .02121 L
.7868 .02515 L
.78695 .02678 L
.78712 .02818 L
.78719 .02866 L
.78726 .02909 L
.78733 .02942 L
.78739 .02967 L
.78745 .02984 L
.78751 .02998 L
.78758 .03006 L
.78764 .03006 L
.78772 .02999 L
.78779 .02985 L
.78786 .02962 L
.78794 .02928 L
.78808 .0285 L
.78823 .02735 L
.78854 .02397 L
Mistroke
.78884 .01977 L
.78911 .01533 L
.78926 .01272 L
.7894 .0102 L
.78947 .0089 L
.78955 .00839 L
.78959 .00915 L
.78963 .00995 L
.78971 .01138 L
.79 .01647 L
.79035 .02187 L
.79066 .02583 L
.7908 .02725 L
.79095 .0285 L
.79102 .02896 L
.7911 .02938 L
.79117 .02969 L
.79123 .02991 L
.7913 .0301 L
.79138 .0302 L
.79145 .03022 L
.79152 .03016 L
.79156 .0301 L
.7916 .03001 L
.79168 .02978 L
.79176 .0294 L
.79184 .02896 L
.79199 .02794 L
.79212 .02677 L
.79241 .02333 L
.79295 .01494 L
.79309 .01235 L
.79323 .00983 L
.79331 .00843 L
.79335 .00824 L
.79339 .00897 L
.79353 .01163 L
.79408 .02094 L
.79439 .02519 L
.79468 .02817 L
.79483 .02924 L
.79491 .0297 L
.79499 .03004 L
.79507 .0303 L
.79511 .0304 L
.79515 .03048 L
.7952 .03052 L
.79524 .03054 L
.79528 .03053 L
.79532 .0305 L
Mistroke
.79539 .03037 L
.79547 .03016 L
.79554 .02989 L
.7956 .02957 L
.79576 .02853 L
.79591 .02723 L
.79621 .0238 L
.79653 .01898 L
.79681 .01415 L
.79696 .01135 L
.79704 .00995 L
.7971 .00865 L
.79717 .00846 L
.79724 .00976 L
.79739 .01247 L
.79764 .01704 L
.79793 .02185 L
.79821 .02566 L
.79836 .02739 L
.79853 .02891 L
.79861 .02946 L
.79868 .02995 L
.79876 .03034 L
.79882 .03061 L
.79889 .03082 L
.79895 .03096 L
.79902 .03103 L
.79909 .03103 L
.79916 .03096 L
.79923 .03082 L
.79929 .03062 L
.79935 .03038 L
.79949 .02958 L
.79965 .02837 L
.79993 .02533 L
.80023 .02107 L
.80055 .0156 L
.8007 .01272 L
.80078 .01127 L
.80085 .00992 L
.80091 .00868 L
.80098 .00851 L
.80105 .00983 L
.80113 .01128 L
.80173 .02204 L
.80189 .02449 L
.80207 .02679 L
.80223 .02849 L
.80239 .02993 L
.80247 .03048 L
Mistroke
.80255 .03092 L
.80262 .03123 L
.80269 .03149 L
.80276 .03165 L
.80283 .03174 L
.8029 .03174 L
.80297 .03167 L
.80301 .03159 L
.80305 .03149 L
.80312 .03123 L
.80321 .03085 L
.80329 .03031 L
.80345 .02906 L
.8036 .02758 L
.80425 .0178 L
.80441 .01491 L
.80457 .01172 L
.80464 .01038 L
.80471 .00893 L
.80475 .00809 L
.80479 .00854 L
.80487 .01003 L
.80546 .02125 L
.80577 .02602 L
.80593 .0281 L
.8061 .02993 L
.80624 .0311 L
.80632 .0316 L
.8064 .03204 L
.80648 .03234 L
.80654 .03254 L
.80661 .03265 L
.80668 .0327 L
.80674 .03267 L
.80681 .03256 L
.80688 .03238 L
.80694 .03216 L
.80701 .03182 L
.80708 .03136 L
.80722 .03029 L
.80752 .02705 L
.80779 .02297 L
.80812 .01709 L
.80842 .0111 L
.80849 .00959 L
.80857 .00797 L
.80861 .00874 L
.80865 .00967 L
.80873 .01131 L
.80903 .01736 L
Mistroke
.80935 .02327 L
.80969 .02839 L
.80983 .0301 L
.80998 .0316 L
.81006 .0323 L
.81014 .03284 L
.81022 .03328 L
.81029 .03359 L
.81036 .03379 L
.81043 .03392 L
.8105 .03396 L
.81058 .03391 L
.81064 .03377 L
.81072 .03354 L
.81079 .03323 L
.81085 .03288 L
.81101 .03169 L
.81116 .03021 L
.81149 .02564 L
.8121 .01403 L
.81225 .01082 L
.81232 .00918 L
.81237 .00824 L
.81241 .00851 L
.81245 .00947 L
.81249 .01035 L
.81258 .01231 L
.81274 .01574 L
.81302 .02164 L
.81334 .02723 L
.81348 .02944 L
.81363 .03146 L
.81378 .033 L
.81391 .03414 L
.81404 .03492 L
.81411 .03523 L
.81417 .03544 L
.81424 .03558 L
.81431 .03563 L
.81438 .03558 L
.81446 .03544 L
.81453 .03518 L
.81457 .035 L
.81461 .03478 L
.81476 .03376 L
.81493 .0321 L
.81509 .0301 L
.81538 .02551 L
.81569 .01942 L
.81583 .0163 L
Mistroke
.81599 .01274 L
.81606 .01107 L
.81613 .00928 L
.81621 .00829 L
.81627 .00984 L
.8168 .02204 L
.8171 .02787 L
.81741 .03281 L
.81754 .03441 L
.81767 .03581 L
.81775 .03645 L
.81782 .03694 L
.8179 .03732 L
.81796 .0376 L
.81804 .03778 L
.81812 .03787 L
.81816 .03786 L
.8182 .03782 L
.81828 .03765 L
.81835 .03735 L
.81843 .03696 L
.81857 .03594 L
.81873 .03427 L
.81888 .03229 L
.81922 .0264 L
.81952 .01981 L
.81968 .01596 L
.81985 .01172 L
.81992 .00988 L
.82 .00797 L
.82005 .00911 L
.82009 .01015 L
.82016 .01219 L
.82045 .01946 L
.82073 .02593 L
.82103 .03203 L
.82116 .03438 L
.82131 .03653 L
.82143 .03806 L
.82157 .03938 L
.82164 .03993 L
.82171 .04034 L
.82179 .04066 L
.82186 .04087 L
.82194 .04095 L
.822 .04091 L
.82207 .04079 L
.82213 .04056 L
.82221 .0402 L
.82229 .03966 L
Mistroke
.82245 .03814 L
.8226 .03624 L
.82274 .03404 L
.82327 .02274 L
.82355 .01543 L
.82362 .0134 L
.8237 .01117 L
.82377 .00905 L
.82384 .00879 L
.82388 .0099 L
.82392 .01112 L
.824 .01358 L
.82415 .01788 L
.82445 .02589 L
.82477 .03363 L
.82494 .03722 L
.82511 .0401 L
.82527 .04228 L
.82535 .0432 L
.82544 .04401 L
.82551 .04455 L
.82555 .04479 L
.82559 .045 L
.82567 .04526 L
.82574 .04537 L
.82581 .04537 L
.82589 .04522 L
.82592 .04508 L
.82597 .0449 L
.82604 .04445 L
.82612 .04386 L
.82619 .04317 L
.82632 .04155 L
.8266 .0368 L
.82691 .02969 L
.8272 .02124 L
.82737 .01611 L
.82745 .0135 L
.82753 .01104 L
.8276 .00874 L
.82767 .00961 L
.82771 .01102 L
.82775 .01236 L
.82783 .01485 L
.8281 .02387 L
.82864 .03943 L
.82892 .04561 L
.82908 .0483 L
.82923 .05022 L
.82931 .05101 L
Mistroke
.82938 .05159 L
.82945 .05196 L
.82953 .05221 L
.82956 .05228 L
.82961 .05229 L
.82965 .05226 L
.82969 .05217 L
.82977 .05188 L
.82981 .05164 L
.82985 .05138 L
.82992 .05079 L
.82999 .05002 L
.83012 .04823 L
.83028 .04545 L
.83042 .04235 L
.83096 .02603 L
.83125 .015 L
.83132 .01217 L
.8314 .0091 L
.83144 .00856 L
.83148 .01019 L
.83156 .01341 L
.83212 .03568 L
.83242 .04653 L
.83259 .05148 L
.83276 .056 L
.83291 .05923 L
.83299 .06066 L
.83308 .06197 L
.83315 .06294 L
.83323 .06363 L
.8333 .06412 L
.83337 .06444 L
.83344 .06457 L
.83349 .06454 L
.83352 .06446 L
.83359 .06416 L
.83367 .06363 L
.83374 .06297 L
.8338 .06219 L
.83394 .05984 L
.8341 .05643 L
.83424 .05254 L
.83456 .04128 L
.83483 .02925 L
.83497 .02218 L
.83505 .01812 L
.83512 .0142 L
.83519 .0104 L
.83527 .00966 L
Mistroke
.83534 .01351 L
.8354 .01709 L
.83566 .03179 L
.83621 .06128 L
.83651 .0748 L
.8368 .0847 L
.83696 .08877 L
.83705 .09052 L
.83713 .09176 L
.8372 .09252 L
.83728 .09303 L
.83732 .09316 L
.83736 .09321 L
.83744 .09303 L
.83751 .09253 L
.83755 .09212 L
.83759 .09164 L
.83767 .09039 L
.83775 .08866 L
.8379 .08443 L
.83804 .07937 L
.8386 .04658 L
.83888 .02326 L
.83896 .01616 L
.839 .01213 L
.83904 .00823 L
.83912 .0154 L
.83919 .02271 L
.83985 .09658 L
.84045 .16943 L
.84103 .2346 L
.84134 .26502 L
.84164 .28879 L
.8419 .30465 L
.84203 .31115 L
.84217 .3169 L
.84232 .32131 L
.8424 .32305 L
.84247 .32424 L
.84254 .32498 L
.84261 .32533 L
.84268 .32536 L
.84275 .32502 L
.84282 .32434 L
.84289 .32322 L
.84296 .32179 L
.84303 .32019 L
.84318 .31506 L
.84333 .30865 L
.84363 .29182 L
Mistroke
.84395 .26792 L
.84506 .15798 L
.84567 .09351 L
.84625 .03985 L
.8464 .0273 L
.84656 .01509 L
.8466 .01219 L
.84665 .00916 L
.8467 .00995 L
.84674 .01287 L
.84691 .02272 L
.8472 .03707 L
.84751 .04803 L
.84766 .05182 L
.84774 .05342 L
.84783 .05484 L
.8479 .05586 L
.84798 .05658 L
.84805 .05707 L
.84812 .05739 L
.84816 .05748 L
.8482 .05751 L
.84824 .05749 L
.84828 .0574 L
.84836 .0571 L
.8484 .05685 L
.84844 .05658 L
.84852 .05585 L
.84861 .05483 L
.84879 .05215 L
.84909 .04602 L
.84941 .03782 L
.85 .02113 L
.85015 .01677 L
.85031 .01226 L
.85039 .01014 L
.85047 .0082 L
.85053 .00937 L
.85061 .01116 L
.85093 .01834 L
.85127 .02433 L
.85142 .02634 L
.85157 .02812 L
.85166 .02896 L
.85174 .02962 L
.85182 .03018 L
.8519 .03061 L
.85197 .03091 L
.85204 .03116 L
.85212 .03132 L
Mistroke
.85216 .03137 L
.8522 .0314 L
.85227 .0314 L
.85233 .03133 L
.85241 .03118 L
.85248 .03096 L
.85255 .03066 L
.85263 .03026 L
.85278 .02931 L
.85306 .02687 L
.85338 .02303 L
.85367 .01871 L
.85395 .01408 L
.85408 .01167 L
.85421 .0094 L
.85427 .00815 L
.85434 .00892 L
.85441 .01019 L
.85448 .01159 L
.85478 .01729 L
.85539 .0283 L
.85569 .03272 L
.85596 .03586 L
.8561 .03704 L
.85618 .03751 L
.85625 .03792 L
.85633 .03823 L
.8564 .03841 L
.85645 .03847 L
.85649 .03849 L
.85656 .03844 L
.8566 .03836 L
.85664 .03824 L
.85669 .03808 L
.85673 .03788 L
.8568 .03744 L
.85688 .03683 L
.85706 .03486 L
.85723 .03237 L
.85751 .02642 L
.85778 .01894 L
.85793 .01403 L
.85801 .01123 L
.85805 .00964 L
.85809 .00812 L
.85816 .0105 L
.85824 .01363 L
.85837 .01943 L
.85902 .05176 L
.85962 .08529 L
Mistroke
.86025 .1192 L
.86056 .13377 L
.86084 .1453 L
.8611 .15365 L
.86123 .15726 L
.86138 .16048 L
.86152 .16297 L
.86159 .16384 L
.86166 .16462 L
.86174 .16525 L
.86178 .1655 L
.86182 .16568 L
.86189 .16586 L
.86196 .16585 L
.86203 .16565 L
.86208 .16544 L
.86212 .16518 L
.8622 .1645 L
.86228 .16351 L
.86244 .16105 L
.86258 .15807 L
.86292 .14812 L
.86325 .1355 L
.86446 .07177 L
.86504 .03974 L
.86536 .02378 L
.86551 .0166 L
.86558 .0136 L
.86565 .01042 L
.86572 .00806 L
.86578 .01042 L
.86591 .01527 L
.86618 .02416 L
.86646 .03131 L
.86662 .03442 L
.86676 .03669 L
.8669 .03838 L
.86698 .03913 L
.86705 .03969 L
.86713 .04014 L
.8672 .04042 L
.86724 .04053 L
.86728 .04061 L
.86736 .04064 L
.86743 .04055 L
.8675 .04037 L
.86757 .04006 L
.86765 .03966 L
.86777 .0387 L
.86791 .03734 L
Mistroke
.86823 .03313 L
.86856 .0274 L
.86888 .02127 L
.86916 .01536 L
.8693 .01245 L
.86938 .01092 L
.86946 .00931 L
.86952 .00794 L
.8696 .00945 L
.86973 .01203 L
.87003 .01733 L
.87034 .02222 L
.87064 .02583 L
.87077 .02709 L
.87091 .02822 L
.87105 .02904 L
.87111 .02935 L
.87117 .02959 L
.87124 .0298 L
.87131 .02994 L
.87137 .03003 L
.87145 .03005 L
.87152 .02999 L
.87159 .02988 L
.87167 .02966 L
.87174 .02938 L
.87187 .02871 L
.87202 .0277 L
.87217 .0263 L
.87234 .02447 L
.87264 .02037 L
.87298 .01464 L
.87315 .0115 L
.87323 .01007 L
.87327 .0093 L
.87331 .00847 L
.87338 .00887 L
.87345 .01026 L
.8736 .01334 L
.87391 .01984 L
.87452 .03151 L
.87469 .03414 L
.87487 .03654 L
.87502 .03822 L
.8751 .03894 L
.87519 .03958 L
.87526 .04002 L
.8753 .04022 L
.87534 .04039 L
.87542 .0406 L
Mistroke
.87549 .04069 L
.87556 .04067 L
.87563 .04054 L
.8757 .04032 L
.87576 .03998 L
.87584 .03947 L
.87593 .03874 L
.8761 .03672 L
.87625 .03419 L
.8764 .03125 L
.8767 .02348 L
.87686 .01846 L
.87695 .01545 L
.87703 .01245 L
.8771 .00973 L
.87717 .0092 L
.87722 .0109 L
.87726 .01274 L
.87734 .01612 L
.87762 .02958 L
.87874 .09073 L
.87931 .1212 L
.87963 .13572 L
.87992 .14728 L
.8802 .15578 L
.88036 .1595 L
.8805 .1622 L
.88062 .16391 L
.88069 .16465 L
.88076 .16518 L
.88083 .16558 L
.88089 .1658 L
.88096 .16587 L
.88103 .16577 L
.8811 .16546 L
.88115 .16519 L
.88118 .16489 L
.88126 .1642 L
.88133 .16327 L
.88146 .16117 L
.88161 .1582 L
.88192 .14922 L
.88222 .13814 L
.88333 .08171 L
.88396 .04651 L
.88427 .03042 L
.8844 .02379 L
.88455 .01686 L
.88462 .01402 L
.88469 .01106 L
Mistroke
.88475 .00836 L
.88481 .00991 L
.88509 .01981 L
.88537 .02805 L
.88567 .03448 L
.88582 .03691 L
.88597 .03864 L
.88603 .03923 L
.8861 .03974 L
.88618 .04017 L
.88624 .04045 L
.88632 .04064 L
.88639 .0407 L
.88647 .04063 L
.88654 .04047 L
.88661 .04016 L
.8867 .03968 L
.88686 .03846 L
.887 .03693 L
.88713 .03527 L
.88743 .03071 L
.88796 .02055 L
.88826 .01442 L
.88842 .01108 L
.8885 .00947 L
.88857 .00802 L
.88863 .00917 L
.8887 .0104 L
.88883 .01303 L
.88912 .01817 L
.88941 .02257 L
.88972 .02623 L
.88989 .02768 L
.88997 .02831 L
.89006 .02889 L
.89015 .02931 L
.89023 .02962 L
.8903 .02985 L
.89038 .02998 L
.89045 .03004 L
.89049 .03005 L
.89053 .03002 L
.8906 .02993 L
.89068 .02976 L
.89075 .02954 L
.89081 .02928 L
.89095 .02848 L
.89111 .02731 L
.89125 .02598 L
.89157 .02213 L
Mistroke
.89184 .01797 L
.89214 .01273 L
.89227 .01012 L
.89234 .00877 L
.89241 .00861 L
.89248 .00992 L
.89255 .01134 L
.89267 .01393 L
.8933 .02659 L
.8936 .03197 L
.89388 .03599 L
.89402 .03762 L
.89417 .03903 L
.89425 .03963 L
.89433 .04007 L
.89441 .04037 L
.89448 .04057 L
.89456 .04064 L
.89461 .04062 L
.89465 .04057 L
.89473 .04035 L
.8948 .04001 L
.89484 .03977 L
.89489 .03946 L
.89497 .03878 L
.89515 .03664 L
.89545 .03121 L
.8956 .02758 L
.89577 .02291 L
.89595 .01705 L
.89604 .0139 L
.89612 .01087 L
.89615 .00938 L
.8962 .00815 L
.89627 .01126 L
.89644 .01854 L
.89765 .08341 L
.89827 .11694 L
.89884 .14296 L
.89913 .15285 L
.89928 .15694 L
.89944 .16057 L
.89961 .16336 L
.8997 .16445 L
.89975 .16486 L
.89979 .16519 L
.89983 .16544 L
.89987 .16564 L
.89994 .16585 L
.89998 .16588 L
Mistroke
.90003 .16584 L
.90011 .1656 L
.90018 .16516 L
.90022 .16483 L
.90026 .16447 L
.9004 .16262 L
.90054 .1603 L
.90068 .15717 L
.90097 .14867 L
.90129 .13643 L
.90239 .0796 L
.90295 .04817 L
.90326 .03223 L
.90355 .01873 L
.9037 .01229 L
.90374 .01053 L
.90378 .0089 L
.90386 .00992 L
.9039 .01146 L
.90395 .01304 L
.90403 .01576 L
.9042 .02135 L
.90449 .02867 L
.90465 .03191 L
.9048 .03434 L
.90488 .03532 L
.90496 .03622 L
.90503 .03687 L
.9051 .03745 L
.90515 .03774 L
.90519 .03796 L
.90523 .03813 L
.90527 .03828 L
.90535 .03845 L
.90539 .03849 L
.90543 .03849 L
.90551 .0384 L
.90558 .03822 L
.90564 .03796 L
.90571 .0376 L
.90587 .03646 L
.90602 .03505 L
.90628 .03188 L
.90656 .02755 L
.90714 .01716 L
.90743 .01149 L
.9075 .01011 L
.90758 .00866 L
.90762 .00805 L
.90767 .0088 L
Mistroke
.90774 .01025 L
.9083 .01972 L
.90861 .02409 L
.90877 .02604 L
.90895 .02782 L
.9091 .02911 L
.90918 .02968 L
.90926 .03022 L
.90934 .03062 L
.90941 .03092 L
.90949 .03115 L
.90955 .0313 L
.90963 .03139 L
.90967 .03141 L
.90971 .0314 L
.90978 .03133 L
.90986 .03117 L
.90993 .03095 L
.90999 .03068 L
.91013 .02984 L
.91029 .02856 L
.91043 .02706 L
.91075 .02252 L
.91102 .01741 L
.91117 .01429 L
.91124 .01248 L
.91132 .01071 L
.91138 .00912 L
.91145 .00851 L
.91153 .01051 L
.9116 .01239 L
.91186 .0196 L
.91241 .03545 L
.91271 .04346 L
.913 .04987 L
.91316 .05282 L
.91325 .05412 L
.91334 .05529 L
.91341 .05609 L
.91345 .05645 L
.9135 .05678 L
.91357 .05722 L
.91364 .05745 L
.91372 .05751 L
.91376 .05745 L
.9138 .05733 L
.91388 .05695 L
.91396 .05632 L
.91403 .05555 L
.91409 .05464 L
Mistroke
.91424 .05189 L
.91439 .04823 L
.91455 .04322 L
.91483 .0313 L
.91499 .02335 L
.91513 .01486 L
.91517 .01236 L
.91521 .00963 L
.91526 .00932 L
.9153 .01224 L
.91546 .02353 L
.91657 .12843 L
.91718 .19387 L
.91776 .25117 L
.91828 .29203 L
.91842 .30077 L
.91857 .30874 L
.91872 .31487 L
.91885 .31931 L
.91892 .32126 L
.919 .32297 L
.91908 .32424 L
.91912 .32473 L
.91916 .32507 L
.91924 .32538 L
.91931 .32531 L
.91938 .32479 L
.91946 .32387 L
.91953 .3227 L
.9196 .32109 L
.91973 .31727 L
.91986 .31186 L
.92002 .30434 L
.92033 .28408 L
.92066 .25576 L
.92127 .19145 L
.9219 .11618 L
.92248 .04765 L
.92263 .0312 L
.92277 .01643 L
.92285 .00861 L
.92289 .01155 L
.92294 .01543 L
.92308 .02886 L
.9234 .0538 L
.92358 .06507 L
.92375 .07405 L
.92389 .08049 L
.92405 .086 L
.92412 .08793 L
Mistroke
.9242 .08965 L
.92427 .09094 L
.92433 .09187 L
.9244 .09262 L
.92448 .09308 L
.92455 .09321 L
.92462 .09306 L
.92468 .09268 L
.92474 .09212 L
.92481 .0913 L
.92488 .09016 L
.92504 .08666 L
.92521 .08153 L
.92553 .06917 L
.92612 .03881 L
.92639 .02331 L
.92647 .01922 L
.92654 .01478 L
.92661 .0109 L
.92669 .00907 L
.92673 .01157 L
.92677 .01381 L
.92686 .01812 L
.92701 .02598 L
.92731 .03979 L
.92763 .05128 L
.9278 .05629 L
.92796 .05988 L
.92811 .0622 L
.92819 .06317 L
.92826 .06385 L
.9283 .06412 L
.92834 .06432 L
.92841 .06453 L
.92849 .06454 L
.92854 .06444 L
.92858 .06428 L
.92865 .06386 L
.92872 .06322 L
.92879 .06251 L
.92886 .06158 L
.92901 .0589 L
.92916 .05572 L
.9297 .03894 L
.93001 .02708 L
.9303 .0152 L
.93038 .01198 L
.93042 .01023 L
.93046 .0086 L
.9305 .00903 L
Mistroke
.93055 .01095 L
.93063 .01429 L
.93094 .02581 L
.93124 .03565 L
.9314 .04008 L
.93157 .04411 L
.93173 .04727 L
.93187 .04949 L
.93194 .05033 L
.93202 .05108 L
.93209 .05162 L
.93216 .05198 L
.93222 .0522 L
.93229 .05229 L
.93236 .05225 L
.93242 .0521 L
.93249 .05179 L
.93256 .05129 L
.93264 .05067 L
.9327 .04997 L
.93283 .04822 L
.93298 .04576 L
.93327 .0393 L
.93384 .02267 L
.93413 .01321 L
.93421 .01059 L
.93425 .00915 L
.93429 .00807 L
.93437 .01069 L
.93444 .01304 L
.93475 .02288 L
.9351 .03212 L
.93525 .03559 L
.93541 .03875 L
.93555 .04099 L
.9357 .04293 L
.93577 .04374 L
.93585 .04434 L
.93592 .04479 L
.93599 .04513 L
.93606 .04532 L
.93612 .04539 L
.93619 .04535 L
.93626 .04518 L
.93634 .04486 L
.93638 .04463 L
.93642 .04437 L
.93658 .04289 L
.93672 .04112 L
.93688 .03876 L
Mistroke
.93745 .02602 L
.9377 .01923 L
.93783 .01546 L
.93798 .01135 L
.93806 .00908 L
.93813 .00887 L
.9382 .01094 L
.93827 .01288 L
.93858 .02125 L
.93884 .02772 L
.93913 .03344 L
.93929 .03605 L
.93944 .03796 L
.93951 .03872 L
.93959 .03942 L
.93966 .03996 L
.93973 .04036 L
.93981 .04069 L
.93985 .04081 L
.93989 .0409 L
.93994 .04094 L
.93998 .04094 L
.94002 .0409 L
.94007 .04081 L
.94015 .04055 L
.94019 .04037 L
.94023 .04012 L
.94038 .03898 L
.94052 .03748 L
.94068 .0354 L
.94099 .02996 L
.94154 .01719 L
.94171 .01307 L
.94179 .01102 L
.94186 .00912 L
.9419 .00806 L
.94194 .00893 L
.94203 .01128 L
.94219 .0153 L
.94251 .02272 L
.9428 .02854 L
.94294 .03093 L
.94309 .03317 L
.94324 .03493 L
.94337 .03618 L
.94344 .03673 L
.94352 .03721 L
.94356 .03741 L
.9436 .03757 L
.94368 .03778 L
Mistroke
.94375 .03786 L
.94383 .03784 L
.9439 .0377 L
.94398 .03746 L
.94405 .03713 L
.94412 .03668 L
.94426 .03557 L
.94439 .03418 L
.94451 .03262 L
.94508 .02249 L
.94536 .01629 L
.94551 .01269 L
.94559 .01089 L
.94566 .00921 L
.94573 .00822 L
.9458 .00987 L
.94594 .01334 L
.9462 .01913 L
.94654 .02572 L
.9467 .02846 L
.94686 .03063 L
.94699 .03227 L
.94714 .03371 L
.94721 .03427 L
.94729 .03476 L
.94733 .03499 L
.94737 .03516 L
.94745 .03543 L
.94752 .03558 L
.94758 .03563 L
.94766 .03559 L
.94773 .03544 L
.94781 .03518 L
.94785 .03501 L
.94789 .03478 L
.94804 .03377 L
.94818 .03248 L
.94833 .03075 L
.94859 .02684 L
.94893 .02069 L
.94925 .01404 L
.94939 .011 L
.94946 .00933 L
.94953 .00811 L
.94961 .0098 L
.94969 .01165 L
.94984 .01483 L
.95014 .02085 L
.95047 .02646 L
.95062 .02858 L
Mistroke
.95077 .03049 L
.95092 .03191 L
.95106 .03291 L
.95113 .03329 L
.95121 .0336 L
.95128 .03382 L
.95132 .0339 L
.95136 .03394 L
.95143 .03396 L
.9515 .03389 L
.95157 .03372 L
.95165 .03346 L
.95171 .03316 L
.95178 .03276 L
.9519 .03186 L
.95218 .02895 L
.95247 .02469 L
.95274 .01994 L
.95303 .01422 L
.95318 .01105 L
.95322 .0102 L
.95327 .00929 L
.95331 .00842 L
.95335 .00825 L
.95342 .00973 L
.95349 .01128 L
.95363 .01398 L
.95388 .01899 L
.95417 .02396 L
.95445 .02782 L
.95459 .02942 L
.95475 .03082 L
.95481 .03132 L
.95489 .03176 L
.95495 .0321 L
.95502 .03235 L
.95509 .03255 L
.95517 .03268 L
.95523 .0327 L
.95531 .03264 L
.95539 .03247 L
.95546 .03222 L
.95554 .03185 L
.95563 .03133 L
.95577 .03022 L
.95592 .02868 L
.9562 .02505 L
.95673 .01608 L
.95687 .01335 L
.95695 .01181 L
Mistroke
.95702 .01034 L
.95709 .00897 L
.95717 .0084 L
.95723 .00976 L
.9573 .01102 L
.95763 .01729 L
.95792 .02237 L
.95822 .02652 L
.95837 .02827 L
.95854 .02976 L
.95862 .03036 L
.95871 .0309 L
.95879 .03128 L
.95887 .03153 L
.95891 .03163 L
.95895 .03169 L
.95902 .03175 L
.9591 .03171 L
.95915 .03165 L
.95919 .03156 L
.95926 .03134 L
.95933 .03103 L
.95947 .03026 L
.95961 .02912 L
.95977 .02755 L
.96031 .01982 L
.96062 .01427 L
.96079 .01103 L
.96088 .00942 L
.96095 .00794 L
.96103 .00935 L
.9611 .01084 L
.96127 .01391 L
.96155 .01897 L
.96184 .02351 L
.96212 .02698 L
.96227 .02847 L
.96235 .02913 L
.96244 .02973 L
.96252 .03019 L
.96259 .03052 L
.96266 .03077 L
.96273 .03093 L
.96279 .03102 L
.96286 .03104 L
.96294 .03098 L
.963 .03085 L
.96307 .03066 L
.96313 .03044 L
.96326 .02974 L
Mistroke
.9634 .02871 L
.96355 .02727 L
.96383 .02391 L
.96413 .01942 L
.96444 .01386 L
.96459 .01114 L
.96467 .00964 L
.96475 .00824 L
.96481 .00883 L
.96488 .01011 L
.96502 .01278 L
.96562 .02275 L
.9658 .0251 L
.96597 .02698 L
.96613 .02845 L
.96621 .02903 L
.96629 .02948 L
.96635 .02981 L
.96642 .03011 L
.96649 .03034 L
.96657 .03048 L
.96664 .03054 L
.96668 .03054 L
.96672 .03051 L
.9668 .03039 L
.96687 .0302 L
.96695 .02991 L
.96703 .02951 L
.96717 .02857 L
.96732 .02724 L
.96749 .02544 L
.96806 .01708 L
.96834 .01212 L
.96847 .00986 L
.96854 .00857 L
.9686 .00852 L
.96867 .0098 L
.96875 .01116 L
.9689 .01391 L
.96922 .01934 L
.96949 .02328 L
.96978 .0267 L
.96996 .02824 L
.97004 .02883 L
.97012 .02928 L
.97019 .02964 L
.97027 .02993 L
.97032 .03004 L
.97036 .03013 L
.9704 .03018 L
Mistroke
.97044 .03022 L
.97051 .03021 L
.97059 .03012 L
.97066 .02996 L
.97073 .02974 L
.9708 .0294 L
.97089 .02893 L
.97104 .02782 L
.97133 .02485 L
.97161 .02118 L
.97193 .01596 L
.97208 .01347 L
.97223 .01066 L
.97231 .00931 L
.97239 .00801 L
.97246 .00938 L
.97253 .01062 L
.97284 .01613 L
.97316 .02119 L
.9735 .02555 L
.97363 .02696 L
.97378 .02819 L
.97387 .02877 L
.97394 .0292 L
.97402 .02955 L
.9741 .0298 L
.97416 .02996 L
.97423 .03005 L
.9743 .03006 L
.97436 .03002 L
.97443 .0299 L
.97451 .02968 L
.97458 .0294 L
.97465 .02907 L
.9748 .02809 L
.97494 .0269 L
.97526 .02329 L
.9759 .01315 L
.97619 .00794 L
Mfstroke
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00E_ooool5o`0000?ooooo0_l0001>ooooo`?o00001?ooool2o`0004oooooo0_l0001Aoooo
o`?o00001?ooool2o`0004gooooo1Ol00003ooooo`;o0000?oooool005Oooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0001>ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000COooool01?l0003oooooooooool0001Aooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000COooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0003kooooo001@ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0004Kooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000COoo
ool01?l0003oooooooooool0001Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000C_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003kooooo001Iooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000COooool01?l0003oooooooooool0001Aooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000Coooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool0??ooool005Kooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0004kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001=
ooooo`04o`000?ooooooooooo`00057ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0001<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000noooo
o`00E_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000COooool2
o`0000Cooooo00Co0000oooooooooooo0000COooool01?l0003oooooooooool0001@ooooo`;o0000
1?ooool01?l0003oooooooooool0001<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000nooooo`00Eoooool3o`0000Cooooo0_l0001?ooooo`03o`000?oooooooooo
00?ooooo0_l0001?ooooo`;o0000D_ooool00ol0003oooooooooo`03ooooo`;o0000C_ooool3o`00
00Cooooo0_l0000oooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`008oooooooo`000<[o00003?oo
ool001Wooooo0_l00008ooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooo`00000<ooooo`006?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
0000013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooo`00000<ooooo`006?ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00[ooooo000Hooooo`04o`000?oooooooooo
o`0000Oooooo0ol00007ooooo`06ool00?ooooooo`00oooooooo003ooooo0_oo00001Oooooooo`00
oooooooo003ooooo00;oo`0000Goooooool00?ooooooo`00ooooo`02ool00003oooooooo003ooooo
00Gooooo00Coo`00oooooooo003oo`000oooool01_oo003oooooool00?oo003oooooool000?ooooo
0_oo00001?ooooooo`00oooooooo0002ooooo`07ool00?ooooooo`00oooooooo003oooooool00002
ooooo`04ool00?ooooooo`00ooooo`;oo`0000?oooooool00?ooool01?oo00000oooooooo`00oooo
o`02ool00005oooooooo003oooooool00?ooool00_oo00001Oooooooo`00oooooooo003ooooo00;o
o`0000Goooooool00?ooooooo`00ooooo`02ool00005oooooooo003oooooool00?ooool00_oo0000
1?ooooooo`00oooooooo0002ooooo`04ool00?ooooooo`00ooooo`;oo`000oooool01_oo003ooooo
ool00?oo003oooooool000?ooooo0_oo00001?ooooooo`00oooooooo0002ooooo`05ool00?oooooo
o`00oooooooo00001?ooool02Ooo003ooooooooooooo003oooooool00?ooooooo`00ooooo`02ool0
0005oooooooo003oooooool00?ooool00_oo00001Oooooooo`00oooooooo003ooooo00;oo`0000Go
ooooool00?ooooooo`00ooooo`02ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool0
0_oo00001?ooooooo`00oooooooo0006ooooo`04ool00?ooooooo`00ool000?ooooo00Woo`00oooo
oooo003oo`00oooooooo003oooooo`000?ooool00_oo00001?ooooooo`00oooooooo0002ooooo`05
ool00?ooooooo`00oooooooo00001_ooool2ool00005oooooooo003oooooool00?ooool01?oo0000
0oooooooo`00ooooo`02ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool01?oo0000
0oooooooo`00ooooo`02ool00005oooooooo003oooooool00?ooool00_oo00001?ooooooo`00oooo
oooo0004ooooo`04ool00?ooooooo`00ooooo`;oo`000oooool4ool0000;oooooooo003ooooooooo
oooo003oooooool00?ooooooo`00oooooooo00000_ooool01?oo003oooooool00?ooool2ool000Go
oooo0_oo00001Oooooooo`00oooooooo003ooooo00Coo`0000?oooooool00?ooool00_oo00000ooo
ooooo`00ooooo`02ool00005oooooooo003oooooool00?ooool00_oo00001Oooooooo`00oooooooo
003ooooo00;oo`0000Goooooool00?ooooooo`00ooooo`02ool00003oooooooo003ooooo00;ooooo
00Goo`00ooooooooooooo`00ooooo`04ool000?ooooo0_oo00001?ooooooo`00oooooooo0002oooo
o`07ool00?ooooooo`00oooooooo003oooooool00002ooooo`04ool00?ooooooo`00ooooo`;oo`00
0oooool01ooo003oooooool00?oo003oooooool00?ooool01?oo00000oooooooo`00ooooo`02ool0
0005oooooooo003oooooool00?ooool00_oo00000oooooooo`00ooooo`06ooooo`Co00003?ooool0
01Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`07ooooo`06ool00?oooooo
o`00oooooooo003ooooo0_oo00001Oooooooo`00oooooooo003ooooo00;oo`0000Goooooool00?oo
ooooo`00ooooo`02ool00004oooooooo003oooooool000;ooooo00Coo`00oooooooo003ooooo0ooo
0002ooooo`03ool00?ooooooo`0000?oo`000oooool2ool00004oooooooo003oooooool000;ooooo
00Ooo`00oooooooo003oooooool00?ooooooo`0000;ooooo00Coo`00oooooooo003ooooo0_oo0000
0oooooooo`00ooooo`04ool00003oooooooo003ooooo00;oo`0000Goooooool00?ooooooo`00oooo
o`02ool00005oooooooo003oooooool00?ooool00_oo00001Oooooooo`00oooooooo003ooooo00;o
o`0000?oooooool00?ooool01?oo00001?ooooooo`00oooooooo0002ooooo`04ool00?ooooooo`00
ooooo`;oo`000oooool01_oo003oooooool00?oo003oooooool000?ooooo0_oo00001?ooooooo`00
oooooooo0002ooooo`04ool00?ooooooo`00ooooo`?oo`000_ooool02Ooo003oooooool00?oo003o
ooooool00?ooooooo`00ooooo`02ool00005oooooooo003oooooool00?ooool00_oo00001Ooooooo
o`00oooooooo003ooooo00;oo`0000?oooooool00?ooool01?oo00000oooooooo`00ooooo`04ool0
0003oooooooo003ooooo00;oo`0000Koooooool00?ooooooo`00oooooooo0002ooooo`04ool00?oo
ooooo`00ooooo`;oo`000oooool02?oo003oooooool00?oo003oooooool00?oooooo00000ooo0000
1?ooooooo`00oooooooo0002ooooo`04ool00?ooooooo`00ooooo`;oo`000oooool02Ooo003ooooo
ool00?oo003oooooool00?ooooooo`00ooooo`02ool00005oooooooo003oooooool00?ooool00_oo
00000oooooooo`00ooooo`04ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool01?oo
00000oooooooo`00ooooo`02ool00006oooooooo003oooooool00?ooooooo`000_ooool00ooo003o
ooooool00003ool000?ooooo1?oo00002oooooooo`00ooooooooooooo`00oooooooo003oooooool0
0?ooooooo`0000;ooooo00Coo`00oooooooo003ooooo0_oo0003ooooo`09ool00?ooooooo`00ool0
0?ooooooo`00oooooooo003ooooo00;oo`0000?oooooool00?ooool01?oo00000oooooooo`00oooo
o`04ool00003oooooooo003ooooo00;oo`0000Goooooool00?ooooooo`00ooooo`02ool00005oooo
oooo003oooooool00?ooool00_oo00001_ooooooo`00oooooooo003oooooool000;ooooo00?oo`00
oooooooo00000ooo0003ooooo`;oo`0000Coooooool00?ooooooo`000_ooool01ooo003oooooool0
0?ooooooo`00oooooooo00000_ooool01?oo003oooooool00?ooool2ool000?ooooo00Ooo`00oooo
oooo003oo`00oooooooo003ooooo00Coo`0000?oooooool00?ooool01?oo00000oooooooo`00oooo
o`02ool00003oooooooo003ooooo00Wooooo00?o0000ooooooooool02_ooool001Sooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`07ooooo`06ool00?ooooooo`00oooooooo003o
oooo1?oo00000oooooooo`00ooooo`02ool00005oooooooo003oooooool00?ooool00_oo00001?oo
ooooo`00oooooooo0002ooooo`04ool00?ooooooo`00ooooo`?oo`000_ooool00ooo003oooooool0
0003ool000?ooooo1?oo00002oooooooo`00ooooooooooooo`00oooooooo003oooooool00?oooooo
o`0000;ooooo00?oo`00oooooooo00000ooo00000oooooooo`00ooooo`04ool00003oooooooo003o
oooo00;oo`0000Goooooool00?ooooooo`00ooooo`02ool00005oooooooo003oooooool00?ooool0
0_oo00000oooooooo`00ooooo`04ool00003oooooooo003ooooo00Coo`0000Coooooool00?oooooo
o`000_ooool01?oo003oooooool00?ooool2ool000?ooooo00?oo`00oooooooo00000ooo0003oooo
o`;oo`0000Coooooool00?ooooooo`000_ooool01?oo003oooooool00?ooool3ool000;ooooo00?o
o`00oooooooo00000ooo00000oooooooo`00ooooo`02ool00005oooooooo003oooooool00?ooool0
0_oo00000oooooooo`00ooooo`04ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool0
1?oo00000oooooooo`00ooooo`02ool00006oooooooo003oooooool00?ooooooo`000_ooool01?oo
003oooooool00?ooool2ool000?ooooo1?oo00001?ooooooo`00ooooool00003ool00004oooooooo
003oooooool000;ooooo00Coo`00oooooooo003ooooo0_oo0003ooooo`09ool00?ooooooo`00ool0
0?ooooooo`00oooooooo003ooooo00;oo`0000Goooooool00?ooooooo`00ooooo`02ool00003oooo
oooo003ooooo00Coo`0000?oooooool00?ooool01?oo00000oooooooo`00ooooo`04ool00003oooo
oooo003ooooo00;oo`0000Koooooool00?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`00
00?oo`000oooool4ool00004oooooooo003oooooooooo`?oo`0000Coooooool00?ooooooo`000_oo
ool01?oo003oooooool00?ooool2ool000?ooooo00Ooo`00oooooooo003oo`00oooooooo003ooooo
00Coo`0000?oooooool00?ooool01?oo00000oooooooo`00ooooo`04ool00003oooooooo003ooooo
00Coo`0000?oooooool00?ooool00_oo00000oooooooo`00ooooo`04ool00006oooooooo003ooooo
ool00?ooooooo`000_ooool00ooo003oooooool00003ool000?ooooo1?oo00002oooooooo`00oooo
ooooooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000ooo0003
ooooo`07ool00?ooooooo`00ool00?ooooooo`00ooooo`04ool00003oooooooo003ooooo00Coo`00
00?oooooool00?ooool00_oo00000oooooooo`00ooooo`09ooooo`03o`000?oooooooooo00[ooooo
000Iooooo`;o00002?ooool00ol0003oooooooooo`08ooooo`;oo`0000?oooooool00?ooool01?oo
00000oooooooo`00ool00002ool00003oooooooo003ooooo00Coo`0000Coooooool00?ooooooo`00
0_ooool01?oo003oooooool00?ooool3ool000;ooooo00?oo`00oooooooo00000ooo0003ooooo`Co
o`0000_oooooool00?ooooooooooool00?ooooooo`00oooooooo003oooooool00002ooooo`03ool0
0?ooooooo`0000?oo`0000?oooooool00?ooool01?oo00000oooooooo`00ooooo`04ool00003oooo
oooo003ooooo00;oo`0000?oooooool00?ooool01_oo00000oooooooo`00ool00002ool00003oooo
oooo003ooooo00Coo`0000Coooooool00?ooooooo`000_ooool01?oo003oooooool00?ooool3ool0
00;ooooo00?oo`00oooooooo00000ooo0003ooooo`;oo`0000Coooooool00?ooooooo`000_ooool0
1?oo003oooooool00?ooool3ool000;ooooo00?oo`00oooooooo00000ooo00000oooooooo`00oooo
o`02ool00003oooooooo003ooooo00Koo`0000?oooooool00?oo00000_oo00000oooooooo`00oooo
o`04ool00003oooooooo003ooooo00Coo`0000?oooooool00?ooool00_oo00001_ooooooo`00oooo
oooo003oooooool000;ooooo00?oo`00oooooooo00000ooo0003ooooo`Coo`0000Coooooool00?oo
oooo00000ooo00001?ooooooo`00oooooooo0002ooooo`04ool00?ooooooo`00ooooo`;oo`000ooo
ool01ooo003oooooool00?oo003oooooool00?ooool01_oo00000oooooooo`00ool00002ool00003
oooooooo003ooooo00Coo`0000?oooooool00?ooool01?oo00000oooooooo`00ooooo`04ool00003
oooooooo003ooooo00;oo`0000Koooooool00?ooooooo`00oooooooo0002ooooo`03ool00?oooooo
o`0000?oo`000oooool4ool00004oooooooo003oooooooooo`?oo`0000Coooooool00?ooooooo`00
0_ooool01?oo003oooooool00?ooool2ool000?ooooo00Ooo`00oooooooo003oo`00oooooooo003o
oooo00Coo`0000?oooooool00?ooool01?oo00000oooooooo`00ooooo`04ool00003oooooooo003o
oooo00Coo`0000?oooooool00?oo00001?oo00000oooooooo`00ool00002ool00006oooooooo003o
ooooool00?ooooooo`000_ooool00ooo003oooooool00003ool000?ooooo1?oo00002oooooooo`00
ooooooooooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000ooo
0003ooooo`Coo`0000?oooooool00?ooool01?oo00000oooooooo`00ooooo`04ool00003oooooooo
003ooooo00Coo`002_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`08
ooooo`;oo`0000?oooooool00?ooool01?oo00000oooooooo`00ool00002ool00003oooooooo003o
oooo00Coo`0000Coooooool00?ooooooo`000_ooool01?oo003oooooool00?ooool3ool000;ooooo
1_oo0003ooooo`Coo`0000_oooooool00?ooooooooooool00?ooooooo`00oooooooo003oooooool0
0002ooooo`03ool00?ooooooo`0000?oo`0000?oooooool00?ooool01_oo00000oooooooo`00ool0
0002ool00003oooooooo003oo`0000Coo`0000?oooooool00?oo00001?oo00000oooooooo`00ool0
0002ool00003oooooooo003ooooo00Coo`0000Coooooool00?ooooooo`000_ooool01?oo003ooooo
ool00?ooool3ool000;ooooo1_oo0002ooooo`Goo`0000Soooooool00?ooooooooooool00?oooooo
o`00ooooo`?oo`000_ooool00ooo003oooooool00003ool00003oooooooo003ooooo00Coo`0000?o
ooooool00?oo00001?oo00000oooooooo`00ool00004ool00003oooooooo003oo`0000;oo`0000?o
ooooool00?ooool01?oo00000oooooooo`00ooooo`04ool00004oooooooo003oooooool000;ooooo
00?oo`00oooooooo00000ooo0003ooooo`Coo`0000Coooooool00?oooooo00000ooo00001?oooooo
o`00oooooooo0002ooooo`04ool00?ooooooo`00ooooo`;oo`000oooool00ooo003oooooool00003
ool00003oooooooo003oo`0000Coo`0000?oooooool00?oo00001?oo00000oooooooo`00ool00002
ool00003oooooooo003oo`0000Coo`0000?oooooool00?oo00001?oo00000oooooooo`00ool00004
ool00004oooooooo003oooooool000;ooooo00?oo`00oooooooo00000ooo0003ooooo`Koo`000_oo
ool3ool00004oooooooo003oooooool000;ooooo00?oo`00oooooooo00000ooo0003ooooo`07ool0
0?ooooooo`00ool00?ooooooo`00ooooo`04ool00003oooooooo003ooooo00Coo`0000?oooooool0
0?oo00001_oo00000oooooooo`00ool00009ool00003oooooooo003oo`0000;oo`0000Koooooool0
0?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000?oo`000oooool4ool00004oooooooo
003oooooooooo`?oo`0000Coooooool00?ooooooo`000_ooool00ooo003oooooool00003ool000?o
oooo1?oo00000oooooooo`00ooooo`04ool00003oooooooo003ooooo00Coo`0000?oooooool00?oo
00001?oo000:ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo00Sooooo
2Ooo00000oooooooo`00ool00002ool00003oooooooo003ooooo00Coo`0000Coooooool00?oooooo
o`000_ooool00ooo003oooooool00004ool000;ooooo1_oo0003ooooo`Coo`0000_oooooool00?oo
ooooooooool00?ooooooo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000?oo`00
00?oooooool00?oo00001_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000Coo`00
00?oooooool00?oo00001?oo00000oooooooo`00ool00004ool00003oooooooo003oo`0000;oo`00
00Coooooool00?ooooooo`000_ooool00ooo003oooooool00004ool000;ooooo1_oo0002ooooo`Go
o`0000Soooooool00?ooooooooooool00?ooooooo`00ooooo`?oo`000_ooool00ooo003oooooool0
0003ool00003oooooooo003oo`0000Coo`0000?oooooool00?oo00001?oo00000oooooooo`00ool0
000;ool00003oooooooo003oo`0000;oo`0000?oooooool00?oo00001?oo00001?ooooooo`00oooo
oooo0002ooooo`03ool00?ooooooo`0000?oo`000oooool4ool00004oooooooo003oooooo`0000Go
o`0000Koooooool00?ooooooooooool00?ooool4ool000?ooooo00?oo`00oooooooo00000ooo0000
0oooooooo`00ool00004ool00003oooooooo003oo`0000Coo`0000?oooooool00?oo00000_oo0000
0oooooooo`00ool00004ool00003oooooooo003oo`0000Coo`0000?oooooool00?oo00001?oo0000
1?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000?oo`000oooool6ool000;ooooo1Ooo
00001_ooooooo`00ooooooooooooo`00ooooo`Coo`000oooool00ooo003oooooool00003ool00003
oooooooo003oo`0000Coo`0000?oooooool00?oo00002ooo00000oooooooo`00ool00009ool00003
oooooooo003oo`0000;oo`0000Koooooool00?ooooooo`00oooooooo0002ooooo`03ool00?oooooo
o`0000?oo`000oooool4ool00004oooooooo003oooooooooo`?oo`0000Coooooool00?ooooooo`00
0_ooool00ooo003oooooool00003ool000?ooooo1?oo00000oooooooo`00ooooo`04ool00003oooo
oooo003oo`0000Coo`0000?oooooool00?oo00001?oo000:ooooo`03o`000?oooooooooo00[ooooo
000Sooooo`03o`000?oooooooooo00Sooooo2Ooo00000oooooooo`00ool00002ool00003oooooooo
003ooooo00Coo`0000Coooooool00?ooooooo`000_ooool00ooo003oooooool00004ool000;ooooo
1_oo0003ooooo`Coo`0000Koooooool00?ooooooooooool00?ooool3ool00006oooooooo003ooooo
oooooooo003ooooo1?oo00000oooooooo`00ool0000Iool00003oooooooo003oo`0000Coo`0000?o
ooooool00?oo00000_oo00001?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000Coo`00
0_ooool6ool000;ooooo1Ooo00001?ooooooo`00ooooooooool7ool000;ooooo00?oo`00oooooooo
00000ooo00000oooooooo`00ool00004ool00003oooooooo003oo`0000Coo`0000?oooooool00?oo
00004?oo00000oooooooo`00ool00004ool00004oooooooo003oooooool000;ooooo00?oo`00oooo
oooo00000ooo0003ooooo`Koo`0000?oooooo`000?oo00001?oo00001_ooooooo`00oooooooooooo
o`00ooooo`Coo`000oooool00ooo003oooooool00003ool00003oooooooo003oo`0000Coo`0000?o
ooooool00?oo00005ooo00000oooooooo`00ool00004ool00004oooooooo003oooooool000;ooooo
00?oo`00oooooooo00000ooo0003ooooo`Koo`000_ooool5ool00006oooooooo003ooooooooooooo
003ooooo1?oo0003ooooo`03ool00?ooooooo`0000?oo`0000?oooooool00?oo00007_oo00000ooo
ooooo`00ool00004ool00004oooooooo003oo`00ool000;ooooo00?oo`00oooooooo00000ooo0003
ooooo`Coo`0000Coooooool00?oooooooooo1ooo0002ooooo`03ool00?ooooooo`0000?oo`000ooo
ool4ool00003oooooooo003ooooo00Coo`0000?oooooool00?oo00001?oo00000oooooooo`00ool0
0004ool000[ooooo00?o0000ooooooooool02_ooool002?ooooo0_l00009oooooa3oo`0000?ooooo
ool00?oo00000_oo00001?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000Coo`000_oo
ool6ool000?ooooo1?oo00001_ooooooo`00ooooooooooooo`00ooooo`Goo`000_ooool00ooo003o
ooooool00003ool00003oooooooo003oo`0001Woo`0000?oooooool00?oo00002Ooo00001?oooooo
o`00oooooooo0002ooooo`03ool00?ooooooo`0000Coo`000_ooool6ool000;ooooo1ooo0002oooo
o`Ooo`000_ooool00ooo003oooooool00003ool00003oooooooo003oo`0000Coo`0000?oooooool0
0?oo00007_oo00001?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000?oo`000oooool6
ool00003ooooool0003oo`0000Coo`0000Koooooool00?ooooooooooool00?ooool4ool000?ooooo
00?oo`00oooooooo00000ooo00000oooooooo`00ool00004ool00003oooooooo003oo`0001Ooo`00
00?oooooool00?oo00001?oo00001?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000?o
o`000oooool6ool000;ooooo1ooo0002ooooo`03ool00?ooooooo`0000?oo`000oooool6ool00003
oooooooo003oo`0002Goo`0000Coooooool00?oo003oo`000_ooool00ooo003oooooool00003ool0
00?ooooo1?oo00001?ooooooo`00ooooooooool7ool000;ooooo1_oo0003ooooo`Coo`0000?ooooo
ool00?oo00004_oo0008ooooo`?o00003?ooool002?ooooo00?o0000ooooooooool02?ooool@ool0
0003oooooooo003oo`0000;oo`0000Coooooool00?ooooooo`000_ooool00ooo003oooooool00004
ool000;ooooo1_oo0002ooooo`Ooo`000_ooool7ool000;ooooo00?oo`00oooooooo00000ooo0000
0oooooooo`00ool0000Uool00004oooooooo003oooooool000;ooooo00?oo`00oooooooo00001?oo
0002ooooo`Koo`000_ooool7ool000;ooooo1ooo0002ooooo`03ool00?ooooooo`0000?oo`0000?o
ooooool00?oo00009Ooo00001?ooooooo`00oooooooo0002ooooo`Ooo`000_ooool6ool00003oooo
ool0003oo`0000Coo`0000Coooooool00?oooooooooo1_oo0003ooooo`03ool00?ooooooo`0000?o
o`0000?oooooool00?oo00009Ooo00001?ooooooo`00oooooooo0002ooooo`Koo`000oooool6ool0
00;ooooo1ooo0002ooooo`03ool00?ooooooo`0000?oo`000oooool6ool00003oooooooo003oo`00
00[oo`0000?oooooool00?oo00006?oo00001?ooooooo`00ool00?oo0002ooooo`03ool00?oooooo
o`0000?oo`000oooool4ool00004oooooooo003oooooooooo`Ooo`000_ooool6ool000?ooooo1?oo
00000oooooooo`00ool0000Bool000[ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000
ooooooooool02?oooolEool00004oooooooo003oooooool000;ooooo00?oo`00oooooooo00001?oo
0002ooooo`Koo`000_ooool7ool000;ooooo1ooo0002ooooo`03ool00?ooooooo`0001;oo`0000?o
ooooool00?oo00005_oo00001?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000Coo`00
0_ooool6ool000;ooooo1?oo00000oooooooo`00ool00002ooooo`;oo`0000?oooooool00?oo0000
0_oo0002ooooo`03ool00?ooooooo`00013oo`0000?oooooool00?oo00001?oo00000oooooooo`00
ool00004ool00003oooooooo003oo`0000[oo`0000Coooooool00?ooooooo`000_ooool7ool000;o
oooo1_oo00000ooooooo0000ool00006ool000;ooooo1_oo0003ooooo`Koo`0000?oooooool00?oo
00002_oo00000oooooooo`00ool00004ool00003oooooooo003oo`00017oo`0000Coooooool00?oo
ooooo`000_ooool6ool000?ooooo1_oo0002ooooo`Ooo`000_ooool00ooo003oooooool00003ool0
00?ooooo4ooo00000oooooooo`00ool00004ool00003oooooooo003oo`00017oo`0000Coooooool0
0?oo003oo`000_ooool00ooo003oooooool00003ool000?ooooo1_oo0002ooooo`Ooo`000_ooool6
ool000?ooooo1?oo00000oooooooo`00ool0000Bool000[ooooo00?o0000ooooooooool02_ooool0
02?ooooo00?o0000ooooooooool02?ooool3ool00003oooooooo003oo`0000;oo`0000?oooooool0
0?oo00002_oo00001?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000Coo`000_ooool6
ool000;ooooo1ooo0002ooooo`;oo`0000?oooooool00?oo00000_oo0002ooooo`03ool00?oooooo
o`0000_oo`0000?oooooool00?oo00001?oo00000oooooooo`00ool00004ool00003oooooooo003o
o`0000;oo`0000?oooooool00?oo00003?oo00001_ooooooo`00ooooooooooooo`00ooooo`Goo`00
0_ooool6ool000;ooooo1?oo00000oooooooo`00ool00002ooooo`;oo`0000?oooooool00?oo0000
0_oo0002ooooo`03ool00?ooooooo`00013oo`0000?oooooool00?ooool01?oo00000oooooooo`00
ool00004ool00003oooooooo003oo`0000[oo`0000Coooooool00?ooooooo`000_ooool7ool000;o
oooo1_oo00000ooooooo0000ool00006ool000;ooooo0_oo00000oooooooo`00ool00002ool000;o
oooo1_oo00000oooooooo`00ool0000:ool00003oooooooo003ooooo00Coo`0000?oooooool00?oo
00001?oo00000oooooooo`00ool0000:ool00004oooooooo003oo`00ool000;ooooo1ooo0002oooo
o`Koo`000_ooool4ool00003oooooooo003oo`0000;ooooo0_oo00001?ooooooo`00ool00?oo0003
ooooo`coo`0000?oooooool00?oo00001?oo00000oooooooo`00ool00004ool00003oooooooo003o
o`0000Coo`0000?oooooool00?oo00002_oo00001?ooooooo`00ool00?oo0002ooooo`Koo`000ooo
ool6ool000;ooooo1ooo0002ooooo`;oo`0000Coooooool00?oo003oo`000oooool4ool00003oooo
oooo003oo`0000Goo`0000?oooooool00?oo00001?oo00000oooooooo`00ool00003ool000[ooooo
00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool03oooool01?oo003oooooool0
0?ooool:ool00004oooooooo003oooooool000;ooooo00?oo`00oooooooo00001?oo0002ooooo`;o
o`000_ooool2ool000;ooooo0ooo0002ooooo`;oo`000_ooool2ool00003oooooooo003oo`0000;o
o`000_ooool00ooo003oooooool0000;ool00004oooooooo003oo`00ool000kooooo00?oo`00oooo
oooo00003Ooo00001_ooooooo`00ooooooooooooo`00ooooo`Goo`000_ooool2ool000;ooooo0_oo
0002ooooo`?oo`000_ooool2ool000;ooooo0_oo00000oooooooo`00ool00002ool000;ooooo00?o
o`00oooooooo00002ooo00001?ooooooo`00ool00?oo000>ooooo`03ool00?ooooooo`0000_oo`00
00Coooooool00?ooooooo`000_ooool2ool00003oooooooo003oo`0000;oo`000_ooool2ool000;o
oooo0_oo00000ooooooo0000ool00002ool00004oooooooo003oo`00ool000;ooooo0_oo00000ooo
ooooo`00ool00002ool000;ooooo1_oo00000oooooooo`00ool00005ool00004oooooooo003oo`00
ool000kooooo00?oo`00oooooooo00002ooo00001?ooooooo`00ool00?oo0002ooooo`;oo`0000?o
ooooool00?oo00000_oo0002ooooo`;oo`000_ooool2ool000;ooooo0ooo0002ooooo`;oo`000_oo
ool2ool00003oooooooo003oo`0000;oo`000_ooool<ool00003oooooooo003oo`0000;oo`003ooo
ool00ooo003oooooool0000;ool00004oooooooo003oo`00ool000;ooooo0_oo00001?ooooooo`00
ool00?oo0002ooooo`?oo`000_ooool2ool000;ooooo0ooo00001?ooooooo`00ool00?oo0002oooo
o`;oo`0000Coooooool00?oo003oo`000oooool<ool00003oooooooo003oo`0000;oo`004_ooool0
0ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Cooooo`Coo`0000?oooooool0
0?oo00000ooo00001?ooooooo`00oooooooo0002ooooo`04ool00?ooooooo`00ooooo`?oo`000_oo
ool2ool000;ooooo0_oo0002ooooo`?oo`000_ooool2ool000;ooooo0_oo0002ooooo`?oo`000_oo
ool00ooo003oooooool0000;ool001Kooooo1?oo00000oooooooo`00ool00005ool00008oooooooo
003ooooooooooooo003oooooool00?ooool3ool000;ooooo0_oo0002ooooo`;oo`000_ooool3ool0
00;ooooo0_oo0002ooooo`;oo`000_ooool3ool000;ooooo3_oo000Fooooo`[oo`0000Coooooool0
0?ooooooo`000_ooool2ool000;ooooo0ooo0002ooooo`;oo`000_ooool2ool00003ooooool0003o
o`0000;oo`000_ooool2ool000;ooooo0_oo0002ooooo`?oo`000_ooool<ool00003oooooooo003o
oooo01Cooooo2ooo00001?ooooooo`00ool00?oo0002ooooo`;oo`000_ooool3ool000;ooooo0_oo
0002ooooo`;oo`000_ooool3ool000;ooooo0_oo0002ooooo`;oo`000_ooool3ool000;ooooo3?oo
00000oooooooo`00ooooo`0Dooooo`?oo`0000?oooooool00?oo00001Ooo00001?ooooooo`00ool0
0?oo0002ooooo`;oo`000_ooool2ool000;ooooo0ooo0002ooooo`;oo`000_ooool2ool000;ooooo
0ooo0002ooooo`;oo`000_ooool2ool000?ooooo3?oo00000oooooooo`00ooooo`0Dooooo`03o`00
0?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo01Kooooo00?oo`00oooooooo00001_oo
00001?ooooooo`00ooooooooool2ool000?ooooo0_oo0002ooooo`;oo`000_ooool2ool000;ooooo
0ooo0002ooooo`;oo`000_ooool2ool000;ooooo0ooo0002ooooo`03ool00?ooooooo`0000Soo`00
7?ooool00ooo003oooooool00006ool00004oooooooo003oooooooooo`;oo`000_ooool3ool000;o
oooo0_oo0002ooooo`;oo`000_ooool3ool000;ooooo0_oo0002ooooo`;oo`000_ooool3ool000;o
oooo1ooo00001?ooooooo`00ool00?oo000Looooo`03ool00?ooooooo`0000Coo`0000Coooooool0
0?ooooooo`000_ooool2ool000;ooooo0ooo0002ooooo`;oo`000_ooool2ool00003ooooool0003o
o`0000;oo`000_ooool2ool000;ooooo0_oo0002ooooo`?oo`000_ooool;ool001cooooo00?oo`00
oooooooo00001?oo00001?ooooooo`00ool00?oo0002ooooo`;oo`000_ooool3ool000;ooooo0_oo
0002ooooo`;oo`000_ooool2ool000?ooooo0_oo0002ooooo`;oo`000_ooool3ool000;ooooo2ooo
000Looooo`_oo`000_ooool2ool000;ooooo0ooo00001?ooooooo`00ool00?oo0002ooooo`;oo`00
0_ooool2ool000?ooooo0_oo0002ooooo`;oo`000_ooool2ool000?ooooo2ooo000Hooooo`03o`00
0?oooooooooo00[ooooo000Sooooo`;o00006Oooool7ool00004oooooooo003oooooooooo`;oo`00
0oooool2ool000;ooooo0_oo0002ooooo`;oo`000_ooool3ool000;ooooo0_oo0002ooooo`;oo`00
0_ooool3ool000;ooooo00?oo`00oooooooo00001?oo00000oooooooo`00ooooo`0Oooooo`Ooo`00
00Coooooool00?oooooooooo0_oo0003ooooo`;oo`000_ooool2ool000;ooooo0_oo0002ooooo`?o
o`000_ooool2ool000;ooooo0_oo0002ooooo`?oo`000_ooool7ool00003oooooooo003ooooo01oo
oooo1ooo00001?ooooooo`00ooooooooool2ool000?ooooo0_oo0002ooooo`;oo`000_ooool2ool0
0004ooooool0003oo`00ool000?ooooo0_oo0002ooooo`;oo`000_ooool3ool000;ooooo1ooo0000
0oooooooo`00ooooo`0Oooooo`Goo`0000Coooooool00?oo003oo`000_ooool2ool000;ooooo0ooo
0002ooooo`;oo`000_ooool2ool000;ooooo0_oo0003ooooo`;oo`000_ooool2ool000;ooooo0ooo
0002ooooo`Woo`007oooool:ool000;ooooo0_oo0002ooooo`?oo`0000Coooooool00?oo003oo`00
0_ooool2ool000;ooooo0_oo0003ooooo`;oo`000_ooool2ool000;ooooo0_oo0003ooooo`Woo`00
6?ooool3o`0000cooooo000Sooooo`03o`000?oooooooooo01Sooooo1ooo00001?ooooooo`00oooo
ooooool2ool000Cooooo00?oo`00ooooooooool00_oo0002ooooo`?oo`0000Coooooool00?oo003o
o`000_ooool2ool000;ooooo00Coo`00oooooooooooooooo0ooo0002ooooo`03ool00?ooooooo`00
00Coo`0000?oooooool00?ooool07oooool7ool00004oooooooo003oooooooooo`;oo`001?ooool0
0ooo003oooooooooo`02ool000;ooooo0_oo0002ooooo`;oo`000oooool2ool000;ooooo00Coo`00
oooooooooooooooo0ooo0002ooooo`Ooo`0000?oooooool00?ooool07oooool7ool00004oooooooo
003oooooooooo`;oo`001?ooool00ooo003oooooooooo`02ool000;ooooo0_oo00000ooooooo0000
ool00002ool000;ooooo0_oo0002ooooo`04ool00?ooooooooooooooo`?oo`000_ooool7ool00003
oooooooo003ooooo01oooooo2Ooo0002ooooo`;oo`001?ooool00ooo003oooooooooo`02ool000;o
oooo0_oo0002ooooo`;oo`000oooool2ool000;ooooo00Coo`00oooooooooooooooo0ooo0002oooo
o`Ooo`0000?oooooool00?ooool07oooool9ool000;ooooo0_oo0004ooooo`03ool00?ooooooo`00
00;oo`000_ooool2ool000;ooooo0_oo0003ooooo`;oo`000_ooool01?oo003oooooooooooooool2
ool000?ooooo2Ooo000Jooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo
01[ooooo1Ooo00001?ooooooo`00ooooooooool2ool000Cooooo00Coo`00ooooooooooooo`001Ooo
ool00ooo003oooooool00005ooooo`04ool00?ooooooooooool000?ooooo0ooo0002ooooo`03ool0
0?ooooooo`0000Coo`008oooool6ool00004oooooooo003oooooooooo`;oo`001?ooool01?oo003o
oooooooooooo0004ooooo`04ool00?ooooooooooool000Gooooo00Coo`00ooooooooooooo`000ooo
ool3ool000;ooooo1ooo000Sooooo`Koo`0000Coooooool00?oooooooooo0_oo0004ooooo`04ool0
0?ooooooooooool000Cooooo00Coo`00ooooool0003oo`001Oooool01?oo003ooooooooooooo0003
ooooo`?oo`000_ooool7ool002?ooooo2?oo0002ooooo`;oo`001?ooool01?oo003ooooooooooooo
0004ooooo`04ool00?ooooooooooool000Gooooo00Coo`00ooooooooooooo`000oooool3ool000;o
oooo1Ooo00000oooooooo`00ooooo`0Rooooo`Soo`000_ooool2ool000Cooooo00?oo`00oooooooo
00001Oooool01?oo003ooooooooooooo0005ooooo`04ool00?ooooooooooool000?ooooo0_oo0003
ooooo`Goo`0000?oooooool00?ooool06oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0
003oooooooooo`0Jooooo`Goo`0000Coooooool00?oooooooooo0_oo0004ooooo`04ool00?oooooo
ooooool000Gooooo00?oo`00oooooooo00001Oooool01?oo003ooooooooooooo0003ooooo`?oo`00
0_ooool00ooo003oooooool00004ool002Cooooo1Ooo00001?ooooooo`00ooooooooool2ool000Co
oooo00Coo`00ooooooooooooo`001?ooool01?oo003ooooooooooooo0005ooooo`04ool00?oooooo
ooooool000?ooooo0ooo0002ooooo`Ooo`009?ooool5ool00004oooooooo003oooooooooo`;oo`00
1?ooool01?oo003ooooooooooooo0004ooooo`04ool00?oooooo0000ool000Gooooo00Coo`00oooo
ooooooooo`000oooool3ool000;ooooo1ooo000Sooooo`Soo`000_ooool2ool000Cooooo00?oo`00
oooooooo00001Oooool01?oo003ooooooooooooo0005ooooo`04ool00?ooooooooooool000?ooooo
0ooo0002ooooo`Goo`0000?oooooool00?ooool08_ooool8ool000;ooooo0_oo0004ooooo`03ool0
0?ooooooo`0000Gooooo00Coo`00ooooooooooooo`001Oooool01?oo003ooooooooooooo0003oooo
o`;oo`000oooool5ool00003oooooooo003ooooo01_ooooo00?o0000ooooooooool02_ooool002?o
oooo00?o0000ooooooooool06oooool4ool00004oooooooo003oooooooooo`;oo`001?ooool01?oo
003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`001?oo
ool2ool000;ooooo00?oo`00oooooooo00000ooo000Vooooo`Coo`0000Coooooool00?oooooooooo
0_oo0004ooooo`04ool00?ooooooooooool000Cooooo00Coo`00ooooooooooooo`001Oooool01?oo
003ooooooooooooo0003ooooo`?oo`000_ooool6ool002Kooooo1?oo00001?ooooooo`00oooooooo
ool2ool000Cooooo00Coo`00ooooooooooooo`001?ooool01?oo003oooooo`000?oo0005ooooo`04
ool00?ooooooooooool000?ooooo0ooo0002ooooo`Goo`009oooool6ool000;ooooo0_oo0004oooo
o`03ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`001Oooool01?oo003ooooooooooooo
0003ooooo`?oo`000_ooool5ool002Oooooo00?oo`00oooooooo00000ooo0002ooooo`;oo`001?oo
ool00ooo003oooooool00005ooooo`04ool00?ooooooooooool000Gooooo00Coo`00oooooooooooo
o`000oooool2ool000?ooooo1Ooo000Nooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`00
0?oooooooooo01_ooooo1?oo00001?ooooooo`00ooooooooool2ool000Cooooo00Coo`00oooooooo
ooooo`001Oooool00ooo003oooooool00005ooooo`04ool00?ooooooooooool000Cooooo0_oo0002
ooooo`03ool00?ooooooo`0000?oo`009_ooool6ool000;ooooo0_oo0004ooooo`04ool00?oooooo
ooooool000Cooooo00Coo`00ooooooooooooo`001Oooool01?oo003ooooooooooooo0003ooooo`?o
o`000_ooool5ool002Oooooo1_oo0002ooooo`;oo`001?ooool00ooo003oooooool00005ooooo`04
ool00?oooooo0000ool000Gooooo00Coo`00ooooooooooooo`000oooool3ool000;ooooo1Ooo000W
ooooo`Koo`000_ooool2ool000Cooooo00?oo`00oooooooo00001Oooool01?oo003ooooooooooooo
0005ooooo`04ool00?ooooooooooool000?ooooo0ooo0002ooooo`Goo`009oooool00ooo003ooooo
ool00003ool000;ooooo0_oo0004ooooo`03ool00?ooooooo`0000Gooooo00Coo`00oooooooooooo
o`001Oooool01?oo003ooooooooooooo0003ooooo`;oo`000oooool5ool001kooooo00?o0000oooo
ooooool02_ooool002?ooooo00?o0000ooooooooool06oooool4ool00004oooooooo003ooooooooo
o`;oo`001?ooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Gooooo00Coo`00
ooooooooooooo`001?ooool2ool000;ooooo00?oo`00oooooooo00000ooo000Vooooo`Koo`000_oo
ool2ool000Cooooo00Coo`00ooooooooooooo`001?ooool01?oo003ooooooooooooo0005ooooo`04
ool00?ooooooooooool000Cooooo0_oo0002ooooo`Goo`009oooool6ool000;ooooo0_oo0004oooo
o`03ool00?ooooooo`0000Gooooo00Coo`00ooooool0003oo`001Oooool01?oo003ooooooooooooo
0003ooooo`?oo`000_ooool5ool002Oooooo00?oo`00oooooooo00000ooo0002ooooo`;oo`001?oo
ool00ooo003oooooool00005ooooo`04ool00?ooooooooooool000Gooooo00Coo`00oooooooooooo
o`000oooool3ool000;ooooo1Ooo000Wooooo`Koo`000_ooool2ool000Cooooo00?oo`00oooooooo
00001Oooool01?oo003ooooooooooooo0005ooooo`04ool00?ooooooooooool000?ooooo0_oo0003
ooooo`Goo`007_ooool00ol0003oooooooooo`0:ooooo`008oooool2o`0001kooooo0_oo00001?oo
ooooo`00ooooooooool2ool000Cooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooool0
0005ooooo`04ool00?ooooooooooool000Cooooo0_oo0002ooooo`04ool00?ooooooo`00ool002[o
oooo1?oo0002ooooo`;oo`001?ooool01?oo003ooooooooooooo0004ooooo`04ool00?oooooooooo
ool000Gooooo00Coo`00ooooooooooooo`001?ooool2ool000;ooooo1?oo000Zooooo`Coo`000_oo
ool2ool000Cooooo00?oo`00oooooooo00001Oooool01?oo003oooooo`000?oo0005ooooo`04ool0
0?ooooooooooool000Cooooo0_oo0002ooooo`Coo`00:_ooool4ool000;ooooo0_oo0004ooooo`03
ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`001Oooool01?oo003ooooooooooooo0003
ooooo`?oo`000_ooool4ool002[ooooo1?oo0002ooooo`;oo`001?ooool00ooo003oooooool00005
ooooo`04ool00?ooooooooooool000Gooooo00Coo`00ooooooooooooo`000oooool2ool000?ooooo
1?oo000Mooooo`?o00003?ooool002?ooooo00?o0000ooooooooool07Oooool2ool00004oooooooo
003oooooooooo`;oo`001?ooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Go
oooo00Coo`00ooooooooooooo`001?ooool2ool000;ooooo00Coo`00oooooooo003oo`00:_ooool4
ool000;ooooo0_oo0004ooooo`04ool00?ooooooooooool000Cooooo00Coo`00ooooooooooooo`00
1Oooool01?oo003ooooooooooooo0004ooooo`;oo`000_ooool4ool002[ooooo1?oo0002ooooo`;o
o`001?ooool00ooo003oooooool00005ooooo`04ool00?oooooo0000ool000Gooooo00Coo`00oooo
ooooooooo`001?ooool2ool000;ooooo1?oo000Zooooo`Coo`000_ooool2ool000Cooooo00?oo`00
oooooooo00001Oooool01?oo003ooooooooooooo0005ooooo`04ool00?ooooooooooool000Cooooo
0_oo0002ooooo`Coo`00:_ooool4ool000;ooooo0_oo0004ooooo`03ool00?ooooooo`0000Gooooo
00Coo`00ooooooooooooo`001Oooool01?oo003ooooooooooooo0003ooooo`;oo`000oooool4ool0
01oooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool07Oooool01?oo003o
ooooool00?oo0002ooooo`03ool00?oooooooooo00?ooooo00Coo`00ooooooooooooo`001Oooool0
0ooo003oooooool00005ooooo`04ool00?ooooooooooool000Gooooo00Goo`00ooooooooooooo`00
ooooo`02ool002[ooooo1?oo0002ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooooooooooo
o`001?ooool01?oo003ooooooooooooo0005ooooo`04ool00?ooooooooooool000Gooooo00?oo`00
ooooooooool01?oo000Zooooo`Coo`000_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
o`0000Gooooo00Coo`00ooooool0003oo`001Oooool01?oo003ooooooooooooo0005ooooo`03ool0
0?oooooooooo00Coo`00:_ooool4ool000;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ool00005ooooo`04ool00?ooooooooooool000Gooooo00Coo`00ooooooooooooo`001Oooool00ooo
003oooooooooo`04ool002[ooooo1?oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
oooo00001Oooool01?oo003ooooooooooooo0005ooooo`04ool00?ooooooooooool000Cooooo00Co
o`00oooooooooooooooo1?oo000Oooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oo
oooooooo01gooooo00Coo`00oooooooo003oo`000_ooool00ooo003oooooooooo`03ooooo`04ool0
0?ooooooooooool000Gooooo00?oo`00oooooooo00001Oooool01?oo003ooooooooooooo0005oooo
o`05ool00?ooooooooooool00?ooool00_oo000Zooooo`Coo`000_ooool00ooo003oooooooooo`03
ooooo`04ool00?ooooooooooool000Cooooo00Coo`00ooooooooooooo`001Oooool01?oo003ooooo
oooooooo0005ooooo`03ool00?oooooooooo00Coo`00:_ooool4ool000;ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooool00005ooooo`04ool00?oooooo0000ool000Gooooo00Coo`00oooo
ooooooooo`001Oooool00ooo003oooooooooo`04ool002[ooooo1?oo0002ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00oooooooo00001Oooool01?oo003ooooooooooooo0005ooooo`04ool00?oo
ooooooooool000Gooooo00?oo`00ooooooooool01?oo000Zooooo`Coo`000_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`001Oooool01?oo003o
oooooooooooo0004ooooo`04ool00?ooooooooooooooo`Coo`007oooool00ol0003oooooooooo`0:
ooooo`008oooool00ol0003oooooooooo`0Mooooo`04ool00?ooooooo`00ool000;ooooo00?oo`00
ooooooooool00oooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Gooooo00Co
o`00ooooooooooooo`001Oooool01Ooo003ooooooooooooo003ooooo00;oo`00:_ooool4ool000;o
oooo00?oo`00ooooooooool00oooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`00
00Gooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooooooo`04ool002[ooooo1?oo0002
ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo00001Oooool01?oo003oooooo`000?oo
0006ooooo`03ool00?ooooooo`0000Gooooo00?oo`00ooooooooool01?oo000Zooooo`Coo`000_oo
ool00ooo003oooooooooo`03ooooo`03ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`00
1Oooool01?oo003ooooooooooooo0005ooooo`03ool00?oooooooooo00Coo`00:_ooool4ool000;o
oooo00?oo`00ooooooooool00oooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Go
oooo00Coo`00ooooooooooooo`001?ooool01?oo003oooooooooooooool4ool001oooooo00?o0000
ooooooooool02_ooool0017ooooo1Ol00003ooooo`;o00002?ooool00ol0003oooooooooo`0Moooo
o`04ool00?ooooooo`00ool000;ooooo00?oo`00ooooooooool00oooool01?oo003ooooooooooooo
0005ooooo`03ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`001Oooool01Ooo003ooooo
oooooooo003ooooo00;oo`00:_ooool4ool000;ooooo00?oo`00ooooooooool00oooool01?oo003o
oooooooooooo0005ooooo`03ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`001Oooool0
0ooo003oooooooooo`04ool002[ooooo1?oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00
oooooooo00001_ooool00ooo003o0000ool00006ooooo`03ool00?ooooooo`0000Gooooo00?oo`00
ooooooooool01?oo000Zooooo`Coo`000_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
o`0000Gooooo00Coo`00ooooooooooooo`001Oooool01?oo003ooooooooooooo0005ooooo`03ool0
0?oooooooooo00?oo`00:oooool4ool000;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ool00006ooooo`03ool00?ooooooo`0000Gooooo00?oo`00oooooooo00001Oooool01?oo003ooooo
ooooooooool3ool0023ooooo00?o0000ooooooooool02_ooool001;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01oooooo0_oo0002oooo
o`03ool00?oooooooooo00?ooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00005
ooooo`04ool00?ooooooooooool000Gooooo00?oo`00ooooooooool00_oo000^ooooo`;oo`000_oo
ool00ooo003oooooooooo`03ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo0000
1Oooool01?oo003ooooooooooooo0005ooooo`03ool00?oooooooooo00;oo`00;Oooool3ool000;o
oooo00?oo`00ooooooooool00oooool00ooo003oooooool00006ooooo`03ool00?l0003oo`0000Ko
oooo00?oo`00oooooooo00001Oooool00ooo003oooooooooo`02ool002gooooo0ooo0002ooooo`03
ool00?oooooooooo00?ooooo00?oo`00oooooooo00001_ooool00ooo003oooooool00005ooooo`04
ool00?ooooooooooool000Gooooo00?oo`00ooooooooool00_oo000]ooooo`?oo`000_ooool00ooo
003oooooooooo`03ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001Oooool00ooo
003oooooool00005ooooo`04ool00?ooooooooooooooo`;oo`008Oooool00ol0003oooooooooo`0:
ooooo`004oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool07oooool2ool000;ooooo00?oo`00ooooooooool00oooool01?oo003ooooooooooooo
0005ooooo`03ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`001Oooool00ooo003ooooo
ooooo`02ool002kooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo0000
1_ooool00ooo003oooooool00005ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo
ool00_oo000]ooooo`?oo`000_ooool00ooo003oooooooooo`03ooooo`03ool00?ooooooo`0000Ko
oooo00?oo`00o`000?oo00001_ooool00ooo003oooooool00005ooooo`03ool00?oooooooooo00;o
o`00;Oooool3ool000;ooooo00?oo`00ooooooooool00oooool00ooo003oooooool00006ooooo`03
ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooooooo`02ool0
02gooooo0ooo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo00001_ooool00ooo
003oooooool00005ooooo`03ool00?ooooooo`0000Gooooo00Coo`00oooooooooooooooo0_oo000Q
ooooo`03o`000?oooooooooo00[ooooo000Dooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`05ooooo`?o00007oooool2ool000;ooooo00?oo`00ooooooooool00oooool0
1?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`00
1Oooool00ooo003oooooooooo`02ool002kooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo
00?oo`00oooooooo00001_ooool00ooo003oooooool00005ooooo`04ool00?ooooooooooool000Go
oooo00?oo`00ooooooooool00_oo000]ooooo`?oo`000_ooool00ooo003oooooooooo`03ooooo`03
ool00?ooooooo`0000Kooooo00?oo`00o`000?oo00001_ooool00ooo003oooooool00005ooooo`03
ool00?oooooooooo00;oo`00;Oooool3ool000;ooooo00?oo`00ooooooooool00oooool00ooo003o
ooooool00006ooooo`03ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`001Oooool00ooo
003oooooooooo`02ool002gooooo0ooo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
oooo00001_ooool00ooo003oooooool00005ooooo`03ool00?ooooooo`0000Gooooo00Coo`00oooo
oooooooooooo0_oo000Nooooo`Co00003?ooool0017ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool07oooool2ool000;ooooo00?o
o`00ooooooooool00oooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Gooooo
00Coo`00ooooooooooooo`001Oooool00ooo003oooooooooo`02ool002kooooo0_oo0002ooooo`03
ool00?oooooooooo00?ooooo00?oo`00oooooooo00001_ooool00ooo003oooooool00005ooooo`04
ool00?ooooooooooool000Gooooo00?oo`00ooooooooool00_oo000]ooooo`?oo`000_ooool00ooo
003oooooooooo`03ooooo`03ool00?ooooooo`0000Kooooo00?oo`00o`000?oo00001_ooool00ooo
003oooooool00005ooooo`03ool00?oooooooooo00;oo`00;Oooool3ool000;ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Gooooo00Coo`00oooo
ooooooooo`001Oooool00ooo003oooooooooo`02ool002gooooo0ooo0002ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00oooooooo00001_ooool00ooo003oooooool00005ooooo`03ool00?oooooo
o`0000Gooooo00Coo`00oooooooooooooooo0_oo000Qooooo`03o`000?oooooooooo00[ooooo000A
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo01oooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00Coo`00oooooooooooo
o`001Oooool00ooo003oooooool00005ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooo
ooooool00_oo000^ooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`03ool00?ooooooo`00
00Kooooo00?oo`00oooooooo00001Oooool01?oo003ooooooooooooo0005ooooo`03ool00?oooooo
oooo00;oo`00;_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ooo003oooooool00006
ooooo`03ool00?l0003oo`0000Kooooo00?oo`00oooooooo00001Oooool00ooo003oooooooooo`02
ool002gooooo0ooo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo00001_ooool0
0ooo003oooooool00005ooooo`04ool00?ooooooooooool000Gooooo00?oo`00ooooooooool00_oo
000]ooooo`?oo`000_ooool00ooo003oooooooooo`03ooooo`03ool00?ooooooo`0000Kooooo00?o
o`00oooooooo00001Oooool00ooo003oooooool00005ooooo`04ool00?ooooooooooooooo`;oo`00
8Oooool00ol0003oooooooooo`0:ooooo`004_ooool3o`0000Cooooo0_l00008ooooo`03o`000?oo
oooooooo01oooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00Coo`00ooooooooooooo`00
1Oooool00ooo003oooooool00005ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo
ool00_oo000^ooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`03ool00?ooooooo`0000Ko
oooo00?oo`00oooooooo00001Oooool01?oo003ooooooooooooo0005ooooo`03ool00?oooooooooo
00;oo`00;_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ooo003oooooool00006oooo
o`03ool00?l0003oo`0000Kooooo00?oo`00oooooooo00001Oooool00ooo003oooooooooo`02ool0
02kooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo00001_ooool00ooo
003oooooool00005ooooo`04ool00?ooooooooooool000Gooooo00?oo`00ooooooooool00_oo000]
ooooo`?oo`000_ooool00ooo003oooooooooo`03ooooo`03ool00?ooooooo`0000Kooooo00?oo`00
oooooooo00001Oooool00ooo003oooooool00006ooooo`03ool00?oooooooooo00;oo`008Oooool0
0ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Oooooo`;oo`000_ooool00ooo
003oooooooooo`03ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001_ooool00ooo
003oooooool00005ooooo`03ool00?oooooooooo00;oo`00;_ooool2ool000;ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Gooooo00Coo`00oooo
ooooooooo`001Oooool00ooo003oooooooooo`02ool002kooooo0_oo0002ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00oooooooo00001_ooool00ooo003o0000ool00006ooooo`03ool00?oooooo
o`0000Gooooo00?oo`00ooooooooool00_oo000^ooooo`;oo`000_ooool00ooo003oooooooooo`03
ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001Oooool01?oo003ooooooooooooo
0005ooooo`03ool00?oooooooooo00;oo`00;_ooool2ool000;ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Gooooo00?oo`00oooooooo00001_oo
ool00ooo003oooooooooo`02ool0027ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000
ooooooooool07oooool2ool000;ooooo00?oo`00ooooooooool00oooool00ooo003oooooool00006
ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001Oooool00ooo003oooooooooo`02
ool002kooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo00001_ooool0
0ooo003oooooool00005ooooo`04ool00?ooooooooooool000Gooooo00?oo`00ooooooooool00_oo
000^ooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`03ool00?ooooooo`0000Kooooo00?o
o`00o`000?oo00001_ooool00ooo003oooooool00005ooooo`03ool00?oooooooooo00;oo`00;_oo
ool2ool000;ooooo00?oo`00ooooooooool00oooool00ooo003oooooool00006ooooo`03ool00?oo
ooooo`0000Gooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooooooo`02ool002kooooo
0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo00001_ooool00ooo003ooooo
ool00005ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00000_oo000Qooooo`03o`00
0?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo01oooooo0_oo0002ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00oooooooo00001_ooool00ooo003oooooool00006ooooo`03ool00?oo
ooooo`0000Gooooo00?oo`00ooooooooool00_oo000^ooooo`;oo`000_ooool00ooo003ooooooooo
o`03ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001Oooool01?oo003ooooooooo
oooo0005ooooo`03ool00?oooooooooo00;oo`00;_ooool2ool000;ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooool00006ooooo`03ool00?l0003oo`0000Kooooo00?oo`00oooooooo0000
1Oooool00ooo003oooooooooo`02ool002kooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo
00?oo`00oooooooo00001_ooool00ooo003oooooool00005ooooo`04ool00?ooooooooooool000Go
oooo00?oo`00ooooooooool00_oo000^ooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`03
ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001Oooool00ooo003oooooool00006ooooo`03
ool00?ooooooo`0000;oo`008Oooool00ol0003oooooooooo`0:ooooo`008oooool2o`00023ooooo
0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo00001_ooool00ooo003ooooo
ool00006ooooo`03ool00?ooooooo`0000Gooooo00?oo`00ooooooooool00_oo000^ooooo`;oo`00
0_ooool00ooo003oooooooooo`03ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo0000
1Oooool01?oo003ooooooooooooo0005ooooo`03ool00?oooooooooo00;oo`00;_ooool2ool000;o
oooo00?oo`00ooooooooool00oooool00ooo003oooooool00006ooooo`03ool00?l0003oo`0000Ko
oooo00?oo`00oooooooo00001Oooool00ooo003oooooooooo`02ool002kooooo0_oo0002ooooo`03
ool00?oooooooooo00?ooooo00?oo`00oooooooo00001_ooool00ooo003oooooool00005ooooo`03
ool00?ooooooo`0000Kooooo00?oo`00ooooooooool00_oo000^ooooo`;oo`000_ooool00ooo003o
ooooooooo`03ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001Oooool00ooo003o
ooooool00006ooooo`03ool00?ooooooo`0000;oo`007oooool3o`0000cooooo000Sooooo`03o`00
0?oooooooooo01oooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo0000
1_ooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Gooooo00?oo`00ooooooooool0
0_oo000^ooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`03ool00?ooooooo`0000Kooooo
00?oo`00oooooooo00001Oooool01?oo003ooooooooooooo0005ooooo`03ool00?oooooooooo00;o
o`00;_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ooo003oooooool00006ooooo`03
ool00?l0003oo`0000Kooooo00?oo`00oooooooo00001Oooool00ooo003oooooooooo`02ool002ko
oooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo00001_ooool00ooo003o
ooooool00005ooooo`03ool00?ooooooo`0000Kooooo00?oo`00ooooooooool00_oo000^ooooo`;o
o`000_ooool00ooo003oooooooooo`03ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo
00001Oooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000;oo`008Oooool00ol0003o
ooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Oooooo`;oo`000_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001_ooool00ooo003ooooo
ool00005ooooo`03ool00?oooooooooo00;oo`00;_ooool2ool000;ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Gooooo00Coo`00oooooooooooo
o`001Oooool00ooo003oooooooooo`02ool002kooooo0_oo0002ooooo`03ool00?oooooooooo00?o
oooo00?oo`00oooooooo00001_ooool00ooo003o0000ool00006ooooo`03ool00?ooooooo`0000Go
oooo00?oo`00ooooooooool00_oo000^ooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`03
ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001Oooool00ooo003oooooool00006ooooo`03
ool00?oooooooooo00;oo`00;_ooool2ool000;ooooo00?oo`00ooooooooool00oooool00ooo003o
ooooool00006ooooo`03ool00?ooooooo`0000Gooooo00?oo`00oooooooo00001_ooool00ooo003o
ooooool00002ool0027ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool0
7oooool2ool000;ooooo00?oo`00ooooooooool00oooool00ooo003oooooool00006ooooo`03ool0
0?ooooooo`0000Kooooo00?oo`00oooooooo00001Oooool00ooo003oooooooooo`02ool002kooooo
0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo00001_ooool00ooo003ooooo
ool00005ooooo`04ool00?ooooooooooool000Gooooo00?oo`00ooooooooool00_oo000^ooooo`;o
o`000_ooool00ooo003oooooooooo`03ooooo`03ool00?ooooooo`0000Kooooo00?oo`00o`000?oo
00001_ooool00ooo003oooooool00005ooooo`03ool00?oooooooooo00;oo`00;_ooool2ool000;o
oooo00?oo`00ooooooooool00oooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Go
oooo00?oo`00oooooooo00001_ooool00ooo003oooooooooo`02ool002kooooo0_oo0002ooooo`03
ool00?oooooooooo00?ooooo00?oo`00oooooooo00001_ooool00ooo003oooooool00005ooooo`03
ool00?ooooooo`0000Kooooo00Goo`00oooooooo003oooooool0000Qooooo`03o`000?oooooooooo
00[ooooo000Sooooo`03o`000?oooooooooo023ooooo00Coo`00ooooooooooooo`001Oooool00ooo
003oooooool00006ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001Oooool01?oo
003ooooooooooooo000`ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_oo
ool00ooo003oooooool00005ooooo`04ool00?ooooooooooool000Gooooo00Coo`00oooooooooooo
o`00<?ooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Kooooo00?oo`00o`00
0?oo00001_ooool2ool000Kooooo00Coo`00ooooooooooooo`00<?ooool01?oo003ooooooooooooo
0005ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001Oooool00ooo003oooooool0
0006ooooo`04ool00?ooooooooooool0033ooooo00Coo`00ooooooooooooo`001Oooool00ooo003o
ooooool00006ooooo`03ool00?ooooooo`0000Gooooo00?oo`00oooooooo00001_ooool00ooo003o
ooooool0000Sooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo023ooooo
00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Ko
oooo00?oo`00oooooooo00001Oooool01?oo003ooooooooooooo000`ooooo`04ool00?oooooooooo
ool000Gooooo00?oo`00oooooooo00001_ooool00ooo003oooooool00006ooooo`03ool00?oooooo
o`0000Gooooo00Coo`00ooooooooooooo`00<?ooool01?oo003ooooooooooooo0005ooooo`03ool0
0?ooooooo`0000Kooooo00?oo`00o`000?oo00001_ooool2ool000Kooooo00Coo`00oooooooooooo
o`00<?ooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Kooooo0_oo0006oooo
o`03ool00?ooooooo`0000Kooooo00Coo`00ooooooooooooo`00<?ooool01?oo003ooooooooooooo
0005ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001Oooool00ooo003oooooool0
0006ooooo`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000
ooooooooool08?ooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Kooooo00?o
o`00oooooooo00001_ooool00ooo003oooooool00005ooooo`04ool00?ooooooooooool0033ooooo
00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Ko
oooo00?oo`00oooooooo00001Oooool01?oo003ooooooooooooo000`ooooo`04ool00?oooooooooo
ool000Gooooo00?oo`00oooooooo00001_ooool00ooo003o0000ool00006ooooo`;oo`001_ooool0
1?oo003ooooooooooooo000`ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo0000
1_ooool2ool000Kooooo00?oo`00oooooooo00001_ooool01?oo003ooooooooooooo000`ooooo`04
ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool00ooo003oooooool00005oooo
o`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00008oooool00ol0003oooooooooo`0:oooo
o`008oooool2o`00027ooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00006oooo
o`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001Oooool01?oo003ooooooooooooo000`
ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool00ooo003oooooool0
0006ooooo`03ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`00<?ooool01?oo003ooooo
oooooooo0005ooooo`03ool00?ooooooo`0000Kooooo00?oo`00o`000?oo00001_ooool2ool000Ko
oooo00Coo`00ooooooooooooo`00<?ooool01?oo003ooooooooooooo0005ooooo`03ool00?oooooo
o`0000Kooooo0_oo0006ooooo`03ool00?ooooooo`0000Kooooo00Coo`00ooooooooooooo`00<?oo
ool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo0000
1_ooool2ool000Kooooo00?oo`00oooooooo00008Oooool3o`0000cooooo000Sooooo`03o`000?oo
oooooooo023ooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00006ooooo`03ool0
0?ooooooo`0000Kooooo00?oo`00oooooooo00001Oooool01?oo003ooooooooooooo000`ooooo`04
ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool00ooo003oooooool00006oooo
o`;oo`001_ooool01?oo003ooooooooooooo000`ooooo`04ool00?ooooooooooool000Gooooo00?o
o`00oooooooo00001_ooool00ooo003o0000ool00006ooooo`;oo`001_ooool01?oo003ooooooooo
oooo000`ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool2ool000Ko
oooo00?oo`00oooooooo00001_ooool01?oo003ooooooooooooo000`ooooo`04ool00?oooooooooo
ool000Gooooo00?oo`00oooooooo00001_ooool00ooo003oooooool00006ooooo`;oo`001_ooool0
0ooo003oooooool0000Sooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo
023ooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00006ooooo`03ool00?oooooo
o`0000Kooooo00?oo`00oooooooo00001Oooool01?oo003ooooooooooooo000`ooooo`04ool00?oo
ooooooooool000Gooooo00?oo`00oooooooo00001_ooool00ooo003oooooool00006ooooo`;oo`00
1_ooool01?oo003ooooooooooooo000`ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooo
oooo00001_ooool00ooo003o0000ool00006ooooo`;oo`001_ooool00ooo003oooooool0000aoooo
o`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool2ool000Kooooo00?oo`00
oooooooo00001_ooool00ooo003oooooool0000aooooo`04ool00?ooooooooooool000Gooooo00?o
o`00oooooooo00001_ooool00ooo003oooooool00006ooooo`;oo`001_ooool00ooo003oooooool0
000Sooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo023ooooo00Coo`00
ooooooooooooo`001Oooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Kooooo00?o
o`00oooooooo00001Oooool01?oo003ooooooooooooo000`ooooo`04ool00?ooooooooooool000Go
oooo00?oo`00oooooooo00001_ooool00ooo003oooooool00006ooooo`;oo`001_ooool01?oo003o
oooooooooooo000`ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool0
0ooo003o0000ool00006ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`04ool00?oooooo
ooooool000Gooooo00?oo`00oooooooo00001_ooool2ool000Kooooo00?oo`00oooooooo00001_oo
ool00ooo003oooooool0000aooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo0000
1_ooool00ooo003oooooool00006ooooo`;oo`001_ooool00ooo003oooooool0000Sooooo`03o`00
0?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo023ooooo00Coo`00ooooooooooooo`00
1Oooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo0000
1Oooool01?oo003ooooooooooooo000`ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooo
oooo00001_ooool00ooo003oooooool00006ooooo`;oo`001_ooool01?oo003ooooooooooooo000`
ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool00ooo003o0000ool0
0006ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`04ool00?ooooooooooool000Gooooo
00?oo`00oooooooo00001_ooool2ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`00037ooooo
00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00006ooooo`;oo`001oooool2ool000Ko
oooo00?oo`00oooooooo00008oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003ooooo
ooooo`0Pooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool00ooo003o
ooooool00006ooooo`03ool00?ooooooo`0000Gooooo00Coo`00ooooooooooooo`00<?ooool01?oo
003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Kooooo0_oo0007ooooo`;oo`001_ooool0
1?oo003ooooooooooooo000`ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo0000
1_ooool00ooo003o0000ool00006ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`04ool0
0?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool2ool000Oooooo0_oo0006ooooo`03
ool00?ooooooo`00037ooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00006oooo
o`;oo`001oooool2ool000Kooooo00?oo`00oooooooo00008oooool00ol0003oooooooooo`0:oooo
o`008oooool00ol0003oooooooooo`0Pooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooo
oooo00001_ooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Gooooo00Coo`00oooo
ooooooooo`00<?ooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Kooooo0_oo
0007ooooo`;oo`001_ooool01?oo003ooooooooooooo000`ooooo`04ool00?ooooooooooool000Go
oooo00?oo`00oooooooo00001_ooool00ooo003o0000ool00006ooooo`;oo`001_ooool00ooo003o
ooooool0000aooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool2ool0
00Oooooo0_oo0006ooooo`03ool00?ooooooo`00037ooooo00Coo`00ooooooooooooo`001Oooool0
0ooo003oooooool00006ooooo`;oo`001oooool2ool000Kooooo00?oo`00oooooooo00008oooool0
0ol0003oooooooooo`0:ooooo`008oooool2o`00027ooooo00Coo`00ooooooooooooo`001Oooool0
0ooo003oooooool00006ooooo`03ool00?ooooooo`0000Kooooo0_oo0006ooooo`04ool00?oooooo
ooooool0033ooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00006ooooo`;oo`00
1oooool2ool000Kooooo00Coo`00ooooooooooooo`00<?ooool01?oo003ooooooooooooo0005oooo
o`03ool00?ooooooo`0000Kooooo00?oo`00o`000?oo00001_ooool2ool000Kooooo00?oo`00oooo
oooo0000<Oooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Kooooo0_oo0007
ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`04ool00?ooooooooooool000Gooooo00?o
o`00oooooooo00001_ooool2ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`00027ooooo0ol0
000<ooooo`008oooool00ol0003oooooooooo`0Pooooo`04ool00?ooooooooooool000Gooooo00?o
o`00oooooooo00001_ooool00ooo003oooooool00006ooooo`;oo`001_ooool01?oo003ooooooooo
oooo000`ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool2ool000Oo
oooo0_oo0006ooooo`04ool00?ooooooooooool0033ooooo00Coo`00ooooooooooooo`001Oooool0
0ooo003oooooool00006ooooo`;oo`001oooool2ool000Kooooo00?oo`00oooooooo0000<Oooool0
1?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Kooooo0_oo0007ooooo`;oo`001_oo
ool00ooo003oooooool0000aooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo0000
1_ooool2ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool0
2_ooool002?ooooo00?o0000ooooooooool08?ooool01?oo003ooooooooooooo0006ooooo`;oo`00
1_ooool00ooo003oooooool00006ooooo`;oo`001_ooool01?oo003ooooooooooooo000`ooooo`04
ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool2ool000Oooooo0_oo0006oooo
o`04ool00?ooooooooooool0033ooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooool0
0006ooooo`;oo`001oooool2ool000Kooooo00?oo`00oooooooo0000<Oooool01?oo003ooooooooo
oooo0005ooooo`03ool00?ooooooo`0000Kooooo0_oo0007ooooo`;oo`001_ooool00ooo003ooooo
ool0000aooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool2ool000Oo
oooo0_oo0006ooooo`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool02_ooool002?ooooo
00?o0000ooooooooool08?ooool01?oo003ooooooooooooo0006ooooo`;oo`001_ooool00ooo003o
ooooool00006ooooo`;oo`001_ooool01?oo003ooooooooooooo000`ooooo`04ool00?oooooooooo
ool000Gooooo00?oo`00oooooooo00001_ooool2ool000Oooooo0_oo0006ooooo`04ool00?oooooo
ooooool0033ooooo00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00006ooooo`;oo`00
1oooool2ool000Kooooo00?oo`00oooooooo0000<Oooool01?oo003ooooooooooooo0005ooooo`03
ool00?ooooooo`0000Kooooo0_oo0007ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`04
ool00?ooooooooooool000Gooooo00?oo`00oooooooo00001_ooool2ool000Oooooo0_oo0006oooo
o`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000oooooooo
ool08?ooool01?oo003ooooooooooooo0006ooooo`;oo`001_ooool00ooo003oooooool00006oooo
o`;oo`001_ooool01?oo003ooooooooooooo000`ooooo`04ool00?ooooooooooool000Gooooo00?o
o`00oooooooo00001_ooool2ool000Oooooo0_oo0006ooooo`04ool00?ooooooooooool0033ooooo
00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00006ooooo`;oo`001oooool2ool000Ko
oooo00?oo`00oooooooo0000<Oooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`00
00Kooooo0_oo0007ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00
00Kooooo00?oo`00oooooooo00001_ooool2ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`00
02?ooooo00?o0000ooooooooool02_ooool001?ooooo0ol00003ooooo`;o00002?ooool00ol0003o
ooooooooo`0Pooooo`04ool00?ooooooooooool000Kooooo0_oo0006ooooo`03ool00?ooooooo`00
00Kooooo0_oo0006ooooo`04ool00?ooooooooooool0033ooooo00Coo`00ooooooooooooo`001Ooo
ool00ooo003oooooool00006ooooo`;oo`001oooool2ool000Kooooo00Coo`00ooooooooooooo`00
<?ooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Kooooo0_oo0007ooooo`;o
o`001_ooool00ooo003oooooool0000aooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooo
oooo00001_ooool2ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`00037ooooo00?oo`00oooo
oooo00001_ooool00ooo003oooooool00006ooooo`;oo`001oooool2ool000Kooooo00?oo`00oooo
oooo00008oooool00ol0003oooooooooo`0:ooooo`005?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`04ool00?oooooooooo
ool000Kooooo0_oo0006ooooo`;oo`001oooool2ool000Kooooo00Coo`00ooooooooooooo`00<?oo
ool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Kooooo0_oo0007ooooo`;oo`00
1_ooool01?oo003ooooooooooooo000`ooooo`04ool00?ooooooooooool000Gooooo00?oo`00oooo
oooo00001_ooool2ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`00037ooooo00Coo`00oooo
ooooooooo`001Oooool00ooo003oooooool00006ooooo`;oo`001oooool2ool000Kooooo00?oo`00
oooooooo0000<Oooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Kooooo0_oo0007
ooooo`;oo`001_ooool00ooo003oooooool0000Sooooo`03o`000?oooooooooo00[ooooo000Aoooo
o`Go00000_ooool01?l0003oooooooooool00007ooooo`?o00008?ooool01?oo003ooooooooooooo
0006ooooo`;oo`001_ooool2ool000Oooooo0_oo0006ooooo`04ool00?ooooooooooool0033ooooo
00Coo`00ooooooooooooo`001Oooool00ooo003oooooool00006ooooo`;oo`001oooool2ool000Ko
oooo00Coo`00ooooooooooooo`00<?ooool01?oo003ooooooooooooo0005ooooo`03ool00?oooooo
o`0000Kooooo0_oo0007ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`04ool00?oooooo
ooooool000Gooooo00?oo`00oooooooo00001_ooool2ool000Oooooo0_oo0006ooooo`03ool00?oo
ooooo`00037ooooo00?oo`00oooooooo00001_ooool00ooo003oooooool00006ooooo`;oo`001ooo
ool2ool000Kooooo00?oo`00oooooooo00008?ooool4o`0000cooooo000Aooooo`04o`000?oooooo
ooooo`0000?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Pooooo`04ool0
0?ooooooooooool000Kooooo0_oo0006ooooo`;oo`001oooool2ool000Kooooo00Coo`00oooooooo
ooooo`00<?ooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Kooooo0_oo0007
ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`0000Kooooo00?oo`00
oooooooo00001_ooool2ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`00037ooooo00Coo`00
ooooooooooooo`001Oooool00ooo003oooooool00006ooooo`;oo`001oooool2ool000Kooooo00?o
o`00oooooooo0000<Oooool00ooo003oooooool00006ooooo`03ool00?ooooooo`0000Kooooo0_oo
0007ooooo`;oo`001_ooool00ooo003oooooool0000Sooooo`03o`000?oooooooooo00[ooooo000B
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`0Pooooo`04ool00?ooooooooooool000Kooooo0_oo0006ooooo`;oo`001oooool2ool000Kooooo
00Coo`00ooooooooooooo`00<?ooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`00
00Kooooo0_oo0007ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00
00Oooooo0_oo0006ooooo`;oo`001oooool2ool000Kooooo00?oo`00oooooooo0000<Oooool01?oo
003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Kooooo0_oo0007ooooo`;oo`001_ooool0
0ooo003oooooool0000aooooo`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001_ooool2
ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool02_ooool0
01?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool08?ooool0
1?oo003ooooooooooooo0006ooooo`;oo`001_ooool2ool000Oooooo0_oo0006ooooo`04ool00?oo
ooooooooool0033ooooo00Coo`00ooooooooooooo`001_ooool2ool000Kooooo0_oo0007ooooo`;o
o`001_ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`0000Oooooo0_oo0006ooooo`;o
o`001oooool2ool000Kooooo00?oo`00oooooooo0000<Oooool01?oo003ooooooooooooo0005oooo
o`03ool00?ooooooo`0000Kooooo0_oo0007ooooo`;oo`001_ooool00ooo003oooooool0000aoooo
o`03ool00?ooooooo`0000Kooooo00?oo`00oooooooo00001_ooool2ool000Oooooo0_oo0006oooo
o`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool02_ooool001Cooooo00?o0000oooooooo
ool00_ooool2o`0000Sooooo00?o0000ooooooooool08?ooool01?oo003ooooooooooooo0006oooo
o`;oo`001_ooool2ool000Oooooo0_oo0006ooooo`04ool00?ooooooooooool0033ooooo00Coo`00
ooooooooooooo`001_ooool2ool000Kooooo0_oo0007ooooo`;oo`001_ooool00ooo003oooooool0
000aooooo`03ool00?ooooooo`0000Oooooo0_oo0006ooooo`;oo`001oooool2ool000Kooooo00?o
o`00oooooooo0000<Oooool01?oo003ooooooooooooo0005ooooo`03ool00?ooooooo`0000Kooooo
0_oo0007ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`0000Kooooo
00?oo`00oooooooo00001_ooool2ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`0002?ooooo
00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool08?ooool01?oo003ooooooooo
oooo0006ooooo`;oo`001_ooool2ool000Oooooo0_oo0006ooooo`04ool00?ooooooooooool0033o
oooo00Coo`00ooooooooooooo`001_ooool2ool000Kooooo0_oo0007ooooo`;oo`001_ooool00ooo
003oooooool0000aooooo`03ool00?ooooooo`0000Oooooo0_oo0006ooooo`;oo`001oooool2ool0
00Kooooo00?oo`00oooooooo0000<Oooool01?oo003ooooooooooooo0005ooooo`03ool00?oooooo
o`0000Kooooo0_oo0007ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`03ool00?oooooo
o`0000Kooooo0_oo0007ooooo`;oo`001oooool2ool000Kooooo00?oo`00oooooooo00008oooool0
0ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Pooooo`04ool00?oooooooooo
ool000Kooooo0_oo0006ooooo`;oo`001oooool2ool000Kooooo00Coo`00ooooooooooooo`00<?oo
ool01?oo003ooooooooooooo0006ooooo`;oo`001_ooool2ool000Oooooo0_oo0006ooooo`03ool0
0?ooooooo`00037ooooo00?oo`00oooooooo00001oooool2ool000Kooooo0_oo0007ooooo`;oo`00
1_ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool0
1Oooool2ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo0000
1_ooool2ool000Oooooo0_oo0007ooooo`;oo`001_ooool00ooo003oooooool0000Sooooo`03o`00
0?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo027ooooo00?oo`00oooooooo00001_oo
ool2ool000Kooooo0_oo0007ooooo`;oo`001_ooool01?oo003ooooooooooooo000`ooooo`03ool0
0?ooooooo`0000Oooooo0_oo0006ooooo`;oo`001oooool2ool000Kooooo00?oo`00oooooooo0000
<Oooool00ooo003oooooool00007ooooo`;oo`001_ooool2ool000Oooooo0_oo0006ooooo`03ool0
0?ooooooo`00037ooooo00?oo`00oooooooo00001oooool00ooo003oooooooooo`05ooooo`;oo`00
1oooool2ool000Kooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool00006ooooo`;oo`00
1oooool2ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool0
2_ooool002?ooooo0_l0000Rooooo`03ool00?ooooooo`0000Kooooo0_oo0007ooooo`03ool00?oo
oooooooo00Gooooo0_oo0006ooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo00001ooo
ool2ool000Kooooo0_oo0007ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`03ool00?oo
ooooo`0000Oooooo0_oo0006ooooo`;oo`001oooool2ool000Kooooo00?oo`00oooooooo0000<Ooo
ool00ooo003oooooool00007ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`;oo`001_oo
ool00ooo003oooooool0000aooooo`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool01Ooo
ool2ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`00027ooooo0ol0000<ooooo`008oooool0
0ol0003oooooooooo`0Qooooo`03ool00?ooooooo`0000Kooooo0_oo0007ooooo`03ool00?oooooo
oooo00Gooooo0_oo0006ooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo00001oooool2
ool000Kooooo0_oo0007ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`03ool00?oooooo
o`0000Oooooo0_oo0006ooooo`;oo`001oooool2ool000Kooooo00?oo`00oooooooo0000<Oooool0
0ooo003oooooool00007ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`;oo`001_ooool0
0ooo003oooooool0000aooooo`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool01Oooool2
ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool02_ooool0
02?ooooo00?o0000ooooooooool08Oooool00ooo003oooooool00006ooooo`;oo`001oooool00ooo
003oooooooooo`05ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00
00Oooooo0_oo0006ooooo`;oo`001oooool2ool000Kooooo00?oo`00oooooooo0000<Oooool00ooo
003oooooool00007ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`;oo`001_ooool00ooo
003oooooool0000aooooo`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool01Oooool2ool0
00Oooooo0_oo0006ooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo00001oooool00ooo
003oooooooooo`05ooooo`;oo`001oooool2ool000Kooooo00?oo`00oooooooo00008oooool00ol0
003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Qooooo`03ool00?ooooooo`0000Ko
oooo0_oo0007ooooo`03ool00?oooooooooo00Gooooo0_oo0006ooooo`03ool00?ooooooo`00037o
oooo00?oo`00oooooooo00001oooool2ool000Kooooo0_oo0007ooooo`;oo`001_ooool00ooo003o
ooooool0000aooooo`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`;oo`001_ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`0000Oo
oooo00?oo`00ooooooooool01Oooool2ool000Oooooo0_oo0006ooooo`03ool00?ooooooo`00037o
oooo00?oo`00oooooooo00001oooool00ooo003oooooooooo`05ooooo`;oo`001oooool2ool000Ko
oooo00?oo`00oooooooo00008oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003ooooo
ooooo`0Qooooo`03ool00?ooooooo`0000Kooooo0_oo0007ooooo`03ool00?oooooooooo00Gooooo
0_oo0006ooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo00001oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0006ooooo`03ool00?ooooooo`00037ooooo
00?oo`00oooooooo00001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
0_oo0006ooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo00001oooool00ooo003ooooo
ooooo`05ooooo`;oo`001oooool2ool000Kooooo00?oo`00oooooooo0000<Oooool00ooo003ooooo
ool00007ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`;oo`001_ooool00ooo003ooooo
ool0000Sooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo027ooooo0_oo
0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Kooooo00?o
o`00oooooooo0000<Oooool00ooo003oooooool00007ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool2ool000Kooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool0
0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Kooooo00?o
o`00oooooooo0000<Oooool00ooo003oooooool00007ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool2ool000Kooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool0
0007ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`;oo`001_ooool00ooo003oooooool0
000Sooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo027ooooo0_oo0007
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Kooooo00?oo`00
oooooooo0000<Oooool00ooo003oooooool00007ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool2ool000Kooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool00007
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Kooooo00?oo`00
oooooooo0000<Oooool00ooo003oooooool00007ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool2ool000Kooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool00007
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05
ooooo`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool02_ooool002?ooooo0_l0000Roooo
o`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`0000Oooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001_ooool00ooo003oooooool0000aoooo
o`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`;oo`001_ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`0000Oooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001_ooool00ooo003oooooool0000aoooo
o`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`;oo`001_ooool00ooo003oooooool0000Qooooo`?o00003?ooool002?ooooo00?o0000oooooooo
ool08Oooool2ool0023ooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool0000Pooooo`03
ool00?ooooooo`00037ooooo00?oo`00oooooooo00004?ooool00ol0003oooooooooo`0=ooooo`03
ool00?ooooooo`00037ooooo00?oo`00oooooooo00008?ooool00ooo003oooooool0000aooooo`03
ool00?ooooooo`00023ooooo00?oo`00oooooooo00008oooool00ol0003oooooooooo`0:ooooo`00
8oooool00ol0003oooooooooo`0Qooooo`;oo`008?ooool00ooo003oooooool0000aooooo`03ool0
0?ooooooo`00023ooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool0000@ooooo`03o`00
0?oooooooooo00gooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool0000Pooooo`03ool0
0?ooooooo`00037ooooo00?oo`00oooooooo00008?ooool00ooo003oooooool0000Sooooo`03o`00
0?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo027ooooo0_oo000Pooooo`03ool00?oo
ooooo`00037ooooo00?oo`00oooooooo00008?ooool00ooo003oooooool0000aooooo`03ool00?oo
ooooo`00013ooooo00?o0000ooooooooool03Oooool00ooo003oooooool0000aooooo`03ool00?oo
ooooo`00023ooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool0000Pooooo`03ool00?oo
ooooo`0002?ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool08Oooool2
ool0023ooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool0000Pooooo`03ool00?oooooo
o`00037ooooo00?oo`00oooooooo00004?ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooo
o`00037ooooo00?oo`00oooooooo00008?ooool00ooo003oooooool0000aooooo`03ool00?oooooo
o`00023ooooo00?oo`00oooooooo00008oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0
003oooooooooo`0Qooooo`;oo`008?ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00
023ooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool0000@ooooo`03o`000?oooooooooo
00gooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`00
037ooooo00?oo`00oooooooo00008?ooool00ooo003oooooool0000Sooooo`03o`000?oooooooooo
00[ooooo000Sooooo`03o`000?oooooooooo027ooooo0_oo000Pooooo`03ool00?ooooooo`00037o
oooo00?oo`00oooooooo00008?ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00013o
oooo00?o0000ooooooooool03Oooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023o
oooo00?oo`00oooooooo0000<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`0002?o
oooo00?o0000ooooooooool02_ooool002?ooooo0_l0000Rooooo`;oo`008?ooool00ooo003ooooo
ool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooooooo0000<Oooool00ooo003ooooo
ool0000@ooooo`03o`000?oooooooooo00gooooo00?oo`00oooooooo0000<Oooool00ooo003ooooo
ool0000Pooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo00008?ooool00ooo003ooooo
ool0000Qooooo`?o00003?ooool002?ooooo00?o0000ooooooooool08Oooool2ool0023ooooo00?o
o`00oooooooo0000<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`00037ooooo00?o
o`00oooooooo00004?ooool00ol0003oooooooooo`0=ooooo`03ool00?ooooooo`00037ooooo00?o
o`00oooooooo00008?ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo00?o
o`00oooooooo00008oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Q
ooooo`;oo`008?ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00
oooooooo0000<Oooool00ooo003oooooool0000@ooooo`03o`000?oooooooooo00gooooo00?oo`00
oooooooo0000<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`00037ooooo00?oo`00
oooooooo00008?ooool00ooo003oooooool0000Sooooo`03o`000?oooooooooo00[ooooo000Soooo
o`03o`000?oooooooooo027ooooo0_oo000Pooooo`03ool00?ooooooo`00037ooooo00?oo`00oooo
oooo00008?ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00013ooooo00?o0000oooo
ooooool03Oooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooo
oooo0000<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`0002?ooooo00?o0000oooo
ooooool02_ooool002?ooooo00?o0000ooooooooool08Oooool2ool0023ooooo00?oo`00oooooooo
0000<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo
00004?ooool00ol0003oooooooooo`0=ooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo
00008?ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooooooo
00008oooool00ol0003oooooooooo`0:ooooo`004_ooool3o`0000Cooooo0_l00008ooooo`03o`00
0?oooooooooo027ooooo0_oo000Pooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo0000
8?ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00013ooooo00?o0000ooooooooool0
3Oooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooooooo0000
<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool0
2_ooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool08Oooool2ool0023ooooo00?oo`00oooooooo0000<Oooool00ooo003o
ooooool0000Pooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo00004?ooool00ol0003o
ooooooooo`0=ooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo00008?ooool00ooo003o
ooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooooooo00008oooool00ol0003o
ooooooooo`0:ooooo`004Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00001oooool3o`00027ooooo0_oo000Pooooo`03ool00?ooooooo`00037ooooo00?oo`00oooo
oooo00008?ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00013ooooo00?o0000oooo
ooooool03Oooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooo
oooo0000<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`00023ooooo1?l0000<oooo
o`004Oooool4o`0000?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Qoooo
o`;oo`008Oooool2ool0037ooooo00?oo`00oooooooo00008Oooool2ool0037ooooo00?oo`00oooo
oooo00004?ooool00ol0003oooooooooo`0=ooooo`03ool00?ooooooo`00037ooooo00?oo`00oooo
oooo00008?ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooo
oooo00008oooool00ol0003oooooooooo`0:ooooo`004Oooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000aoooo
o`03ool00?ooooooo`00027ooooo0_oo000aooooo`03ool00?ooooooo`00013ooooo00?o0000oooo
ooooool03Oooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooo
oooo0000<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`0002?ooooo00?o0000oooo
ooooool02_ooool001;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo027ooooo0_oo000Qooooo`;oo`00<Oooool00ooo003oooooool0000Qoooo
o`;oo`00<Oooool00ooo003oooooool0000@ooooo`03o`000?oooooooooo00gooooo00?oo`00oooo
oooo0000<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`00037ooooo00?oo`00oooo
oooo00008?ooool00ooo003oooooool0000Sooooo`03o`000?oooooooooo00[ooooo000Cooooo`;o
00001?ooool2o`0000Sooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000aooooo`03
ool00?ooooooo`00027ooooo0_oo000aooooo`03ool00?ooooooo`00013ooooo00?o0000oooooooo
ool03Oooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooooooo
0000<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`0002?ooooo00?o0000oooooooo
ool02_ooool002?ooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000aooooo`03ool0
0?ooooooo`00027ooooo0_oo000aooooo`03ool00?ooooooo`00013ooooo00?o0000ooooooooool0
3Oooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooooooo0000
<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool0
2_ooool002?ooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000aooooo`03ool00?oo
ooooo`00027ooooo0_oo000aooooo`03ool00?ooooooo`00013ooooo00?o0000ooooooooool03Ooo
ool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooooooo0000<Ooo
ool00ooo003oooooool0000Pooooo`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool02_oo
ool002?ooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000aooooo`03ool00?oooooo
o`00027ooooo0_oo000aooooo`03ool00?ooooooo`00013ooooo00?o0000ooooooooool03Oooool0
0ooo003oooooool0000booooo`;oo`008?ooool00ooo003oooooool0000aooooo`03ool00?oooooo
o`00023ooooo00?oo`00oooooooo00008oooool00ol0003oooooooooo`0:ooooo`008oooool2o`00
02;ooooo0_oo000Qooooo`;oo`00<Oooool00ooo003oooooool0000Qooooo`;oo`00<Oooool00ooo
003oooooool0000@ooooo`03o`000?oooooooooo00gooooo00?oo`00oooooooo0000<_ooool2ool0
023ooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`00
027ooooo0ol0000<ooooo`008oooool00ol0003oooooooooo`0Qooooo`;oo`008Oooool2ool003;o
oooo0_oo000Qooooo`;oo`00<Oooool00ooo003oooooool0000@ooooo`03o`000?oooooooooo00go
oooo00?oo`00oooooooo0000<_ooool2ool0023ooooo00?oo`00oooooooo0000<Oooool00ooo003o
ooooool0000Pooooo`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool02_ooool002?ooooo
00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000booooo`;oo`008Oooool2ool0037ooooo
00?oo`00oooooooo00004?ooool00ol0003oooooooooo`0=ooooo`03ool00?ooooooo`0003;ooooo
0_oo000Pooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo00008?ooool00ooo003ooooo
ool0000Sooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo027ooooo0_oo
000Qooooo`;oo`00<_ooool2ool0027ooooo0_oo000aooooo`03ool00?ooooooo`00013ooooo00?o
0000ooooooooool03Oooool00ooo003oooooool0000booooo`;oo`008?ooool00ooo003oooooool0
000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooooooo00008oooool00ol0003ooooooooo
o`0:ooooo`008oooool00ol0003oooooooooo`0Qooooo`;oo`008Oooool2ool003;ooooo0_oo000Q
ooooo`;oo`00<Oooool00ooo003oooooool0000@ooooo`03o`000?oooooooooo00gooooo00?oo`00
oooooooo0000<_ooool2ool0023ooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool0000P
ooooo`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000oooo
ooooool08Oooool2ool0027ooooo0_oo000booooo`;oo`008Oooool2ool0037ooooo00?oo`00oooo
oooo00004?ooool00ol0003oooooooooo`0=ooooo`03ool00?ooooooo`0003;ooooo0_oo000Poooo
o`03ool00?ooooooo`00037ooooo00?oo`00oooooooo00008?ooool00ooo003oooooool0000Soooo
o`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo027ooooo0_oo000Qooooo`;o
o`00<_ooool2ool0027ooooo0_oo000aooooo`03ool00?ooooooo`00013ooooo00?o0000oooooooo
ool03Oooool00ooo003oooooool0000booooo`;oo`008?ooool00ooo003oooooool0000aooooo`03
ool00?ooooooo`00023ooooo00?oo`00oooooooo00008oooool00ol0003oooooooooo`0:ooooo`00
8oooool2o`0002;ooooo0_oo000Qooooo`;oo`00<_ooool2ool0027ooooo0_oo000aooooo`03ool0
0?ooooooo`00013ooooo00?o0000ooooooooool03Oooool00ooo003oooooool0000booooo`;oo`00
8?ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooooooo0000
8Oooool3o`0000cooooo000Sooooo`03o`000?oooooooooo027ooooo0_oo000Qooooo`;oo`00<_oo
ool2ool0027ooooo0_oo000aooooo`03ool00?ooooooo`00013ooooo00?o0000ooooooooool03Ooo
ool00ooo003oooooool0000booooo`;oo`008?ooool00ooo003oooooool0000aooooo`03ool00?oo
ooooo`00023ooooo00?oo`00oooooooo00008oooool00ol0003oooooooooo`0:ooooo`008oooool0
0ol0003oooooooooo`0Qooooo`;oo`008Oooool2ool003;ooooo0_oo000Qooooo`;oo`00<_ooool2
ool0013ooooo00?o0000ooooooooool03Oooool00ooo003oooooool0000booooo`;oo`008?ooool0
0ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooooooo00008oooool0
0ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Qooooo`;oo`008Oooool2ool0
03;ooooo0_oo000Qooooo`;oo`00<_ooool2ool0013ooooo00?o0000ooooooooool03Oooool00ooo
003oooooool0000booooo`;oo`008?ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00
023ooooo00?oo`00oooooooo00008oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003o
ooooooooo`0Qooooo`;oo`008Oooool2ool003;ooooo0_oo000Qooooo`;oo`00<_ooool2ool0013o
oooo00?o0000ooooooooool03Oooool00ooo003oooooool0000booooo`;oo`008?ooool00ooo003o
ooooool0000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooooooo00008oooool00ol0003o
ooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Qooooo`;oo`008Oooool2ool003;ooooo
0_oo000Qooooo`;oo`00<_ooool2ool0013ooooo00?o0000ooooooooool03Oooool00ooo003ooooo
ool0000booooo`;oo`008?ooool00ooo003oooooool0000aooooo`03ool00?ooooooo`00023ooooo
00?oo`00oooooooo00008oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003ooooooooo
o`0Qooooo`;oo`008Oooool2ool003;ooooo0_oo000Qooooo`;oo`00<_ooool2ool0013ooooo00?o
0000ooooooooool03Oooool00ooo003oooooool0000booooo`;oo`008?ooool00ooo003oooooool0
000aooooo`03ool00?ooooooo`00023ooooo00?oo`00oooooooo00008oooool00ol0003ooooooooo
o`0:ooooo`008oooool2o`0002;ooooo0_oo000Qooooo`;oo`00<_ooool2ool0027ooooo0_oo000b
ooooo`;oo`004?ooool00ol0003oooooooooo`0=ooooo`03ool00?ooooooo`0003;ooooo0_oo000P
ooooo`03ool00?ooooooo`00037ooooo00?oo`00oooooooo00008?ooool00ooo003oooooool0000Q
ooooo`?o00003?ooool002?ooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000boooo
o`;oo`008Oooool2ool003;ooooo0_oo000@ooooo`03o`000?oooooooooo00gooooo00?oo`00oooo
oooo0000<_ooool2ool0023ooooo00?oo`00oooooooo0000<Oooool00ooo003oooooool0000Poooo
o`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000oooooooo
ool08Oooool2ool0027ooooo0_oo000booooo`;oo`008Oooool2ool003;ooooo0_oo000@ooooo`03
o`000?oooooooooo00gooooo00?oo`00oooooooo0000<_ooool2ool0023ooooo00?oo`00oooooooo
0000<Oooool00ooo003oooooool0000Pooooo`03ool00?ooooooo`0002?ooooo00?o0000oooooooo
ool02_ooool002?ooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000booooo`;oo`00
8Oooool2ool003;ooooo0_oo000@ooooo`03o`000?oooooooooo00gooooo00?oo`00oooooooo0000
<_ooool2ool0023ooooo00?oo`00oooooooo0000<_ooool2ool0023ooooo00?oo`00oooooooo0000
8oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Qooooo`;oo`008Ooo
ool2ool003;ooooo0_oo000Qooooo`;oo`00<_ooool2ool0013ooooo00?o0000ooooooooool03Ooo
ool00ooo003oooooool0000booooo`;oo`008?ooool00ooo003oooooool0000booooo`;oo`008?oo
ool00ooo003oooooool0000Sooooo`03o`000?oooooooooo00[ooooo000Booooo`?o00001?ooool2
o`0000Sooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000booooo`;oo`008Oooool2
ool003;ooooo0_oo000@ooooo`03o`000?oooooooooo00gooooo00?oo`00oooooooo0000<_ooool2
ool0023ooooo00?oo`00oooooooo0000<_ooool2ool0023ooooo00?oo`00oooooooo00008oooool0
0ol0003oooooooooo`0:ooooo`004Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`0Qooooo`;oo`008Oooool2ool003;ooooo0_oo
000Qooooo`;oo`00<_ooool2ool0013ooooo00?o0000ooooooooool03_ooool2ool003;ooooo0_oo
000Pooooo`03ool00?ooooooo`0003;ooooo0_oo000Pooooo`03ool00?ooooooo`0002?ooooo00?o
0000ooooooooool02_ooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Oooooo0ol0000Qooooo`;oo`008Oooool2ool003;ooooo0_oo000Qooooo`;oo`00
<_ooool2ool0013ooooo00?o0000ooooooooool03_ooool2ool003;ooooo0_oo000Qooooo`;oo`00
<_ooool2ool0023ooooo00?oo`00oooooooo00008?ooool4o`0000cooooo000Booooo`?o00000ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo027ooooo0_oo000Qooooo`;oo`00
<_ooool2ool0027ooooo0_oo000booooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`;oo`00
<_ooool2ool0027ooooo0_oo000booooo`;oo`008?ooool00ooo003oooooool0000Sooooo`03o`00
0?oooooooooo00[ooooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo027ooooo0_oo000Qooooo`;oo`00<_ooool2ool0027o
oooo0_oo000booooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`;oo`00<_ooool2ool0027o
oooo0_oo000booooo`;oo`008?ooool00ooo003oooooool0000Sooooo`03o`000?oooooooooo00[o
oooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo027ooooo0_oo000Qooooo`;oo`00<_ooool2ool0027ooooo0_oo000boooo
o`;oo`004?ooool00ol0003oooooooooo`0>ooooo`;oo`00<_ooool2ool0027ooooo0_oo000boooo
o`;oo`008?ooool00ooo003oooooool0000Sooooo`03o`000?oooooooooo00[ooooo000Booooo`?o
00001?ooool2o`0000Sooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000booooo`;o
o`008Oooool2ool003;ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo0_oo000booooo`;o
o`008Oooool2ool003;ooooo0_oo000Pooooo`03ool00?ooooooo`0002?ooooo00?o0000oooooooo
ool02_ooool002?ooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000booooo`;oo`00
8Oooool2ool003;ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo0_oo000booooo`;oo`00
8Oooool2ool003;ooooo0_oo000Pooooo`03ool00?ooooooo`0002?ooooo00?o0000ooooooooool0
2_ooool002?ooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000booooo`;oo`008Ooo
ool2ool003;ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo0_oo000booooo`;oo`008Ooo
ool2ool003;ooooo0_oo000Qooooo`;oo`008oooool00ol0003oooooooooo`0:ooooo`008oooool2
o`0002;ooooo0_oo000Qooooo`;oo`00<_ooool2ool0027ooooo0_oo000booooo`;oo`004?ooool0
0ol0003oooooooooo`0>ooooo`;oo`00<_ooool2ool0027ooooo0_oo000booooo`;oo`008Oooool2
ool0027ooooo0ol0000<ooooo`008oooool00ol0003oooooooooo`0Qooooo`;oo`008Oooool2ool0
03;ooooo0_oo000Qooooo`;oo`00<_ooool2ool0013ooooo00?o0000ooooooooool03_ooool2ool0
03;ooooo0_oo000Qooooo`;oo`00<_ooool2ool0027ooooo0_oo000Sooooo`03o`000?oooooooooo
00[ooooo000Sooooo`03o`000?oooooooooo027ooooo0_oo000Qooooo`;oo`00<_ooool2ool0027o
oooo0_oo000booooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`;oo`00<_ooool2ool0027o
oooo0_oo000booooo`;oo`008Oooool2ool002?ooooo00?o0000ooooooooool02_ooool002?ooooo
00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000booooo`;oo`008Oooool2ool003;ooooo
0_oo000@ooooo`03o`000?oooooooooo00kooooo0_oo000booooo`;oo`008Oooool2ool003;ooooo
0_oo000Qooooo`;oo`008oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003ooooooooo
o`0Qooooo`;oo`008Oooool2ool003;ooooo0_oo000Qooooo`;oo`00<_ooool2ool0013ooooo00?o
0000ooooooooool03_ooool2ool003;ooooo0_oo000Qooooo`;oo`00<_ooool2ool0027ooooo0_oo
000Sooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo027ooooo0_oo000Q
ooooo`;oo`00<_ooool2ool0027ooooo0_oo000booooo`;oo`004?ooool00ol0003oooooooooo`0>
ooooo`;oo`00<_ooool2ool0027ooooo0_oo000booooo`;oo`008Oooool2ool002?ooooo00?o0000
ooooooooool02_ooool002?ooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000boooo
o`;oo`008Oooool2ool003;ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo0_oo000boooo
o`;oo`008Oooool2ool003;ooooo0_oo000Qooooo`;oo`008oooool00ol0003oooooooooo`0:oooo
o`008oooool00ol0003oooooooooo`0Qooooo`;oo`008Oooool2ool003;ooooo0_oo000Qooooo`;o
o`00<_ooool2ool0013ooooo00?o0000ooooooooool03_ooool2ool003;ooooo0_oo000Qooooo`;o
o`00<_ooool2ool0027ooooo0_oo000Sooooo`03o`000?oooooooooo00[ooooo000Sooooo`;o0000
8_ooool2ool0027ooooo0_oo000booooo`;oo`008Oooool2ool003;ooooo0_oo000@ooooo`03o`00
0?oooooooooo00kooooo0_oo000booooo`;oo`008Oooool2ool003;ooooo0_oo000Qooooo`;oo`00
8Oooool3o`0000cooooo000Sooooo`03o`000?oooooooooo027ooooo0_oo000Qooooo`;oo`00<_oo
ool2ool0027ooooo0_oo000booooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`;oo`00<_oo
ool2ool0027ooooo0_oo000booooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oo
oooooooo00[ooooo000Sooooo`03o`000?oooooooooo027ooooo0_oo000Qooooo`;oo`00<_ooool2
ool0027ooooo0_oo000booooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`;oo`00<_ooool2
ool0027ooooo0_oo000booooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooo
oooo00[ooooo000Sooooo`03o`000?oooooooooo027ooooo0_oo000Qooooo`;oo`00<_ooool2ool0
027ooooo0_oo000booooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`;oo`00<_ooool2ool0
027ooooo0_oo000booooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo
00[ooooo000Sooooo`03o`000?oooooooooo027ooooo0_oo000Qooooo`;oo`00<_ooool2ool0027o
oooo0_oo000booooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`;oo`00<_ooool2ool0027o
oooo0_oo000booooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool08_ooool00ol0003o
ooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Qooooo`;oo`008Oooool2ool003;ooooo
0_oo000Qooooo`;oo`00<_ooool2ool0013ooooo00?o0000ooooooooool03_ooool2ool003;ooooo
0_oo000Qooooo`;oo`00<_ooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo02;ooooo
00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo
000booooo`;oo`008Oooool2ool003;ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo0_oo
000booooo`;oo`008Oooool2ool003;ooooo00?oo`00ooooooooool08?ooool00ooo003ooooooooo
o`0Rooooo`03o`000?oooooooooo00[ooooo000Sooooo`;o00008_ooool2ool0027ooooo0_oo000b
ooooo`;oo`008Oooool2ool003;ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo0_oo000b
ooooo`;oo`008Oooool2ool003;ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0P
ooooo`?o00003?ooool002?ooooo00?o0000ooooooooool08Oooool2ool0027ooooo0_oo000boooo
o`;oo`008Oooool2ool003;ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo0_oo000boooo
o`;oo`008Oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo023ooooo00?oo`00oooo
ooooool08_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Qooooo`;o
o`008Oooool2ool003;ooooo0_oo000Qooooo`;oo`00<_ooool2ool0013ooooo00?o0000oooooooo
ool03_ooool2ool003;ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo00?oo`00oooooooo
ool08?ooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`00
0?oooooooooo027ooooo0_oo000Qooooo`;oo`00<_ooool2ool0027ooooo0_oo000booooo`;oo`00
4?ooool00ol0003oooooooooo`0>ooooo`;oo`00<_ooool00ooo003oooooooooo`0Pooooo`03ool0
0?oooooooooo037ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0Rooooo`03o`00
0?oooooooooo00[ooooo000<ooooo`?o00001?ooool2o`0000Cooooo0_l00008ooooo`03o`000?oo
oooooooo027ooooo0_oo000Qooooo`;oo`00<_ooool2ool0027ooooo0_oo000booooo`;oo`004?oo
ool00ol0003oooooooooo`0>ooooo`;oo`00<_ooool00ooo003oooooooooo`0Pooooo`03ool00?oo
oooooooo037ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0Rooooo`03o`000?oo
oooooooo00[ooooo000=ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo027ooooo0_oo000Qooooo`;oo`00
<_ooool2ool0027ooooo0_oo000booooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`03ool0
0?oooooooooo037ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0aooooo`03ool0
0?oooooooooo023ooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`003Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Qooooo`;oo`008Oooool2ool003;ooooo0_oo000Qooooo`03
ool00?oooooooooo037ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03
ool00?oooooooooo037ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0aooooo`03
ool00?oooooooooo023ooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`00
3Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001oooool3o`00027ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo00?oo`00oooo
ooooool08?ooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00oooooo00?o0000oooo
ooooool03_ooool2ool003;ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0aoooo
o`03ool00?oooooooooo023ooooo00?oo`00ooooooooool07oooool4o`0000cooooo000=ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool000cooooo0_l00004oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`1Dooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0:ooooo`003Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Sooooo00?o0000
ooooool000004?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000cooooo000Soooo
oooo0000b_l0000<ooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-30.2852, -12.7129, 0.115026, \
0.69362}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Example #2b: infinite-length spectrum of sample waveform (",
  Cell[BoxData[
      \(TraditionalForm\`f\_s = 10  Hz\  > \ 2  f\_max\)]],
  ")"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Sampling frequency", "Subsubsection"],

Cell[BoxData[
    \(\(fs = 10\  (*\ Hz\ *) ;\)\)], "Input",
  Background->RGBColor[1, 1, 0]]
}, Closed]],

Cell[CellGroupData[{

Cell["Original waveform", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := 1 + 2  Cos[2  \[Pi]\ t] + 4  Cos[4  \[Pi]\ t];\)\), "\n", 
    \(\(Plot[x[t], {t, 0, 5}, \ PlotStyle \[Rule] {Blue}, \ 
        Frame \[Rule] True, Axes \[Rule] {True, False}, \ 
        AspectRatio \[Rule] 1/3, ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.105916 0.0313544 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04321 -12 -4.5 ]
[-0.0125 .04321 0 4.5 ]
[-0.0125 .10592 -6 -4.5 ]
[-0.0125 .10592 0 4.5 ]
[-0.0125 .16862 -6 -4.5 ]
[-0.0125 .16862 0 4.5 ]
[-0.0125 .23133 -6 -4.5 ]
[-0.0125 .23133 0 4.5 ]
[-0.0125 .29404 -6 -4.5 ]
[-0.0125 .29404 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(1)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(2)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(3)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(4)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04321 m
.00625 .04321 L
s
[(-2)] -0.0125 .04321 1 0 Mshowa
0 .10592 m
.00625 .10592 L
s
[(0)] -0.0125 .10592 1 0 Mshowa
0 .16862 m
.00625 .16862 L
s
[(2)] -0.0125 .16862 1 0 Mshowa
0 .23133 m
.00625 .23133 L
s
[(4)] -0.0125 .23133 1 0 Mshowa
0 .29404 m
.00625 .29404 L
s
[(6)] -0.0125 .29404 1 0 Mshowa
.125 Mabswid
0 .05888 m
.00375 .05888 L
s
0 .07456 m
.00375 .07456 L
s
0 .09024 m
.00375 .09024 L
s
0 .12159 m
.00375 .12159 L
s
0 .13727 m
.00375 .13727 L
s
0 .15295 m
.00375 .15295 L
s
0 .1843 m
.00375 .1843 L
s
0 .19998 m
.00375 .19998 L
s
0 .21566 m
.00375 .21566 L
s
0 .24701 m
.00375 .24701 L
s
0 .26269 m
.00375 .26269 L
s
0 .27837 m
.00375 .27837 L
s
0 .02753 m
.00375 .02753 L
s
0 .01185 m
.00375 .01185 L
s
0 .30972 m
.00375 .30972 L
s
0 .3254 m
.00375 .3254 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.21429 .32708 m
.21429 .33333 L
s
.40476 .32708 m
.40476 .33333 L
s
.59524 .32708 m
.59524 .33333 L
s
.78571 .32708 m
.78571 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.0619 .32958 m
.0619 .33333 L
s
.1 .32958 m
.1 .33333 L
s
.1381 .32958 m
.1381 .33333 L
s
.17619 .32958 m
.17619 .33333 L
s
.25238 .32958 m
.25238 .33333 L
s
.29048 .32958 m
.29048 .33333 L
s
.32857 .32958 m
.32857 .33333 L
s
.36667 .32958 m
.36667 .33333 L
s
.44286 .32958 m
.44286 .33333 L
s
.48095 .32958 m
.48095 .33333 L
s
.51905 .32958 m
.51905 .33333 L
s
.55714 .32958 m
.55714 .33333 L
s
.63333 .32958 m
.63333 .33333 L
s
.67143 .32958 m
.67143 .33333 L
s
.70952 .32958 m
.70952 .33333 L
s
.74762 .32958 m
.74762 .33333 L
s
.82381 .32958 m
.82381 .33333 L
s
.8619 .32958 m
.8619 .33333 L
s
.9 .32958 m
.9 .33333 L
s
.9381 .32958 m
.9381 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .04321 m
1 .04321 L
s
.99375 .10592 m
1 .10592 L
s
.99375 .16862 m
1 .16862 L
s
.99375 .23133 m
1 .23133 L
s
.99375 .29404 m
1 .29404 L
s
.125 Mabswid
.99625 .05888 m
1 .05888 L
s
.99625 .07456 m
1 .07456 L
s
.99625 .09024 m
1 .09024 L
s
.99625 .12159 m
1 .12159 L
s
.99625 .13727 m
1 .13727 L
s
.99625 .15295 m
1 .15295 L
s
.99625 .1843 m
1 .1843 L
s
.99625 .19998 m
1 .19998 L
s
.99625 .21566 m
1 .21566 L
s
.99625 .24701 m
1 .24701 L
s
.99625 .26269 m
1 .26269 L
s
.99625 .27837 m
1 .27837 L
s
.99625 .02753 m
1 .02753 L
s
.99625 .01185 m
1 .01185 L
s
.99625 .30972 m
1 .30972 L
s
.99625 .3254 m
1 .3254 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
0 .10592 m
1 .10592 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .3254 m
.02499 .32497 L
.02605 .32385 L
.02729 .32169 L
.02846 .31881 L
.03053 .31173 L
.03279 .30131 L
.0379 .26836 L
.04262 .22893 L
.05285 .13087 L
.05786 .08595 L
.06244 .05156 L
.06469 .03789 L
.06713 .02571 L
.06847 .02033 L
.06972 .01618 L
.07091 .013 L
.07218 .01046 L
.0729 .0094 L
.07357 .00868 L
.0743 .00817 L
.07507 .00794 L
.07637 .00828 L
.07711 .00888 L
.0778 .00969 L
.07909 .01185 L
.08026 .01453 L
.0829 .02291 L
.08567 .03486 L
.08823 .04833 L
.09403 .08476 L
.09911 .11932 L
.10458 .15406 L
.10703 .16743 L
.1096 .17942 L
.1118 .1877 L
.11306 .19154 L
.11421 .19443 L
.11537 .19677 L
.11647 .1984 L
.11763 .1995 L
.11889 .19997 L
.11999 .19977 L
.12115 .19892 L
.12215 .19769 L
.12324 .1958 L
.12462 .19266 L
.12593 .18889 L
.12838 .17992 L
.13389 .15188 L
Mistroke
.14385 .08622 L
.1488 .0545 L
.15346 .03007 L
.15604 .0199 L
.15749 .01544 L
.15883 .01222 L
.15996 .01017 L
.16119 .00868 L
.16249 .00797 L
.16369 .00812 L
.16484 .00898 L
.16608 .01074 L
.16726 .01317 L
.16834 .01608 L
.1704 .02333 L
.17258 .03342 L
.1771 .06159 L
.18209 .10192 L
.19154 .19194 L
.19669 .23971 L
.20148 .2777 L
.20421 .29524 L
.20668 .30799 L
.208 .31344 L
.20944 .31823 L
.21022 .32035 L
.21095 .32199 L
.21163 .32324 L
.21237 .32427 L
.21357 .32524 L
.21468 .32535 L
.21536 .32504 L
.21601 .32449 L
.21722 .32276 L
.21849 .31999 L
.21967 .31657 L
.22235 .30587 L
.22476 .29293 L
.22697 .27858 L
.23196 .23903 L
.24099 .1534 L
.24614 .10494 L
.25165 .06028 L
.25433 .04272 L
.25685 .02916 L
.25912 .01972 L
.2604 .01558 L
.26158 .01255 L
.26267 .01043 L
.26384 .00888 L
Mistroke
.26494 .00809 L
.26595 .00795 L
.26713 .00847 L
.26841 .00988 L
.26963 .01198 L
.27076 .01459 L
.27323 .02237 L
.27547 .03166 L
.28048 .05876 L
.29126 .13047 L
.29599 .15935 L
.29849 .1723 L
.30117 .18378 L
.30248 .18835 L
.30371 .19201 L
.30491 .19494 L
.30602 .19706 L
.30707 .19854 L
.30819 .19955 L
.30931 .19997 L
.31054 .19973 L
.31182 .19872 L
.313 .19711 L
.31429 .19461 L
.31564 .19116 L
.31793 .18357 L
.32043 .17289 L
.33122 .10735 L
.33645 .07213 L
.34126 .04327 L
.34367 .03127 L
.34631 .02059 L
.3476 .01649 L
.34898 .01293 L
.34974 .01136 L
.35043 .01018 L
.35113 .00924 L
.35179 .00858 L
.35299 .00797 L
.35426 .00816 L
.35546 .00915 L
.35655 .01072 L
.35783 .01341 L
.35922 .01732 L
.36173 .02701 L
.36398 .03843 L
.36645 .05371 L
.37142 .09198 L
.38032 .17549 L
.38514 .22155 L
Mistroke
.39038 .26612 L
.39278 .28336 L
.39532 .29884 L
.39749 .30946 L
.39872 .31433 L
.39989 .31816 L
.40057 .32003 L
.40131 .32175 L
.40261 .32398 L
.40335 .32478 L
.40413 .32528 L
.40487 .32539 L
.40554 .32521 L
.40686 .32405 L
.40759 .32294 L
.40827 .32162 L
.40952 .31848 L
.41085 .31417 L
.4133 .30353 L
.4156 .29071 L
.42082 .25276 L
.42985 .16913 L
.43945 .08075 L
.44445 .04485 L
.4473 .0293 L
.4486 .02353 L
.44997 .0184 L
.45114 .01483 L
.45242 .01177 L
.45358 .00976 L
.45466 .00856 L
.45594 .00795 L
.45711 .00816 L
.45775 .00859 L
.45845 .0093 L
.45972 .01123 L
.46104 .01409 L
.46227 .01752 L
.46508 .02785 L
.46782 .0409 L
.47076 .05757 L
.48095 .12526 L
.48634 .15866 L
.48899 .17244 L
.49146 .18306 L
.49368 .1906 L
.49482 .19365 L
.49605 .19628 L
.49676 .19748 L
.49741 .19838 L
Mistroke
.49868 .19957 L
.49984 .19997 L
.50107 .19971 L
.50229 .19873 L
.50298 .19787 L
.50362 .19687 L
.50479 .19455 L
.50604 .19141 L
.50819 .18439 L
.51056 .17451 L
.51581 .14605 L
.52073 .11394 L
.5295 .056 L
.5319 .04238 L
.53446 .02983 L
.53668 .02099 L
.53784 .01717 L
.53908 .01381 L
.53974 .01231 L
.54046 .01091 L
.54173 .00909 L
.54303 .0081 L
.54424 .00798 L
.54542 .00863 L
.5465 .00988 L
.54775 .01212 L
.54893 .01503 L
.5515 .02396 L
.55389 .03531 L
.55929 .07078 L
.5778 .24111 L
.58242 .27767 L
.58485 .29344 L
.58741 .30696 L
.58966 .31593 L
.59093 .31973 L
.59212 .32241 L
.59321 .32413 L
.5942 .32507 L
.59535 .32539 L
.59644 .32496 L
.59762 .32365 L
.59893 .32123 L
.59959 .31963 L
.60029 .31762 L
.60157 .31324 L
.60405 .30218 L
.60631 .28926 L
.6118 .24852 L
.61703 .20114 L
Mistroke
.62662 .10923 L
.63188 .06554 L
.63446 .04775 L
.63684 .03398 L
.63909 .02347 L
.64147 .01524 L
.64271 .01217 L
.64386 .01005 L
.64513 .00857 L
.64584 .00812 L
.64648 .00794 L
.6476 .00817 L
.64863 .00897 L
.64977 .01049 L
.65097 .01282 L
.653 .01829 L
.65523 .02646 L
.66545 .08467 L
.67102 .12257 L
.67621 .1552 L
.68065 .17779 L
.68313 .18738 L
.68539 .19387 L
.68668 .19656 L
.68787 .19836 L
.68918 .19958 L
.68984 .19988 L
.69056 .19998 L
.69177 .19958 L
.69308 .19836 L
.69431 .19649 L
.69544 .19416 L
.69783 .18736 L
.70037 .17752 L
.70494 .15411 L
.71529 .08612 L
.72039 .05356 L
.72288 .03972 L
.72518 .02878 L
.72723 .02071 L
.72948 .01398 L
.73065 .01143 L
.73175 .00966 L
.7329 .00845 L
.73413 .00794 L
.73536 .00824 L
.73605 .00877 L
.73671 .00951 L
.73802 .0117 L
.73876 .01335 L
Mistroke
.73944 .01512 L
.74195 .02383 L
.74434 .03515 L
.74963 .06976 L
.75542 .11914 L
.76598 .22043 L
.77096 .26326 L
.77555 .29477 L
.77792 .30709 L
.78041 .31684 L
.78171 .32049 L
.78292 .323 L
.78361 .32404 L
.78425 .32474 L
.78498 .32523 L
.78567 .3254 L
.78682 .32502 L
.78804 .32374 L
.78909 .32192 L
.79024 .31916 L
.79147 .31533 L
.7928 .31023 L
.79521 .29854 L
.80053 .26274 L
.80614 .21402 L
.81617 .11762 L
.82108 .07534 L
.82571 .04301 L
.82827 .02922 L
.82962 .02328 L
.83104 .01801 L
.83225 .01443 L
.83357 .01138 L
.83477 .00944 L
.8359 .00835 L
.83703 .00794 L
.83827 .00828 L
.83944 .00934 L
.84052 .01096 L
.84159 .01314 L
.84257 .0156 L
.84475 .0227 L
.8471 .03261 L
.84965 .0456 L
.85426 .07362 L
.86458 .14261 L
.86962 .17088 L
.87183 .18074 L
.87422 .18934 L
.87551 .19299 L
Mistroke
.87671 .19571 L
.87785 .1977 L
.87907 .19913 L
.88034 .19989 L
.88154 .1999 L
.88285 .19912 L
.88359 .19832 L
.88427 .19737 L
.8856 .19487 L
.88683 .19184 L
.88964 .1825 L
.89237 .17044 L
.89529 .15482 L
.90555 .08761 L
.91094 .05308 L
.9139 .037 L
.91666 .02463 L
.91907 .01637 L
.92042 .0129 L
.92165 .0105 L
.92235 .00949 L
.923 .00877 L
.92372 .00823 L
.92447 .00796 L
.9252 .00798 L
.92588 .00826 L
.92715 .00946 L
.92833 .01136 L
.92957 .01419 L
.9318 .02134 L
.93419 .03193 L
.93681 .04679 L
.97619 .3254 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00:Oooool2o`0005Cooooo0ol0001Cooooo`Go0000Doooool3o`0005Gooooo0ol0001Coooo
o`?o00006_ooool002Sooooo00Co0000oooooooooooo0000E?ooool00ol0003oooooooooo`1Coooo
o`04o`000?ooooooooooo`0005;ooooo00Go0000ooooooooooooooooo`00001Eooooo`03o`000?oo
oooooooo057ooooo00Go0000ooooooooooooooooo`00000Iooooo`00:?ooool01?l0003ooooooooo
ool0001Dooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
ooooo`1@ooooo`Go0000E_ooool00ol0003oooooooooo`0Gooooo`00:?ooool01?l0003ooooooooo
ool0001Dooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0Doooool2o`0005?ooooo
00Co0000oooooooooooo0000Eoooool00ol0003oooooooooo`0Gooooo`00:?ooool01?l0003ooooo
ooooool0001Dooooo`03o`000?oooooooooo05;ooooo00Go0000ooooooooooooooooo`00001Foooo
o`03o`000?oooooooooo057ooooo00?o0000ooooool00000Doooool4o`0001[ooooo000Xooooo`04
o`000?ooooooooooo`0005?ooooo0_l0001Dooooo`05o`000?ooooooooooooooool00000D_ooool0
1Ol0003ooooooooooooooooo000005Cooooo0_l0001Cooooo`03o`000?oooooooooo01_ooooo000Y
ooooo`;o0000EOooool00ol0003oooooooooo`1Cooooo`?o0000E?ooool3o`0005Kooooo00?o0000
ooooooooool0DOooool5o`0001Wooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo
003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo000Ooooooooo0000
bol0000?ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`03
o`000?oooooooooo01oooooo0ol00?lUooooo`?o003o;?ooool2o`00obKooooo0ol00?l/ooooo`?o
003o9Oooool3o`00obcooooo0ol00?lUooooo`?o003o;?ooool3o`00obGooooo0_l00?lQooooo`03
o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01kooooo0_l00?l00ooooooo003o
ooooo`0Sooooo`04o`00ooooooooooooo`00ob_ooooo00Co003ooooooooooooo003o9?ooool01?l0
0?ooooooooooool00?l/ooooo`03o`00oooooooo003o02Cooooo00Co003ooooooooooooo003o;?oo
ool00ol00?ooooooo`00o`0Tooooo`;o003o00?oooooo`00ooooool0:_ooool2o`00o`03ooooool0
0?oooooo02?ooooo0_l00?l00ooooooo003oooooo`0Oooooo`03o`000?oooooooooo00gooooo000O
ooooo`?o00007_ooool01?l00?ooooooooooool00?lTooooo`05o`00ooooooooooooooooool00?l0
:_ooool01Ol00?oooooooooooooooooo003o02?ooooo00Go003oooooooooooooooooo`00o`0Zoooo
o`04o`00ooooooooooooo`00obCooooo00Go003oooooooooooooooooo`00o`0Zooooo`05o`00oooo
ooooooooooooool00?l08oooool01Ol00?oooooooooooooooooo003o02[ooooo00Go003ooooooooo
ooooooooo`00o`0Sooooo`04o`00ooooooooooooo`00oaoooooo0_l0000?ooooo`007oooool00ol0
003oooooooooo`0Nooooo`05o`00ooooooooooooooooool00?l08_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Q
ooooo`05o`00ooooooooooooooooool00?l0:Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo027ooooo00Go003oooooooooooooooooo`00o`0Yooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool08Oooool01Ol00?oooooooooooooooooo003o02[ooooo00Go003ooooooooo
ooooooooo`00o`0Sooooo`05o`00ooooooooooooooooool00?l07oooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool08?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool09oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool08?ooool01Ol00?oooooooooooooooooo003o02Wooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07Oooool0
0ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
02Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
01oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
02Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool07?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003o
ooooooooo`0Mooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Uooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0Nooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07?ooool00ol0003o
ooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Looooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Kooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool09Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01kooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool07?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooooooo
o`0Looooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Nooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Nooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07?ooool00ol0003ooooooooo
o`0=ooooo`007oooool3o`0001cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0J
ooooo`;o00003oooool001oooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Toooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo02Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Toooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo01_ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooooooo
ool07?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02Cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool08oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01_ooooo00?o0000oooooooo
ool03Oooool001oooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Tooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo02?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Tooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01_ooooo00?o0000ooooooooool03Oooool001Cooooo1Ol00006ooooo`03o`000?oo
oooooooo01_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Rooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo02?ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Kooooo`03o`000?oo
oooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool06ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool08ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01_ooooo00?o0000ooooooooool03Ooo
ool000kooooo1Ol00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06_ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool03Oooool0
01Oooooo00?o0000ooooooooool01Oooool4o`0001[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Iooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool06_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0Gooooo`Co00003oooool001Cooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo01_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Ioooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo01[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Qoooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo027ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Joooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Joooo
o`03o`000?oooooooooo00gooooo000Dooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0Jooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool06Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Iooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool06_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Iooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool06_ooool00ol0
003oooooooooo`0=ooooo`005Oooool3o`0000Oooooo00?o0000ooooooooool06_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool06Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Jooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool08Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool06Oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool03Oooool001oooooo
00?o0000ooooooooool06_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo023ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool08Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool06Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01[ooooo
00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool06_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0Qooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool08?ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0Pooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo01[ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000
ooooooooool06_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool05oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool08?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool06?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01[ooooo00?o0000
ooooooooool03Oooool001oooooo0ol0000Jooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool07oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo023ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool06?ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo01[ooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01oooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`00
0?oooooooooo01Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Oooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo01oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Iooooo`03o`00
0?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07_oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooo
oooo01Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo01Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo01kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo01Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooo
oooo00gooooo000Oooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0Nooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0Iooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Wo
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01ko
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00go
oooo000Oooooo`?o00006Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo
0_l0000?ooooo`007oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool06?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0H
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`0Hooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool07Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool06?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Hooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo01Cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Mooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0=ooooo`00
7oooool00ol0003oooooooooo`0Hooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
6?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Hooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0=ooooo`007oooool3
o`0001Sooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo01?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Fooooo`;o00003oooool0
01oooooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
01Oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool06?ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`0Looooo`03o`00oooooooooooo00kooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00oooooo00?o003oooooooooool07?ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03Oooool001oooooo
00?o0000ooooooooool06?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01?ooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool04oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01_ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01Oooooo
00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool05oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`0Jooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04oooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00oooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`0Kooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool03Oooool001Kooooo0_l00007
ooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0G
ooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool05oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01Oooooo00?o0000
ooooooooool03Oooool001Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0G
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool05_ooool00ol0003oooooooooo`0=
ooooo`005Oooool01?l0003oooooooooool00006oooooa[o000000?o003oo`000?l000004?l00000
0ol00?oo0000o`00000Ao`000003o`00ool0003o0000013o000000?o003oo`000?l000006_l00000
0ol00?oo0000o`00000@o`000003o`00ool0003o0000017o000000?o003oo`000?l000004?l00000
0ol00?oo0000o`00000Jo`000003o`00ool0003o0000013o000000?o003oo`000?l000004Ol00000
0ol00?oo0000o`00000@o`000003o`00ool0003o000001[o000000?o003oo`000?l000004?l00000
0ol00?oo0000o`00000Ao`000003o`00ool0003o000000oo000000?o003oo`000?l000006ol00000
0ol00?oo0000o`00000@o`000003o`00ool0003o0000017o000000?o003oo`000?l000004?l00000
0ol00?oo0000o`00000Go`0000oooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool05oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Kooooo00?o0000
ooooooooool03Oooool001Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0G
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool05_ooool00ol0003oooooooooo`0=
ooooo`005_ooool2o`0000Oooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Joooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo01[ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Ioooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo01Kooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooooooo
ool05oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Wooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool06_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Kooooo00?o0000oooooooo
ool03Oooool001oooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo017ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo017ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Iooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo01Kooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool05ooo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06Ooo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool03Ooo
ool001oooooo0ol0000Fooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool06Oooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05?ooool2
o`0000oooooo000Oooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06?ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo00oooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0Hooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06Oooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo00kooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`0Eooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Ko
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01So
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06?ooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo00kooooo00?o003oooooooooool04oooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`0Cooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool06Oooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo00kooooo00?o003oooooooooool04oooool00ol00?oooooo
ooooo`0Eooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Kooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool06?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00gooooo000O
ooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0C
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0H
ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0C
ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0C
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0E
ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Kooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo00gooooo000Oooooo`?o
00005_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool05?ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool05?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool06?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool05?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01?ooooo0_l0000?ooooo`00
7oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool0
5oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
5?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Eooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0=ooooo`007oooool0
0ol0003oooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool0
0ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
01Oooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003o
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05_ooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Fooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol0003o
ooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool04oooool00ol0003oooooooooo`0=ooooo`007oooool3o`0001Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool05oooool00ol00?ooooooooooo`0Booooo`;o00003oooool001oooooo00?o0000
ooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01?ooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooooooo01?ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooooooo
ool05Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Kooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01?ooooo00?o0000oooooooo
ool03Oooool001oooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Dooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo01Kooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo01?ooooo00?o0000ooooooooool03Oooool001Cooooo1Ol00006ooooo`03o`000?oo
oooooooo01Cooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05oooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Gooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Cooooo`03o`000?oo
oooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool05?oo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool05ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool03Ooo
ool001Kooooo00?o0000ooooooooool01_ooool4o`0001?ooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool04oooool0
0ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05oooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06Oooool0
0ol00?ooooooooooo`0?ooooo`Co00003oooool001Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Hooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool06Oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool05?ooool00ol0
0?ooooooooooo`0Hooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06?ooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Gooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool06?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool04_ooool00ol0
003oooooooooo`0=ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool05?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Wooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool06Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01;ooooo00?o0000oooo
ooooool03Oooool001Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
01Cooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01Wooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo
00gooooo000Eooooo`?o00001oooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo01So
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01?o
oooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01So
oooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Wo
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01Wo
oooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooo
ooooo`0Dooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Iooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool06_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`0Iooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06?ooool00ol00?oooooo
ooooo`0Cooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Iooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool06_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool04_ooool00ol0003ooooo
ooooo`0=ooooo`007oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo01Wooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Wooooo00?o
003oooooooooool04oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool06Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01Wooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01?ooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01_ooooo00?o
003oooooooooool04Oooool00ol0003oooooooooo`0=ooooo`007oooool3o`0001?ooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool06Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01?ooooo00?o003o
ooooooooool06_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0@ooooo`;o00003oooool001oooooo00?o0000oooo
ooooool04oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01[ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo01?ooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01Wooooo00?o003ooooo
ooooool04oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01[ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo017ooooo00?o0000oooo
ooooool03Oooool001oooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`0Jooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Jooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo01Wooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`0Jooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0Cooooo`03
o`00oooooooooooo01_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Kooooo`03
o`00oooooooooooo017ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0
4oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
6_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool0
3Oooool001oooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo017ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool04oooool0
0ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l07_ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo01gooooo00Go003oooooooooooooooooo`00o`0Nooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Mooooo`03o`00
oooooooooooo017ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool04ooo
ool00ol00?ooooooooooo`0Looooo`05o`00ooooooooooooooooool00?l07_ooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo01gooooo00Co003ooooooooooooo003o7oooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo01cooooo00Co003ooooooooooooo003o7oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo01gooooo00Go003oooooooooooooooooo`00o`0N
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool07?ooool01?l00?ooooooooooool0
0?lQooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000
ooooooooool04oooool00ol00?ooooooooooo`0Mooooo`?o003o7oooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo01kooooo0ol00?lOooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool07Oooool3o`00oaoooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0N
ooooo`?o003o7oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo0_l00?l0
0ooooooo003oooooo`0Pooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03Oooool0
01oooooo0ol0000Booooo`03o`00oooooooooooo01oooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo01kooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo01kooooo00?o003oooooooooool08?ooool00ol0
0?ooooooooooo`0?ooooo`;o00003oooool001oooooo00?o0000ooooooooool04_ooool00ol00?oo
ooooooooo`10ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0@?ooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`10ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0@_ooool00ol00?oo
ooooooooo`0@ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01;ooooo
00?o003oooooooooool0@Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo043ooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool0@?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo04;ooooo
00?o003oooooooooool04?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooooooo
o`0Booooo`03o`00oooooooooooo047ooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`11ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0@?ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`12ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000
ooooooooool04_ooool00ol00?ooooooooooo`11ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool0@Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo043ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool0@_ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00gooooo000Ooooo
o`03o`000?oooooooooo01;ooooo00?o003oooooooooool0@Oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo04;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`11oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool0@Oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo04?ooooo00?o003oooooooooool03oooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo047ooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool0@Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04;ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00oooooo00?o0000oooooooo
ool03Oooool001oooooo0ol0000Booooo`03o`00oooooooooooo047ooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
@Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04;ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00kooooo0_l0000?ooooo`007ooo
ool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo047ooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`12ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0@Ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04;ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00oooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool0@_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo047ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooo
oooo00gooooo000Oooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool0@_ooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo04;ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`12ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0@_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool03oooool00ol0
003oooooooooo`0=ooooo`005_ooool3o`0000Kooooo00?o0000ooooooooool04Oooool00ol00?oo
ooooooooo`12ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0@_ooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo04;ooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`12ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0A?ooool00ol00?oo
ooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool0@_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04;ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`12ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool0AOooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
000Dooooo`Go00001_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo04?ooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool0@_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo04?ooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo00kooooo00?o
0000ooooooooool03Oooool001Cooooo00Co0000oooooooooooo00001oooool4o`00013ooooo00?o
003oooooooooool0@oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo04Cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool0@oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo04Gooooo00?o
003oooooooooool02oooool4o`0000oooooo000Eooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool04Oooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool0A?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo04?ooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool0AOooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00gooooo000Foooo
o`;o00001oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo04?ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool0@oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo04?ooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo00kooooo00?o0000oooo
ooooool03Oooool001Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03
o`00oooooooooooo04?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`14ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool0@oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo04Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`15ooooo`03
o`00oooooooooooo00kooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0
4?ooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
A?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo04?ooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`14ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
A_ooool00ol00?ooooooooooo`0>ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oo
oooooooo013ooooo00?o003oooooooooool0A?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo04Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`13ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool0AOooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo04Oooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0=ooooo`007oooool0
0ol0003oooooooooo`0@ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`15ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0A?ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo04Gooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`17ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool03Oooool0
01oooooo0ol0000@ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`15ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0A?ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo04Gooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`17ooooo`03o`00oooooooooooo00cooooo0_l0000?ooooo`007oooool00ol0003o
ooooooooo`0@ooooo`03o`00oooooooooooo04Cooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`16ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0A?ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo04Gooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`17ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool03Oooool001oooooo
00?o0000ooooooooool04?ooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool0A_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo04Gooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool0Aoooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
000Oooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0AOooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo04Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`15ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0AOooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`007oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo04Gooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool0AOooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo04Gooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00gooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`15oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool0A_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo04Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`17oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool0BOooool00ol00?ooooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00oooooo00?o003ooooooooo
ool0A_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo04Oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool0Aoooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04Wooooo00?o003ooooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`007oooool3o`0000oooooo00?o003oooooooooool0
A_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
Aoooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool0
2oooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool0A_oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0Aooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooo
oooo04Kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`17ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool0A_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo04Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`19ooooo`03o`00oooooooo
oooo00cooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool03oooool00ol0
0?ooooooooooo`16ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0B?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo04Kooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`17ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0BOooool00ol0
0?ooooooooooo`0<ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00oo
oooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo04So
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`17ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04Wo
oooo00?o003oooooooooool03?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooo
ooooo`0?ooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`18ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0B?ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`1;ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool03Oooool001oooooo00?o
0000ooooooooool03_ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool0B?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo04Sooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`19ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool0Boooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000O
ooooo`?o00003_ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo04Sooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`19ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool0Boooool00ol00?ooooooooooo`0:ooooo`;o00003oooool001oooooo00?o0000oooo
ooooool03_ooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool0BOooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo04Sooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`19ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool0Boooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000Oooooo`03
o`000?oooooooooo00kooooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo04Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`18ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool0BOooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo04_ooooo00?o003oooooooooool02oooool00ol0003oooooooooo`0=ooooo`00
7oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`19ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
BOooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo04[ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`1;ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool0
3Oooool001oooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`1:ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool0B_ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo04[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`1:ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool0Boooool00ol00?ooooooooooo`0;ooooo`03o`000?oo
oooooooo00gooooo000Eooooo`?o00001oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooo
oooo04[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`1:ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool0B_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo04_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`1<ooooo`03o`00oooooooo
oooo00[ooooo00?o0000ooooooooool03Oooool001Cooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0B_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo04[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`1;
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0Boooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo04cooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`0=
ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool03Oooool0
0ol00?ooooooooooo`1;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0Boooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04_ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`1;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0COooool0
0ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00gooooo000Dooooo`Co00001oooool4o`00
00cooooo00?o003oooooooooool0Boooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
04_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`1;ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool0Boooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
04gooooo00?o003oooooooooool01oooool4o`0000oooooo000Dooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`1<ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool0Boooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo04_o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1<ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool0COooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00go
oooo000Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol00?oooooo
ooooo`1<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0Boooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo04cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`1<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0COooool00ol00?oooooo
ooooo`0:ooooo`03o`000?oooooooooo00gooooo000Fooooo`;o00001oooool00ol0003ooooooooo
o`0<ooooo`03o`00oooooooooooo04cooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`1<ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0COooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo04cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`1=ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000
ooooooooool03?ooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool0C?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool0C_ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00gooooo000Ooooo
o`03o`000?oooooooooo00cooooo00?o003oooooooooool0COooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo04gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1=oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool0COooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo04oooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo04kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool0COooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo00Wooooo00?o0000oooooooo
ool03Oooool001oooooo0ol0000;ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`1=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
C_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo00Sooooo0_l0000?ooooo`007ooo
ool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`1>ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0Cooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`1>ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo04oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool0D?ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooo
oooo00gooooo000Oooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0D?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`1?ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Coooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool02Oooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo053o
oooo00Go003oooooooooooooooooo`00o`1Booooo`05o`00ooooooooooooooooool00?l0D_ooool0
1Ol00?oooooooooooooooooo003o05;ooooo00Go003oooooooooooooooooo`00o`1Dooooo`03o`00
oooooooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02_oo
ool00ol00?ooooooooooo`1@ooooo`;o003o0_ooool00ol00?ooooooooooo`1Aooooo`04o`00oooo
ooooooooo`00oe;ooooo00Go003oooooooooooooooooo`00o`1Booooo`05o`00oooooooooooooooo
ool00?l0E?ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00gooooo000Oooooo`03
o`000?oooooooooo00Wooooo00?o003oooooooooool0D_ooool01?l00?ooooooo`00ool00?mCoooo
o`04o`00oooooooo003oo`00oe?ooooo00?o003oooooool00?l0E?ooool00ol00?ooooooo`00o`1E
ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03Oooool001oooooo0ol00008oooo
o`;o003oEOooool2o`00oeGooooo0_l00?mEooooo`;o003oEOooool2o`00oeGooooo00?o003ooooo
ooooool01oooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo05Cooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03Oooool001oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03Oooool001ooooooool0003;o`0000oooooo0000
\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-0.491105, -4.40503, 0.0114913, \
0.069809}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Continuous-time frequency spectrum (CTFT)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(X[f_] = 
      FourierTransform[x[t], t, 
          f]\  /. {\[Delta][b_\ a_ + f_\ a_] \[Rule] \[Delta][b + f]/
              a, \[Delta][\ a_ + f_\ a_] \[Rule] \[Delta][1 + f]/
              a}\)], "Input"],

Cell[BoxData[
    \(2\ DiracDelta[\(-2\) + f] + DiracDelta[\(-1\) + f] + DiracDelta[f] + 
      DiracDelta[1 + f] + 2\ DiracDelta[2 + f]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gX = 
        Plot[Evaluate[PlotConvert[X[f],  .04]], {f, \(-5\), 5}, 
          PlotStyle \[Rule] {Blue, Thickness[ .005]}, \ 
          PlotPoints \[Rule] 1000, \ 
          PlotRange \[Rule] {\(- .02\), 4.02}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.00305957 0.152979 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00306 -6 -4.5 ]
[-0.0125 .00306 0 4.5 ]
[-0.0125 .15604 -6 -4.5 ]
[-0.0125 .15604 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .462 -6 -4.5 ]
[-0.0125 .462 0 4.5 ]
[-0.0125 .61497 -6 -4.5 ]
[-0.0125 .61497 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00306 m
.00625 .00306 L
s
[(0)] -0.0125 .00306 1 0 Mshowa
0 .15604 m
.00625 .15604 L
s
[(1)] -0.0125 .15604 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(2)] -0.0125 .30902 1 0 Mshowa
0 .462 m
.00625 .462 L
s
[(3)] -0.0125 .462 1 0 Mshowa
0 .61497 m
.00625 .61497 L
s
[(4)] -0.0125 .61497 1 0 Mshowa
.125 Mabswid
0 .03366 m
.00375 .03366 L
s
0 .06425 m
.00375 .06425 L
s
0 .09485 m
.00375 .09485 L
s
0 .12544 m
.00375 .12544 L
s
0 .18663 m
.00375 .18663 L
s
0 .21723 m
.00375 .21723 L
s
0 .24783 m
.00375 .24783 L
s
0 .27842 m
.00375 .27842 L
s
0 .33961 m
.00375 .33961 L
s
0 .37021 m
.00375 .37021 L
s
0 .4008 m
.00375 .4008 L
s
0 .4314 m
.00375 .4314 L
s
0 .49259 m
.00375 .49259 L
s
0 .52319 m
.00375 .52319 L
s
0 .55378 m
.00375 .55378 L
s
0 .58438 m
.00375 .58438 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00306 m
1 .00306 L
s
.99375 .15604 m
1 .15604 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .462 m
1 .462 L
s
.99375 .61497 m
1 .61497 L
s
.125 Mabswid
.99625 .03366 m
1 .03366 L
s
.99625 .06425 m
1 .06425 L
s
.99625 .09485 m
1 .09485 L
s
.99625 .12544 m
1 .12544 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .21723 m
1 .21723 L
s
.99625 .24783 m
1 .24783 L
s
.99625 .27842 m
1 .27842 L
s
.99625 .33961 m
1 .33961 L
s
.99625 .37021 m
1 .37021 L
s
.99625 .4008 m
1 .4008 L
s
.99625 .4314 m
1 .4314 L
s
.99625 .49259 m
1 .49259 L
s
.99625 .52319 m
1 .52319 L
s
.99625 .55378 m
1 .55378 L
s
.99625 .58438 m
1 .58438 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.02381 .00306 m
.02474 .00306 L
.02575 .00306 L
.0267 .00306 L
.02761 .00306 L
.02859 .00306 L
.02952 .00306 L
.03052 .00306 L
.03148 .00306 L
.0324 .00306 L
.03338 .00306 L
.03433 .00306 L
.03524 .00306 L
.03621 .00306 L
.03714 .00306 L
.03813 .00306 L
.03908 .00306 L
.04 .00306 L
.04098 .00306 L
.04192 .00306 L
.04292 .00306 L
.04388 .00306 L
.0448 .00306 L
.04579 .00306 L
.04674 .00306 L
.04765 .00306 L
.04862 .00306 L
.04956 .00306 L
.05055 .00306 L
.05151 .00306 L
.05243 .00306 L
.05341 .00306 L
.05435 .00306 L
.05526 .00306 L
.05622 .00306 L
.05715 .00306 L
.05814 .00306 L
.05909 .00306 L
.06001 .00306 L
.06098 .00306 L
.06192 .00306 L
.06292 .00306 L
.06388 .00306 L
.0648 .00306 L
.06579 .00306 L
.06673 .00306 L
.06764 .00306 L
.06861 .00306 L
.06954 .00306 L
.07054 .00306 L
Mistroke
.07149 .00306 L
.07241 .00306 L
.07339 .00306 L
.07433 .00306 L
.07533 .00306 L
.07629 .00306 L
.07722 .00306 L
.07821 .00306 L
.07916 .00306 L
.08007 .00306 L
.08104 .00306 L
.08198 .00306 L
.08297 .00306 L
.08393 .00306 L
.08485 .00306 L
.08584 .00306 L
.08678 .00306 L
.08769 .00306 L
.08866 .00306 L
.08959 .00306 L
.09058 .00306 L
.09153 .00306 L
.09245 .00306 L
.09342 .00306 L
.09436 .00306 L
.09536 .00306 L
.09632 .00306 L
.09725 .00306 L
.09823 .00306 L
.09918 .00306 L
.10009 .00306 L
.10106 .00306 L
.10199 .00306 L
.10299 .00306 L
.10394 .00306 L
.10486 .00306 L
.10584 .00306 L
.10678 .00306 L
.10769 .00306 L
.10866 .00306 L
.10958 .00306 L
.11057 .00306 L
.11152 .00306 L
.11244 .00306 L
.11341 .00306 L
.11435 .00306 L
.11535 .00306 L
.1163 .00306 L
.11723 .00306 L
.11821 .00306 L
Mistroke
.11916 .00306 L
.12007 .00306 L
.12103 .00306 L
.12197 .00306 L
.12296 .00306 L
.12391 .00306 L
.12483 .00306 L
.12581 .00306 L
.12675 .00306 L
.12775 .00306 L
.12871 .00306 L
.12964 .00306 L
.13062 .00306 L
.13157 .00306 L
.13248 .00306 L
.13345 .00306 L
.13439 .00306 L
.13538 .00306 L
.13634 .00306 L
.13726 .00306 L
.13824 .00306 L
.13919 .00306 L
.14009 .00306 L
.14106 .00306 L
.14199 .00306 L
.14298 .00306 L
.14393 .00306 L
.14485 .00306 L
.14582 .00306 L
.14676 .00306 L
.14776 .00306 L
.14872 .00306 L
.14964 .00306 L
.15063 .00306 L
.15158 .00306 L
.15249 .00306 L
.15346 .00306 L
.15439 .00306 L
.15538 .00306 L
.15634 .00306 L
.15726 .00306 L
.15823 .00306 L
.15918 .00306 L
.16018 .00306 L
.16114 .00306 L
.16207 .00306 L
.16306 .00306 L
.16401 .00306 L
.16492 .00306 L
.16589 .00306 L
Mistroke
.16683 .00306 L
.16782 .00306 L
.16878 .00306 L
.16971 .00306 L
.17069 .00306 L
.17163 .00306 L
.17254 .00306 L
.17351 .00306 L
.17444 .00306 L
.17543 .00306 L
.17638 .00306 L
.1773 .00306 L
.17828 .00306 L
.17922 .00306 L
.18022 .00306 L
.18118 .00306 L
.1821 .00306 L
.18309 .00306 L
.18404 .00306 L
.18495 .00306 L
.18592 .00306 L
.18685 .00306 L
.18785 .00306 L
.1888 .00306 L
.18972 .00306 L
.1907 .00306 L
.19165 .00306 L
.19255 .00306 L
.19352 .00306 L
.19445 .00306 L
.19544 .00306 L
.19639 .00306 L
.1973 .00306 L
.19828 .00306 L
.19922 .00306 L
.20021 .00306 L
.20117 .00306 L
.2021 .00306 L
.20308 .00306 L
.20403 .00306 L
.20494 .00306 L
.2059 .00306 L
.20684 .00306 L
.20783 .00306 L
.20878 .00306 L
.2097 .00306 L
.21068 .00306 L
.21162 .00306 L
.21262 .00306 L
.21358 .00306 L
Mistroke
.21451 .00306 L
.2155 .00306 L
.21645 .00306 L
.21736 .00306 L
.21833 .00306 L
.21927 .00306 L
.22026 .00306 L
.22122 .00306 L
.22214 .00306 L
.22312 .00306 L
.22407 .00306 L
.22497 .00306 L
.22594 .00306 L
.22687 .00306 L
.22786 .00306 L
.22881 .00306 L
.22973 .00306 L
.23071 .00306 L
.23164 .00306 L
.23264 .00306 L
.2336 .00306 L
.23453 .00306 L
.23551 .00306 L
.23646 .00306 L
.23737 .00306 L
.23834 .00306 L
.23928 .00306 L
.24027 .00306 L
.24122 .00306 L
.24214 .00306 L
.24312 .00306 L
.24406 .00306 L
.24497 .00306 L
.24594 .00306 L
.24686 .00306 L
.24785 .00306 L
.2488 .00306 L
.24972 .00306 L
.25069 .00306 L
.25163 .00306 L
.25262 .00306 L
.25358 .00306 L
.25451 .00306 L
.25549 .00306 L
.25643 .00306 L
.25734 .00306 L
.25831 .00306 L
.25924 .00306 L
.26023 .00306 L
.26119 .00306 L
Mistroke
.2621 .00306 L
.26308 .00306 L
.26402 .00306 L
.26502 .00306 L
.26598 .00306 L
.26691 .00306 L
.26789 .00306 L
.26884 .00306 L
.26976 .00306 L
.27073 .00306 L
.27166 .00306 L
.27266 .00306 L
.27361 .00306 L
.27453 .00306 L
.27551 .00306 L
.27646 .00306 L
.27736 .00306 L
.27833 .00306 L
.27926 .00306 L
.28025 .00306 L
.2812 .00306 L
.28212 .00306 L
.28309 .00306 L
.28403 .00306 L
.28503 .00306 L
.28599 .00306 L
.28691 .00306 L
.28789 .00306 L
.28884 .00306 L
.28975 .00306 L
.29072 .00306 L
.29165 .00306 L
.29265 .00306 L
.2936 .00306 L
.29452 .00306 L
.2955 .00306 L
.29644 .00306 L
.29744 .00306 L
.2984 .00306 L
.29933 .00306 L
.30032 .00306 L
.30127 .00306 L
.30218 .00306 L
.30315 .00306 L
.30409 .00306 L
.30509 .00306 L
.30604 .00306 L
.30697 .00306 L
.30721 .00306 L
.30744 .00306 L
Mistroke
.3075 .00306 L
.30756 .00306 L
.30759 .00306 L
.30761 .00306 L
.30762 .30902 L
.30765 .30902 L
.30768 .30902 L
.30795 .30902 L
.30895 .30902 L
.30991 .30902 L
.31083 .30902 L
.31108 .30902 L
.3112 .30902 L
.31131 .30902 L
.31134 .30902 L
.31137 .30902 L
.3114 .30902 L
.31143 .00306 L
.31146 .00306 L
.31149 .00306 L
.31155 .00306 L
.31182 .00306 L
.31278 .00306 L
.31371 .00306 L
.3147 .00306 L
.31565 .00306 L
.31657 .00306 L
.31754 .00306 L
.31848 .00306 L
.31947 .00306 L
.32043 .00306 L
.32136 .00306 L
.32234 .00306 L
.32329 .00306 L
.3242 .00306 L
.32516 .00306 L
.3261 .00306 L
.32709 .00306 L
.32804 .00306 L
.32896 .00306 L
.32994 .00306 L
.33088 .00306 L
.33188 .00306 L
.33284 .00306 L
.33377 .00306 L
.33475 .00306 L
.3357 .00306 L
.33662 .00306 L
.33759 .00306 L
.33852 .00306 L
Mistroke
.33952 .00306 L
.34048 .00306 L
.3414 .00306 L
.34238 .00306 L
.34332 .00306 L
.34423 .00306 L
.3452 .00306 L
.34613 .00306 L
.34711 .00306 L
.34807 .00306 L
.34898 .00306 L
.34996 .00306 L
.3509 .00306 L
.35189 .00306 L
.35286 .00306 L
.35378 .00306 L
.35476 .00306 L
.35571 .00306 L
.35662 .00306 L
.35759 .00306 L
.35853 .00306 L
.35952 .00306 L
.36047 .00306 L
.36139 .00306 L
.36237 .00306 L
.36331 .00306 L
.36431 .00306 L
.36528 .00306 L
.36621 .00306 L
.36719 .00306 L
.36814 .00306 L
.36906 .00306 L
.37003 .00306 L
.37097 .00306 L
.37196 .00306 L
.37292 .00306 L
.37385 .00306 L
.37483 .00306 L
.37577 .00306 L
.37668 .00306 L
.37765 .00306 L
.37858 .00306 L
.37957 .00306 L
.38052 .00306 L
.38144 .00306 L
.38242 .00306 L
.38336 .00306 L
.38436 .00306 L
.38532 .00306 L
.38625 .00306 L
Mistroke
.38723 .00306 L
.38818 .00306 L
.38909 .00306 L
.39006 .00306 L
.391 .00306 L
.39199 .00306 L
.39295 .00306 L
.39387 .00306 L
.39485 .00306 L
.39579 .00306 L
.3967 .00306 L
.39766 .00306 L
.39859 .00306 L
.39958 .00306 L
.40053 .00306 L
.40145 .00306 L
.40196 .00306 L
.40242 .00306 L
.40265 .00306 L
.40272 .00306 L
.40278 .00306 L
.40281 .00306 L
.40284 .00306 L
.40286 .15604 L
.40287 .15604 L
.40291 .15604 L
.40336 .15604 L
.40432 .15604 L
.40523 .15604 L
.40575 .15604 L
.40621 .15604 L
.40645 .15604 L
.40651 .15604 L
.40658 .15604 L
.40663 .15604 L
.40665 .15604 L
.40667 .15604 L
.4067 .00306 L
.40673 .00306 L
.40676 .00306 L
.40682 .00306 L
.40694 .00306 L
.40715 .00306 L
.4081 .00306 L
.40901 .00306 L
.40997 .00306 L
.4109 .00306 L
.41189 .00306 L
.41285 .00306 L
.41376 .00306 L
Mistroke
.41474 .00306 L
.41568 .00306 L
.41668 .00306 L
.41764 .00306 L
.41856 .00306 L
.41955 .00306 L
.42049 .00306 L
.42141 .00306 L
.42238 .00306 L
.42331 .00306 L
.4243 .00306 L
.42526 .00306 L
.42618 .00306 L
.42716 .00306 L
.4281 .00306 L
.42901 .00306 L
.42997 .00306 L
.4309 .00306 L
.43189 .00306 L
.43284 .00306 L
.43375 .00306 L
.43473 .00306 L
.43566 .00306 L
.43666 .00306 L
.43762 .00306 L
.43854 .00306 L
.43952 .00306 L
.44047 .00306 L
.44138 .00306 L
.44235 .00306 L
.44328 .00306 L
.44427 .00306 L
.44522 .00306 L
.44614 .00306 L
.44712 .00306 L
.44806 .00306 L
.44906 .00306 L
.45002 .00306 L
.45095 .00306 L
.45193 .00306 L
.45288 .00306 L
.4538 .00306 L
.45477 .00306 L
.4557 .00306 L
.4567 .00306 L
.45765 .00306 L
.45858 .00306 L
.45956 .00306 L
.4605 .00306 L
.46141 .00306 L
Mistroke
.46237 .00306 L
.4633 .00306 L
.46429 .00306 L
.46524 .00306 L
.46616 .00306 L
.46713 .00306 L
.46807 .00306 L
.46907 .00306 L
.47003 .00306 L
.47095 .00306 L
.47194 .00306 L
.47289 .00306 L
.4738 .00306 L
.47477 .00306 L
.4757 .00306 L
.47669 .00306 L
.47765 .00306 L
.47857 .00306 L
.47954 .00306 L
.48048 .00306 L
.48149 .00306 L
.48245 .00306 L
.48338 .00306 L
.48436 .00306 L
.48531 .00306 L
.48623 .00306 L
.4872 .00306 L
.48814 .00306 L
.48913 .00306 L
.49009 .00306 L
.49101 .00306 L
.492 .00306 L
.49294 .00306 L
.49385 .00306 L
.49482 .00306 L
.49575 .00306 L
.49674 .00306 L
.49723 .00306 L
.49747 .00306 L
.49769 .00306 L
.4978 .00306 L
.49792 .00306 L
.49797 .00306 L
.49803 .00306 L
.49806 .00306 L
.49808 .00306 L
.49811 .15604 L
.49813 .15604 L
.49861 .15604 L
.4996 .15604 L
Mistroke
.50056 .15604 L
.501 .15604 L
.50124 .15604 L
.50148 .15604 L
.50171 .15604 L
.50177 .15604 L
.50184 .15604 L
.50186 .15604 L
.50189 .15604 L
.50191 .00306 L
.50192 .00306 L
.50195 .00306 L
.50246 .00306 L
.50342 .00306 L
.50434 .00306 L
.50532 .00306 L
.50627 .00306 L
.50718 .00306 L
.50815 .00306 L
.50908 .00306 L
.51007 .00306 L
.51103 .00306 L
.51195 .00306 L
.51292 .00306 L
.51386 .00306 L
.51486 .00306 L
.51583 .00306 L
.51675 .00306 L
.51774 .00306 L
.51869 .00306 L
.5196 .00306 L
.52057 .00306 L
.52151 .00306 L
.5225 .00306 L
.52346 .00306 L
.52438 .00306 L
.52537 .00306 L
.52631 .00306 L
.52722 .00306 L
.52818 .00306 L
.52911 .00306 L
.5301 .00306 L
.53106 .00306 L
.53197 .00306 L
.53295 .00306 L
.53389 .00306 L
.53488 .00306 L
.53585 .00306 L
.53677 .00306 L
.53775 .00306 L
Mistroke
.5387 .00306 L
.53961 .00306 L
.54058 .00306 L
.54152 .00306 L
.54251 .00306 L
.54347 .00306 L
.54438 .00306 L
.54536 .00306 L
.54631 .00306 L
.54721 .00306 L
.54818 .00306 L
.5491 .00306 L
.55009 .00306 L
.55104 .00306 L
.55196 .00306 L
.55293 .00306 L
.55387 .00306 L
.55486 .00306 L
.55582 .00306 L
.55674 .00306 L
.55773 .00306 L
.55867 .00306 L
.55958 .00306 L
.56055 .00306 L
.56148 .00306 L
.56247 .00306 L
.56342 .00306 L
.56434 .00306 L
.56532 .00306 L
.56626 .00306 L
.56726 .00306 L
.56822 .00306 L
.56915 .00306 L
.57013 .00306 L
.57108 .00306 L
.57199 .00306 L
.57296 .00306 L
.5739 .00306 L
.57489 .00306 L
.57585 .00306 L
.57677 .00306 L
.57775 .00306 L
.57869 .00306 L
.5796 .00306 L
.58057 .00306 L
.5815 .00306 L
.58249 .00306 L
.58344 .00306 L
.58435 .00306 L
.58533 .00306 L
Mistroke
.58627 .00306 L
.58726 .00306 L
.58822 .00306 L
.58915 .00306 L
.59013 .00306 L
.59108 .00306 L
.59199 .00306 L
.59249 .00306 L
.59296 .00306 L
.59319 .00306 L
.59325 .00306 L
.59328 .00306 L
.5933 .00306 L
.59331 .00306 L
.59335 .15604 L
.59336 .15604 L
.59338 .15604 L
.59343 .15604 L
.59389 .15604 L
.5948 .15604 L
.59578 .15604 L
.59622 .15604 L
.59671 .15604 L
.59684 .15604 L
.59698 .15604 L
.59703 .15604 L
.59709 .15604 L
.59711 .15604 L
.59713 .15604 L
.59716 .00306 L
.59719 .00306 L
.59722 .00306 L
.59771 .00306 L
.59868 .00306 L
.59962 .00306 L
.60062 .00306 L
.60158 .00306 L
.60251 .00306 L
.60349 .00306 L
.60444 .00306 L
.60535 .00306 L
.60632 .00306 L
.60726 .00306 L
.60825 .00306 L
.6092 .00306 L
.61012 .00306 L
.6111 .00306 L
.61205 .00306 L
.61295 .00306 L
.61392 .00306 L
Mistroke
.61485 .00306 L
.61583 .00306 L
.61679 .00306 L
.6177 .00306 L
.61867 .00306 L
.61961 .00306 L
.62061 .00306 L
.62157 .00306 L
.62249 .00306 L
.62347 .00306 L
.62442 .00306 L
.62533 .00306 L
.6263 .00306 L
.62723 .00306 L
.62822 .00306 L
.62917 .00306 L
.63009 .00306 L
.63107 .00306 L
.63201 .00306 L
.63301 .00306 L
.63397 .00306 L
.6349 .00306 L
.63588 .00306 L
.63683 .00306 L
.63775 .00306 L
.63872 .00306 L
.63965 .00306 L
.64065 .00306 L
.64161 .00306 L
.64253 .00306 L
.64351 .00306 L
.64445 .00306 L
.64536 .00306 L
.64633 .00306 L
.64726 .00306 L
.64824 .00306 L
.6492 .00306 L
.65011 .00306 L
.65109 .00306 L
.65203 .00306 L
.65302 .00306 L
.65398 .00306 L
.65491 .00306 L
.65589 .00306 L
.65684 .00306 L
.65775 .00306 L
.65872 .00306 L
.65965 .00306 L
.66065 .00306 L
.6616 .00306 L
Mistroke
.66252 .00306 L
.6635 .00306 L
.66444 .00306 L
.66544 .00306 L
.66641 .00306 L
.66733 .00306 L
.66832 .00306 L
.66927 .00306 L
.67019 .00306 L
.67116 .00306 L
.6721 .00306 L
.67309 .00306 L
.67405 .00306 L
.67497 .00306 L
.67595 .00306 L
.6769 .00306 L
.67781 .00306 L
.67878 .00306 L
.67971 .00306 L
.6807 .00306 L
.68165 .00306 L
.68257 .00306 L
.68354 .00306 L
.68448 .00306 L
.68548 .00306 L
.68645 .00306 L
.68737 .00306 L
.68784 .00306 L
.68809 .00306 L
.68823 .00306 L
.68836 .00306 L
.68848 .00306 L
.68851 .00306 L
.68853 .00306 L
.68855 .00306 L
.68858 .30902 L
.68859 .30902 L
.68861 .30902 L
.68885 .30902 L
.6893 .30902 L
.69029 .30902 L
.69124 .30902 L
.69172 .30902 L
.69193 .30902 L
.69216 .30902 L
.69222 .30902 L
.69229 .30902 L
.69234 .30902 L
.69237 .30902 L
.6924 .00306 L
Mistroke
.69243 .00306 L
.69246 .00306 L
.69251 .00306 L
.69263 .00306 L
.69313 .00306 L
.69405 .00306 L
.69503 .00306 L
.69597 .00306 L
.69697 .00306 L
.69793 .00306 L
.69886 .00306 L
.69985 .00306 L
.7008 .00306 L
.70171 .00306 L
.70268 .00306 L
.70362 .00306 L
.70461 .00306 L
.70557 .00306 L
.70649 .00306 L
.70747 .00306 L
.70842 .00306 L
.70933 .00306 L
.71029 .00306 L
.71122 .00306 L
.71221 .00306 L
.71317 .00306 L
.71408 .00306 L
.71506 .00306 L
.716 .00306 L
.717 .00306 L
.71796 .00306 L
.71888 .00306 L
.71987 .00306 L
.72081 .00306 L
.72172 .00306 L
.72269 .00306 L
.72363 .00306 L
.72462 .00306 L
.72558 .00306 L
.7265 .00306 L
.72748 .00306 L
.72842 .00306 L
.72932 .00306 L
.73029 .00306 L
.73122 .00306 L
.73221 .00306 L
.73316 .00306 L
.73407 .00306 L
.73504 .00306 L
.73598 .00306 L
Mistroke
.73698 .00306 L
.73794 .00306 L
.73886 .00306 L
.73984 .00306 L
.74079 .00306 L
.7417 .00306 L
.74266 .00306 L
.7436 .00306 L
.74459 .00306 L
.74554 .00306 L
.74646 .00306 L
.74744 .00306 L
.74838 .00306 L
.74938 .00306 L
.75034 .00306 L
.75126 .00306 L
.75225 .00306 L
.7532 .00306 L
.75411 .00306 L
.75508 .00306 L
.75602 .00306 L
.75701 .00306 L
.75797 .00306 L
.75889 .00306 L
.75987 .00306 L
.76081 .00306 L
.76172 .00306 L
.76269 .00306 L
.76362 .00306 L
.76461 .00306 L
.76556 .00306 L
.76647 .00306 L
.76745 .00306 L
.76839 .00306 L
.76938 .00306 L
.77034 .00306 L
.77127 .00306 L
.77225 .00306 L
.7732 .00306 L
.77411 .00306 L
.77508 .00306 L
.77601 .00306 L
.777 .00306 L
.77796 .00306 L
.77888 .00306 L
.77986 .00306 L
.7808 .00306 L
.7818 .00306 L
.78276 .00306 L
.78369 .00306 L
Mistroke
.78468 .00306 L
.78563 .00306 L
.78654 .00306 L
.78751 .00306 L
.78845 .00306 L
.78944 .00306 L
.7904 .00306 L
.79133 .00306 L
.79231 .00306 L
.79325 .00306 L
.79416 .00306 L
.79513 .00306 L
.79606 .00306 L
.79705 .00306 L
.798 .00306 L
.79892 .00306 L
.79989 .00306 L
.80083 .00306 L
.80183 .00306 L
.80279 .00306 L
.80372 .00306 L
.8047 .00306 L
.80565 .00306 L
.80656 .00306 L
.80753 .00306 L
.80847 .00306 L
.80946 .00306 L
.81042 .00306 L
.81134 .00306 L
.81232 .00306 L
.81326 .00306 L
.81417 .00306 L
.81513 .00306 L
.81606 .00306 L
.81705 .00306 L
.818 .00306 L
.81892 .00306 L
.81989 .00306 L
.82083 .00306 L
.82182 .00306 L
.82278 .00306 L
.82371 .00306 L
.82469 .00306 L
.82564 .00306 L
.82655 .00306 L
.82751 .00306 L
.82845 .00306 L
.82944 .00306 L
.83039 .00306 L
.83131 .00306 L
Mistroke
.83229 .00306 L
.83323 .00306 L
.83423 .00306 L
.83519 .00306 L
.83612 .00306 L
.8371 .00306 L
.83805 .00306 L
.83897 .00306 L
.83994 .00306 L
.84087 .00306 L
.84187 .00306 L
.84283 .00306 L
.84375 .00306 L
.84473 .00306 L
.84567 .00306 L
.84658 .00306 L
.84755 .00306 L
.84848 .00306 L
.84947 .00306 L
.85042 .00306 L
.85133 .00306 L
.85231 .00306 L
.85325 .00306 L
.85425 .00306 L
.85521 .00306 L
.85613 .00306 L
.85712 .00306 L
.85806 .00306 L
.85897 .00306 L
.85994 .00306 L
.86088 .00306 L
.86187 .00306 L
.86283 .00306 L
.86375 .00306 L
.86472 .00306 L
.86567 .00306 L
.86667 .00306 L
.86763 .00306 L
.86856 .00306 L
.86955 .00306 L
.8705 .00306 L
.87141 .00306 L
.87238 .00306 L
.87332 .00306 L
.87432 .00306 L
.87528 .00306 L
.8762 .00306 L
.87718 .00306 L
.87813 .00306 L
.87904 .00306 L
Mistroke
.88 .00306 L
.88093 .00306 L
.88192 .00306 L
.88288 .00306 L
.8838 .00306 L
.88477 .00306 L
.88571 .00306 L
.88671 .00306 L
.88767 .00306 L
.8886 .00306 L
.88959 .00306 L
.89053 .00306 L
.89145 .00306 L
.89242 .00306 L
.89335 .00306 L
.89435 .00306 L
.8953 .00306 L
.89622 .00306 L
.8972 .00306 L
.89815 .00306 L
.89905 .00306 L
.90002 .00306 L
.90095 .00306 L
.90194 .00306 L
.90289 .00306 L
.9038 .00306 L
.90478 .00306 L
.90572 .00306 L
.90671 .00306 L
.90767 .00306 L
.9086 .00306 L
.90958 .00306 L
.91053 .00306 L
.91144 .00306 L
.91241 .00306 L
.91334 .00306 L
.91433 .00306 L
.91529 .00306 L
.91621 .00306 L
.91718 .00306 L
.91812 .00306 L
.91912 .00306 L
.92009 .00306 L
.92102 .00306 L
.922 .00306 L
.92295 .00306 L
.92386 .00306 L
.92484 .00306 L
.92577 .00306 L
.92677 .00306 L
Mistroke
.92773 .00306 L
.92865 .00306 L
.92963 .00306 L
.93057 .00306 L
.93148 .00306 L
.93245 .00306 L
.93338 .00306 L
.93437 .00306 L
.93532 .00306 L
.93624 .00306 L
.93721 .00306 L
.93815 .00306 L
.93915 .00306 L
.94011 .00306 L
.94104 .00306 L
.94202 .00306 L
.94297 .00306 L
.94388 .00306 L
.94485 .00306 L
.94579 .00306 L
.94678 .00306 L
.94774 .00306 L
.94866 .00306 L
.94964 .00306 L
.95058 .00306 L
.95148 .00306 L
.95245 .00306 L
.95338 .00306 L
.95437 .00306 L
.95532 .00306 L
.95623 .00306 L
.9572 .00306 L
.95814 .00306 L
.95914 .00306 L
.9601 .00306 L
.96102 .00306 L
.962 .00306 L
.96295 .00306 L
.96386 .00306 L
.96483 .00306 L
.96576 .00306 L
.96675 .00306 L
.9677 .00306 L
.96862 .00306 L
.9696 .00306 L
.97054 .00306 L
.97154 .00306 L
.9725 .00306 L
.97343 .00306 L
.97441 .00306 L
Mistroke
.97536 .00306 L
.97619 .00306 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<_ooool3o`0002gooooo1Ol0000/ooooo`;o0000;Oooool5o`0002oooooo0ol0000Woooo
o`00<oooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`0002_ooooo00Co0000oooo
oooooooo0000;Oooool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo02Kooooo000Z
ooooo`Go000000?oooooo`000?l000000ol0000Wooooo`Go00000oooool00ol0003oooooooooo`0[
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool0;Oooool5o`0002Oooooo000`
ooooo`04o`000?ooooooooooo`00037ooooo00?o0000ooooooooool0:_ooool01?l0003ooooooooo
ool0000_ooooo`03o`000?oooooooooo02cooooo00Co0000oooooooooooo0000:?ooool0037ooooo
00?o0000ooooool00000;_ooool01Ol0003ooooooooooooooooo000002_ooooo00Co0000oooooooo
oooo0000;?ooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooool00000:?ooool0
03;ooooo0_l0000^ooooo`05o`000?ooooooooooooooool00000:oooool01?l0003oooooooooool0
000/ooooo`05o`000?ooooooooooooooool00000;oooool2o`0002Sooooo000cooooo`03o`000?oo
oooooooo02gooooo0ol0000]ooooo`;o0000;_ooool3o`00037ooooo00?o0000ooooooooool09_oo
ool00?oooooo8Oooool00?oooooo8Oooool000[ooooo0_l0003ooooooaGooooo0009ooooo`04o`00
0?ooooooooooo`000?oooooo5?ooool000Wooooo00Co0000oooooooooooo00001?ooooooo`0000Oo
00002Oooool000Wooooo00Co0000oooooooooooo00001?ooool3o`0000CooooonOl00?l3ooooo`?o
00002Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1=ooooo`;o
003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00odoooooo00?o0000oooooooo
ool01oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1=ooooo`;o
003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00odoooooo00?o0000oooooooo
ool01oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo04gooooo0_l00?lGooooo`;o003o
5oooool2o`00oaOooooo0_l00?lGooooo`;o003oCoooool00ol0003oooooooooo`07ooooo`004Ooo
ool00ol0003oooooooooo`1=ooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003o5ooo
ool2o`00odoooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0COooool2
o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00oaOooooo0_l00?m?ooooo`03o`000?oooooo
oooo00Oooooo000Aooooo`03o`000?oooooooooo04gooooo0_l00?lGooooo`;o003o5oooool2o`00
oaOooooo0_l00?lGooooo`;o003oCoooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003o
ooooooooo`1=ooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00odoo
oooo00?o0000ooooooooool01oooool0017ooooo0_l0001>ooooo`;o003o5oooool2o`00oaOooooo
0_l00?lGooooo`;o003o5oooool2o`00odkooooo0_l00009ooooo`004Oooool00ol0003ooooooooo
o`1=ooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00odoooooo00?o
0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0COooool2o`00oaOooooo0_l00?lG
ooooo`;o003o5oooool2o`00oaOooooo0_l00?m?ooooo`03o`000?oooooooooo00Oooooo000Aoooo
o`03o`000?oooooooooo04gooooo0_l00?lGooooo`;o003o5oooool2o`00oaOooooo0_l00?lGoooo
o`;o003oCoooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003oooooooooo`1=ooooo`;o
003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00odoooooo00?o0000oooooooo
ool01oooool0017ooooo00?o0000ooooooooool0COooool2o`00oaOooooo0_l00?lGooooo`;o003o
5oooool2o`00oaOooooo0_l00?m?ooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oo
oooooooo04gooooo0_l00?lGooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003oCooo
ool00ol0003oooooooooo`07ooooo`004Oooool00ol0003oooooooooo`1=ooooo`;o003o5oooool2
o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00odoooooo00?o0000ooooooooool01oooool0
017ooooo0_l0001>ooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00
odkooooo0_l00009ooooo`004Oooool00ol0003oooooooooo`1=ooooo`;o003o5oooool2o`00oaOo
oooo0_l00?lGooooo`;o003o5oooool2o`00odoooooo00?o0000ooooooooool01oooool0017ooooo
00?o0000ooooooooool0COooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00oaOooooo
0_l00?m?ooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo04gooooo0_l0
0?lGooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003oCoooool00ol0003ooooooooo
o`07ooooo`004Oooool00ol0003oooooooooo`1=ooooo`;o003o5oooool2o`00oaOooooo0_l00?lG
ooooo`;o003o5oooool2o`00odoooooo00?o0000ooooooooool01oooool0017ooooo00?o0000oooo
ooooool0COooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00oaOooooo0_l00?m?oooo
o`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo04gooooo0_l00?lGooooo`;o
003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003oCoooool00ol0003oooooooooo`07ooooo`00
4Oooool00ol0003oooooooooo`1=ooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003o
5oooool2o`00odoooooo00?o0000ooooooooool01oooool0017ooooo0_l0001>ooooo`;o003o5ooo
ool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00odkooooo0_l00009ooooo`004Oooool0
0ol0003oooooooooo`1=ooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2
o`00odoooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0COooool2o`00
oaOooooo0_l00?lGooooo`;o003o5oooool2o`00oaOooooo0_l00?m?ooooo`03o`000?oooooooooo
00Oooooo000Aooooo`03o`000?oooooooooo04gooooo0_l00?lGooooo`;o003o5oooool2o`00oaOo
oooo0_l00?lGooooo`;o003oCoooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003ooooo
ooooo`1=ooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00odoooooo
00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0COooool2o`00oaOooooo0_l0
0?lGooooo`;o003o5oooool2o`00oaOooooo0_l00?m?ooooo`03o`000?oooooooooo00Oooooo000A
ooooo`03o`000?oooooooooo04gooooo0_l00?lGooooo`;o003o5oooool2o`00oaOooooo0_l00?lG
ooooo`;o003oCoooool00ol0003oooooooooo`07ooooo`004Oooool2o`0004kooooo0_l00?lGoooo
o`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003oC_ooool2o`0000Wooooo000Aooooo`03
o`000?oooooooooo04gooooo0_l00?lGooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`;o
003oCoooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003oooooooooo`1=ooooo`;o003o
5oooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00odoooooo00?o0000ooooooooool0
1oooool0017ooooo00?o0000ooooooooool0COooool2o`00oaOooooo0_l00?lGooooo`;o003o5ooo
ool2o`00oaOooooo0_l00?m?ooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooo
oooo04gooooo0_l00?lGooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003oCoooool0
0ol0003oooooooooo`07ooooo`004Oooool00ol0003oooooooooo`1=ooooo`;o003o5oooool2o`00
oaOooooo0_l00?lGooooo`;o003o5oooool2o`00odoooooo00?o0000ooooooooool01oooool000Wo
oooo0ol00005ooooo`03o`000?oooooooooo04gooooo0_l00?lGooooo`;o003o5oooool2o`00oaOo
oooo0_l00?lGooooo`;o003oCoooool00ol0003oooooooooo`07ooooo`002_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo04gooooo0_l00?lGooooo`;o003o5oooool2o`00oaOooooo
0_l00?lGooooo`;o003oCoooool00ol0003oooooooooo`07ooooo`002_ooool00ol0003ooooooooo
o`04ooooo`?o0000COooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00oaOooooo0_l0
0?m=ooooo`?o00002Oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1=
ooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool2o`00odoooooo00?o0000
ooooooooool01oooool000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1=oooo
o`;o003o<Oooool00ol0003oooooooooo`0^ooooo`;o003oCoooool00ol0003oooooooooo`07oooo
o`002Oooool2o`0000Kooooo00?o0000ooooooooool0COooool2o`00oc7ooooo00?o0000oooooooo
ool0;_ooool2o`00odoooooo00?o0000ooooooooool01oooool000[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1=ooooo`;o003o<Oooool00ol0003oooooooooo`0^ooooo`;o003o
Coooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003oooooooooo`1=ooooo`;o003o<Ooo
ool00ol0003oooooooooo`0^ooooo`;o003oCoooool00ol0003oooooooooo`07ooooo`004Oooool0
0ol0003oooooooooo`1=ooooo`;o003o<Oooool00ol0003oooooooooo`0^ooooo`;o003oCoooool0
0ol0003oooooooooo`07ooooo`004Oooool00ol0003oooooooooo`1=ooooo`;o003o<Oooool00ol0
003oooooooooo`0^ooooo`;o003oCoooool00ol0003oooooooooo`07ooooo`004Oooool2o`0004ko
oooo0_l00?laooooo`03o`000?oooooooooo02kooooo0_l00?m>ooooo`;o00002Oooool0017ooooo
00?o0000ooooooooool0COooool2o`00oc7ooooo00?o0000ooooooooool0;_ooool2o`00odoooooo
00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0COooool2o`00oc7ooooo00?o
0000ooooooooool0;_ooool2o`00odoooooo00?o0000ooooooooool01oooool0017ooooo00?o0000
ooooooooool0COooool2o`00oc7ooooo00?o0000ooooooooool0;_ooool2o`00odoooooo00?o0000
ooooooooool01oooool0017ooooo00?o0000ooooooooool0COooool2o`00oc7ooooo00?o0000oooo
ooooool0;_ooool2o`00odoooooo00?o0000ooooooooool01oooool0017ooooo00?o0000oooooooo
ool0COooool2o`00oc7ooooo00?o0000ooooooooool0;_ooool2o`00odoooooo00?o0000oooooooo
ool01oooool0017ooooo00?o0000ooooooooool0COooool2o`00oc7ooooo00?o0000ooooooooool0
;_ooool2o`00odoooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0COoo
ool2o`00oc7ooooo00?o0000ooooooooool0;_ooool2o`00odoooooo00?o0000ooooooooool01ooo
ool0017ooooo0_l0001>ooooo`;o003o<Oooool00ol0003oooooooooo`0^ooooo`;o003oC_ooool2
o`0000Wooooo000Aooooo`03o`000?oooooooooo04gooooo0_l00?laooooo`03o`000?oooooooooo
02kooooo0_l00?m?ooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo04go
oooo0_l00?laooooo`03o`000?oooooooooo02kooooo0_l00?m?ooooo`03o`000?oooooooooo00Oo
oooo000Aooooo`03o`000?oooooooooo04gooooo0_l00?laooooo`03o`000?oooooooooo02kooooo
0_l00?m?ooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo04gooooo0_l0
0?laooooo`03o`000?oooooooooo02kooooo0_l00?m?ooooo`03o`000?oooooooooo00Oooooo000A
ooooo`03o`000?oooooooooo04gooooo0_l00?laooooo`03o`000?oooooooooo02kooooo0_l00?m?
ooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo04gooooo0_l00?laoooo
o`03o`000?oooooooooo02kooooo0_l00?m?ooooo`03o`000?oooooooooo00Oooooo000Aooooo`03
o`000?oooooooooo04gooooo0_l00?laooooo`03o`000?oooooooooo02kooooo0_l00?m?ooooo`03
o`000?oooooooooo00Oooooo000Aooooo`;o0000C_ooool2o`00oc7ooooo00?o0000ooooooooool0
;_ooool2o`00odkooooo0_l00009ooooo`004Oooool00ol0003oooooooooo`1=ooooo`;o003o<Ooo
ool00ol0003oooooooooo`0^ooooo`;o003oCoooool00ol0003oooooooooo`07ooooo`004Oooool0
0ol0003oooooooooo`1=ooooo`;o003o<Oooool00ol0003oooooooooo`0^ooooo`;o003oCoooool0
0ol0003oooooooooo`07ooooo`004Oooool00ol0003oooooooooo`1=ooooo`;o003o<Oooool00ol0
003oooooooooo`0^ooooo`;o003oCoooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003o
ooooooooo`1=ooooo`;o003o<Oooool00ol0003oooooooooo`0^ooooo`;o003oCoooool00ol0003o
ooooooooo`07ooooo`004Oooool00ol0003oooooooooo`1=ooooo`;o003o<Oooool00ol0003ooooo
ooooo`0^ooooo`;o003oCoooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003ooooooooo
o`1=ooooo`;o003o<Oooool00ol0003oooooooooo`0^ooooo`;o003oCoooool00ol0003ooooooooo
o`07ooooo`004Oooool00ol0003oooooooooo`1=ooooo`;o003o<Oooool00ol0003oooooooooo`0^
ooooo`;o003oCoooool00ol0003oooooooooo`07ooooo`004Oooool2o`0004kooooo0_l00?laoooo
o`03o`000?oooooooooo02kooooo0_l00?m>ooooo`;o00002Oooool0017ooooo00?o0000oooooooo
ool0COooool2o`00oc7ooooo00?o0000ooooooooool0;_ooool2o`00odoooooo00?o0000oooooooo
ool01oooool0017ooooo00?o0000ooooooooool0COooool2o`00oc7ooooo00?o0000ooooooooool0
;_ooool2o`00odoooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0COoo
ool2o`00oc7ooooo00?o0000ooooooooool0;_ooool2o`00odoooooo00?o0000ooooooooool01ooo
ool0017ooooo00?o0000ooooooooool0COooool2o`00oc7ooooo00?o0000ooooooooool0;_ooool2
o`00odoooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0COooool2o`00
oc7ooooo00?o0000ooooooooool0;_ooool2o`00odoooooo00?o0000ooooooooool01oooool000So
oooo1Ol00004ooooo`03o`000?oooooooooo04gooooo0_l00?laooooo`03o`000?oooooooooo02ko
oooo0_l00?m?ooooo`03o`000?oooooooooo00Oooooo0009ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0COooool2o`00oc7ooooo00?o0000ooooooooool0;_ooool2o`00odoo
oooo00?o0000ooooooooool01oooool000[ooooo00?o0000ooooooooool01?ooool3o`0004gooooo
0_l00?laooooo`03o`000?oooooooooo02kooooo0_l00?m=ooooo`?o00002Oooool000_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool01oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo083ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`07ooooo`002?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0P?ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo00Oooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`20
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool0017ooooo00?o0000oooo
ooooool0P?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oooooo000Aooooo`03
o`000?oooooooooo083ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`07ooooo`00
4Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
1oooool0017ooooo0_l00021ooooo`03o`000?oooooooooo07kooooo0_l00009ooooo`004Oooool0
0ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool0
017ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
00Oooooo000Aooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`07ooooo`004Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0P?ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo083ooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003oooooooooo`20oooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool0017ooooo0_l00021ooooo`03
o`000?oooooooooo07kooooo0_l00009ooooo`004Oooool00ol0003oooooooooo`20ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0P?oo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooo
oooo083ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`07ooooo`004Oooool00ol0
003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool0017o
oooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oo
oooo000Aooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`07ooooo`004Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool01oooool0017ooooo0_l00021ooooo`03o`000?oooooooooo07kooooo0_l00009
ooooo`004Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool01oooool0017ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003oooooooooo`20ooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0P?ooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003o
ooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool0017ooooo
0_l00021ooooo`03o`000?oooooooooo07kooooo0_l00009ooooo`004Oooool00ol0003ooooooooo
o`20ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool0017ooooo00?o0000
ooooooooool0P?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oooooo000Aoooo
o`03o`000?oooooooooo083ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`07oooo
o`004Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool01oooool0017ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo00Oooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`20ooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool01oooool000Sooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`07ooooo`003?ooool00ol0003oooooooooo`02ooooo`?o0000P?ooool00ol0003oooooooooo`1m
ooooo`?o00002Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo083ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`07ooooo`00
2?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0P?ooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo00Oooooo0009ooooo`?o00001Oooool00ol0003ooooo
ooooo`20ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool0017ooooo00?o
0000ooooooooool0P?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oooooo000A
ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`07
ooooo`004Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool01oooool0017ooooo0_l00021ooooo`03o`000?oooooooooo07kooooo0_l00009ooooo`00
4Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
1oooool0017ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo00Oooooo000Aooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`07ooooo`004Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0P?ooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003ooooooooo
o`20ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool0017ooooo0_l00021
ooooo`03o`000?oooooooooo07kooooo0_l00009ooooo`004Oooool00ol0003oooooooooo`20oooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool0017ooooo00?o0000oooooooo
ool0P?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`00
0?oooooooooo083ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`07ooooo`004Ooo
ool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01ooo
ool0017ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo00Oooooo000Aooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`07ooooo`004Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool01oooool0017ooooo0_l00021ooooo`03o`000?oooooooooo07kooooo
0_l00009ooooo`004Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`07ooooo`004Oooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool0017ooooo00?o0000ooooooooool0
P?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oooooo000Aooooo`03o`000?oo
oooooooo083ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`07ooooo`004Oooool0
0ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool0
017ooooo0_l00021ooooo`03o`000?oooooooooo07kooooo0_l00009ooooo`004Oooool00ol0003o
ooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool0017ooooo
00?o0000ooooooooool0P?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oooooo
000Aooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`07ooooo`004Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool01oooool000[ooooo0ol00004ooooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`07ooooo`002oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo083ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`07ooooo`00
2?ooool5o`0000Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool01oooool000Sooooo00Co0000oooooooooooo0000
1Oooool3o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`04o`00
0?ooooooooooooooo`?o00002Oooool000Wooooo00?o0000ooooool000001Oooooooo`0000Oo0000
2Oooool000[ooooo0_l0003ooooooaGooooo000;ooooo`03o`000?oooooooooo0?oooooo4oooool0
0?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.96882, -0.3276, 0.040312, \
0.0250965}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Frequency spectrum of sampled signal", "Subsubsection"],

Cell[BoxData[
    \(\(Xs[f_, fs_, n_:  5] := SampledSpectrum[X, f, fs, n];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gXs = 
        Plot[Evaluate[PlotConvert[Xs[f, fs, 10],  .05]], {f, \(-25\), 25}, 
          PlotStyle \[Rule] {Red}, \ PlotPoints \[Rule] 1000, \ 
          PlotRange \[Rule] {\(- .02\), 2.12}, \ ImageSize \[Rule] 504, \ 
          AspectRatio \[Rule] 1/3];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0190476 0.00311526 0.155763 [
[.11905 -0.0125 -9 -9 ]
[.11905 -0.0125 9 0 ]
[.30952 -0.0125 -9 -9 ]
[.30952 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -6 -9 ]
[.69048 -0.0125 6 0 ]
[.88095 -0.0125 -6 -9 ]
[.88095 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00312 -6 -4.5 ]
[-0.0125 .00312 0 4.5 ]
[-0.0125 .081 -18 -4.5 ]
[-0.0125 .081 0 4.5 ]
[-0.0125 .15888 -6 -4.5 ]
[-0.0125 .15888 0 4.5 ]
[-0.0125 .23676 -18 -4.5 ]
[-0.0125 .23676 0 4.5 ]
[-0.0125 .31464 -6 -4.5 ]
[-0.0125 .31464 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-20)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-10)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(10)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(20)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.15714 0 m
.15714 .00375 L
s
.19524 0 m
.19524 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.27143 0 m
.27143 .00375 L
s
.34762 0 m
.34762 .00375 L
s
.38571 0 m
.38571 .00375 L
s
.42381 0 m
.42381 .00375 L
s
.4619 0 m
.4619 .00375 L
s
.5381 0 m
.5381 .00375 L
s
.57619 0 m
.57619 .00375 L
s
.61429 0 m
.61429 .00375 L
s
.65238 0 m
.65238 .00375 L
s
.72857 0 m
.72857 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.80476 0 m
.80476 .00375 L
s
.84286 0 m
.84286 .00375 L
s
.08095 0 m
.08095 .00375 L
s
.04286 0 m
.04286 .00375 L
s
.00476 0 m
.00476 .00375 L
s
.91905 0 m
.91905 .00375 L
s
.95714 0 m
.95714 .00375 L
s
.99524 0 m
.99524 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00312 m
.00625 .00312 L
s
[(0)] -0.0125 .00312 1 0 Mshowa
0 .081 m
.00625 .081 L
s
[(0.5)] -0.0125 .081 1 0 Mshowa
0 .15888 m
.00625 .15888 L
s
[(1)] -0.0125 .15888 1 0 Mshowa
0 .23676 m
.00625 .23676 L
s
[(1.5)] -0.0125 .23676 1 0 Mshowa
0 .31464 m
.00625 .31464 L
s
[(2)] -0.0125 .31464 1 0 Mshowa
.125 Mabswid
0 .01869 m
.00375 .01869 L
s
0 .03427 m
.00375 .03427 L
s
0 .04984 m
.00375 .04984 L
s
0 .06542 m
.00375 .06542 L
s
0 .09657 m
.00375 .09657 L
s
0 .11215 m
.00375 .11215 L
s
0 .12773 m
.00375 .12773 L
s
0 .1433 m
.00375 .1433 L
s
0 .17445 m
.00375 .17445 L
s
0 .19003 m
.00375 .19003 L
s
0 .20561 m
.00375 .20561 L
s
0 .22118 m
.00375 .22118 L
s
0 .25234 m
.00375 .25234 L
s
0 .26791 m
.00375 .26791 L
s
0 .28349 m
.00375 .28349 L
s
0 .29907 m
.00375 .29907 L
s
0 .33022 m
.00375 .33022 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.11905 .32708 m
.11905 .33333 L
s
.30952 .32708 m
.30952 .33333 L
s
.5 .32708 m
.5 .33333 L
s
.69048 .32708 m
.69048 .33333 L
s
.88095 .32708 m
.88095 .33333 L
s
.125 Mabswid
.15714 .32958 m
.15714 .33333 L
s
.19524 .32958 m
.19524 .33333 L
s
.23333 .32958 m
.23333 .33333 L
s
.27143 .32958 m
.27143 .33333 L
s
.34762 .32958 m
.34762 .33333 L
s
.38571 .32958 m
.38571 .33333 L
s
.42381 .32958 m
.42381 .33333 L
s
.4619 .32958 m
.4619 .33333 L
s
.5381 .32958 m
.5381 .33333 L
s
.57619 .32958 m
.57619 .33333 L
s
.61429 .32958 m
.61429 .33333 L
s
.65238 .32958 m
.65238 .33333 L
s
.72857 .32958 m
.72857 .33333 L
s
.76667 .32958 m
.76667 .33333 L
s
.80476 .32958 m
.80476 .33333 L
s
.84286 .32958 m
.84286 .33333 L
s
.08095 .32958 m
.08095 .33333 L
s
.04286 .32958 m
.04286 .33333 L
s
.00476 .32958 m
.00476 .33333 L
s
.91905 .32958 m
.91905 .33333 L
s
.95714 .32958 m
.95714 .33333 L
s
.99524 .32958 m
.99524 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00312 m
1 .00312 L
s
.99375 .081 m
1 .081 L
s
.99375 .15888 m
1 .15888 L
s
.99375 .23676 m
1 .23676 L
s
.99375 .31464 m
1 .31464 L
s
.125 Mabswid
.99625 .01869 m
1 .01869 L
s
.99625 .03427 m
1 .03427 L
s
.99625 .04984 m
1 .04984 L
s
.99625 .06542 m
1 .06542 L
s
.99625 .09657 m
1 .09657 L
s
.99625 .11215 m
1 .11215 L
s
.99625 .12773 m
1 .12773 L
s
.99625 .1433 m
1 .1433 L
s
.99625 .17445 m
1 .17445 L
s
.99625 .19003 m
1 .19003 L
s
.99625 .20561 m
1 .20561 L
s
.99625 .22118 m
1 .22118 L
s
.99625 .25234 m
1 .25234 L
s
.99625 .26791 m
1 .26791 L
s
.99625 .28349 m
1 .28349 L
s
.99625 .29907 m
1 .29907 L
s
.99625 .33022 m
1 .33022 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
.5 0 m
.5 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .00312 m
.02474 .00312 L
.02575 .00312 L
.0267 .00312 L
.02761 .00312 L
.02859 .00312 L
.02952 .00312 L
.03052 .00312 L
.03148 .00312 L
.0324 .00312 L
.03338 .00312 L
.03433 .00312 L
.03524 .00312 L
.03621 .00312 L
.03714 .00312 L
.03813 .00312 L
.03908 .00312 L
.04 .00312 L
.04098 .00312 L
.04192 .00312 L
.04292 .00312 L
.04388 .00312 L
.0448 .00312 L
.04579 .00312 L
.04674 .00312 L
.04765 .00312 L
.04862 .00312 L
.04956 .00312 L
.05055 .00312 L
.05151 .00312 L
.05243 .00312 L
.05341 .00312 L
.05435 .00312 L
.05526 .00312 L
.05622 .00312 L
.05715 .00312 L
.05814 .00312 L
.05909 .00312 L
.06001 .00312 L
.06098 .00312 L
.06192 .00312 L
.06292 .00312 L
.06388 .00312 L
.0648 .00312 L
.06579 .00312 L
.06673 .00312 L
.06764 .00312 L
.06861 .00312 L
.06954 .00312 L
.07054 .00312 L
Mistroke
.07149 .00312 L
.07241 .00312 L
.07339 .00312 L
.07433 .00312 L
.07533 .00312 L
.07629 .00312 L
.07722 .00312 L
.07821 .00312 L
.07916 .00312 L
.07964 .00312 L
.08007 .00312 L
.08019 .00312 L
.08031 .00312 L
.08037 .00312 L
.0804 .00312 L
.08043 .00312 L
.08046 .00312 L
.08048 .31464 L
.08051 .31464 L
.08054 .31464 L
.0808 .31464 L
.08104 .31464 L
.08126 .31464 L
.08133 .31464 L
.08136 .31464 L
.08139 .31464 L
.08141 .31464 L
.08144 .00312 L
.08147 .00312 L
.0815 .00312 L
.082 .00312 L
.08297 .00312 L
.0839 .00312 L
.08489 .00312 L
.08585 .00312 L
.08677 .00312 L
.08775 .00312 L
.08869 .00312 L
.0896 .00312 L
.09056 .00312 L
.09149 .00312 L
.09248 .00312 L
.09343 .00312 L
.09434 .00312 L
.09532 .00312 L
.09626 .00312 L
.09725 .00312 L
.09821 .00312 L
.09865 .00312 L
.0989 .00312 L
Mistroke
.09913 .00312 L
.09936 .00312 L
.09943 .00312 L
.09946 .00312 L
.09949 .00312 L
.09952 .00312 L
.09955 .15888 L
.09957 .15888 L
.09958 .15888 L
.09961 .15888 L
.09986 .15888 L
.10012 .15888 L
.10023 .15888 L
.10035 .15888 L
.10038 .15888 L
.10042 .15888 L
.10045 .15888 L
.10046 .15888 L
.10048 .00312 L
.10051 .00312 L
.10054 .00312 L
.1006 .00312 L
.10104 .00312 L
.10201 .00312 L
.10294 .00312 L
.10393 .00312 L
.10488 .00312 L
.1058 .00312 L
.10677 .00312 L
.10771 .00312 L
.10871 .00312 L
.10967 .00312 L
.11059 .00312 L
.11158 .00312 L
.11252 .00312 L
.11343 .00312 L
.1144 .00312 L
.11534 .00312 L
.11633 .00312 L
.11729 .00312 L
.11777 .00312 L
.1182 .00312 L
.11832 .00312 L
.11845 .00312 L
.11851 .00312 L
.11854 .00312 L
.11857 .00312 L
.11859 .15888 L
.11862 .15888 L
.11868 .15888 L
Mistroke
.11918 .15888 L
.1193 .15888 L
.11943 .15888 L
.11946 .15888 L
.11949 .15888 L
.11951 .15888 L
.11953 .00312 L
.11955 .00312 L
.11957 .00312 L
.11969 .00312 L
.12018 .00312 L
.1211 .00312 L
.12207 .00312 L
.12301 .00312 L
.12401 .00312 L
.12497 .00312 L
.1259 .00312 L
.12688 .00312 L
.12783 .00312 L
.12874 .00312 L
.12971 .00312 L
.13065 .00312 L
.13164 .00312 L
.1326 .00312 L
.13352 .00312 L
.1345 .00312 L
.13544 .00312 L
.13635 .00312 L
.13685 .00312 L
.13707 .00312 L
.13731 .00312 L
.13743 .00312 L
.13749 .00312 L
.13755 .00312 L
.13758 .00312 L
.1376 .00312 L
.13763 .15888 L
.13766 .15888 L
.13777 .15888 L
.138 .15888 L
.13824 .15888 L
.13837 .15888 L
.13843 .15888 L
.13849 .15888 L
.13854 .15888 L
.13857 .15888 L
.1386 .00312 L
.13863 .00312 L
.13866 .00312 L
.13871 .00312 L
Mistroke
.13915 .00312 L
.14014 .00312 L
.14109 .00312 L
.142 .00312 L
.14297 .00312 L
.14391 .00312 L
.1449 .00312 L
.14586 .00312 L
.14678 .00312 L
.14777 .00312 L
.14871 .00312 L
.14962 .00312 L
.15058 .00312 L
.15151 .00312 L
.1525 .00312 L
.15346 .00312 L
.15437 .00312 L
.15535 .00312 L
.1558 .00312 L
.15629 .00312 L
.15642 .00312 L
.15649 .00312 L
.15655 .00312 L
.15661 .00312 L
.15664 .00312 L
.15667 .31464 L
.1567 .31464 L
.15674 .31464 L
.1568 .31464 L
.15703 .31464 L
.15729 .31464 L
.1574 .31464 L
.15746 .31464 L
.15753 .31464 L
.15756 .31464 L
.15759 .31464 L
.1576 .31464 L
.15762 .00312 L
.15765 .00312 L
.15776 .00312 L
.15826 .00312 L
.15922 .00312 L
.16015 .00312 L
.16113 .00312 L
.16207 .00312 L
.16298 .00312 L
.16395 .00312 L
.16488 .00312 L
.16587 .00312 L
.16683 .00312 L
Mistroke
.16775 .00312 L
.16872 .00312 L
.16966 .00312 L
.17066 .00312 L
.17162 .00312 L
.17255 .00312 L
.17354 .00312 L
.17448 .00312 L
.1754 .00312 L
.17637 .00312 L
.1773 .00312 L
.1783 .00312 L
.17925 .00312 L
.18018 .00312 L
.18116 .00312 L
.1821 .00312 L
.18301 .00312 L
.18397 .00312 L
.1849 .00312 L
.18589 .00312 L
.18684 .00312 L
.18776 .00312 L
.18873 .00312 L
.18967 .00312 L
.19067 .00312 L
.19163 .00312 L
.19255 .00312 L
.19354 .00312 L
.19448 .00312 L
.19539 .00312 L
.19636 .00312 L
.1973 .00312 L
.19829 .00312 L
.19924 .00312 L
.20016 .00312 L
.20114 .00312 L
.20208 .00312 L
.20308 .00312 L
.20405 .00312 L
.20497 .00312 L
.20596 .00312 L
.20691 .00312 L
.20782 .00312 L
.2088 .00312 L
.20973 .00312 L
.21073 .00312 L
.21169 .00312 L
.21261 .00312 L
.21359 .00312 L
.21453 .00312 L
Mistroke
.21544 .00312 L
.21641 .00312 L
.21734 .00312 L
.21833 .00312 L
.21928 .00312 L
.2202 .00312 L
.22118 .00312 L
.22212 .00312 L
.22311 .00312 L
.22408 .00312 L
.225 .00312 L
.22599 .00312 L
.22693 .00312 L
.22785 .00312 L
.22882 .00312 L
.22975 .00312 L
.23074 .00312 L
.2317 .00312 L
.23262 .00312 L
.2336 .00312 L
.23454 .00312 L
.23545 .00312 L
.23641 .00312 L
.23734 .00312 L
.23833 .00312 L
.23928 .00312 L
.2402 .00312 L
.24117 .00312 L
.24211 .00312 L
.2431 .00312 L
.24406 .00312 L
.24499 .00312 L
.24597 .00312 L
.24692 .00312 L
.24783 .00312 L
.24879 .00312 L
.24973 .00312 L
.25072 .00312 L
.25167 .00312 L
.25259 .00312 L
.25357 .00312 L
.25451 .00312 L
.25551 .00312 L
.25647 .00312 L
.2574 .00312 L
.25838 .00312 L
.25933 .00312 L
.26025 .00312 L
.26122 .00312 L
.26215 .00312 L
Mistroke
.26315 .00312 L
.26411 .00312 L
.26503 .00312 L
.26601 .00312 L
.26695 .00312 L
.26786 .00312 L
.26883 .00312 L
.26976 .00312 L
.27023 .00312 L
.27048 .00312 L
.27062 .00312 L
.27074 .00312 L
.27087 .00312 L
.2709 .00312 L
.27092 .00312 L
.27094 .00312 L
.27097 .31464 L
.27099 .31464 L
.271 .31464 L
.27124 .31464 L
.27148 .31464 L
.2717 .31464 L
.27182 .31464 L
.27185 .31464 L
.27187 .31464 L
.27188 .31464 L
.27191 .00312 L
.27194 .00312 L
.27221 .00312 L
.27269 .00312 L
.27364 .00312 L
.27455 .00312 L
.27553 .00312 L
.27646 .00312 L
.27746 .00312 L
.27842 .00312 L
.27934 .00312 L
.28032 .00312 L
.28127 .00312 L
.28218 .00312 L
.28315 .00312 L
.28408 .00312 L
.28507 .00312 L
.28602 .00312 L
.28694 .00312 L
.28791 .00312 L
.28885 .00312 L
.28933 .00312 L
.28959 .00312 L
.28972 .00312 L
Mistroke
.28985 .00312 L
.28991 .00312 L
.28997 .00312 L
.29 .00312 L
.29002 .15888 L
.29003 .15888 L
.29009 .15888 L
.29035 .15888 L
.29059 .15888 L
.29071 .15888 L
.29082 .15888 L
.29087 .15888 L
.29092 .15888 L
.29095 .15888 L
.29097 .00312 L
.291 .00312 L
.29103 .00312 L
.29126 .00312 L
.29176 .00312 L
.29272 .00312 L
.29364 .00312 L
.29463 .00312 L
.29557 .00312 L
.29648 .00312 L
.29745 .00312 L
.29838 .00312 L
.29938 .00312 L
.30033 .00312 L
.30125 .00312 L
.30223 .00312 L
.30317 .00312 L
.30417 .00312 L
.30513 .00312 L
.30606 .00312 L
.30705 .00312 L
.308 .00312 L
.30847 .00312 L
.30868 .00312 L
.30891 .00312 L
.30897 .00312 L
.309 .00312 L
.30903 .00312 L
.30906 .15888 L
.30909 .15888 L
.30915 .15888 L
.30938 .15888 L
.30962 .15888 L
.30975 .15888 L
.30982 .15888 L
.30988 .15888 L
Mistroke
.30994 .15888 L
.30996 .15888 L
.30998 .15888 L
.31 .15888 L
.31001 .00312 L
.31004 .00312 L
.31007 .00312 L
.31013 .00312 L
.31036 .00312 L
.31087 .00312 L
.31186 .00312 L
.31282 .00312 L
.31374 .00312 L
.31472 .00312 L
.31566 .00312 L
.31657 .00312 L
.31753 .00312 L
.31846 .00312 L
.31945 .00312 L
.3204 .00312 L
.32131 .00312 L
.32229 .00312 L
.32322 .00312 L
.32422 .00312 L
.32518 .00312 L
.3261 .00312 L
.32709 .00312 L
.32757 .00312 L
.32781 .00312 L
.32793 .00312 L
.32803 .00312 L
.32806 .00312 L
.32808 .00312 L
.32811 .15888 L
.32814 .15888 L
.32826 .15888 L
.32847 .15888 L
.32869 .15888 L
.32882 .15888 L
.32888 .15888 L
.32894 .15888 L
.32897 .15888 L
.329 .15888 L
.32903 .15888 L
.32905 .00312 L
.32908 .00312 L
.32911 .00312 L
.32918 .00312 L
.32942 .00312 L
.32987 .00312 L
Mistroke
.33083 .00312 L
.33176 .00312 L
.33275 .00312 L
.3337 .00312 L
.33462 .00312 L
.33559 .00312 L
.33653 .00312 L
.33753 .00312 L
.33849 .00312 L
.33942 .00312 L
.3404 .00312 L
.34135 .00312 L
.34226 .00312 L
.34323 .00312 L
.34416 .00312 L
.34515 .00312 L
.34611 .00312 L
.34659 .00312 L
.3468 .00312 L
.34691 .00312 L
.34703 .00312 L
.34709 .00312 L
.3471 .00312 L
.34712 .00312 L
.34714 .00312 L
.34715 .31464 L
.34718 .31464 L
.34721 .31464 L
.34727 .31464 L
.3475 .31464 L
.34774 .31464 L
.34787 .31464 L
.34794 .31464 L
.348 .31464 L
.34803 .31464 L
.34807 .31464 L
.34808 .31464 L
.3481 .00312 L
.34812 .00312 L
.34813 .00312 L
.34825 .00312 L
.34848 .00312 L
.34899 .00312 L
.34991 .00312 L
.3509 .00312 L
.35184 .00312 L
.35276 .00312 L
.35373 .00312 L
.35466 .00312 L
.35565 .00312 L
Mistroke
.35661 .00312 L
.35753 .00312 L
.35851 .00312 L
.35945 .00312 L
.36036 .00312 L
.36133 .00312 L
.36225 .00312 L
.36324 .00312 L
.36419 .00312 L
.36511 .00312 L
.36608 .00312 L
.36702 .00312 L
.36802 .00312 L
.36898 .00312 L
.3699 .00312 L
.37088 .00312 L
.37183 .00312 L
.37274 .00312 L
.37371 .00312 L
.37464 .00312 L
.37563 .00312 L
.37659 .00312 L
.37751 .00312 L
.37848 .00312 L
.37942 .00312 L
.38042 .00312 L
.38139 .00312 L
.38231 .00312 L
.3833 .00312 L
.38425 .00312 L
.38516 .00312 L
.38613 .00312 L
.38707 .00312 L
.38806 .00312 L
.38902 .00312 L
.38994 .00312 L
.39092 .00312 L
.39187 .00312 L
.39278 .00312 L
.39374 .00312 L
.39467 .00312 L
.39566 .00312 L
.39662 .00312 L
.39753 .00312 L
.39851 .00312 L
.39945 .00312 L
.40044 .00312 L
.40141 .00312 L
.40233 .00312 L
.40331 .00312 L
Mistroke
.40426 .00312 L
.40517 .00312 L
.40614 .00312 L
.40708 .00312 L
.40807 .00312 L
.40902 .00312 L
.40994 .00312 L
.41092 .00312 L
.41187 .00312 L
.41277 .00312 L
.41374 .00312 L
.41466 .00312 L
.41565 .00312 L
.4166 .00312 L
.41752 .00312 L
.41849 .00312 L
.41943 .00312 L
.42042 .00312 L
.42138 .00312 L
.4223 .00312 L
.42329 .00312 L
.42423 .00312 L
.42514 .00312 L
.42611 .00312 L
.42704 .00312 L
.42803 .00312 L
.42898 .00312 L
.4299 .00312 L
.43088 .00312 L
.43182 .00312 L
.43282 .00312 L
.43378 .00312 L
.43471 .00312 L
.43569 .00312 L
.43664 .00312 L
.43755 .00312 L
.43852 .00312 L
.43946 .00312 L
.44045 .00312 L
.44141 .00312 L
.44233 .00312 L
.44331 .00312 L
.44425 .00312 L
.44516 .00312 L
.44613 .00312 L
.44706 .00312 L
.44804 .00312 L
.449 .00312 L
.44991 .00312 L
.45089 .00312 L
Mistroke
.45182 .00312 L
.45282 .00312 L
.45378 .00312 L
.45471 .00312 L
.45569 .00312 L
.45664 .00312 L
.45755 .00312 L
.45852 .00312 L
.45945 .00312 L
.46044 .00312 L
.46094 .00312 L
.46118 .00312 L
.46129 .00312 L
.46134 .00312 L
.46137 .00312 L
.4614 .00312 L
.46142 .00312 L
.46145 .31464 L
.46148 .31464 L
.46151 .31464 L
.46163 .31464 L
.46184 .31464 L
.46209 .31464 L
.4622 .31464 L
.46225 .31464 L
.46231 .31464 L
.46234 .31464 L
.46237 .31464 L
.4624 .00312 L
.46243 .00312 L
.46254 .00312 L
.46277 .00312 L
.46327 .00312 L
.46425 .00312 L
.46519 .00312 L
.46619 .00312 L
.46715 .00312 L
.46807 .00312 L
.46906 .00312 L
.47001 .00312 L
.47092 .00312 L
.47189 .00312 L
.47282 .00312 L
.47382 .00312 L
.47477 .00312 L
.47569 .00312 L
.47667 .00312 L
.47761 .00312 L
.47852 .00312 L
.47948 .00312 L
Mistroke
.47993 .00312 L
.48018 .00312 L
.4803 .00312 L
.48041 .00312 L
.48044 .00312 L
.48047 .00312 L
.48049 .15888 L
.4805 .15888 L
.48053 .15888 L
.48065 .15888 L
.48089 .15888 L
.48116 .15888 L
.48127 .15888 L
.48134 .15888 L
.48137 .15888 L
.4814 .15888 L
.48143 .00312 L
.48145 .00312 L
.48147 .00312 L
.48153 .00312 L
.48164 .00312 L
.48187 .00312 L
.48237 .00312 L
.48332 .00312 L
.48423 .00312 L
.4852 .00312 L
.48614 .00312 L
.48713 .00312 L
.48809 .00312 L
.48901 .00312 L
.48999 .00312 L
.49094 .00312 L
.49184 .00312 L
.49281 .00312 L
.49374 .00312 L
.49473 .00312 L
.49568 .00312 L
.4966 .00312 L
.49757 .00312 L
.49851 .00312 L
.49899 .00312 L
.49924 .00312 L
.49938 .00312 L
.49945 .00312 L
.49948 .00312 L
.49949 .00312 L
.49951 .00312 L
.49954 .15888 L
.49957 .15888 L
.49962 .15888 L
Mistroke
.49975 .15888 L
.50001 .15888 L
.50025 .15888 L
.50035 .15888 L
.50041 .15888 L
.50044 .15888 L
.50047 .15888 L
.50049 .00312 L
.5005 .00312 L
.50053 .00312 L
.50059 .00312 L
.50072 .00312 L
.50099 .00312 L
.50147 .00312 L
.50245 .00312 L
.5034 .00312 L
.50431 .00312 L
.50527 .00312 L
.5062 .00312 L
.50719 .00312 L
.50815 .00312 L
.50907 .00312 L
.51004 .00312 L
.51098 .00312 L
.51198 .00312 L
.51294 .00312 L
.51387 .00312 L
.51485 .00312 L
.5158 .00312 L
.51671 .00312 L
.51722 .00312 L
.51769 .00312 L
.51791 .00312 L
.51816 .00312 L
.51828 .00312 L
.5184 .00312 L
.5185 .00312 L
.51853 .00312 L
.51856 .00312 L
.51859 .15888 L
.51862 .15888 L
.51907 .15888 L
.5192 .15888 L
.51933 .15888 L
.5194 .15888 L
.51946 .15888 L
.51948 .15888 L
.51951 .15888 L
.51954 .00312 L
.51957 .00312 L
Mistroke
.52048 .00312 L
.52145 .00312 L
.52238 .00312 L
.52337 .00312 L
.52433 .00312 L
.52525 .00312 L
.52623 .00312 L
.52717 .00312 L
.52817 .00312 L
.52913 .00312 L
.53006 .00312 L
.53104 .00312 L
.53199 .00312 L
.53291 .00312 L
.53388 .00312 L
.53481 .00312 L
.53581 .00312 L
.53631 .00312 L
.53677 .00312 L
.53721 .00312 L
.53744 .00312 L
.5375 .00312 L
.53753 .00312 L
.53757 .00312 L
.5376 .00312 L
.53762 .00312 L
.53763 .31464 L
.53766 .31464 L
.53769 .31464 L
.53794 .31464 L
.5382 .31464 L
.53832 .31464 L
.53845 .31464 L
.53851 .31464 L
.53854 .31464 L
.53857 .31464 L
.53858 .00312 L
.5386 .00312 L
.53863 .00312 L
.53869 .00312 L
.53967 .00312 L
.54061 .00312 L
.54151 .00312 L
.54248 .00312 L
.54341 .00312 L
.54439 .00312 L
.54535 .00312 L
.54626 .00312 L
.54723 .00312 L
.54817 .00312 L
Mistroke
.54917 .00312 L
.55013 .00312 L
.55105 .00312 L
.55203 .00312 L
.55298 .00312 L
.55389 .00312 L
.55485 .00312 L
.55579 .00312 L
.55678 .00312 L
.55773 .00312 L
.55865 .00312 L
.55962 .00312 L
.56057 .00312 L
.56156 .00312 L
.56253 .00312 L
.56345 .00312 L
.56444 .00312 L
.56539 .00312 L
.5663 .00312 L
.56727 .00312 L
.56821 .00312 L
.5692 .00312 L
.57016 .00312 L
.57108 .00312 L
.57206 .00312 L
.573 .00312 L
.57391 .00312 L
.57488 .00312 L
.57581 .00312 L
.57679 .00312 L
.57775 .00312 L
.57866 .00312 L
.57964 .00312 L
.58058 .00312 L
.58157 .00312 L
.58253 .00312 L
.58346 .00312 L
.58444 .00312 L
.58539 .00312 L
.5863 .00312 L
.58727 .00312 L
.5882 .00312 L
.58919 .00312 L
.59015 .00312 L
.59107 .00312 L
.59205 .00312 L
.59299 .00312 L
.59399 .00312 L
.59495 .00312 L
.59588 .00312 L
Mistroke
.59687 .00312 L
.59782 .00312 L
.59873 .00312 L
.5997 .00312 L
.60064 .00312 L
.60163 .00312 L
.60259 .00312 L
.60351 .00312 L
.6045 .00312 L
.60544 .00312 L
.60635 .00312 L
.60732 .00312 L
.60825 .00312 L
.60924 .00312 L
.61019 .00312 L
.61111 .00312 L
.61208 .00312 L
.61302 .00312 L
.61402 .00312 L
.61498 .00312 L
.61591 .00312 L
.61689 .00312 L
.61784 .00312 L
.61875 .00312 L
.61972 .00312 L
.62066 .00312 L
.62165 .00312 L
.62261 .00312 L
.62353 .00312 L
.62451 .00312 L
.62545 .00312 L
.62636 .00312 L
.62732 .00312 L
.62825 .00312 L
.62924 .00312 L
.63019 .00312 L
.63111 .00312 L
.63208 .00312 L
.63302 .00312 L
.63401 .00312 L
.63497 .00312 L
.6359 .00312 L
.63688 .00312 L
.63783 .00312 L
.63874 .00312 L
.6397 .00312 L
.64064 .00312 L
.64163 .00312 L
.64258 .00312 L
.6435 .00312 L
Mistroke
.64448 .00312 L
.64542 .00312 L
.64642 .00312 L
.64738 .00312 L
.64831 .00312 L
.64929 .00312 L
.65024 .00312 L
.65116 .00312 L
.65163 .00312 L
.65176 .00312 L
.65183 .00312 L
.65186 .00312 L
.65187 .00312 L
.65189 .00312 L
.65192 .31464 L
.65194 .31464 L
.652 .31464 L
.65213 .31464 L
.65261 .31464 L
.65273 .31464 L
.65279 .31464 L
.65282 .31464 L
.65285 .31464 L
.65287 .00312 L
.65289 .00312 L
.65292 .00312 L
.65299 .00312 L
.65312 .00312 L
.65403 .00312 L
.655 .00312 L
.65593 .00312 L
.65692 .00312 L
.65788 .00312 L
.6588 .00312 L
.65978 .00312 L
.66072 .00312 L
.66172 .00312 L
.66269 .00312 L
.66361 .00312 L
.6646 .00312 L
.66555 .00312 L
.66647 .00312 L
.66744 .00312 L
.66837 .00312 L
.66937 .00312 L
.66987 .00312 L
.67033 .00312 L
.67056 .00312 L
.67078 .00312 L
.67089 .00312 L
Mistroke
.67092 .00312 L
.67095 .00312 L
.67097 .15888 L
.671 .15888 L
.67125 .15888 L
.6715 .15888 L
.67173 .15888 L
.67179 .15888 L
.67185 .15888 L
.67187 .15888 L
.67189 .15888 L
.67191 .00312 L
.67192 .00312 L
.67199 .00312 L
.67223 .00312 L
.67322 .00312 L
.67418 .00312 L
.6751 .00312 L
.67608 .00312 L
.67702 .00312 L
.67793 .00312 L
.6789 .00312 L
.67983 .00312 L
.68081 .00312 L
.68177 .00312 L
.68268 .00312 L
.68366 .00312 L
.68459 .00312 L
.68559 .00312 L
.68655 .00312 L
.68748 .00312 L
.68846 .00312 L
.68895 .00312 L
.6894 .00312 L
.68963 .00312 L
.68984 .00312 L
.6899 .00312 L
.68996 .00312 L
.68998 .00312 L
.69 .00312 L
.69003 .15888 L
.69006 .15888 L
.69009 .15888 L
.69031 .15888 L
.69056 .15888 L
.69079 .15888 L
.69085 .15888 L
.69091 .15888 L
.69094 .15888 L
.69096 .00312 L
Mistroke
.69098 .00312 L
.69104 .00312 L
.6913 .00312 L
.69225 .00312 L
.69315 .00312 L
.69412 .00312 L
.69505 .00312 L
.69604 .00312 L
.69699 .00312 L
.69791 .00312 L
.69889 .00312 L
.69983 .00312 L
.70082 .00312 L
.70179 .00312 L
.70271 .00312 L
.7037 .00312 L
.70464 .00312 L
.70555 .00312 L
.70652 .00312 L
.70746 .00312 L
.70793 .00312 L
.70845 .00312 L
.70869 .00312 L
.70882 .00312 L
.70889 .00312 L
.70895 .00312 L
.709 .00312 L
.70903 .00312 L
.70905 .15888 L
.70908 .15888 L
.70911 .15888 L
.70917 .15888 L
.70941 .15888 L
.70965 .15888 L
.70978 .15888 L
.70985 .15888 L
.70992 .15888 L
.70995 .15888 L
.70998 .15888 L
.70999 .15888 L
.71001 .00312 L
.71004 .00312 L
.71017 .00312 L
.7104 .00312 L
.71138 .00312 L
.71232 .00312 L
.71332 .00312 L
.71428 .00312 L
.71521 .00312 L
.7162 .00312 L
Mistroke
.71715 .00312 L
.71806 .00312 L
.71903 .00312 L
.71996 .00312 L
.72096 .00312 L
.72192 .00312 L
.72284 .00312 L
.72382 .00312 L
.72476 .00312 L
.72567 .00312 L
.72664 .00312 L
.72757 .00312 L
.72781 .00312 L
.72794 .00312 L
.72799 .00312 L
.72805 .00312 L
.72808 .00312 L
.72811 .31464 L
.72813 .31464 L
.72816 .31464 L
.72829 .31464 L
.72855 .31464 L
.72878 .31464 L
.72891 .31464 L
.72897 .31464 L
.729 .31464 L
.72902 .31464 L
.72905 .00312 L
.72908 .00312 L
.72913 .00312 L
.72925 .00312 L
.72946 .00312 L
.73039 .00312 L
.73138 .00312 L
.73233 .00312 L
.73324 .00312 L
.73422 .00312 L
.73515 .00312 L
.73615 .00312 L
.73711 .00312 L
.73803 .00312 L
.73901 .00312 L
.73996 .00312 L
.74086 .00312 L
.74183 .00312 L
.74276 .00312 L
.74375 .00312 L
.74471 .00312 L
.74562 .00312 L
.7466 .00312 L
Mistroke
.74754 .00312 L
.74854 .00312 L
.7495 .00312 L
.75043 .00312 L
.75141 .00312 L
.75236 .00312 L
.75327 .00312 L
.75424 .00312 L
.75518 .00312 L
.75617 .00312 L
.75713 .00312 L
.75805 .00312 L
.75903 .00312 L
.75997 .00312 L
.76088 .00312 L
.76184 .00312 L
.76277 .00312 L
.76376 .00312 L
.76471 .00312 L
.76563 .00312 L
.7666 .00312 L
.76754 .00312 L
.76853 .00312 L
.76949 .00312 L
.77042 .00312 L
.7714 .00312 L
.77235 .00312 L
.77326 .00312 L
.77423 .00312 L
.77516 .00312 L
.77615 .00312 L
.7771 .00312 L
.77802 .00312 L
.779 .00312 L
.77994 .00312 L
.78094 .00312 L
.7819 .00312 L
.78283 .00312 L
.78382 .00312 L
.78477 .00312 L
.78568 .00312 L
.78665 .00312 L
.78759 .00312 L
.78858 .00312 L
.78954 .00312 L
.79046 .00312 L
.79144 .00312 L
.79239 .00312 L
.7933 .00312 L
.79426 .00312 L
Mistroke
.79519 .00312 L
.79618 .00312 L
.79713 .00312 L
.79805 .00312 L
.79903 .00312 L
.79997 .00312 L
.80096 .00312 L
.80192 .00312 L
.80285 .00312 L
.80383 .00312 L
.80478 .00312 L
.80569 .00312 L
.80666 .00312 L
.8076 .00312 L
.80859 .00312 L
.80954 .00312 L
.81046 .00312 L
.81144 .00312 L
.81238 .00312 L
.81329 .00312 L
.81426 .00312 L
.81518 .00312 L
.81617 .00312 L
.81712 .00312 L
.81804 .00312 L
.81901 .00312 L
.81995 .00312 L
.82094 .00312 L
.8219 .00312 L
.82282 .00312 L
.82381 .00312 L
.82475 .00312 L
.82566 .00312 L
.82663 .00312 L
.82756 .00312 L
.82855 .00312 L
.82951 .00312 L
.83042 .00312 L
.8314 .00312 L
.83234 .00312 L
.83334 .00312 L
.8343 .00312 L
.83523 .00312 L
.83621 .00312 L
.83716 .00312 L
.83807 .00312 L
.83905 .00312 L
.83998 .00312 L
.84097 .00312 L
.84147 .00312 L
Mistroke
.84193 .00312 L
.84216 .00312 L
.84227 .00312 L
.84232 .00312 L
.84235 .00312 L
.84238 .00312 L
.8424 .31464 L
.84243 .31464 L
.84249 .31464 L
.8426 .31464 L
.84285 .31464 L
.8431 .31464 L
.84317 .31464 L
.84324 .31464 L
.8433 .31464 L
.84332 .31464 L
.84333 .31464 L
.84335 .00312 L
.84337 .00312 L
.84385 .00312 L
.84481 .00312 L
.84572 .00312 L
.8467 .00312 L
.84764 .00312 L
.84864 .00312 L
.84961 .00312 L
.85054 .00312 L
.85152 .00312 L
.85247 .00312 L
.85339 .00312 L
.85436 .00312 L
.85529 .00312 L
.85629 .00312 L
.85725 .00312 L
.85817 .00312 L
.85915 .00312 L
.8601 .00312 L
.86057 .00312 L
.861 .00312 L
.86123 .00312 L
.86135 .00312 L
.86138 .00312 L
.86139 .00312 L
.86141 .00312 L
.86144 .15888 L
.86147 .15888 L
.86171 .15888 L
.86197 .15888 L
.8622 .15888 L
.86226 .15888 L
Mistroke
.8623 .15888 L
.86233 .15888 L
.86236 .15888 L
.86238 .15888 L
.8624 .00312 L
.86242 .00312 L
.86245 .00312 L
.8629 .00312 L
.8638 .00312 L
.86477 .00312 L
.8657 .00312 L
.86668 .00312 L
.86764 .00312 L
.86855 .00312 L
.86952 .00312 L
.87046 .00312 L
.87146 .00312 L
.87242 .00312 L
.87334 .00312 L
.87432 .00312 L
.87527 .00312 L
.87618 .00312 L
.87715 .00312 L
.87808 .00312 L
.87907 .00312 L
.87957 .00312 L
.88003 .00312 L
.88026 .00312 L
.88037 .00312 L
.88042 .00312 L
.88044 .00312 L
.88047 .00312 L
.8805 .15888 L
.88053 .15888 L
.88059 .15888 L
.88072 .15888 L
.88094 .15888 L
.88119 .15888 L
.88126 .15888 L
.88133 .15888 L
.88139 .15888 L
.8814 .15888 L
.88142 .15888 L
.88144 .00312 L
.88145 .00312 L
.88194 .00312 L
.88289 .00312 L
.88381 .00312 L
.88478 .00312 L
.88572 .00312 L
Mistroke
.88672 .00312 L
.88768 .00312 L
.8886 .00312 L
.88959 .00312 L
.89054 .00312 L
.89145 .00312 L
.89242 .00312 L
.89335 .00312 L
.89434 .00312 L
.8953 .00312 L
.89622 .00312 L
.89719 .00312 L
.89814 .00312 L
.89862 .00312 L
.89887 .00312 L
.89914 .00312 L
.89938 .00312 L
.89944 .00312 L
.89948 .00312 L
.8995 .00312 L
.89951 .00312 L
.89953 .15888 L
.89955 .15888 L
.89958 .15888 L
.89964 .15888 L
.9001 .15888 L
.90033 .15888 L
.90039 .15888 L
.90043 .15888 L
.90046 .15888 L
.90048 .00312 L
.90051 .00312 L
.90057 .00312 L
.90101 .00312 L
.90201 .00312 L
.90297 .00312 L
.9039 .00312 L
.90488 .00312 L
.90583 .00312 L
.90674 .00312 L
.90771 .00312 L
.90865 .00312 L
.90964 .00312 L
.9106 .00312 L
.91152 .00312 L
.9125 .00312 L
.91344 .00312 L
.91435 .00312 L
.91532 .00312 L
.91624 .00312 L
Mistroke
.91723 .00312 L
.91773 .00312 L
.91797 .00312 L
.91818 .00312 L
.91829 .00312 L
.91841 .00312 L
.91847 .00312 L
.9185 .00312 L
.91852 .00312 L
.91855 .00312 L
.91857 .31464 L
.9186 .31464 L
.91863 .31464 L
.91887 .31464 L
.9191 .31464 L
.91932 .31464 L
.91939 .31464 L
.91945 .31464 L
.91947 .31464 L
.9195 .31464 L
.91953 .00312 L
.91956 .00312 L
.92006 .00312 L
.92097 .00312 L
.92194 .00312 L
.92288 .00312 L
.92387 .00312 L
.92483 .00312 L
.92575 .00312 L
.92673 .00312 L
.92768 .00312 L
.92859 .00312 L
.92955 .00312 L
.93048 .00312 L
.93147 .00312 L
.93243 .00312 L
.93334 .00312 L
.93432 .00312 L
.93526 .00312 L
.93625 .00312 L
.93722 .00312 L
.93814 .00312 L
.93913 .00312 L
.94007 .00312 L
.94098 .00312 L
.94195 .00312 L
.94289 .00312 L
.94388 .00312 L
.94484 .00312 L
.94576 .00312 L
Mistroke
.94674 .00312 L
.94768 .00312 L
.94858 .00312 L
.94955 .00312 L
.95048 .00312 L
.95147 .00312 L
.95242 .00312 L
.95333 .00312 L
.9543 .00312 L
.95524 .00312 L
.95624 .00312 L
.9572 .00312 L
.95812 .00312 L
.9591 .00312 L
.96005 .00312 L
.96096 .00312 L
.96193 .00312 L
.96286 .00312 L
.96385 .00312 L
.9648 .00312 L
.96572 .00312 L
.9667 .00312 L
.96764 .00312 L
.96864 .00312 L
.9696 .00312 L
.97053 .00312 L
.97151 .00312 L
.97246 .00312 L
.97337 .00312 L
.97434 .00312 L
.97528 .00312 L
.97619 .00312 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00E_ooool5o`0000?ooooo0_l0001>ooooo`?o00001?ooool2o`0004oooooo0_l0001Aoooo
o`?o00001?ooool2o`0004gooooo1Ol00003ooooo`;o0000?oooool005Oooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0001>ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000COooool01?l0003oooooooooool0001Aooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000COooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0003kooooo001@ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0004Kooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000COoo
ool01?l0003oooooooooool0001Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000C_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003kooooo001Iooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000COooool01?l0003oooooooooool0001Aooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000Coooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool0??ooool005Kooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0004kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001=
ooooo`04o`000?ooooooooooo`00057ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0001<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000noooo
o`00E_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000COooool2
o`0000Cooooo00Co0000oooooooooooo0000COooool01?l0003oooooooooool0001@ooooo`;o0000
1?ooool01?l0003oooooooooool0001<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000nooooo`00Eoooool3o`0000Cooooo0_l0001?ooooo`03o`000?oooooooooo
00?ooooo0_l0001?ooooo`;o0000D_ooool00ol0003oooooooooo`03ooooo`;o0000C_ooool3o`00
00Cooooo0_l0000oooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`006Oooool2o`000?oooooog_ooool001Sooooo00Co
0000oooooooooooo00001_ooooooo`000<_o00003?ooool001Sooooo00Co0000oooooooooooo0000
1_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00kooooo0_oo0007ooooo`;o
o`001oooool00ooo003oooooooooo`05ooooo`;oo`001oooool2ool0013ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`;oo`001oooool2ool000Oooooo00?oo`00oooooooo
ool01Oooool2ool000Oooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03_ooool2ool000Oooooo0_oo0007ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`;o
o`004?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo0_oo0007ooooo`;o
o`001oooool00ooo003oooooooooo`05ooooo`;oo`001oooool2ool0013ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`;oo`001oooool2ool000Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`05ooooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooo000000cooooo000Hooooo`04o`000?ooooooooooo`0000Kooooo1?l00007oooooooo
o`00]Ooo0007ooooo`Co00003?ooool001Sooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooooooo`0Rooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oo
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003o
ooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool08_ooool00ol0003o
ooooooooo`0:ooooo`006?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02;o
oooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oo
oooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037o
oooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oo
oooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[o
oooo000Iooooo`;o00001oooool00ol0003oooooooooo`0Rooooo`;oo`001oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo
0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo
00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo
0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo
00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003ooooooooo
o`0Rooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo
0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003ooooooooo
o`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo
0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool08_ooool00ol0003ooooooooo
o`0:ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`001oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00
ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05
ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00
ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`0Roooo
o`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007oooo
o`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aoooo
o`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007oooo
o`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool2ool000Oooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:oooo
o`008_ooool3o`0002;ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;o
o`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03
ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0Qooooo`;o
00003?ooool002;ooooo00?o0000ooooooooool08_ooool2ool000Oooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`00
1oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool0
0?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`00
1oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool0
0?oooooooooo02;ooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool08_oo
ool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001ooo
ool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Ooo
ool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001ooo
ool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_oo
ool002;ooooo00?o0000ooooooooool08_ooool2ool000Oooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooo
oooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2
ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooo
oooo02;ooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool08_ooool2ool0
00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo
003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool0
00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo
003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo0_oo0007ooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool002;o
oooo00?o0000ooooooooool08_ooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037o
oooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oo
oooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo02;o
oooo00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool08_ooool2ool000Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003ooooo
ooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003ooooo
ooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
0_oo0007ooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool002;ooooo0ol0
000Rooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo
0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003ooooooooo
o`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo
0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool08Oooool2o`0000cooooo000R
ooooo`03o`000?oooooooooo02;ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0a
ooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007
ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0R
ooooo`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo0007oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooo
ooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06oooo
o`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooo
ooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05oooo
o`;oo`001oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`03
o`000?oooooooooo02;ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;o
o`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03
ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0Rooooo`03
o`000?oooooooooo00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo0007ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0
<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`00
1oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0
<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`00
1oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oo
oooooooo02;ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Ooo
ool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001ooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oo
oooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Ooo
ool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0Rooooo`03o`000?oo
oooooooo00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo0007ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2
ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool0
0ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2
ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool0
0ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`?o00008_ooool2ool0
00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo
003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool0
00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo
003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo0_oo0007ooooo`03ool00?oooooooooo027ooooo0_l0000<ooooo`008_ooool00ol0003o
ooooooooo`0Rooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oo
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003o
ooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool08_ooool00ol0003o
ooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`001oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo
0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo
00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo
0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo
00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003ooooooooo
o`0Rooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo
0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003ooooooooo
o`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo
0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool08_ooool00ol0003ooooooooo
o`0:ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`001oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00
ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05
ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00
ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`0Roooo
o`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007oooo
o`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aoooo
o`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007oooo
o`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool2ool000Oooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:oooo
o`008_ooool00ol0003oooooooooo`0Rooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooooooo
ool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;o
o`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooooooo
ool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool3o`0002;ooooo0_oo0007ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0
<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`00
1oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0
<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`00
1oooool00ooo003oooooooooo`0Qooooo`;o00003?ooool002;ooooo00?o0000ooooooooool08_oo
ool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001ooo
ool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Ooo
ool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001ooo
ool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_oo
ool002;ooooo00?o0000ooooooooool08_ooool2ool000Oooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooo
oooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2
ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooo
oooo02;ooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool08_ooool2ool0
00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo
003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool0
00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo
003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo0_oo0007ooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool002;o
oooo00?o0000ooooooooool08_ooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037o
oooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oo
oooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo02;o
oooo00?o0000ooooooooool02_ooool000gooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00007ooooo`03o`000?oooooooooo02;ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003ooooo
ooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00[ooooo000<ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02;ooooo0_oo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooooooo
ool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;o
o`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooooooo
ool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;o
o`001oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000<ooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool01?ooool4o`00027ooooo0_oo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooooooo
ool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;o
o`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooooooo
ool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;o
o`001oooool00ooo003oooooooooo`0Oooooo`Co00003?ooool000cooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02;ooooo0_oo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooooooo
ool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;o
o`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooooooo
ool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;o
o`001oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000<ooooo`04o`00
0?ooooooooooo`0000Oooooo1?l00007ooooo`03o`000?oooooooooo02;ooooo0_oo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooooooo
ool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;o
o`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooooooo
ool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;o
o`001oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000<ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`;o
o`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03
ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;o
o`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03
ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool2ool000Oooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`00
3Oooool2o`0000Sooooo1Ol00006ooooo`03o`000?oooooooooo02;ooooo0_oo0007ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0
<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`00
1oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0
<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`00
1oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oo
oooooooo02;ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Ooo
ool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001ooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oo
oooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Ooo
ool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0Rooooo`03o`000?oo
oooooooo00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo0007ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2
ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool0
0ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2
ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool0
0ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`?o00008_ooool2ool0
00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo
003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool0
00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo
003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo0_oo0007ooooo`03ool00?oooooooooo027ooooo0_l0000<ooooo`008_ooool00ol0003o
ooooooooo`0Rooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oo
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003o
ooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool08_ooool00ol0003o
ooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`001oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo
0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo
00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo
0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo
00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003ooooooooo
o`0Rooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo
0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003ooooooooo
o`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo
0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool08_ooool00ol0003ooooooooo
o`0:ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`001oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00
ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05
ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00
ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`0Roooo
o`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007oooo
o`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aoooo
o`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007oooo
o`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool2ool000Oooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:oooo
o`008_ooool00ol0003oooooooooo`0Rooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooooooo
ool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;o
o`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00oooooooo
ool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool3o`0002;ooooo0_oo0007ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0
<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`00
1oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0
<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`00
1oooool00ooo003oooooooooo`0Qooooo`;o00003?ooool002;ooooo00?o0000ooooooooool08_oo
ool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001ooo
ool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oo
oooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Ooo
ool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001ooo
ool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oo
oooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_oo
ool002;ooooo00?o0000ooooooooool08_ooool2ool000Oooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooo
oooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2
ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooo
oooo02;ooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool08_ooool2ool0
00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo
003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo
00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool0
00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo
003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo
00Gooooo0_oo0007ooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool002;o
oooo00?o0000ooooooooool08_ooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037o
oooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oo
oooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo02;o
oooo00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool08_ooool2ool000Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003ooooo
ooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003ooooo
ooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
0_oo0007ooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool002;ooooo00?o
0000ooooooooool08_ooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo
0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?o
o`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003ooooooooo
o`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo02;ooooo00?o
0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool08_ooool2ool000Oooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0a
ooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007
ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0a
ooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007
ooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool002;ooooo0ol0000Roooo
o`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007oooo
o`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aoooo
o`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007oooo
o`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool2ool000Oooooo00?oo`00ooooooooool08Oooool2o`0000cooooo000Rooooo`03
o`000?oooooooooo02;ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;o
o`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03
ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0Rooooo`03
o`000?oooooooooo00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo0007ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0
<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`00
1oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0
<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`00
1oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oo
oooooooo02;ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Ooo
ool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001ooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oo
oooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Ooo
ool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0Rooooo`03o`000?oo
oooooooo00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo0007ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2
ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool0
0ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2
ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool0
0ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oooooooooo
02;ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool0
00Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo
037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool0
00Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo
003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo
00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo0007ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oo
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003o
ooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Go
oooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oo
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003o
ooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`?o00008_ooool2ool000Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003ooooo
ooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003ooooo
ooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo
0_oo0007ooooo`03ool00?oooooooooo027ooooo0_l0000<ooooo`008_ooool00ol0003ooooooooo
o`0Rooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo
0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?o
o`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003ooooooooo
o`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo
0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?o
o`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool08_ooool00ol0003ooooooooo
o`0:ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`001oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00
ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05
ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00
ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`0Roooo
o`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007oooo
o`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00oooo
ooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aoooo
o`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007oooo
o`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool01Oooool2ool000Oooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:oooo
o`006?ooool3o`0000Oooooo00?o0000ooooooooool08_ooool2ool000Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;o
o`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03
ool00?oooooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo
ool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;o
o`001oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03
ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool001Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Rooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0
<Oooool2ool000Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`05ooooo`;oo`00
1oooool00ooo003oooooooooo`0aooooo`;oo`001oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo0_oo0007ooooo`03ool0
0?oooooooooo00Kooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0
8_ooool00ol0003oooooooooo`0:ooooo`006Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02;ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Ooo
ool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0aooooo`;oo`001ooo
ool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oo
oooooooo037ooooo0_oo0007ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01Ooo
ool2ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooooooo`05ooooo`;oo`001oooool00ooo003oooooooooo`0Rooooo`03o`000?oo
oooooooo00[ooooo000Iooooo`03o`000?oooooooooo00Kooooo1?l0000Qooooo`;oo`001oooool2
ool000Oooooo00?oo`00ooooooooool01Oooool2ool000Oooooo00?oo`00ooooooooool0<Oooool2
ool000Oooooo0_oo0007ooooo`03ool00?oooooooooo00Gooooo0_oo0007ooooo`03ool00?oooooo
oooo037ooooo0_oo0007ooooo`;oo`001oooool00ooo003oooooooooo`05ooooo`;oo`001oooool0
0ooo003oooooooooo`0aooooo`;oo`001oooool2ool000Oooooo00?oo`00ooooooooool01Oooool2
ool000Oooooo00?oo`00ooooooooool0<Oooool2ool000Oooooo0_oo0007ooooo`03ool00?oooooo
oooo00Gooooo0_oo0007ooooo`03ool00?oooooooooo01oooooo1?l0000<ooooo`006Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo02;ooooo0_oo000Qooooo`03ool00?oooooooooo
037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000@ooooo`03o`000?oooooooooo
00kooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0
027ooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`006?ooool2o`0000So
oooo00?o0000ooooooooool08_ooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027o
oooo00?oo`00ooooooooool0<Oooool2ool0013ooooo00?o0000ooooooooool03_ooool00ooo003o
ooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003o
ooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Iooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool08_ooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo
00?oo`00ooooooooool0<Oooool2ool0013ooooo00?o0000ooooooooool03_ooool00ooo003ooooo
ooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo
000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo
000@ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?o
o`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool08_ooool00ol0003ooooooooo
o`0:ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`008Oooool00ooo003oooooooooo`0a
ooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`004?ooool00ol0003oooooooooo`0>
ooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Q
ooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000oooo
ooooool08_ooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00oooo
ooooool0<Oooool2ool0013ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0aoooo
o`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Roooo
o`03o`000?oooooooooo00[ooooo000Rooooo`?o00008_ooool2ool0027ooooo00?oo`00oooooooo
ool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013ooooo00?o0000oooooooo
ool03_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;o
o`008Oooool00ooo003oooooooooo`0Qooooo`;o00003?ooool002;ooooo00?o0000ooooooooool0
8_ooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0
<Oooool2ool0013ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;oo`00
8Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`00
0?oooooooooo00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo000Qooooo`03ool00?oo
oooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000@ooooo`03o`000?oo
oooooooo00kooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Ooo
ool2ool0027ooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool0
0ol0003oooooooooo`0Rooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool0
0ooo003oooooooooo`0aooooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooo
oooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooo
oooo02;ooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool08_ooool2ool0
027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0
013ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo
003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo
00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo000Qooooo`03ool00?oooooooooo037o
oooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000@ooooo`03o`000?oooooooooo00ko
oooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027o
oooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003ooooo
ooooo`0Rooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003ooooo
ooooo`0aooooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo037ooooo
0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo02;ooooo
00?o0000ooooooooool02_ooool002;ooooo0ol0000Rooooo`;oo`008Oooool00ooo003ooooooooo
o`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`004?ooool00ol0003ooooooooo
o`0>ooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo
000Qooooo`03ool00?oooooooooo027ooooo0_l0000<ooooo`008_ooool00ol0003oooooooooo`0R
ooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0a
ooooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo037ooooo0_oo000Q
ooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo02;ooooo00?o0000
ooooooooool02_ooool002;ooooo00?o0000ooooooooool08_ooool2ool0027ooooo00?oo`00oooo
ooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013ooooo00?o0000oooo
ooooool03_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aoooo
o`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`03
o`000?oooooooooo02;ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03
ool00?oooooooooo037ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo00?oo`00oooooooo
ool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00oooooooo
ool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`00
8Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`00
4?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool0
0?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool0
2_ooool002;ooooo00?o0000ooooooooool08_ooool2ool0027ooooo00?oo`00ooooooooool0<Ooo
ool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013ooooo00?o0000ooooooooool03_oo
ool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Ooo
ool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oooooo
oooo02;ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooo
oooo037ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0<Oooool2
ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool08_ooool0
0ol0003oooooooooo`0:ooooo`008_ooool3o`0002;ooooo0_oo000Qooooo`03ool00?oooooooooo
037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000@ooooo`03o`000?oooooooooo
00kooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0
027ooooo00?oo`00ooooooooool08Oooool2o`0000cooooo000Rooooo`03o`000?oooooooooo02;o
oooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037o
oooo0_oo000@ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0<Oooool2ool0027o
oooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool08_ooool00ol0003o
ooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`008Oooool00ooo003ooooo
ooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`004?ooool00ol0003ooooo
ooooo`0>ooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo
0_oo000Qooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool002;ooooo00?o
0000ooooooooool08_ooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?o
o`00ooooooooool0<Oooool2ool0013ooooo00?o0000ooooooooool03_ooool00ooo003ooooooooo
o`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003ooooooooo
o`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo000Q
ooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000@
ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00
ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:
ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`008Oooool00ooo003oooooooooo`0aoooo
o`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`004?ooool00ol0003oooooooooo`0>oooo
o`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qoooo
o`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000oooooooo
ool08_ooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00oooooooo
ool0<Oooool2ool0013ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;o
o`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03
o`000?oooooooooo00[ooooo000Rooooo`?o00008_ooool2ool0027ooooo00?oo`00ooooooooool0
<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013ooooo00?o0000ooooooooool0
3_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`00
8Oooool00ooo003oooooooooo`0Qooooo`;o00003?ooool002;ooooo00?o0000ooooooooool08_oo
ool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Ooo
ool2ool0013ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;oo`008Ooo
ool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oo
oooooooo00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo000Qooooo`03ool00?oooooo
oooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000@ooooo`03o`000?oooooo
oooo00kooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2
ool0027ooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0
003oooooooooo`0Rooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo
003oooooooooo`0aooooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo
037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo
02;ooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool08_ooool2ool0027o
oooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013o
oooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003o
ooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[o
oooo000<ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00001oooool00ol0003ooooo
ooooo`0Rooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003ooooo
ooooo`0aooooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo037ooooo
0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo02;ooooo
00?o0000ooooooooool02_ooool000gooooo00?o0000ooooooooool01oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool08_ooool2ool0027ooooo00?oo`00ooooooooool0
<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013ooooo00?o0000ooooooooool0
3_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`00
8Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000=ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01?ooool4o`00027ooooo0_oo000Qooooo`03ool00?oo
oooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000@ooooo`03o`000?oo
oooooooo00kooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Ooo
ool2ool0027ooooo00?oo`00ooooooooool07oooool4o`0000cooooo000=ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Rooooo`;oo`008Oooool0
0ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`004?ooool0
0ol0003oooooooooo`0>ooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooo
oooo037ooooo0_oo000Qooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool0
00gooooo00?o0000ooooooooool01oooool4o`0000Oooooo00?o0000ooooooooool08_ooool2ool0
027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0
013ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo
003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo
00[ooooo000<ooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;o
oooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037o
oooo0_oo000@ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0<Oooool2ool0027o
oooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool08_ooool00ol0003o
ooooooooo`0:ooooo`003Oooool00ol0003oooooooooo`07ooooo`Go00001_ooool00ol0003ooooo
ooooo`0Rooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003ooooo
ooooo`0aooooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo037ooooo
0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo02;ooooo
00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool08_ooool2ool0027ooooo00?o
o`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013ooooo00?o
0000ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003ooooooooo
o`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000R
ooooo`03o`000?oooooooooo02;ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Q
ooooo`03ool00?oooooooooo037ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo00?oo`00
ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00
ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool3o`0002;ooooo0_oo000Qoooo
o`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000@oooo
o`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00oooo
ooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool08Oooool2o`0000cooooo000Rooooo`03
o`000?oooooooooo02;ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03
ool00?oooooooooo037ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo00?oo`00oooooooo
ool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00oooooooo
ool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`00
8Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`00
4?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool0
0?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool0
2_ooool002;ooooo00?o0000ooooooooool08_ooool2ool0027ooooo00?oo`00ooooooooool0<Ooo
ool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013ooooo00?o0000ooooooooool03_oo
ool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Ooo
ool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oooooo
oooo02;ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooo
oooo037ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0<Oooool2
ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool08_ooool0
0ol0003oooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`008Oooool00ooo
003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`004?ooool00ol0
003oooooooooo`0>ooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo
037ooooo0_oo000Qooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool002;o
oooo00?o0000ooooooooool08_ooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027o
oooo00?oo`00ooooooooool0<Oooool2ool0013ooooo00?o0000ooooooooool03_ooool00ooo003o
ooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003o
ooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo
0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo
0_oo000@ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo
00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool08_ooool00ol0003ooooo
ooooo`0:ooooo`008_ooool3o`0002;ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo
000Qooooo`03ool00?oooooooooo037ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo00?o
o`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?o
o`00ooooooooool08Oooool2o`0000cooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo000Q
ooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000@
ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00
ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:
ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`008Oooool00ooo003oooooooooo`0aoooo
o`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`004?ooool00ol0003oooooooooo`0>oooo
o`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qoooo
o`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000oooooooo
ool08_ooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00oooooooo
ool0<Oooool2ool0013ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;o
o`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03
o`000?oooooooooo00[ooooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo000Qooooo`03ool0
0?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000@ooooo`03o`00
0?oooooooooo00kooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0
<Oooool2ool0027ooooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`008_oo
ool00ol0003oooooooooo`0Rooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Ooo
ool00ooo003oooooooooo`0aooooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`03ool00?oo
oooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oo
oooooooo02;ooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool08_ooool2
ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2
ool0013ooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool0
0ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooo
oooo00[ooooo000Rooooo`?o00008_ooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0
027ooooo00?oo`00ooooooooool0<Oooool2ool0013ooooo00?o0000ooooooooool03_ooool00ooo
003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo
003oooooooooo`0Qooooo`;o00003?ooool002;ooooo00?o0000ooooooooool08_ooool2ool0027o
oooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013o
oooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003o
ooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[o
oooo000Rooooo`03o`000?oooooooooo02;ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo
0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo
00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo
00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003ooooooooo
o`0Rooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003ooooooooo
o`0aooooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo037ooooo0_oo
000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo02;ooooo00?o
0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool08_ooool2ool0027ooooo00?oo`00
ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013ooooo00?o0000
ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0a
ooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Roooo
o`03o`000?oooooooooo02;ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qoooo
o`03ool00?oooooooooo037ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo00?oo`00oooo
ooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00oooo
ooooool08_ooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;o
o`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;o
o`004?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03
ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo02;ooooo00?o0000oooooooo
ool02_ooool002;ooooo0ol0000Rooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`00
8Oooool00ooo003oooooooooo`0aooooo`;oo`004?ooool00ol0003oooooooooo`0>ooooo`03ool0
0?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool0
0?oooooooooo027ooooo0_l0000<ooooo`008_ooool00ol0003oooooooooo`0Rooooo`;oo`008Ooo
ool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`004?oo
ool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oo
oooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo02;ooooo00?o0000ooooooooool02_oo
ool002;ooooo00?o0000ooooooooool08_ooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2
ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013ooooo00?o0000ooooooooool03_ooool0
0ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0aooooo`;oo`008Oooool0
0ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oooooooooo
02;ooooo0_oo000Qooooo`03ool00?oooooooooo037ooooo0_oo000Qooooo`03ool00?oooooooooo
037ooooo0_oo000@ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0<Oooool2ool0
027ooooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool08_ooool00ol0
003oooooooooo`0:ooooo`005oooool5o`0000Kooooo00?o0000ooooooooool08_ooool2ool0027o
oooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013o
oooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003o
ooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[o
oooo000Hooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool08_ooool2ool0027o
oooo00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013o
oooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003o
ooooooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[o
oooo000Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08_ooool2ool0027ooooo
00?oo`00ooooooooool0<Oooool2ool0027ooooo00?oo`00ooooooooool0<Oooool2ool0013ooooo
00?o0000ooooooooool03_ooool00ooo003oooooooooo`0aooooo`;oo`008Oooool00ooo003ooooo
ooooo`0aooooo`;oo`008Oooool00ooo003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo
000Jooooo`03o`000?oooooooooo00Gooooo1?l0000Qooooo`;oo`008Oooool2ool003;ooooo0_oo
000Qooooo`;oo`00<_ooool2ool0013ooooo00?o0000ooooooooool03_ooool2ool003;ooooo0_oo
000Qooooo`;oo`00<_ooool2ool0027ooooo0_oo000Pooooo`Co00003?ooool001Oooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0>;ooooo00?o0000ooooooooool0hOoo
ool00ol0003oooooooooo`0:ooooo`005oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0h_ooool00ol0003oooooooooo`3Qooooo`03o`000?oooooooooo00[ooooo000H
ooooo`?o00001oooool00ol0003oooooooooo`3Rooooo`03o`000?oooooooooo0>7ooooo00?o0000
ooooooooool02_ooool002;ooooo00?o0000ooooooooool0h_ooool00ol0003oooooooooo`3Qoooo
o`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oooooooooo0>;ooooo00?o0000oooooooo
ool0hOooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1Dooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0:ooooo`008_oo
ool4o`00013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03_ooool3o`0000cooooo000Roooooooo0000bol0000<
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-30.2558, -0.226731, 0.114913, \
0.0140522}}]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Undersampling and the DTFT: Example #1", "Section"],

Cell[CellGroupData[{

Cell["Sampling frequency", "Subsection"],

Cell[BoxData[
    \(\(fs = 3\  (*\ Hz\ *) ;\)\)], "Input",
  Background->RGBColor[1, 1, 0]]
}, Closed]],

Cell[CellGroupData[{

Cell["Continuous-time signal", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := 
        1\  + \ 2\ Cos[2  \[Pi]\ t]\  + \ 4\ Cos[4  \[Pi]\ t];\)\), "\n", 
    \(\(gxt = 
        Plot[x[t], {t, 0, 5}, PlotStyle \[Rule] {Blue, Thickness[ .005]}, \ 
          PlotPoints \[Rule] 100];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.196383 0.0581337 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -12 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .31265 -6 -4.5 ]
[-0.0125 .31265 0 4.5 ]
[-0.0125 .42892 -6 -4.5 ]
[-0.0125 .42892 0 4.5 ]
[-0.0125 .54519 -6 -4.5 ]
[-0.0125 .54519 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(1)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(2)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(3)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(4)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(-2)] -0.0125 .08012 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(0)] -0.0125 .19638 1 0 Mshowa
0 .31265 m
.00625 .31265 L
s
[(2)] -0.0125 .31265 1 0 Mshowa
0 .42892 m
.00625 .42892 L
s
[(4)] -0.0125 .42892 1 0 Mshowa
0 .54519 m
.00625 .54519 L
s
[(6)] -0.0125 .54519 1 0 Mshowa
.125 Mabswid
0 .10918 m
.00375 .10918 L
s
0 .13825 m
.00375 .13825 L
s
0 .16732 m
.00375 .16732 L
s
0 .22545 m
.00375 .22545 L
s
0 .25452 m
.00375 .25452 L
s
0 .28358 m
.00375 .28358 L
s
0 .34172 m
.00375 .34172 L
s
0 .37078 m
.00375 .37078 L
s
0 .39985 m
.00375 .39985 L
s
0 .45798 m
.00375 .45798 L
s
0 .48705 m
.00375 .48705 L
s
0 .51612 m
.00375 .51612 L
s
0 .05105 m
.00375 .05105 L
s
0 .02198 m
.00375 .02198 L
s
0 .57425 m
.00375 .57425 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .31265 m
1 .31265 L
s
.99375 .42892 m
1 .42892 L
s
.99375 .54519 m
1 .54519 L
s
.125 Mabswid
.99625 .10918 m
1 .10918 L
s
.99625 .13825 m
1 .13825 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .22545 m
1 .22545 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .28358 m
1 .28358 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .37078 m
1 .37078 L
s
.99625 .39985 m
1 .39985 L
s
.99625 .45798 m
1 .45798 L
s
.99625 .48705 m
1 .48705 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .02198 m
1 .02198 L
s
.99625 .57425 m
1 .57425 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .19638 m
1 .19638 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.02381 .60332 m
.02409 .60327 L
.02435 .60315 L
.02465 .60291 L
.02494 .6026 L
.02544 .60181 L
.02599 .60063 L
.02659 .59894 L
.02722 .5967 L
.02837 .59157 L
.03066 .57704 L
.03318 .55482 L
.03845 .48973 L
.04339 .4114 L
.05279 .24379 L
.05757 .16395 L
.06278 .0915 L
.0652 .06507 L
.06778 .04268 L
.06903 .0341 L
.07021 .02743 L
.07126 .02263 L
.07241 .01871 L
.07298 .01724 L
.0733 .01658 L
.0736 .01604 L
.07388 .01562 L
.07418 .01526 L
.07446 .01501 L
.07471 .01485 L
.07501 .01474 L
.0753 .01472 L
.07561 .01479 L
.07578 .01487 L
.07594 .01497 L
.07624 .01523 L
.07657 .01561 L
.07724 .01672 L
.07791 .01826 L
.07852 .02003 L
.07989 .02524 L
.08115 .03157 L
.08235 .03879 L
.0872 .07912 L
.09167 .12835 L
.10123 .24727 L
.10603 .30069 L
.11041 .33874 L
.11157 .34657 L
.11283 .35393 L
Mistroke
.11404 .35977 L
.11513 .36402 L
.11574 .36596 L
.1164 .36769 L
.1171 .3691 L
.11741 .3696 L
.11775 .37004 L
.11807 .37036 L
.11837 .37058 L
.11869 .37073 L
.11886 .37077 L
.11902 .37078 L
.11931 .37075 L
.11962 .37064 L
.11992 .37045 L
.12019 .37021 L
.12048 .36988 L
.12078 .36946 L
.12132 .36851 L
.1219 .3672 L
.12253 .36544 L
.12367 .36141 L
.12473 .35669 L
.12714 .34252 L
.12972 .32259 L
.13491 .27024 L
.1398 .21108 L
.14913 .0974 L
.15396 .05168 L
.15639 .03472 L
.15778 .02724 L
.15907 .02176 L
.16028 .01801 L
.16096 .01651 L
.16129 .01595 L
.1616 .01552 L
.16186 .01522 L
.16215 .01497 L
.16247 .0148 L
.16276 .01472 L
.16305 .01473 L
.16336 .01484 L
.16352 .01493 L
.16369 .01505 L
.16399 .01535 L
.1643 .01574 L
.16457 .01618 L
.1652 .01746 L
.16576 .01892 L
.16635 .02081 L
Mistroke
.16737 .02492 L
.16849 .03065 L
.17095 .04758 L
.1732 .06811 L
.17826 .13016 L
.18789 .29 L
.19716 .45192 L
.20233 .52571 L
.20477 .5533 L
.20702 .57375 L
.20936 .58964 L
.2106 .59562 L
.21123 .59802 L
.2119 .60009 L
.2125 .6015 L
.21304 .60243 L
.2133 .60277 L
.21358 .60304 L
.21385 .60321 L
.2141 .6033 L
.21438 .60331 L
.21465 .60324 L
.21495 .60307 L
.21527 .60277 L
.21558 .60236 L
.21591 .60181 L
.21651 .60052 L
.21713 .59872 L
.21772 .59663 L
.21882 .59168 L
.22001 .58487 L
.2213 .5758 L
.22575 .53171 L
.23057 .46515 L
.23567 .38002 L
.24486 .21607 L
.24998 .13491 L
.25465 .0757 L
.25696 .05313 L
.25818 .04321 L
.25948 .03424 L
.26073 .02719 L
.26186 .02216 L
.26241 .02019 L
.263 .0184 L
.26356 .01703 L
.26406 .01606 L
.26434 .01564 L
.26464 .01528 L
.26496 .01499 L
Mistroke
.26526 .01481 L
.26554 .01473 L
.26584 .01472 L
.2661 .01479 L
.26638 .01494 L
.26655 .01507 L
.26671 .01521 L
.26701 .01556 L
.26769 .01665 L
.26827 .01795 L
.26891 .01975 L
.27019 .0245 L
.27156 .03118 L
.27402 .04717 L
.27921 .09495 L
.2841 .15207 L
.29344 .26771 L
.29818 .31668 L
.30087 .33859 L
.30216 .34728 L
.30338 .35432 L
.30454 .35988 L
.30579 .36466 L
.30635 .36634 L
.30694 .36783 L
.30749 .36896 L
.308 .36975 L
.30828 .3701 L
.30858 .37039 L
.30888 .3706 L
.30905 .37069 L
.30921 .37074 L
.3095 .37078 L
.30976 .37076 L
.31006 .37065 L
.31035 .37048 L
.31067 .37021 L
.311 .36982 L
.3116 .36888 L
.31224 .36752 L
.31295 .36561 L
.31421 .36114 L
.31541 .35565 L
.31766 .34223 L
.32008 .32358 L
.32273 .29887 L
.33259 .18173 L
.33715 .12531 L
.34208 .07219 L
.34479 .04892 L
Mistroke
.34598 .04039 L
.34728 .03232 L
.34843 .02639 L
.34966 .02133 L
.35034 .01913 L
.35096 .01751 L
.35159 .01624 L
.35187 .01579 L
.35217 .01539 L
.35247 .01509 L
.35275 .01489 L
.35301 .01477 L
.35329 .01472 L
.35359 .01475 L
.35388 .01486 L
.35419 .01507 L
.35436 .01523 L
.35452 .01541 L
.35513 .01632 L
.35548 .01701 L
.3558 .01775 L
.35701 .02147 L
.35804 .02584 L
.35918 .03188 L
.36148 .04798 L
.36394 .07087 L
.3662 .09647 L
.37127 .16804 L
.38091 .33603 L
.39019 .49078 L
.39498 .55056 L
.3974 .57301 L
.3987 .58265 L
.40007 .59088 L
.40124 .59627 L
.40185 .59851 L
.40251 .60044 L
.40282 .60118 L
.40312 .60178 L
.40341 .60227 L
.40367 .60264 L
.40392 .60292 L
.40419 .60313 L
.40446 .60327 L
.40475 .60332 L
.40491 .60331 L
.40509 .60326 L
.40541 .60308 L
.40572 .6028 L
.40601 .60243 L
Mistroke
.40635 .60188 L
.40666 .60126 L
.40736 .59948 L
.40797 .59749 L
.40862 .59488 L
.40981 .58896 L
.41211 .57312 L
.41464 .54953 L
.41975 .48471 L
.42955 .31903 L
.43898 .15677 L
.44145 .12088 L
.44413 .08679 L
.44645 .06212 L
.44901 .04059 L
.4502 .03272 L
.45149 .02582 L
.4527 .02082 L
.45381 .01754 L
.45442 .01626 L
.45472 .01579 L
.45499 .01542 L
.45515 .01525 L
.45532 .01508 L
.45562 .01487 L
.45579 .01479 L
.45597 .01474 L
.45612 .01472 L
.45629 .01472 L
.45646 .01476 L
.45663 .01482 L
.45694 .015 L
.45711 .01515 L
.45727 .01531 L
.45764 .01577 L
.45825 .01683 L
.4589 .01835 L
.4602 .0226 L
.4614 .02787 L
.4641 .04428 L
.46648 .06342 L
.469 .08767 L
.47822 .19798 L
.48335 .26118 L
.48803 .31092 L
.49036 .33113 L
.49289 .34882 L
.49404 .3553 L
.49527 .36097 L
.49632 .36482 L
Mistroke
.49748 .36797 L
.49808 .36915 L
.4984 .36965 L
.49874 .37008 L
.49906 .37039 L
.49936 .3706 L
.49965 .37073 L
.49993 .37078 L
.5002 .37077 L
.50049 .37068 L
.50074 .37054 L
.50101 .37033 L
.5013 .37003 L
.50161 .36963 L
.50218 .36869 L
.50283 .36725 L
.50354 .36527 L
.50482 .36058 L
.50724 .34807 L
.50951 .33214 L
.51203 .31037 L
.51712 .25564 L
.52686 .13451 L
.53133 .08427 L
.53387 .06032 L
.53623 .04192 L
.53858 .02797 L
.53989 .02224 L
.54109 .01839 L
.54174 .01684 L
.54235 .01579 L
.54266 .01538 L
.54301 .01504 L
.54319 .01491 L
.54337 .01481 L
.54355 .01475 L
.54371 .01472 L
.54403 .01474 L
.54432 .01484 L
.54449 .01494 L
.54465 .01506 L
.54499 .0154 L
.54529 .0158 L
.54561 .01633 L
.5462 .01756 L
.54678 .01911 L
.54739 .02114 L
.54851 .02578 L
.54983 .03293 L
.55104 .04095 L
Mistroke
.55366 .06324 L
.55615 .09009 L
.56544 .22957 L
.57534 .40593 L
.58025 .48472 L
.58266 .51787 L
.58486 .5442 L
.58697 .56528 L
.58927 .5833 L
.59047 .59048 L
.59159 .59576 L
.59219 .59806 L
.59276 .59984 L
.59342 .60145 L
.59371 .60199 L
.59402 .60248 L
.59433 .60284 L
.5946 .60309 L
.59488 .60325 L
.59515 .60331 L
.59545 .60329 L
.59574 .60318 L
.59605 .60294 L
.59622 .60277 L
.59638 .60257 L
.597 .60155 L
.59735 .60079 L
.59767 .59996 L
.59888 .59581 L
.59992 .59094 L
.60106 .58426 L
.60335 .56664 L
.60584 .54171 L
.6081 .51423 L
.61317 .43891 L
.62285 .26805 L
.63216 .11766 L
.63697 .06173 L
.6394 .04126 L
.64077 .0322 L
.64207 .02532 L
.64324 .02058 L
.64391 .01851 L
.64453 .01699 L
.64482 .01641 L
.6451 .01593 L
.64535 .01557 L
.64561 .01526 L
.6459 .015 L
.64617 .01483 L
Mistroke
.64646 .01473 L
.64677 .01472 L
.64694 .01475 L
.64711 .01482 L
.64728 .01491 L
.64743 .01502 L
.64773 .01528 L
.64804 .01566 L
.64868 .01673 L
.64939 .01839 L
.65065 .02249 L
.65183 .02766 L
.65422 .04173 L
.65673 .06136 L
.66121 .10646 L
.67045 .22014 L
.6756 .28122 L
.68028 .32665 L
.68262 .34411 L
.68385 .35167 L
.68515 .35836 L
.68629 .36307 L
.68689 .36512 L
.68754 .36698 L
.68814 .36836 L
.68868 .36936 L
.68894 .36974 L
.68923 .37009 L
.68948 .37034 L
.68975 .37055 L
.6899 .37064 L
.69007 .37071 L
.69037 .37078 L
.69053 .37078 L
.69071 .37076 L
.69088 .37071 L
.69104 .37064 L
.69134 .37046 L
.69151 .37031 L
.69166 .37016 L
.69225 .36939 L
.69278 .36845 L
.69335 .36713 L
.69452 .36358 L
.69579 .35843 L
.69715 .35142 L
.69961 .33506 L
.70448 .29062 L
.7096 .23143 L
.71885 .11665 L
Mistroke
.7215 .08744 L
.72401 .0633 L
.72644 .04377 L
.72751 .03661 L
.72869 .02983 L
.72976 .02471 L
.7309 .02035 L
.73153 .01846 L
.73211 .01707 L
.73269 .01599 L
.73297 .01558 L
.73324 .01527 L
.73352 .01501 L
.73383 .01482 L
.73414 .01473 L
.73431 .01472 L
.73446 .01473 L
.73473 .01481 L
.73502 .01497 L
.73532 .01524 L
.7356 .01556 L
.73625 .01663 L
.73684 .01797 L
.73752 .01995 L
.73817 .02226 L
.74052 .03423 L
.74171 .04236 L
.74301 .05288 L
.74748 .1006 L
.75219 .16762 L
.75725 .25296 L
.76725 .4302 L
.77225 .50611 L
.77468 .53673 L
.77688 .56004 L
.77919 .57943 L
.78025 .58648 L
.78136 .59262 L
.78194 .59523 L
.78256 .59768 L
.78314 .59954 L
.78366 .60092 L
.78428 .60215 L
.78462 .60264 L
.78478 .60282 L
.78495 .60298 L
.78524 .60319 L
.78552 .6033 L
.78582 .60331 L
.78598 .60328 L
Mistroke
.78614 .60321 L
.78643 .60303 L
.78673 .60273 L
.78702 .60235 L
.78728 .60192 L
.78792 .60054 L
.78853 .59882 L
.78973 .59417 L
.79104 .58733 L
.79337 .57056 L
.79553 .55024 L
.80008 .4937 L
.80508 .41503 L
.81486 .24079 L
.81937 .16554 L
.82428 .09644 L
.82695 .06664 L
.82942 .04468 L
.83178 .02917 L
.8331 .02292 L
.83367 .02076 L
.83429 .01877 L
.83486 .0173 L
.83548 .01609 L
.83582 .01558 L
.83613 .01522 L
.83644 .01496 L
.83673 .0148 L
.837 .01472 L
.83729 .01473 L
.83753 .01479 L
.8378 .01494 L
.83809 .01517 L
.8384 .01552 L
.83897 .01638 L
.83961 .01775 L
.84032 .01969 L
.84161 .02443 L
.84286 .03047 L
.84402 .03728 L
.84899 .07799 L
.8535 .12742 L
.86321 .24822 L
.86766 .29799 L
.87019 .32185 L
.87255 .34042 L
.87488 .35471 L
.87619 .36083 L
.87738 .36517 L
.87799 .36692 L
Mistroke
.87864 .36842 L
.87898 .36906 L
.87935 .36964 L
.87969 .37008 L
.88 .37039 L
.8803 .3706 L
.88062 .37074 L
.88094 .37078 L
.88112 .37077 L
.88129 .37073 L
.88159 .3706 L
.88187 .37041 L
.88219 .37011 L
.88249 .36974 L
.88307 .36881 L
.88361 .36767 L
.88484 .36412 L
.88605 .35942 L
.88734 .35303 L
.88967 .33812 L
.89181 .32102 L
.90144 .21431 L
.91071 .10096 L
.91549 .05473 L
.91816 .03559 L
.91931 .02909 L
.92057 .02329 L
.92176 .01917 L
.9224 .01747 L
.92301 .01625 L
.9233 .01579 L
.92357 .01543 L
.92382 .01516 L
.92409 .01495 L
.92438 .01479 L
.92464 .01472 L
.92493 .01473 L
.92525 .01483 L
.92556 .01503 L
.92573 .01517 L
.9259 .01535 L
.9265 .01621 L
.92684 .01686 L
.9272 .01768 L
.92785 .01948 L
.92913 .02429 L
.9303 .03009 L
.93272 .04649 L
.93495 .06658 L
.94 .12776 L
Mistroke
.94956 .28566 L
.95875 .44693 L
.96387 .52113 L
.9661 .54732 L
.96854 .57063 L
.97058 .58557 L
.97147 .59075 L
.97247 .59546 L
.9734 .59888 L
.97427 .60122 L
.97475 .60214 L
.97519 .60275 L
.97543 .60299 L
.97568 .60317 L
.97594 .60328 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`00033ooooo0ol0000^ooooo`Go0000;oooool3o`00037ooooo0ol0000^oooo
o`?o00002_ooool001Kooooo00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`0^oooo
o`04o`000?ooooooooooo`0002kooooo00Go0000ooooooooooooooooo`00000aooooo`03o`000?oo
oooooooo02cooooo00Go0000ooooooooooooooooo`000009ooooo`005_ooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0/ooooo`Go0000<Oooool00ol0003oooooooooo`07ooooo`005_ooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool2o`0002oooooo
00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`07ooooo`005_ooool01?l0003ooooo
ooooool0000`ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000boooo
o`03o`000?oooooooooo02gooooo00?o0000ooooool00000;_ooool4o`0000[ooooo000Fooooo`04
o`000?ooooooooooo`0002oooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;_ooool0
1Ol0003ooooooooooooooooo0000033ooooo0_l0000^ooooo`03o`000?oooooooooo00_ooooo000G
ooooo`;o0000<Oooool00ol0003oooooooooo`0^ooooo`?o0000<?ooool3o`0003;ooooo00?o0000
ooooooooool0;?ooool5o`0000Wooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo000Aoooooooo00003Ol00003ooooo`004Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo0?oooooo2Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`0Aooooo`;o003o5Oooool2o`00oa[ooooo0_l00?lEooooo`;o003o6Oooool2o`00oaKooooo0_l0
0?lIooooo`;o003o5Oooool3o`00oaWooooo0_l00?lEooooo`;o003o4oooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`0Aooooo`;o003o5Oooool3o`00oaSooooo00?o003o
ooooool00?l05Oooool2o`00oaWooooo00?o003oooooool00?l05Oooool2o`00oaWooooo0_l00?lE
ooooo`03o`00oooooooo003o01Sooooo0ol00?lEooooo`?o003o4_ooool00ol0003oooooooooo`01
ooooo`004Oooool2o`00017ooooo00?o003oooooool00?l05Oooool00ol00?ooooooo`00o`0Hoooo
o`03o`00oooooooo003o01Gooooo00?o003oooooool00?l06?ooool00ol00?ooooooo`00o`0Doooo
o`03o`00oooooooo003o01Wooooo00?o003oooooool00?l05?ooool00ol00?ooooooo`00o`0Hoooo
o`04o`00ooooooooooooo`00oaCooooo00?o003oooooool00?l04Oooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo013ooooo00Co003ooooooooooooo003o4oooool01?l00?ooooooooooool0
0?lHooooo`03o`00oooooooo003o01Cooooo00Co003ooooooooooooo003o6?ooool00ol00?oooooo
o`00o`0Dooooo`04o`00ooooooooooooo`00oaOooooo00Co003ooooooooooooo003o5?ooool00ol0
0?ooooooo`00o`0Hooooo`04o`00ooooooooooooo`00oaCooooo00?o003oooooool00?l04_ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0@ooooo`04o`00oooooooooooo
o`00oa?ooooo00Co003ooooooooooooo003o6?ooool01?l00?ooooooooooool00?lCooooo`04o`00
ooooooooooooo`00oaSooooo00?o003oooooool00?l05?ooool01?l00?ooooooooooool00?lGoooo
o`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5oooool01?l00?oooooooooo
ool00?lCooooo`04o`00ooooooooooooo`00oa;ooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool04?ooool01?l00?ooooooooooool00?lCooooo`04o`00ooooooooooooo`00
oaSooooo00Co003ooooooooooooo003o4oooool01?l00?ooooooooooool00?lGooooo`04o`00oooo
ooooooooo`00oaCooooo00Co003ooooooooooooo003o5oooool01?l00?ooooooooooool00?lDoooo
o`04o`00ooooooooooooo`00oaOooooo00Co003ooooooooooooo003o4oooool01?l00?oooooooooo
ool00?lBooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo013ooooo00Co
003ooooooooooooo003o4oooool01?l00?ooooooooooool00?lHooooo`04o`00ooooooooooooo`00
oa?ooooo00Co003ooooooooooooo003o5oooool01Ol00?oooooooooooooooooo003o01;ooooo00Go
003oooooooooooooooooo`00o`0Gooooo`05o`00ooooooooooooooooool00?l04_ooool01Ol00?oo
oooooooooooooooo003o01Oooooo00Co003ooooooooooooo003o4oooool01?l00?ooooooooooool0
0?lBooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00oooooo00Go003o
ooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l05_ooool01Ol00?oooooo
oooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Fooooo`05o`00oooooooooooo
ooooool00?l04_ooool01Ol00?oooooooooooooooooo003o01Oooooo00Go003ooooooooooooooooo
o`00o`0Booooo`05o`00ooooooooooooooooool00?l05_ooool01Ol00?oooooooooooooooooo003o
01?ooooo00Go003oooooooooooooooooo`00o`0Aooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00oooooo00Go003oooooooooooooooooo`00o`0Booooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooooooo003o01?ooooo00Go
003oooooooooooooooooo`00o`0Fooooo`05o`00ooooooooooooooooool00?l04_ooool01Ol00?oo
oooooooooooooooo003o01Oooooo00Go003oooooooooooooooooo`00o`0Booooo`05o`00oooooooo
ooooooooool00?l05_ooool01Ol00?oooooooooooooooooo003o01;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00004?oo
ool01Ol00?oooooooooooooooooo003o01;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Dooooo`05o`00ooooooooooooooooool00?l04_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`0Booooo`05o`00oooooooooooo
ooooool00?l05oooool01Ol00?oooooooooooooooooo003o01;ooooo00Go003ooooooooooooooooo
o`00o`0Fooooo`05o`00ooooooooooooooooool00?l04_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00kooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`0Booooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013o
oooo00Go003oooooooooooooooooo`00o`0Fooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04?ooool01Ol00?oooooooooooooooooo003o01Kooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03oooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01Cooooo00Go003oooooooooooooooooo`00o`0Booooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool03oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0?oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo01Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool03oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol0003oooooooooo`01ooooo`002?oo
ool5o`0000Cooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00oooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03ooo
ool00ol0003oooooooooo`01ooooo`000_ooool5o`0000?ooooo00?o0000ooooooooool01?ooool3
o`0000kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`?o00000oooool0
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00kooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0>ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003o
ooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool03_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000oooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo017ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0=ooooo`;o00000oooool0017ooooo00?o0000oooooooo
ool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo017ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool03_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00go
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool03Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0
000>ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00003_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo0_l00003ooooo`004Oooool00ol0003o
ooooooooo`0=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`0=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0=oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`01oooo
o`002_ooool2o`0000Gooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool03?ooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`oo
000000?o003oo`000?l000002?l000000ol00?oo0000o`000009o`000003o`00ool0003o000000So
000000?o003oo`000?l000003_l000000ol00?oo0000o`000008o`000003o`00ool0003o000000Wo
000000?o003oo`000?l000001ol000000ol00?oo0000o`00000?o`000003o`00ool0003o000000So
000000?o003oo`000?l000002Ol000000ol00?oo0000o`000007o`000003o`00ool0003o000000ko
000000?o003oo`000?l000002Ol000000ol00?oo0000o`000008o`000003o`00ool0003o000000So
000000?o003oo`000?l000003_l000000ol00?oo0000o`000008o`000003o`00ool0003o000000Wo
000000?o003oo`000?l000002?l000000ol00?oo0000o`00000=o`0000?ooooo0009ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool03?ooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03
o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`0<ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool03?oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`0<ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool03?ooool00ol0
003oooooooooo`01ooooo`004Oooool2o`0000gooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0;ooooo`;o00000oooool0017ooooo00?o0000ooooooooool02oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool02oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool02oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00cooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
2oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00_ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000<ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo
00_ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00_ooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00_ooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0;oooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o00003?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00[ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0;ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02ooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02oooool00ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo
00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo
00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol0003ooooo
ooooo`01ooooo`002_ooool00ol0003oooooooooo`04ooooo`?o00002_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Wooooo0ol00003ooooo`002oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0:
ooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool0
0ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool02_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o0000
ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo00[ooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00[ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0:ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0
3_ooool01Ol00?oooooooooooooooooo003o013ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l04?ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0>oooo
o`05o`00ooooooooooooooooool00?l04?ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool03_ooool01Ol0
0?oooooooooooooooooo003o013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0>
ooooo`05o`00ooooooooooooooooool00?l04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooo
ooooooooooooool00?l04?ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o00002oooool00ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l0
4?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00kooooo00Go003ooooooooooooo
ooooo`00o`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03_ooool01Ol00?oo
oooooooooooooooo003o013ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00kooooo00Go003oooooooooooooooooo`00o`0@ooooo`03o`00oooooooo
oooo00Wooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo
00kooooo00Go003oooooooooooooooooo`00o`0@ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool03_ooool01Ol00?oooooooooooooooooo003o013ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l04?ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00kooooo00Go003oooooooooooooooooo`00o`0Aooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool03_ooool01Ol00?oooooooooooooooooo003o
013ooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`0:ooooo`03o`00oooooooooooo00kooooo00Go003oooooooooooooooooo`00o`0@oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool03_ooool01Ol00?oooooooooooooooooo
003o013ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0?ooooo`05o`00oooooooo
ooooooooool00?l04?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00kooooo00Go
003oooooooooooooooooo`00o`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
3_ooool01Ol00?oooooooooooooooooo003o013ooooo00?o003oooooooooool02_ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00kooooo
00Go003oooooooooooooooooo`00o`0@ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool03_ooool01?l00?ooooooooooool00?lAooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool03oooool01Ol00?oooooooooooooooooo003o013ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0?ooooo`04o`00ooooooooooooo`00oa7ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l04?ooool00ol00?oooooo
ooooo`0:ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o
003oooooooooool03_ooool01Ol00?oooooooooooooooooo003o013ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0?ooooo`04o`00ooooooooooooo`00oa7ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0?ooooo`04o`00ooooooooooooo`00oa7ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0?ooooo`04o`00ooooooooooooo`00oa7ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l04?oo
ool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00[ooooo00?o003oooooooooool03oooool00ol00?ooooooo`00o`0Aooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool04?ooool00ol00?ooooooo`00o`0Aooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool03oooool01?l00?ooooooooooool00?lAooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool03oooool01?l00?ooooooooooool00?lAooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool03oooool00ol00?ooooooo`00o`0Aooooo`03o`00
oooooooooooo00[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02_oo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo003o017ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo003o017ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo003o017ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo003o01;ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo003o017ooooo00?o003oooooooooool02_oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooo
oooo00oooooo0ol00?lAooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04?ooool3
o`00oa7ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0@ooooo`;o003o4_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo013ooooo0_l00?lBooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool03oooool3o`00oa;ooooo00?o003oooooooooool02Oooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0000[ooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04?ooool2o`00
oa;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0@ooooo`;o003o4_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`08ooooo`;o00000oooool0017ooooo00?o0000ooooooooool02Oooool00ol00?oo
ooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0Tooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`09ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Wooooo
00?o003oooooooooool09Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02Gooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool09?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02Gooooo
00?o003oooooooooool02Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`09ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool02Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00Wooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Uoooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02Cooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Wooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l0000:ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
9Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo02Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool09Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0Vooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool09_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool02Oooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo02Go
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Wo
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02Oooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool09Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0Vooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool09Oooool00ol00?oooooo
ooooo`09ooooo`03o`000?oooooooooo007ooooo000:ooooo`?o00001?ooool00ol0003ooooooooo
o`09ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool09_ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool00Oooool000_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool09_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Kooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Sooooo00?o0000
ooooooooool00Oooool000Sooooo1Ol00004ooooo`?o00002Oooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo02Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`06oooo
o`?o00000oooool000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`09oooo
o`03o`00oooooooooooo02Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo02Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool00Oooool000Wooooo00?o0000ooooool0
00001Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo02Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool09_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Kooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Sooooo00?o0000oooooooo
ool00Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0
9_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
9_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0
2?ooool00ol0003oooooooooo`01ooooo`002oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Wooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo02Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Vooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo02Kooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`09ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool09oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
02Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool09oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Wooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool09_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`01ooooo`004Oooool2o`0000Wooooo00?o003oooooooooool09oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Wooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool09_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool01oooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool09oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0Xooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo02Oooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Oooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00Sooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0Woooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo02Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Xoooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Sooooo00?o003ooooooooo
ool09oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02Oooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Oooooo00?o003ooooooooo
ool02?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`00
oooooooooooo02Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Wooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo02Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Wooooo`03o`00
oooooooooooo00Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool09ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09ooo
ool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00Sooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo02Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo02Oooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`00
00Wooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
02Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
02Sooooo00?o003oooooooooool01_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Oo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02So
oooo00?o003oooooooooool01oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`08ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Wooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0:?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Xooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool02?ooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool09oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Sooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool0:?ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Y
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool01oooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo02Wooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool0:Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Wooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo00Oooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0Yooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo02Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Yooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`07ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o00002?ooool00ol00?ooooooooooo`0Yooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo02Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Yooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`06ooooo`;o0000
0oooool0017ooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0Yooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo02[ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Yooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`07ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0:Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0:Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool01oooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo
02Wooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
02[ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo
00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01oooool00ol00?oo
ooooooooo`0Yooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Zooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0:Oooool00ol00?oo
ooooooooo`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Oooooo
00?o003oooooooooool0:Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Wooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool0:_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Wooooo
00?o003oooooooooool01oooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o
0000ooooooooool01oooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0:Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02[ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0:oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo0008
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`06ooooo`03o`00oooo
oooooooo02_ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Zooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo02[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0[ooooo`03o`00oooo
oooooooo00Kooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`00
0004ooooo`?o00001_ooool00ol00?ooooooooooo`0[ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool0:_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02[ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0:oooool00ol00?ooooooooooo`04ooooo`?o00000oooool000Sooooo1?l00005
ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Z
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`01
ooooo`002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o003ooooo
ooooool0:oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02_ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool0:_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02_ooooo00?o003ooooo
ooooool01_ooool00ol0003oooooooooo`01ooooo`002Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo02_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0[ooooo`05
o`00ooooooooooooooooool00?l0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
02_ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`01ooooo`002_ooool2o`0000Go
oooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0[ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02_o
oooo00Go003oooooooooooooooooo`00o`0]ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0:oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Kooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo02_ooooo00Go003oooooooooooooooooo`00o`0^ooooo`05o`00oooooooooooo
ooooool00?l0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02_ooooo00?o003o
ooooooooool01_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06oooo
o`03o`00oooooooooooo02cooooo00Co003ooooooooooooo003o;_ooool01Ol00?oooooooooooooo
oooo003o02kooooo00Go003oooooooooooooooooo`00o`0]ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0:oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool0;?ooool01?l00?oooooooooo
ool00?l^ooooo`05o`00ooooooooooooooooool00?l0;_ooool01Ol00?oooooooooooooooooo003o
02kooooo00Go003oooooooooooooooooo`00o`0]ooooo`03o`00oooooooooooo00Kooooo00?o0000
ooooooooool00Oooool0017ooooo0_l00007ooooo`03o`00oooooooooooo02cooooo00Co003ooooo
oooooooo003o;_ooool01Ol00?oooooooooooooooooo003o02kooooo00Go003ooooooooooooooooo
o`00o`0^ooooo`05o`00ooooooooooooooooool00?l0;Oooool00ol00?ooooooooooo`05ooooo`;o
00000oooool0017ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0/ooooo`04o`00
ooooooooooooo`00obkooooo00Go003oooooooooooooooooo`00o`0^ooooo`05o`00oooooooooooo
ooooool00?l0;_ooool01Ol00?oooooooooooooooooo003o02gooooo00?o003oooooooooool01_oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooo
oooo02cooooo00Co003ooooooooooooo003o;oooool01?l00?ooooooooooool00?l^ooooo`05o`00
ooooooooooooooooool00?l0;_ooool01?l00?ooooooooooool00?l_ooooo`03o`00oooooooooooo
00Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool00ol00?oo
ooooooooo`0]ooooo`04o`00ooooooooooooo`00oboooooo00Co003ooooooooooooo003o;_ooool0
1Ol00?oooooooooooooooooo003o02kooooo00Co003ooooooooooooo003o;oooool00ol00?oooooo
ooooo`05ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Gooooo00?o
003oooooooooool0;Oooool01?l00?ooooooooooool00?l_ooooo`04o`00ooooooooooooo`00oboo
oooo00?o003oooooool00?l0;oooool01?l00?ooooooooooool00?l_ooooo`03o`00oooooooooooo
00Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool00ol00?oo
ooooooooo`0]ooooo`04o`00ooooooooooooo`00oboooooo00?o003oooooool00?l0<?ooool00ol0
0?ooooooo`00o`0`ooooo`03o`00oooooooo003o02oooooo00?o003oooooooooool01Oooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo02ko
oooo0_l00?l`ooooo`03o`00oooooooo003o033ooooo00?o003oooooool00?l0<?ooool2o`00oc7o
oooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`04ooooo`03o`00oooooooooooo02oooooo0_l00?laooooo`;o003o<?ooool3o`00oc3ooooo
0_l00?laooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo0_l0
0005ooooo`03o`00oooooooooooo02oooooo0_l00?laooooo`03o`00oooooooooooo033ooooo00?o
003oooooooooool0;oooool2o`00oc7ooooo00?o003oooooooooool00oooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo0?oooooo2Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`01ooooo`004Oooooooo`0000go00000oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.478464, -4.17447, \
0.0197116, 0.0645854}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CTFT of infinite-length x(t)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X[f_] = 
        FourierTransform[x[t], t, 
            f]\  /. {\[Delta][b_\ a_ + f_\ a_] \[Rule] \[Delta][b + f]/
                a, \[Delta][\ a_ + f_\ a_] \[Rule] \[Delta][1 + f]/
                a};\)\), "\[IndentingNewLine]", 
    \(X[f]\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", 
          RowBox[{
            InterpretationBox["\[Delta]",
              DiracDelta,
              Editable->False,
              Selectable->False], "(", \(f - 2\), ")"}]}], "+", 
        RowBox[{
          InterpretationBox["\[Delta]",
            DiracDelta,
            Editable->False,
            Selectable->False], "(", \(f - 1\), ")"}], "+", 
        RowBox[{
          InterpretationBox["\[Delta]",
            DiracDelta,
            Editable->False,
            Selectable->False], "(", "f", ")"}], "+", 
        RowBox[{
          InterpretationBox["\[Delta]",
            DiracDelta,
            Editable->False,
            Selectable->False], "(", \(f + 1\), ")"}], "+", 
        RowBox[{"2", " ", 
          RowBox[{
            InterpretationBox["\[Delta]",
              DiracDelta,
              Editable->False,
              Selectable->False], "(", \(f + 2\), ")"}]}]}], 
      TraditionalForm]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gX = 
        Plot[Evaluate[PlotConvert[X[f],  .04]], {f, \(-2.5\) fs, 2.5  fs}, 
          PlotStyle \[Rule] {Blue, Thickness[ .005]}, \ 
          PlotPoints \[Rule] 1000, \ 
          PlotRange \[Rule] {\(- .02\), 3.12}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0634921 0.00393652 0.196826 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.24603 -0.0125 -6 -9 ]
[.24603 -0.0125 6 0 ]
[.37302 -0.0125 -6 -9 ]
[.37302 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.62698 -0.0125 -3 -9 ]
[.62698 -0.0125 3 0 ]
[.75397 -0.0125 -3 -9 ]
[.75397 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-6)] .11905 -0.0125 0 1 Mshowa
.24603 0 m
.24603 .00625 L
s
[(-4)] .24603 -0.0125 0 1 Mshowa
.37302 0 m
.37302 .00625 L
s
[(-2)] .37302 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.62698 0 m
.62698 .00625 L
s
[(2)] .62698 -0.0125 0 1 Mshowa
.75397 0 m
.75397 .00625 L
s
[(4)] .75397 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(6)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.15079 0 m
.15079 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.05556 0 m
.05556 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.24603 .61178 m
.24603 .61803 L
s
.37302 .61178 m
.37302 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.62698 .61178 m
.62698 .61803 L
s
.75397 .61178 m
.75397 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.15079 .61428 m
.15079 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.05556 .61428 m
.05556 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.02381 .00394 m
.02474 .00394 L
.02575 .00394 L
.0267 .00394 L
.02761 .00394 L
.02859 .00394 L
.02952 .00394 L
.03052 .00394 L
.03148 .00394 L
.0324 .00394 L
.03338 .00394 L
.03433 .00394 L
.03524 .00394 L
.03621 .00394 L
.03714 .00394 L
.03813 .00394 L
.03908 .00394 L
.04 .00394 L
.04098 .00394 L
.04192 .00394 L
.04292 .00394 L
.04388 .00394 L
.0448 .00394 L
.04579 .00394 L
.04674 .00394 L
.04765 .00394 L
.04862 .00394 L
.04956 .00394 L
.05055 .00394 L
.05151 .00394 L
.05243 .00394 L
.05341 .00394 L
.05435 .00394 L
.05526 .00394 L
.05622 .00394 L
.05715 .00394 L
.05814 .00394 L
.05909 .00394 L
.06001 .00394 L
.06098 .00394 L
.06192 .00394 L
.06292 .00394 L
.06388 .00394 L
.0648 .00394 L
.06579 .00394 L
.06673 .00394 L
.06764 .00394 L
.06861 .00394 L
.06954 .00394 L
.07054 .00394 L
Mistroke
.07149 .00394 L
.07241 .00394 L
.07339 .00394 L
.07433 .00394 L
.07533 .00394 L
.07629 .00394 L
.07722 .00394 L
.07821 .00394 L
.07916 .00394 L
.08007 .00394 L
.08104 .00394 L
.08198 .00394 L
.08297 .00394 L
.08393 .00394 L
.08485 .00394 L
.08584 .00394 L
.08678 .00394 L
.08769 .00394 L
.08866 .00394 L
.08959 .00394 L
.09058 .00394 L
.09153 .00394 L
.09245 .00394 L
.09342 .00394 L
.09436 .00394 L
.09536 .00394 L
.09632 .00394 L
.09725 .00394 L
.09823 .00394 L
.09918 .00394 L
.10009 .00394 L
.10106 .00394 L
.10199 .00394 L
.10299 .00394 L
.10394 .00394 L
.10486 .00394 L
.10584 .00394 L
.10678 .00394 L
.10769 .00394 L
.10866 .00394 L
.10958 .00394 L
.11057 .00394 L
.11152 .00394 L
.11244 .00394 L
.11341 .00394 L
.11435 .00394 L
.11535 .00394 L
.1163 .00394 L
.11723 .00394 L
.11821 .00394 L
Mistroke
.11916 .00394 L
.12007 .00394 L
.12103 .00394 L
.12197 .00394 L
.12296 .00394 L
.12391 .00394 L
.12483 .00394 L
.12581 .00394 L
.12675 .00394 L
.12775 .00394 L
.12871 .00394 L
.12964 .00394 L
.13062 .00394 L
.13157 .00394 L
.13248 .00394 L
.13345 .00394 L
.13439 .00394 L
.13538 .00394 L
.13634 .00394 L
.13726 .00394 L
.13824 .00394 L
.13919 .00394 L
.14009 .00394 L
.14106 .00394 L
.14199 .00394 L
.14298 .00394 L
.14393 .00394 L
.14485 .00394 L
.14582 .00394 L
.14676 .00394 L
.14776 .00394 L
.14872 .00394 L
.14964 .00394 L
.15063 .00394 L
.15158 .00394 L
.15249 .00394 L
.15346 .00394 L
.15439 .00394 L
.15538 .00394 L
.15634 .00394 L
.15726 .00394 L
.15823 .00394 L
.15918 .00394 L
.16018 .00394 L
.16114 .00394 L
.16207 .00394 L
.16306 .00394 L
.16401 .00394 L
.16492 .00394 L
.16589 .00394 L
Mistroke
.16683 .00394 L
.16782 .00394 L
.16878 .00394 L
.16971 .00394 L
.17069 .00394 L
.17163 .00394 L
.17254 .00394 L
.17351 .00394 L
.17444 .00394 L
.17543 .00394 L
.17638 .00394 L
.1773 .00394 L
.17828 .00394 L
.17922 .00394 L
.18022 .00394 L
.18118 .00394 L
.1821 .00394 L
.18309 .00394 L
.18404 .00394 L
.18495 .00394 L
.18592 .00394 L
.18685 .00394 L
.18785 .00394 L
.1888 .00394 L
.18972 .00394 L
.1907 .00394 L
.19165 .00394 L
.19255 .00394 L
.19352 .00394 L
.19445 .00394 L
.19544 .00394 L
.19639 .00394 L
.1973 .00394 L
.19828 .00394 L
.19922 .00394 L
.20021 .00394 L
.20117 .00394 L
.2021 .00394 L
.20308 .00394 L
.20403 .00394 L
.20494 .00394 L
.2059 .00394 L
.20684 .00394 L
.20783 .00394 L
.20878 .00394 L
.2097 .00394 L
.21068 .00394 L
.21162 .00394 L
.21262 .00394 L
.21358 .00394 L
Mistroke
.21451 .00394 L
.2155 .00394 L
.21645 .00394 L
.21736 .00394 L
.21833 .00394 L
.21927 .00394 L
.22026 .00394 L
.22122 .00394 L
.22214 .00394 L
.22312 .00394 L
.22407 .00394 L
.22497 .00394 L
.22594 .00394 L
.22687 .00394 L
.22786 .00394 L
.22881 .00394 L
.22973 .00394 L
.23071 .00394 L
.23164 .00394 L
.23264 .00394 L
.2336 .00394 L
.23453 .00394 L
.23551 .00394 L
.23646 .00394 L
.23737 .00394 L
.23834 .00394 L
.23928 .00394 L
.24027 .00394 L
.24122 .00394 L
.24214 .00394 L
.24312 .00394 L
.24406 .00394 L
.24497 .00394 L
.24594 .00394 L
.24686 .00394 L
.24785 .00394 L
.2488 .00394 L
.24972 .00394 L
.25069 .00394 L
.25163 .00394 L
.25262 .00394 L
.25358 .00394 L
.25451 .00394 L
.25549 .00394 L
.25643 .00394 L
.25734 .00394 L
.25831 .00394 L
.25924 .00394 L
.26023 .00394 L
.26119 .00394 L
Mistroke
.2621 .00394 L
.26308 .00394 L
.26402 .00394 L
.26502 .00394 L
.26598 .00394 L
.26691 .00394 L
.26789 .00394 L
.26884 .00394 L
.26976 .00394 L
.27073 .00394 L
.27166 .00394 L
.27266 .00394 L
.27361 .00394 L
.27453 .00394 L
.27551 .00394 L
.27646 .00394 L
.27736 .00394 L
.27833 .00394 L
.27926 .00394 L
.28025 .00394 L
.2812 .00394 L
.28212 .00394 L
.28309 .00394 L
.28403 .00394 L
.28503 .00394 L
.28599 .00394 L
.28691 .00394 L
.28789 .00394 L
.28884 .00394 L
.28975 .00394 L
.29072 .00394 L
.29165 .00394 L
.29265 .00394 L
.2936 .00394 L
.29452 .00394 L
.2955 .00394 L
.29644 .00394 L
.29744 .00394 L
.2984 .00394 L
.29933 .00394 L
.30032 .00394 L
.30127 .00394 L
.30218 .00394 L
.30315 .00394 L
.30409 .00394 L
.30509 .00394 L
.30604 .00394 L
.30697 .00394 L
.30795 .00394 L
.30889 .00394 L
Mistroke
.3098 .00394 L
.31077 .00394 L
.3117 .00394 L
.31269 .00394 L
.31364 .00394 L
.31456 .00394 L
.31554 .00394 L
.31647 .00394 L
.31747 .00394 L
.31844 .00394 L
.31936 .00394 L
.32035 .00394 L
.32129 .00394 L
.3222 .00394 L
.32318 .00394 L
.32411 .00394 L
.3251 .00394 L
.32606 .00394 L
.32698 .00394 L
.32796 .00394 L
.3289 .00394 L
.32981 .00394 L
.33077 .00394 L
.3317 .00394 L
.33269 .00394 L
.33364 .00394 L
.33456 .00394 L
.33553 .00394 L
.33647 .00394 L
.33746 .00394 L
.33842 .00394 L
.33935 .00394 L
.34033 .00394 L
.34128 .00394 L
.34218 .00394 L
.34315 .00394 L
.34409 .00394 L
.34508 .00394 L
.34603 .00394 L
.34695 .00394 L
.34793 .00394 L
.34887 .00394 L
.34987 .00394 L
.35083 .00394 L
.35176 .00394 L
.35274 .00394 L
.35369 .00394 L
.3546 .00394 L
.35558 .00394 L
.35651 .00394 L
Mistroke
.35751 .00394 L
.35846 .00394 L
.35939 .00394 L
.36037 .00394 L
.36131 .00394 L
.36222 .00394 L
.36318 .00394 L
.36411 .00394 L
.3651 .00394 L
.36606 .00394 L
.36697 .00394 L
.36795 .00394 L
.36889 .00394 L
.36988 .00394 L
.37038 .00394 L
.37084 .00394 L
.37129 .00394 L
.37152 .00394 L
.37158 .00394 L
.37165 .00394 L
.37168 .00394 L
.37171 .00394 L
.37174 .00394 L
.37177 .39759 L
.37179 .39759 L
.3718 .39759 L
.37183 .39759 L
.3719 .39759 L
.37202 .39759 L
.37224 .39759 L
.37275 .39759 L
.37366 .39759 L
.3739 .39759 L
.37413 .39759 L
.37419 .39759 L
.37423 .39759 L
.37426 .39759 L
.37427 .39759 L
.37429 .00394 L
.37431 .00394 L
.37433 .00394 L
.3744 .00394 L
.37464 .00394 L
.37559 .00394 L
.37651 .00394 L
.37748 .00394 L
.37842 .00394 L
.37942 .00394 L
.38038 .00394 L
.38131 .00394 L
Mistroke
.3823 .00394 L
.38324 .00394 L
.38416 .00394 L
.38513 .00394 L
.38606 .00394 L
.38705 .00394 L
.38801 .00394 L
.38893 .00394 L
.38991 .00394 L
.39086 .00394 L
.39176 .00394 L
.39273 .00394 L
.39366 .00394 L
.39465 .00394 L
.3956 .00394 L
.39651 .00394 L
.39749 .00394 L
.39843 .00394 L
.39942 .00394 L
.40038 .00394 L
.40131 .00394 L
.40229 .00394 L
.40324 .00394 L
.40415 .00394 L
.40511 .00394 L
.40605 .00394 L
.40704 .00394 L
.40799 .00394 L
.40891 .00394 L
.40989 .00394 L
.41083 .00394 L
.41183 .00394 L
.4128 .00394 L
.41372 .00394 L
.41471 .00394 L
.41566 .00394 L
.41657 .00394 L
.41754 .00394 L
.41848 .00394 L
.41948 .00394 L
.42043 .00394 L
.42136 .00394 L
.42234 .00394 L
.42328 .00394 L
.42419 .00394 L
.42516 .00394 L
.42609 .00394 L
.42708 .00394 L
.42803 .00394 L
.42895 .00394 L
Mistroke
.42992 .00394 L
.43086 .00394 L
.43186 .00394 L
.43282 .00394 L
.43375 .00394 L
.43421 .00394 L
.43473 .00394 L
.43497 .00394 L
.4351 .00394 L
.43516 .00394 L
.43519 .00394 L
.43522 .00394 L
.43525 .20076 L
.43528 .20076 L
.43533 .20076 L
.43546 .20076 L
.43568 .20076 L
.43661 .20076 L
.43708 .20076 L
.43733 .20076 L
.43746 .20076 L
.43759 .20076 L
.43765 .20076 L
.43772 .20076 L
.43775 .20076 L
.43777 .20076 L
.43779 .00394 L
.43782 .00394 L
.43785 .00394 L
.43809 .00394 L
.43854 .00394 L
.43954 .00394 L
.44049 .00394 L
.44141 .00394 L
.44238 .00394 L
.44332 .00394 L
.44432 .00394 L
.44529 .00394 L
.44621 .00394 L
.4472 .00394 L
.44815 .00394 L
.44906 .00394 L
.45003 .00394 L
.45097 .00394 L
.45196 .00394 L
.45292 .00394 L
.45384 .00394 L
.45482 .00394 L
.45576 .00394 L
.45667 .00394 L
Mistroke
.45764 .00394 L
.45857 .00394 L
.45956 .00394 L
.46051 .00394 L
.46142 .00394 L
.4624 .00394 L
.46334 .00394 L
.46433 .00394 L
.4653 .00394 L
.46622 .00394 L
.4672 .00394 L
.46815 .00394 L
.46906 .00394 L
.47003 .00394 L
.47096 .00394 L
.47196 .00394 L
.47291 .00394 L
.47383 .00394 L
.47481 .00394 L
.47575 .00394 L
.47675 .00394 L
.47771 .00394 L
.47864 .00394 L
.47963 .00394 L
.48058 .00394 L
.48149 .00394 L
.48247 .00394 L
.4834 .00394 L
.4844 .00394 L
.48536 .00394 L
.48628 .00394 L
.48726 .00394 L
.48821 .00394 L
.48911 .00394 L
.49008 .00394 L
.49101 .00394 L
.492 .00394 L
.49296 .00394 L
.49387 .00394 L
.49485 .00394 L
.49579 .00394 L
.49679 .00394 L
.49775 .00394 L
.49819 .00394 L
.49844 .00394 L
.49856 .00394 L
.49862 .00394 L
.49867 .00394 L
.4987 .00394 L
.49873 .20076 L
Mistroke
.49876 .20076 L
.49879 .20076 L
.49891 .20076 L
.49915 .20076 L
.49966 .20076 L
.50016 .20076 L
.50063 .20076 L
.50086 .20076 L
.50108 .20076 L
.50119 .20076 L
.50122 .20076 L
.50125 .20076 L
.50128 .00394 L
.50131 .00394 L
.50155 .00394 L
.50254 .00394 L
.50348 .00394 L
.50439 .00394 L
.50536 .00394 L
.50629 .00394 L
.50728 .00394 L
.50824 .00394 L
.50916 .00394 L
.51014 .00394 L
.51108 .00394 L
.51208 .00394 L
.51304 .00394 L
.51397 .00394 L
.51495 .00394 L
.5159 .00394 L
.51682 .00394 L
.51779 .00394 L
.51872 .00394 L
.51972 .00394 L
.52068 .00394 L
.5216 .00394 L
.52258 .00394 L
.52352 .00394 L
.52443 .00394 L
.5254 .00394 L
.52633 .00394 L
.52732 .00394 L
.52827 .00394 L
.52918 .00394 L
.53016 .00394 L
.5311 .00394 L
.5321 .00394 L
.53306 .00394 L
.53398 .00394 L
.53497 .00394 L
Mistroke
.53591 .00394 L
.53683 .00394 L
.5378 .00394 L
.53873 .00394 L
.53972 .00394 L
.54068 .00394 L
.5416 .00394 L
.54258 .00394 L
.54352 .00394 L
.54442 .00394 L
.54539 .00394 L
.54632 .00394 L
.5473 .00394 L
.54825 .00394 L
.54917 .00394 L
.55014 .00394 L
.55108 .00394 L
.55207 .00394 L
.55303 .00394 L
.55396 .00394 L
.55494 .00394 L
.55588 .00394 L
.55679 .00394 L
.55776 .00394 L
.55869 .00394 L
.55968 .00394 L
.56064 .00394 L
.56155 .00394 L
.5618 .00394 L
.56203 .00394 L
.56209 .00394 L
.56215 .00394 L
.56219 .00394 L
.56221 .00394 L
.56223 .20076 L
.56226 .20076 L
.56229 .20076 L
.56253 .20076 L
.56352 .20076 L
.56402 .20076 L
.56424 .20076 L
.56448 .20076 L
.56459 .20076 L
.56465 .20076 L
.56468 .20076 L
.56471 .20076 L
.56474 .20076 L
.56477 .00394 L
.5648 .00394 L
.56483 .00394 L
Mistroke
.56493 .00394 L
.5654 .00394 L
.56636 .00394 L
.56729 .00394 L
.56827 .00394 L
.56922 .00394 L
.57013 .00394 L
.5711 .00394 L
.57203 .00394 L
.57302 .00394 L
.57398 .00394 L
.5749 .00394 L
.57587 .00394 L
.57682 .00394 L
.57782 .00394 L
.57878 .00394 L
.57971 .00394 L
.58069 .00394 L
.58164 .00394 L
.58256 .00394 L
.58353 .00394 L
.58447 .00394 L
.58546 .00394 L
.58642 .00394 L
.58734 .00394 L
.58832 .00394 L
.58927 .00394 L
.59017 .00394 L
.59114 .00394 L
.59207 .00394 L
.59306 .00394 L
.59402 .00394 L
.59493 .00394 L
.59591 .00394 L
.59685 .00394 L
.59785 .00394 L
.59881 .00394 L
.59973 .00394 L
.60072 .00394 L
.60167 .00394 L
.60258 .00394 L
.60355 .00394 L
.60448 .00394 L
.60547 .00394 L
.60643 .00394 L
.60735 .00394 L
.60833 .00394 L
.60927 .00394 L
.61018 .00394 L
.61114 .00394 L
Mistroke
.61207 .00394 L
.61306 .00394 L
.61401 .00394 L
.61493 .00394 L
.6159 .00394 L
.61684 .00394 L
.61783 .00394 L
.61879 .00394 L
.61972 .00394 L
.6207 .00394 L
.62165 .00394 L
.62255 .00394 L
.62352 .00394 L
.62446 .00394 L
.62493 .00394 L
.62518 .00394 L
.62545 .00394 L
.62558 .00394 L
.62565 .00394 L
.62567 .00394 L
.62571 .00394 L
.62573 .39759 L
.62576 .39759 L
.62582 .39759 L
.62594 .39759 L
.6264 .39759 L
.62734 .39759 L
.62758 .39759 L
.62785 .39759 L
.62797 .39759 L
.6281 .39759 L
.62815 .39759 L
.62821 .39759 L
.62822 .39759 L
.62824 .39759 L
.62827 .00394 L
.6283 .00394 L
.62833 .00394 L
.62931 .00394 L
.63024 .00394 L
.63124 .00394 L
.6322 .00394 L
.63313 .00394 L
.63411 .00394 L
.63506 .00394 L
.63597 .00394 L
.63694 .00394 L
.63787 .00394 L
.63886 .00394 L
.63982 .00394 L
Mistroke
.64074 .00394 L
.64172 .00394 L
.64266 .00394 L
.64366 .00394 L
.64462 .00394 L
.64555 .00394 L
.64654 .00394 L
.64749 .00394 L
.6484 .00394 L
.64938 .00394 L
.65031 .00394 L
.65131 .00394 L
.65227 .00394 L
.65319 .00394 L
.65417 .00394 L
.65512 .00394 L
.65603 .00394 L
.65699 .00394 L
.65792 .00394 L
.65891 .00394 L
.65987 .00394 L
.66079 .00394 L
.66176 .00394 L
.6627 .00394 L
.6637 .00394 L
.66466 .00394 L
.66559 .00394 L
.66657 .00394 L
.66752 .00394 L
.66843 .00394 L
.6694 .00394 L
.67034 .00394 L
.67133 .00394 L
.67229 .00394 L
.67321 .00394 L
.67419 .00394 L
.67513 .00394 L
.67604 .00394 L
.67701 .00394 L
.67793 .00394 L
.67892 .00394 L
.67987 .00394 L
.68079 .00394 L
.68176 .00394 L
.6827 .00394 L
.6837 .00394 L
.68466 .00394 L
.68558 .00394 L
.68657 .00394 L
.68751 .00394 L
Mistroke
.68842 .00394 L
.68939 .00394 L
.69032 .00394 L
.69131 .00394 L
.69227 .00394 L
.69319 .00394 L
.69417 .00394 L
.69511 .00394 L
.69611 .00394 L
.69707 .00394 L
.698 .00394 L
.69898 .00394 L
.69993 .00394 L
.70085 .00394 L
.70182 .00394 L
.70275 .00394 L
.70375 .00394 L
.70471 .00394 L
.70563 .00394 L
.70661 .00394 L
.70755 .00394 L
.70846 .00394 L
.70943 .00394 L
.71036 .00394 L
.71135 .00394 L
.7123 .00394 L
.71322 .00394 L
.71419 .00394 L
.71513 .00394 L
.71613 .00394 L
.71709 .00394 L
.71802 .00394 L
.719 .00394 L
.71995 .00394 L
.72086 .00394 L
.72183 .00394 L
.72276 .00394 L
.72376 .00394 L
.72471 .00394 L
.72563 .00394 L
.72661 .00394 L
.72755 .00394 L
.72846 .00394 L
.72942 .00394 L
.73035 .00394 L
.73134 .00394 L
.73229 .00394 L
.73321 .00394 L
.73418 .00394 L
.73512 .00394 L
Mistroke
.73611 .00394 L
.73707 .00394 L
.738 .00394 L
.73898 .00394 L
.73992 .00394 L
.74083 .00394 L
.7418 .00394 L
.74273 .00394 L
.74372 .00394 L
.74468 .00394 L
.74559 .00394 L
.74657 .00394 L
.74751 .00394 L
.74851 .00394 L
.74947 .00394 L
.7504 .00394 L
.75139 .00394 L
.75233 .00394 L
.75325 .00394 L
.75422 .00394 L
.75515 .00394 L
.75615 .00394 L
.7571 .00394 L
.75803 .00394 L
.75901 .00394 L
.75995 .00394 L
.76086 .00394 L
.76182 .00394 L
.76275 .00394 L
.76374 .00394 L
.76469 .00394 L
.76561 .00394 L
.76658 .00394 L
.76752 .00394 L
.76852 .00394 L
.76948 .00394 L
.7704 .00394 L
.77139 .00394 L
.77233 .00394 L
.77324 .00394 L
.77421 .00394 L
.77515 .00394 L
.77614 .00394 L
.77709 .00394 L
.77801 .00394 L
.77899 .00394 L
.77993 .00394 L
.78093 .00394 L
.7819 .00394 L
.78283 .00394 L
Mistroke
.78381 .00394 L
.78476 .00394 L
.78568 .00394 L
.78665 .00394 L
.78758 .00394 L
.78858 .00394 L
.78954 .00394 L
.79046 .00394 L
.79144 .00394 L
.79239 .00394 L
.7933 .00394 L
.79426 .00394 L
.79519 .00394 L
.79618 .00394 L
.79714 .00394 L
.79805 .00394 L
.79903 .00394 L
.79997 .00394 L
.80097 .00394 L
.80193 .00394 L
.80286 .00394 L
.80384 .00394 L
.80479 .00394 L
.8057 .00394 L
.80667 .00394 L
.8076 .00394 L
.8086 .00394 L
.80955 .00394 L
.81047 .00394 L
.81145 .00394 L
.8124 .00394 L
.8133 .00394 L
.81427 .00394 L
.8152 .00394 L
.81619 .00394 L
.81714 .00394 L
.81805 .00394 L
.81903 .00394 L
.81996 .00394 L
.82096 .00394 L
.82192 .00394 L
.82284 .00394 L
.82383 .00394 L
.82477 .00394 L
.82568 .00394 L
.82665 .00394 L
.82758 .00394 L
.82857 .00394 L
.82953 .00394 L
.83045 .00394 L
Mistroke
.83142 .00394 L
.83236 .00394 L
.83336 .00394 L
.83433 .00394 L
.83525 .00394 L
.83624 .00394 L
.83719 .00394 L
.8381 .00394 L
.83907 .00394 L
.84001 .00394 L
.841 .00394 L
.84196 .00394 L
.84288 .00394 L
.84386 .00394 L
.84481 .00394 L
.84572 .00394 L
.84668 .00394 L
.84761 .00394 L
.8486 .00394 L
.84955 .00394 L
.85047 .00394 L
.85145 .00394 L
.85238 .00394 L
.85338 .00394 L
.85434 .00394 L
.85527 .00394 L
.85625 .00394 L
.8572 .00394 L
.85811 .00394 L
.85908 .00394 L
.86001 .00394 L
.86101 .00394 L
.86196 .00394 L
.86288 .00394 L
.86386 .00394 L
.8648 .00394 L
.8658 .00394 L
.86677 .00394 L
.8677 .00394 L
.86868 .00394 L
.86963 .00394 L
.87055 .00394 L
.87152 .00394 L
.87246 .00394 L
.87345 .00394 L
.87441 .00394 L
.87533 .00394 L
.87632 .00394 L
.87726 .00394 L
.87817 .00394 L
Mistroke
.87914 .00394 L
.88007 .00394 L
.88106 .00394 L
.88201 .00394 L
.88293 .00394 L
.88391 .00394 L
.88485 .00394 L
.88585 .00394 L
.88681 .00394 L
.88774 .00394 L
.88872 .00394 L
.88967 .00394 L
.89058 .00394 L
.89155 .00394 L
.89249 .00394 L
.89348 .00394 L
.89444 .00394 L
.89536 .00394 L
.89634 .00394 L
.89728 .00394 L
.89819 .00394 L
.89915 .00394 L
.90008 .00394 L
.90107 .00394 L
.90202 .00394 L
.90294 .00394 L
.90391 .00394 L
.90485 .00394 L
.90585 .00394 L
.90681 .00394 L
.90773 .00394 L
.90872 .00394 L
.90966 .00394 L
.91057 .00394 L
.91154 .00394 L
.91248 .00394 L
.91347 .00394 L
.91442 .00394 L
.91534 .00394 L
.91632 .00394 L
.91726 .00394 L
.91826 .00394 L
.91922 .00394 L
.92015 .00394 L
.92114 .00394 L
.92209 .00394 L
.923 .00394 L
.92397 .00394 L
.92491 .00394 L
.9259 .00394 L
Mistroke
.92686 .00394 L
.92778 .00394 L
.92877 .00394 L
.92971 .00394 L
.93062 .00394 L
.93158 .00394 L
.93252 .00394 L
.93351 .00394 L
.93446 .00394 L
.93537 .00394 L
.93635 .00394 L
.93729 .00394 L
.93829 .00394 L
.93925 .00394 L
.94018 .00394 L
.94116 .00394 L
.94211 .00394 L
.94302 .00394 L
.94399 .00394 L
.94492 .00394 L
.94592 .00394 L
.94687 .00394 L
.94779 .00394 L
.94877 .00394 L
.94971 .00394 L
.95062 .00394 L
.95158 .00394 L
.95251 .00394 L
.9535 .00394 L
.95445 .00394 L
.95537 .00394 L
.95634 .00394 L
.95728 .00394 L
.95827 .00394 L
.95923 .00394 L
.96016 .00394 L
.96114 .00394 L
.96208 .00394 L
.96299 .00394 L
.96396 .00394 L
.96489 .00394 L
.96588 .00394 L
.96684 .00394 L
.96776 .00394 L
.96873 .00394 L
.96967 .00394 L
.97067 .00394 L
.97164 .00394 L
.97256 .00394 L
.97355 .00394 L
Mistroke
.9745 .00394 L
.97541 .00394 L
.97619 .00394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00=Oooool3o`00023ooooo0ol0000Mooooo`Go00007?ooool2o`0001gooooo1Ol0000Ooooo
o`?o00007_ooool3o`00023ooooo000dooooo`05o`000?ooooooooooooooool000008?ooool00ol0
003oooooooooo`0Mooooo`04o`000?ooooooooooo`0001_ooooo00Co0000oooooooooooo00007Ooo
ool01?l0003oooooooooool0000Pooooo`03o`000?oooooooooo01cooooo00Go0000oooooooooooo
ooooo`00000Oooooo`00;_ooool5o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
5Oooool5o`000003ooooool0003o000000?o00005oooool5o`0000?ooooo00?o0000ooooooooool0
6oooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo01gooooo1Ol0000Mooooo`05
o`000?ooooooooooooooool000007oooool003Cooooo1?l0000Nooooo`04o`000?ooooooooooo`00
027ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0000Oooooo`03o`000?oooooo
oooo01cooooo00Co0000oooooooooooo00007_ooool4o`00023ooooo000dooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooool000007_ooool01Ol0003ooooooooooooooooo000001_ooooo00Co
0000oooooooooooo00007?ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooool0
00007_ooool00ol0003oooooooooo`0Qooooo`00=Oooool00ol0003oooooooooo`0Pooooo`;o0000
7_ooool01Ol0003ooooooooooooooooo000001_ooooo00Co0000oooooooooooo00007?ooool01Ol0
003ooooooooooooooooo000001oooooo0_l0000Oooooo`03o`000?oooooooooo023ooooo000foooo
o`;o00008Oooool00ol0003oooooooooo`0Mooooo`?o00007Oooool2o`0001kooooo0ol0000Qoooo
o`03o`000?oooooooooo01kooooo0_l0000Pooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`003_ooool2o`000?oooooo4Oooool000gooooo00Co0000oooooooooooo00001?oooooo
o`0000_o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool2o`0000Coooooo_l00?l4
ooooo`;o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07oooool00ol00?ooooooooooo`0=
ooooo`;o003o3oooool2o`00o`oooooo0_l00?l?ooooo`;o003o8?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01cooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool03Oooool2o`00o`oooooo0_l00?l?
ooooo`;o003o3oooool2o`00of7ooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool03Oooool2o`00o`oooooo0_l00?l?
ooooo`;o003o3oooool2o`00of7ooooo0Ol00001ooooo`003_ooool2o`0000Gooooo00?o0000oooo
ooooool0H?ooool00ol00?ooooooooooo`0=ooooo`;o003o3oooool2o`00o`oooooo0_l00?l?oooo
o`;o003oHOooool1o`00007ooooo000Eooooo`;o0000HOooool00ol00?ooooooooooo`0=ooooo`;o
003o3oooool2o`00o`oooooo0_l00?l?ooooo`;o003oH?ooool2o`00007ooooo000Eooooo`03o`00
0?oooooooooo063ooooo00?o003oooooooooool03Oooool2o`00o`oooooo0_l00?l?ooooo`;o003o
3oooool2o`00of7ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Pooooo`03o`00oooo
oooooooo00gooooo0_l00?l?ooooo`;o003o3oooool2o`00o`oooooo0_l00?mQooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`0=ooooo`;o003o3oooool2
o`00o`oooooo0_l00?l?ooooo`;o003oHOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
063ooooo00?o003oooooooooool03Oooool2o`00o`oooooo0_l00?l?ooooo`;o003o3oooool2o`00
of7ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo00go
oooo0_l00?l?ooooo`;o003o3oooool2o`00o`oooooo0_l00?mQooooo`7o00000Oooool001Gooooo
0_l0001Qooooo`03o`00oooooooooooo00gooooo0_l00?l?ooooo`;o003o3oooool2o`00o`oooooo
0_l00?mPooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0H?ooool00ol00?oooooooooo
o`0=ooooo`;o003o3oooool2o`00o`oooooo0_l00?l?ooooo`;o003oHOooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool03Oooool2o`00o`oooooo0_l00?l?
ooooo`;o003o3oooool2o`00of7ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Poooo
o`03o`00oooooooooooo00gooooo0_l00?l?ooooo`;o003o3oooool2o`00o`oooooo0_l00?mQoooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`0=ooooo`;o
003o3oooool2o`00o`oooooo0_l00?l?ooooo`;o003oHOooool1o`00007ooooo000Eooooo`;o0000
HOooool00ol00?ooooooooooo`0=ooooo`;o003o3oooool2o`00o`oooooo0_l00?l?ooooo`;o003o
H?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool03Ooo
ool2o`00o`oooooo0_l00?l?ooooo`;o003o3oooool2o`00of7ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1Pooooo`03o`00oooooooooooo00gooooo0_l00?l?ooooo`;o003o3oooool2
o`00o`oooooo0_l00?mQooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H?ooool00ol0
0?ooooooooooo`0=ooooo`;o003o3oooool2o`00o`oooooo0_l00?l?ooooo`;o003oHOooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool03Oooool2o`00o`oo
oooo0_l00?l?ooooo`;o003o3oooool2o`00of7ooooo0Ol00001ooooo`005Oooool2o`00067ooooo
00?o003oooooooooool03Oooool2o`00o`oooooo0_l00?l?ooooo`;o003o3oooool2o`00of3ooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo00gooooo0_l0
0?l?ooooo`;o003o3oooool2o`00o`oooooo0_l00?mQooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0H?ooool00ol00?ooooooooooo`0=ooooo`;o003o3oooool2o`00o`oooooo0_l00?l?
ooooo`;o003oHOooool1o`00007ooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`?o00001Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo00gooooo0_l00?l?oooo
o`;o003o3oooool2o`00o`oooooo0_l00?mQooooo`7o00000Oooool00005ooooool0003ooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0H?ooool0
0ol00?ooooooooooo`0=ooooo`;o003o3oooool2o`00o`oooooo0_l00?l?ooooo`;o003oHOooool1
o`00007ooooo00001Ooooooo0000oooooooooooo000000_ooooo00?o0000ooooooooool00_ooool2
o`00067ooooo00?o003oooooooooool03Oooool2o`00o`oooooo0_l00?l?ooooo`;o003o3oooool2
o`00of3ooooo0_l00001ooooo`0000Goooooo`000?ooooooooooo`00000;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`0=ooooo`;o003o3oooool2
o`00o`oooooo0_l00?l?ooooo`;o003oHOooool1o`00007ooooo00001Ooooooo0000oooooooooooo
000000Oooooo1?l00005ooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool03Oooool2
o`00o`oooooo0_l00?l?ooooo`;o003o3oooool2o`00of7ooooo0Ol00001ooooo`0000Goooooo`00
0?ooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H?ooool0
0ol00?ooooooooooo`0=ooooo`;o003o3oooool2o`00o`oooooo0_l00?l?ooooo`;o003oHOooool1
o`00007ooooo0002ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool0H?ooool00ol0
0?ooooooooooo`0=ooooo`;o003o3oooool2o`00o`oooooo0_l00?l?ooooo`;o003oHOooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool03Oooool2o`00o`oo
oooo0_l00?l?ooooo`;o003o3oooool2o`00of7ooooo0Ol00001ooooo`005Oooool2o`00067ooooo
00?o003oooooooooool03Oooool2o`00o`oooooo0_l00?l?ooooo`;o003o3oooool2o`00of3ooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo00gooooo0_l0
0?l?ooooo`;o003o3oooool2o`00o`oooooo0_l00?mQooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0H?ooool00ol00?ooooooooooo`0=ooooo`;o003o3oooool2o`00o`oooooo0_l00?l?
ooooo`;o003oHOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo063ooooo00?o003ooooo
ooooool03Oooool2o`00o`oooooo0_l00?l?ooooo`;o003o3oooool2o`00of7ooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo00gooooo0_l00?l?ooooo`;o
003o3oooool2o`00o`oooooo0_l00?mQooooo`7o00000Oooool001Gooooo0_l0001Qooooo`03o`00
oooooooooooo00gooooo0_l00?l?ooooo`;o003o3oooool2o`00o`oooooo0_l00?mPooooo`;o0000
0Oooool001Gooooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`0=ooooo`;o003o3ooo
ool2o`00o`oooooo0_l00?l?ooooo`;o003oHOooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo063ooooo00?o003oooooooooool03Oooool2o`00o`oooooo0_l00?l?ooooo`;o003o3oooool2
o`00of7ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo
00gooooo0_l00?l?ooooo`;o003o3oooool2o`00o`oooooo0_l00?mQooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`0=ooooo`;o003o3oooool2o`00o`oo
oooo0_l00?l?ooooo`;o003oHOooool1o`00007ooooo000Eooooo`;o0000HOooool00ol00?oooooo
ooooo`0=ooooo`;o003o3oooool2o`00o`oooooo0_l00?l?ooooo`;o003oH?ooool2o`00007ooooo
000Eooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool03Oooool2o`00o`oooooo0_l0
0?l?ooooo`;o003o3oooool2o`00of7ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1P
ooooo`03o`00oooooooooooo00gooooo0_l00?l?ooooo`;o003o3oooool2o`00o`oooooo0_l00?mQ
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`0=oooo
o`;o003o3oooool2o`00o`oooooo0_l00?l?ooooo`;o003oHOooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo063ooooo00?o003oooooooooool03Oooool2o`00o`oooooo0_l00?l?ooooo`;o
003o3oooool2o`00of7ooooo0Ol00001ooooo`005Oooool2o`00067ooooo00?o003oooooooooool0
3Oooool2o`00o`oooooo0_l00?l?ooooo`;o003o3oooool2o`00of3ooooo0_l00001ooooo`005Ooo
ool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo00gooooo0_l00?l?ooooo`;o003o3ooo
ool2o`00o`oooooo0_l00?mQooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H?ooool0
0ol00?ooooooooooo`0=ooooo`;o003o3oooool2o`00o`oooooo0_l00?l?ooooo`;o003oHOooool1
o`00007ooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo
00gooooo0_l00?l?ooooo`;o003o3oooool2o`00o`oooooo0_l00?mQooooo`7o00000Oooool000ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo00go
oooo0_l00?l?ooooo`;o003o3oooool2o`00o`oooooo0_l00?mQooooo`7o00000Oooool000kooooo
00?o0000ooooooooool01?ooool2o`00067ooooo00?o003oooooooooool03Oooool2o`00o`oooooo
0_l00?l?ooooo`;o003o3oooool2o`00of3ooooo0_l00001ooooo`003_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool03Oooool2o`00o`oooooo0_l0
0?l?ooooo`;o003o3oooool2o`00of7ooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool07oooool00ol0003oooooooooo`0N
ooooo`;o003oHOooool1o`00007ooooo000=ooooo`;o00001_ooool00ol0003oooooooooo`1Poooo
o`03o`00oooooooooooo01oooooo00?o0000ooooooooool07_ooool2o`00of7ooooo0Ol00001oooo
o`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?o003ooooooooo
ool07oooool00ol0003oooooooooo`0Nooooo`;o003oHOooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo063ooooo00?o003oooooooooool07oooool00ol0003oooooooooo`0Nooooo`;o003o
HOooool1o`00007ooooo000Eooooo`;o0000HOooool00ol00?ooooooooooo`0Oooooo`03o`000?oo
oooooooo01kooooo0_l00?mPooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0H?ooool0
0ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo01kooooo0_l00?mQooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo
01kooooo0_l00?mQooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H?ooool00ol00?oo
ooooooooo`0Oooooo`03o`000?oooooooooo01kooooo0_l00?mQooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo01kooooo
0_l00?mQooooo`7o00000Oooool001Gooooo0_l0001Qooooo`03o`00oooooooooooo01oooooo00?o
0000ooooooooool07_ooool2o`00of3ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`1P
ooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool07_ooool2o`00of7ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo01oooooo00?o0000oooo
ooooool07_ooool2o`00of7ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Pooooo`03
o`00oooooooooooo01oooooo00?o0000ooooooooool07_ooool2o`00of7ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool0
7_ooool2o`00of7ooooo0Ol00001ooooo`005Oooool2o`00067ooooo00?o003oooooooooool07ooo
ool00ol0003oooooooooo`0Nooooo`;o003oH?ooool2o`00007ooooo000Eooooo`03o`000?oooooo
oooo063ooooo00?o003oooooooooool07oooool00ol0003oooooooooo`0Nooooo`;o003oHOooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool07oooool00ol0
003oooooooooo`0Nooooo`;o003oHOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo063o
oooo00?o003oooooooooool07oooool00ol0003oooooooooo`0Nooooo`;o003oHOooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool07oooool00ol0003ooooo
ooooo`0Nooooo`;o003oHOooool1o`00007ooooo000Eooooo`;o0000HOooool00ol00?oooooooooo
o`0Oooooo`03o`000?oooooooooo01kooooo0_l00?mPooooo`;o00000Oooool001Gooooo00?o0000
ooooooooool0H?ooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo01kooooo0_l00?mQ
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`0Ooooo
o`03o`000?oooooooooo01kooooo0_l00?mQooooo`7o00000Oooool00004ooooool0003o0000o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0H?ooool00ol0
0?ooooooooooo`0Oooooo`03o`000?oooooooooo01kooooo0_l00?mQooooo`7o00000Oooool000;o
oooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0H?ooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo01kooooo0_l00?mQoooo
o`7o00000Oooool000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo063ooooo00?o003oooooooooool07oooool00ol0003oooooooooo`0Nooooo`;o
003oHOooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0_ooool2o`00067ooooo00?o003oooooooooool07oooool00ol0003oooooooooo`0Nooooo`;o003o
H?ooool2o`00007ooooo0002ooooo`03o`000?oooooooooo00Oooooo1?l00005ooooo`03o`000?oo
oooooooo063ooooo00?o003oooooooooool07oooool00ol0003oooooooooo`0Nooooo`;o003oHOoo
ool1o`00007ooooo00000ooooooo0000o`000009ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0H?ooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo01kooooo0_l00?mQ
ooooo`7o00000Oooool000;ooooo00?o0000ooooooooool01oooool5o`0000Cooooo00?o0000oooo
ooooool0H?ooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo01kooooo0_l00?mQoooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`0Oooooo`03
o`000?oooooooooo01kooooo0_l00?mQooooo`7o00000Oooool001Gooooo0_l0001Qooooo`03o`00
oooooooooooo01oooooo00?o0000ooooooooool07_ooool2o`00of3ooooo0_l00001ooooo`005Ooo
ool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool07_oo
ool2o`00of7ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooo
oooo01oooooo00?o0000ooooooooool07_ooool2o`00of7ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`1Pooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool07_ooool2o`00
of7ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo01oo
oooo00?o0000ooooooooool07_ooool2o`00of7ooooo0Ol00001ooooo`005Oooool2o`00067ooooo
00?o003oooooooooool07oooool00ol0003oooooooooo`0Nooooo`;o003oH?ooool2o`00007ooooo
000Eooooo`03o`000?oooooooooo063ooooo00?o003oooooooooool07oooool00ol0003ooooooooo
o`0Nooooo`;o003oHOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo063ooooo00?o003o
ooooooooool07oooool00ol0003oooooooooo`0Nooooo`;o003oHOooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo063ooooo00?o003oooooooooool07oooool00ol0003oooooooooo`0Noooo
o`;o003oHOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo063ooooo00?o003ooooooooo
ool07oooool00ol0003oooooooooo`0Nooooo`;o003oHOooool1o`00007ooooo000Eooooo`;o0000
HOooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo01kooooo0_l00?mPooooo`;o0000
0Oooool001Gooooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`0Oooooo`03o`000?oo
oooooooo01kooooo0_l00?mQooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H?ooool0
0ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo01kooooo0_l00?mQooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`0Oooooo`03o`000?oooooooooo
01kooooo0_l00?mQooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H?ooool00ol00?oo
ooooooooo`0Oooooo`03o`000?oooooooooo01kooooo0_l00?mQooooo`7o00000Oooool001Gooooo
0_l0001Qooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool07_ooool2o`00of3ooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo01oooooo00?o
0000ooooooooool07_ooool2o`00of7ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1P
ooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool07_ooool2o`00of7ooooo0Ol00001
ooooo`003?ooool5o`0000Cooooo00?o0000ooooooooool0H?ooool00ol00?ooooooooooo`0Ooooo
o`03o`000?oooooooooo01kooooo0_l00?mQooooo`7o00000Oooool000gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`1Pooooo`03o`00oooooooooooo01oooooo00?o0000oooo
ooooool07_ooool2o`00of7ooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo063ooooo00?o003oooooooooool07oooool00ol0003oooooooooo`0Nooooo`;o
003oHOooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo0_l0001Pooooo`;o003o
8Oooool00ol0003oooooooooo`0Nooooo`;o003oH?ooool2o`00007ooooo000<ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo
0Ol00001ooooo`003?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool000gooooo0ol00005ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0
003oooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001oooo
o`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`00
08?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003oooooooooo`20ooooo`;o
00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o0000
0Oooool000Go00000oooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo087ooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Ooo
ool000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`;o0000Poooool0
0ol0003oooooooooo`20ooooo`;o00000Oooool00005o`000?ooooooooooooooool000001oooool4
o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool0
0005o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo00001?oooooo0000o`000?l00008
ooooo`Go00001?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001oooo
o`005Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003o
ooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o
00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`005Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?ooooo
00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0POooool1o`00007ooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`22
ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`003?ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool0
013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
087ooooo0Ol00001ooooo`003_ooool2o`0000Gooooo0_l00023ooooo`03o`000?oooooooooo083o
oooo0_l00001ooooo`004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool0POooool1o`00007ooooo000<ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`003Ooo
ool3o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool0
01Gooooo0_l00004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l00001ooooo`005Oooooooo`0000_o
00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.13953, -0.260466, \
0.0593102, 0.0191323}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CTFT of finite-length x(t)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xf\  = \ 
        Integrate[x[t]\ Exp[\(-I\)\ 2  \[Pi]\ f\ t], {t, 0, \ 5}]\  // \ 
          FullSimplify;\)\), "\[IndentingNewLine]", 
    \(xf\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(\[ExponentialE]\^\(\(-5\)\ \[ImaginaryI]\ f\ \[Pi]\)\
\ \((7\ f\^4 - 17\ f\^2 + 4)\)\ \(sin(5\ f\ \[Pi])\)\)\/\(\((f - 2)\)\ \((f - \
1)\)\ f\ \((f + 1)\)\ \((f + 2)\)\ \[Pi]\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gX2 = 
        Plot[Abs[xf], {f, \(-5\), 5}, \ PlotStyle \[Rule] {Blue}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.0583928 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1315 -6 -4.5 ]
[-0.0125 .1315 0 4.5 ]
[-0.0125 .24829 -6 -4.5 ]
[-0.0125 .24829 0 4.5 ]
[-0.0125 .36507 -6 -4.5 ]
[-0.0125 .36507 0 4.5 ]
[-0.0125 .48186 -6 -4.5 ]
[-0.0125 .48186 0 4.5 ]
[-0.0125 .59864 -12 -4.5 ]
[-0.0125 .59864 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1315 m
.00625 .1315 L
s
[(2)] -0.0125 .1315 1 0 Mshowa
0 .24829 m
.00625 .24829 L
s
[(4)] -0.0125 .24829 1 0 Mshowa
0 .36507 m
.00625 .36507 L
s
[(6)] -0.0125 .36507 1 0 Mshowa
0 .48186 m
.00625 .48186 L
s
[(8)] -0.0125 .48186 1 0 Mshowa
0 .59864 m
.00625 .59864 L
s
[(10)] -0.0125 .59864 1 0 Mshowa
.125 Mabswid
0 .04391 m
.00375 .04391 L
s
0 .07311 m
.00375 .07311 L
s
0 .1023 m
.00375 .1023 L
s
0 .1607 m
.00375 .1607 L
s
0 .18989 m
.00375 .18989 L
s
0 .21909 m
.00375 .21909 L
s
0 .27748 m
.00375 .27748 L
s
0 .30668 m
.00375 .30668 L
s
0 .33588 m
.00375 .33588 L
s
0 .39427 m
.00375 .39427 L
s
0 .42346 m
.00375 .42346 L
s
0 .45266 m
.00375 .45266 L
s
0 .51105 m
.00375 .51105 L
s
0 .54025 m
.00375 .54025 L
s
0 .56945 m
.00375 .56945 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1315 m
1 .1315 L
s
.99375 .24829 m
1 .24829 L
s
.99375 .36507 m
1 .36507 L
s
.99375 .48186 m
1 .48186 L
s
.99375 .59864 m
1 .59864 L
s
.125 Mabswid
.99625 .04391 m
1 .04391 L
s
.99625 .07311 m
1 .07311 L
s
.99625 .1023 m
1 .1023 L
s
.99625 .1607 m
1 .1607 L
s
.99625 .18989 m
1 .18989 L
s
.99625 .21909 m
1 .21909 L
s
.99625 .27748 m
1 .27748 L
s
.99625 .30668 m
1 .30668 L
s
.99625 .33588 m
1 .33588 L
s
.99625 .39427 m
1 .39427 L
s
.99625 .42346 m
1 .42346 L
s
.99625 .45266 m
1 .45266 L
s
.99625 .51105 m
1 .51105 L
s
.99625 .54025 m
1 .54025 L
s
.99625 .56945 m
1 .56945 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02608 .02544 L
.02847 .03524 L
.02972 .03925 L
.03089 .04206 L
.03157 .04323 L
.03188 .04367 L
.03218 .044 L
.03252 .04429 L
.03269 .04441 L
.03288 .04451 L
.03296 .04454 L
.03305 .04457 L
.0332 .04461 L
.03329 .04463 L
.03338 .04463 L
.03346 .04463 L
.03355 .04463 L
.03363 .04462 L
.03371 .0446 L
.03386 .04456 L
.03402 .0445 L
.03419 .0444 L
.0345 .04417 L
.0348 .04388 L
.03534 .04316 L
.03592 .04214 L
.03725 .03887 L
.03845 .03487 L
.04095 .02417 L
.04205 .0188 L
.04235 .01729 L
.04251 .0165 L
.04267 .01566 L
.04282 .01492 L
.0429 .01493 L
.04298 .01532 L
.04326 .01675 L
.0455 .02778 L
.04788 .03767 L
.04915 .04164 L
.04977 .04318 L
.05035 .04434 L
.05087 .04516 L
.05114 .0455 L
.05142 .04579 L
.05157 .04592 L
.05171 .04602 L
.05185 .0461 L
.05198 .04616 L
Mistroke
.05213 .04622 L
.05221 .04624 L
.05229 .04626 L
.05245 .04627 L
.05259 .04627 L
.05274 .04625 L
.05287 .04621 L
.05302 .04615 L
.05318 .04607 L
.05351 .04583 L
.0538 .04553 L
.05437 .04475 L
.05492 .04377 L
.05612 .04074 L
.05743 .03627 L
.05977 .02583 L
.06101 .01945 L
.06135 .01765 L
.06154 .01666 L
.06171 .01574 L
.06186 .01495 L
.06202 .01533 L
.06211 .01581 L
.06219 .01626 L
.06235 .01711 L
.0648 .02976 L
.06709 .03961 L
.06827 .04341 L
.06891 .04505 L
.06951 .04628 L
.07003 .04709 L
.07029 .04742 L
.07057 .04771 L
.07074 .04784 L
.07089 .04794 L
.07103 .04801 L
.07118 .04807 L
.07132 .04811 L
.07145 .04813 L
.07159 .04813 L
.07174 .04811 L
.07189 .04807 L
.07203 .04802 L
.07219 .04794 L
.07234 .04784 L
.0726 .04762 L
.07289 .0473 L
.07355 .04631 L
.07415 .04506 L
.07539 .04158 L
Mistroke
.0767 .03664 L
.07908 .0251 L
.08013 .01938 L
.08041 .01778 L
.08057 .01689 L
.08072 .01606 L
.08085 .01527 L
.081 .015 L
.08114 .01577 L
.08126 .01648 L
.08246 .02326 L
.08361 .02943 L
.08491 .03589 L
.08612 .04109 L
.08731 .04519 L
.0884 .04794 L
.08869 .04851 L
.08901 .04905 L
.08929 .04943 L
.0896 .04977 L
.08976 .04991 L
.08992 .05003 L
.0901 .05013 L
.09018 .05016 L
.09027 .0502 L
.09043 .05023 L
.09051 .05024 L
.09059 .05025 L
.09074 .05024 L
.09089 .05021 L
.09104 .05015 L
.09112 .05012 L
.0912 .05007 L
.09153 .04983 L
.09182 .04953 L
.09213 .04912 L
.09283 .04787 L
.09347 .04633 L
.09471 .04231 L
.0959 .03738 L
.09714 .0312 L
.09832 .0247 L
.09937 .01849 L
.09966 .01676 L
.09982 .01581 L
.09997 .01492 L
.10009 .01527 L
.10023 .01609 L
.10051 .01781 L
.10289 .03173 L
Mistroke
.10542 .04389 L
.10665 .04816 L
.10735 .04999 L
.10799 .05127 L
.10826 .05169 L
.10855 .05206 L
.10872 .05224 L
.10887 .05237 L
.10901 .05248 L
.10917 .05257 L
.10933 .05264 L
.10948 .05268 L
.10957 .05269 L
.10965 .05269 L
.10981 .05268 L
.10996 .05265 L
.1101 .05259 L
.11026 .05251 L
.11042 .05239 L
.11073 .05211 L
.11102 .05174 L
.11156 .05083 L
.11215 .04952 L
.11279 .04771 L
.11393 .04354 L
.115 .03872 L
.11617 .03249 L
.11744 .02497 L
.11802 .02132 L
.11834 .01929 L
.11863 .01739 L
.11889 .01575 L
.11903 .01483 L
.11916 .01543 L
.11973 .01915 L
.1221 .03391 L
.12428 .04523 L
.12541 .04967 L
.12598 .05149 L
.1266 .0531 L
.12692 .05378 L
.12721 .05431 L
.12751 .05476 L
.12779 .05508 L
.12796 .05524 L
.12811 .05536 L
.12828 .05546 L
.12838 .0555 L
.12846 .05553 L
.12854 .05554 L
Mistroke
.12862 .05556 L
.12877 .05556 L
.12893 .05554 L
.12902 .05551 L
.1291 .05548 L
.12926 .0554 L
.12942 .05529 L
.12971 .05502 L
.13002 .05462 L
.13037 .05406 L
.13098 .05273 L
.13156 .05112 L
.13264 .04723 L
.1338 .04185 L
.13617 .02784 L
.13682 .02351 L
.13752 .01875 L
.13768 .01762 L
.13785 .0164 L
.13793 .01584 L
.13802 .01524 L
.13817 .01525 L
.13832 .01628 L
.13846 .01724 L
.13877 .01942 L
.14127 .03622 L
.14355 .04876 L
.1447 .05344 L
.14535 .0555 L
.14596 .057 L
.14648 .05797 L
.14678 .05838 L
.14706 .05867 L
.14721 .05878 L
.14736 .05887 L
.14749 .05893 L
.14763 .05897 L
.14778 .05898 L
.14787 .05898 L
.14794 .05897 L
.14809 .05892 L
.14824 .05886 L
.14838 .05877 L
.14852 .05865 L
.14879 .05837 L
.14911 .05792 L
.14941 .0574 L
.15004 .05592 L
.15065 .05409 L
.15171 .04991 L
Mistroke
.15287 .04406 L
.1542 .03602 L
.15544 .02741 L
.15656 .01912 L
.15687 .01679 L
.15702 .01562 L
.15711 .01495 L
.15719 .0151 L
.15734 .01622 L
.15747 .01724 L
.15777 .01953 L
.16023 .03755 L
.16249 .05135 L
.16361 .05647 L
.16418 .05858 L
.1648 .06042 L
.16512 .0612 L
.16541 .0618 L
.16571 .0623 L
.16599 .06266 L
.16615 .06283 L
.16629 .06295 L
.16645 .06305 L
.16654 .06309 L
.16663 .06312 L
.16671 .06314 L
.1668 .06315 L
.16695 .06315 L
.16704 .06313 L
.16712 .06311 L
.16721 .06307 L
.1673 .06302 L
.16746 .06291 L
.16761 .06278 L
.16793 .06238 L
.16824 .06189 L
.16852 .06132 L
.16916 .05965 L
.16985 .05727 L
.17112 .05148 L
.17228 .04467 L
.17347 .03645 L
.17475 .02661 L
.17537 .02157 L
.17567 .01905 L
.17595 .01671 L
.17608 .01561 L
.17621 .01486 L
.17634 .01594 L
.17648 .01713 L
Mistroke
.17705 .02193 L
.1794 .04086 L
.18164 .05571 L
.1828 .0615 L
.18346 .06406 L
.18408 .06593 L
.18437 .06664 L
.18464 .0672 L
.18489 .06762 L
.18516 .06796 L
.18529 .0681 L
.18544 .06822 L
.18558 .06831 L
.18571 .06836 L
.18586 .06839 L
.186 .06839 L
.18616 .06835 L
.18631 .06829 L
.18645 .0682 L
.18659 .06807 L
.18686 .06776 L
.18718 .06725 L
.18747 .06665 L
.18807 .06504 L
.18871 .06279 L
.18977 .05783 L
.19093 .05081 L
.19225 .04114 L
.19349 .0307 L
.19461 .0206 L
.19491 .01776 L
.19508 .0162 L
.19524 .01473 L
.19537 .01595 L
.19551 .01729 L
.19582 .02015 L
.19807 .04074 L
.20052 .0597 L
.20116 .06364 L
.20185 .06728 L
.20244 .06991 L
.20307 .07219 L
.20342 .07316 L
.20373 .07389 L
.20403 .07444 L
.20418 .07467 L
.20435 .07487 L
.2045 .07501 L
.20463 .07511 L
.20477 .07518 L
Mistroke
.2049 .07522 L
.20505 .07523 L
.20518 .07521 L
.20534 .07515 L
.20541 .0751 L
.2055 .07504 L
.20578 .07474 L
.20594 .07452 L
.20609 .07427 L
.20672 .07284 L
.20726 .0711 L
.20783 .06872 L
.20915 .06142 L
.21035 .05273 L
.21157 .04219 L
.21286 .02962 L
.21339 .02415 L
.21396 .01814 L
.21413 .01636 L
.21429 .01477 L
.21443 .0163 L
.21459 .01797 L
.21518 .02425 L
.21761 .04936 L
.21982 .06818 L
.22104 .07601 L
.22161 .07882 L
.2222 .08121 L
.2225 .0822 L
.22283 .0831 L
.22313 .08374 L
.22342 .08419 L
.22359 .08439 L
.22367 .08446 L
.22375 .08452 L
.22389 .08461 L
.22405 .08465 L
.22421 .08465 L
.2243 .08463 L
.22438 .08459 L
.22447 .08454 L
.22455 .08448 L
.22473 .0843 L
.22488 .0841 L
.22503 .08386 L
.2253 .08332 L
.22592 .08158 L
.22645 .07951 L
.22702 .07669 L
.22832 .06816 L
Mistroke
.22952 .05793 L
.23071 .04587 L
.23198 .03133 L
.2326 .02385 L
.2329 .0201 L
.23304 .01844 L
.23318 .0166 L
.23331 .01495 L
.23344 .01603 L
.23357 .01767 L
.23371 .01943 L
.23428 .02665 L
.23647 .05346 L
.23886 .07822 L
.24011 .08792 L
.24071 .09156 L
.24128 .09435 L
.24158 .0956 L
.24192 .09673 L
.24222 .09754 L
.24251 .09811 L
.24266 .09835 L
.24281 .09852 L
.24289 .0986 L
.24297 .09866 L
.24306 .09871 L
.24314 .09874 L
.24323 .09876 L
.24331 .09876 L
.24347 .09871 L
.24356 .09866 L
.24365 .09859 L
.24382 .09841 L
.24396 .0982 L
.24411 .09794 L
.24438 .09732 L
.24471 .09637 L
.245 .0953 L
.24564 .09228 L
.24625 .08859 L
.24731 .08017 L
.24847 .06845 L
.25082 .03821 L
.25146 .02879 L
.2518 .02371 L
.25198 .02091 L
.25215 .01829 L
.2523 .01596 L
.25238 .01477 L
.25246 .01596 L
Mistroke
.2528 .02127 L
.2534 .03063 L
.25587 .06828 L
.25814 .09746 L
.25927 .10852 L
.25984 .11308 L
.26046 .11707 L
.26078 .11877 L
.26108 .12007 L
.26138 .12116 L
.26165 .12194 L
.26181 .12229 L
.26198 .12258 L
.26206 .12269 L
.26214 .12279 L
.26224 .12287 L
.26233 .12293 L
.26241 .12296 L
.26249 .12297 L
.26258 .12296 L
.26266 .12293 L
.26281 .12282 L
.26297 .12264 L
.26312 .1224 L
.26328 .12206 L
.26361 .12114 L
.26391 .11999 L
.2642 .11866 L
.26485 .11477 L
.26554 .10922 L
.26681 .09553 L
.26797 .0793 L
.27026 .03865 L
.27089 .026 L
.27107 .02226 L
.27124 .01872 L
.27139 .01551 L
.27148 .01573 L
.27156 .01741 L
.27276 .04334 L
.27522 .09604 L
.27643 .11953 L
.27752 .13853 L
.27858 .15399 L
.27973 .16687 L
.28037 .17195 L
.28065 .1737 L
.28095 .17528 L
.28124 .17642 L
.28137 .17682 L
Mistroke
.28151 .17717 L
.28166 .17745 L
.2818 .17763 L
.28194 .17773 L
.28203 .17774 L
.2821 .17773 L
.28226 .17762 L
.28234 .17752 L
.28242 .17739 L
.28257 .17707 L
.28271 .17668 L
.28303 .17547 L
.28337 .17365 L
.2837 .17144 L
.284 .1689 L
.28457 .16295 L
.28565 .1476 L
.28682 .12471 L
.28919 .05931 L
.28988 .03622 L
.29021 .02429 L
.29036 .01893 L
.29045 .01586 L
.29052 .01645 L
.29066 .02153 L
.2908 .02704 L
.2911 .03847 L
.29173 .06337 L
.29672 .28613 L
.29922 .39594 L
.30154 .48366 L
.30378 .54913 L
.30492 .57304 L
.30556 .58365 L
.30617 .59156 L
.30676 .59741 L
.3071 .59984 L
.30726 .60078 L
.30742 .60153 L
.30756 .60212 L
.30772 .60263 L
.30786 .60297 L
.30799 .60318 L
.30814 .60331 L
.30829 .60331 L
.30837 .60327 L
.30845 .60318 L
.30861 .60291 L
.30876 .60253 L
.30889 .60207 L
Mistroke
.30921 .60064 L
.30948 .59894 L
.30977 .59668 L
.31028 .5917 L
.31084 .58464 L
.31206 .56391 L
.31317 .53887 L
.31569 .46467 L
.32046 .28396 L
.32506 .11293 L
.32627 .07479 L
.32742 .04268 L
.32806 .02671 L
.32823 .02257 L
.32841 .01828 L
.32857 .01472 L
.32866 .0167 L
.32874 .01854 L
.32995 .04234 L
.3312 .06188 L
.33182 .06954 L
.33239 .07551 L
.33295 .08033 L
.33346 .08385 L
.33403 .08683 L
.33434 .08808 L
.33463 .089 L
.33477 .08936 L
.33492 .08969 L
.33505 .08992 L
.33519 .09013 L
.33528 .09023 L
.33536 .0903 L
.33551 .0904 L
.33566 .09044 L
.33581 .09043 L
.33595 .09036 L
.33611 .09023 L
.33626 .09006 L
.3364 .08986 L
.33672 .08923 L
.33705 .08834 L
.3376 .0864 L
.33812 .0841 L
.33928 .07743 L
.34399 .04002 L
.34523 .03031 L
.34588 .02557 L
.34657 .02093 L
.34717 .01722 L
Mistroke
.34734 .01627 L
.34743 .01575 L
.34752 .01527 L
.3476 .01483 L
.34768 .01507 L
.34784 .01587 L
.349 .0212 L
.34955 .02317 L
.35013 .02493 L
.35078 .02641 L
.35138 .0274 L
.35169 .02775 L
.35187 .02791 L
.35203 .02803 L
.3522 .02812 L
.35229 .02816 L
.35238 .02819 L
.35253 .02823 L
.35262 .02824 L
.3527 .02824 L
.35285 .02823 L
.35298 .02821 L
.35313 .02816 L
.35322 .02813 L
.35329 .02809 L
.35361 .02788 L
.35392 .02761 L
.35452 .02687 L
.35507 .02599 L
.3563 .02346 L
.35852 .01795 L
.35911 .01649 L
.35943 .01573 L
.35959 .01537 L
.35973 .01505 L
.35986 .01475 L
.35999 .01495 L
.36026 .01552 L
.36084 .01663 L
.36143 .01756 L
.36205 .01833 L
.36237 .01863 L
.36254 .01876 L
.36273 .01888 L
.3629 .01896 L
.36305 .01902 L
.3632 .01905 L
.36335 .01908 L
.3635 .01908 L
.36359 .01907 L
Mistroke
.36367 .01906 L
.36381 .01903 L
.36396 .01897 L
.36409 .01891 L
.36422 .01883 L
.36451 .01862 L
.36482 .0183 L
.3651 .01794 L
.36574 .01688 L
.36628 .0157 L
.36643 .01534 L
.36659 .01493 L
.36674 .01491 L
.36687 .01529 L
.36795 .01885 L
.37028 .02909 L
.37279 .04217 L
.37515 .05343 L
.3758 .0559 L
.37649 .05811 L
.37683 .059 L
.37715 .05972 L
.37743 .06025 L
.37774 .06072 L
.37789 .06089 L
.37804 .06104 L
.37818 .06115 L
.37832 .06123 L
.37846 .06127 L
.37862 .06129 L
.37869 .06129 L
.37878 .06127 L
.37893 .06121 L
.37907 .06113 L
.37923 .061 L
.37937 .06083 L
.37951 .06066 L
.38003 .05966 L
.38032 .05887 L
.3806 .05799 L
.38123 .05545 L
.38185 .05224 L
.38251 .04795 L
.38374 .03767 L
.38438 .03102 L
.38507 .02304 L
.38536 .01942 L
.38551 .01746 L
.38567 .01534 L
.38575 .01524 L
Mistroke
.38585 .01651 L
.38601 .01878 L
.38633 .02338 L
.3875 .04166 L
.39238 .13711 L
.39709 .23263 L
.39832 .25362 L
.39966 .27313 L
.40092 .28785 L
.40209 .29787 L
.40265 .30139 L
.40296 .30296 L
.40326 .3042 L
.40353 .30513 L
.40367 .30554 L
.40383 .30591 L
.40397 .30618 L
.4041 .30639 L
.40423 .30654 L
.40435 .30665 L
.4045 .30671 L
.40465 .30672 L
.40473 .30669 L
.40482 .30665 L
.40497 .30651 L
.40513 .3063 L
.40527 .30604 L
.40555 .3054 L
.40587 .30436 L
.40617 .30315 L
.40684 .29949 L
.4074 .29551 L
.408 .2903 L
.40909 .27855 L
.41158 .24205 L
.41654 .1445 L
.41902 .09396 L
.42132 .05168 L
.42247 .03338 L
.42303 .02518 L
.42355 .01811 L
.4237 .01615 L
.42384 .01507 L
.42398 .0169 L
.42414 .01887 L
.42479 .0263 L
.42592 .03736 L
.42652 .04224 L
.42718 .04677 L
.42776 .05009 L
Mistroke
.42837 .05294 L
.42898 .0551 L
.42953 .0565 L
.4298 .05699 L
.42994 .05721 L
.43009 .0574 L
.43022 .05754 L
.43036 .05766 L
.43049 .05775 L
.43061 .0578 L
.43076 .05785 L
.43084 .05786 L
.43092 .05785 L
.43107 .05783 L
.43121 .05778 L
.4313 .05773 L
.43138 .05768 L
.43153 .05756 L
.43187 .05717 L
.43217 .05673 L
.43244 .05622 L
.43307 .05475 L
.43415 .05133 L
.43531 .04673 L
.43772 .03546 L
.44032 .02349 L
.44155 .01878 L
.44221 .01657 L
.44254 .01559 L
.44268 .01519 L
.44284 .01477 L
.44298 .01504 L
.44311 .01537 L
.44337 .01599 L
.44394 .01718 L
.44453 .01817 L
.44483 .01858 L
.44515 .01894 L
.44543 .0192 L
.44574 .01941 L
.44588 .01949 L
.44602 .01955 L
.44616 .0196 L
.44628 .01963 L
.44644 .01966 L
.44658 .01967 L
.44674 .01967 L
.44682 .01966 L
.44691 .01965 L
.44706 .01961 L
Mistroke
.44721 .01956 L
.4475 .01943 L
.44778 .01926 L
.44809 .01902 L
.44865 .01846 L
.44971 .01705 L
.45035 .016 L
.45066 .01545 L
.4508 .0152 L
.45095 .01493 L
.45109 .01476 L
.45122 .01499 L
.45149 .01551 L
.45208 .01663 L
.45338 .01902 L
.45461 .02096 L
.45518 .02167 L
.45579 .02227 L
.45611 .0225 L
.45627 .0226 L
.45646 .02269 L
.45662 .02276 L
.45677 .02281 L
.45692 .02284 L
.45707 .02286 L
.45721 .02286 L
.45734 .02285 L
.45749 .02283 L
.45763 .02279 L
.45775 .02275 L
.45787 .0227 L
.45814 .02254 L
.45841 .02233 L
.45871 .02204 L
.45931 .02125 L
.45994 .02013 L
.46054 .01879 L
.46108 .01733 L
.46166 .01555 L
.4618 .01507 L
.46196 .0149 L
.46205 .01521 L
.46213 .0155 L
.46229 .01608 L
.46287 .01835 L
.46418 .0242 L
.46665 .03696 L
.46895 .04889 L
.47009 .054 L
.47117 .05794 L
Mistroke
.47177 .05963 L
.47208 .06037 L
.47241 .06102 L
.47269 .06145 L
.47284 .06164 L
.473 .06182 L
.47315 .06194 L
.47328 .06203 L
.47342 .06209 L
.47354 .06213 L
.47369 .06214 L
.47378 .06213 L
.47386 .06212 L
.474 .06206 L
.47415 .06197 L
.47429 .06185 L
.47441 .06172 L
.4747 .06131 L
.47501 .06072 L
.4753 .06003 L
.47593 .05797 L
.47648 .05562 L
.47707 .05243 L
.47815 .04488 L
.47929 .03449 L
.47994 .02737 L
.48054 .02012 L
.4807 .01809 L
.48084 .01615 L
.481 .01534 L
.48108 .01645 L
.48117 .01764 L
.48185 .02742 L
.48307 .04705 L
.48808 .14521 L
.49059 .19721 L
.4929 .24055 L
.49516 .27455 L
.49629 .28757 L
.49693 .29352 L
.49754 .29818 L
.49813 .30173 L
.49844 .30323 L
.49877 .30453 L
.49907 .30546 L
.49935 .30608 L
.49948 .3063 L
.49963 .30648 L
.49976 .3066 L
.49989 .30666 L
Mistroke
.50003 .30668 L
.50019 .30663 L
.50034 .30652 L
.50047 .30636 L
.50063 .30611 L
.5008 .30577 L
.50111 .30492 L
.50144 .30374 L
.50179 .30217 L
.50241 .29852 L
.50354 .28921 L
.50476 .2756 L
.50697 .24278 L
.51194 .14489 L
.51442 .09366 L
.51672 .05055 L
.51787 .03175 L
.51843 .0233 L
.51868 .01977 L
.51881 .01794 L
.51895 .01602 L
.5191 .01544 L
.51924 .0173 L
.51955 .02123 L
.5202 .02893 L
.52133 .04043 L
.52255 .05007 L
.52325 .05423 L
.52389 .05727 L
.52445 .05929 L
.52477 .0602 L
.52506 .06088 L
.52537 .06143 L
.52554 .06166 L
.52571 .06185 L
.52586 .06197 L
.526 .06206 L
.52615 .06212 L
.52624 .06214 L
.52631 .06214 L
.52646 .06213 L
.52659 .06209 L
.52674 .06202 L
.5269 .06191 L
.52706 .06175 L
.52722 .06157 L
.52752 .06113 L
.52805 .06008 L
.52862 .05856 L
.52993 .05392 L
Mistroke
.53113 .04847 L
.5334 .03667 L
.53586 .02403 L
.53651 .02102 L
.5372 .01808 L
.53779 .0158 L
.53795 .01521 L
.53805 .01489 L
.53813 .01483 L
.5382 .01509 L
.53829 .01537 L
.53844 .01587 L
.5396 .01912 L
.54026 .02051 L
.54087 .02152 L
.54117 .0219 L
.54147 .02223 L
.54174 .02246 L
.54202 .02264 L
.54218 .02272 L
.54233 .02278 L
.54248 .02282 L
.54261 .02285 L
.54269 .02285 L
.54278 .02286 L
.54293 .02286 L
.54301 .02285 L
.54309 .02284 L
.54317 .02282 L
.54326 .0228 L
.54343 .02274 L
.54359 .02267 L
.54394 .02247 L
.54425 .02223 L
.54459 .02192 L
.5458 .02037 L
.54704 .01827 L
.5477 .01705 L
.54839 .01574 L
.54868 .01519 L
.54876 .01503 L
.54884 .01488 L
.54899 .01482 L
.54908 .01498 L
.54916 .01512 L
.54934 .01544 L
.54966 .016 L
.55082 .01781 L
.55138 .0185 L
.55169 .01882 L
Mistroke
.55199 .01909 L
.55226 .01929 L
.55256 .01946 L
.55269 .01952 L
.55283 .01958 L
.55296 .01962 L
.55308 .01964 L
.55323 .01967 L
.55331 .01967 L
.5534 .01967 L
.55355 .01966 L
.55369 .01964 L
.55378 .01962 L
.55386 .01959 L
.55402 .01954 L
.55418 .01946 L
.55436 .01935 L
.55466 .01911 L
.55499 .01879 L
.55557 .01803 L
.55616 .017 L
.5567 .01583 L
.55698 .01514 L
.55706 .01494 L
.55714 .01472 L
.55729 .01511 L
.55791 .01697 L
.56012 .02537 L
.56252 .03661 L
.56378 .04265 L
.56512 .04854 L
.56632 .05294 L
.56695 .05481 L
.5673 .05567 L
.56763 .05637 L
.56793 .05689 L
.56826 .05734 L
.5684 .05749 L
.56855 .05763 L
.5687 .05773 L
.56883 .05779 L
.56897 .05784 L
.5691 .05786 L
.56925 .05785 L
.5694 .0578 L
.56954 .05773 L
.56966 .05765 L
.5698 .05752 L
.56995 .05736 L
.57026 .0569 L
Mistroke
.57058 .05624 L
.57118 .05461 L
.57181 .05217 L
.57251 .04863 L
.57376 .03999 L
.57494 .02915 L
.57556 .02241 L
.57586 .01886 L
.57599 .01727 L
.57613 .0155 L
.57628 .01582 L
.57642 .01765 L
.57673 .02178 L
.57738 .03108 L
.57961 .06806 L
.58455 .1673 L
.58701 .2166 L
.58931 .25648 L
.59044 .2727 L
.59152 .28548 L
.59211 .29134 L
.59276 .2967 L
.5933 .30035 L
.59361 .30205 L
.59389 .30338 L
.59417 .3045 L
.59447 .30544 L
.59473 .30605 L
.59488 .30631 L
.59502 .3065 L
.5951 .30658 L
.59518 .30665 L
.59533 .30672 L
.59548 .30672 L
.59562 .30666 L
.59577 .30654 L
.59586 .30645 L
.59594 .30634 L
.5961 .30606 L
.59627 .30568 L
.59659 .30474 L
.59695 .30337 L
.59759 .29997 L
.59822 .29556 L
.5988 .29053 L
.60008 .2765 L
.60128 .25984 L
.60352 .22134 L
.60817 .12531 L
.61053 .07729 L
Mistroke
.61178 .05409 L
.61312 .03172 L
.61344 .02685 L
.61378 .02175 L
.61394 .01949 L
.61411 .01714 L
.61425 .01517 L
.61441 .01638 L
.61456 .01839 L
.6147 .02018 L
.61502 .02409 L
.61559 .03067 L
.61678 .04235 L
.61789 .05063 L
.61845 .05392 L
.61899 .05644 L
.61929 .0576 L
.61961 .05867 L
.6199 .05948 L
.62017 .06009 L
.62047 .06062 L
.62063 .06084 L
.6208 .06102 L
.62089 .0611 L
.62098 .06116 L
.62107 .06121 L
.62115 .06125 L
.6213 .06129 L
.62139 .06129 L
.62147 .06129 L
.62162 .06125 L
.62177 .06118 L
.62192 .06107 L
.62209 .06092 L
.62236 .06058 L
.62267 .06009 L
.6233 .05868 L
.6239 .05692 L
.62503 .05269 L
.62755 .04039 L
.62975 .02894 L
.63101 .02307 L
.63218 .01837 L
.63277 .01637 L
.63306 .01548 L
.6332 .01507 L
.63333 .01472 L
.63348 .01511 L
.63364 .01551 L
.63398 .0163 L
Mistroke
.63457 .01744 L
.63488 .01791 L
.6352 .01832 L
.63555 .01867 L
.63571 .01879 L
.63588 .01889 L
.63604 .01897 L
.63618 .01902 L
.63633 .01906 L
.63646 .01908 L
.63654 .01908 L
.63662 .01908 L
.63677 .01906 L
.63693 .01902 L
.63702 .01899 L
.63711 .01896 L
.6374 .0188 L
.63767 .0186 L
.63829 .01794 L
.6389 .01707 L
.63954 .01591 L
.63983 .01533 L
.63998 .01501 L
.64006 .01483 L
.64014 .01477 L
.64028 .01508 L
.64044 .01543 L
.64071 .01606 L
.64177 .01869 L
.64401 .02417 L
.64462 .02543 L
.64528 .02657 L
.6456 .02703 L
.64589 .02741 L
.64616 .02769 L
.64645 .02793 L
.6466 .02803 L
.64676 .02812 L
.64685 .02816 L
.64693 .02818 L
.64709 .02822 L
.64724 .02824 L
.64739 .02824 L
.64754 .02821 L
.64768 .02817 L
.64784 .0281 L
.64799 .02802 L
.64832 .02774 L
.64865 .02735 L
.64901 .02681 L
Mistroke
.64962 .02554 L
.65027 .02376 L
.65143 .0194 L
.65171 .0181 L
.65202 .01659 L
.65216 .01586 L
.65231 .01508 L
.65244 .01505 L
.65258 .01583 L
.65323 .01966 L
.65381 .02348 L
.65603 .04022 L
.65858 .06142 L
.6609 .07858 L
.66205 .0849 L
.6627 .08754 L
.66301 .08853 L
.6633 .08928 L
.66356 .08978 L
.66369 .08999 L
.66383 .09017 L
.66398 .09031 L
.66413 .09041 L
.66428 .09044 L
.66441 .09043 L
.66456 .09036 L
.66471 .09024 L
.66484 .09009 L
.66498 .08988 L
.66529 .08921 L
.66559 .08835 L
.66615 .08601 L
.66675 .08246 L
.66732 .07808 L
.66785 .07317 L
.66912 .05737 L
.67033 .03724 L
.67093 .0255 L
.67107 .02252 L
.67122 .0193 L
.67135 .01649 L
.67149 .01608 L
.67157 .01785 L
.67165 .01976 L
.6718 .02327 L
.67214 .0314 L
.67272 .04646 L
.67494 .11285 L
.67993 .29954 L
.68243 .39703 L
Mistroke
.68473 .47859 L
.68698 .54252 L
.68811 .56715 L
.68872 .57794 L
.68936 .58733 L
.68994 .59404 L
.69025 .59687 L
.69058 .59933 L
.69088 .60108 L
.69115 .60224 L
.69129 .60266 L
.69143 .60299 L
.69157 .6032 L
.69169 .60331 L
.69184 .60332 L
.69199 .6032 L
.69214 .60297 L
.69227 .60265 L
.69243 .60214 L
.6926 .60144 L
.69291 .59974 L
.69324 .59738 L
.69359 .59423 L
.69421 .58691 L
.69486 .57703 L
.69545 .56599 L
.6968 .53447 L
.69923 .45659 L
.704 .25311 L
.7064 .14364 L
.70745 .09789 L
.70859 .05084 L
.70889 .03878 L
.70922 .02629 L
.70935 .02125 L
.70949 .01589 L
.70965 .01934 L
.7098 .02471 L
.71094 .06373 L
.71215 .09924 L
.71347 .13083 L
.71408 .14272 L
.71472 .1535 L
.71528 .16121 L
.71589 .16788 L
.71625 .17101 L
.71658 .17335 L
.71689 .17511 L
.71705 .17584 L
.71722 .17649 L
Mistroke
.71738 .17695 L
.71752 .17729 L
.71767 .17753 L
.7178 .17767 L
.71796 .17774 L
.71811 .1777 L
.71818 .17765 L
.71827 .17756 L
.71835 .17743 L
.71844 .17728 L
.71858 .17696 L
.71873 .17652 L
.719 .17549 L
.71933 .17387 L
.71962 .17204 L
.72026 .1669 L
.72087 .16068 L
.72194 .14679 L
.7231 .12808 L
.72545 .0821 L
.72669 .0553 L
.72738 .04034 L
.72803 .02623 L
.72833 .01989 L
.72841 .01807 L
.72849 .01637 L
.72864 .01623 L
.72873 .01805 L
.72881 .01972 L
.72899 .02346 L
.72931 .03006 L
.73048 .05289 L
.73167 .0736 L
.73278 .09015 L
.73397 .10444 L
.73505 .11404 L
.73567 .11798 L
.73626 .12066 L
.73658 .1217 L
.73687 .12238 L
.73703 .12264 L
.73712 .12275 L
.7372 .12283 L
.73728 .1229 L
.73738 .12295 L
.73746 .12297 L
.73754 .12297 L
.73769 .12292 L
.73778 .12286 L
.73786 .12279 L
Mistroke
.738 .12261 L
.73815 .12236 L
.73841 .12178 L
.7387 .12091 L
.73933 .11819 L
.73993 .11468 L
.741 .10618 L
.74214 .09427 L
.74453 .06251 L
.74579 .04338 L
.74648 .03259 L
.74681 .02728 L
.74713 .02241 L
.74743 .01763 L
.74759 .01524 L
.74767 .01554 L
.74775 .0168 L
.74843 .02716 L
.74962 .04434 L
.75192 .07275 L
.75319 .08443 L
.75381 .08897 L
.75439 .09242 L
.75491 .09492 L
.75546 .09689 L
.75575 .09763 L
.75601 .09816 L
.75617 .09839 L
.75631 .09855 L
.75639 .09862 L
.75647 .09868 L
.75663 .09875 L
.7567 .09876 L
.75679 .09876 L
.75693 .09872 L
.75709 .09862 L
.75718 .09853 L
.75727 .09844 L
.75756 .098 L
.75772 .09766 L
.75787 .09731 L
.75845 .09548 L
.759 .09309 L
.76021 .0857 L
.76153 .07473 L
.76386 .04958 L
.76511 .03438 L
.76576 .02618 L
.76611 .02168 L
.76629 .0195 L
Mistroke
.76644 .01751 L
.7666 .01561 L
.76674 .01561 L
.76689 .0175 L
.76705 .01954 L
.76772 .02771 L
.76889 .04138 L
.77118 .06414 L
.77232 .07271 L
.77298 .07666 L
.77358 .0796 L
.77421 .08199 L
.77456 .08298 L
.77489 .08371 L
.77503 .08397 L
.77519 .0842 L
.77533 .08436 L
.77547 .0845 L
.77556 .08456 L
.77565 .0846 L
.77573 .08463 L
.77581 .08465 L
.77595 .08465 L
.77611 .0846 L
.77627 .08451 L
.77642 .08438 L
.77658 .0842 L
.77675 .08395 L
.77703 .08341 L
.77735 .08264 L
.77793 .08076 L
.77847 .07847 L
.77969 .07161 L
.78099 .06187 L
.78337 .03959 L
.78462 .02641 L
.78498 .02254 L
.78532 .01889 L
.78547 .0173 L
.78563 .01561 L
.78571 .01474 L
.7858 .01566 L
.78596 .01735 L
.78844 .0423 L
.79075 .06075 L
.79138 .06465 L
.79197 .06782 L
.79252 .07023 L
.7931 .07229 L
.79339 .07314 L
Mistroke
.79372 .07391 L
.79402 .07446 L
.7943 .07485 L
.79446 .07501 L
.79455 .07507 L
.79463 .07513 L
.79478 .07519 L
.79493 .07523 L
.79502 .07523 L
.79511 .07522 L
.79526 .07517 L
.79535 .07512 L
.79543 .07507 L
.79562 .07491 L
.79577 .07473 L
.79591 .07453 L
.79618 .07407 L
.79678 .07262 L
.79731 .07091 L
.79788 .06858 L
.79917 .06167 L
.80036 .05348 L
.80263 .03453 L
.80382 .02351 L
.80443 .01787 L
.80459 .01633 L
.80468 .01548 L
.80477 .01476 L
.80485 .0155 L
.80493 .01631 L
.80508 .01773 L
.80643 .02999 L
.80767 .04045 L
.80882 .04913 L
.8101 .05711 L
.81069 .06016 L
.81133 .06295 L
.81188 .0649 L
.81249 .06656 L
.81282 .06725 L
.81313 .06775 L
.8133 .06796 L
.81346 .06812 L
.81355 .06819 L
.81364 .06826 L
.81373 .06831 L
.81381 .06834 L
.81396 .06838 L
.81403 .06839 L
.81412 .06839 L
Mistroke
.8142 .06838 L
.81428 .06836 L
.81444 .0683 L
.81458 .0682 L
.81472 .06809 L
.81502 .06774 L
.81534 .06723 L
.81564 .06663 L
.8163 .06485 L
.81688 .06279 L
.8175 .06015 L
.81975 .04701 L
.82098 .03794 L
.82215 .02859 L
.8232 .01986 L
.82348 .01745 L
.82364 .01612 L
.82379 .01489 L
.82391 .01559 L
.82405 .01672 L
.82434 .01911 L
.82669 .03766 L
.828 .04645 L
.82922 .0532 L
.83044 .05835 L
.83108 .06034 L
.83141 .06116 L
.83177 .0619 L
.83211 .06244 L
.83226 .06263 L
.83242 .0628 L
.83256 .06293 L
.83272 .06303 L
.8328 .06308 L
.83288 .06311 L
.83304 .06315 L
.83318 .06315 L
.83332 .06314 L
.83347 .06309 L
.83363 .063 L
.83376 .06291 L
.83389 .06279 L
.83419 .06245 L
.83448 .062 L
.83475 .06148 L
.83537 .05996 L
.83598 .05803 L
.83662 .05552 L
.83885 .04363 L
.84125 .02691 L
Mistroke
.84191 .02195 L
.84227 .01921 L
.84261 .01664 L
.84275 .01551 L
.84289 .01498 L
.84297 .01557 L
.84305 .01621 L
.8432 .01732 L
.84385 .02225 L
.84638 .03969 L
.84748 .04598 L
.84867 .05156 L
.84931 .05395 L
.8499 .05576 L
.85046 .05712 L
.85077 .05772 L
.85105 .05816 L
.85135 .05853 L
.85152 .05869 L
.85167 .0588 L
.85182 .05889 L
.85195 .05894 L
.8521 .05897 L
.85226 .05898 L
.85241 .05896 L
.8525 .05893 L
.85258 .0589 L
.85273 .05882 L
.85289 .05871 L
.85322 .05838 L
.85358 .05787 L
.85422 .05661 L
.85482 .05499 L
.85595 .05095 L
.85716 .04526 L
.85848 .03781 L
.86088 .02192 L
.86146 .01784 L
.86163 .01666 L
.86179 .01554 L
.86193 .01489 L
.86209 .01598 L
.86277 .02075 L
.86341 .02511 L
.86575 .03947 L
.86699 .04563 L
.86764 .04834 L
.86833 .05077 L
.86893 .05252 L
.86925 .05329 L
Mistroke
.8696 .05399 L
.86991 .05452 L
.8702 .05491 L
.87034 .05507 L
.87049 .05521 L
.87062 .05532 L
.87076 .05541 L
.87091 .05548 L
.87104 .05553 L
.8712 .05556 L
.87134 .05556 L
.87149 .05554 L
.87158 .05551 L
.87166 .05548 L
.8718 .05541 L
.87196 .05531 L
.87225 .05504 L
.87253 .0547 L
.87306 .05383 L
.87362 .05258 L
.87423 .05085 L
.87548 .04627 L
.87771 .03504 L
.87891 .02779 L
.88006 .02051 L
.88037 .01853 L
.88069 .01641 L
.88086 .01531 L
.88096 .01475 L
.88105 .01534 L
.88138 .01747 L
.88258 .02509 L
.88481 .03775 L
.88607 .04357 L
.88669 .04594 L
.88725 .04782 L
.88781 .0494 L
.88842 .05078 L
.88875 .05139 L
.88906 .05184 L
.88935 .05219 L
.88952 .05234 L
.88966 .05246 L
.88982 .05255 L
.88997 .05262 L
.89012 .05267 L
.89021 .05268 L
.89029 .05269 L
.89044 .05269 L
.89057 .05267 L
Mistroke
.89073 .05262 L
.89088 .05255 L
.89104 .05244 L
.89121 .05231 L
.89152 .05199 L
.89185 .05153 L
.89221 .05092 L
.89284 .04953 L
.89344 .04787 L
.89457 .04393 L
.89709 .03183 L
.89826 .02518 L
.8989 .02138 L
.8995 .01776 L
.89974 .01626 L
.89988 .01544 L
.90001 .01475 L
.90014 .01558 L
.90029 .01648 L
.90055 .01806 L
.90172 .02493 L
.90398 .03683 L
.90518 .04189 L
.90644 .04605 L
.90708 .04765 L
.90741 .04835 L
.90778 .04898 L
.90811 .04945 L
.90842 .04978 L
.90856 .04991 L
.90872 .05003 L
.90887 .05011 L
.90901 .05018 L
.90915 .05022 L
.9093 .05024 L
.90944 .05025 L
.90957 .05023 L
.90972 .0502 L
.90988 .05014 L
.91004 .05005 L
.91019 .04995 L
.91051 .04966 L
.9108 .04931 L
.91145 .04825 L
.91203 .04698 L
.91265 .04531 L
.91376 .04155 L
.91626 .03011 L
.9174 .024 L
.91803 .0205 L
Mistroke
.91834 .01876 L
.91862 .01713 L
.91889 .01561 L
.91904 .01477 L
.91917 .01543 L
.91978 .01883 L
.92083 .02464 L
.92206 .03095 L
.92335 .03684 L
.92455 .04136 L
.92513 .0432 L
.92566 .04463 L
.92618 .04579 L
.92674 .04679 L
.92704 .04722 L
.92733 .04755 L
.9276 .04779 L
.92775 .0479 L
.92788 .04798 L
.92802 .04804 L
.92817 .04809 L
.92832 .04812 L
.9284 .04813 L
.92848 .04813 L
.92862 .04812 L
.92875 .04809 L
.9289 .04804 L
.92904 .04798 L
.9292 .04788 L
.92936 .04776 L
.92965 .04748 L
.92997 .0471 L
.93032 .04658 L
.93095 .04537 L
.93154 .04392 L
.93266 .04047 L
.93518 .02984 L
.93634 .024 L
.93698 .02066 L
.93758 .01748 L
.93785 .01602 L
.93799 .01528 L
.93814 .01495 L
.93822 .01538 L
.9383 .01583 L
.93846 .01664 L
.93874 .01818 L
.9398 .02367 L
.9422 .03478 L
.94355 .03971 L
Mistroke
.94419 .04163 L
.9448 .04314 L
.94538 .04433 L
.94591 .04517 L
.94619 .04553 L
.9465 .04583 L
.94667 .04597 L
.94682 .04607 L
.94697 .04615 L
.94713 .04621 L
.94721 .04624 L
.9473 .04626 L
.94745 .04627 L
.94754 .04628 L
.94762 .04627 L
.94771 .04626 L
.9478 .04624 L
.94788 .04622 L
.94797 .04619 L
.94813 .04611 L
.94829 .04602 L
.94843 .04591 L
.949 .04533 L
.94929 .04493 L
.94961 .04441 L
.95083 .0417 L
.95194 .03829 L
.95446 .02797 L
.95556 .02267 L
.95617 .01965 L
.95674 .01676 L
.9569 .01596 L
.95706 .01511 L
.95715 .01476 L
.95725 .01525 L
.95742 .0161 L
.95803 .01919 L
.95924 .02505 L
.96054 .03088 L
.96178 .0357 L
.96298 .03952 L
.96357 .04103 L
.9641 .04218 L
.96462 .0431 L
.96518 .04386 L
.96549 .04417 L
.96563 .04428 L
.96578 .04438 L
.96591 .04446 L
.96605 .04453 L
Mistroke
.9662 .04458 L
.96634 .04461 L
.96642 .04463 L
.9665 .04463 L
.96665 .04463 L
.96674 .04462 L
.96682 .04461 L
.9669 .04459 L
.96699 .04456 L
.96715 .0445 L
.96732 .04441 L
.96762 .04419 L
.9679 .04391 L
.96817 .04359 L
.96878 .04267 L
.96939 .04146 L
.97005 .03986 L
.97125 .03621 L
.97349 .02735 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017oooooool0
000=o`0000?ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00Oooool0
00Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool3
o`0000Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo0_l00?l3ooooo`;o003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00ol00?l4ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool00_ooool4o`00o`03ooooool00?oo003o00Cooooo00?o003oooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Ko003oooooool00?oo003ooooo
ool00?l4ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool00_ooool00ol00?oooooo
o`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`02ooooo`;o003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`?o00000oooool000Wooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`;o003o0oooool2o`00o`?ooooo
0_l00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00ol00?l4ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool00_ooool7o`00o`?ooooo0_l00?l4ooooo`03o`00
0?oooooooooo00;ooooo00Co003ooooooooooooooooo0_l00?l00ooooooo003oo`00o`02o`00o`Co
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`02ooooo`?o003o0_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool00_ooool2o`00o`Co
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`;o003o0oooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01?ooool01ol00?oooooooooooooooooo003oooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool2
o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l4ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`02ooooo`?o003o0_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooooooool3o`00o`?ooooo0_l00?l4ooooo`03o`000?oooooooooo00;ooooo00Co
003ooooooooooooooooo0ol00?l4ooooo`05o`00ooooooooooooooooool00?l02Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Co003oooooool00?oo003o0oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00;ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool00ol00?ooooooooooo`04
ooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`04oooo
o`07o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00;ooooo0_l0
0?l4ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l0
0?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`02ooooo`?o003o0oooool01Ol00?oooooooooooooooooo003o00Wooooo0_l00?l3ooooo`03o`00
oooooooooooo00?ooooo00Co003ooooooooooooooooo0_l00?l4ooooo`03o`000?oooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`06ooooo`05o`00ooooooooooooooooool00?l02Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?l00ooooooo003oooooo`02ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool00_ooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0ooo
ool2o`00o`Cooooo00Co003ooooooooooooooooo0_l00?l3ooooo`;o003o1?ooool00ol00?oooooo
ooooo`02ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`04ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00;o
oooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`03ooooo`;o003o0oooool2o`00o`?o
oooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`Co
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`07ooooo`05o`00oooooooooooooooo
ool00?l01_ooool01Ol00?oooooooooooooooooo003o00Wooooo0_l00?l2ooooo`03o`00oooooooo
oooo00Cooooo00Co003ooooooooooooooooo0_l00?l4ooooo`04o`000?ooooooooooooooo`;o003o
0oooool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l02Oooool01Ol00?oo
oooooooooooooooo003o00Kooooo00Go003oooooooooooooooooo`00o`09ooooo`03o`00oooooooo
oooo00;ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool0
0ol00?ooooooo`00o`02ooooo`;o003o1?ooool00ol00?ooooooooooo`02ooooo`;o003o0_ooool0
0ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo0_l00?l3ooooo`;o003o0oooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
00Gooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`03o`00oooooooo003o00;ooooo00?o
003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo0_l0
0?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l0
0?l3ooooo`;o003o1?ooool00ol00?ooooooooooo`07ooooo`05o`00ooooooooooooooooool00?l0
1_ooool01?l00?ooooooooooooooool2o`00o`Sooooo0_l00?l2ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool00_l00?l4ooooo`04o`000?ooooooooooooooo`;o003o0_ooool00ol0
0?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l02Oooool01Ol00?oooooooooooooo
oooo003o00Kooooo00Go003oooooooooooooooooo`00o`09ooooo`03o`00oooooooooooo00;ooooo
0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool00ol00?oooooo
o`00o`02ooooo`03o`00oooooooo003o00;ooooo00?o003oooooool00?l00_ooool00ol00?oooooo
o`00o`02ooooo`03o`00oooooooo003o00;ooooo00?o003oooooool00?l00oooool2o`00o`;ooooo
00Ko003ooooooooooooo003oooooool00?l7ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Gooooo00?o003oooooool00?l00_ooool01_l00?ooooooooooool00?oooooo
o`00o`;ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo
003o00;ooooo00?o003oooooool00?l00oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2
o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`Cooooo00?o003oooooooooool01oooool0
1Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00_l00?l8ooooo`;o003o0_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;o003o1?ooool01?l0003ooooooooo
ooooool2o`00o`;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02o`00o`Wooooo
0_l00?l2ooooo`03o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`09ooooo`03
o`00oooooooooooo00;ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`03
o`00oooooooo003o00;ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03
o`00oooooooo003o00;ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03
o`00oooooooo003o00;ooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`03o`00oooooooo
003o00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01_ooool2o`00
o`?ooooo0_l00?l3ooooo`05o`00oooooooo003oooooool00?l00_ooool01_l00?ooooooooooool0
0?ooooooo`00o`;ooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?o
oooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`Co
oooo00?o003oooooooooool01oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003ooooo
ooooool00_l00?l8ooooo`;o003o00?oooooo`00ooooool01oooool00ol00?ooooooooooo`02o`00
o`Cooooo00Co0000oooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00Kooooo00Co003o
ooooool00?oo003o2Oooool2o`00o`;ooooo00?o003oooooooooool01?ooool01?l00?oooooooooo
ooooool2o`00o`Sooooo00?o003oooooooooool00_ooool2o`00o`?ooooo0_l00?l3ooooo`;o003o
0oooool2o`00o`?ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03o`00
oooooooo003o00;ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`06o`00
ooooooooooooo`00oooooooo003o0_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o
00;ooooo0ol00?l7ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001oooool2o`00o`?o
oooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo00?o003oooooool00?l00_ooool00ol00?oo
ooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`03oooo
o`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`Cooooo00?o003ooooo
ooooool01oooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003oooooool00?ooooooo`00
o`08ooooo`;o003o00?oooooo`00ooooool01oooool00ol00?ooooooooooo`02o`00o`Cooooo00Co
0000oooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00Kooooo00Co003oooooool00?oo
003o2?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooo
oooooooo0_l00?l8ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00
o`?ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooool00?l00_ooool01_l00?ooooooooooool00?ooooooo`00o`;ooooo0ol0
0?l2ooooo`?o003o0_ooool2o`00o`Cooooo00?o003oooooooooool01Oooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo013ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo00?o003o
ooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l00_oo
ool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo0_l00?l3ooooo`;o003o0ooo
ool2o`00o`Cooooo00?o003oooooooooool01oooool01Ol00?oooooooooooooooooo003o00Oooooo
00Go003oooooool00?ooooooo`00o`08ooooo`;o003o00?oooooo`00ooooool01oooool00ol00?oo
ooooooooo`02o`00o`Cooooo00Wo0000ooooooooooooooooo`00oooooooo003oooooool00?l02?oo
ool01?l00?ooooooo`00ool00?l8ooooo`05o`00oooooooo003oooooool00?l01oooool01?l00?oo
ooooooooooooool2o`00o`Sooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3oooo
o`;o003o0oooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00;ooooo00Go003ooooo
ool00?ooooooo`00o`03ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o4_ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Jooooo`;o003o0oooool2o`00
o`?ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o
00;ooooo00Go003oooooool00?ooooooo`00o`03ooooo`;o003o0oooool00ol00?ooooooo`00o`02
ooooo`;o003o0oooool2o`00o`Wooooo0_l00?l2ooooo`03o`00oooooooooooo00Gooooo00Go003o
ooooool00?ooooooo`00o`08ooooo`04o`00oooooooo003oo`00o`Wooooo0_l00?l00ooooooo003o
ooooo`03ooooo`09o`000?ooooooooooooooool00?ooooooo`00oooooooo003o00Sooooo00Go003o
ooooool00?ooooooo`00o`07ooooo`05o`00oooooooo003oooooool00?l02?ooool00ol00?oooooo
ooooo`02o`00o`Sooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l2ooooo`04o`00
ooooooooooooo`00o`;ooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o
00;ooooo0ol00?l3ooooo`;o003o0oooool2o`00oacooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool07oooool2o`00o`?ooooo0_l00?l3ooooo`03o`00oooooooo003o00;o
oooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00?ooooo0_l00?l3oooo
o`03o`00oooooooo003o00;ooooo0_l00?l3ooooo`;o003o2Oooool2o`00o`;ooooo00?o003ooooo
ooooool01_ooool2o`00o`03ooooool00?oooooo00Oooooo00Co003oooooool00?oo003o2Oooool2
o`00o`03ooooool00?oooooo00?ooooo00Ko0000ooooooooooooooooo`00ooooool2o`00o`[ooooo
00Co003ooooooooooooo003o1oooool01Ol00?ooooooo`00oooooooo003o00Sooooo00?o003ooooo
ooooool00_l00?l8ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`05o`00oooooooo003o
ooooool00?l00_ooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o0oooool2o`00o`?o
oooo0_l00?l3ooooo`;o003o8Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`0Uooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooo`00o`02ooooo`03
o`00oooooooo003o00;ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooo003o00;o
oooo0_l00?l3ooooo`;o003o2?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00Ko
oooo0_l00?l00ooooooo003oooooo`07ooooo`03o`00oooooooooooo00[ooooo0_l00?l00ooooooo
003oooooo`03ooooo`06o`000?ooooooooooooooool00?oooooo0_l00?l=ooooo`03o`00oooooooo
oooo00Gooooo00Co003oooooool00?oo003o2Oooool00ol00?ooooooooooo`02o`00o`Sooooo0_l0
0?l3ooooo`;o003o0oooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l0
0_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo0_l00?l3ooooo`;o003o
9_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Zooooo`07o`00oooo
ooooooooooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool0
0?ooooooo`00o`03ooooo`03o`00oooooooo003o00;ooooo0_l00?l3ooooo`;o003o2?ooool01Ol0
0?ooooooo`00oooooooo003o00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`0@ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`02o`00o`Sooooo0_l0
0?l3ooooo`;o003o0oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l0
0_ooool00ol00?ooooooo`00o`03ooooo`;o003o0oooool2o`00ob_ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0;oooool01ol00?oooooooooooooooooo003oooooool0
0?l00_ooool00ol00?ooooooo`00o`02ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool2
o`00o`?ooooo0_l00?l8ooooo`05o`00oooooooo003oooooool00?l03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool01Ol0003ooooooooo
oooooooo003o013ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0:ooooo`05o`00
oooooooo003oooooool00?l02?ooool2o`00o`?ooooo0_l00?l3ooooo`05o`00oooooooo003ooooo
ool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo0_l00?l`oooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o0000=?ooool3o`00o`;ooooo00?o003oooooool0
0?l00_ooool01_l00?ooooooooooool00?ooooooo`00o`;ooooo00?o003oooooool00?l00_ooool2
o`00o`Sooooo00Go003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`05o`000?ooooooooooooooool00?l0
4?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00[ooooo00Go003oooooool00?oo
ooooo`00o`08ooooo`;o003o0oooool2o`00o`?ooooo00Go003oooooool00?ooooooo`00o`02oooo
o`03o`00oooooooo003o00?ooooo0_l00?ldooooo`;o00000oooool0017ooooo00?o0000oooooooo
ool0=?ooool01ol00?oooooooooooooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`02
ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool2o`00o`Sooooo00Go003oooooool00?oo
ooooo`00o`0<ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`02ooooo`04o`000?ooooooooooo`00oa7ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0:ooooo`05o`00oooooooo003oooooool00?l02?ooool2o`00o`?ooooo0_l00?l3
ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`03ooooo`;o003o=Ooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0hooooo`03o`00oooooooo
003o00;ooooo00?o003oooooool00?l00_ooool01_l00?ooooooooooool00?ooooooo`00o`;ooooo
0_l00?l8ooooo`05o`00oooooooo003oooooool00?l03?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool01?l0003oooooooooool00?lAoooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool01Ol00?ooooooo`00oooooooo
003o00Sooooo0_l00?l3ooooo`;o003o0oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o
003oooooool00?l0>_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0i
ooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`06o`00ooooooooooooo`00oooooooo003o
0_ooool2o`00o`Sooooo00Co003oooooool00?oo003o3Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool01?l0003oooooooooool00?lAoooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool01Ol00?ooooooo`00oooooooo
003o00Sooooo0_l00?l3ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00
o`03ooooo`03o`00oooooooooooo03Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0?Oooool00ol00?ooooooo`00o`02ooooo`06o`00ooooooooooooo`00oooooooo003o
0_ooool2o`00o`Sooooo00Co003oooooool00?oo003o3Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool01?l0003oooooooooool00?lAoooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool2o`00o`03ooooool00?oooooo
00Oooooo0_l00?l3ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0o
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo03kooooo0_l00?l2oooo
o`03o`00oooooooo003o00;ooooo00?o003oooooooooool00_l00?l8ooooo`04o`00oooooooooooo
o`00o`kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo00;ooooo00Co0000oooooooooooo003o4Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00_ooooo0_l00?l00ooooooo003oooooo`07ooooo`;o003o0oooool01Ol00?ooooooo`00
oooooooo003o00;ooooo00?o003oooooool00?l0?oooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0nooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooo
oooooooo00;o003o2?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`04o`000?ooooooooooo`00oa7ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo
0_l00?l3ooooo`05o`00oooooooo003oooooool00?l00_ooool3o`00ocoooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0?_ooool2o`00o`;ooooo00?o003oooooool00?l0
0_ooool00ol00?ooooooooooo`02o`00o`Sooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00oooooo00Go003oooooooooooooooooo`000002ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Kooooo0_l00?l3ooooo`05o`00oooooooo003oooooool00?l00oooool00ol0
0?ooooooooooo`0nooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000@oooool00ol00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00;o003o2?ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool01Ol00?oooooooooooooooooo0000
00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool01_ooool2o`00o`?ooooo00Go003oooooool00?ooooooo`00o`13
ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0@_ooool00ol00?ooooooo`00o`02oooo
o`03o`00oooooooooooo00;o003o2?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03oooool01Ol00?oooooooooooooooooo000000;ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01_ooool2o`00o`?ooooo00Go003oooooool00?ooooooo`00o`14ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo04;ooooo00?o003oooooool00?l00_ooool0
0ol00?ooooooooooo`02o`00o`Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00oooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Kooooo0_l00?l2ooooo`06o`00ooooooooooooo`00oooooooo003oA?ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`13ooooo`;o003o0_ooool00ol00?oooooo
ooooo`02o`00o`Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00oooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Ko
oooo0_l00?l2ooooo`06o`00ooooooooooooo`00oooooooo003oA?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`13ooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00
o`Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Kooooo0_l00?l2
ooooo`03o`00oooooooooooo00;o003oAOooool00ol0003oooooooooo`01ooooo`002?ooool5o`00
00Cooooo00?o0000ooooooooool0@oooool2o`00o`;ooooo00?o003oooooooooool00_l00?l8oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`05o`00ooooooooooooooooool000000_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06ooooo`;o003o0_ooool0
1Ol00?oooooooooooooooooo003o04Gooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`13ooooo`05o`00ooooooooooooooooool00?l0
0_ooool2o`00o`Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo013ooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Ko
oooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l0AOooool00ol0003oooooooooo`01oooo
o`002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Oooooo00?o003ooooooooo
ool00_l00?l8ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0@ooooo`05o`00ooooooooooooooooool000000_ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06oooo
o`;o003o0_ooool00ol00?ooooooooooo`17ooooo`03o`000?oooooooooo007ooooo000;ooooo`03
o`000?oooooooooo00?ooooo0ol00017ooooo`03o`00oooooooooooo00;o003o2?ooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool01Ol00?oo
oooooooooooooooo000000;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool01_ooool2o`00o`;ooooo00?o003ooooo
ooooool0AOooool3o`0000?ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`17ooooo`03o`00oooooooooooo00;o003o2?ooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool01Ol00?oooooooooooooooooo
000000;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool01_ooool2o`00o`;ooooo00?o003oooooooooool0Aoooool0
0ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0Aoooool00ol00?ooooooooooo`02o`00o`Sooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00Go003oooooooooooooooooo`00
0002ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo00Kooooo00Go003oooooool00?ooooooo`00o`19ooooo`03o`00
0?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`17ooooo`03o`00oooo
oooooooo00;o003o2?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04?ooool01Ol00?oooooooooooooooooo000000;ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
1_ooool01Ol00?ooooooo`00oooooooo003o04Wooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0Aoooool00ol00?ooooooooooo`02o`00o`Sooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00Go003ooooooooooooo
ooooo`000002ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00Kooooo00Go003oooooool00?ooooooo`00o`19oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Sooooo00Co003oooooool0
0?oo003o2?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool04?ooool01Ol00?oooooooooooooooooo000000;ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01_ooool0
1Ol00?ooooooo`00oooooooo003o04Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0B?ooool01?l00?ooooooo`00ool00?l8ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`05o`00ooooooooooooooooool00000
0_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`06ooooo`05o`00oooooooo003oooooool00?l0BOooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`18ooooo`;o003o00?oooooo`00ooooool0
1oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
4?ooool01Ol00?oooooooooooooooooo000000;ooooo00?o003oooooooooool04?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01_ooool01?l00?oo
ooooo`00ool00?m:ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000BOooool2o`00o`03
ooooool00?oooooo00Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo013ooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00Gooooo00Co003oooooool00?oo003oBOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo
04Sooooo0_l00?l00ooooooo003oooooo`07ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0@ooooo`05o`00ooooooooooooooooool000000_ooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`05ooooo`04o`00oooooooo003oo`00od[ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0B?ooool2o`00o`03ooooool00?oooooo00Oooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00Go003o
ooooooooooooooooo`000002ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Gooooo00Co003oooooool00?oo003o
B_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`18ooooo`;o003o00?o
ooooo`00ooooool01oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04Oooool01_l00?ooooooooooool0003oooooo`00oa?ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Gooooo00Co003oooooool0
0?oo003oB_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`18ooooo`;o
003o0_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0Aooooo`06o`00ooooooooooooo`000?oooooo003o4oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01Oooool0
1?l00?ooooooo`00ool00?m:ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo04cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool04Oooool01_l00?ooooooooooool0003oooooo`00oa?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool0Boooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1<ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo017ooooo00Ko003ooooooooooooo0000ooooool00?lCooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo04_ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo017ooooo00Ko003ooooooooooooo0000ooooool00?lCooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
04[ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017o
oooo00Ko003ooooooooooooo0000ooooool00?lCooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04_ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo013ooooo00Go003oooooooooooooooooo`00o`0Dooooo`06o`00oooooooo
ooooo`000?oooooo003o5?ooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo04cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0@ooooo`05o`00
ooooooooooooooooool00?l05?ooool01_l00?ooooooooooool0003oooooo`00oaCooooo00Go003o
ooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0C?oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01Cooooo00Ko
003ooooooooooooo0000ooooool00?lDooooo`05o`00ooooooooooooooooool00?l04oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo017o
oooo00Go003oooooooooooooooooo`00o`0Dooooo`06o`00ooooooooooooo`000?oooooo003o5?oo
ool01Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l0
5?ooool01_l00?ooooooooooool0003oooooo`00oaCooooo00Go003oooooooooooooooooo`00o`0C
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool04Oooool01Ol00?oooooooooooooooooo003o01Cooooo00Ko003ooooooooooooo0000oooo
ool00?lDooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001=ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01Co
oooo00Ko003ooooooooooooo0000ooooool00?lDooooo`05o`00ooooooooooooooooool00?l04ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04_ooooo0_l00003ooooo`004Oooool0
0ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04Oooool0
1Ol00?oooooooooooooooooo003o01Gooooo00Co003oooooool0003o003o5Oooool01Ol00?oooooo
oooooooooooo003o01?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1<ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l05Oooool01?l00?oo
ooooo`000?l00?lEooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo017ooooo00Go003ooooo
ooooooooooooo`00o`0Eooooo`04o`00oooooooo0000o`00oaGooooo00Go003ooooooooooooooooo
o`00o`0Cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0C?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01Gooooo00Co003oooooool0003o
003o5Oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Aooooo`05o`00oooooooooooooooo
ool00?l05Oooool01?l00?ooooooo`000?l00?lEooooo`05o`00ooooooooooooooooool00?l04ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Ooo
ool000[ooooo0ol00004ooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l05Oooool01?l00?ooooooo`00
0?l00?lEooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool000_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
4_ooool01?l00?ooooooooooool00?lEooooo`04o`00oooooooo0000o`00oaGooooo00Go003ooooo
ooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0C?ooool0
0ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo0ol0001<ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool04_ooool01?l00?ooooooooooool00?lEooooo`04o`00oooooooo
0000o`00oaGooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool0B_ooool3o`0000?ooooo0008ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01;ooooo
00Co003ooooooooooooo003o5Oooool01?l00?ooooooo`000?l00?lEooooo`05o`00oooooooooooo
ooooool00?l04oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04cooooo00?o0000
ooooooooool00Oooool000Wooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`1<oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool01?l00?ooooooooooool00?lE
ooooo`04o`00oooooooo0000o`00oaGooooo00Go003oooooooooooooooooo`00o`0Dooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`01ooooo`002_oo
ool2o`0000Gooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo01;ooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooo`000?l00?lEooooo`05
o`00ooooooooooooooooool00?l05?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
04cooooo00?o0000ooooooooool00Oooool000_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol00?oo
ooooo`00o`0Fooooo`04o`00oooooooo0000o`00oaGooooo00Go003oooooooooooooooooo`00o`0D
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooo`00o`0Fooooo`04o`00oooooooo0000o`00oaKooooo00Co003o
oooooooooooo003o5?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04cooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooool00?l05_ooool01?l00?ooooooo`000?l0
0?lFooooo`03o`00oooooooo003o01Gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo003o01Kooooo00Co003o
ooooool0003o003o5_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool0C?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo003o01Kooooo00Co003o
ooooool0003o003o5_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool0Boooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo003o01Oooooo00?o003o
o`000?l00?l05_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0C?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1<oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol00?ooooooo`00o`0Goooo
o`03o`00ool0003o003o01Kooooo00?o003oooooool00?l05Oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01;ooooo00?o003oooooool0
0?l05oooool00ol00?oo0000o`00o`0Fooooo`03o`00oooooooo003o01Gooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo04cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooo003o01Oooooo00?o003oo`000?l00?l05_ooool00ol00?ooooooo`00o`0Eooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04ooo
ool2o`00oaOooooo0_l00?lGooooo`03o`00oooooooo003o01Gooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo04cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Cooooo`;o003o5oooool2
o`00oaOooooo0ol00?lEooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0C?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool04oooool2o`00oaOooooo0_l00?lHooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo
007ooooo000Aooooo`;o0000COooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01?o
oooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1;ooooo`;o00000oooool0017ooooo
00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo
00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04cooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo00?o0000
ooooooooool0;Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04cooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo00?o0000oooooooo
ool0;Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04cooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001=ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool0Boooool2o`0000?ooooo000Aooooo`03o`000?oooooo
oooo04cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooo
oooo02gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo02go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04gooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo007ooooo0009
ooooo`?o00001Oooool00ol0003oooooooooo`1=ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0COooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo02gooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo04gooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004
ooooo`?o0000COooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02gooooo00?o0000
ooooooooool0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04_ooooo0ol00003
ooooo`002?ooool4o`0000Gooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo04gooooo00?o0000ooooooooool00Oooool000Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1=ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool0;Oooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0COooool00ol0003oooooooooo`01ooooo`002Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0]ooooo`03o`00
0?oooooooooo02gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1=ooooo`03o`00
0?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`1=ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0COooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`1=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0;_ooool0
0ol0003oooooooooo`0]ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0COooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1=ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0COooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0;_ooool00ol0003o
ooooooooo`0]ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0COooool00ol0003o
ooooooooo`01ooooo`004Oooool2o`0004kooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1<ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0COooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo02kooooo00?o0000ooooooooool0;Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo04gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0COooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02kooooo00?o0000
ooooooooool0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04gooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo02kooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo04gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0COooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02kooooo00?o0000oooooooo
ool0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04gooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo02kooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo04gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0COoo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02kooooo00?o0000ooooooooool0;Ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04gooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo02kooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo04gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001>ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0C?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04go
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo02go
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1=ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0^
ooooo`03o`000?oooooooooo02kooooo00Go003oooooooooooooooooo`00o`1?ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo04kooooo00Go003oooooooooooooooooo`00
o`0`ooooo`03o`000?oooooooooo02kooooo00Go003oooooooooooooooooo`00o`1?ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04kooooo00Go003ooooooooooooooooo
o`00o`0`ooooo`03o`000?oooooooooo02kooooo00Go003oooooooooooooooooo`00o`1?ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o0000Coooool01Ol00?oooooooooooooooooo003o033o
oooo00?o0000ooooooooool0;_ooool01Ol00?oooooooooooooooooo003o04kooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool00?l0<?ooool00ol0
003oooooooooo`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool00?l0<?ooool0
0ol0003oooooooooo`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool00?l0<?oo
ool00ol0003oooooooooo`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool00?l0
<?ooool00ol0003oooooooooo`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool0
0?l0<?ooool00ol0003oooooooooo`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0
003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool0C_ooool01Ol00?oo
oooooooooooooooo003o033ooooo00?o0000ooooooooool0;_ooool01Ol00?oooooooooooooooooo
003o04oooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo04kooooo00Go003oooooooooooooooooo`00o`0`ooooo`03o`000?oo
oooooooo02kooooo00Go003oooooooooooooooooo`00o`1?ooooo`03o`000?oooooooooo007ooooo
0008ooooo`05o`000?ooooooooooooooool000001?ooool3o`0004kooooo00Go003ooooooooooooo
ooooo`00o`0`ooooo`03o`000?oooooooooo02kooooo00Go003oooooooooooooooooo`00o`1=oooo
o`?o00000oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo04kooooo00Go003ooooooooo
ooooooooo`00o`0`ooooo`03o`000?oooooooooo02kooooo00Go003oooooooooooooooooo`00o`1?
ooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool00?l0<?ooool00ol0003ooooooooo
o`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0003oooooooooo`01ooooo`002?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0C_ooool01Ol00?oooooo
oooooooooooo003o033ooooo00?o0000ooooooooool0;_ooool01Ol00?oooooooooooooooooo003o
04oooooo00?o0000ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo04ko
oooo00Go003oooooooooooooooooo`00o`0`ooooo`03o`000?oooooooooo02kooooo00Co003ooooo
oooooooo003oD?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>oooo
o`05o`00ooooooooooooooooool00?l0<?ooool00ol0003oooooooooo`0^ooooo`04o`00oooooooo
ooooo`00oe3ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C_ooool0
1?l00?ooooooooooool00?laooooo`03o`000?oooooooooo02kooooo00Co003ooooooooooooo003o
D?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`04o`00oooo
ooooooooo`00oc7ooooo00?o0000ooooooooool0;_ooool01?l00?ooooooooooool00?m@ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o0000Coooool01?l00?ooooooooooool00?laooooo`03
o`000?oooooooooo02kooooo00Co003ooooooooooooo003oCoooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo04kooooo00Co003ooooooooooooo003o<Oooool00ol0003oooooooooo`0^oooo
o`04o`00ooooooooooooo`00oe3ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0C_ooool01?l00?ooooooooooool00?laooooo`03o`000?oooooooooo02kooooo00Co003o
oooooooooooo003oD?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>
ooooo`04o`00ooooooooooooo`00oc7ooooo00?o0000ooooooooool0;_ooool01?l00?oooooooooo
ool00?m@ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04kooooo00Co
003ooooooooooooo003o<Oooool00ol0003oooooooooo`0^ooooo`04o`00ooooooooooooo`00oe3o
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C_ooool01?l00?oooooo
ooooool00?laooooo`03o`000?oooooooooo02kooooo00Co003ooooooooooooo003oD?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`04o`00ooooooooooooo`00
oc7ooooo00?o0000ooooooooool0;_ooool01?l00?ooooooooooool00?m@ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo04kooooo00Co003ooooooooooooo003o<Oooool0
0ol0003oooooooooo`0^ooooo`04o`00ooooooooooooo`00oe3ooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l0001?ooooo`04o`00ooooooooooooo`00oc7ooooo00?o0000ooooooooool0;_oo
ool01?l00?ooooooooooool00?m?ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0C_oo
ool01?l00?ooooooooooool00?laooooo`03o`000?oooooooooo02kooooo00Co003ooooooooooooo
003oD?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`04o`00
ooooooooooooo`00oc7ooooo00?o0000ooooooooool0;_ooool01?l00?ooooooooooool00?m@oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04kooooo00Co003ooooooooo
oooo003o<Oooool00ol0003oooooooooo`0^ooooo`04o`00ooooooooooooo`00oe3ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C_ooool01?l00?ooooooooooool00?la
ooooo`03o`000?oooooooooo02oooooo00?o003oooooool00?l0D?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1>ooooo`04o`00ooooooooooooo`00oc7ooooo00?o0000
ooooooooool0;oooool00ol00?ooooooo`00o`1@ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo04oooooo00?o003oooooool00?l0<Oooool00ol0003oooooooooo`0_oooo
o`03o`00oooooooo003o053ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0Coooool00ol00?ooooooo`00o`0aooooo`03o`000?oooooooooo02oooooo00?o003oooooool0
0?l0D?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`00053ooooo00?o003oooooool00?l0
<Oooool00ol0003oooooooooo`0_ooooo`03o`00oooooooo003o04oooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`1?ooooo`03o`00oooooooo003o037ooooo00?o0000ooooooooool0;ooo
ool00ol00?ooooooo`00o`1@ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo04oooooo0_l00?lbooooo`03o`000?oooooooooo02oooooo00?o003oooooool00?l0D?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1?ooooo`;o003o<_ooool00ol0
003oooooooooo`0_ooooo`03o`00oooooooo003o053ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0Coooool2o`00oc;ooooo00?o0000ooooooooool0;oooool2o`00oe7o
oooo00?o0000ooooooooool00Oooool000?ooooo0ol00004ooooo`;o00001Oooool00ol0003ooooo
ooooo`1?ooooo`;o003o<_ooool00ol0003oooooooooo`0_ooooo`;o003oDOooool00ol0003ooooo
ooooo`01ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0Coooool2o`00oc;ooooo00?o0000ooooooooool0;oooool2o`00oe7ooooo
00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00004ooooo`?o0000Coooool2o`00oc;ooooo00?o0000ooooooooool0;oooool2o`00odoooooo
0ol00003ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0Coooool2o`00oc;ooooo00?o0000ooooooooool0;oooool2o`00oe7ooooo
00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo04oooooo0_l00?lbooooo`03o`000?oooooooooo033ooooo
00?o003oooooooooool0Coooool00ol0003oooooooooo`01ooooo`000oooool2o`0000Cooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooooooo`0000go00000oooool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -1.04481, \
0.0394232, 0.0642988}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampled waveform (finite-length)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(xd = \ sampler[x, fs]; \ 
    If[OddQ[Length[xd]], \ xd\  = \ Drop[xd, \(-1\)]];\), "\n", 
    \(\(gxn\  = \ 
        DiscreteListPlot[xd, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, 
          PlotRange -> {All, 
              Evaluate[\(AbsoluteOptions[gxt, PlotRange]\)[\([1, 2, 
                    2]\)]]}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0.196383 0.0581337 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15079 -0.0125 -3 -9 ]
[.15079 -0.0125 3 0 ]
[.27778 -0.0125 -3 -9 ]
[.27778 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.53175 -0.0125 -3 -9 ]
[.53175 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.9127 -0.0125 -6 -9 ]
[.9127 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -12 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .31265 -6 -4.5 ]
[-0.0125 .31265 0 4.5 ]
[-0.0125 .42892 -6 -4.5 ]
[-0.0125 .42892 0 4.5 ]
[-0.0125 .54519 -6 -4.5 ]
[-0.0125 .54519 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15079 0 m
.15079 .00625 L
s
[(2)] .15079 -0.0125 0 1 Mshowa
.27778 0 m
.27778 .00625 L
s
[(4)] .27778 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(6)] .40476 -0.0125 0 1 Mshowa
.53175 0 m
.53175 .00625 L
s
[(8)] .53175 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(12)] .78571 -0.0125 0 1 Mshowa
.9127 0 m
.9127 .00625 L
s
[(14)] .9127 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.5 0 m
.5 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(-2)] -0.0125 .08012 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(0)] -0.0125 .19638 1 0 Mshowa
0 .31265 m
.00625 .31265 L
s
[(2)] -0.0125 .31265 1 0 Mshowa
0 .42892 m
.00625 .42892 L
s
[(4)] -0.0125 .42892 1 0 Mshowa
0 .54519 m
.00625 .54519 L
s
[(6)] -0.0125 .54519 1 0 Mshowa
.125 Mabswid
0 .10918 m
.00375 .10918 L
s
0 .13825 m
.00375 .13825 L
s
0 .16732 m
.00375 .16732 L
s
0 .22545 m
.00375 .22545 L
s
0 .25452 m
.00375 .25452 L
s
0 .28358 m
.00375 .28358 L
s
0 .34172 m
.00375 .34172 L
s
0 .37078 m
.00375 .37078 L
s
0 .39985 m
.00375 .39985 L
s
0 .45798 m
.00375 .45798 L
s
0 .48705 m
.00375 .48705 L
s
0 .51612 m
.00375 .51612 L
s
0 .05105 m
.00375 .05105 L
s
0 .02198 m
.00375 .02198 L
s
0 .57425 m
.00375 .57425 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15079 .61178 m
.15079 .61803 L
s
.27778 .61178 m
.27778 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.53175 .61178 m
.53175 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.9127 .61178 m
.9127 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .31265 m
1 .31265 L
s
.99375 .42892 m
1 .42892 L
s
.99375 .54519 m
1 .54519 L
s
.125 Mabswid
.99625 .10918 m
1 .10918 L
s
.99625 .13825 m
1 .13825 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .22545 m
1 .22545 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .28358 m
1 .28358 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .37078 m
1 .37078 L
s
.99625 .39985 m
1 .39985 L
s
.99625 .45798 m
1 .45798 L
s
.99625 .48705 m
1 .48705 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .02198 m
1 .02198 L
s
.99625 .57425 m
1 .57425 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .19638 m
1 .19638 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .19638 m
.02381 .60332 L
s
.0873 .19638 m
.0873 .08012 L
s
.15079 .19638 m
.15079 .08012 L
s
.21429 .19638 m
.21429 .60332 L
s
.27778 .19638 m
.27778 .08012 L
s
.34127 .19638 m
.34127 .08012 L
s
.40476 .19638 m
.40476 .60332 L
s
.46825 .19638 m
.46825 .08012 L
s
.53175 .19638 m
.53175 .08012 L
s
.59524 .19638 m
.59524 .60332 L
s
.65873 .19638 m
.65873 .08012 L
s
.72222 .19638 m
.72222 .08012 L
s
.78571 .19638 m
.78571 .60332 L
s
.84921 .19638 m
.84921 .08012 L
s
.9127 .19638 m
.9127 .08012 L
s
.97619 .19638 m
.97619 .60332 L
s
.015 w
.02381 .60332 Mdot
.0873 .08012 Mdot
.15079 .08012 Mdot
.21429 .60332 Mdot
.27778 .08012 Mdot
.34127 .08012 Mdot
.40476 .60332 Mdot
.46825 .08012 Mdot
.53175 .08012 Mdot
.59524 .60332 Mdot
.65873 .08012 Mdot
.72222 .08012 Mdot
.78571 .60332 Mdot
.84921 .08012 Mdot
.9127 .08012 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`0001kooooo1Ol0000Nooooo`?o00007_ooool3o`0001oooooo0ol0000Loooo
o`?o00001?ooool2o`0001Wooooo0ol00002ooooo`Go00006?ooool3o`0000Cooooo0ol0000Foooo
o`005_ooool01?l0003oooooooooool0000Nooooo`04o`000?ooooooooooo`0001oooooo00?o0000
ooooooooool07?ooool01Ol0003ooooooooooooooooo000001gooooo00Go0000oooooooooooooooo
o`00000Looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Eooooo`005_ooool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo
01cooooo1Ol0000Mooooo`05o`000?ooooooooooooooool000007Oooool01Ol0003ooooooooooooo
oooo000001cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Iooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool06Oooool01?l0003oooooooooooooool5o`0001Ko
oooo000Fooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool06oooool01?l0003o
ooooooooool0000Nooooo`Co00007oooool3o`0001gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool05Oooool001Kooooo00Co0000
oooooooooooo00007Oooool01Ol0003ooooooooooooooooo000001gooooo00?o0000ooooool00000
7_ooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool000007?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001Wooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000G
ooooo`005_ooool01?l0003oooooooooool0000Mooooo`05o`000?ooooooooooooooool000007_oo
ool2o`0001oooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo000001_ooooo
0_l00004ooooo`04o`000?ooooooooooo`0001Sooooo0_l00003ooooo`05o`000?oooooooooooooo
ool000006?ooool2o`0000Gooooo0_l0000Gooooo`005oooool2o`0001oooooo0ol0000Pooooo`03
o`000?oooooooooo01kooooo0_l0000Oooooo`?o00007Oooool00ol0003oooooooooo`03ooooo`;o
00006_ooool00ol0003oooooooooo`02ooooo`?o00006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01Gooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo000Aoooooooo00003Ol00003ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0ooooool9ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo0?oooooo2Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`3oooooo`Wooooo00?o0000ooooooooool00Oooool0017ooooo0_l0003oooooo`Wooooo
0_l00003ooooo`004Oooool00ol0003oooooooooo`3oooooo`Wooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0ooooool9ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo0?oooooo2Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`3oooooo`Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
ooooool9ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo0?oooooo2Ooo
ool00ol0003oooooooooo`01ooooo`004Oooool2o`000?oooooo2Oooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo0?oooooo2Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`3oooooo`Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
ooooool9ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo0?oooooo2Ooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`3oooooo`Wooooo00?o0000
ooooooooool00Oooool000Sooooo1Ol00004ooooo`03o`000?oooooooooo0?oooooo2Oooool00ol0
003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
0?oooooo2Oooool00ol0003oooooooooo`01ooooo`000_ooool5o`0000?ooooo00?o0000oooooooo
ool01?ooool3o`0001?ooooo0ol00?l>ooooo`?o003o7oooool3o`00o`kooooo0ol00?lOooooo`?o
003o3_ooool3o`00oakooooo0ol00?l>ooooo`?o003o7oooool3o`00o`kooooo0ol00?lDooooo`?o
00000oooool000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`?o003o
3_ooool3o`00oaoooooo0ol00?l>ooooo`?o003o7oooool3o`00o`kooooo0ol00?lNooooo`?o003o
3_ooool3o`00oaoooooo0ol00?l>ooooo`?o003o5_ooool00ol0003oooooooooo`01ooooo`002?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool04oooool3o`00o`kooooo
0ol00?lOooooo`?o003o3_ooool3o`00oaoooooo0ol00?l>ooooo`?o003o7_ooool3o`00o`kooooo
0ol00?lOooooo`?o003o3_ooool3o`00oaKooooo00?o0000ooooooooool00Oooool000Sooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
7oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
5?ooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool05Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo01Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`0Eooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01ko
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo007o
oooo000Aooooo`;o00005_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01kooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool07oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Cooooo`;o00000oooool0017ooooo00?o
0000ooooooooool05Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01kooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool07oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0N
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0O
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool07_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool07oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01Cooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo01kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Oooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo01oooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Dooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
7oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
5?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Eooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo01oooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo01Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool05Oooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07oooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00005_ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`0Cooooo`;o00000oooool0017ooooo00?o0000ooooooooool05Oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`0Dooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool07oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool05?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`0Eooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07_ooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`0Oooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07oooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool05Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01kooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool07oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo01Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Noooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo01oooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Ooooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool05?ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool07_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool07oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01Cooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l0000Fooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
7_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
7oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01?ooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07_oo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo01kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`0Nooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool05?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01Co
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool05Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`0Dooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003ooooooooo
o`0Eooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07_ooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`0Oooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool07oooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo01Cooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool07_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool07oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01Cooooo00?o
0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool7o`000003o`00ool0
003o000000ko000000?o003oo`000?l000003_l000000ol00?oo0000o`00000>o`000003o`00ool0
003o000000go000000?o003oo`000?l000003_l000000ol00?oo0000o`00000>o`000003o`00ool0
003o000000ko000000?o003oo`000?l000003_l000000ol00?oo0000o`00000>o`000003o`00ool0
003o000000ko000000?o003oo`000?l000003_l000000ol00?oo0000o`00000>o`000003o`00ool0
003o000000ko000000?o003oo`000?l000003_l000000ol00?oo0000o`00000=o`000003o`00ool0
003o000000Go00000oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oooooooooo
o`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oooooooooo
o`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o
003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o
003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0<?ooool00ol00?oooooooooo
o`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?oooooooooo
o`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool000[ooooo0_l00005
ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_
ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_
ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003ooooo
ooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03
o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`ooooo`03
o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0
<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool0
0Oooool0017ooooo0_l00005ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;ooo
ool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;ooo
ool00ol00?ooooooooooo`03ooooo`;o00000oooool0017ooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool0<?ooool0
0ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo
033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo
033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0<?ooool00ol00?oo
ooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?oo
ooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo
00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oooooooooo
o`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oooooooooo
o`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003o
ooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003o
ooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`oooo
o`03o`00oooooooooooo02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`oooo
o`03o`00oooooooooooo02oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01oooo
o`004Oooool2o`0000Gooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03
o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03
o`00oooooooooooo00?ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00
oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00
oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`04ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0<?oo
ool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?oo
ool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooo
oooo02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooo
oooo02oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol0
0?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol0
0?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Co
oooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033o
oooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Co
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?oooooo
ooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool0<?ooool00ol00?oooooo
ooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool01?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool2o`0000Gooooo00?o003oooooooooool0<?ooool00ol00?oooooooooo
o`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?oooooooooo
o`0_ooooo`03o`00oooooooooooo00?ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`04
ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`
ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`04
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003ooooo
ooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003ooooo
ooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03
o`00oooooooooooo02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03
o`00oooooooooooo02oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0
;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0
;oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo00Cooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooo
oooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00Oooool000Sooooo1Ol00004ooooo`03o`000?oooooo
oooo00Cooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooo
oooo033ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooo
oooo00Cooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool0
0ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000:ooooo`03o`000?oooooooooo
00Cooooo0ol00004ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol0
0?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol0
0?ooooooooooo`02ooooo`?o00000oooool000_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oo
ooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003ooooooooo
ool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003ooooooooo
ool0;oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo033o
oooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033o
oooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007o
oooo0009ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo033ooooo
00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo
00?o003oooooooooool0;oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0<?ooool00ol00?oooooooooo
o`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?oooooooooo
o`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003o
ooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003o
ooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04oooo
o`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`oooo
o`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o00001Oooool00ol00?ooooooooooo`0`ooooo`03
o`00oooooooooooo02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03
o`00oooooooooooo02oooooo00?o003oooooooooool00oooool2o`0000?ooooo000Aooooo`03o`00
0?oooooooooo00Cooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00
oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00
oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?oo
ool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool0<?oo
ool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool01?oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooo
oooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooo
oooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0<?ooool00ol0
0?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol0
0?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oo
oooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oo
oooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oooooo
ooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oooooo
ooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o
003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o
003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o
0000ooooooooool00Oooool0017ooooo0_l00005ooooo`03o`00oooooooooooo033ooooo00?o003o
ooooooooool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003o
ooooooooool0;oooool00ol00?ooooooooooo`03ooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003ooooo
ooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03
o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`ooooo`03
o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0
<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooo
oooooooo02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooo
oooooooo02oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool0
0ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
00Cooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo
033ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo
00Cooooo00?o0000ooooooooool00Oooool0017ooooo0_l00005ooooo`03o`00oooooooooooo033o
oooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033o
oooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`03ooooo`;o00000oooool0017ooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo
00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oooooooooo
o`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oooooooooo
o`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003o
ooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003o
ooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`oooo
o`03o`00oooooooooooo02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`oooo
o`03o`00oooooooooooo02oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003ooooooooo
ool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003ooooooooo
ool0;oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000:ooooo`?o0000
1?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0
;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0
;oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000;ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooo
oooooooo02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooo
oooooooo02oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`002?ooool5
o`0000Cooooo0ol00004ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool0
0ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool0
0ol00?ooooooooooo`02ooooo`?o00000oooool000Sooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool0
0ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo
02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo
02oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`002_ooool2o`0000Go
oooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oo
oooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oo
oooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`002oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0<?ooool00ol00?oooooo
ooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?oooooo
ooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o
003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o
003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04
ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`
ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`04
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003ooooo
ooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003ooooo
ooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool00Oooool0017ooooo0_l00005ooooo`03o`00oooooooooooo033ooooo00?o003ooooooooo
ool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003ooooooooo
ool0;oooool00ol00?ooooooooooo`03ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0
1?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool0
<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooo
oooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooo
oooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`04ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0<?ooool0
0ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool0
0ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo
02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo
02oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oo
ooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo
00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo
00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?oooooooooo
o`0`ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool0<?ooool00ol00?oooooooooo
o`0`ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool01?ooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0000Gooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_
ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_
ooooo`03o`00oooooooooooo00?ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`04oooo
o`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`oooo
o`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003ooooooooo
ool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003ooooooooo
ool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00
oooooooooooo02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00
oooooooooooo02oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;ooo
ool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;ooo
ool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00Cooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooo
oooo033ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooo
oooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol0
0?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool0<?ooool00ol0
0?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool01?ooool00ol0
003oooooooooo`01ooooo`004Oooool2o`0000Gooooo00?o003oooooooooool0<?ooool00ol00?oo
ooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?oo
ooooooooo`0_ooooo`03o`00oooooooooooo00?ooooo0_l00003ooooo`004Oooool00ol0003ooooo
ooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oooooo
ooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oooooo
ooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o
003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o
003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`
ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`
ooooo`03o`00oooooooooooo02oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003ooooo
ooooool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003ooooo
ooooool0;oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Cooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03
o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03
o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`00
0?oooooooooo00Cooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00
oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00
oooooooooooo00Cooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0<?ooool00ol00?oooooo
ooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?oooooo
ooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool000Sooooo00Go
0000ooooooooooooooooo`000004ooooo`?o00001?ooool00ol00?ooooooooooo`0`ooooo`03o`00
oooooooooooo02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00
oooooooooooo02oooooo00?o003oooooooooool00_ooool3o`0000?ooooo0008ooooo`Co00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;ooo
ool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;ooo
ool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo0008ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooo
oooo02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooo
oooo02oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`002Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0<?ooool00ol0
0?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol0
0?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool000[o
oooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0<?ooool00ol00?oo
ooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?ooool00ol00?oo
ooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo
00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oooooooooo
o`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?oooooooooo
o`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003o
ooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003o
ooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000
ooooooooool00Oooool0017ooooo0_l00005ooooo`03o`00oooooooooooo033ooooo00?o003ooooo
ooooool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003ooooo
ooooool0;oooool00ol00?ooooooooooo`03ooooo`;o00000oooool0017ooooo00?o0000oooooooo
ool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003ooooooooo
ool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo02oooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00
oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`0`ooooo`03o`00
oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`04ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0<?oo
ool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<?oo
ool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooo
oooo02oooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooo
oooo02oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`04ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol0
0?ooooooooooo`0`ooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0;oooool00ol0
0?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Co
oooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo033o
oooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooooooo00Co
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool00_ooool3o`00oc3ooooo
0ol00?l`ooooo`?o003o<?ooool3o`00oboooooo0ol00?l`ooooo`?o003o1Oooool00ol0003ooooo
ooooo`01ooooo`004Oooool2o`0000?ooooo0ol00?l`ooooo`?o003o<?ooool3o`00oc3ooooo0ol0
0?l_ooooo`?o003o<?ooool3o`00o`Cooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`02
ooooo`?o003o<?ooool3o`00oc3ooooo0ol00?l`ooooo`?o003o;oooool3o`00oc3ooooo0ol00?l5
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooooooo`0000go00000oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.43539, -4.17447, \
0.0591347, 0.0645854}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CTFT of infinite-length sampled signal", "Subsection"],

Cell[BoxData[
    \(\(Xs[f_, fs_, n_:  5] := SampledSpectrum[X, f, fs, n];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gXs = 
        Plot[Evaluate[PlotConvert[Xs[f, fs, 10],  .05]], {f, \(-2.5\) fs, 
            2.5  fs}, PlotStyle \[Rule] {Red, Thickness[ .01]}, \ 
          PlotPoints \[Rule] 500, \ 
          PlotRange \[Rule] {\(- .02\), 3.12}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0634921 0.00393652 0.196826 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.24603 -0.0125 -6 -9 ]
[.24603 -0.0125 6 0 ]
[.37302 -0.0125 -6 -9 ]
[.37302 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.62698 -0.0125 -3 -9 ]
[.62698 -0.0125 3 0 ]
[.75397 -0.0125 -3 -9 ]
[.75397 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-6)] .11905 -0.0125 0 1 Mshowa
.24603 0 m
.24603 .00625 L
s
[(-4)] .24603 -0.0125 0 1 Mshowa
.37302 0 m
.37302 .00625 L
s
[(-2)] .37302 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.62698 0 m
.62698 .00625 L
s
[(2)] .62698 -0.0125 0 1 Mshowa
.75397 0 m
.75397 .00625 L
s
[(4)] .75397 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(6)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.15079 0 m
.15079 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.05556 0 m
.05556 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.24603 .61178 m
.24603 .61803 L
s
.37302 .61178 m
.37302 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.62698 .61178 m
.62698 .61803 L
s
.75397 .61178 m
.75397 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.15079 .61428 m
.15079 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.05556 .61428 m
.05556 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .00394 m
.02567 .00394 L
.02769 .00394 L
.0296 .00394 L
.03143 .00394 L
.03338 .00394 L
.03525 .00394 L
.03724 .00394 L
.03917 .00394 L
.04101 .00394 L
.04298 .00394 L
.04487 .00394 L
.04669 .00394 L
.04863 .00394 L
.05049 .00394 L
.05144 .00394 L
.05248 .00394 L
.05296 .00394 L
.05347 .00394 L
.05371 .00394 L
.05384 .00394 L
.05389 .00394 L
.05395 .00394 L
.054 .59441 L
.05405 .59441 L
.05416 .59441 L
.05439 .59441 L
.05528 .59441 L
.05626 .59441 L
.05651 .59441 L
.05679 .59441 L
.0569 .59441 L
.05702 .59441 L
.05706 .59441 L
.05709 .59441 L
.05715 .00394 L
.05721 .00394 L
.05728 .00394 L
.05825 .00394 L
.0602 .00394 L
.06208 .00394 L
.06407 .00394 L
.06599 .00394 L
.06784 .00394 L
.06981 .00394 L
.07171 .00394 L
.07353 .00394 L
.07547 .00394 L
.07734 .00394 L
.07932 .00394 L
Mistroke
.08123 .00394 L
.08307 .00394 L
.08503 .00394 L
.08692 .00394 L
.08892 .00394 L
.09085 .00394 L
.0927 .00394 L
.09468 .00394 L
.09658 .00394 L
.09841 .00394 L
.10036 .00394 L
.10223 .00394 L
.10422 .00394 L
.10614 .00394 L
.10799 .00394 L
.10995 .00394 L
.11184 .00394 L
.11366 .00394 L
.1156 .00394 L
.11649 .00394 L
.11699 .00394 L
.11724 .00394 L
.11735 .00394 L
.1174 .00394 L
.11746 .00394 L
.11752 .20076 L
.11758 .20076 L
.1177 .20076 L
.11793 .20076 L
.11843 .20076 L
.11944 .20076 L
.11992 .20076 L
.12038 .20076 L
.1205 .20076 L
.12057 .20076 L
.12063 .20076 L
.12066 .00394 L
.1207 .00394 L
.12077 .00394 L
.1209 .00394 L
.12138 .00394 L
.12336 .00394 L
.12527 .00394 L
.1271 .00394 L
.12905 .00394 L
.13092 .00394 L
.13292 .00394 L
.13484 .00394 L
.13669 .00394 L
.13865 .00394 L
Mistroke
.14055 .00394 L
.14237 .00394 L
.14431 .00394 L
.14617 .00394 L
.14816 .00394 L
.15007 .00394 L
.1519 .00394 L
.15386 .00394 L
.15574 .00394 L
.15774 .00394 L
.15967 .00394 L
.16153 .00394 L
.1635 .00394 L
.1654 .00394 L
.16723 .00394 L
.16917 .00394 L
.17104 .00394 L
.17303 .00394 L
.17495 .00394 L
.1768 .00394 L
.17876 .00394 L
.17973 .00394 L
.18021 .00394 L
.18042 .00394 L
.18065 .00394 L
.18076 .00394 L
.18081 .00394 L
.18087 .00394 L
.18092 .00394 L
.18098 .59441 L
.18103 .59441 L
.18107 .59441 L
.18152 .59441 L
.18247 .59441 L
.18337 .59441 L
.18362 .59441 L
.18375 .59441 L
.18388 .59441 L
.184 .59441 L
.18403 .59441 L
.18407 .59441 L
.18413 .00394 L
.18419 .00394 L
.18425 .00394 L
.18436 .00394 L
.18622 .00394 L
.18819 .00394 L
.1901 .00394 L
.19193 .00394 L
.19387 .00394 L
Mistroke
.19575 .00394 L
.19774 .00394 L
.19966 .00394 L
.20151 .00394 L
.20347 .00394 L
.20537 .00394 L
.20719 .00394 L
.20912 .00394 L
.21099 .00394 L
.21297 .00394 L
.21488 .00394 L
.21671 .00394 L
.21867 .00394 L
.22055 .00394 L
.22255 .00394 L
.22448 .00394 L
.22633 .00394 L
.2283 .00394 L
.2302 .00394 L
.23203 .00394 L
.23397 .00394 L
.23584 .00394 L
.23783 .00394 L
.23974 .00394 L
.24159 .00394 L
.24252 .00394 L
.24301 .00394 L
.24355 .00394 L
.2438 .00394 L
.24406 .00394 L
.24428 .00394 L
.24434 .00394 L
.24437 .00394 L
.2444 .00394 L
.24447 .59441 L
.24452 .59441 L
.24544 .59441 L
.24632 .59441 L
.24682 .59441 L
.24706 .59441 L
.24729 .59441 L
.2474 .59441 L
.24746 .59441 L
.24752 .59441 L
.24758 .59441 L
.24764 .00394 L
.24769 .00394 L
.24775 .00394 L
.24824 .00394 L
.24925 .00394 L
Mistroke
.25111 .00394 L
.25308 .00394 L
.25498 .00394 L
.25681 .00394 L
.25876 .00394 L
.26063 .00394 L
.26262 .00394 L
.26454 .00394 L
.26639 .00394 L
.26835 .00394 L
.27024 .00394 L
.27206 .00394 L
.27399 .00394 L
.27586 .00394 L
.27784 .00394 L
.27974 .00394 L
.28158 .00394 L
.28353 .00394 L
.28541 .00394 L
.28741 .00394 L
.28933 .00394 L
.29119 .00394 L
.29316 .00394 L
.29505 .00394 L
.29688 .00394 L
.29882 .00394 L
.30069 .00394 L
.30268 .00394 L
.30459 .00394 L
.30643 .00394 L
.30738 .00394 L
.30761 .00394 L
.30773 .00394 L
.30786 .00394 L
.30789 .00394 L
.30793 .00394 L
.30797 .20076 L
.308 .20076 L
.30813 .20076 L
.30839 .20076 L
.30935 .20076 L
.30985 .20076 L
.31038 .20076 L
.31061 .20076 L
.31086 .20076 L
.31093 .20076 L
.311 .20076 L
.31106 .20076 L
.3111 .20076 L
.31113 .00394 L
Mistroke
.31116 .00394 L
.31119 .00394 L
.31125 .00394 L
.31138 .00394 L
.31231 .00394 L
.31416 .00394 L
.31613 .00394 L
.31803 .00394 L
.31986 .00394 L
.3218 .00394 L
.32368 .00394 L
.32567 .00394 L
.32758 .00394 L
.32943 .00394 L
.33139 .00394 L
.33328 .00394 L
.33509 .00394 L
.33703 .00394 L
.33889 .00394 L
.34087 .00394 L
.34277 .00394 L
.34461 .00394 L
.34656 .00394 L
.34844 .00394 L
.35043 .00394 L
.35236 .00394 L
.35421 .00394 L
.35617 .00394 L
.35807 .00394 L
.35989 .00394 L
.36183 .00394 L
.3637 .00394 L
.36569 .00394 L
.3676 .00394 L
.36944 .00394 L
.37047 .00394 L
.37095 .00394 L
.37116 .00394 L
.37128 .00394 L
.37134 .00394 L
.3714 .00394 L
.37145 .59441 L
.37151 .59441 L
.37162 .59441 L
.37186 .59441 L
.37237 .59441 L
.37328 .59441 L
.37375 .59441 L
.374 .59441 L
.37424 .59441 L
Mistroke
.37444 .59441 L
.3745 .59441 L
.37456 .59441 L
.37461 .00394 L
.37466 .00394 L
.37513 .00394 L
.37708 .00394 L
.37896 .00394 L
.38096 .00394 L
.38289 .00394 L
.38474 .00394 L
.38671 .00394 L
.38861 .00394 L
.39043 .00394 L
.39238 .00394 L
.39425 .00394 L
.39623 .00394 L
.39815 .00394 L
.39999 .00394 L
.40195 .00394 L
.40384 .00394 L
.40565 .00394 L
.40759 .00394 L
.40945 .00394 L
.41142 .00394 L
.41333 .00394 L
.41516 .00394 L
.41711 .00394 L
.41899 .00394 L
.42098 .00394 L
.4229 .00394 L
.42475 .00394 L
.42672 .00394 L
.42861 .00394 L
.43043 .00394 L
.43237 .00394 L
.43327 .00394 L
.43424 .00394 L
.43449 .00394 L
.43463 .00394 L
.43477 .00394 L
.43483 .00394 L
.43489 .00394 L
.43492 .59441 L
.43496 .59441 L
.43502 .59441 L
.43526 .59441 L
.43622 .59441 L
.43716 .59441 L
.43743 .59441 L
Mistroke
.43769 .59441 L
.43792 .59441 L
.43798 .59441 L
.43802 .59441 L
.43805 .59441 L
.43811 .00394 L
.43817 .00394 L
.44003 .00394 L
.44201 .00394 L
.44392 .00394 L
.44575 .00394 L
.4477 .00394 L
.44958 .00394 L
.45158 .00394 L
.4535 .00394 L
.45536 .00394 L
.45733 .00394 L
.45922 .00394 L
.46105 .00394 L
.46299 .00394 L
.46486 .00394 L
.46684 .00394 L
.46876 .00394 L
.4706 .00394 L
.47256 .00394 L
.47444 .00394 L
.47645 .00394 L
.47838 .00394 L
.48023 .00394 L
.48221 .00394 L
.48411 .00394 L
.48594 .00394 L
.48789 .00394 L
.48977 .00394 L
.49176 .00394 L
.49368 .00394 L
.49553 .00394 L
.49646 .00394 L
.49696 .00394 L
.49749 .00394 L
.49775 .00394 L
.498 .00394 L
.49823 .00394 L
.49829 .00394 L
.49832 .00394 L
.49835 .00394 L
.49841 .20076 L
.49847 .20076 L
.49938 .20076 L
.50027 .20076 L
Mistroke
.50077 .20076 L
.50102 .20076 L
.50124 .20076 L
.50135 .20076 L
.50141 .20076 L
.50148 .20076 L
.50153 .20076 L
.50159 .00394 L
.50165 .00394 L
.5017 .00394 L
.5022 .00394 L
.50321 .00394 L
.50507 .00394 L
.50705 .00394 L
.50896 .00394 L
.51079 .00394 L
.51274 .00394 L
.51462 .00394 L
.51661 .00394 L
.51853 .00394 L
.52038 .00394 L
.52235 .00394 L
.52425 .00394 L
.52607 .00394 L
.52801 .00394 L
.52988 .00394 L
.53186 .00394 L
.53377 .00394 L
.53561 .00394 L
.53757 .00394 L
.53945 .00394 L
.54146 .00394 L
.54339 .00394 L
.54524 .00394 L
.54722 .00394 L
.54912 .00394 L
.55095 .00394 L
.55289 .00394 L
.55477 .00394 L
.55676 .00394 L
.55868 .00394 L
.56052 .00394 L
.56101 .00394 L
.56148 .00394 L
.56171 .00394 L
.56177 .00394 L
.56184 .00394 L
.56189 .00394 L
.56196 .59441 L
.56199 .59441 L
Mistroke
.56203 .59441 L
.56209 .59441 L
.56223 .59441 L
.56249 .59441 L
.56337 .59441 L
.56387 .59441 L
.56434 .59441 L
.5648 .59441 L
.56493 .59441 L
.565 .59441 L
.56506 .59441 L
.56511 .00394 L
.56517 .00394 L
.5653 .00394 L
.56631 .00394 L
.56812 .00394 L
.57005 .00394 L
.57191 .00394 L
.57389 .00394 L
.57579 .00394 L
.57763 .00394 L
.57957 .00394 L
.58145 .00394 L
.58344 .00394 L
.58537 .00394 L
.58721 .00394 L
.58918 .00394 L
.59107 .00394 L
.59289 .00394 L
.59483 .00394 L
.5967 .00394 L
.59868 .00394 L
.60059 .00394 L
.60243 .00394 L
.60439 .00394 L
.60627 .00394 L
.60827 .00394 L
.6102 .00394 L
.61205 .00394 L
.61402 .00394 L
.61592 .00394 L
.61775 .00394 L
.6197 .00394 L
.62157 .00394 L
.62252 .00394 L
.62356 .00394 L
.62404 .00394 L
.62455 .00394 L
.62499 .00394 L
.62511 .00394 L
Mistroke
.62524 .00394 L
.6253 .00394 L
.62536 .00394 L
.62542 .59441 L
.62548 .59441 L
.6265 .59441 L
.62743 .59441 L
.62789 .59441 L
.62814 .59441 L
.62827 .59441 L
.62839 .59441 L
.6285 .59441 L
.62856 .59441 L
.62862 .00394 L
.62868 .00394 L
.62875 .00394 L
.62887 .00394 L
.62931 .00394 L
.63126 .00394 L
.63315 .00394 L
.63515 .00394 L
.63708 .00394 L
.63894 .00394 L
.64092 .00394 L
.64282 .00394 L
.64465 .00394 L
.6466 .00394 L
.64847 .00394 L
.65046 .00394 L
.65238 .00394 L
.65423 .00394 L
.65619 .00394 L
.65809 .00394 L
.6599 .00394 L
.66184 .00394 L
.6637 .00394 L
.66569 .00394 L
.6676 .00394 L
.66943 .00394 L
.67139 .00394 L
.67327 .00394 L
.67527 .00394 L
.67719 .00394 L
.67905 .00394 L
.68102 .00394 L
.68292 .00394 L
.68474 .00394 L
.68668 .00394 L
.68758 .00394 L
.68805 .00394 L
Mistroke
.68855 .00394 L
.68868 .00394 L
.68881 .00394 L
.68884 .00394 L
.68888 .00394 L
.68891 .20076 L
.68895 .20076 L
.68909 .20076 L
.68958 .20076 L
.69054 .20076 L
.69149 .20076 L
.69176 .20076 L
.69189 .20076 L
.69195 .20076 L
.69198 .20076 L
.69201 .20076 L
.69207 .00394 L
.69213 .00394 L
.69224 .00394 L
.69249 .00394 L
.69448 .00394 L
.69639 .00394 L
.69823 .00394 L
.70018 .00394 L
.70207 .00394 L
.70407 .00394 L
.706 .00394 L
.70785 .00394 L
.70983 .00394 L
.71173 .00394 L
.71356 .00394 L
.7155 .00394 L
.71738 .00394 L
.71937 .00394 L
.72129 .00394 L
.72313 .00394 L
.72509 .00394 L
.72698 .00394 L
.7288 .00394 L
.73074 .00394 L
.7326 .00394 L
.73458 .00394 L
.73649 .00394 L
.73832 .00394 L
.74027 .00394 L
.74215 .00394 L
.74415 .00394 L
.74608 .00394 L
.74793 .00394 L
.7499 .00394 L
Mistroke
.75088 .00394 L
.75136 .00394 L
.75179 .00394 L
.75201 .00394 L
.75212 .00394 L
.75225 .00394 L
.7523 .00394 L
.75235 .00394 L
.75241 .59441 L
.75247 .59441 L
.75267 .59441 L
.75362 .59441 L
.75458 .59441 L
.75506 .59441 L
.7552 .59441 L
.75534 .59441 L
.75541 .59441 L
.75547 .59441 L
.75553 .59441 L
.75559 .00394 L
.75565 .00394 L
.75571 .00394 L
.75583 .00394 L
.75605 .00394 L
.75655 .00394 L
.75756 .00394 L
.75947 .00394 L
.76131 .00394 L
.76326 .00394 L
.76514 .00394 L
.76714 .00394 L
.76907 .00394 L
.77093 .00394 L
.7729 .00394 L
.7748 .00394 L
.77662 .00394 L
.77857 .00394 L
.78044 .00394 L
.78243 .00394 L
.78435 .00394 L
.78619 .00394 L
.78815 .00394 L
.79004 .00394 L
.79186 .00394 L
.79379 .00394 L
.79565 .00394 L
.79763 .00394 L
.79953 .00394 L
.80137 .00394 L
.80332 .00394 L
Mistroke
.8052 .00394 L
.80719 .00394 L
.80912 .00394 L
.81097 .00394 L
.81293 .00394 L
.81391 .00394 L
.81483 .00394 L
.81528 .00394 L
.8155 .00394 L
.81571 .00394 L
.81577 .00394 L
.81582 .00394 L
.81585 .00394 L
.81589 .59441 L
.81594 .59441 L
.8162 .59441 L
.81665 .59441 L
.81759 .59441 L
.81809 .59441 L
.81837 .59441 L
.81863 .59441 L
.81887 .59441 L
.81894 .59441 L
.81898 .59441 L
.81901 .59441 L
.81907 .00394 L
.81911 .00394 L
.81914 .00394 L
.81961 .00394 L
.82053 .00394 L
.82251 .00394 L
.82442 .00394 L
.82625 .00394 L
.82821 .00394 L
.83009 .00394 L
.83209 .00394 L
.83401 .00394 L
.83586 .00394 L
.83784 .00394 L
.83973 .00394 L
.84156 .00394 L
.8435 .00394 L
.84537 .00394 L
.84736 .00394 L
.84927 .00394 L
.85112 .00394 L
.85308 .00394 L
.85496 .00394 L
.85678 .00394 L
.85871 .00394 L
Mistroke
.86057 .00394 L
.86255 .00394 L
.86445 .00394 L
.86628 .00394 L
.86823 .00394 L
.87011 .00394 L
.8721 .00394 L
.87402 .00394 L
.87587 .00394 L
.87681 .00394 L
.87784 .00394 L
.87831 .00394 L
.87882 .00394 L
.87906 .00394 L
.87918 .00394 L
.87924 .00394 L
.8793 .00394 L
.87935 .00394 L
.8794 .20076 L
.87945 .20076 L
.8795 .20076 L
.87973 .20076 L
.88067 .20076 L
.88117 .20076 L
.88171 .20076 L
.88197 .20076 L
.88222 .20076 L
.88233 .20076 L
.88244 .20076 L
.88251 .20076 L
.88254 .20076 L
.88257 .00394 L
.88263 .00394 L
.88269 .00394 L
.88361 .00394 L
.88559 .00394 L
.88749 .00394 L
.88933 .00394 L
.89128 .00394 L
.89316 .00394 L
.89515 .00394 L
.89708 .00394 L
.89893 .00394 L
.9009 .00394 L
.9028 .00394 L
.90462 .00394 L
.90656 .00394 L
.90843 .00394 L
.91041 .00394 L
.91233 .00394 L
Mistroke
.91417 .00394 L
.91613 .00394 L
.91801 .00394 L
.92002 .00394 L
.92195 .00394 L
.9238 .00394 L
.92578 .00394 L
.92768 .00394 L
.92951 .00394 L
.93146 .00394 L
.93334 .00394 L
.93533 .00394 L
.93725 .00394 L
.9391 .00394 L
.94003 .00394 L
.94106 .00394 L
.94153 .00394 L
.94204 .00394 L
.94228 .00394 L
.94252 .00394 L
.94273 .00394 L
.94278 .00394 L
.94284 .00394 L
.9429 .59441 L
.94295 .59441 L
.94396 .59441 L
.94488 .59441 L
.94535 .59441 L
.94578 .59441 L
.94589 .59441 L
.94595 .59441 L
.946 .59441 L
.94606 .00394 L
.94609 .00394 L
.94612 .00394 L
.94624 .00394 L
.94673 .00394 L
.94855 .00394 L
.95048 .00394 L
.95234 .00394 L
.95432 .00394 L
.95623 .00394 L
.95806 .00394 L
.96001 .00394 L
.96189 .00394 L
.96388 .00394 L
.9658 .00394 L
.96765 .00394 L
.96962 .00394 L
.97152 .00394 L
Mistroke
.97334 .00394 L
.97528 .00394 L
.97619 .00394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00=Oooool3o`00023ooooo0ol0000Mooooo`Go00007?ooool2o`0001gooooo1Ol0000Ooooo
o`?o00007_ooool3o`00023ooooo000dooooo`05o`000?ooooooooooooooool000008?ooool00ol0
003oooooooooo`0Mooooo`04o`000?ooooooooooo`0001_ooooo00Co0000oooooooooooo00007Ooo
ool01?l0003oooooooooool0000Pooooo`03o`000?oooooooooo01cooooo00Go0000oooooooooooo
ooooo`00000Oooooo`00;_ooool5o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
5Oooool5o`000003ooooool0003o000000?o00005oooool5o`0000?ooooo00?o0000ooooooooool0
6oooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo01gooooo1Ol0000Mooooo`05
o`000?ooooooooooooooool000007oooool003Cooooo1?l0000Nooooo`04o`000?ooooooooooo`00
027ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0000Oooooo`03o`000?oooooo
oooo01cooooo00Co0000oooooooooooo00007_ooool4o`00023ooooo000dooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooool000007_ooool01Ol0003ooooooooooooooooo000001_ooooo00Co
0000oooooooooooo00007?ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooool0
00007_ooool00ol0003oooooooooo`0Qooooo`00=Oooool00ol0003oooooooooo`0Pooooo`;o0000
7_ooool01Ol0003ooooooooooooooooo000001_ooooo00Co0000oooooooooooo00007?ooool01Ol0
003ooooooooooooooooo000001oooooo0_l0000Oooooo`03o`000?oooooooooo023ooooo000foooo
o`;o00008Oooool00ol0003oooooooooo`0Mooooo`?o00007Oooool2o`0001kooooo0ol0000Qoooo
o`03o`000?oooooooooo01kooooo0_l0000Pooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`003_ooool2o`000?oooooo4Oooool000gooooo00Co0000oooooooooooo00001?oooooo
o`0000_o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool2o`0000?ooooooooo0004
ooooo`;o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02
ooooooooo`001Oooool1o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool02_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>
ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>
ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Oooool1o`00007ooooo000=oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo000>
ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>
ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>
ooooo`?oo`003Oooool1o`00007ooooo000>ooooo`;o00001Oooool00ol0003oooooooooo`0:oooo
o`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>oooo
o`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>oooo
o`?oo`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool001Gooooo0_l0000;ooooo`?o
o`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?o
o`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?o
o`003_ooool3ool000kooooo0ooo000<ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0
2_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`00
3_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`00
3_ooool3ool000kooooo0ooo000>ooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo00[ooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_oo
ool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_oo
ool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2
ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool0
00kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool0
00kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Oooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000>ooooo`?oo`003_ooool3ool000ko
oooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000ko
oooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000go
oooo0Ol00001ooooo`005Oooool2o`0000_ooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo
0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo
0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000cooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo
000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo
000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo
000=ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo000>
ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>
ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>
ooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000>oooo
o`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>oooo
o`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>oooo
o`?oo`003_ooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?o
o`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?o
o`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?o
o`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool001Gooooo0_l0000;ooooo`?oo`00
3_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`00
3_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`00
3_ooool3ool000kooooo0ooo000<ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool02_oo
ool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`003_oo
ool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_oo
ool3ool000kooooo0ooo000>ooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo00[ooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool3
ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2
ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool0
00kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool0
00kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000ko
oooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000ko
oooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Oooool1o`00007o
oooo000Eooooo`;o00002oooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo
0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo
0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003?ooool2o`00007ooooo
000Eooooo`03o`000?oooooooooo00[ooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo
000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo
000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000gooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo000>
ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>
ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=
ooooo`7o00000Oooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005oooo
o`03o`000?oooooooooo00[ooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>oooo
o`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>oooo
o`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001oooo
o`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2
ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool0
0005ooooool0003oooooooooool000002oooool00ol0003oooooooooo`02ooooo`;o00002oooool3
ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3
ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool3
ool000kooooo0ooo000>ooooo`?oo`003?ooool2o`00007ooooo00001Ooooooo0000oooooooooooo
000000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3
ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3
ool000kooooo0ooo000=ooooo`7o00000Oooool00005ooooool0003oooooooooool000001oooool4
o`0000Gooooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Oooool1
o`00007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2
ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool0
00;ooooo0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool0
00kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool0
00kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool0
00kooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool000ko
oooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000ko
oooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool3ool000ko
oooo0ooo000>ooooo`?oo`003Oooool1o`00007ooooo000Eooooo`;o00002oooool3ool000kooooo
0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo
0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo
0ooo000>ooooo`?oo`003?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo
000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo
000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo
000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:
ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>
ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>
ooooo`?oo`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool02_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>oooo
o`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>oooo
o`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00[ooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;o
o`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?o
o`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`00
5Oooool2o`0000_ooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`00
3_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`00
3_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000cooooo0_l00001ooooo`005Ooo
ool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_oo
ool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_oo
ool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Oooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000>ooooo`?oo`003_ooool3ool0
00kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool0
00kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool0
00gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000ko
oooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000ko
oooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000ko
oooo0ooo000=ooooo`7o00000Oooool001Gooooo0_l0000;ooooo`?oo`003_ooool3ool000kooooo
0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo
0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo
0ooo000<ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo
000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo
000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo
000>ooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000>
ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>
ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>
ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:oooo
o`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>oooo
o`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>oooo
o`?oo`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool02_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?o
o`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;o
o`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Oooool1o`00007ooooo000Eooooo`;o0000
2oooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`?oo`00
3_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`00
3_ooool3ool000kooooo0ooo000>ooooo`?oo`003?ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo00[ooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_oo
ool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_oo
ool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2
ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool0
00gooooo0ol00005ooooo`03o`000?oooooooooo00[ooooo0ooo000>ooooo`?oo`003_ooool3ool0
00kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool0
00kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool0
00gooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[o
oooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool3ool000ko
oooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000ko
oooo0ooo000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`003_ooool00ol0003ooooo
ooooo`04ooooo`;o00002oooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo
0ooo000=ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo
0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003?ooool2o`00007ooooo
000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo
000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=ooooo`?oo`003_ooool3ool000kooooo0ooo
000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo
000>ooooo`?oo`003Oooool1o`00007ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@
ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000O
ooooo`?oo`003Oooool1o`00007ooooo000=ooooo`;o00001_ooool00ol0003oooooooooo`0:oooo
o`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000oooo
ooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=oooo
o`7o00000Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`?o
o`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000oooooooo
ool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`00
7_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`00
7oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`;o00002ooo
ool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oo
oooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003?oo
ool2o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3
ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3
ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0
013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool0
01oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oo
oooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00co
oooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo
0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo
0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool2o`0000_ooooo0ooo
000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003ooooooooo
o`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000cooooo0_l0
0001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000N
ooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000O
ooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@oooo
o`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Ooooo
o`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?o
o`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?o
o`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`00
3_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`00
3_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo0_l0000;ooooo`?oo`007ooo
ool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?oo
ool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000<ooooo`;o00000Ooo
ool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3
ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2
ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0
003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool0
00gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000ko
oooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000ko
oooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo
0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo
0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`;o00002oooool3ool001oooooo0ooo
000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo
000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003?ooool2o`00007ooooo000E
ooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>
ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>
ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:oooo
o`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000oooo
ooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=oooo
o`7o00000Oooool00004ooooool0003o0000o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool0
00kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool0
00kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00Oo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00[ooooo0ooo000Ooooo
o`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<oooo
o`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001oooo
o`000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03
o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?o
o`003Oooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0_ooool2o`0000_ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`00
4?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`00
7oooool3ool000cooooo0_l00001ooooo`000_ooool00ol0003oooooooooo`07ooooo`Co00001Ooo
ool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_oo
ool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_oo
ool3ool001oooooo0ooo000=ooooo`7o00000Oooool00003ooooool0003o000000Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000N
ooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000O
ooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool000;ooooo00?o0000oooo
ooooool01oooool5o`0000Cooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>oooo
o`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>oooo
o`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?o
o`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?o
o`007oooool3ool000gooooo0Ol00001ooooo`005Oooool2o`0000_ooooo0ooo000Oooooo`?oo`00
3_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`00
3_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000cooooo0_l00001ooooo`005Ooo
ool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_oo
ool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_oo
ool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3
ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooo
oooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool0
01kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool0
01oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013o
oooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oo
oooo0ooo000=ooooo`7o00000Oooool001Gooooo0_l0000;ooooo`?oo`007oooool3ool000kooooo
0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo
0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000<ooooo`;o00000Oooool001Gooooo00?o
0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo
000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo
000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000O
ooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<
ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Noooo
o`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Ooooo
o`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03
o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?o
o`003Oooool1o`00007ooooo000Eooooo`;o00002oooool3ool001oooooo0ooo000>ooooo`?oo`00
7_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`00
7oooool2ool000kooooo0ooo000Oooooo`?oo`003?ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?oo
ool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007ooo
ool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3
ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3
ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool0
00kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool0
00kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[o
oooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003o
ooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000go
oooo0Ol00001ooooo`005Oooool2o`0000_ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo
0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo
0_oo000>ooooo`?oo`007oooool3ool000cooooo0_l00001ooooo`005Oooool00ol0003ooooooooo
o`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o
0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo
000=ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>
ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>
ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000<oooo
o`Go00001?ooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Noooo
o`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Ooooo
o`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool000gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Noooo
o`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Ooooo
o`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool000kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?o
o`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;o
o`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool000oooooo00?o0000ooooooooool0
0oooool2o`0000_ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`00
4?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`00
7oooool3ool000cooooo0_l00001ooooo`003?ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo
0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo
0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000<ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`00
3_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`00
3_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool000gooooo0ol00005ooooo`03o`000?oo
oooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?oo
ool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007ooo
ool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3
ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3
ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool0
01Gooooo0_l0000;ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0
013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool0
01oooooo0ooo000<ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oo
oooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00co
oooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo
0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo
0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o
0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo
000=ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>
ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>
ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eoooo
o`;o00002oooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@oooo
o`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Ooooo
o`?oo`003?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?o
o`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?o
o`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`00
3_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`00
3_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_oo
ool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oo
oooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Ooo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3
ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3
ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool2o`00
00_ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0
003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool0
00cooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000ko
oooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000ko
oooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo
0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo
0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo
000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003ooooooooo
o`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000N
ooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000O
ooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@oooo
o`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Ooooo
o`?oo`003Oooool1o`00007ooooo000Eooooo`;o00002oooool3ool001oooooo0ooo000>ooooo`?o
o`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?o
o`007oooool2ool000kooooo0ooo000Oooooo`?oo`003?ooool2o`00007ooooo000Eooooo`03o`00
0?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`00
4?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`00
7oooool3ool000gooooo0Ol00001ooooo`001Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0
0005ooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo
000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo
000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0:ooooo`?oo`00
7oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool0
3?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o0000
0Oooool000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?oo
ool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007ooo
ool3ool000gooooo0Ol00001ooooo`000oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00;ooooo0_l0000;ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3
ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3
ool001oooooo0ooo000<ooooo`;o00000Oooool00005o`000?ooooooooooooooool000001oooool4
o`0000Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3
ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2
ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo00001Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3
ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3
ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool0
0004ooooool0003o0000o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo00[ooooo0ooo000O
ooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<
ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Noooo
o`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Ooooo
o`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo0_l0000;ooooo`?o
o`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000oooooooo
ool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000<ooooo`;o
00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`00
7_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`00
7oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?oo
ool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007ooo
ool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3
ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3
ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool0
00kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool0
00kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`;o00002oooool3ool001oo
oooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00co
oooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003?ooool2o`00007o
oooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo
0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo
0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o
0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo
000=ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>
ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>
ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>oooo
o`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>oooo
o`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?o
o`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000oooooooo
ool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o
00000Oooool001Gooooo0_l0000;ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`00
3_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`00
3_ooool3ool001oooooo0ooo000<ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool02_oo
ool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oo
oooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Ooo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3
ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3
ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0
013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool0
01oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oo
oooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00co
oooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007o
oooo000Eooooo`;o00002oooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo
0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo
0ooo000Oooooo`?oo`003?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo
000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003ooooooooo
o`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol0
0001ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>
ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>
ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000<oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3
ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3
ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool0
013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool0
00kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool0
00kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool000ko
oooo0_l00005ooooo`;o00002oooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000ko
oooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool3ool000go
oooo0ooo000Oooooo`?oo`003?ooool2o`00007ooooo000@ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo
0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool3ool000gooooo
0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000<ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`003Ooo
ool3o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool0
01Gooooo0_l00004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l00001ooooo`005Oooooooo`0000_o
00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.13953, -0.260466, \
0.0593102, 0.0191323}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gXXs = Show[gXs, gX];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0634921 0.00393652 0.196826 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.24603 -0.0125 -6 -9 ]
[.24603 -0.0125 6 0 ]
[.37302 -0.0125 -6 -9 ]
[.37302 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.62698 -0.0125 -3 -9 ]
[.62698 -0.0125 3 0 ]
[.75397 -0.0125 -3 -9 ]
[.75397 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-6)] .11905 -0.0125 0 1 Mshowa
.24603 0 m
.24603 .00625 L
s
[(-4)] .24603 -0.0125 0 1 Mshowa
.37302 0 m
.37302 .00625 L
s
[(-2)] .37302 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.62698 0 m
.62698 .00625 L
s
[(2)] .62698 -0.0125 0 1 Mshowa
.75397 0 m
.75397 .00625 L
s
[(4)] .75397 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(6)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.15079 0 m
.15079 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.05556 0 m
.05556 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.24603 .61178 m
.24603 .61803 L
s
.37302 .61178 m
.37302 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.62698 .61178 m
.62698 .61803 L
s
.75397 .61178 m
.75397 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.15079 .61428 m
.15079 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.05556 .61428 m
.05556 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .00394 m
.02567 .00394 L
.02769 .00394 L
.0296 .00394 L
.03143 .00394 L
.03338 .00394 L
.03525 .00394 L
.03724 .00394 L
.03917 .00394 L
.04101 .00394 L
.04298 .00394 L
.04487 .00394 L
.04669 .00394 L
.04863 .00394 L
.05049 .00394 L
.05144 .00394 L
.05248 .00394 L
.05296 .00394 L
.05347 .00394 L
.05371 .00394 L
.05384 .00394 L
.05389 .00394 L
.05395 .00394 L
.054 .59441 L
.05405 .59441 L
.05416 .59441 L
.05439 .59441 L
.05528 .59441 L
.05626 .59441 L
.05651 .59441 L
.05679 .59441 L
.0569 .59441 L
.05702 .59441 L
.05706 .59441 L
.05709 .59441 L
.05715 .00394 L
.05721 .00394 L
.05728 .00394 L
.05825 .00394 L
.0602 .00394 L
.06208 .00394 L
.06407 .00394 L
.06599 .00394 L
.06784 .00394 L
.06981 .00394 L
.07171 .00394 L
.07353 .00394 L
.07547 .00394 L
.07734 .00394 L
.07932 .00394 L
Mistroke
.08123 .00394 L
.08307 .00394 L
.08503 .00394 L
.08692 .00394 L
.08892 .00394 L
.09085 .00394 L
.0927 .00394 L
.09468 .00394 L
.09658 .00394 L
.09841 .00394 L
.10036 .00394 L
.10223 .00394 L
.10422 .00394 L
.10614 .00394 L
.10799 .00394 L
.10995 .00394 L
.11184 .00394 L
.11366 .00394 L
.1156 .00394 L
.11649 .00394 L
.11699 .00394 L
.11724 .00394 L
.11735 .00394 L
.1174 .00394 L
.11746 .00394 L
.11752 .20076 L
.11758 .20076 L
.1177 .20076 L
.11793 .20076 L
.11843 .20076 L
.11944 .20076 L
.11992 .20076 L
.12038 .20076 L
.1205 .20076 L
.12057 .20076 L
.12063 .20076 L
.12066 .00394 L
.1207 .00394 L
.12077 .00394 L
.1209 .00394 L
.12138 .00394 L
.12336 .00394 L
.12527 .00394 L
.1271 .00394 L
.12905 .00394 L
.13092 .00394 L
.13292 .00394 L
.13484 .00394 L
.13669 .00394 L
.13865 .00394 L
Mistroke
.14055 .00394 L
.14237 .00394 L
.14431 .00394 L
.14617 .00394 L
.14816 .00394 L
.15007 .00394 L
.1519 .00394 L
.15386 .00394 L
.15574 .00394 L
.15774 .00394 L
.15967 .00394 L
.16153 .00394 L
.1635 .00394 L
.1654 .00394 L
.16723 .00394 L
.16917 .00394 L
.17104 .00394 L
.17303 .00394 L
.17495 .00394 L
.1768 .00394 L
.17876 .00394 L
.17973 .00394 L
.18021 .00394 L
.18042 .00394 L
.18065 .00394 L
.18076 .00394 L
.18081 .00394 L
.18087 .00394 L
.18092 .00394 L
.18098 .59441 L
.18103 .59441 L
.18107 .59441 L
.18152 .59441 L
.18247 .59441 L
.18337 .59441 L
.18362 .59441 L
.18375 .59441 L
.18388 .59441 L
.184 .59441 L
.18403 .59441 L
.18407 .59441 L
.18413 .00394 L
.18419 .00394 L
.18425 .00394 L
.18436 .00394 L
.18622 .00394 L
.18819 .00394 L
.1901 .00394 L
.19193 .00394 L
.19387 .00394 L
Mistroke
.19575 .00394 L
.19774 .00394 L
.19966 .00394 L
.20151 .00394 L
.20347 .00394 L
.20537 .00394 L
.20719 .00394 L
.20912 .00394 L
.21099 .00394 L
.21297 .00394 L
.21488 .00394 L
.21671 .00394 L
.21867 .00394 L
.22055 .00394 L
.22255 .00394 L
.22448 .00394 L
.22633 .00394 L
.2283 .00394 L
.2302 .00394 L
.23203 .00394 L
.23397 .00394 L
.23584 .00394 L
.23783 .00394 L
.23974 .00394 L
.24159 .00394 L
.24252 .00394 L
.24301 .00394 L
.24355 .00394 L
.2438 .00394 L
.24406 .00394 L
.24428 .00394 L
.24434 .00394 L
.24437 .00394 L
.2444 .00394 L
.24447 .59441 L
.24452 .59441 L
.24544 .59441 L
.24632 .59441 L
.24682 .59441 L
.24706 .59441 L
.24729 .59441 L
.2474 .59441 L
.24746 .59441 L
.24752 .59441 L
.24758 .59441 L
.24764 .00394 L
.24769 .00394 L
.24775 .00394 L
.24824 .00394 L
.24925 .00394 L
Mistroke
.25111 .00394 L
.25308 .00394 L
.25498 .00394 L
.25681 .00394 L
.25876 .00394 L
.26063 .00394 L
.26262 .00394 L
.26454 .00394 L
.26639 .00394 L
.26835 .00394 L
.27024 .00394 L
.27206 .00394 L
.27399 .00394 L
.27586 .00394 L
.27784 .00394 L
.27974 .00394 L
.28158 .00394 L
.28353 .00394 L
.28541 .00394 L
.28741 .00394 L
.28933 .00394 L
.29119 .00394 L
.29316 .00394 L
.29505 .00394 L
.29688 .00394 L
.29882 .00394 L
.30069 .00394 L
.30268 .00394 L
.30459 .00394 L
.30643 .00394 L
.30738 .00394 L
.30761 .00394 L
.30773 .00394 L
.30786 .00394 L
.30789 .00394 L
.30793 .00394 L
.30797 .20076 L
.308 .20076 L
.30813 .20076 L
.30839 .20076 L
.30935 .20076 L
.30985 .20076 L
.31038 .20076 L
.31061 .20076 L
.31086 .20076 L
.31093 .20076 L
.311 .20076 L
.31106 .20076 L
.3111 .20076 L
.31113 .00394 L
Mistroke
.31116 .00394 L
.31119 .00394 L
.31125 .00394 L
.31138 .00394 L
.31231 .00394 L
.31416 .00394 L
.31613 .00394 L
.31803 .00394 L
.31986 .00394 L
.3218 .00394 L
.32368 .00394 L
.32567 .00394 L
.32758 .00394 L
.32943 .00394 L
.33139 .00394 L
.33328 .00394 L
.33509 .00394 L
.33703 .00394 L
.33889 .00394 L
.34087 .00394 L
.34277 .00394 L
.34461 .00394 L
.34656 .00394 L
.34844 .00394 L
.35043 .00394 L
.35236 .00394 L
.35421 .00394 L
.35617 .00394 L
.35807 .00394 L
.35989 .00394 L
.36183 .00394 L
.3637 .00394 L
.36569 .00394 L
.3676 .00394 L
.36944 .00394 L
.37047 .00394 L
.37095 .00394 L
.37116 .00394 L
.37128 .00394 L
.37134 .00394 L
.3714 .00394 L
.37145 .59441 L
.37151 .59441 L
.37162 .59441 L
.37186 .59441 L
.37237 .59441 L
.37328 .59441 L
.37375 .59441 L
.374 .59441 L
.37424 .59441 L
Mistroke
.37444 .59441 L
.3745 .59441 L
.37456 .59441 L
.37461 .00394 L
.37466 .00394 L
.37513 .00394 L
.37708 .00394 L
.37896 .00394 L
.38096 .00394 L
.38289 .00394 L
.38474 .00394 L
.38671 .00394 L
.38861 .00394 L
.39043 .00394 L
.39238 .00394 L
.39425 .00394 L
.39623 .00394 L
.39815 .00394 L
.39999 .00394 L
.40195 .00394 L
.40384 .00394 L
.40565 .00394 L
.40759 .00394 L
.40945 .00394 L
.41142 .00394 L
.41333 .00394 L
.41516 .00394 L
.41711 .00394 L
.41899 .00394 L
.42098 .00394 L
.4229 .00394 L
.42475 .00394 L
.42672 .00394 L
.42861 .00394 L
.43043 .00394 L
.43237 .00394 L
.43327 .00394 L
.43424 .00394 L
.43449 .00394 L
.43463 .00394 L
.43477 .00394 L
.43483 .00394 L
.43489 .00394 L
.43492 .59441 L
.43496 .59441 L
.43502 .59441 L
.43526 .59441 L
.43622 .59441 L
.43716 .59441 L
.43743 .59441 L
Mistroke
.43769 .59441 L
.43792 .59441 L
.43798 .59441 L
.43802 .59441 L
.43805 .59441 L
.43811 .00394 L
.43817 .00394 L
.44003 .00394 L
.44201 .00394 L
.44392 .00394 L
.44575 .00394 L
.4477 .00394 L
.44958 .00394 L
.45158 .00394 L
.4535 .00394 L
.45536 .00394 L
.45733 .00394 L
.45922 .00394 L
.46105 .00394 L
.46299 .00394 L
.46486 .00394 L
.46684 .00394 L
.46876 .00394 L
.4706 .00394 L
.47256 .00394 L
.47444 .00394 L
.47645 .00394 L
.47838 .00394 L
.48023 .00394 L
.48221 .00394 L
.48411 .00394 L
.48594 .00394 L
.48789 .00394 L
.48977 .00394 L
.49176 .00394 L
.49368 .00394 L
.49553 .00394 L
.49646 .00394 L
.49696 .00394 L
.49749 .00394 L
.49775 .00394 L
.498 .00394 L
.49823 .00394 L
.49829 .00394 L
.49832 .00394 L
.49835 .00394 L
.49841 .20076 L
.49847 .20076 L
.49938 .20076 L
.50027 .20076 L
Mistroke
.50077 .20076 L
.50102 .20076 L
.50124 .20076 L
.50135 .20076 L
.50141 .20076 L
.50148 .20076 L
.50153 .20076 L
.50159 .00394 L
.50165 .00394 L
.5017 .00394 L
.5022 .00394 L
.50321 .00394 L
.50507 .00394 L
.50705 .00394 L
.50896 .00394 L
.51079 .00394 L
.51274 .00394 L
.51462 .00394 L
.51661 .00394 L
.51853 .00394 L
.52038 .00394 L
.52235 .00394 L
.52425 .00394 L
.52607 .00394 L
.52801 .00394 L
.52988 .00394 L
.53186 .00394 L
.53377 .00394 L
.53561 .00394 L
.53757 .00394 L
.53945 .00394 L
.54146 .00394 L
.54339 .00394 L
.54524 .00394 L
.54722 .00394 L
.54912 .00394 L
.55095 .00394 L
.55289 .00394 L
.55477 .00394 L
.55676 .00394 L
.55868 .00394 L
.56052 .00394 L
.56101 .00394 L
.56148 .00394 L
.56171 .00394 L
.56177 .00394 L
.56184 .00394 L
.56189 .00394 L
.56196 .59441 L
.56199 .59441 L
Mistroke
.56203 .59441 L
.56209 .59441 L
.56223 .59441 L
.56249 .59441 L
.56337 .59441 L
.56387 .59441 L
.56434 .59441 L
.5648 .59441 L
.56493 .59441 L
.565 .59441 L
.56506 .59441 L
.56511 .00394 L
.56517 .00394 L
.5653 .00394 L
.56631 .00394 L
.56812 .00394 L
.57005 .00394 L
.57191 .00394 L
.57389 .00394 L
.57579 .00394 L
.57763 .00394 L
.57957 .00394 L
.58145 .00394 L
.58344 .00394 L
.58537 .00394 L
.58721 .00394 L
.58918 .00394 L
.59107 .00394 L
.59289 .00394 L
.59483 .00394 L
.5967 .00394 L
.59868 .00394 L
.60059 .00394 L
.60243 .00394 L
.60439 .00394 L
.60627 .00394 L
.60827 .00394 L
.6102 .00394 L
.61205 .00394 L
.61402 .00394 L
.61592 .00394 L
.61775 .00394 L
.6197 .00394 L
.62157 .00394 L
.62252 .00394 L
.62356 .00394 L
.62404 .00394 L
.62455 .00394 L
.62499 .00394 L
.62511 .00394 L
Mistroke
.62524 .00394 L
.6253 .00394 L
.62536 .00394 L
.62542 .59441 L
.62548 .59441 L
.6265 .59441 L
.62743 .59441 L
.62789 .59441 L
.62814 .59441 L
.62827 .59441 L
.62839 .59441 L
.6285 .59441 L
.62856 .59441 L
.62862 .00394 L
.62868 .00394 L
.62875 .00394 L
.62887 .00394 L
.62931 .00394 L
.63126 .00394 L
.63315 .00394 L
.63515 .00394 L
.63708 .00394 L
.63894 .00394 L
.64092 .00394 L
.64282 .00394 L
.64465 .00394 L
.6466 .00394 L
.64847 .00394 L
.65046 .00394 L
.65238 .00394 L
.65423 .00394 L
.65619 .00394 L
.65809 .00394 L
.6599 .00394 L
.66184 .00394 L
.6637 .00394 L
.66569 .00394 L
.6676 .00394 L
.66943 .00394 L
.67139 .00394 L
.67327 .00394 L
.67527 .00394 L
.67719 .00394 L
.67905 .00394 L
.68102 .00394 L
.68292 .00394 L
.68474 .00394 L
.68668 .00394 L
.68758 .00394 L
.68805 .00394 L
Mistroke
.68855 .00394 L
.68868 .00394 L
.68881 .00394 L
.68884 .00394 L
.68888 .00394 L
.68891 .20076 L
.68895 .20076 L
.68909 .20076 L
.68958 .20076 L
.69054 .20076 L
.69149 .20076 L
.69176 .20076 L
.69189 .20076 L
.69195 .20076 L
.69198 .20076 L
.69201 .20076 L
.69207 .00394 L
.69213 .00394 L
.69224 .00394 L
.69249 .00394 L
.69448 .00394 L
.69639 .00394 L
.69823 .00394 L
.70018 .00394 L
.70207 .00394 L
.70407 .00394 L
.706 .00394 L
.70785 .00394 L
.70983 .00394 L
.71173 .00394 L
.71356 .00394 L
.7155 .00394 L
.71738 .00394 L
.71937 .00394 L
.72129 .00394 L
.72313 .00394 L
.72509 .00394 L
.72698 .00394 L
.7288 .00394 L
.73074 .00394 L
.7326 .00394 L
.73458 .00394 L
.73649 .00394 L
.73832 .00394 L
.74027 .00394 L
.74215 .00394 L
.74415 .00394 L
.74608 .00394 L
.74793 .00394 L
.7499 .00394 L
Mistroke
.75088 .00394 L
.75136 .00394 L
.75179 .00394 L
.75201 .00394 L
.75212 .00394 L
.75225 .00394 L
.7523 .00394 L
.75235 .00394 L
.75241 .59441 L
.75247 .59441 L
.75267 .59441 L
.75362 .59441 L
.75458 .59441 L
.75506 .59441 L
.7552 .59441 L
.75534 .59441 L
.75541 .59441 L
.75547 .59441 L
.75553 .59441 L
.75559 .00394 L
.75565 .00394 L
.75571 .00394 L
.75583 .00394 L
.75605 .00394 L
.75655 .00394 L
.75756 .00394 L
.75947 .00394 L
.76131 .00394 L
.76326 .00394 L
.76514 .00394 L
.76714 .00394 L
.76907 .00394 L
.77093 .00394 L
.7729 .00394 L
.7748 .00394 L
.77662 .00394 L
.77857 .00394 L
.78044 .00394 L
.78243 .00394 L
.78435 .00394 L
.78619 .00394 L
.78815 .00394 L
.79004 .00394 L
.79186 .00394 L
.79379 .00394 L
.79565 .00394 L
.79763 .00394 L
.79953 .00394 L
.80137 .00394 L
.80332 .00394 L
Mistroke
.8052 .00394 L
.80719 .00394 L
.80912 .00394 L
.81097 .00394 L
.81293 .00394 L
.81391 .00394 L
.81483 .00394 L
.81528 .00394 L
.8155 .00394 L
.81571 .00394 L
.81577 .00394 L
.81582 .00394 L
.81585 .00394 L
.81589 .59441 L
.81594 .59441 L
.8162 .59441 L
.81665 .59441 L
.81759 .59441 L
.81809 .59441 L
.81837 .59441 L
.81863 .59441 L
.81887 .59441 L
.81894 .59441 L
.81898 .59441 L
.81901 .59441 L
.81907 .00394 L
.81911 .00394 L
.81914 .00394 L
.81961 .00394 L
.82053 .00394 L
.82251 .00394 L
.82442 .00394 L
.82625 .00394 L
.82821 .00394 L
.83009 .00394 L
.83209 .00394 L
.83401 .00394 L
.83586 .00394 L
.83784 .00394 L
.83973 .00394 L
.84156 .00394 L
.8435 .00394 L
.84537 .00394 L
.84736 .00394 L
.84927 .00394 L
.85112 .00394 L
.85308 .00394 L
.85496 .00394 L
.85678 .00394 L
.85871 .00394 L
Mistroke
.86057 .00394 L
.86255 .00394 L
.86445 .00394 L
.86628 .00394 L
.86823 .00394 L
.87011 .00394 L
.8721 .00394 L
.87402 .00394 L
.87587 .00394 L
.87681 .00394 L
.87784 .00394 L
.87831 .00394 L
.87882 .00394 L
.87906 .00394 L
.87918 .00394 L
.87924 .00394 L
.8793 .00394 L
.87935 .00394 L
.8794 .20076 L
.87945 .20076 L
.8795 .20076 L
.87973 .20076 L
.88067 .20076 L
.88117 .20076 L
.88171 .20076 L
.88197 .20076 L
.88222 .20076 L
.88233 .20076 L
.88244 .20076 L
.88251 .20076 L
.88254 .20076 L
.88257 .00394 L
.88263 .00394 L
.88269 .00394 L
.88361 .00394 L
.88559 .00394 L
.88749 .00394 L
.88933 .00394 L
.89128 .00394 L
.89316 .00394 L
.89515 .00394 L
.89708 .00394 L
.89893 .00394 L
.9009 .00394 L
.9028 .00394 L
.90462 .00394 L
.90656 .00394 L
.90843 .00394 L
.91041 .00394 L
.91233 .00394 L
Mistroke
.91417 .00394 L
.91613 .00394 L
.91801 .00394 L
.92002 .00394 L
.92195 .00394 L
.9238 .00394 L
.92578 .00394 L
.92768 .00394 L
.92951 .00394 L
.93146 .00394 L
.93334 .00394 L
.93533 .00394 L
.93725 .00394 L
.9391 .00394 L
.94003 .00394 L
.94106 .00394 L
.94153 .00394 L
.94204 .00394 L
.94228 .00394 L
.94252 .00394 L
.94273 .00394 L
.94278 .00394 L
.94284 .00394 L
.9429 .59441 L
.94295 .59441 L
.94396 .59441 L
.94488 .59441 L
.94535 .59441 L
.94578 .59441 L
.94589 .59441 L
.94595 .59441 L
.946 .59441 L
.94606 .00394 L
.94609 .00394 L
.94612 .00394 L
.94624 .00394 L
.94673 .00394 L
.94855 .00394 L
.95048 .00394 L
.95234 .00394 L
.95432 .00394 L
.95623 .00394 L
.95806 .00394 L
.96001 .00394 L
.96189 .00394 L
.96388 .00394 L
.9658 .00394 L
.96765 .00394 L
.96962 .00394 L
.97152 .00394 L
Mistroke
.97334 .00394 L
.97528 .00394 L
.97619 .00394 L
Mfstroke
0 0 1 r
.005 w
.02381 .00394 m
.02474 .00394 L
.02575 .00394 L
.0267 .00394 L
.02761 .00394 L
.02859 .00394 L
.02952 .00394 L
.03052 .00394 L
.03148 .00394 L
.0324 .00394 L
.03338 .00394 L
.03433 .00394 L
.03524 .00394 L
.03621 .00394 L
.03714 .00394 L
.03813 .00394 L
.03908 .00394 L
.04 .00394 L
.04098 .00394 L
.04192 .00394 L
.04292 .00394 L
.04388 .00394 L
.0448 .00394 L
.04579 .00394 L
.04674 .00394 L
.04765 .00394 L
.04862 .00394 L
.04956 .00394 L
.05055 .00394 L
.05151 .00394 L
.05243 .00394 L
.05341 .00394 L
.05435 .00394 L
.05526 .00394 L
.05622 .00394 L
.05715 .00394 L
.05814 .00394 L
.05909 .00394 L
.06001 .00394 L
.06098 .00394 L
.06192 .00394 L
.06292 .00394 L
.06388 .00394 L
.0648 .00394 L
.06579 .00394 L
.06673 .00394 L
.06764 .00394 L
.06861 .00394 L
.06954 .00394 L
.07054 .00394 L
Mistroke
.07149 .00394 L
.07241 .00394 L
.07339 .00394 L
.07433 .00394 L
.07533 .00394 L
.07629 .00394 L
.07722 .00394 L
.07821 .00394 L
.07916 .00394 L
.08007 .00394 L
.08104 .00394 L
.08198 .00394 L
.08297 .00394 L
.08393 .00394 L
.08485 .00394 L
.08584 .00394 L
.08678 .00394 L
.08769 .00394 L
.08866 .00394 L
.08959 .00394 L
.09058 .00394 L
.09153 .00394 L
.09245 .00394 L
.09342 .00394 L
.09436 .00394 L
.09536 .00394 L
.09632 .00394 L
.09725 .00394 L
.09823 .00394 L
.09918 .00394 L
.10009 .00394 L
.10106 .00394 L
.10199 .00394 L
.10299 .00394 L
.10394 .00394 L
.10486 .00394 L
.10584 .00394 L
.10678 .00394 L
.10769 .00394 L
.10866 .00394 L
.10958 .00394 L
.11057 .00394 L
.11152 .00394 L
.11244 .00394 L
.11341 .00394 L
.11435 .00394 L
.11535 .00394 L
.1163 .00394 L
.11723 .00394 L
.11821 .00394 L
Mistroke
.11916 .00394 L
.12007 .00394 L
.12103 .00394 L
.12197 .00394 L
.12296 .00394 L
.12391 .00394 L
.12483 .00394 L
.12581 .00394 L
.12675 .00394 L
.12775 .00394 L
.12871 .00394 L
.12964 .00394 L
.13062 .00394 L
.13157 .00394 L
.13248 .00394 L
.13345 .00394 L
.13439 .00394 L
.13538 .00394 L
.13634 .00394 L
.13726 .00394 L
.13824 .00394 L
.13919 .00394 L
.14009 .00394 L
.14106 .00394 L
.14199 .00394 L
.14298 .00394 L
.14393 .00394 L
.14485 .00394 L
.14582 .00394 L
.14676 .00394 L
.14776 .00394 L
.14872 .00394 L
.14964 .00394 L
.15063 .00394 L
.15158 .00394 L
.15249 .00394 L
.15346 .00394 L
.15439 .00394 L
.15538 .00394 L
.15634 .00394 L
.15726 .00394 L
.15823 .00394 L
.15918 .00394 L
.16018 .00394 L
.16114 .00394 L
.16207 .00394 L
.16306 .00394 L
.16401 .00394 L
.16492 .00394 L
.16589 .00394 L
Mistroke
.16683 .00394 L
.16782 .00394 L
.16878 .00394 L
.16971 .00394 L
.17069 .00394 L
.17163 .00394 L
.17254 .00394 L
.17351 .00394 L
.17444 .00394 L
.17543 .00394 L
.17638 .00394 L
.1773 .00394 L
.17828 .00394 L
.17922 .00394 L
.18022 .00394 L
.18118 .00394 L
.1821 .00394 L
.18309 .00394 L
.18404 .00394 L
.18495 .00394 L
.18592 .00394 L
.18685 .00394 L
.18785 .00394 L
.1888 .00394 L
.18972 .00394 L
.1907 .00394 L
.19165 .00394 L
.19255 .00394 L
.19352 .00394 L
.19445 .00394 L
.19544 .00394 L
.19639 .00394 L
.1973 .00394 L
.19828 .00394 L
.19922 .00394 L
.20021 .00394 L
.20117 .00394 L
.2021 .00394 L
.20308 .00394 L
.20403 .00394 L
.20494 .00394 L
.2059 .00394 L
.20684 .00394 L
.20783 .00394 L
.20878 .00394 L
.2097 .00394 L
.21068 .00394 L
.21162 .00394 L
.21262 .00394 L
.21358 .00394 L
Mistroke
.21451 .00394 L
.2155 .00394 L
.21645 .00394 L
.21736 .00394 L
.21833 .00394 L
.21927 .00394 L
.22026 .00394 L
.22122 .00394 L
.22214 .00394 L
.22312 .00394 L
.22407 .00394 L
.22497 .00394 L
.22594 .00394 L
.22687 .00394 L
.22786 .00394 L
.22881 .00394 L
.22973 .00394 L
.23071 .00394 L
.23164 .00394 L
.23264 .00394 L
.2336 .00394 L
.23453 .00394 L
.23551 .00394 L
.23646 .00394 L
.23737 .00394 L
.23834 .00394 L
.23928 .00394 L
.24027 .00394 L
.24122 .00394 L
.24214 .00394 L
.24312 .00394 L
.24406 .00394 L
.24497 .00394 L
.24594 .00394 L
.24686 .00394 L
.24785 .00394 L
.2488 .00394 L
.24972 .00394 L
.25069 .00394 L
.25163 .00394 L
.25262 .00394 L
.25358 .00394 L
.25451 .00394 L
.25549 .00394 L
.25643 .00394 L
.25734 .00394 L
.25831 .00394 L
.25924 .00394 L
.26023 .00394 L
.26119 .00394 L
Mistroke
.2621 .00394 L
.26308 .00394 L
.26402 .00394 L
.26502 .00394 L
.26598 .00394 L
.26691 .00394 L
.26789 .00394 L
.26884 .00394 L
.26976 .00394 L
.27073 .00394 L
.27166 .00394 L
.27266 .00394 L
.27361 .00394 L
.27453 .00394 L
.27551 .00394 L
.27646 .00394 L
.27736 .00394 L
.27833 .00394 L
.27926 .00394 L
.28025 .00394 L
.2812 .00394 L
.28212 .00394 L
.28309 .00394 L
.28403 .00394 L
.28503 .00394 L
.28599 .00394 L
.28691 .00394 L
.28789 .00394 L
.28884 .00394 L
.28975 .00394 L
.29072 .00394 L
.29165 .00394 L
.29265 .00394 L
.2936 .00394 L
.29452 .00394 L
.2955 .00394 L
.29644 .00394 L
.29744 .00394 L
.2984 .00394 L
.29933 .00394 L
.30032 .00394 L
.30127 .00394 L
.30218 .00394 L
.30315 .00394 L
.30409 .00394 L
.30509 .00394 L
.30604 .00394 L
.30697 .00394 L
.30795 .00394 L
.30889 .00394 L
Mistroke
.3098 .00394 L
.31077 .00394 L
.3117 .00394 L
.31269 .00394 L
.31364 .00394 L
.31456 .00394 L
.31554 .00394 L
.31647 .00394 L
.31747 .00394 L
.31844 .00394 L
.31936 .00394 L
.32035 .00394 L
.32129 .00394 L
.3222 .00394 L
.32318 .00394 L
.32411 .00394 L
.3251 .00394 L
.32606 .00394 L
.32698 .00394 L
.32796 .00394 L
.3289 .00394 L
.32981 .00394 L
.33077 .00394 L
.3317 .00394 L
.33269 .00394 L
.33364 .00394 L
.33456 .00394 L
.33553 .00394 L
.33647 .00394 L
.33746 .00394 L
.33842 .00394 L
.33935 .00394 L
.34033 .00394 L
.34128 .00394 L
.34218 .00394 L
.34315 .00394 L
.34409 .00394 L
.34508 .00394 L
.34603 .00394 L
.34695 .00394 L
.34793 .00394 L
.34887 .00394 L
.34987 .00394 L
.35083 .00394 L
.35176 .00394 L
.35274 .00394 L
.35369 .00394 L
.3546 .00394 L
.35558 .00394 L
.35651 .00394 L
Mistroke
.35751 .00394 L
.35846 .00394 L
.35939 .00394 L
.36037 .00394 L
.36131 .00394 L
.36222 .00394 L
.36318 .00394 L
.36411 .00394 L
.3651 .00394 L
.36606 .00394 L
.36697 .00394 L
.36795 .00394 L
.36889 .00394 L
.36988 .00394 L
.37038 .00394 L
.37084 .00394 L
.37129 .00394 L
.37152 .00394 L
.37158 .00394 L
.37165 .00394 L
.37168 .00394 L
.37171 .00394 L
.37174 .00394 L
.37177 .39759 L
.37179 .39759 L
.3718 .39759 L
.37183 .39759 L
.3719 .39759 L
.37202 .39759 L
.37224 .39759 L
.37275 .39759 L
.37366 .39759 L
.3739 .39759 L
.37413 .39759 L
.37419 .39759 L
.37423 .39759 L
.37426 .39759 L
.37427 .39759 L
.37429 .00394 L
.37431 .00394 L
.37433 .00394 L
.3744 .00394 L
.37464 .00394 L
.37559 .00394 L
.37651 .00394 L
.37748 .00394 L
.37842 .00394 L
.37942 .00394 L
.38038 .00394 L
.38131 .00394 L
Mistroke
.3823 .00394 L
.38324 .00394 L
.38416 .00394 L
.38513 .00394 L
.38606 .00394 L
.38705 .00394 L
.38801 .00394 L
.38893 .00394 L
.38991 .00394 L
.39086 .00394 L
.39176 .00394 L
.39273 .00394 L
.39366 .00394 L
.39465 .00394 L
.3956 .00394 L
.39651 .00394 L
.39749 .00394 L
.39843 .00394 L
.39942 .00394 L
.40038 .00394 L
.40131 .00394 L
.40229 .00394 L
.40324 .00394 L
.40415 .00394 L
.40511 .00394 L
.40605 .00394 L
.40704 .00394 L
.40799 .00394 L
.40891 .00394 L
.40989 .00394 L
.41083 .00394 L
.41183 .00394 L
.4128 .00394 L
.41372 .00394 L
.41471 .00394 L
.41566 .00394 L
.41657 .00394 L
.41754 .00394 L
.41848 .00394 L
.41948 .00394 L
.42043 .00394 L
.42136 .00394 L
.42234 .00394 L
.42328 .00394 L
.42419 .00394 L
.42516 .00394 L
.42609 .00394 L
.42708 .00394 L
.42803 .00394 L
.42895 .00394 L
Mistroke
.42992 .00394 L
.43086 .00394 L
.43186 .00394 L
.43282 .00394 L
.43375 .00394 L
.43421 .00394 L
.43473 .00394 L
.43497 .00394 L
.4351 .00394 L
.43516 .00394 L
.43519 .00394 L
.43522 .00394 L
.43525 .20076 L
.43528 .20076 L
.43533 .20076 L
.43546 .20076 L
.43568 .20076 L
.43661 .20076 L
.43708 .20076 L
.43733 .20076 L
.43746 .20076 L
.43759 .20076 L
.43765 .20076 L
.43772 .20076 L
.43775 .20076 L
.43777 .20076 L
.43779 .00394 L
.43782 .00394 L
.43785 .00394 L
.43809 .00394 L
.43854 .00394 L
.43954 .00394 L
.44049 .00394 L
.44141 .00394 L
.44238 .00394 L
.44332 .00394 L
.44432 .00394 L
.44529 .00394 L
.44621 .00394 L
.4472 .00394 L
.44815 .00394 L
.44906 .00394 L
.45003 .00394 L
.45097 .00394 L
.45196 .00394 L
.45292 .00394 L
.45384 .00394 L
.45482 .00394 L
.45576 .00394 L
.45667 .00394 L
Mistroke
.45764 .00394 L
.45857 .00394 L
.45956 .00394 L
.46051 .00394 L
.46142 .00394 L
.4624 .00394 L
.46334 .00394 L
.46433 .00394 L
.4653 .00394 L
.46622 .00394 L
.4672 .00394 L
.46815 .00394 L
.46906 .00394 L
.47003 .00394 L
.47096 .00394 L
.47196 .00394 L
.47291 .00394 L
.47383 .00394 L
.47481 .00394 L
.47575 .00394 L
.47675 .00394 L
.47771 .00394 L
.47864 .00394 L
.47963 .00394 L
.48058 .00394 L
.48149 .00394 L
.48247 .00394 L
.4834 .00394 L
.4844 .00394 L
.48536 .00394 L
.48628 .00394 L
.48726 .00394 L
.48821 .00394 L
.48911 .00394 L
.49008 .00394 L
.49101 .00394 L
.492 .00394 L
.49296 .00394 L
.49387 .00394 L
.49485 .00394 L
.49579 .00394 L
.49679 .00394 L
.49775 .00394 L
.49819 .00394 L
.49844 .00394 L
.49856 .00394 L
.49862 .00394 L
.49867 .00394 L
.4987 .00394 L
.49873 .20076 L
Mistroke
.49876 .20076 L
.49879 .20076 L
.49891 .20076 L
.49915 .20076 L
.49966 .20076 L
.50016 .20076 L
.50063 .20076 L
.50086 .20076 L
.50108 .20076 L
.50119 .20076 L
.50122 .20076 L
.50125 .20076 L
.50128 .00394 L
.50131 .00394 L
.50155 .00394 L
.50254 .00394 L
.50348 .00394 L
.50439 .00394 L
.50536 .00394 L
.50629 .00394 L
.50728 .00394 L
.50824 .00394 L
.50916 .00394 L
.51014 .00394 L
.51108 .00394 L
.51208 .00394 L
.51304 .00394 L
.51397 .00394 L
.51495 .00394 L
.5159 .00394 L
.51682 .00394 L
.51779 .00394 L
.51872 .00394 L
.51972 .00394 L
.52068 .00394 L
.5216 .00394 L
.52258 .00394 L
.52352 .00394 L
.52443 .00394 L
.5254 .00394 L
.52633 .00394 L
.52732 .00394 L
.52827 .00394 L
.52918 .00394 L
.53016 .00394 L
.5311 .00394 L
.5321 .00394 L
.53306 .00394 L
.53398 .00394 L
.53497 .00394 L
Mistroke
.53591 .00394 L
.53683 .00394 L
.5378 .00394 L
.53873 .00394 L
.53972 .00394 L
.54068 .00394 L
.5416 .00394 L
.54258 .00394 L
.54352 .00394 L
.54442 .00394 L
.54539 .00394 L
.54632 .00394 L
.5473 .00394 L
.54825 .00394 L
.54917 .00394 L
.55014 .00394 L
.55108 .00394 L
.55207 .00394 L
.55303 .00394 L
.55396 .00394 L
.55494 .00394 L
.55588 .00394 L
.55679 .00394 L
.55776 .00394 L
.55869 .00394 L
.55968 .00394 L
.56064 .00394 L
.56155 .00394 L
.5618 .00394 L
.56203 .00394 L
.56209 .00394 L
.56215 .00394 L
.56219 .00394 L
.56221 .00394 L
.56223 .20076 L
.56226 .20076 L
.56229 .20076 L
.56253 .20076 L
.56352 .20076 L
.56402 .20076 L
.56424 .20076 L
.56448 .20076 L
.56459 .20076 L
.56465 .20076 L
.56468 .20076 L
.56471 .20076 L
.56474 .20076 L
.56477 .00394 L
.5648 .00394 L
.56483 .00394 L
Mistroke
.56493 .00394 L
.5654 .00394 L
.56636 .00394 L
.56729 .00394 L
.56827 .00394 L
.56922 .00394 L
.57013 .00394 L
.5711 .00394 L
.57203 .00394 L
.57302 .00394 L
.57398 .00394 L
.5749 .00394 L
.57587 .00394 L
.57682 .00394 L
.57782 .00394 L
.57878 .00394 L
.57971 .00394 L
.58069 .00394 L
.58164 .00394 L
.58256 .00394 L
.58353 .00394 L
.58447 .00394 L
.58546 .00394 L
.58642 .00394 L
.58734 .00394 L
.58832 .00394 L
.58927 .00394 L
.59017 .00394 L
.59114 .00394 L
.59207 .00394 L
.59306 .00394 L
.59402 .00394 L
.59493 .00394 L
.59591 .00394 L
.59685 .00394 L
.59785 .00394 L
.59881 .00394 L
.59973 .00394 L
.60072 .00394 L
.60167 .00394 L
.60258 .00394 L
.60355 .00394 L
.60448 .00394 L
.60547 .00394 L
.60643 .00394 L
.60735 .00394 L
.60833 .00394 L
.60927 .00394 L
.61018 .00394 L
.61114 .00394 L
Mistroke
.61207 .00394 L
.61306 .00394 L
.61401 .00394 L
.61493 .00394 L
.6159 .00394 L
.61684 .00394 L
.61783 .00394 L
.61879 .00394 L
.61972 .00394 L
.6207 .00394 L
.62165 .00394 L
.62255 .00394 L
.62352 .00394 L
.62446 .00394 L
.62493 .00394 L
.62518 .00394 L
.62545 .00394 L
.62558 .00394 L
.62565 .00394 L
.62567 .00394 L
.62571 .00394 L
.62573 .39759 L
.62576 .39759 L
.62582 .39759 L
.62594 .39759 L
.6264 .39759 L
.62734 .39759 L
.62758 .39759 L
.62785 .39759 L
.62797 .39759 L
.6281 .39759 L
.62815 .39759 L
.62821 .39759 L
.62822 .39759 L
.62824 .39759 L
.62827 .00394 L
.6283 .00394 L
.62833 .00394 L
.62931 .00394 L
.63024 .00394 L
.63124 .00394 L
.6322 .00394 L
.63313 .00394 L
.63411 .00394 L
.63506 .00394 L
.63597 .00394 L
.63694 .00394 L
.63787 .00394 L
.63886 .00394 L
.63982 .00394 L
Mistroke
.64074 .00394 L
.64172 .00394 L
.64266 .00394 L
.64366 .00394 L
.64462 .00394 L
.64555 .00394 L
.64654 .00394 L
.64749 .00394 L
.6484 .00394 L
.64938 .00394 L
.65031 .00394 L
.65131 .00394 L
.65227 .00394 L
.65319 .00394 L
.65417 .00394 L
.65512 .00394 L
.65603 .00394 L
.65699 .00394 L
.65792 .00394 L
.65891 .00394 L
.65987 .00394 L
.66079 .00394 L
.66176 .00394 L
.6627 .00394 L
.6637 .00394 L
.66466 .00394 L
.66559 .00394 L
.66657 .00394 L
.66752 .00394 L
.66843 .00394 L
.6694 .00394 L
.67034 .00394 L
.67133 .00394 L
.67229 .00394 L
.67321 .00394 L
.67419 .00394 L
.67513 .00394 L
.67604 .00394 L
.67701 .00394 L
.67793 .00394 L
.67892 .00394 L
.67987 .00394 L
.68079 .00394 L
.68176 .00394 L
.6827 .00394 L
.6837 .00394 L
.68466 .00394 L
.68558 .00394 L
.68657 .00394 L
.68751 .00394 L
Mistroke
.68842 .00394 L
.68939 .00394 L
.69032 .00394 L
.69131 .00394 L
.69227 .00394 L
.69319 .00394 L
.69417 .00394 L
.69511 .00394 L
.69611 .00394 L
.69707 .00394 L
.698 .00394 L
.69898 .00394 L
.69993 .00394 L
.70085 .00394 L
.70182 .00394 L
.70275 .00394 L
.70375 .00394 L
.70471 .00394 L
.70563 .00394 L
.70661 .00394 L
.70755 .00394 L
.70846 .00394 L
.70943 .00394 L
.71036 .00394 L
.71135 .00394 L
.7123 .00394 L
.71322 .00394 L
.71419 .00394 L
.71513 .00394 L
.71613 .00394 L
.71709 .00394 L
.71802 .00394 L
.719 .00394 L
.71995 .00394 L
.72086 .00394 L
.72183 .00394 L
.72276 .00394 L
.72376 .00394 L
.72471 .00394 L
.72563 .00394 L
.72661 .00394 L
.72755 .00394 L
.72846 .00394 L
.72942 .00394 L
.73035 .00394 L
.73134 .00394 L
.73229 .00394 L
.73321 .00394 L
.73418 .00394 L
.73512 .00394 L
Mistroke
.73611 .00394 L
.73707 .00394 L
.738 .00394 L
.73898 .00394 L
.73992 .00394 L
.74083 .00394 L
.7418 .00394 L
.74273 .00394 L
.74372 .00394 L
.74468 .00394 L
.74559 .00394 L
.74657 .00394 L
.74751 .00394 L
.74851 .00394 L
.74947 .00394 L
.7504 .00394 L
.75139 .00394 L
.75233 .00394 L
.75325 .00394 L
.75422 .00394 L
.75515 .00394 L
.75615 .00394 L
.7571 .00394 L
.75803 .00394 L
.75901 .00394 L
.75995 .00394 L
.76086 .00394 L
.76182 .00394 L
.76275 .00394 L
.76374 .00394 L
.76469 .00394 L
.76561 .00394 L
.76658 .00394 L
.76752 .00394 L
.76852 .00394 L
.76948 .00394 L
.7704 .00394 L
.77139 .00394 L
.77233 .00394 L
.77324 .00394 L
.77421 .00394 L
.77515 .00394 L
.77614 .00394 L
.77709 .00394 L
.77801 .00394 L
.77899 .00394 L
.77993 .00394 L
.78093 .00394 L
.7819 .00394 L
.78283 .00394 L
Mistroke
.78381 .00394 L
.78476 .00394 L
.78568 .00394 L
.78665 .00394 L
.78758 .00394 L
.78858 .00394 L
.78954 .00394 L
.79046 .00394 L
.79144 .00394 L
.79239 .00394 L
.7933 .00394 L
.79426 .00394 L
.79519 .00394 L
.79618 .00394 L
.79714 .00394 L
.79805 .00394 L
.79903 .00394 L
.79997 .00394 L
.80097 .00394 L
.80193 .00394 L
.80286 .00394 L
.80384 .00394 L
.80479 .00394 L
.8057 .00394 L
.80667 .00394 L
.8076 .00394 L
.8086 .00394 L
.80955 .00394 L
.81047 .00394 L
.81145 .00394 L
.8124 .00394 L
.8133 .00394 L
.81427 .00394 L
.8152 .00394 L
.81619 .00394 L
.81714 .00394 L
.81805 .00394 L
.81903 .00394 L
.81996 .00394 L
.82096 .00394 L
.82192 .00394 L
.82284 .00394 L
.82383 .00394 L
.82477 .00394 L
.82568 .00394 L
.82665 .00394 L
.82758 .00394 L
.82857 .00394 L
.82953 .00394 L
.83045 .00394 L
Mistroke
.83142 .00394 L
.83236 .00394 L
.83336 .00394 L
.83433 .00394 L
.83525 .00394 L
.83624 .00394 L
.83719 .00394 L
.8381 .00394 L
.83907 .00394 L
.84001 .00394 L
.841 .00394 L
.84196 .00394 L
.84288 .00394 L
.84386 .00394 L
.84481 .00394 L
.84572 .00394 L
.84668 .00394 L
.84761 .00394 L
.8486 .00394 L
.84955 .00394 L
.85047 .00394 L
.85145 .00394 L
.85238 .00394 L
.85338 .00394 L
.85434 .00394 L
.85527 .00394 L
.85625 .00394 L
.8572 .00394 L
.85811 .00394 L
.85908 .00394 L
.86001 .00394 L
.86101 .00394 L
.86196 .00394 L
.86288 .00394 L
.86386 .00394 L
.8648 .00394 L
.8658 .00394 L
.86677 .00394 L
.8677 .00394 L
.86868 .00394 L
.86963 .00394 L
.87055 .00394 L
.87152 .00394 L
.87246 .00394 L
.87345 .00394 L
.87441 .00394 L
.87533 .00394 L
.87632 .00394 L
.87726 .00394 L
.87817 .00394 L
Mistroke
.87914 .00394 L
.88007 .00394 L
.88106 .00394 L
.88201 .00394 L
.88293 .00394 L
.88391 .00394 L
.88485 .00394 L
.88585 .00394 L
.88681 .00394 L
.88774 .00394 L
.88872 .00394 L
.88967 .00394 L
.89058 .00394 L
.89155 .00394 L
.89249 .00394 L
.89348 .00394 L
.89444 .00394 L
.89536 .00394 L
.89634 .00394 L
.89728 .00394 L
.89819 .00394 L
.89915 .00394 L
.90008 .00394 L
.90107 .00394 L
.90202 .00394 L
.90294 .00394 L
.90391 .00394 L
.90485 .00394 L
.90585 .00394 L
.90681 .00394 L
.90773 .00394 L
.90872 .00394 L
.90966 .00394 L
.91057 .00394 L
.91154 .00394 L
.91248 .00394 L
.91347 .00394 L
.91442 .00394 L
.91534 .00394 L
.91632 .00394 L
.91726 .00394 L
.91826 .00394 L
.91922 .00394 L
.92015 .00394 L
.92114 .00394 L
.92209 .00394 L
.923 .00394 L
.92397 .00394 L
.92491 .00394 L
.9259 .00394 L
Mistroke
.92686 .00394 L
.92778 .00394 L
.92877 .00394 L
.92971 .00394 L
.93062 .00394 L
.93158 .00394 L
.93252 .00394 L
.93351 .00394 L
.93446 .00394 L
.93537 .00394 L
.93635 .00394 L
.93729 .00394 L
.93829 .00394 L
.93925 .00394 L
.94018 .00394 L
.94116 .00394 L
.94211 .00394 L
.94302 .00394 L
.94399 .00394 L
.94492 .00394 L
.94592 .00394 L
.94687 .00394 L
.94779 .00394 L
.94877 .00394 L
.94971 .00394 L
.95062 .00394 L
.95158 .00394 L
.95251 .00394 L
.9535 .00394 L
.95445 .00394 L
.95537 .00394 L
.95634 .00394 L
.95728 .00394 L
.95827 .00394 L
.95923 .00394 L
.96016 .00394 L
.96114 .00394 L
.96208 .00394 L
.96299 .00394 L
.96396 .00394 L
.96489 .00394 L
.96588 .00394 L
.96684 .00394 L
.96776 .00394 L
.96873 .00394 L
.96967 .00394 L
.97067 .00394 L
.97164 .00394 L
.97256 .00394 L
.97355 .00394 L
Mistroke
.9745 .00394 L
.97541 .00394 L
.97619 .00394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00=Oooool3o`00023ooooo0ol0000Mooooo`Go00007?ooool2o`0001gooooo1Ol0000Ooooo
o`?o00007_ooool3o`00023ooooo000dooooo`05o`000?ooooooooooooooool000008?ooool00ol0
003oooooooooo`0Mooooo`04o`000?ooooooooooo`0001_ooooo00Co0000oooooooooooo00007Ooo
ool01?l0003oooooooooool0000Pooooo`03o`000?oooooooooo01cooooo00Go0000oooooooooooo
ooooo`00000Oooooo`00;_ooool5o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
5Oooool5o`000003ooooool0003o000000?o00005oooool5o`0000?ooooo00?o0000ooooooooool0
6oooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo01gooooo1Ol0000Mooooo`05
o`000?ooooooooooooooool000007oooool003Cooooo1?l0000Nooooo`04o`000?ooooooooooo`00
027ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0000Oooooo`03o`000?oooooo
oooo01cooooo00Co0000oooooooooooo00007_ooool4o`00023ooooo000dooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooool000007_ooool01Ol0003ooooooooooooooooo000001_ooooo00Co
0000oooooooooooo00007?ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooool0
00007_ooool00ol0003oooooooooo`0Qooooo`00=Oooool00ol0003oooooooooo`0Pooooo`;o0000
7_ooool01Ol0003ooooooooooooooooo000001_ooooo00Co0000oooooooooooo00007?ooool01Ol0
003ooooooooooooooooo000001oooooo0_l0000Oooooo`03o`000?oooooooooo023ooooo000foooo
o`;o00008Oooool00ol0003oooooooooo`0Mooooo`?o00007Oooool2o`0001kooooo0ol0000Qoooo
o`03o`000?oooooooooo01kooooo0_l0000Pooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`003_ooool2o`000?oooooo4Oooool000gooooo00Co0000oooooooooooo00001?oooooo
o`0000_o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool2o`0000?ooooo00?oo`00
o`00ool00?l0o?l00?l4ooooo`;o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`02oooooekoo`0000?o003oool00?oo00003Ooo0002o`00o`ooo`000_l00?l?
ool000;o003o3ooo0002o`00oecoo`001Oooool1o`00007ooooo000=ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0_oo000>ooooo`;oo`0000?o003oooooooooool03?ooool00ooo003o003oo`00o`0>
ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>
ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001
ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00[ooooo0ooo000>
ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool00003o`00oooooooo
oooo00cooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo
003o00kooooo00?oo`00o`00ool00?l03_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3
ool000kooooo0ooo000=ooooo`7o00000Oooool000kooooo0_l00005ooooo`03o`000?oooooooooo
00[ooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool0
0003o`00oooooooooooo00cooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>oooo
o`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool3ool000kooooo0_oo000>oooo
o`?oo`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool001Gooooo0_l0000;ooooo`?o
o`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0_oo00000ol00?oo
ooooooooo`0<ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o
003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3ool000ko
oooo0ooo000>ooooo`?oo`003?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo
0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool00003o`00
oooooooooooo00cooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool0
0?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool3ool000kooooo0_oo000>ooooo`?oo`00
3_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_oo
ool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`;oo`0000?o
003oooooooooool03?ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?o
o`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo
000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:
ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0_oo0000
0ol00?ooooooooooo`0<ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool0
0ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3
ool000kooooo0ooo000>ooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
00[ooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool0
0003o`00oooooooooooo00cooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>oooo
o`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool3ool000kooooo0_oo000>oooo
o`?oo`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool02_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`;o
o`0000?o003oooooooooool03?ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00ko
oooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`?oo`003_ooool2ool000ko
oooo0ooo000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`005Oooool2o`0000_ooooo
0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool00003o`00
oooooooooooo00cooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool0
0?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool3ool000kooooo0_oo000>ooooo`?oo`00
3_ooool3ool000kooooo0ooo000<ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool02_oo
ool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`;oo`0000?o
003oooooooooool03?ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?o
o`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo
000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:
ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0_oo0000
0ol00?ooooooooooo`0<ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool0
0ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3
ool000kooooo0ooo000>ooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
00[ooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool0
0003o`00oooooooooooo00cooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>oooo
o`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool3ool000kooooo0_oo000>oooo
o`?oo`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool02_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`;o
o`0000?o003oooooooooool03?ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00ko
oooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`?oo`003_ooool2ool000ko
oooo0ooo000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`005Oooool2o`0000_ooooo
0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool00003o`00
oooooooooooo00cooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool0
0?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool3ool000kooooo0_oo000>ooooo`?oo`00
3_ooool3ool000kooooo0ooo000<ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool02_oo
ool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`;oo`0000?o
003oooooooooool03?ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?o
o`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo
000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:
ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0_oo0000
0ol00?ooooooooooo`0<ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool0
0ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3
ool000kooooo0ooo000>ooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
00[ooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool0
0003o`00oooooooooooo00cooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>oooo
o`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool3ool000kooooo0_oo000>oooo
o`?oo`003_ooool3ool000kooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool02_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`;o
o`0000?o003oooooooooool03?ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00ko
oooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`?oo`003_ooool2ool000ko
oooo0ooo000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`005Oooool2o`0000_ooooo
0ooo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool00003o`00
oooooooooooo00cooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool0
0?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool3ool000kooooo0_oo000>ooooo`?oo`00
3_ooool3ool000kooooo0ooo000<ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool02_oo
ool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`;oo`0000?o
003oooooooooool03?ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?o
o`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo
000>ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:
ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0_oo0000
0ol00?ooooooooooo`0<ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool0
0ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3
ool000kooooo0ooo000>ooooo`?oo`003Oooool1o`00007ooooo0002ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool0
00kooooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0_oo00000ol00?ooooooooooo`0<oooo
o`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>oooo
o`03ool00?l00?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>oooo
o`?oo`003Oooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00[ooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool00003o`00oooooooooooo00cooooo00?oo`00
o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00
o`00ool00?l03_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=
ooooo`7o00000Oooool00005ooooool0003oooooooooool000002oooool00ol0003oooooooooo`02
ooooo`;o00002oooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>
ooooo`;oo`0000?o003oooooooooool03?ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo
003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`?oo`003_ooool2
ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000cooooo0_l00001ooooo`0000Goooooo`00
0?ooooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool3
ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000kooooo0_oo000>ooooo`;oo`0000?o003o
ooooooooool03?ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00
o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo000>
ooooo`?oo`003_ooool3ool000gooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000007
ooooo`Co00001Oooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo000>
ooooo`?oo`003_ooool2ool000kooooo0_oo00000ol00?ooooooooooo`0<ooooo`03ool00?l00?oo
003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo
003o00kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Oooool1
o`00007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2
ool000kooooo0_oo00000ol00?ooooooooooo`0<ooooo`03ool00?l00?oo003o00kooooo00?oo`00
o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo0ooo000>
ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Oooool1o`00007ooooo0002oooo
o`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo000>oooo
o`?oo`003_ooool3ool000kooooo0_oo000>ooooo`;oo`0000?o003oooooooooool03?ooool00ooo
003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo
003o003oo`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool0
00gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000ko
oooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0_oo00000ol00?ooooooooooo`0<ooooo`03
ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03
ool00?l00?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?o
o`003Oooool1o`00007ooooo000Eooooo`;o00002oooool3ool000kooooo0ooo000>ooooo`?oo`00
3_ooool3ool000kooooo0_oo000>ooooo`;oo`0000?o003oooooooooool03?ooool00ooo003o003o
o`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003o
o`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000cooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo
000>ooooo`?oo`003_ooool2ool000kooooo0_oo00000ol00?ooooooooooo`0<ooooo`03ool00?l0
0?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l0
0?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Ooo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool00003o`00oooooooooooo00cooooo00?oo`00
o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00
o`00ool00?l03_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo000>oooo
o`?oo`003_ooool3ool000kooooo0_oo000>ooooo`;oo`0000?o003oooooooooool03?ooool00ooo
003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo
003o003oo`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool0
00gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000ko
oooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0_oo00000ol00?ooooooooooo`0<ooooo`03
ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03
ool00?l00?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?o
o`003Oooool1o`00007ooooo000Eooooo`;o00002oooool3ool000kooooo0ooo000>ooooo`?oo`00
3_ooool3ool000kooooo0_oo000>ooooo`;oo`0000?o003oooooooooool03?ooool00ooo003o003o
o`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003o
o`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000cooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo
000>ooooo`?oo`003_ooool2ool000kooooo0_oo00000ol00?ooooooooooo`0<ooooo`03ool00?l0
0?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l0
0?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Ooo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool00003o`00oooooooooooo00cooooo00?oo`00
o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00
o`00ool00?l03_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo000>oooo
o`?oo`003_ooool3ool000kooooo0_oo000>ooooo`;oo`0000?o003oooooooooool03?ooool00ooo
003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo
003o003oo`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool0
00gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000ko
oooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0_oo00000ol00?ooooooooooo`0<ooooo`03
ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03
ool00?l00?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?o
o`003Oooool1o`00007ooooo000Eooooo`;o00002oooool3ool000kooooo0ooo000>ooooo`?oo`00
3_ooool3ool000kooooo0_oo000>ooooo`;oo`0000?o003oooooooooool03?ooool00ooo003o003o
o`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003o
o`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000cooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo
000>ooooo`?oo`003_ooool2ool000kooooo0_oo00000ol00?ooooooooooo`0<ooooo`03ool00?l0
0?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l0
0?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Ooo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool00003o`00oooooooooooo00cooooo00?oo`00
o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00
o`00ool00?l03_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo000>oooo
o`?oo`003_ooool3ool000kooooo0_oo000>ooooo`;oo`0000?o003oooooooooool03?ooool00ooo
003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo
003o003oo`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool0
00gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000ko
oooo0ooo000>ooooo`?oo`003_ooool2ool000kooooo0_oo00000ol00?ooooooooooo`0<ooooo`03
ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03
ool00?l00?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?o
o`003Oooool1o`00007ooooo000Eooooo`;o00002oooool3ool000kooooo0ooo000>ooooo`?oo`00
3_ooool3ool000kooooo0_oo000>ooooo`;oo`0000?o003oooooooooool03?ooool00ooo003o003o
o`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003o
o`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_ooool3ool000cooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo
000>ooooo`?oo`003_ooool2ool000kooooo0_oo00000ol00?ooooooooooo`0<ooooo`03ool00?l0
0?oo003o00kooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l0
0?oo003o00kooooo0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Ooo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000>ooooo`?oo`003_ooool3
ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool00003o`00oooooooooooo00cooooo00?oo`00
o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00
o`00ool00?l03_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=
ooooo`7o00000Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo00[ooooo0ooo000>oooo
o`?oo`003_ooool3ool000kooooo0ooo000>ooooo`;oo`003_ooool2ool00003o`00oooooooooooo
00cooooo00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o
00kooooo00?oo`00o`00ool00?l03_ooool3ool000kooooo0_oo000>ooooo`?oo`003_ooool3ool0
00kooooo0ooo000=ooooo`7o00000Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003_ooool2ool000ko
oooo0_oo00000ol00?ooooooooooo`0<ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool0
0?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo0ooo000>ooooo`;o
o`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003Oooool1o`00007ooooo000>ooooo`03o`00
0?oooooooooo00Cooooo0_l0000;ooooo`?oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`00
3_ooool3ool000gooooo0_oo00000ol00?ooooooooooo`0<ooooo`03ool00?l00?oo003o00kooooo
00?oo`00o`00ool00?l03_ooool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo
0ooo000>ooooo`;oo`003_ooool3ool000kooooo0ooo000>ooooo`?oo`003?ooool2o`00007ooooo
000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool3ool000kooooo0ooo
000>ooooo`?oo`003_ooool3ool000kooooo0ooo000=ooooo`;oo`0000?o003oooooooooool03?oo
ool00ooo003o003oo`00o`0>ooooo`03ool00?l00?oo003o00kooooo00?oo`00o`00ool00?l03_oo
ool00ooo003o003oo`00o`0>ooooo`?oo`003_ooool2ool000kooooo0ooo000>ooooo`?oo`003_oo
ool3ool000gooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0_oo00000ol00?ooooooooooo`0<
ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool00ooo003o003oo`00o`0O
ooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool000gooooo0_l00006oooo
o`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0_oo00000ol0
0?ooooooooooo`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool00ooo
003o003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool000ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000ko
oooo0ooo000Nooooo`;oo`0000?o003oooooooooool03?ooool3ool0013ooooo00?o0000oooooooo
ool03?ooool3ool000kooooo00?oo`00o`00ool00?l07oooool2ool000kooooo0ooo000Oooooo`?o
o`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`00
3_ooool3ool001kooooo0_oo00000ol00?ooooooooooo`0<ooooo`?oo`004?ooool00ol0003ooooo
ooooo`0<ooooo`?oo`003_ooool00ooo003o003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo
0ooo000=ooooo`7o00000Oooool001Gooooo0_l0000;ooooo`?oo`007oooool3ool000kooooo0ooo
000Nooooo`;oo`0000?o003oooooooooool03?ooool3ool0013ooooo00?o0000ooooooooool03?oo
ool3ool000kooooo00?oo`00o`00ool00?l07oooool2ool000kooooo0ooo000Oooooo`?oo`003?oo
ool2o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3
ool001kooooo0_oo00000ol00?ooooooooooo`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<
ooooo`?oo`003_ooool00ooo003o003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>oooo
o`?oo`007_ooool2ool00003o`00oooooooooooo00cooooo0ooo000@ooooo`03o`000?oooooooooo
00cooooo0ooo000>ooooo`03ool00?l00?oo003o01oooooo0_oo000>ooooo`?oo`007oooool3ool0
00gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000ko
oooo0ooo000Nooooo`;oo`0000?o003oooooooooool03?ooool3ool0013ooooo00?o0000oooooooo
ool03?ooool3ool000kooooo00?oo`00o`00ool00?l07oooool2ool000kooooo0ooo000Oooooo`?o
o`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`00
3_ooool3ool001kooooo0_oo00000ol00?ooooooooooo`0<ooooo`?oo`004?ooool00ol0003ooooo
ooooo`0<ooooo`?oo`003_ooool00ooo003o003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo
0ooo000=ooooo`7o00000Oooool001Gooooo0_l0000;ooooo`?oo`007oooool3ool000kooooo0ooo
000Nooooo`;oo`0000?o003oooooooooool03?ooool3ool0013ooooo00?o0000ooooooooool03?oo
ool3ool000kooooo00?oo`00o`00ool00?l07oooool2ool000kooooo0ooo000Oooooo`?oo`003?oo
ool2o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3
ool001kooooo0_oo00000ol00?ooooooooooo`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<
ooooo`?oo`003_ooool00ooo003o003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>oooo
o`?oo`007_ooool2ool00003o`00oooooooooooo00cooooo0ooo000@ooooo`03o`000?oooooooooo
00cooooo0ooo000>ooooo`03ool00?l00?oo003o01oooooo0_oo000>ooooo`?oo`007oooool3ool0
00gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000ko
oooo0ooo000Nooooo`;oo`0000?o003oooooooooool03?ooool3ool0013ooooo00?o0000oooooooo
ool03?ooool3ool000kooooo00?oo`00o`00ool00?l07oooool2ool000kooooo0ooo000Oooooo`?o
o`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`00
3_ooool3ool001kooooo0_oo00000ol00?ooooooooooo`0<ooooo`?oo`004?ooool00ol0003ooooo
ooooo`0<ooooo`?oo`003_ooool00ooo003o003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo
0ooo000=ooooo`7o00000Oooool001Gooooo0_l0000;ooooo`?oo`007oooool3ool000kooooo0ooo
000Nooooo`;oo`0000?o003oooooooooool03?ooool3ool0013ooooo00?o0000ooooooooool03?oo
ool3ool000kooooo00?oo`00o`00ool00?l07oooool2ool000kooooo0ooo000Oooooo`?oo`003?oo
ool2o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3
ool001kooooo0_oo00000ol00?ooooooooooo`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<
ooooo`?oo`003_ooool00ooo003o003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>oooo
o`?oo`007_ooool2ool00003o`00oooooooooooo00cooooo0ooo000@ooooo`03o`000?oooooooooo
00cooooo0ooo000>ooooo`03ool00?l00?oo003o01oooooo0_oo000>ooooo`?oo`007oooool3ool0
00gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000ko
oooo0ooo000Nooooo`;oo`0000?o003oooooooooool03?ooool3ool0013ooooo00?o0000oooooooo
ool03?ooool3ool000kooooo00?oo`00o`00ool00?l07oooool2ool000kooooo0ooo000Oooooo`?o
o`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`00
3_ooool3ool001kooooo0_oo00000ol00?ooooooooooo`0<ooooo`?oo`004?ooool00ol0003ooooo
ooooo`0<ooooo`?oo`003_ooool00ooo003o003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo
0ooo000=ooooo`7o00000Oooool001Gooooo0_l0000;ooooo`?oo`007oooool3ool000kooooo0ooo
000Nooooo`;oo`0000?o003oooooooooool03?ooool3ool0013ooooo00?o0000ooooooooool03?oo
ool3ool000kooooo00?oo`00o`00ool00?l07oooool2ool000kooooo0ooo000Oooooo`?oo`003?oo
ool2o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3
ool001kooooo0_oo00000ol00?ooooooooooo`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<
ooooo`?oo`003_ooool00ooo003o003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>oooo
o`?oo`007_ooool2ool00003o`00oooooooooooo00cooooo0ooo000@ooooo`03o`000?oooooooooo
00cooooo0ooo000>ooooo`03ool00?l00?oo003o01oooooo0_oo000>ooooo`?oo`007oooool3ool0
00gooooo0Ol00001ooooo`0000Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`02oooo
o`?o00001Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Noooo
o`;oo`0000?o003oooooooooool03?ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool0
00kooooo00?oo`00o`00ool00?l07oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00
007ooooo0002ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0_oo00000ol0
0?ooooooooooo`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool00ooo
003o003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool000;o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0_oo00000ol00?ooooooooooo`0<ooooo`?o
o`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool00ooo003o003oo`00o`0Oooooo`;o
o`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool000;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`02ooooo`;o00002oooool3ool001oooooo0ooo000>ooooo`?oo`00
7_ooool2ool00003o`00oooooooooooo00cooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo
0ooo000>ooooo`03ool00?l00?oo003o01oooooo0_oo000>ooooo`?oo`007oooool3ool000cooooo
0_l00001ooooo`000_ooool00ol0003oooooooooo`07ooooo`Co00001Oooool00ol0003ooooooooo
o`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`;oo`0000?o003oooooooooool03?oo
ool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo00?oo`00o`00ool00?l07ooo
ool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo00000ooooooo0000o`000009
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>
ooooo`?oo`007_ooool2ool00003o`00oooooooooooo00cooooo0ooo000@ooooo`03o`000?oooooo
oooo00cooooo0ooo000>ooooo`03ool00?l00?oo003o01oooooo0_oo000>ooooo`?oo`007oooool3
ool000gooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`07ooooo`Go00001?ooool00ol0
003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`;oo`0000?o003ooooo
ooooool03?ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo00?oo`00o`00
ool00?l07oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0_oo00000ol00?oo
ooooooooo`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool00ooo003o
003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo
0_l0000;ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`;oo`0000?o003oooooooooool0
3?ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo00?oo`00o`00ool00?l0
7oooool2ool000kooooo0ooo000Oooooo`?oo`003?ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0_oo00000ol00?oooooooooo
o`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool00ooo003o003oo`00
o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool2ool00003o`00oooooooo
oooo00cooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`03ool00?l00?oo
003o01oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`;oo`0000?o003ooooo
ooooool03?ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo00?oo`00o`00
ool00?l07oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0_oo00000ol00?oo
ooooooooo`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool00ooo003o
003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo
0_l0000;ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`;oo`0000?o003oooooooooool0
3?ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo00?oo`00o`00ool00?l0
7oooool2ool000kooooo0ooo000Oooooo`?oo`003?ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0_oo00000ol00?oooooooooo
o`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool00ooo003o003oo`00
o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool2ool00003o`00oooooooo
oooo00cooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`03ool00?l00?oo
003o01oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`;oo`0000?o003ooooo
ooooool03?ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo00?oo`00o`00
ool00?l07oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0_oo00000ol00?oo
ooooooooo`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool00ooo003o
003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo
0_l0000;ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`;oo`0000?o003oooooooooool0
3?ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo00?oo`00o`00ool00?l0
7oooool2ool000kooooo0ooo000Oooooo`?oo`003?ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0_oo00000ol00?oooooooooo
o`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool00ooo003o003oo`00
o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool2ool00003o`00oooooooo
oooo00cooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`03ool00?l00?oo
003o01oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`;oo`0000?o003ooooo
ooooool03?ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo00?oo`00o`00
ool00?l07oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0_oo00000ol00?oo
ooooooooo`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool00ooo003o
003oo`00o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo
0_l0000;ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`;oo`0000?o003oooooooooool0
3?ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo00?oo`00o`00ool00?l0
7oooool2ool000kooooo0ooo000Oooooo`?oo`003?ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0_oo00000ol00?oooooooooo
o`0<ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool00ooo003o003oo`00
o`0Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool2ool00003o`00oooooooo
oooo00cooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`03ool00?l00?oo
003o01oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`003?ooool5o`00
00Cooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool2ool0
0003o`00oooooooooooo00cooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>oooo
o`03ool00?l00?oo003o01oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001oooo
o`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00[ooooo0ooo000Ooooo
o`?oo`003_ooool3ool001kooooo0_oo00000ol00?ooooooooooo`0<ooooo`?oo`004?ooool00ol0
003oooooooooo`0<ooooo`?oo`003_ooool00ooo003o003oo`00o`0Oooooo`;oo`003_ooool3ool0
01oooooo0ooo000=ooooo`7o00000Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`;oo`0000?o003ooooooooo
ool03?ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo00?oo`00o`00ool0
0?l07oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000?ooooo`03o`00
0?oooooooooo00?ooooo0_l0000;ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`03ool0
0?l00?oo003o00kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`03ool0
0?l00?oo003o01oooooo0_oo000>ooooo`?oo`007oooool3ool000cooooo0_l00001ooooo`003?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02_ooool3ool001oooooo
0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo
0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo
000<ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0:ooooo`?oo`00
7oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool0
3?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o0000
0Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_oo
ool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_oo
ool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3
ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3
ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo0_l0000;ooooo`?oo`007oooool3ool0
00kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool0
00kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000<ooooo`;o00000Oooool001Go
oooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000ko
oooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000ko
oooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo
0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003ooooo
ooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo
000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo
000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@
ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000O
ooooo`?oo`003Oooool1o`00007ooooo000Eooooo`;o00002oooool3ool001oooooo0ooo000>oooo
o`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>oooo
o`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003?ooool2o`00007ooooo000Eooooo`03
o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?o
o`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?o
o`007oooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`00
7oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool0
3?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_oo
ool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007ooo
ool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool0
0ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3
ool000gooooo0Ol00001ooooo`005Oooool2o`0000_ooooo0ooo000Oooooo`?oo`003_ooool3ool0
01kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool0
01oooooo0_oo000>ooooo`?oo`007oooool3ool000cooooo0_l00001ooooo`005Oooool00ol0003o
ooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013o
oooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oo
oooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo
0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo
0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo
000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo
000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo
000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:
ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000
ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>oooo
o`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>oooo
o`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`;o
00002oooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03
o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?o
o`003?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`00
3_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`00
3_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`001Ol0
0003ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo00[ooooo0ooo
000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003ooooooooo
o`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol0
0001ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`00
3_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`00
3_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool000;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_oo
ool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_oo
ool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`000oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0_l0000;ooooo`?oo`007oooool3
ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3
ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000<ooooo`;o00000Oooool0
0005o`000?ooooooooooooooool000001oooool4o`0000Gooooo00?o0000ooooooooool02_ooool3
ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooo
oooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1
o`00007ooooo00001Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3
ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3
ool001oooooo0ooo000=ooooo`7o00000Oooool00004ooooool0003o0000o`0000Sooooo1Ol00004
ooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>
ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>
ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:oooo
o`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000oooo
ooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=oooo
o`7o00000Oooool001Gooooo0_l0000;ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?o
o`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;o
o`003_ooool3ool001oooooo0ooo000<ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0
2_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`00
0?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`00
3Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_oo
ool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_oo
ool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3
ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3
ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool02_ooool3ool0
01oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo
00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00
007ooooo000Eooooo`;o00002oooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000ko
oooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000ko
oooo0ooo000Oooooo`?oo`003?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo
0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003ooooo
ooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo
000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo
000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@
ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000O
ooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Ooooo
o`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<oooo
o`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3ool000gooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?o
o`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;o
o`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Gooooo0_l0000;ooooo`?oo`00
7oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool0
3?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000<ooooo`;o0000
0Oooool001Gooooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_oo
ool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007ooo
ool2ool000kooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo000>ooooo`?oo`004?ooool0
0ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo000>ooooo`?oo`007oooool3
ool000gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0:ooooo`?oo`007oooool3ool0
00kooooo0ooo000Nooooo`?oo`003_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool0
00kooooo0ooo000Oooooo`;oo`003_ooool3ool001oooooo0ooo000=ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000ko
oooo0ooo000@ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000ko
oooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo000Eooooo`;o00002oooool3ool001oooooo
0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo
0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000Oooooo`?oo`003?ooool2o`00007ooooo
000Eooooo`03o`000?oooooooooo00[ooooo0ooo000Oooooo`?oo`003_ooool3ool001kooooo0ooo
000>ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`003_ooool3ool001oooooo0_oo
000>ooooo`?oo`007oooool3ool000gooooo0Ol00001ooooo`003Oooool3o`0000Gooooo00?o0000
ooooooooool02_ooool3ool001oooooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@
ooooo`03o`000?oooooooooo00cooooo0ooo000>ooooo`?oo`007oooool2ool000kooooo0ooo000O
ooooo`?oo`003Oooool1o`00007ooooo000<ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3
ool0013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3
ool001oooooo0ooo000=ooooo`7o00000Oooool0013ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`?oo`007oooool3ool000kooooo0ooo000Nooooo`?oo`003_ooool3ool0
013ooooo00?o0000ooooooooool03?ooool3ool000kooooo0ooo000Oooooo`;oo`003_ooool3ool0
01oooooo0ooo000=ooooo`7o00000Oooool000kooooo0_l00005ooooo`;o00002oooool3ool001oo
oooo0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00co
oooo0ooo000>ooooo`?oo`007oooool3ool000gooooo0ooo000Oooooo`?oo`003?ooool2o`00007o
oooo000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool3ool001oooooo
0ooo000>ooooo`?oo`007_ooool3ool000kooooo0ooo000@ooooo`03o`000?oooooooooo00cooooo
0ooo000>ooooo`?oo`007oooool3ool000gooooo0ooo000Oooooo`?oo`003Oooool1o`00007ooooo
000<ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo087ooooo0Ol00001ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00004ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo0_l00001ooooo`005Oooooooo`0000_o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.13953, -0.260466, \
0.0593102, 0.0191323}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DTFT of finite-length sampled signal", "Subsection"],

Cell[BoxData[
    \(\(X\[Theta]\  = DTFT[xd, \[Theta]]\  // \ Simplify;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gX\[Theta] = 
        Plot[Abs[
            X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-2.5\) 
              fs, 2.5  fs}, \ PlotStyle \[Rule] {Red}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200, \ 
          AspectRatio \[Rule] 1/3, \ ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0634921 0.00793645 0.00610159 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.24603 -0.0125 -6 -9 ]
[.24603 -0.0125 6 0 ]
[.37302 -0.0125 -6 -9 ]
[.37302 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.62698 -0.0125 -3 -9 ]
[.62698 -0.0125 3 0 ]
[.75397 -0.0125 -3 -9 ]
[.75397 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00794 -6 -4.5 ]
[-0.0125 .00794 0 4.5 ]
[-0.0125 .06895 -12 -4.5 ]
[-0.0125 .06895 0 4.5 ]
[-0.0125 .12997 -12 -4.5 ]
[-0.0125 .12997 0 4.5 ]
[-0.0125 .19098 -12 -4.5 ]
[-0.0125 .19098 0 4.5 ]
[-0.0125 .252 -12 -4.5 ]
[-0.0125 .252 0 4.5 ]
[-0.0125 .31302 -12 -4.5 ]
[-0.0125 .31302 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-6)] .11905 -0.0125 0 1 Mshowa
.24603 0 m
.24603 .00625 L
s
[(-4)] .24603 -0.0125 0 1 Mshowa
.37302 0 m
.37302 .00625 L
s
[(-2)] .37302 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.62698 0 m
.62698 .00625 L
s
[(2)] .62698 -0.0125 0 1 Mshowa
.75397 0 m
.75397 .00625 L
s
[(4)] .75397 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(6)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.15079 0 m
.15079 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.05556 0 m
.05556 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00794 m
.00625 .00794 L
s
[(0)] -0.0125 .00794 1 0 Mshowa
0 .06895 m
.00625 .06895 L
s
[(10)] -0.0125 .06895 1 0 Mshowa
0 .12997 m
.00625 .12997 L
s
[(20)] -0.0125 .12997 1 0 Mshowa
0 .19098 m
.00625 .19098 L
s
[(30)] -0.0125 .19098 1 0 Mshowa
0 .252 m
.00625 .252 L
s
[(40)] -0.0125 .252 1 0 Mshowa
0 .31302 m
.00625 .31302 L
s
[(50)] -0.0125 .31302 1 0 Mshowa
.125 Mabswid
0 .02014 m
.00375 .02014 L
s
0 .03234 m
.00375 .03234 L
s
0 .04455 m
.00375 .04455 L
s
0 .05675 m
.00375 .05675 L
s
0 .08116 m
.00375 .08116 L
s
0 .09336 m
.00375 .09336 L
s
0 .10556 m
.00375 .10556 L
s
0 .11777 m
.00375 .11777 L
s
0 .14217 m
.00375 .14217 L
s
0 .15437 m
.00375 .15437 L
s
0 .16658 m
.00375 .16658 L
s
0 .17878 m
.00375 .17878 L
s
0 .20319 m
.00375 .20319 L
s
0 .21539 m
.00375 .21539 L
s
0 .22759 m
.00375 .22759 L
s
0 .2398 m
.00375 .2398 L
s
0 .2642 m
.00375 .2642 L
s
0 .27641 m
.00375 .27641 L
s
0 .28861 m
.00375 .28861 L
s
0 .30081 m
.00375 .30081 L
s
0 .32522 m
.00375 .32522 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.11905 .32708 m
.11905 .33333 L
s
.24603 .32708 m
.24603 .33333 L
s
.37302 .32708 m
.37302 .33333 L
s
.5 .32708 m
.5 .33333 L
s
.62698 .32708 m
.62698 .33333 L
s
.75397 .32708 m
.75397 .33333 L
s
.88095 .32708 m
.88095 .33333 L
s
.125 Mabswid
.15079 .32958 m
.15079 .33333 L
s
.18254 .32958 m
.18254 .33333 L
s
.21429 .32958 m
.21429 .33333 L
s
.27778 .32958 m
.27778 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.34127 .32958 m
.34127 .33333 L
s
.40476 .32958 m
.40476 .33333 L
s
.43651 .32958 m
.43651 .33333 L
s
.46825 .32958 m
.46825 .33333 L
s
.53175 .32958 m
.53175 .33333 L
s
.56349 .32958 m
.56349 .33333 L
s
.59524 .32958 m
.59524 .33333 L
s
.65873 .32958 m
.65873 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.72222 .32958 m
.72222 .33333 L
s
.78571 .32958 m
.78571 .33333 L
s
.81746 .32958 m
.81746 .33333 L
s
.84921 .32958 m
.84921 .33333 L
s
.0873 .32958 m
.0873 .33333 L
s
.05556 .32958 m
.05556 .33333 L
s
.02381 .32958 m
.02381 .33333 L
s
.9127 .32958 m
.9127 .33333 L
s
.94444 .32958 m
.94444 .33333 L
s
.97619 .32958 m
.97619 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00794 m
1 .00794 L
s
.99375 .06895 m
1 .06895 L
s
.99375 .12997 m
1 .12997 L
s
.99375 .19098 m
1 .19098 L
s
.99375 .252 m
1 .252 L
s
.99375 .31302 m
1 .31302 L
s
.125 Mabswid
.99625 .02014 m
1 .02014 L
s
.99625 .03234 m
1 .03234 L
s
.99625 .04455 m
1 .04455 L
s
.99625 .05675 m
1 .05675 L
s
.99625 .08116 m
1 .08116 L
s
.99625 .09336 m
1 .09336 L
s
.99625 .10556 m
1 .10556 L
s
.99625 .11777 m
1 .11777 L
s
.99625 .14217 m
1 .14217 L
s
.99625 .15437 m
1 .15437 L
s
.99625 .16658 m
1 .16658 L
s
.99625 .17878 m
1 .17878 L
s
.99625 .20319 m
1 .20319 L
s
.99625 .21539 m
1 .21539 L
s
.99625 .22759 m
1 .22759 L
s
.99625 .2398 m
1 .2398 L
s
.99625 .2642 m
1 .2642 L
s
.99625 .27641 m
1 .27641 L
s
.99625 .28861 m
1 .28861 L
s
.99625 .30081 m
1 .30081 L
s
.99625 .32522 m
1 .32522 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
.5 0 m
.5 .33333 L
s
1 0 0 r
.5 Mabswid
.02381 .00794 m
.02489 .02187 L
.02608 .03552 L
.02668 .04126 L
.02732 .04628 L
.02763 .04824 L
.02792 .04978 L
.0282 .05098 L
.02847 .05182 L
.02861 .05216 L
.02876 .05244 L
.02885 .05255 L
.02893 .05264 L
.02908 .05272 L
.02916 .05273 L
.02925 .05271 L
.0294 .0526 L
.02949 .05249 L
.02957 .05235 L
.02974 .05202 L
.02988 .05164 L
.03003 .05115 L
.0303 .05004 L
.03091 .04649 L
.03156 .04113 L
.03217 .03481 L
.03283 .02665 L
.03355 .01657 L
.03387 .01182 L
.03403 .00936 L
.03412 .00795 L
.03421 .00925 L
.03481 .01884 L
.03601 .03772 L
.03707 .05309 L
.03764 .06007 L
.03824 .0663 L
.03856 .06903 L
.03886 .0711 L
.03915 .07277 L
.03943 .07394 L
.03958 .07441 L
.03966 .07461 L
.03974 .07477 L
.03988 .07496 L
.04003 .07506 L
.04011 .07505 L
.04019 .07501 L
.04034 .07482 L
.04042 .07466 L
Mistroke
.0405 .07448 L
.04068 .07392 L
.04082 .07334 L
.04097 .07257 L
.04124 .0708 L
.04176 .06622 L
.04236 .05869 L
.04291 .04972 L
.04401 .02613 L
.04432 .018 L
.04448 .0138 L
.04462 .0098 L
.04475 .0098 L
.04489 .01385 L
.04518 .02271 L
.04647 .06632 L
.04768 .11168 L
.05006 .20385 L
.05224 .27506 L
.05338 .30171 L
.05395 .31159 L
.05427 .31602 L
.05457 .31944 L
.05473 .32092 L
.05491 .32229 L
.05505 .32324 L
.05521 .32409 L
.05538 .32477 L
.05547 .32504 L
.05556 .32522 L
.05571 .32539 L
.0558 .32539 L
.05588 .32534 L
.05603 .32508 L
.05618 .32465 L
.05633 .32399 L
.0565 .32305 L
.05678 .32095 L
.05709 .31786 L
.05768 .30979 L
.05831 .29832 L
.05942 .27089 L
.06194 .18459 L
.06434 .08908 L
.06539 .04954 L
.06594 .03015 L
.06625 .02008 L
.06639 .01531 L
.06653 .01103 L
.06667 .00932 L
Mistroke
.06683 .01402 L
.06716 .02357 L
.06774 .03889 L
.06889 .06298 L
.06951 .07243 L
.06984 .07639 L
.07019 .07982 L
.07052 .08236 L
.07082 .08403 L
.07097 .08462 L
.07113 .08511 L
.07128 .08542 L
.07142 .08559 L
.07157 .08564 L
.07171 .08555 L
.07184 .08537 L
.07198 .08507 L
.07214 .0846 L
.0723 .08397 L
.07259 .08246 L
.07311 .07869 L
.07369 .07304 L
.07497 .0559 L
.07618 .03605 L
.0768 .02529 L
.07737 .01525 L
.07752 .01267 L
.07766 .01025 L
.07773 .00892 L
.07782 .00838 L
.07796 .01086 L
.07862 .0215 L
.07977 .038 L
.08085 .04974 L
.0814 .0541 L
.08168 .05587 L
.08199 .05743 L
.08217 .05814 L
.08233 .05869 L
.0825 .05914 L
.08265 .05945 L
.0828 .05966 L
.08294 .05977 L
.08309 .05981 L
.08317 .05979 L
.08325 .05974 L
.0834 .05959 L
.08355 .05933 L
.0837 .059 L
.08384 .05862 L
Mistroke
.08417 .05739 L
.08448 .05586 L
.08511 .05179 L
.08579 .04599 L
.08702 .03252 L
.08818 .01777 L
.08848 .01383 L
.08876 .01008 L
.08892 .00802 L
.089 .00902 L
.08909 .0101 L
.08938 .01398 L
.09071 .03001 L
.09133 .03631 L
.09199 .04207 L
.09261 .04634 L
.09291 .04795 L
.09319 .04918 L
.09344 .05007 L
.09371 .05078 L
.09386 .05107 L
.09401 .05127 L
.09414 .05138 L
.09428 .05144 L
.09442 .05143 L
.09457 .05133 L
.09473 .05115 L
.09488 .0509 L
.09502 .05059 L
.09514 .05025 L
.09543 .04928 L
.09573 .04798 L
.096 .04655 L
.09661 .04249 L
.09771 .03265 L
.09834 .02582 L
.09901 .01793 L
.09929 .01456 L
.09958 .01087 L
.09967 .00978 L
.09975 .00874 L
.09991 .00908 L
.10005 .01091 L
.10021 .01291 L
.10133 .02659 L
.10252 .03923 L
.1032 .04499 L
.10382 .049 L
.10412 .05048 L
.10428 .05113 L
Mistroke
.10444 .05171 L
.10459 .05214 L
.10475 .05252 L
.10489 .05278 L
.10503 .05295 L
.10518 .05305 L
.10526 .05306 L
.10534 .05305 L
.10549 .05296 L
.10563 .05279 L
.10571 .05265 L
.1058 .05248 L
.10595 .0521 L
.10629 .0509 L
.10659 .04945 L
.10686 .04778 L
.10749 .04283 L
.10806 .03697 L
.10857 .0306 L
.10912 .02275 L
.10943 .01787 L
.10973 .01304 L
.10987 .01056 L
.11001 .00815 L
.11017 .01055 L
.11031 .01318 L
.11093 .02494 L
.11204 .04733 L
.11455 .09726 L
.11571 .11638 L
.11635 .12498 L
.11695 .13162 L
.11746 .13606 L
.11772 .13788 L
.11801 .13952 L
.1183 .14081 L
.11846 .14133 L
.11861 .14171 L
.11875 .14196 L
.11888 .1421 L
.11903 .14217 L
.11917 .14213 L
.11931 .142 L
.11946 .14176 L
.1196 .14143 L
.11973 .14104 L
.12004 .13976 L
.12034 .13811 L
.12093 .13361 L
.12158 .12694 L
Mistroke
.12273 .11099 L
.1238 .09245 L
.12607 .04691 L
.12669 .03424 L
.12735 .02132 L
.12762 .0162 L
.12791 .01087 L
.12799 .00934 L
.12808 .00797 L
.12823 .01062 L
.12852 .01564 L
.12976 .03365 L
.13046 .04144 L
.13111 .04692 L
.13138 .0487 L
.13167 .05028 L
.13183 .05103 L
.13199 .05161 L
.13214 .0521 L
.13229 .05247 L
.13243 .05274 L
.13258 .05294 L
.13266 .05301 L
.13275 .05305 L
.1329 .05305 L
.13298 .05302 L
.13306 .05296 L
.13321 .05278 L
.13337 .05248 L
.13354 .05205 L
.13384 .05103 L
.13417 .04955 L
.13477 .04589 L
.13589 .0362 L
.13721 .02131 L
.13751 .01758 L
.13783 .01358 L
.13811 .01013 L
.13826 .00818 L
.13841 .00952 L
.139 .01685 L
.13963 .02444 L
.14078 .03659 L
.14141 .04196 L
.14201 .04604 L
.14234 .04784 L
.14269 .04939 L
.14285 .04994 L
.14302 .05043 L
.14317 .0508 L
Mistroke
.14332 .05107 L
.14346 .05127 L
.14362 .0514 L
.14376 .05144 L
.14391 .05141 L
.14405 .0513 L
.14419 .05113 L
.14432 .05092 L
.14445 .05064 L
.14476 .04974 L
.14508 .04843 L
.14567 .0452 L
.14621 .04123 L
.14672 .03677 L
.14788 .02437 L
.14848 .01696 L
.1488 .01288 L
.14897 .01061 L
.14906 .00949 L
.14913 .00846 L
.14928 .00928 L
.14943 .0113 L
.14975 .01561 L
.15033 .02314 L
.15141 .03648 L
.15256 .04834 L
.15318 .05321 L
.15375 .05656 L
.15402 .05777 L
.15416 .0583 L
.15431 .05878 L
.15444 .05912 L
.15459 .05942 L
.15472 .05962 L
.15485 .05974 L
.155 .05981 L
.15509 .0598 L
.15517 .05977 L
.15532 .05964 L
.15547 .0594 L
.15563 .05907 L
.15577 .05866 L
.15605 .05767 L
.15637 .05609 L
.15667 .05427 L
.15734 .04888 L
.15852 .03551 L
.15961 .01936 L
.15994 .01409 L
.1601 .01144 L
Mistroke
.16024 .00896 L
.16038 .00919 L
.16052 .01162 L
.16082 .01682 L
.16211 .03935 L
.16324 .05767 L
.16383 .06606 L
.16446 .07359 L
.16501 .0789 L
.1653 .08114 L
.16561 .08305 L
.16576 .08379 L
.16589 .08437 L
.16603 .08484 L
.16615 .08517 L
.16627 .08541 L
.1664 .08557 L
.16652 .08564 L
.16666 .0856 L
.16682 .08542 L
.16696 .08511 L
.16712 .08463 L
.16729 .08393 L
.16761 .08215 L
.16789 .07999 L
.16847 .07394 L
.16901 .06622 L
.17022 .04203 L
.1709 .02455 L
.17107 .01975 L
.17123 .01508 L
.17137 .01076 L
.17153 .00992 L
.17167 .01433 L
.17182 .01911 L
.17209 .02795 L
.17268 .04871 L
.17394 .09648 L
.17649 .19714 L
.17762 .23809 L
.17884 .27555 L
.17943 .29048 L
.17999 .30243 L
.18054 .31173 L
.18105 .31836 L
.18134 .32117 L
.18149 .32237 L
.18165 .32342 L
.18179 .32413 L
.18194 .32473 L
Mistroke
.18208 .32511 L
.1822 .32532 L
.18228 .32538 L
.18236 .32539 L
.18252 .32526 L
.18266 .32494 L
.1828 .32448 L
.18295 .32381 L
.18311 .32286 L
.18344 .32025 L
.18372 .31724 L
.18399 .31389 L
.18458 .30434 L
.18565 .28048 L
.18684 .24583 L
.18794 .20762 L
.19043 .11112 L
.1917 .06344 L
.19232 .04173 L
.1929 .0231 L
.19317 .01488 L
.1933 .01099 L
.19342 .00836 L
.19355 .01193 L
.19368 .01568 L
.19397 .02329 L
.19514 .04889 L
.19572 .05839 L
.19603 .06269 L
.19633 .06615 L
.19661 .06886 L
.19691 .07122 L
.19718 .07287 L
.19743 .07398 L
.19758 .07444 L
.19773 .07479 L
.19788 .07499 L
.19801 .07506 L
.19817 .07501 L
.19826 .07492 L
.19834 .07479 L
.19849 .07447 L
.19865 .07399 L
.19897 .07265 L
.19926 .07094 L
.19994 .06553 L
.20217 .03653 L
.20278 .02691 L
.20343 .01648 L
.20358 .01407 L
Mistroke
.20375 .01146 L
.2039 .00903 L
.20405 .00907 L
.20418 .01106 L
.20432 .01321 L
.20461 .01748 L
.20577 .03302 L
.20642 .03999 L
.20703 .04531 L
.20736 .04761 L
.20772 .04965 L
.20804 .05106 L
.2082 .05158 L
.20834 .05198 L
.20848 .05228 L
.20863 .05252 L
.20871 .05261 L
.20879 .05268 L
.20894 .05273 L
.2091 .05269 L
.20924 .05256 L
.20933 .05245 L
.2094 .05232 L
.20957 .05196 L
.20985 .05112 L
.21016 .04987 L
.21078 .04631 L
.21135 .04188 L
.21188 .03687 L
.21317 .02228 L
.21348 .01842 L
.2138 .01422 L
.21396 .01216 L
.21411 .01021 L
.21425 .00845 L
.21439 .00932 L
.21453 .01116 L
.21469 .01318 L
.215 .01722 L
.21556 .02423 L
.21683 .03833 L
.21739 .0433 L
.21799 .04757 L
.21828 .04921 L
.21856 .05049 L
.2188 .0514 L
.21893 .05179 L
.21907 .05212 L
.21922 .0524 L
.21935 .05258 L
Mistroke
.2195 .0527 L
.21965 .05273 L
.21979 .05267 L
.21994 .05252 L
.22008 .05231 L
.2202 .05204 L
.22051 .05112 L
.22069 .05043 L
.22085 .04968 L
.22146 .04596 L
.22204 .04106 L
.22269 .03431 L
.22336 .026 L
.22399 .01711 L
.22427 .01288 L
.22443 .01051 L
.22458 .00825 L
.22466 .00892 L
.22475 .01034 L
.22491 .01282 L
.22522 .01771 L
.22634 .03549 L
.22754 .05295 L
.22818 .06075 L
.22886 .06752 L
.22919 .07015 L
.22951 .07215 L
.22979 .07352 L
.22996 .07411 L
.2301 .07453 L
.23024 .07482 L
.23037 .07498 L
.23052 .07506 L
.23067 .075 L
.23075 .07493 L
.23083 .0748 L
.23098 .07447 L
.23113 .07401 L
.23127 .07346 L
.2316 .07164 L
.23191 .06929 L
.2325 .0632 L
.23313 .05415 L
.23381 .04148 L
.23436 .0291 L
.23467 .0215 L
.23496 .01381 L
.23503 .01163 L
.23512 .00927 L
.23521 .00923 L
Mistroke
.2353 .01171 L
.23561 .02102 L
.23621 .04057 L
.23875 .13511 L
.24113 .22524 L
.24217 .25934 L
.2433 .28998 L
.24385 .30172 L
.24444 .3118 L
.24476 .31623 L
.24506 .31952 L
.24536 .3221 L
.24564 .32386 L
.24578 .32451 L
.24586 .32481 L
.24594 .32502 L
.24602 .3252 L
.24611 .32533 L
.24626 .32539 L
.24641 .32527 L
.24656 .32495 L
.24671 .32445 L
.24684 .32383 L
.24701 .32282 L
.24717 .32165 L
.24748 .31887 L
.2478 .31504 L
.24815 .30994 L
.2493 .28669 L
.25056 .25101 L
.2531 .15752 L
.25546 .06466 L
.25613 .04 L
.25647 .02851 L
.25678 .0183 L
.25692 .01368 L
.25706 .00944 L
.2572 .01076 L
.25735 .01542 L
.25798 .03282 L
.25917 .05939 L
.25976 .06933 L
.26011 .07396 L
.26042 .07749 L
.26069 .08002 L
.26098 .08222 L
.26114 .0832 L
.26128 .08395 L
.26143 .08457 L
.26157 .08502 L
Mistroke
.26169 .08531 L
.26182 .08552 L
.26197 .08563 L
.2621 .08562 L
.26223 .08551 L
.26238 .08526 L
.26252 .0849 L
.26265 .08448 L
.26294 .08318 L
.26321 .0816 L
.26381 .07672 L
.26434 .07108 L
.2649 .06395 L
.2661 .04559 L
.26676 .03434 L
.26738 .02341 L
.26798 .01297 L
.26814 .01014 L
.26822 .00873 L
.26831 .00869 L
.26839 .01 L
.26847 .0114 L
.26862 .01391 L
.26976 .0314 L
.27035 .03927 L
.27091 .04572 L
.27146 .05088 L
.27197 .05471 L
.27226 .05642 L
.27258 .05788 L
.27271 .0584 L
.27286 .05885 L
.273 .0592 L
.27313 .05945 L
.27327 .05966 L
.27343 .05978 L
.27357 .05981 L
.27371 .05975 L
.27379 .05968 L
.27387 .05959 L
.27402 .05935 L
.27418 .05899 L
.27436 .05848 L
.27465 .0574 L
.27491 .05614 L
.2755 .05241 L
.27658 .04289 L
.27768 .0303 L
.27829 .0226 L
.27886 .01508 L
Mistroke
.27918 .01077 L
.27927 .00959 L
.27937 .00834 L
.27945 .00859 L
.27954 .00975 L
.28015 .01769 L
.28135 .03179 L
.28198 .03801 L
.28258 .04296 L
.28312 .04651 L
.28342 .0481 L
.2837 .04932 L
.28386 .04989 L
.28403 .05041 L
.28418 .05076 L
.28433 .05106 L
.28442 .05119 L
.2845 .05129 L
.28459 .05137 L
.28469 .05142 L
.28477 .05144 L
.28485 .05144 L
.28501 .05136 L
.28515 .05122 L
.28531 .05098 L
.28544 .05071 L
.28559 .05034 L
.28591 .04926 L
.28622 .04792 L
.28679 .04463 L
.28741 .03994 L
.28866 .02762 L
.28922 .02116 L
.28953 .01745 L
.28982 .01387 L
.29009 .01049 L
.29024 .00857 L
.29038 .00907 L
.2905 .01057 L
.29063 .01221 L
.29089 .01551 L
.2921 .02995 L
.29324 .04144 L
.29387 .04637 L
.29421 .04848 L
.29456 .05031 L
.29486 .05151 L
.29502 .05201 L
.29519 .05244 L
.29534 .05274 L
Mistroke
.29548 .05293 L
.29562 .05303 L
.29576 .05306 L
.29591 .05301 L
.296 .05293 L
.29607 .05284 L
.29622 .05261 L
.29637 .05227 L
.29663 .05146 L
.29691 .05023 L
.29722 .04855 L
.29755 .0463 L
.29814 .04112 L
.2993 .02713 L
.29985 .01877 L
.3001 .01483 L
.30036 .0104 L
.30051 .00818 L
.30065 .01071 L
.30093 .01584 L
.30155 .02761 L
.30265 .04998 L
.30515 .09939 L
.30625 .11717 L
.30685 .12524 L
.30742 .13157 L
.30774 .13453 L
.3081 .13723 L
.30839 .13903 L
.30855 .13988 L
.30871 .14056 L
.30887 .14112 L
.30901 .14153 L
.30917 .14186 L
.30925 .14199 L
.30934 .14208 L
.30948 .14217 L
.30961 .14215 L
.30976 .14204 L
.30991 .1418 L
.31006 .14146 L
.31023 .14097 L
.31056 .13957 L
.31086 .13781 L
.31115 .13578 L
.3118 .12983 L
.31249 .12151 L
.31492 .08013 L
.31614 .05524 L
.31679 .04195 L
Mistroke
.31748 .02811 L
.31782 .02148 L
.31814 .01542 L
.31828 .01284 L
.31843 .01016 L
.3185 .00878 L
.31859 .00859 L
.31874 .01117 L
.3199 .02926 L
.32054 .03721 L
.32114 .04332 L
.32168 .04757 L
.32198 .04943 L
.32226 .05082 L
.32256 .05194 L
.32273 .05238 L
.3229 .05273 L
.32299 .05286 L
.32308 .05296 L
.32317 .05303 L
.32325 .05306 L
.32341 .05304 L
.32349 .05299 L
.32357 .05292 L
.32373 .0527 L
.32387 .05241 L
.32403 .05201 L
.3242 .05148 L
.32448 .05035 L
.32479 .04879 L
.3261 .03881 L
.32734 .0255 L
.32788 .01898 L
.32845 .01182 L
.32859 .01001 L
.32875 .00805 L
.32884 .00894 L
.32892 .00997 L
.32908 .01197 L
.32966 .01915 L
.33084 .0325 L
.33195 .0424 L
.3325 .04615 L
.33279 .04771 L
.33309 .0491 L
.33327 .04976 L
.33343 .05027 L
.33359 .05066 L
.33375 .05101 L
.3339 .05123 L
Mistroke
.33404 .05137 L
.33419 .05144 L
.33435 .05142 L
.33443 .05138 L
.33451 .05132 L
.33466 .05115 L
.33482 .05088 L
.33499 .05049 L
.33529 .04953 L
.33557 .04837 L
.33622 .0447 L
.3369 .03943 L
.33806 .02774 L
.33871 .01999 L
.33903 .01596 L
.33933 .01215 L
.33948 .01022 L
.33962 .00839 L
.33976 .00939 L
.33984 .0104 L
.33992 .0115 L
.34056 .01999 L
.34169 .03414 L
.34233 .04138 L
.343 .048 L
.34364 .05304 L
.34421 .0565 L
.34449 .05778 L
.34464 .05833 L
.3448 .05882 L
.34494 .05917 L
.34509 .05947 L
.34523 .05966 L
.34536 .05977 L
.34552 .05981 L
.34567 .05975 L
.34581 .05962 L
.34596 .05939 L
.34612 .05904 L
.34629 .05855 L
.34659 .05737 L
.34685 .05605 L
.34714 .05433 L
.34765 .05041 L
.34881 .03788 L
.34941 .02966 L
.35006 .01984 L
.35037 .01476 L
.35053 .0122 L
.35067 .00981 L
Mistroke
.3508 .00825 L
.35094 .0106 L
.35122 .0156 L
.35244 .03686 L
.35377 .05846 L
.3549 .07326 L
.35523 .07662 L
.35554 .07937 L
.35582 .08147 L
.35612 .08326 L
.35627 .08397 L
.35641 .08452 L
.35655 .08496 L
.35667 .08526 L
.35679 .08547 L
.35692 .0856 L
.35704 .08564 L
.35718 .08557 L
.35733 .08536 L
.35747 .08504 L
.35763 .08453 L
.35778 .0839 L
.35804 .08242 L
.35833 .08028 L
.35888 .07472 L
.35946 .06669 L
.36009 .05536 L
.36067 .04271 L
.36131 .02648 L
.36164 .01697 L
.36173 .01436 L
.36183 .01148 L
.36192 .00872 L
.362 .00973 L
.36208 .01219 L
.36217 .01492 L
.36234 .02055 L
.36265 .03084 L
.36325 .05207 L
.36799 .23438 L
.36919 .27208 L
.37033 .29975 L
.37096 .31099 L
.3713 .31567 L
.37165 .31967 L
.37182 .32121 L
.37198 .32244 L
.37213 .32343 L
.37228 .32417 L
.37241 .32471 L
Mistroke
.37255 .32511 L
.3727 .32534 L
.37285 .32539 L
.37301 .32523 L
.37316 .32488 L
.37323 .32463 L
.37332 .3243 L
.37349 .32344 L
.3738 .32126 L
.37409 .31848 L
.37463 .31148 L
.37521 .30137 L
.37653 .26963 L
.37774 .23163 L
.38022 .13811 L
.38143 .09119 L
.38252 .0512 L
.38307 .03267 L
.38336 .02345 L
.38352 .01857 L
.38367 .01413 L
.3838 .01033 L
.38394 .00952 L
.38409 .01381 L
.38423 .01761 L
.38475 .03067 L
.38534 .04347 L
.38597 .05498 L
.38657 .06346 L
.38713 .06922 L
.38742 .07144 L
.38768 .073 L
.38782 .07365 L
.38798 .07421 L
.38806 .07444 L
.38814 .07464 L
.38829 .07491 L
.38843 .07504 L
.38858 .07505 L
.38872 .07493 L
.38886 .07472 L
.38898 .07445 L
.38911 .07405 L
.38938 .07298 L
.3897 .07119 L
.38999 .06912 L
.39066 .06306 L
.39186 .04815 L
.39297 .03144 L
.39358 .02174 L
Mistroke
.39415 .01261 L
.39431 .01011 L
.39439 .00886 L
.39448 .00838 L
.39457 .00985 L
.39466 .01121 L
.39483 .01377 L
.39545 .0227 L
.39665 .03753 L
.39726 .04331 L
.39758 .04585 L
.39791 .04812 L
.39821 .04974 L
.39854 .05112 L
.39868 .05159 L
.39883 .05201 L
.39898 .05232 L
.39911 .05252 L
.39924 .05266 L
.39938 .05272 L
.39951 .05271 L
.39963 .05264 L
.39977 .05249 L
.39992 .05223 L
.40007 .05191 L
.4002 .05154 L
.40047 .0506 L
.40076 .04925 L
.40135 .04563 L
.40198 .04052 L
.40258 .03466 L
.4037 .02165 L
.40428 .0142 L
.40445 .01201 L
.40461 .00995 L
.40475 .00809 L
.4049 .00979 L
.40559 .01861 L
.40622 .02642 L
.40682 .0333 L
.40747 .0398 L
.40806 .04482 L
.40863 .04853 L
.40893 .05007 L
.40909 .05075 L
.40927 .05136 L
.40941 .05179 L
.40957 .05217 L
.40971 .05243 L
.40984 .0526 L
Mistroke
.40993 .05267 L
.41001 .05271 L
.4101 .05273 L
.41018 .05271 L
.41033 .05262 L
.41048 .05243 L
.41057 .05227 L
.41067 .05206 L
.41084 .0516 L
.41117 .05039 L
.41176 .04718 L
.41231 .04294 L
.41295 .0367 L
.41353 .0299 L
.41417 .02135 L
.41451 .01648 L
.41469 .01372 L
.41487 .01109 L
.41502 .00881 L
.4151 .00836 L
.41518 .00955 L
.41552 .01491 L
.41612 .0245 L
.41732 .04317 L
.41844 .05826 L
.41905 .06491 L
.4196 .06968 L
.41992 .07178 L
.42022 .07331 L
.42039 .07395 L
.42054 .07442 L
.42062 .07463 L
.4207 .07479 L
.42079 .07492 L
.42088 .07501 L
.42103 .07506 L
.42111 .07503 L
.42119 .07496 L
.42134 .07474 L
.42148 .07441 L
.42164 .07386 L
.42179 .07322 L
.42213 .07125 L
.42241 .0691 L
.42271 .06617 L
.42333 .05846 L
.42388 .04929 L
.42448 .03728 L
.42501 .02497 L
.42529 .01756 L
Mistroke
.42543 .01376 L
.42556 .01019 L
.42571 .00986 L
.42587 .01449 L
.4262 .02473 L
.42679 .04403 L
.42813 .09237 L
.43056 .1868 L
.43284 .2653 L
.43347 .28241 L
.43414 .29787 L
.43477 .30952 L
.43534 .31743 L
.43562 .32033 L
.43593 .32278 L
.43608 .32371 L
.43625 .32448 L
.4364 .32499 L
.43655 .32528 L
.43669 .3254 L
.43682 .32535 L
.43697 .32512 L
.43712 .32469 L
.43725 .32416 L
.43738 .32352 L
.43766 .32158 L
.43797 .31872 L
.43829 .31487 L
.43887 .3059 L
.43949 .29339 L
.44017 .27657 L
.44253 .19831 L
.44506 .09837 L
.44629 .05145 L
.44694 .02866 L
.44711 .02294 L
.44729 .01693 L
.44738 .01408 L
.44747 .01141 L
.44763 .00938 L
.44778 .01388 L
.44792 .01795 L
.44823 .02679 L
.44889 .04359 L
.45006 .06654 L
.45067 .07503 L
.45102 .0787 L
.45133 .08139 L
.45161 .08319 L
.45177 .084 L
Mistroke
.45192 .0846 L
.45207 .08508 L
.45216 .08528 L
.45224 .08543 L
.45238 .0856 L
.45253 .08563 L
.45267 .08555 L
.4528 .08536 L
.45295 .08504 L
.4531 .08457 L
.45325 .08397 L
.45341 .0832 L
.4537 .08148 L
.45422 .07736 L
.45478 .07148 L
.4561 .05324 L
.45734 .0324 L
.45789 .02286 L
.45846 .0128 L
.45861 .0103 L
.45876 .00823 L
.45885 .00974 L
.45893 .01112 L
.45909 .01378 L
.45967 .02311 L
.46083 .03933 L
.46144 .04626 L
.46209 .05217 L
.46241 .0545 L
.46271 .05631 L
.46299 .05761 L
.46313 .05817 L
.46328 .05868 L
.46342 .05906 L
.46356 .05937 L
.46371 .05961 L
.46386 .05975 L
.464 .05981 L
.46413 .05978 L
.46425 .0597 L
.46438 .05954 L
.46453 .05928 L
.46467 .05897 L
.46497 .058 L
.46525 .0568 L
.46552 .05538 L
.46612 .05134 L
.46677 .04565 L
.4681 .03092 L
.46931 .01539 L
Mistroke
.4696 .01161 L
.46975 .00955 L
.4699 .00824 L
.47005 .01031 L
.47023 .01257 L
.47053 .01648 L
.47168 .03019 L
.4729 .04177 L
.47325 .04436 L
.47359 .04647 L
.47391 .04817 L
.47421 .04945 L
.47448 .05032 L
.47461 .05067 L
.47476 .05098 L
.47492 .05122 L
.475 .05131 L
.47508 .05138 L
.47522 .05144 L
.47537 .05142 L
.47546 .05138 L
.47553 .05132 L
.47562 .05123 L
.47571 .05111 L
.47586 .05084 L
.47602 .05046 L
.47633 .0495 L
.47661 .04832 L
.47717 .04525 L
.47768 .0416 L
.47883 .03091 L
.47994 .01819 L
.48026 .01426 L
.48042 .01231 L
.48056 .0105 L
.48069 .00885 L
.48083 .00877 L
.48097 .01053 L
.48112 .01245 L
.48242 .02822 L
.48363 .04062 L
.48426 .04573 L
.48457 .04781 L
.48486 .04944 L
.48511 .05065 L
.4854 .05172 L
.48553 .05212 L
.48568 .05248 L
.48584 .05277 L
.48598 .05295 L
Mistroke
.48614 .05305 L
.48629 .05305 L
.48637 .05302 L
.48645 .05296 L
.48654 .05286 L
.48662 .05273 L
.48679 .05239 L
.48695 .05198 L
.4873 .05066 L
.48758 .04924 L
.48789 .04731 L
.48851 .04222 L
.48914 .03548 L
.48973 .02772 L
.49028 .01962 L
.49057 .01479 L
.49072 .01234 L
.49085 .01003 L
.491 .00835 L
.49115 .01112 L
.49148 .01718 L
.49206 .02839 L
.49338 .05515 L
.49457 .07946 L
.49585 .10327 L
.49695 .12038 L
.49753 .12768 L
.49815 .13391 L
.49845 .13639 L
.49879 .13862 L
.4991 .14018 L
.49938 .14124 L
.49953 .14164 L
.49968 .14192 L
.49981 .14208 L
.49995 .14216 L
.5001 .14215 L
.50018 .14209 L
.50026 .14201 L
.50041 .14176 L
.50055 .14143 L
.50082 .14054 L
.5011 .13923 L
.5016 .13596 L
.50214 .13116 L
.50274 .12445 L
.50397 .10638 L
.50509 .08609 L
.5064 .05974 L
.50761 .03487 L
Mistroke
.50819 .02347 L
.50873 .01326 L
.50886 .01085 L
.509 .00836 L
.50915 .01019 L
.50929 .01259 L
.50992 .02261 L
.51111 .03832 L
.51179 .04484 L
.51212 .04734 L
.51242 .04924 L
.51272 .05073 L
.51303 .05191 L
.51319 .05236 L
.51334 .05268 L
.51343 .05282 L
.51351 .05292 L
.5136 .053 L
.51369 .05305 L
.51383 .05306 L
.51399 .05298 L
.51413 .05281 L
.51426 .05259 L
.51442 .05225 L
.51459 .05177 L
.51489 .05064 L
.51546 .04764 L
.51606 .04333 L
.51713 .03317 L
.51828 .0199 L
.51861 .01581 L
.51892 .01189 L
.51906 .01018 L
.5192 .00836 L
.51936 .00951 L
.5195 .01134 L
.52066 .02531 L
.52172 .0364 L
.52226 .04113 L
.52285 .04538 L
.52345 .04858 L
.52377 .04983 L
.52391 .05028 L
.52407 .05068 L
.52422 .05099 L
.52436 .0512 L
.52449 .05134 L
.52463 .05143 L
.52476 .05144 L
.52487 .0514 L
Mistroke
.525 .05131 L
.52514 .05114 L
.52528 .05089 L
.52544 .05053 L
.52573 .04965 L
.52602 .04852 L
.52628 .04723 L
.52745 .03881 L
.52811 .0324 L
.52872 .02567 L
.52929 .01866 L
.52983 .01178 L
.52997 .00996 L
.5301 .00822 L
.53026 .00965 L
.53039 .01148 L
.53101 .01961 L
.53207 .03303 L
.53319 .04533 L
.53378 .05053 L
.53409 .05288 L
.53442 .05506 L
.53473 .05671 L
.53501 .05793 L
.53514 .05841 L
.53529 .05886 L
.53542 .05918 L
.53556 .05945 L
.53564 .05957 L
.53572 .05967 L
.53587 .05978 L
.53595 .05981 L
.53604 .0598 L
.53612 .05977 L
.5362 .05971 L
.53635 .05953 L
.53643 .05939 L
.53651 .05923 L
.5368 .05841 L
.53707 .05739 L
.53735 .05594 L
.53793 .05198 L
.53856 .04624 L
.53924 .03848 L
.53987 .0299 L
.54046 .02098 L
.54075 .01636 L
.54102 .01187 L
.54117 .00934 L
.54126 .00797 L
Mistroke
.54134 .0093 L
.54162 .01421 L
.54288 .03633 L
.5442 .05779 L
.54484 .06681 L
.54543 .0738 L
.54599 .07915 L
.54625 .08111 L
.54652 .08284 L
.54667 .08363 L
.54681 .08424 L
.54695 .08475 L
.54708 .08511 L
.54723 .08542 L
.54731 .08553 L
.5474 .08561 L
.54754 .08563 L
.54769 .08553 L
.54777 .08541 L
.54786 .08524 L
.54802 .08481 L
.54817 .08424 L
.54832 .08358 L
.54864 .08159 L
.54898 .07872 L
.54955 .07221 L
.55018 .06251 L
.55141 .03637 L
.55169 .02907 L
.55199 .0208 L
.55213 .0166 L
.55227 .01254 L
.55239 .00881 L
.55252 .01119 L
.55268 .01614 L
.55285 .02149 L
.55314 .0314 L
.55381 .05527 L
.55504 .10226 L
.55744 .19709 L
.55962 .27076 L
.5602 .28605 L
.56083 .30012 L
.56142 .31072 L
.56197 .31805 L
.56227 .32101 L
.56255 .3231 L
.56272 .324 L
.56286 .32463 L
.56294 .32488 L
Mistroke
.56303 .3251 L
.56311 .32527 L
.5632 .32536 L
.56328 .3254 L
.56337 .32537 L
.56345 .32529 L
.56352 .32516 L
.56367 .32477 L
.56382 .32417 L
.56399 .3233 L
.56414 .32228 L
.5645 .31921 L
.56481 .31565 L
.5651 .31164 L
.56575 .30017 L
.56694 .27147 L
.56918 .1969 L
.57145 .10867 L
.57264 .06386 L
.57329 .04116 L
.5739 .02155 L
.57406 .01668 L
.57421 .0122 L
.5743 .00977 L
.57439 .0087 L
.57454 .01314 L
.57525 .03119 L
.57584 .04401 L
.57649 .05563 L
.5771 .06411 L
.57744 .06771 L
.57775 .07043 L
.57805 .07239 L
.57832 .07371 L
.57846 .07422 L
.57861 .07464 L
.57869 .07479 L
.57877 .07492 L
.57892 .07504 L
.57907 .07504 L
.57916 .07498 L
.57924 .07489 L
.57932 .07475 L
.57939 .07459 L
.57957 .07412 L
.57971 .07359 L
.57987 .07289 L
.58016 .07129 L
.58086 .06583 L
.5815 .059 L
Mistroke
.58275 .04209 L
.58393 .02371 L
.58446 .0153 L
.58472 .01112 L
.58487 .00877 L
.58501 .00927 L
.58517 .01163 L
.58531 .01374 L
.58562 .01838 L
.58618 .02615 L
.58679 .03379 L
.58746 .04082 L
.58808 .04607 L
.58839 .04809 L
.58866 .04962 L
.58895 .0509 L
.58923 .0518 L
.58938 .05216 L
.58951 .05242 L
.58967 .05262 L
.58975 .05268 L
.58983 .05272 L
.58997 .05272 L
.5901 .05265 L
.59024 .0525 L
.59039 .05225 L
.59052 .05196 L
.59065 .05163 L
.59092 .05068 L
.59125 .0492 L
.59155 .04746 L
.59212 .04336 L
.59341 .03075 L
.59458 .01655 L
.59486 .01289 L
.59501 .01095 L
.59516 .00891 L
.59525 .00806 L
.59534 .00925 L
.5955 .01134 L
.59581 .01542 L
.59696 .02949 L
.59803 .04064 L
.59863 .04548 L
.59894 .04757 L
.59927 .04942 L
.59955 .05068 L
.5997 .05122 L
.59986 .05172 L
.60001 .05209 L
Mistroke
.60014 .05235 L
.60027 .05255 L
.6004 .05267 L
.60048 .05271 L
.60056 .05273 L
.60071 .05269 L
.60086 .05256 L
.60095 .05244 L
.60103 .05231 L
.60116 .05202 L
.60131 .05162 L
.60161 .05055 L
.60194 .04896 L
.60229 .04678 L
.60293 .04167 L
.60416 .02795 L
.60481 .01906 L
.60516 .01384 L
.60534 .01121 L
.6055 .00876 L
.60564 .00941 L
.60579 .01162 L
.6061 .01656 L
.60676 .02713 L
.60792 .04506 L
.60908 .0602 L
.60973 .06679 L
.61003 .06931 L
.61031 .07126 L
.61057 .07273 L
.61086 .07395 L
.61101 .07441 L
.61115 .07473 L
.61129 .07495 L
.61145 .07505 L
.61159 .07503 L
.61174 .07487 L
.61188 .07459 L
.61202 .07423 L
.61213 .07381 L
.61226 .07325 L
.61253 .07179 L
.61284 .06953 L
.61317 .06644 L
.61376 .05908 L
.61438 .04898 L
.61506 .03513 L
.61536 .02811 L
.61568 .0199 L
.61583 .01594 L
Mistroke
.61599 .0116 L
.61612 .00807 L
.61627 .01237 L
.61737 .04767 L
.62204 .22381 L
.62324 .26299 L
.62438 .29286 L
.62501 .30556 L
.62534 .31108 L
.6257 .316 L
.62603 .31966 L
.62632 .3222 L
.62647 .32317 L
.62662 .32402 L
.62677 .32464 L
.6269 .32504 L
.62705 .32532 L
.6272 .3254 L
.62733 .32531 L
.62747 .32506 L
.62762 .32459 L
.6277 .32428 L
.62778 .32388 L
.62808 .32203 L
.62835 .31966 L
.62864 .31642 L
.62917 .30878 L
.62981 .2968 L
.63048 .28105 L
.63167 .24595 L
.63408 .15647 L
.63627 .06995 L
.63685 .04833 L
.63749 .0263 L
.63778 .01675 L
.63794 .0117 L
.63808 .00878 L
.63821 .01262 L
.63835 .01664 L
.63864 .02487 L
.63931 .04232 L
.63996 .05628 L
.64053 .06648 L
.64083 .07102 L
.64116 .07522 L
.64148 .07855 L
.64176 .08103 L
.64204 .0829 L
.64232 .08433 L
.64247 .08486 L
Mistroke
.64263 .08528 L
.64278 .08552 L
.64291 .08563 L
.64307 .08561 L
.64316 .08553 L
.64325 .08542 L
.6434 .0851 L
.64347 .08489 L
.64356 .08462 L
.64385 .08341 L
.64411 .0819 L
.64471 .07723 L
.64526 .07147 L
.64578 .06489 L
.64694 .04744 L
.64817 .02628 L
.64846 .02122 L
.64877 .01576 L
.64891 .01328 L
.64906 .01067 L
.64919 .00846 L
.64933 .00982 L
.64947 .01214 L
.64959 .01422 L
.64988 .01882 L
.65039 .02672 L
.6515 .0417 L
.65211 .04822 L
.65269 .0531 L
.65301 .05527 L
.65331 .0569 L
.65363 .05828 L
.65381 .05883 L
.65399 .05928 L
.65413 .05954 L
.65429 .05972 L
.65443 .0598 L
.65456 .0598 L
.65472 .05971 L
.65481 .05961 L
.65489 .0595 L
.65503 .05922 L
.65519 .05884 L
.6555 .05781 L
.65579 .05652 L
.65633 .05329 L
.65691 .04873 L
.65755 .04264 L
.65869 .02957 L
.65976 .01573 L
Mistroke
.66005 .01186 L
.66021 .00975 L
.66036 .00808 L
.66044 .0091 L
.66052 .0102 L
.6607 .0125 L
.66101 .01649 L
.66214 .02997 L
.66282 .03692 L
.66346 .04243 L
.66404 .04635 L
.66434 .04797 L
.66467 .04939 L
.66482 .04991 L
.66498 .05038 L
.66512 .05074 L
.66526 .05101 L
.66538 .0512 L
.66552 .05135 L
.66567 .05143 L
.66581 .05144 L
.66588 .05141 L
.66597 .05136 L
.66612 .05121 L
.6662 .05109 L
.66628 .05096 L
.66645 .05058 L
.66674 .04971 L
.66706 .04845 L
.66774 .04464 L
.66838 .03975 L
.66959 .02782 L
.67019 .0209 L
.67076 .01403 L
.67104 .0105 L
.6712 .0085 L
.67134 .00921 L
.67149 .01111 L
.67166 .01319 L
.67199 .01735 L
.67313 .03087 L
.67421 .0416 L
.67481 .04624 L
.67512 .04825 L
.67545 .05002 L
.67573 .05121 L
.67588 .05173 L
.67604 .05219 L
.67618 .05253 L
.67631 .05277 L
Mistroke
.67645 .05294 L
.67658 .05303 L
.67673 .05306 L
.67688 .053 L
.67696 .05292 L
.67705 .05282 L
.6772 .05254 L
.67735 .05219 L
.6775 .05172 L
.67778 .05062 L
.67811 .04893 L
.67841 .04696 L
.6791 .04106 L
.67971 .03435 L
.68036 .02553 L
.68094 .01657 L
.6811 .01405 L
.68126 .01125 L
.68142 .00855 L
.68156 .00985 L
.68169 .01218 L
.68183 .01477 L
.68211 .0201 L
.68272 .03204 L
.6838 .05401 L
.68512 .08086 L
.68636 .10393 L
.68757 .12235 L
.68811 .12877 L
.68869 .13448 L
.68896 .13664 L
.68926 .13857 L
.68954 .14002 L
.68979 .14102 L
.68994 .14146 L
.69007 .14178 L
.69023 .14202 L
.69031 .1421 L
.69039 .14215 L
.69053 .14217 L
.69068 .14207 L
.69082 .14188 L
.69095 .14162 L
.69109 .14124 L
.69125 .14072 L
.69152 .13951 L
.69185 .13761 L
.69214 .13545 L
.69279 .12938 L
.6934 .12205 L
Mistroke
.69581 .08138 L
.69803 .03602 L
.69859 .02486 L
.6989 .01891 L
.6992 .01341 L
.69933 .011 L
.69947 .00849 L
.69963 .0101 L
.69977 .01256 L
.70029 .02104 L
.70096 .03072 L
.7016 .03839 L
.70216 .04393 L
.70246 .04635 L
.70278 .04853 L
.7031 .05028 L
.70339 .05151 L
.70353 .05197 L
.70368 .05238 L
.70382 .05268 L
.70395 .05288 L
.7041 .05302 L
.70424 .05306 L
.70439 .05303 L
.70448 .05296 L
.70456 .05288 L
.70471 .05266 L
.70487 .05231 L
.70504 .05184 L
.7052 .0513 L
.70576 .04866 L
.70628 .04531 L
.70743 .03507 L
.70855 .02238 L
.70916 .01481 L
.70946 .01103 L
.7096 .00937 L
.70974 .00831 L
.70989 .01024 L
.71004 .01207 L
.71036 .01606 L
.71104 .02425 L
.71225 .0369 L
.71289 .04233 L
.71349 .04639 L
.71404 .04906 L
.71434 .05014 L
.71462 .05085 L
.71477 .05111 L
.71493 .05131 L
Mistroke
.71508 .05141 L
.71521 .05144 L
.71537 .05139 L
.71546 .05133 L
.71554 .05124 L
.71569 .05102 L
.71585 .05069 L
.71617 .04978 L
.71647 .04861 L
.71715 .04483 L
.71939 .0234 L
.72 .01581 L
.72033 .01148 L
.72041 .01043 L
.7205 .00932 L
.72065 .00855 L
.72079 .01042 L
.72095 .01247 L
.72127 .01671 L
.72182 .02402 L
.72299 .03823 L
.72424 .05046 L
.7246 .05311 L
.72493 .05526 L
.72526 .05697 L
.72556 .05821 L
.72585 .05906 L
.72599 .05937 L
.72615 .05962 L
.72631 .05976 L
.7264 .0598 L
.72648 .05981 L
.72663 .05974 L
.72679 .05958 L
.72694 .05933 L
.7271 .05896 L
.72739 .05801 L
.72768 .05675 L
.72794 .05529 L
.72854 .05095 L
.72917 .04488 L
.73022 .03173 L
.73078 .02354 L
.73138 .01383 L
.73154 .0112 L
.73163 .00975 L
.73171 .00837 L
.73187 .01021 L
.73201 .01269 L
.7326 .02312 L
Mistroke
.73372 .04255 L
.73495 .06177 L
.73562 .07053 L
.73624 .07718 L
.7368 .08163 L
.73711 .08344 L
.73725 .08408 L
.7374 .08464 L
.73747 .08488 L
.73756 .08511 L
.73771 .08542 L
.73779 .08553 L
.73788 .08561 L
.73797 .08564 L
.73805 .08562 L
.73819 .0855 L
.73835 .08522 L
.73843 .08502 L
.73851 .08476 L
.73866 .08419 L
.73895 .08268 L
.73926 .08044 L
.73983 .07473 L
.74038 .0671 L
.74089 .05829 L
.74198 .0338 L
.7423 .02541 L
.7426 .01693 L
.74273 .0131 L
.74286 .00892 L
.74302 .01165 L
.74316 .0161 L
.74444 .06083 L
.74564 .10729 L
.74806 .20262 L
.74933 .24736 L
.75067 .28585 L
.75125 .29898 L
.75187 .31027 L
.75223 .3154 L
.75255 .31916 L
.75271 .32067 L
.75288 .32207 L
.75304 .32316 L
.75319 .32399 L
.75332 .32457 L
.75347 .32502 L
.75355 .3252 L
.75363 .32532 L
.75377 .3254 L
Mistroke
.75393 .32528 L
.75407 .325 L
.75423 .32448 L
.75439 .32371 L
.75454 .32284 L
.75469 .32172 L
.75498 .31915 L
.75551 .3126 L
.7561 .30265 L
.75665 .29101 L
.75791 .25705 L
.76045 .1664 L
.76269 .07935 L
.76331 .05701 L
.76396 .03472 L
.76452 .01714 L
.76467 .01258 L
.76476 .01023 L
.76484 .00808 L
.765 .01246 L
.76514 .01636 L
.76636 .04493 L
.76705 .05702 L
.76738 .06171 L
.7677 .06548 L
.76799 .06845 L
.76831 .07104 L
.7686 .07283 L
.76887 .07401 L
.76902 .07447 L
.76916 .07478 L
.76931 .07499 L
.7694 .07505 L
.76948 .07506 L
.76964 .07497 L
.76973 .07486 L
.76981 .07472 L
.76996 .07436 L
.77012 .07384 L
.77044 .07243 L
.77077 .0704 L
.77137 .06551 L
.77201 .05865 L
.77271 .04959 L
.77398 .03049 L
.77459 .02088 L
.77514 .01201 L
.77529 .00974 L
.77542 .00825 L
.77557 .01044 L
Mistroke
.77572 .01282 L
.77635 .02201 L
.7775 .03638 L
.77809 .04227 L
.77871 .04713 L
.77904 .0491 L
.7794 .05077 L
.77955 .05134 L
.77972 .05185 L
.77988 .05222 L
.78002 .05247 L
.78017 .05264 L
.7803 .05272 L
.78045 .05272 L
.78061 .05262 L
.78069 .05254 L
.78077 .05242 L
.78093 .05212 L
.78108 .05174 L
.78123 .05131 L
.78176 .04897 L
.78207 .04722 L
.78234 .04537 L
.78363 .03357 L
.78421 .02699 L
.78485 .01917 L
.78514 .01539 L
.78546 .01128 L
.78561 .00927 L
.78576 .0085 L
.78589 .0102 L
.78603 .01205 L
.78728 .02767 L
.78843 .03988 L
.78899 .04462 L
.78951 .04809 L
.78977 .04951 L
.79005 .05077 L
.79021 .05133 L
.79036 .05177 L
.79049 .05212 L
.79064 .0524 L
.79073 .05252 L
.79081 .05261 L
.79096 .05271 L
.7911 .05272 L
.79125 .05265 L
.79141 .05246 L
.79156 .0522 L
.79172 .05181 L
Mistroke
.7919 .05127 L
.79222 .04994 L
.79258 .04801 L
.79322 .04327 L
.79385 .03722 L
.79443 .0305 L
.79499 .02317 L
.79529 .01903 L
.79559 .0145 L
.79587 .01039 L
.79602 .00802 L
.79616 .01008 L
.79668 .01834 L
.79796 .03853 L
.79917 .05555 L
.79974 .06228 L
.80035 .06809 L
.80067 .07049 L
.80102 .07259 L
.80117 .07331 L
.80134 .07396 L
.80149 .07443 L
.80164 .07475 L
.80177 .07496 L
.80192 .07505 L
.80206 .07503 L
.80219 .07491 L
.80233 .07465 L
.80242 .07444 L
.8025 .07422 L
.80279 .07303 L
.80304 .07157 L
.80332 .06949 L
.80388 .06379 L
.80451 .05488 L
.80511 .04407 L
.80566 .03228 L
.80623 .01784 L
.80638 .01395 L
.80653 .00963 L
.80662 .00877 L
.8067 .01113 L
.80686 .01584 L
.80744 .03405 L
.80876 .08027 L
.81124 .17645 L
.81245 .22143 L
.81354 .25778 L
.81461 .28713 L
.81517 .29961 L
Mistroke
.81577 .3103 L
.81607 .3147 L
.81641 .31868 L
.81671 .32152 L
.81699 .32347 L
.81714 .32423 L
.81728 .32478 L
.81741 .32512 L
.81755 .32534 L
.8177 .32539 L
.81777 .32535 L
.81786 .32524 L
.81801 .3249 L
.81815 .32441 L
.81829 .32374 L
.81844 .32285 L
.81871 .32074 L
.81903 .31743 L
.81933 .31368 L
.81997 .30312 L
.82058 .29029 L
.82281 .22323 L
.82501 .13813 L
.82627 .08826 L
.82744 .04428 L
.82803 .02393 L
.82817 .0193 L
.82832 .01446 L
.82847 .00999 L
.8286 .00984 L
.82867 .01216 L
.82875 .01463 L
.8289 .01903 L
.82924 .02846 L
.82984 .0434 L
.83048 .05716 L
.83116 .06881 L
.83174 .07633 L
.83207 .0796 L
.83237 .08201 L
.83252 .08297 L
.83269 .08383 L
.83283 .08444 L
.83298 .08495 L
.83306 .08517 L
.83314 .08534 L
.83329 .08556 L
.83337 .08562 L
.83346 .08564 L
.83355 .08561 L
Mistroke
.83363 .08554 L
.83379 .08529 L
.83394 .08494 L
.83407 .08451 L
.83421 .08394 L
.83453 .08225 L
.83483 .08022 L
.83535 .07564 L
.83592 .06927 L
.83707 .05299 L
.83827 .03283 L
.83886 .02242 L
.83941 .0128 L
.83957 .01009 L
.83972 .00832 L
.8398 .00971 L
.83989 .0112 L
.84004 .01378 L
.84073 .02474 L
.84193 .04117 L
.84249 .04724 L
.84308 .05249 L
.84343 .05489 L
.84374 .05667 L
.84405 .05806 L
.84434 .059 L
.84449 .05933 L
.84458 .05948 L
.84465 .0596 L
.84473 .05969 L
.84482 .05976 L
.84498 .05981 L
.84512 .05976 L
.84528 .05962 L
.84543 .05939 L
.84556 .0591 L
.84574 .05864 L
.8459 .05809 L
.8462 .05681 L
.84689 .05272 L
.8491 .03037 L
.84971 .02266 L
.85004 .01829 L
.85036 .0141 L
.85065 .01021 L
.85073 .00914 L
.85082 .00801 L
.85097 .00988 L
.85153 .01712 L
.85277 .03169 L
Mistroke
.85394 .04242 L
.85452 .04635 L
.85482 .04796 L
.85514 .04938 L
.85548 .05047 L
.85567 .05089 L
.85576 .05105 L
.85584 .05118 L
.85592 .05127 L
.856 .05135 L
.85615 .05143 L
.85623 .05144 L
.85632 .05143 L
.85648 .05133 L
.85662 .05116 L
.85678 .0509 L
.85693 .05056 L
.85707 .05018 L
.85733 .04929 L
.85761 .04808 L
.85826 .04437 L
.85884 .03995 L
.85991 .02956 L
.86105 .01635 L
.86132 .0129 L
.86148 .01098 L
.86162 .00915 L
.8617 .00812 L
.86179 .00888 L
.86195 .01085 L
.86226 .0147 L
.86337 .02816 L
.86456 .0405 L
.86524 .04597 L
.86555 .048 L
.86588 .0498 L
.86617 .05107 L
.86632 .05162 L
.86648 .05211 L
.86663 .05248 L
.86677 .05273 L
.8669 .05292 L
.86703 .05302 L
.86718 .05306 L
.86734 .05301 L
.86748 .05288 L
.86763 .05264 L
.86779 .05229 L
.86796 .05179 L
.86827 .05058 L
Mistroke
.8686 .04887 L
.86895 .04651 L
.86959 .04089 L
.8708 .02603 L
.87135 .01771 L
.87163 .01299 L
.87179 .01032 L
.87194 .0081 L
.87201 .00948 L
.8721 .01096 L
.87227 .01417 L
.87258 .01996 L
.87318 .0318 L
.87572 .08331 L
.87695 .10582 L
.8776 .11607 L
.87829 .12536 L
.87889 .13195 L
.87921 .13482 L
.87955 .1374 L
.87986 .13929 L
.88015 .14061 L
.88029 .1411 L
.88044 .14153 L
.88058 .14184 L
.88072 .14203 L
.88087 .14216 L
.88095 .14217 L
.88103 .14215 L
.88119 .14204 L
.88133 .14183 L
.88141 .14165 L
.8815 .14145 L
.88165 .14099 L
.88199 .13955 L
.88229 .13783 L
.88257 .13588 L
.88319 .13019 L
.88428 .11646 L
.88544 .09746 L
.88781 .05032 L
.88885 .02918 L
.88944 .01777 L
.88972 .01253 L
.88986 .01003 L
.88999 .00812 L
.89013 .01053 L
.89028 .0131 L
.89054 .01743 L
.89113 .0264 L
Mistroke
.89232 .04101 L
.8929 .04613 L
.89324 .04844 L
.89354 .05015 L
.89387 .05152 L
.89404 .05209 L
.89421 .05251 L
.89437 .05279 L
.89451 .05297 L
.89467 .05306 L
.89476 .05306 L
.89484 .05304 L
.89498 .05294 L
.89512 .05276 L
.89527 .05249 L
.89543 .0521 L
.89575 .051 L
.89605 .04966 L
.89662 .04623 L
.89716 .04204 L
.89838 .02988 L
.89905 .02207 L
.89968 .01434 L
.89995 .01096 L
.90008 .00926 L
.90023 .00847 L
.90031 .00945 L
.90039 .01049 L
.90054 .01236 L
.90082 .01589 L
.90208 .03052 L
.90268 .03653 L
.90325 .04143 L
.9038 .04533 L
.90431 .04816 L
.90458 .04932 L
.90487 .05028 L
.90503 .05071 L
.90519 .05102 L
.90533 .05123 L
.90548 .05137 L
.90563 .05144 L
.90572 .05144 L
.9058 .05142 L
.90588 .05137 L
.90596 .05131 L
.90604 .05121 L
.90613 .05109 L
.90628 .05081 L
.90641 .05049 L
Mistroke
.90673 .04951 L
.90702 .0483 L
.90729 .04691 L
.9078 .04364 L
.90895 .03355 L
.91012 .02021 L
.91071 .01272 L
.91088 .01061 L
.91096 .00944 L
.91105 .00833 L
.91113 .00858 L
.91121 .00971 L
.91136 .0117 L
.91359 .03957 L
.91423 .04615 L
.91483 .05135 L
.91538 .05506 L
.91568 .0567 L
.91596 .05793 L
.91627 .05892 L
.91643 .0593 L
.91652 .05947 L
.9166 .05959 L
.91669 .05969 L
.91679 .05976 L
.91687 .0598 L
.91696 .05981 L
.91711 .05974 L
.9172 .05966 L
.91728 .05956 L
.91743 .0593 L
.91759 .05893 L
.91786 .05802 L
.91816 .05669 L
.91849 .0548 L
.91913 .04996 L
.91981 .04301 L
.92106 .02649 L
.92165 .01728 L
.9218 .01474 L
.92197 .01197 L
.92213 .00932 L
.92227 .009 L
.9224 .01125 L
.92254 .01371 L
.9228 .01823 L
.92339 .02852 L
.92457 .04874 L
.92583 .06732 L
.92645 .07449 L
Mistroke
.92702 .0798 L
.92727 .08163 L
.92754 .0832 L
.92768 .08388 L
.92783 .08449 L
.92796 .08492 L
.9281 .08526 L
.92826 .08552 L
.9284 .08563 L
.92856 .0856 L
.92865 .08552 L
.92873 .0854 L
.92889 .08507 L
.92902 .08464 L
.92918 .08399 L
.92933 .08323 L
.92961 .08143 L
.92987 .0793 L
.93046 .07283 L
.9311 .06314 L
.93168 .05202 L
.93231 .03747 L
.93266 .02849 L
.93298 .01948 L
.93313 .01532 L
.93326 .01129 L
.93342 .00936 L
.93356 .01382 L
.93419 .03479 L
.9353 .0754 L
.93782 .17489 L
.94001 .25398 L
.94061 .27189 L
.94126 .28873 L
.94182 .30096 L
.94244 .31166 L
.94273 .31572 L
.94304 .3193 L
.94322 .32093 L
.94337 .32219 L
.94353 .32326 L
.94368 .32406 L
.94382 .32463 L
.94396 .32507 L
.94411 .32532 L
.94419 .32539 L
.94427 .32539 L
.94441 .32528 L
.94453 .32503 L
.94468 .32457 L
Mistroke
.94482 .32396 L
.94498 .32306 L
.94513 .32206 L
.94545 .31919 L
.94603 .31186 L
.94671 .29994 L
.94735 .28563 L
.94978 .20984 L
.95201 .12391 L
.95311 .08172 L
.95428 .03991 L
.95463 .02857 L
.95496 .01834 L
.9551 .01405 L
.95525 .00961 L
.95533 .00853 L
.95542 .011 L
.95557 .01524 L
.95678 .04373 L
.95737 .05452 L
.958 .06342 L
.95853 .069 L
.95883 .07135 L
.95911 .07301 L
.95927 .07372 L
.95944 .07432 L
.95952 .07453 L
.9596 .07472 L
.95975 .07495 L
.95989 .07505 L
.96003 .07504 L
.96017 .0749 L
.96033 .07463 L
.96042 .07441 L
.9605 .07418 L
.96068 .07353 L
.96101 .0719 L
.96131 .06995 L
.96163 .06743 L
.96276 .05527 L
.96397 .03803 L
.96453 .02942 L
.96512 .02001 L
.9654 .01545 L
.96554 .01322 L
.96567 .01117 L
.96579 .00933 L
.96591 .00849 L
.96604 .01042 L
.96618 .01252 L
Mistroke
.96733 .02873 L
.96859 .04249 L
.96922 .04737 L
.96958 .04944 L
.9699 .0509 L
.97021 .05188 L
.97038 .05227 L
.97054 .05252 L
.97069 .05267 L
.97083 .05273 L
.97099 .05269 L
.97114 .05257 L
.97128 .05238 L
.97143 .05208 L
.9717 .05133 L
.97202 .05006 L
.97231 .04858 L
.97295 .04433 L
.97356 .03913 L
.97579 .01322 L
.97619 .00794 L
Mfstroke
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00Eoooool3o`0003Sooooo0ol0000eooooo`Go0000=?ooool2o`0003Kooooo1Ol0000goooo
o`?o0000=_ooool3o`0004Gooooo001Fooooo`05o`000?ooooooooooooooool00000>?ooool00ol0
003oooooooooo`0eooooo`04o`000?ooooooooooo`0003?ooooo00Co0000oooooooooooo0000=_oo
ool01?l0003oooooooooool0000hooooo`03o`000?oooooooooo03Cooooo00Go0000oooooooooooo
ooooo`000014ooooo`00D?ooool5o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
;Oooool5o`000003ooooool0003o000000?o0000;oooool5o`0000?ooooo00?o0000ooooooooool0
<oooool01?l0003oooooooooool0000gooooo`03o`000?oooooooooo03Gooooo1Ol0000eooooo`05
o`000?ooooooooooooooool00000A?ooool005Kooooo1?l0000fooooo`04o`000?ooooooooooo`00
03Wooooo00?o0000ooooooooool0<_ooool01?l0003oooooooooool0000hooooo`03o`000?oooooo
oooo03Cooooo00Co0000oooooooooooo0000=_ooool4o`0004Gooooo001Fooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooool00000=_ooool01Ol0003ooooooooooooooooo000003?ooooo00Co
0000oooooooooooo0000=Oooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooool0
0000=_ooool00ol0003oooooooooo`16ooooo`00Eoooool00ol0003oooooooooo`0hooooo`;o0000
=_ooool01Ol0003ooooooooooooooooo000003?ooooo00Co0000oooooooooooo0000=Oooool01Ol0
003ooooooooooooooooo000003Oooooo0_l0000gooooo`03o`000?oooooooooo04Gooooo001Hoooo
o`;o0000>Oooool00ol0003oooooooooo`0eooooo`?o0000=Oooool2o`0003Oooooo0ol0000ioooo
o`03o`000?oooooooooo03Kooooo0_l00015ooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`007ooo
ooooo`000<_o00003oooool001Kooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`005Oooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=
ooooo`005Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0=ooooo`005Oooool01?l0003oooooooooool00006
ooooo`Co00001oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00Coo`00
oooooooooooooooo0_oo0004ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`0<ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`0<ooooo`05ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`0<ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooo`000003ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooo
oooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`02ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00_oo
ool01Ooo003oooooooooooooooooo`0000Oooooo1?l0000?ooooo`005Oooool01?l0003ooooooooo
ool00006ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`05ooooo`04ool00?ooooooooooooooo`;oo`000oooool2ool000Cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`07ooooo`04ool00?ooooooooooooooo`;oo`000oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Coo`00oooooooooooooooo0_oo0003
ooooo`;oo`001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00
ooooooooool00_ooool01Ooo003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Goo`00oooooooooooooooo
o`000003ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0_oo0004ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`02ooooo`05
ool00?oooooooooooooooooo00001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`04ool00?oooooooooo
ooooo`;oo`000oooool2ool000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo00;ooooo00Goo`00ooooooooooooooooool00004ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`07ooooo`03ool00?oo
oooooooo00;ooooo00Goo`00ooooooooooooooooool0000:ooooo`03o`000?oooooooooo00gooooo
000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01?oo003ooooo
ooooooooool2ool000Oooooo00Coo`00oooooooooooooooo0_oo0003ooooo`;oo`001?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00Oooooo00Coo`00oooooooooooooooo0_oo0003
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01?oo003ooooooooooooo
ool2ool000?ooooo0_oo0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01ooo
ool01?oo003oooooooooooooool2ool000?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01Ooo003ooooo
oooooooooooo000000?ooooo00Coo`00oooooooooooooooo0_oo0003ooooo`;oo`001?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00_ooool01Ooo
003oooooooooooooooooo`0000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01?oo003ooooooooooooo
ool2ool000?ooooo0_oo0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01ooo
ool01?oo003oooooooooooooool2ool000?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0_oo0004ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool01oooool01?oo003oooooooooooooool2ool0
00?ooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`005_ooool2o`0000Oo
oooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool01?oo003oooooooooooooool2ool000Oooooo00Coo`00oooo
oooooooooooo0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?oo`00ooooooooool01oooool0
1?oo003oooooooooooooool2ool000?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0_oo0007ooooo`04ool0
0?ooooooooooooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03ool00?oooooooooo00Oo
oooo00Coo`00oooooooooooooooo0_oo0003ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`04ool00?ooooooooooooooo`;oo`000oooool0
1Ol0003oooooooooooooooooo`0000?ooooo0_oo0003ooooo`;oo`001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Oooooo00Coo`00oooooooooooooooo0_oo0003ooooo`;oo`00
0oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooooooo`;oo`000oooool2ool000Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`07ooooo`04ool00?oooooooooooooo
o`;oo`000oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool01oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Coo`00oooo
oooooooooooo0_oo0003ooooo`;oo`001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00Oooooo00Coo`00oooooooooooooooo0_oo0003ooooo`03ool00?oooooooooo00Sooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02Oooool01Ooo003ooooooooooooo
ooooo`0000Cooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool01?oo003oooooooooooooool2ool000Oooooo
00Coo`00oooooooooooooooo0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?oo`00oooooooo
ool01oooool01?oo003oooooooooooooool2ool000?ooooo0_oo0003ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool01?oo003oooooooooooooool2ool000Oooooo00Coo`00
oooooooooooooooo0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?oo`00ooooooooool01ooo
ool01?oo003oooooooooooooool2ool000?ooooo0_oo0003ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool01?oo003oooooooooooooool2ool000?ooooo00Go0000oooooooo
ooooooooool00003ooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03ool00?oooooooooo
00Oooooo00Coo`00oooooooooooooooo0_oo0003ooooo`;oo`000oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0_oo0007ooooo`04ool00?oo
ooooooooooooo`;oo`000oooool2ool000Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`07ooooo`04ool00?ooooooooooooooo`;oo`000oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01?oo003oooooooooooooool2ool0
00Oooooo00Coo`00oooooooooooooooo0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?oo`00
ooooooooool01oooool01?oo003oooooooooooooool2ool000?ooooo00?oo`00ooooooooool02?oo
ool00ol0003oooooooooo`0=ooooo`007oooool3o`0000Wooooo00Goo`00ooooooooooooooooool0
0004ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0_oo0007ooooo`04ool0
0?ooooooooooooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03ool00?oooooooooo00Oo
oooo00Coo`00oooooooooooooooo0_oo0003ooooo`;oo`000oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0_oo0007ooooo`04ool00?oooooo
ooooooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03ool00?oooooooooo00Oooooo00Co
o`00oooooooooooooooo0_oo0003ooooo`;oo`000oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00Coo`00oooooooooooooooo0_oo0003ooooo`05o`000?oooooooooooooo
oooo00000oooool2ool000?ooooo0_oo0003ooooo`;oo`001?ooool00ooo003oooooooooo`07oooo
o`04ool00?ooooooooooooooo`;oo`000oooool2ool000?ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`07ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`04ool00?ooooooooooooooo`;oo`001oooool01?oo003ooooooooo
ooooool2ool000?ooooo0_oo0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
1oooool01?oo003oooooooooooooool2ool000?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0_oo0007oooo
o`04ool00?ooooooooooooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03ool00?oooooo
oooo00Oooooo00Coo`00oooooooooooooooo0_oo0003ooooo`03ool00?oooooooooo00Oooooo0_l0
000?ooooo`007oooool00ol0003oooooooooo`09ooooo`05ool00?oooooooooooooooooo00001?oo
ool00ooo003oooooooooo`07ooooo`04ool00?ooooooooooooooo`;oo`001?ooool00ooo003ooooo
ooooo`02ooooo`;oo`000_ooool2ool000Oooooo00Coo`00oooooooooooooooo0_oo0003ooooo`;o
o`000oooool2ool000Cooooo00?oo`00ooooooooool01_ooool2ool000?ooooo0_oo0003ooooo`;o
o`000oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`04ool00?ooooooooooooooo`;oo`000oooool2ool0
00Oooooo0_oo0002ooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03ool00?oooooooooo
00Oooooo00Coo`00oooooooooooooooo0_oo0003ooooo`;oo`000oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo0_oo0002ooooo`;oo`000oooool01Ol0003ooooooooooooo
ooooo`0000?ooooo0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?oo`00ooooooooool01ooo
ool01?oo003oooooooooooooool2ool000?ooooo0_oo0003ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool01?oo003oooooooooooooool2ool000Oooooo00Coo`00oooooooo
oooooooo0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?oo`00ooooooooool01oooool01?oo
003oooooooooooooool2ool000?ooooo0_oo0003ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00_ooool01?oo003oooooooooooooool2ool000Oooooo00Coo`00oooooooooooooooo
0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?oo`00ooooooooool01oooool01?oo003ooooo
ooooooooool2ool000?ooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`00
7oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00;oo`000oooool2ool000Wooooo
00Coo`00oooooooooooooooo0_oo0004ooooo`;oo`000_ooool00ooo003oooooool00002ooooo`;o
o`001oooool01?oo003oooooooooooooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool0
00Sooooo0_oo0003ooooo`;oo`000oooool2ool000;ooooo0_oo0004ooooo`03ool00?oooooooooo
00Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`07ool00?oooooooooo
oooooooo003oooooool00002ooooo`;oo`001oooool2ool000;ooooo0_oo0003ooooo`;oo`000ooo
ool2ool000?ooooo0_oo0009ooooo`04ool00?ooooooooooooooo`;oo`000oooool2ool000?ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00;ooooo
00Coo`00oooooooooooooooo0_oo0004ooooo`;oo`000_ooool2ool000?ooooo00Go0000oooooooo
ooooooooool00003ooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03ool00?oooooooooo
00Oooooo00Coo`00oooooooooooooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`02ooooo`;oo`000_ooool2ool000Cooooo00Coo`00
oooooooooooooooo0_oo0007ooooo`04ool00?ooooooooooooooo`;oo`000oooool2ool000?ooooo
0_oo0003ooooo`;oo`002Oooool01?oo003oooooooooooooool2ool000?ooooo0_oo0003ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool2ool000;ooooo0_oo0007ooooo`04
ool00?ooooooooooooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03ool00?oooooooooo
00Oooooo00Coo`00oooooooooooooooo0_oo0003ooooo`03ool00?oooooooooo00Sooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`02ool0
00?ooooo0_oo0008ooooo`;oo`000oooool2ool000?ooooo00?oo`00oooooooo00000_ooool00ooo
003oooooool00002ooooo`;oo`001oooool2ool000;ooooo0_oo0003ooooo`;oo`000oooool2ool0
00?ooooo0_oo0008ooooo`;oo`000oooool2ool000?ooooo0_oo0002ooooo`;oo`001?ooool00ooo
003oooooooooo`07ooooo`03ool00?oooooooooo00;ooooo0_oo0003ooooo`;oo`000_ooool00ooo
003oooooool00002ooooo`;oo`001_ooool00ooo003oooooool00002ooooo`;oo`000oooool2ool0
00?ooooo0_oo0003ooooo`;oo`002Oooool01?oo003oooooooooooooool2ool000?ooooo0_oo0003
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`02
ooooo`07ool00?oooooooooooooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo
0_oo0003ooooo`05o`000?oooooooooooooooooo00000oooool2ool000?ooooo0_oo0003ooooo`;o
o`000oooool2ool000Wooooo00Coo`00oooooooooooooooo0_oo0002ooooo`03ool00?ooooooo`00
00;ooooo00?oo`00oooooooo00000_ooool2ool000Wooooo00Ooo`00ooooooooooooooooool00?oo
ooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`;oo`001ooo
ool01?oo003oooooooooooooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool000Wooooo
00Coo`00oooooooooooooooo0_oo0003ooooo`;oo`000oooool01?oo003oooooooooooooool2ool0
00Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`;oo`000_ooool00ooo
003oooooool00002ooooo`;oo`001_ooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool0
00?ooooo0_oo0009ooooo`04ool00?ooooooooooooooo`;oo`000oooool00ooo003oooooooooo`08
ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00Wooooo00?oo`00oooo
ooooool00_oo0003ooooo`;oo`002?ooool2ool000?ooooo0_oo0003ooooo`03ool00?ooooooo`00
00;ooooo00?oo`00oooooooo00000_ooool2ool000Oooooo0_oo0002ooooo`;oo`000oooool2ool0
00?ooooo0_oo0003ooooo`;oo`002?ooool2ool000?ooooo0_oo0003ooooo`;oo`000_ooool00ooo
003oooooool00002ooooo`;oo`002Oooool00ooo003oooooooooo`02ooooo`;oo`000_ooool00ooo
003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo0_oo0006ooooo`03ool00?ooooooo`00
00;ooooo00?oo`00oooooooo00000_ooool2ool000?ooooo0_oo0003ooooo`;oo`002Oooool01?oo
003oooooooooooooool2ool000?ooooo0_oo0002ooooo`;oo`001?ooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo00;ooooo00Ooo`00ooooooooooooooooool00?ooooooo`0000;ooooo
00?oo`00oooooooo00000_ooool2ool000?ooooo00Go0000ooooooooooooooooool00003ooooo`;o
o`000oooool2ool000?ooooo0_oo0003ooooo`;oo`002Oooool01?oo003oooooooooooooool2ool0
00;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`;oo`002Oooool01ooo
003oooooooooooooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?oo
ooooo`0000;ooooo0_oo0007ooooo`;oo`000_ooool2ool000?ooooo0_oo0003ooooo`;oo`000ooo
ool2ool000Sooooo0_oo0003ooooo`;oo`000oooool2ool000;ooooo0_oo0003ooooo`;oo`002Ooo
ool01?oo003oooooooooooooool2ool000?ooooo00?oo`00oooooooo00000_ooool00ooo003ooooo
ool00002ooooo`;oo`001_ooool2ool000?ooooo0_oo0003ooooo`03ool00?ooooooo`0000;ooooo
0_oo0003ooooo`;oo`002Oooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00oooooooo
ool02Oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`09ooooo`06ool0
0?ooooooooooool00?ooooooo`000_ooool2ool000Sooooo0_oo0003ooooo`;oo`000oooool00ooo
003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo0_oo0006ooooo`07ool00?ooooooo`00
oooooooo003oooooool00003ooooo`;oo`000oooool2ool000?ooooo0_oo0008ooooo`;oo`000ooo
ool2ool000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`;oo`002Ooo
ool01ooo003oooooooooooooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03
ool00?ooooooo`0000;ooooo0_oo0006ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo
00000_ooool2ool000?ooooo0_oo0003ooooo`;oo`002?ooool2ool000?ooooo0_oo0002ooooo`03
ool00?ooooooo`0000;ooooo0_oo0004ooooo`03ool00?oooooooooo00Oooooo00Coo`00oooooooo
oooooooo0_oo0003ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool2ool0
00?ooooo00?o0000ooooooooool00_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003oooo
o`;oo`002Oooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00oooooooo00000_ooool0
0ooo003oooooool00002ooooo`;oo`002Oooool01ooo003oooooooooooooooooo`00oooooooo0000
0_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo0_oo0007ooooo`;oo`00
0_ooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool000Sooooo0_oo0003ooooo`03ool0
0?ooooooo`0000;ooooo0_oo0002ooooo`03ool00?ooooooo`0000;ooooo0_oo0009ooooo`04ool0
0?ooooooooooooooo`;oo`000oooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;o
oooo0_oo0006ooooo`;oo`000oooool2ool000?ooooo00?oo`00oooooooo00000_ooool2ool000?o
oooo0_oo0009ooooo`04ool00?ooooooooooooooo`;oo`000_ooool00ooo003oooooooooo`09oooo
o`03o`000?oooooooooo00gooooo000Oooooo`?o00002Oooool01_oo003ooooooooooooo003ooooo
ool000;ooooo0_oo0008ooooo`;oo`000oooool00ooo003oooooool00002ooooo`03ool00?oooooo
o`0000;ooooo00?oo`00oooooooo00000_ooool2ool000Kooooo00Goo`00oooooooo003oooooool0
0002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool00_oo0003ooooo`;oo`002?oo
ool2ool000?ooooo0_oo0002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_oo
ool2ool000Wooooo00Ooo`00ooooooooooooooooool00?ooooooo`0000;ooooo00?oo`00oooooooo
00000_ooool00ooo003oooooool00002ooooo`;oo`001_ooool00ooo003oooooool00002ooooo`03
ool00?ooooooo`0000;ooooo0_oo0003ooooo`;oo`000oooool2ool000Sooooo0_oo0003ooooo`07
ool00?ooooooo`00oooooooo003oooooool00002ooooo`;oo`000oooool2ool000Wooooo00Ooo`00
ooooooooooooooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003ooooo
ool00002ooooo`;oo`000oooool01_l0003ooooooooooooo003oooooool000;ooooo00?oo`00oooo
oooo00000_ooool2ool000?ooooo0_oo0003ooooo`;oo`002?ooool2ool000?ooooo0_oo0002oooo
o`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool2ool000Wooooo00Ooo`00oooo
ooooooooooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool0
0002ooooo`;oo`001_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?o
o`00oooooooo00000_ooool2ool000?ooooo0_oo0008ooooo`;oo`000oooool01ooo003oooooool0
0?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`;oo`002Oooool01?oo003o
ooooooooooooool2ool000?ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`;oo`001_ooool2ool000?ooooo0_oo0003ooooo`03ool00?ooooooo`0000;ooooo0_oo0003oooo
o`;oo`002Oooool01?oo003oooooooooooooool2ool000;ooooo00?oo`00ooooooooool02?ooool2
o`0000oooooo000Oooooo`03o`000?oooooooooo00Wooooo00Koo`00ooooooooooooo`00oooooooo
0002ooooo`;oo`002?ooool2ool000?ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool0
0002ooooo`03ool00?ooooooo`0000;ooooo0_oo0006ooooo`05ool00?ooooooo`00oooooooo0000
0_ooool00ooo003oooooool00002ooooo`03ool00?oooooooooo00;oo`000oooool2ool000Sooooo
0_oo0003ooooo`;oo`000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo
0_oo0008ooooo`;oo`000oooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo
00?oo`00oooooooo00000_ooool2ool000Kooooo00Goo`00oooooooo003oooooool00002ooooo`05
ool00?ooooooo`00oooooooo00000oooool2ool000?ooooo0_oo0008ooooo`;oo`000oooool01ooo
003oooooool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`;oo`002Ooo
ool01ooo003oooooooooooooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03
ool00?ooooooo`0000;ooooo0_oo0003ooooo`06o`000?ooooooooooool00?ooooooo`000_ooool0
0ooo003oooooool00002ooooo`;oo`000oooool2ool000?ooooo0_oo0008ooooo`;oo`000oooool2
ool000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`;oo`002Oooool0
1ooo003oooooooooooooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool0
0?ooooooo`0000;ooooo0_oo0006ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo0000
0_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo0_oo0008ooooo`;oo`00
0oooool01Ooo003oooooool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002oooo
o`;oo`002?ooool2ool000?ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`03ool00?ooooooo`0000;ooooo0_oo0006ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooo
oooo00000_ooool00ooo003oooooool00002ooooo`;oo`000oooool2ool000Sooooo0_oo0003oooo
o`;oo`000_ooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo000Oooooo`03
o`000?oooooooooo00Wooooo00Koo`00ooooooooooooo`00oooooooo0002ooooo`;oo`002?ooool2
ool000?ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?oooooo
o`0000;ooooo0_oo0006ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool0
0002ooooo`03ool00?oooooooooo00;oo`000oooool2ool000Sooooo0_oo0003ooooo`07ool00?oo
ooooo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo0_oo0008ooooo`;o
o`000oooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo
00000_ooool2ool000Kooooo00Goo`00oooooooo003oooooool00002ooooo`05ool00?ooooooo`00
oooooooo00000oooool2ool000?ooooo0_oo0008ooooo`;oo`000oooool01Ooo003oooooool00?oo
ooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`;oo`002Oooool01ooo003ooooo
ooooooooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`00
00;ooooo0_oo0003ooooo`06o`000?ooooooooooool00?ooooooo`000_ooool01ooo003oooooool0
0?ooooooo`00oooooooo00000oooool2ool000?ooooo0_oo0008ooooo`;oo`000oooool2ool000;o
oooo00Soo`00ooooooooooooo`00oooooooo003oooooool000;ooooo0_oo0009ooooo`07ool00?oo
oooooooooooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo
00000_ooool2ool000Kooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`00
00;ooooo00Koo`00ooooooooooooo`00oooooooo0002ooooo`;oo`002?ooool2ool000?ooooo00Go
o`00oooooooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000So
oooo0_oo0003ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003o
ooooool00002ooooo`;oo`001_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00Koo`00oooo
ooooooooo`00oooooooo0002ooooo`;oo`000oooool2ool000Sooooo0_oo0003ooooo`05ool00?oo
ooooo`00oooooooo00002oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooooooo
o`0:ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000Sooooo0_oo0003ooooo`03ool0
0?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`06ool00?ooooooooooool0
0?ooooooo`001Oooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_oo
ool00ooo003oooooooooo`02ool000?ooooo0_oo0008ooooo`03ool00?ooooooo`0000;ooooo00Oo
o`00oooooooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool2ool000So
oooo0_oo0003ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003o
ooooool00002ooooo`;oo`001_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooo
oooo00000_ooool00ooo003oooooooooo`02ool000?ooooo0_oo0008ooooo`;oo`000oooool01Ooo
003oooooool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`;oo`002Ooo
ool01ooo003oooooooooooooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03
ool00?ooooooo`0000;ooooo0_oo0003ooooo`08o`000?ooooooooooool00?ooooooo`00oooooooo
0002ooooo`05ool00?ooooooo`00oooooooo00000oooool2ool000?ooooo0_oo0008ooooo`;oo`00
0oooool01Ooo003oooooool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002oooo
o`;oo`002?ooool2ool000?ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`03ool00?ooooooo`0000;ooooo0_oo0006ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooo
oooo003oooooool00002ooooo`06ool00?ooooooooooool00?ooooooo`000_ooool2ool000Sooooo
0_oo0003ooooo`05ool00?ooooooo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`00
00;ooooo0_oo0008ooooo`;oo`000oooool00ooo003oooooool00002ooooo`03ool00?ooooooo`00
00;ooooo00?oo`00oooooooo00000_ooool2ool000Kooooo00Goo`00oooooooo003oooooool00002
ooooo`06ool00?ooooooooooool00?ooooooo`000_ooool00ooo003oooooool00002ooooo`;oo`00
2?ooool2ool000?ooooo00Goo`00oooooooo003oooooool0000;ooooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo00[ooooo00Goo`00oooooooo003oooooool00002ooooo`;o
o`002?ooool2ool000?ooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`00
00;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`03ooooo`05ool00?ooooooo`00
oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?oooooooooo00;oo`000oooool2
ool000Sooooo00?oo`00oooooooo00000_ooool01ooo003oooooool00?ooooooo`00oooooooo0000
0_ooool00ooo003oooooool00002ooooo`;oo`002?ooool2ool000?ooooo00?oo`00oooooooo0000
0_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo0000
1Oooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003o
ooooooooo`02ool000?ooooo0_oo0008ooooo`;oo`000_ooool01_oo003ooooooooooooo003ooooo
ool000;ooooo00Goo`00oooooooo003oooooool00002ooooo`;oo`002?ooool2ool000?ooooo00?o
o`00oooooooo00000_ooool00ooo003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo0_oo
0003ooooo`08o`000?ooooooooooool00?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`00
00;ooooo00?oo`00ooooooooool00_oo0003ooooo`;oo`002?ooool2ool000?ooooo00Goo`00oooo
oooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000Sooooo0_oo
0003ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool0
0002ooooo`;oo`001_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo0000
0_ooool00ooo003oooooool00002ooooo`03ool00?oooooooooo00;oo`002?ooool2ool000;ooooo
00Koo`00ooooooooooooo`00oooooooo0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2
ool000Sooooo0_oo0003ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool0
0ooo003oooooool00002ooooo`;oo`001_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?o
o`00oooooooo00000_ooool01_oo003ooooooooooooo003oooooool000;ooooo0_oo0008ooooo`;o
o`000oooool01Ooo003oooooool00?ooooooo`0000_ooooo00?o0000ooooooooool03Oooool001oo
oooo00?o0000ooooooooool02_ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0008oooo
o`;oo`000oooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000oooool2
ool000;ooooo00?oo`00ooooooooool00oooool01Ooo003oooooool00?ooooooo`0000;ooooo00?o
o`00oooooooo00000_ooool01Ooo003oooooool00?ooooooo`0000?ooooo0_oo0008ooooo`03ool0
0?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`05ool00?ooooooo`00oooo
oooo00000_ooool2ool000Sooooo0_oo0003ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooo
oooo003oooooool00002ooooo`06ool00?ooooooooooool00?ooooooo`001Oooool01Ooo003ooooo
ool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`02ool000?o
oooo0_oo0008ooooo`;oo`000_ooool01_oo003ooooooooooooo003oooooool000;ooooo00Goo`00
oooooooo003oooooool00002ooooo`;oo`002?ooool2ool000?ooooo00?oo`00oooooooo00000_oo
ool02?oo003ooooooooooooo003oooooool00?ooooooo`000_ooool00ooo003oooooool00002oooo
o`08o`000?ooooooooooool00?ooooooo`00oooooooo0002ooooo`03ool00?ooooooo`0000;ooooo
00Goo`00oooooooo003oooooool00003ooooo`;oo`002?ooool2ool000?ooooo00Goo`00oooooooo
003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000Sooooo0_oo0003
ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?oo
oooooooo00;oo`001_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo0000
0_ooool00ooo003oooooool00002ooooo`03ool00?oooooooooo00;oo`002?ooool2ool000;ooooo
00Koo`00ooooooooooooo`00oooooooo0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2
ool000Sooooo0_oo0003ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool0
0002ooooo`03ool00?oooooooooo00;oo`001_ooool01Ooo003oooooool00?ooooooo`0000;ooooo
00?oo`00oooooooo00000_ooool01_oo003ooooooooooooo003oooooool000;ooooo0_oo0008oooo
o`;oo`000oooool01Ooo003oooooool00?ooooooo`0000_ooooo00?o0000ooooooooool03Oooool0
01oooooo0ol0000:ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000Sooooo0_oo0003oooo
o`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool00_oo0003ooooo`;oo`000_ooool00ooo
003oooooooooo`03ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002
ooooo`05ool00?ooooooo`00oooooooo00000oooool2ool000Sooooo00?oo`00oooooooo00000_oo
ool01Ooo003oooooool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00002ooooo`;o
o`002?ooool2ool000?ooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`02ool000?o
oooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00Goo`00oooooooo003oooooool00002oooo
o`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00003ooooo`;oo`002?ooool2
ool000;ooooo00Koo`00ooooooooooooo`00oooooooo0002ooooo`05ool00?ooooooo`00oooooooo
00000_ooool2ool000Sooooo0_oo0003ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo
ool00_oo0003ooooo`;oo`000_ooool01?oo003oooooooooool00002ooooo`05ool00?ooooooo`00
oooooooo00000_ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000ooo
ool2ool000Sooooo0_oo0003ooooo`05ool00?ooooooo`00oooooooo00000_ooool01Ooo003ooooo
ool00?ooooooo`0000;ooooo0_oo0008ooooo`;oo`000oooool00ooo003oooooool00002ooooo`03
ool00?oooooooooo00;oo`000oooool2ool000;ooooo00?oo`00ooooooooool00oooool01Ooo003o
ooooool00?ooooooo`0000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002oooo
o`03ool00?oooooooooo00;oo`002?ooool2ool000;ooooo00Koo`00ooooooooooooo`00oooooooo
0002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000Sooooo0_oo0003ooooo`05ool0
0?ooooooo`00oooooooo00000oooool2ool000?ooooo0_oo00000oooooooo`00ooooo`05ooooo`05
ool00?ooooooo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`06ool00?oooooooooo
ool00?ooooooo`000_ooool2ool000Sooooo0_oo0003ooooo`05ool00?ooooooo`00oooooooo0000
2_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00[ooooo0_oo0002ooooo`06ool00?oo
ooooooooool00?ooooooo`001oooool2ool000?ooooo00?oo`00oooooooo00000_ooool00ooo003o
ooooooooo`02ool000?ooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00Goo`00oooooooo
003oooooool00002ooooo`03ool00?ooooooo`0000;ooooo00Goo`00oooooooo003oooooool00003
ooooo`;oo`002?ooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_oo
ool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0008ooooo`03ool00?ooooooo`0000;ooooo
00?oo`00oooooooo00000_ooool00ooo003oooooooooo`02ool000?ooooo0_oo0002ooooo`03ool0
0?oooooooooo00?ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;o
oooo00Goo`00oooooooo003oooooool00003ooooo`;oo`002?ooool2ool000;ooooo00Koo`00oooo
ooooooooo`00oooooooo0002ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000Sooooo0_oo
0003ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool00_oo0003ooooo`;oo`000_oo
ool01?oo003oooooooooool00002ooooo`05ool00?ooooooo`00oooooooo00000oooool2ool000;o
oooo00Goo`00oooooooo003oooooool00003ooooo`;oo`002?ooool2ool000?ooooo00Goo`00oooo
oooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000Sooooo0_oo
0003ooooo`05ool00?ooooooo`00oooooooo00000oooool2ool000?ooooo0_oo0002ooooo`03ool0
0?oooooooooo00?ooooo00Goo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000;o
oooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`02ool000Sooooo0_oo0002ooooo`06
ool00?ooooooooooool00?ooooooo`000_ooool2ool000;ooooo00?oo`00ooooooooool00_oo0008
ooooo`;oo`000oooool01Ooo003oooooool00?ooooooo`0000?ooooo0_oo0003ooooo`;oo`0000?o
ooooool00?ooool01Oooool01Ooo003oooooool00?ooooooo`0000?ooooo0_oo0002ooooo`03ool0
0?ooooooo`0000;ooooo00?oo`00ooooooooool00_oo0008ooooo`;oo`000_ooool01_oo003ooooo
oooooooo003oooooool000_ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooooooo
ool02_ooool2ool000;ooooo00Koo`00ooooooooooooo`00oooooooo0007ooooo`;oo`000oooool0
1Ooo003oooooool00?ooooooo`0000?ooooo0_oo0003ooooo`;oo`000_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00;oo`000oooool01ooo003oooooooooooooooooo`00oooooooo
00000_ooool00ooo003oooooooooo`02ool000Sooooo00?oo`00oooooooo00000_ooool01?oo003o
ooooool00?oo0003ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000Sooooo00?oo`00oooo
oooo00000_ooool01Ooo003oooooool00?ooooooo`0000?ooooo0_oo0003ooooo`;oo`000_ooool0
0ooo003oooooooooo`03ooooo`03ool00?ooooooo`0000;oo`000oooool2ool000;ooooo00?oo`00
oooooooo00000_ooool00ooo003oooooooooo`02ool000Sooooo00Goo`00oooooooo003oooooool0
0002ooooo`;oo`000oooool2ool000;ooooo00?oo`00ooooooooool00_oo0008ooooo`;oo`000ooo
ool01Ooo003oooooool00?ooooooo`0000?ooooo0_oo0003ooooo`;oo`000_ooool01?oo003ooooo
ooooool00002ooooo`03ool00?ooooooo`0000;oo`000oooool2ool000;ooooo00?oo`00oooooooo
00000_ooool00ooo003oooooooooo`02ool000Sooooo0_oo0003ooooo`04ool00?ooooooo`00ool0
00?ooooo0_oo0002ooooo`03ool00?oooooooooo00;oo`002?ooool2ool000?ooooo00Goo`00oooo
oooo003oooooool00003ooooo`;oo`000oooool2ool000;ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`02ool000?ooooo0_oo0002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00
ooooooooool00_oo0008ooooo`;oo`000_ooool01_oo003ooooooooooooo003oooooool000;ooooo
0_oo0002ooooo`03ool00?oooooooooo00;oo`002?ooool2ool000?ooooo00Goo`00oooooooo003o
ooooool00003ooooo`;oo`000oooool2ool00003oooooooo003ooooo00Gooooo00?oo`00oooooooo
ool00_oo0003ooooo`;oo`000_ooool00ooo003oooooool00002ooooo`03ool00?oooooooooo00;o
o`002?ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo000<ooooo`03o`000?oooooooooo
00gooooo000Oooooo`03o`000?oooooooooo00[ooooo0_oo0002ooooo`06ool00?ooooooooooool0
0?ooooooo`001oooool00ooo003oooooool00002ooooo`05ool00?ooooooo`00oooooooo00000ooo
ool2ool000?ooooo0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
0003ooooo`07ool00?oooooooooooooooooo003oooooool00002ooooo`03ool00?oooooooooo00;o
o`002?ooool01Ooo003oooooool00?ooooooo`0000;ooooo0_oo0003ooooo`;oo`000_ooool00ooo
003oooooooooo`02ool000Sooooo00?oo`00oooooooo00000_ooool01Ooo003oooooool00?oooooo
o`0000?ooooo0_oo0003ooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`04ool00?oooooo
ooooool000Cooooo00Ooo`00ooooooooooooooooool00?ooooooo`0000;ooooo00?oo`00oooooooo
ool00_oo0008ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000?ooooo0_oo0003oooo
o`04ool00?ooooooo`00ool000Sooooo0_oo0003ooooo`05ool00?ooooooo`00oooooooo00000ooo
ool2ool000?ooooo0_oo0002ooooo`04ool00?ooooooooooo`0000;ooooo00Coo`00oooooooooooo
o`001?ooool01ooo003oooooooooooooooooo`00oooooooo00000_ooool00ooo003oooooooooo`02
ool000Sooooo00Goo`00oooooooo003oooooool00003ooooo`04ool00?ooooooooooooooo`;oo`00
0_ooool00ooo003oooooooooo`02ool000Sooooo00?oo`00oooooooo00000_ooool00ooo003ooooo
ooooo`02ool000?ooooo0_oo0003ooooo`;oo`000_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00;oo`000oooool01ooo003oooooooooooooooooo`00oooooooo00000_ooool00ooo
003oooooooooo`02ool000Sooooo00Goo`00oooooooo003oooooool00003ooooo`04ool00?oooooo
ooooooooo`;oo`000_ooool00ooo003oooooooooo`02ool000Sooooo00?oo`00oooooooo00000_oo
ool00ooo003oooooooooo`02ool000?ooooo0_oo0003ooooo`;oo`0000?oooooool00?ooool01Ooo
ool00ooo003oooooooooo`02ool000?ooooo00Ooo`00ooooooooooooooooool00?ooooooo`0000;o
oooo00?oo`00ooooooooool00_oo0008ooooo`05ool00?ooooooo`00oooooooo00000oooool00ooo
003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00ko
oooo00Koo`00ooooooooooooo`00oooooooo0007ooooo`03ool00?ooooooo`0000;ooooo00?oo`00
ooooooooool00_oo000<ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02Oooool0
0ooo003oooooool00002ooooo`03ool00?oooooooooo00;oo`002?ooool01Ooo003oooooool00?oo
ooooo`0000_ooooo00?oo`00ooooooooool00_oo0008ooooo`03ool00?ooooooo`0000;ooooo00?o
o`00ooooooooool00_oo000<ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02Ooo
ool00ooo003oooooool00002ooooo`03ool00?oooooooooo00;oo`002?ooool01Ooo003oooooool0
0?ooooooo`0000cooooo00Coo`00oooooooo003oo`002?ooool2ool000?ooooo00?oo`00oooooooo
ool00_oo000<ooooo`04ool00?ooooooooooo`0000;ooooo00?oo`00ooooooooool02_ooool2ool0
00;ooooo00?oo`00ooooooooool00_oo0008ooooo`05ool00?ooooooo`00oooooooo00003?ooool0
1?oo003oooooool00?oo0008ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool00_oo
000<ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool2ool000;ooooo00?o
o`00ooooooooool00_oo0008ooooo`05ool00?ooooooo`00oooooooo00002oooool00ooo003ooooo
ooooo`02ool000Sooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`02ool000_ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0:ooooo`;oo`000_ooool00ooo003ooooo
ooooo`02ool000Sooooo00Goo`00oooooooo003oooooool0000@ooooo`03o`000?oooooooooo00go
oooo000Oooooo`?o00003_ooool01_oo003ooooooooooooo003oooooool000Oooooo00?oo`00oooo
oooo00000_ooool00ooo003oooooooooo`02ool000cooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0:ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000Sooooo00Goo`00oooo
oooo003oooooool0000;ooooo`03ool00?oooooooooo00;oo`002?ooool01Ooo003oooooool00?oo
ooooo`0000?ooooo0_oo000<ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02_oo
ool2ool000;ooooo00?oo`00ooooooooool00_oo0008ooooo`05ool00?ooooooo`00oooooooo0000
3?ooool01?oo003oooooool00?oo0008ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo
ool00_oo000<ooooo`04ool00?ooooooooooo`0000;ooooo00?oo`00ooooooooool02_ooool2ool0
00;ooooo00?oo`00ooooooooool00_oo0008ooooo`05ool00?ooooooo`00oooooooo00003?ooool0
1?oo003oooooool00?oo0008ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool00_oo
000<ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool2ool000;ooooo00?o
o`00ooooooooool00_oo0008ooooo`05ool00?ooooooo`00oooooooo00002oooool00ooo003ooooo
ooooo`02ool000Sooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`02ool000_ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0:ooooo`;oo`000_ooool01_oo003ooooo
oooooooo003oooooool000Oooooo00Goo`00oooooooo003oooooool0000?ooooo`;o00003oooool0
01oooooo00?o0000ooooooooool03oooool01Ooo003oooooool00?ooooooo`0000Oooooo00?oo`00
oooooooo00000_ooool00ooo003oooooooooo`02ool000cooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0:ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000Sooooo00Goo`00
oooooooo003oooooool0000<ooooo`04ool00?ooooooo`00ool000Sooooo00Goo`00oooooooo003o
ooooool00003ooooo`;oo`003?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00[o
oooo0_oo0002ooooo`03ool00?oooooooooo00;oo`002?ooool01Ooo003oooooool00?ooooooo`00
00cooooo00Coo`00oooooooo003oo`002?ooool00ooo003oooooool00002ooooo`03ool00?oooooo
oooo00;oo`003?ooool01?oo003oooooooooool00002ooooo`03ool00?oooooooooo00[ooooo0_oo
0002ooooo`03ool00?oooooooooo00;oo`002?ooool01Ooo003oooooool00?ooooooo`0000cooooo
00Coo`00oooooooo003oo`002?ooool01Ooo003oooooool00?ooooooo`0000?ooooo0_oo000<oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool2ool000;ooooo00?oo`00oooo
ooooool00_oo0008ooooo`05ool00?ooooooo`00oooooooo00002oooool01_oo003ooooooooooooo
003oooooool000Oooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`02ool000cooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0:ooooo`;oo`000_ooool01_oo003ooooo
oooooooo003oooooool000Oooooo00Goo`00oooooooo003oooooool0000@ooooo`03o`000?oooooo
oooo00gooooo000Oooooo`03o`000?oooooooooo00oooooo00Goo`00oooooooo003oooooool00007
ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`003Oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`00
2?ooool01Ooo003oooooool00?ooooooo`0000cooooo00Coo`00oooooooo003oo`002?ooool01Ooo
003oooooool00?ooooooo`0000?ooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00[ooooo00Goo`00ooooooooooooooooool00002ooooo`;oo`002?oo
ool01Ooo003oooooool00?ooooooo`0000cooooo00Coo`00oooooooo003oo`002?ooool00ooo003o
ooooool00002ooooo`04ool00?ooooooooooool000gooooo00Coo`00oooooooooooo00000_ooool0
0ooo003oooooooooo`0:ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000Sooooo00Go
o`00oooooooo003oooooool0000<ooooo`04ool00?ooooooo`00ool000Sooooo00Goo`00oooooooo
003oooooool00003ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`0;ooooo`05ool00?oooooooooooooooooo00000_ooool2ool000Sooooo00Goo`00
oooooooo003oooooool0000<ooooo`05ool00?ooooooo`00oooooooo00001oooool00ooo003ooooo
ool00002ooooo`04ool00?ooooooooooool000gooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0:ooooo`05ool00?oooooooooooooooooo00000_ooool00ooo003oooooool00007oooo
o`05ool00?ooooooo`00oooooooo00004?ooool00ol0003oooooooooo`0=ooooo`003oooool3o`00
00Cooooo0_l00007ooooo`03o`000?oooooooooo00oooooo0_oo0002ooooo`03ool00?oooooooooo
00Gooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`02ool000Sooooo00Goo`00oooo
oooo003oooooool0000<ooooo`04ool00?ooooooo`00ool000Sooooo00Goo`00oooooooo003ooooo
ool0000Aooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03_ooool00ooo003ooooo
ooooo`02ool000Sooooo00Goo`00oooooooo003oooooool0000<ooooo`;oo`0000?oooooool00?oo
ool01oooool00ooo003oooooool00002ooooo`03ool00?oooooooooo00kooooo00Coo`00oooooooo
oooo00000_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00;oo`002?ooool01Ooo
003oooooool00?ooooooo`0000cooooo00Coo`00oooooooo003oo`002?ooool01Ooo003oooooool0
0?ooooooo`00017ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0?ooooo`03ool0
0?oooooooooo00;oo`002?ooool01Ooo003oooooool00?ooooooo`0000cooooo00Goo`00oooooooo
003oooooool00007ooooo`05ool00?ooooooo`00oooooooo00004Oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00kooooo00Koo`00ooooooooooooo`00oooooooo0007ooooo`05ool0
0?ooooooo`00oooooooo00004?ooool00ol0003oooooooooo`0=ooooo`004?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool03oooool2ool000;o
oooo00?oo`00ooooooooool01Oooool00ooo003oooooool00002ooooo`03ool00?oooooooooo00ko
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00;o
o`002?ooool01Ooo003oooooool00?ooooooo`0000cooooo00Coo`00oooooooo003oo`002?ooool0
1Ooo003oooooool00?ooooooo`00017ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`0>ooooo`03ool00?oooooooooo00;oo`002?ooool01Ooo003oooooool00?ooooooo`0000cooooo
0_oo00000oooooooo`00ooooo`07ooooo`05ool00?ooooooo`00oooooooo00004Oooool01?oo003o
ooooooooool00002ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool00_oo0008oooo
o`05ool00?ooooooo`00oooooooo00003?ooool2ool00003oooooooo003ooooo00Oooooo00Goo`00
oooooooo003oooooool0000Aooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03ooo
ool00ooo003oooooooooo`02ool000Sooooo00Goo`00oooooooo003oooooool0000<ooooo`05ool0
0?ooooooo`00oooooooo00001oooool01Ooo003oooooool00?ooooooo`00017ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0>ooooo`06ool00?ooooooooooool00?ooooooo`001ooo
ool01Ooo003oooooool00?ooooooo`00013ooooo00?o0000ooooooooool03Oooool0013ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00oooooo
0_oo0002ooooo`03ool00?oooooooooo00Gooooo00Goo`00oooooooo003oooooool0000Aooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`02ool000So
oooo00Goo`00oooooooo003oooooool0000<ooooo`;oo`0000?oooooool00?ooool01oooool01Ooo
003oooooool00?ooooooo`00017ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0?
ooooo`04ool00?ooooooo`00ool000Sooooo00Goo`00oooooooo003oooooool0000<ooooo`;oo`00
00?oooooool00?ooool01oooool01Ooo003oooooool00?ooooooo`00017ooooo00Coo`00oooooooo
oooo00000_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00;oo`002?ooool01Ooo
003oooooool00?ooooooo`0000cooooo0_oo00000oooooooo`00ooooo`07ooooo`05ool00?oooooo
o`00oooooooo00004Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00oooooo00?o
o`00ooooooooool00_oo0008ooooo`05ool00?ooooooo`00oooooooo00003?ooool2ool000;ooooo
00?oo`00ooooooooool01Oooool01Ooo003oooooool00?ooooooo`00017ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`0>ooooo`06ool00?ooooooooooool00?ooooooo`001oooool0
1Ooo003oooooool00?ooooooo`00013ooooo00?o0000ooooooooool03Oooool0013ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00006ooooo`Co00003_ooool2ool000;ooooo00?o
o`00ooooooooool01Oooool01Ooo003oooooool00?ooooooo`00017ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00;oo`002?ooool01?oo003ooooo
ool00?oo000=ooooo`;oo`0000?oooooool00?ooool01oooool01Ooo003oooooool00?ooooooo`00
017ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0@ooooo`04ool00?ooooooo`00
ool000Sooooo00Goo`00oooooooo003oooooool0000<ooooo`;oo`000_ooool00ooo003ooooooooo
o`05ooooo`05ool00?ooooooo`00oooooooo00004Oooool01?oo003oooooooooool00002ooooo`03
ool00?oooooooooo00kooooo00Goo`00oooooooo003oooooool00008ooooo`04ool00?ooooooo`00
ool000gooooo0_oo00000oooooooo`00ooooo`07ooooo`05ool00?ooooooo`00oooooooo00004Ooo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool00_oo
0008ooooo`05ool00?ooooooo`00oooooooo00003?ooool2ool000;ooooo00?oo`00ooooooooool0
1Oooool01Ooo003oooooool00?ooooooo`00017ooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0>ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool01Oooool01Ooo003o
ooooool00?ooooooo`0000gooooo1?l0000?ooooo`004?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool03oooool2ool000;ooooo00?oo`00oooo
ooooool01Oooool01Ooo003oooooool00?ooooooo`00017ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`0?ooooo`05ool00?ooooooo`00oooooooo00002?ooool01?oo003oooooool0
0?oo000=ooooo`;oo`0000?oooooool00?ooool01oooool01Ooo003oooooool00?ooooooo`00017o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0@ooooo`;oo`0000?oooooool00?oo
ool01oooool01?oo003oooooool00?oo000=ooooo`;oo`000_ooool00ooo003oooooooooo`05oooo
o`05ool00?ooooooo`00oooooooo00004Oooool01?oo003oooooooooool00002ooooo`03ool00?oo
oooooooo00oooooo0_oo00000oooooooo`00ooooo`07ooooo`04ool00?ooooooo`00ool000gooooo
0_oo00000oooooooo`00ooooo`07ooooo`05ool00?ooooooo`00oooooooo00004Oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00oooooo00Goo`00oooooooo003oooooool00008oooo
o`04ool00?ooooooo`00ool000gooooo0_oo0002ooooo`03ool00?oooooooooo00Gooooo00Goo`00
oooooooo003oooooool0000Aooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03ooo
ool2ool000;ooooo00?oo`00ooooooooool01Oooool01?oo003oooooool00?oo000Aooooo`03o`00
0?oooooooooo00gooooo000?ooooo`;o00001?ooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo00oooooo0_oo0002ooooo`03ool00?oooooooooo00Gooooo00Goo`00oooooooo003o
ooooool0000Booooo`05ool00?oooooooooooooooooo00004Oooool00ooo003oooooool00002oooo
o`03ool00?oooooooooo00Gooooo00Coo`00oooooooo003oo`003Oooool2ool00003oooooooo003o
oooo00Oooooo00Goo`00oooooooo003oooooool0000Aooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool04?ooool2ool00003oooooooo003ooooo00Oooooo00Coo`00oooooooo003oo`00
3Oooool2ool000;ooooo00?oo`00ooooooooool01Oooool01Ooo003oooooool00?ooooooo`00017o
oooo00Coo`00oooooooooooo00000_ooool00ooo003oooooooooo`0?ooooo`;oo`0000?oooooool0
0?ooool01oooool01?oo003ooooooooooooo000=ooooo`;oo`0000?oooooool00?ooool01oooool0
1Ooo003oooooool00?ooooooo`00017ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0@ooooo`;oo`0000?oooooool00?ooool01oooool01?oo003ooooooooooooo000=ooooo`;oo`00
0_ooool00ooo003oooooooooo`05ooooo`05ool00?ooooooo`00oooooooo00004Oooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00oooooo0_oo0002ooooo`03ool00?oooooooooo00Go
oooo00Coo`00ooooooooooooo`004Oooool00ol0003oooooooooo`0=ooooo`004?ooool00ol0003o
ooooooooo`03ooooo`;o00001oooool00ol0003oooooooooo`0@ooooo`04ool00?ooooooooooool0
00Oooooo00Goo`00oooooooo003oooooool0000Booooo`05ool00?oooooooooooooooooo00004Ooo
ool00ooo003oooooool00002ooooo`03ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`00
3_ooool00ooo003oooooool00008ooooo`05ool00?ooooooo`00oooooooo00004_ooool01Ooo003o
ooooooooooooooooo`0001;ooooo0_oo00000oooooooo`00ooooo`07ooooo`03ool00?oooooooooo
00oooooo00Coo`00ooooooooooooo`001oooool01Ooo003oooooool00?ooooooo`00017ooooo00Ko
o`00oooooooooooo0000oooooooo000Booooo`;oo`0000?oooooool00?ooool01oooool00ooo003o
ooooooooo`0Aooooo`03ool00?oooooooooo00Kooooo00Goo`00oooooooo003oooooool0000Aoooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04?ooool2ool00003oooooooo003ooooo
00Oooooo00Coo`00ooooooooooooo`004Oooool00ooo003oooooooooo`05ooooo`05ool00?oooooo
o`00oooooooo00004Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo013ooooo0_oo
0002ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool04_ooool00ol0003ooooooooo
o`0=ooooo`007oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo00Goo`00
oooooooo003oooooool0000Booooo`05ool00?oooooooooooooooooo00004_ooool2ool000;ooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00Kooooo
00Goo`00oooooooo003oooooool0000Booooo`05ool00?oooooooooooooooooo00004_ooool2ool0
0003oooooooo003ooooo00Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`05oooo
o`05ool00?ooooooo`00oooooooo00004Oooool01_oo003oooooooooool0003oooooool001;ooooo
0_oo00000oooooooo`00ooooo`07ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0
1Oooool01Ooo003oooooool00?ooooooo`00017ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0@ooooo`;oo`0000?oooooool00?ooool01oooool00ooo003oooooooooo`0Booooo`03
ool00?oooooooooo00Gooooo00Goo`00oooooooo003oooooool0000Aooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool04?ooool2ool000;ooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo000Oooooo`?o00004oooool00ooo003o
ooooooooo`05ooooo`05ool00?ooooooo`00oooooooo00004_ooool01Ooo003ooooooooooooooooo
o`0001;ooooo0_oo0002ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool04Oooool0
0ooo003oooooooooo`06ooooo`05ool00?ooooooo`00oooooooo00004_ooool01Ooo003ooooooooo
ooooooooo`0001;ooooo0_oo00000oooooooo`00ooooo`07ooooo`03ool00?oooooooooo01;ooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ool0017ooooo00Koo`00oooooooooooo
0000oooooooo000Booooo`;oo`000_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
01;ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`02ool0017ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0@ooooo`;oo`0000?oooooool00?ooool01oooool00ooo
003oooooooooo`0Booooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_oo000Aoooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04?ooool2ool000;ooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`0Aooooo`;o00003oooool001oooooo00?o0000oooooooo
ool04oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;oo`004_ooool01Ooo003o
ooooooooooooooooo`0001;ooooo0_oo0002ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool04Oooool00ooo003oooooooooo`06ooooo`04ool00?ooooooooooool001?ooooo00Goo`00
ooooooooooooooooool0000Booooo`;oo`0000?oooooool00?ooool01oooool00ooo003ooooooooo
o`0Booooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_oo000Aooooo`06ool00?oo
ooooooooo`000?ooooooo`004_ooool2ool000;ooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`0Booooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00_oo000Aooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool04?ooool2ool00003oooooooo003ooooo00Oo
oooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00;o
o`004Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo013ooooo0_oo0002ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`00
7oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo00Coo`00oooooooooooo
o`004oooool01Ooo003oooooooooooooooooo`0001;ooooo0_oo0002ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`06ooooo`04ool00?oooooooooo
ool001?ooooo00Goo`00ooooooooooooooooool0000Booooo`;oo`0000?oooooool00?ooool01ooo
ool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`00
4_ooool01_oo003oooooooooool0003oooooool001;ooooo0_oo0002ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`05ooooo`04ool00?oooooooooo
ool001;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0@ooooo`;oo`000_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool01Oooool0
1?oo003ooooooooooooo000Booooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04?oo
ool2ool000;ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Booooo`03o`000?oo
oooooooo00gooooo000Oooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`0Dooooo`05ool00?oooooooooooooooooo00005_ooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`0Dooooo`05ool00?oooooooooooooooooo00005Oooool00ooo003oooooooooo`06ooooo`03ool0
0?oooooooooo01;ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Cooooo`06ool0
0?ooooooooooo`000?ooooooo`005_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
01?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
01;ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
01;ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool04oooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo01Cooooo00Goo`00ooooooooooooooooool0000Foooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo01Cooooo00Goo`00ooooooooooooooooool0000Eooooo`03ool00?oooooo
oooo00Kooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo01?ooooo00Koo`00oooooooooooo0000oooooooo000Fooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool04oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01?ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool04_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01?ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooooooo
o`0Cooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool05?ooool01Ooo003ooooooooo
ooooooooo`0001Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Cooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool05?ooool01Ooo003oooooooooooooooooo`0001Go
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool04oooool01_oo003oooooooooool0003oooooool001Kooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool04oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Cooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool04oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Cooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo000Ooooo
o`?o00004oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Cooooo00Goo`00oooo
ooooooooooooool0000Fooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04oooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Cooooo00Goo`00ooooooooooooooooool0
000Eooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool04_ooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo01Cooooo00Goo`00ooooool0003oooooool0000Fooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo01Cooooo00Goo`00ooooooooooooooooool0000Fooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool04Oooool2o`0000oooooo000Oooooo`03o`000?oooooooooo01?ooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Dooooo`05ool00?oooooooooooooooooo
00005_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`0Dooooo`05ool00?oooooooooooooooooo00005Oooool00ooo
003oooooooooo`06ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`0Dooooo`05ool00?oooooo0000oooooooo00005_ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0D
ooooo`05ool00?oooooooooooooooooo00005_ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo01;ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Dooooo`05ool00?oo
oooooooooooooooo00005_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01;ooooo
00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool04oooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo01Cooooo00Goo`00ooooooooooooooooool0000Fooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo01Cooooo00Goo`00ooooooooooooooooool0000Eooooo`03ool00?oooooooooo00Ko
oooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Co
oooo00Goo`00ooooool0003oooooool0000Fooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool04oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Cooooo00Goo`00oooo
ooooooooooooool0000Fooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool04_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Cooooo00Goo`00ooooooooooooooooool0
000Fooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool04_ooool00ol0003ooooooooo
o`0=ooooo`007oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool05?ooool01Ooo003oooooooooooooooooo`0001Kooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool05?oo
ool01Ooo003oooooooooooooooooo`0001Kooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`0Booooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool05?ooool01Ooo003ooooo
o`000?ooooooo`0001Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Cooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool05?ooool01Ooo003oooooooooooooooooo`00
01Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool05?ooool01Ooo003oooooooooooooooooo`0001Kooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo000Ooooo
o`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Doooo
o`04ool00?ooooooooooool001Oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0C
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool05?ooool01?oo003ooooooooooooo
000Gooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool04_ooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo01Cooooo00Goo`00ooooool0003oooooool0000Fooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo01Cooooo00Coo`00ooooooooooooo`005oooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo01;ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Dooooo`05
ool00?oooooooooooooooooo00005_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
01;ooooo00?o0000ooooooooool03Oooool001oooooo0ol0000Cooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool05?ooool01?oo003ooooooooooooo000Gooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
01Cooooo00Coo`00ooooooooooooo`005oooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo01;ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Dooooo`05ool00?oooooo
0000oooooooo00005_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`0Dooooo`04ool00?ooooooooooool001Oooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool05?ooool01Ooo003oooooooooooooooooo`0001Kooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`0Booooo`;o00003oooool001oooooo00?o0000ooooooooool0
4oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Cooooo00Coo`00oooooooooooo
o`005oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`0Dooooo`04ool00?ooooooooooool001Oooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool05?ooool01Ooo003oooooo`000?ooooooo`0001Kooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool05?ooool0
1?oo003ooooooooooooo000Gooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool04_oo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Cooooo00Goo`00oooooooooooooooo
ool0000Fooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ol0003ooooo
ooooo`0=ooooo`007oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool05?ooool01?oo003ooooooooooooo000Gooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool04oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Cooooo
00Coo`00ooooooooooooo`005oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01;o
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Dooooo`05ool00?oooooo0000oooo
oooo00005_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`0Dooooo`04ool00?ooooooooooool001Oooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool05?ooool01?oo003ooooooooooooo000Gooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool04oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0C
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool05?ooool01?oo003ooooooooooooo
000Gooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo01Cooooo00Coo`00ooooooooooooo`005oooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`0Dooooo`05ool00?oooooo0000oooooooo00005_ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo01?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Dooooo`04
ool00?ooooooooooool001Oooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Boooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool05?ooool01?oo003ooooooooooooo000G
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool05?ooool01?oo003ooooooooooooo000Gooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool04oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Gooooo00Coo`00
ooooooooooooo`005oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01;ooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`0Dooooo`05ool00?oooooo0000oooooooo0000
5_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`0Dooooo`04ool00?ooooooooooool001Oooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool05?ooool01?oo003ooooooooooooo000Gooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool04oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Cooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool05?ooool01?oo003ooooooooooooo000Goooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo01Gooooo00Coo`00ooooooooooooo`005oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0D
ooooo`05ool00?oooooo0000oooooooo00005_ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo01?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Eooooo`04ool00?oo
ooooooooool001Oooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Booooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool05Oooool01?oo003ooooooooooooo000Gooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`0=ooooo`00
7oooool3o`0001?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Dooooo`04ool0
0?ooooooooooool001Oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Cooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool05Oooool01?oo003ooooooooooooo000Goooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo01Cooooo00Coo`00ooooool0003oo`005oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0E
ooooo`04ool00?ooooooooooool001Oooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`0Booooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool05Oooool01?oo003ooooooooo
oooo000Gooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04_ooool2o`0000oooooo
000Oooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`0Dooooo`04ool00?ooooooooooool001Oooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`0Cooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool05Oooool01?oo003ooooo
oooooooo000Gooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo01Cooooo00Coo`00ooooool0003oo`005oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0Eooooo`04ool00?ooooooooooool001Oooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`0Booooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool05Oooool0
1?oo003ooooooooooooo000Gooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04ooo
ool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool05Oooool00ooo003oooooool0000Gooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo01Kooooo00?oo`00oooooooo00005oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo01?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Dooooo`04ool00?oooooo
0000ool001Oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Cooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool05Oooool01?oo003ooooooooooooo000Gooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo01Kooooo00?oo`00oooooooo00005oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo01?ooooo00?o0000ooooooooool03Oooool000kooooo1Ol00003ooooo`;o00001ooo
ool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool05Ooo
ool00ooo003oooooool0000Gooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Kooooo00?oo`00oooooooo00005ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`0Dooooo`04ool00?oooooo0000ool001Oooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
5Oooool01?oo003ooooooooooooo000Gooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool04oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Kooooo00?oo`00oooooooo
00005oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?o0000oooooooo
ool03Oooool000oooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Eoooo
o`03ool00?ooooooo`0001Oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Coooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool05_ooool00ooo003oooooool0000Goooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo01Gooooo00?oo`00o`000?oo00005oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Foooo
o`03ool00?ooooooo`0001Oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Coooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool05_ooool00ooo003oooooool0000Hoooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`0=oooo
o`004?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool04oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
oooo00005oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`0Fooooo`03ool00?ooooooo`0001Oooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool05Oooool00ooo003o0000ool0000Gooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool04oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Kooooo00?oo`00oooo
oooo00005oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`0Fooooo`03ool00?ooooooo`0001Sooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo000Aooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`Co00004_ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo01Gooooo00?oo`00oooooooo00005oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0Fooooo`03ool00?ooooooo`0001Oooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool05Oooool00ooo
003o0000ool0000Gooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo01Kooooo00?oo`00oooooooo00005oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0Fooooo`03ool00?ooooooo`0001Sooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0@ooooo`Co00003oooool000kooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo01Gooooo00?oo`00oooooooo00005oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0F
ooooo`03ool00?ooooooo`0001Oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0C
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool05Oooool00ooo003o0000ool0000G
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo01Kooooo00?oo`00oooooooo00005oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0F
ooooo`03ool00?ooooooo`0001Sooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0C
ooooo`03o`000?oooooooooo00gooooo000>ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`0Eooooo`03ool00?ooooooo`0001Oooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool05_oo
ool00ooo003oooooool0000Gooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool04ooo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01Gooooo00?oo`00o`000?oo00005ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`0Fooooo`03ool00?ooooooo`0001Oooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05_oo
ool00ooo003oooooool0000Hooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04ooo
ool00ol0003oooooooooo`0=ooooo`003oooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooo
oooo01?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Eooooo`;oo`006?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0Fooooo`;oo`006?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo01?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Eooooo`03ool00?l0003o
o`0001Oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool05_ooool2ool001Sooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05_ooool2
ool001Wooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Cooooo`03o`000?oooooo
oooo00gooooo000Oooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0Fooooo`;oo`006?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
01?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Fooooo`;oo`006?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`0Eooooo`;oo`006?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Fooooo`;oo`006?ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0Fooooo`;oo`006Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
01?ooooo00?o0000ooooooooool03Oooool001oooooo0ol0000Cooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool05_ooool2ool001Sooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`0Cooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool05_ooool2ool001So
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Oo
oooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Co
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo01Oo
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Booooo`;o00003oooool001oooooo
00?o0000ooooooooool04oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo033ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool0<?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool0<?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Cooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool04oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooooooo
o`0Cooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0<?ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0`ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool05?ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05_ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`0`ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool05?ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`0Cooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01?ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool04oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo033ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo033ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool0<Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01?ooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo037ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Coooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0<?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Goooo
o`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Doooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0<?ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0aoooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool0<Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01?ooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`0`ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?o0000oooooooo
ool05oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Cooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`0`ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo000Oooooo`?o0000
4oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
<?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
<?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
4_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo033ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool05Ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0<Ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01?ooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo037ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool0<?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooo
oooo01Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0aooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0
003oooooooooo`0Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0<Oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0`ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool05?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0aooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Co
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo033o
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo037o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01?o
oooo00?o0000ooooooooool03Oooool001oooooo0ol0000Dooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0`ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo
00?o0000ooooooooool05oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Booooo`;o00003oooool001oooooo00?o
0000ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool0<?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool0<Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0D
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0`
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0a
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0D
ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Cooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo033ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool05oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool0<Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Cooooo00?o0000oooo
ooooool03Oooool001oooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo037ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Eooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool0<?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03
o`000?oooooooooo01Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Eooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0aooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`00
7oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
<Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`0`ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
5?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool0
5oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
5?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo000Oooooo`?o00005?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0<?oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0<Ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04ooo
ool2o`0000oooooo000Oooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0aooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool05Oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo033ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05oooool0
0ol0003oooooooooo`0Gooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool05Oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0Dooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0<_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool03Oooool0
01oooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
037ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool0<?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo
01Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
01Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0booooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`003oooool3o`0000Co
oooo0_l00007ooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0aooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool05Oooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo033ooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05oooool00ol0003o
ooooooooo`0Gooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool05Oooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0Dooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0<_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool03Oooool000kooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool0<?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool0<Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0booooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool05?ooool00ol0003oooooooooo`0=ooooo`004_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00Cooooo1?l0000Cooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool0<Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?o0000oooo
ooooool05oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool05?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0Aooooo`Co00003oooool0013ooooo0_l00003ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo037ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Goooo
o`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Eoooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0boooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`0=oooo
o`004_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool0<Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool0<Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0booooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool05?ooool00ol0003oooooooooo`0=ooooo`003_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Dooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo01Gooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0aooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo01Oooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo01Kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0aooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo03;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooo
oooo00gooooo000?ooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool05?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0<Oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`0Fooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0<Oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`0booooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool05?ooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Go
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Oo
oooo00?o0000ooooooooool05oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Ko
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool05Oooool01Ooo003oooooooooooooooooo`0003Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo000Oooooo`?o
00005?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool0<Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0Fooooo`05ool00?oooooooooooooooooo0000=?ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo01Gooooo00Goo`00ooooooooooooooooool0000d
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04oooool2o`0000oooooo000Ooooo
o`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0aoooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool05_ooool01Ooo003ooooooooooooooooo
o`0003Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool05_ooool01Ooo003oooooooooooooooooo`0003Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo0000
=?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool0
3Oooool001oooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo037ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Fooooo`05ool00?oo
oooooooooooooooo0000=?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Fooooo`05ool00?oooooooooooooooooo
0000=?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Gooooo00Goo`00oooooooo
ooooooooool0000dooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool05?ooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool0<Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Ko
oooo00Goo`00ooooooooooooooooool0000dooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?o0000oooo
ooooool05oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Kooooo00Goo`00oooo
ooooooooooooool0000dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05Oooool0
1Ooo003oooooooooooooooooo`0003Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0Dooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Cooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool05_ooool01Ooo003oooooooooooooooooo`0003Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool05_oo
ool01Ooo003oooooooooooooooooo`0003Cooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0Eooooo`05ool00?oooooooooooooooooo0000=?ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo01Cooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool0
5?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo037ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0Fooooo`05ool00?oooooooooooooooooo0000=?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0Fooooo`05ool00?oooooooooooooooooo0000=?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo01Kooooo00Goo`00ooooooooooooooooool0000dooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`007oooool3o`00
01Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0aooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool05_ooool01Ooo003oooooooooooooooooo`0003Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0Eooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool05_ooool01Ooo003oooooooooooooooooo`0003Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0Fooooo`05ool00?oooooooooooooooooo0000=Oooool01Ooo003ooooo
ooooooooooooo`0001Gooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`0Dooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool0<_ooool01Ooo003oooooooooooooooooo`0001So
oooo00Goo`00ooooooooooooooooool0000dooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool05Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01Oooooo00?o0000oooo
ooooool05oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Kooooo00Goo`00oooo
ooooooooooooool0000dooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool05_ooool0
1Ooo003oooooooooooooooooo`0003Gooooo00Goo`00ooooooooooooooooool0000Fooooo`03o`00
0?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`0booooo`05ool00?oooooooooooooooooo00006?ooool01Ooo003ooooo
ooooooooooooo`0003Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Eooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool05_ooool01Ooo003oooooooooooooooooo`00
03Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Fooooo`05ool00?oooooooooo
oooooooo0000=Oooool01Ooo003oooooooooooooooooo`0001Kooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo03;ooooo00Goo`00ooooooooooooooooool0000Hooooo`05ool00?oooooooooooooooooo0000
=?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Gooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0Fooooo`05ool00?oooooooooooooooooo0000=?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo01Kooooo00Goo`00ooooooooooooooooool0000eoooo
o`05ool00?oooooooooooooooooo00005_ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0
003oooooooooo`0Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0<_ooool01Ooo
003oooooooooooooooooo`0001Sooooo00Goo`00ooooooooooooooooool0000dooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo01Sooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo01Kooooo00Goo`00ooooooooooooooooool0000dooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool05_ooool01Ooo003oooooooooooooooooo`0003Gooooo00Goo`00oooooooo
ooooooooool0000Fooooo`03o`000?oooooooooo00gooooo000Oooooo`?o00005?ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo03;ooooo00Goo`00ooooooooooooooooool0000Hoooo
o`05ool00?oooooooooooooooooo0000=?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo01Kooooo00Goo`00ooooooooooooooooool0000Jooooo`03o`000?oooooooooo01Oooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0Fooooo`05ool00?oooooooooooooooooo0000
=Oooool01Ooo003oooooooooooooooooo`0001Sooooo00Goo`00ooooooooooooooooool0000eoooo
o`05ool00?oooooooooooooooooo00005Oooool2o`0000oooooo000Oooooo`03o`000?oooooooooo
01Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0cooooo`05ool00?oooooooooo
oooooooo00006?ooool01Ooo003oooooooooooooooooo`0003Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0Fooooo`05ool00?oooooooooooooooooo00006_ooool00ol0003ooooo
ooooo`0Gooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool05_ooool01Ooo003ooooo
ooooooooooooo`0003Gooooo00Goo`00ooooooooooooooooool0000Hooooo`05ool00?oooooooooo
oooooooo0000=Oooool01Ooo003oooooooooooooooooo`0001Kooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo03?ooooo00Goo`00ooooooooooooooooool0000Hooooo`05ool00?oooooooooooooooooo0000
=?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01Kooooo00Goo`00oooooooooooo
ooooool0000Jooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0Fooooo`05ool00?oooooooooooooooooo0000=Oooool01Ooo003ooooooooooooooooo
o`0001Sooooo00Goo`00ooooooooooooooooool0000eooooo`05ool00?oooooooooooooooooo0000
5_ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Dooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool0<oooool01Ooo003oooooooooooooooooo`0001Sooooo
00Goo`00ooooooooooooooooool0000dooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool05_ooool01Ooo003oooooooooooooooooo`0001[ooooo00?o0000ooooooooool05oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo01Kooooo00Goo`00ooooooooooooooooool0000e
ooooo`05ool00?oooooooooooooooooo00006?ooool01Ooo003oooooooooooooooooo`0003Gooooo
00Goo`00ooooooooooooooooool0000Fooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`00
0?oooooooooo01Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0cooooo`05ool0
0?oooooooooooooooooo00006?ooool01Ooo003oooooooooooooooooo`0003Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0Fooooo`05ool00?oooooooooooooooooo00006_ooool0
0ol0003oooooooooo`0Hooooo`04ool00?ooooooooooool001Wooooo00Goo`00oooooooooooooooo
ool0000eooooo`05ool00?oooooooooooooooooo00006?ooool01Ooo003oooooooooooooooooo`00
03Gooooo00Goo`00ooooooooooooooooool0000Fooooo`03o`000?oooooooooo00gooooo000Ooooo
o`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0coooo
o`05ool00?oooooooooooooooooo00006?ooool01Ooo003oooooooooooooooooo`0003Cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0Fooooo`05ool00?oooooooooooooooooo0000
6_ooool00ol0003oooooooooo`0Hooooo`04ool00?ooooooooooool001Wooooo00Goo`00oooooooo
ooooooooool0000eooooo`05ool00?oooooooooooooooooo00006?ooool01Ooo003ooooooooooooo
ooooo`0003Gooooo00Goo`00ooooooooooooooooool0000Fooooo`03o`000?oooooooooo00gooooo
000Oooooo`?o00005Oooool01Ooo003oooooooooooooooooo`0003Gooooo00Goo`00oooooooooooo
ooooool0000Hooooo`05ool00?oooooooooooooooooo0000=?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo01Kooooo00Goo`00ooooooooooooooooool0000Jooooo`03o`000?oooooo
oooo01Sooooo00Coo`00ooooooooooooo`006Oooool01Ooo003oooooooooooooooooo`0003Gooooo
00Goo`00ooooooooooooooooool0000Hooooo`05ool00?oooooooooooooooooo0000=Oooool01Ooo
003oooooooooooooooooo`0001Gooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`0Eoooo
o`05ool00?oooooooooooooooooo0000=Oooool01Ooo003oooooooooooooooooo`0001Sooooo00Go
o`00ooooooooooooooooool0000dooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
5_ooool01Ooo003oooooooooooooooooo`0001[ooooo00?o0000ooooooooool06?ooool01?oo003o
oooooooooooo000Iooooo`05ool00?oooooooooooooooooo0000=Oooool01Ooo003ooooooooooooo
ooooo`0001Sooooo00Goo`00ooooooooooooooooool0000eooooo`05ool00?oooooooooooooooooo
00005_ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Eooooo`05ool0
0?oooooooooooooooooo0000=Oooool01Ooo003oooooooooooooooooo`0001Sooooo00Goo`00oooo
ooooooooooooool0000dooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool05_ooool0
1Ooo003oooooooooooooooooo`0001[ooooo00?o0000ooooooooool06?ooool01?oo003ooooooooo
oooo000Iooooo`05ool00?oooooooooooooooooo0000=Oooool01Ooo003oooooooooooooooooo`00
01Sooooo00Goo`00ooooooooooooooooool0000eooooo`05ool00?oooooooooooooooooo00005_oo
ool00ol0003oooooooooo`0=ooooo`004?ooool3o`0000?ooooo0_l00007ooooo`03o`000?oooooo
oooo01Gooooo00Goo`00ooooooooooooooooool0000eooooo`05ool00?oooooooooooooooooo0000
6?ooool01Ooo003oooooooooooooooooo`0003Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0Fooooo`05ool00?oooooooooooooooooo00006_ooool00ol0003oooooooooo`0Hoooo
o`04ool00?ooooooooooool001Wooooo00Goo`00ooooooooooooooooool0000eooooo`05ool00?oo
oooooooooooooooo00006?ooool01Ooo003oooooooooooooooooo`0003Gooooo00Goo`00oooooooo
ooooooooool0000Fooooo`03o`000?oooooooooo00gooooo000Aooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00Goo`00oooo
ooooooooooooool0000eooooo`05ool00?oooooooooooooooooo00006?ooool01Ooo003ooooooooo
ooooooooo`0003Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Fooooo`05ool0
0?oooooooooooooooooo00006_ooool00ol0003oooooooooo`0Hooooo`04ool00?ooooooooooool0
01Wooooo00Goo`00ooooooooooooooooool0000eooooo`05ool00?oooooooooooooooooo00006?oo
ool01Ooo003oooooooooooooooooo`0003Gooooo00Coo`00ooooooooooooo`005oooool00ol0003o
ooooooooo`0=ooooo`003_ooool5o`0000;ooooo00Co0000oooooooooooo00001_ooool4o`0001Co
oooo00Goo`00ooooooooooooooooool0000eooooo`05ool00?oooooooooooooooooo00006?ooool0
1Ooo003oooooooooooooooooo`0003Cooooo00Goo`00ooooooooooooooooool0000Iooooo`05ool0
0?oooooooooooooooooo00006_ooool00ol0003oooooooooo`0Hooooo`04ool00?ooooooooooool0
01Wooooo00Goo`00ooooooooooooooooool0000eooooo`05ool00?oooooooooooooooooo00006?oo
ool01Ooo003oooooooooooooooooo`0003Gooooo00Coo`00ooooooooooooo`005?ooool4o`0000oo
oooo000>ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo0000=Oooool01Ooo003ooooooooooooo
ooooo`0001Sooooo00Goo`00ooooooooooooooooool0000dooooo`05ool00?oooooooooooooooooo
00006Oooool01Ooo003oooooooooooooooooo`0001[ooooo00?o0000ooooooooool06?ooool01?oo
003ooooooooooooo000Iooooo`05ool00?oooooooooooooooooo0000=Oooool01Ooo003ooooooooo
ooooooooo`0001Sooooo00Goo`00ooooooooooooooooool0000eooooo`04ool00?ooooooooooool0
01Oooooo00?o0000ooooooooool03Oooool000oooooo00?o0000ooooool000000oooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo01Gooooo00Goo`00ooooooooooooooooool0000e
ooooo`05ool00?oooooooooooooooooo00006?ooool01Ooo003oooooooooooooooooo`0003Gooooo
00Coo`00ooooooooooooo`006Oooool01Ooo003oooooooooooooooooo`0001[ooooo00?o0000oooo
ooooool06?ooool01?oo003ooooooooooooo000Iooooo`05ool00?oooooooooooooooooo0000=Ooo
ool01Ooo003oooooooooooooooooo`0001Sooooo00Goo`00ooooooooooooooooool0000eooooo`04
ool00?ooooooooooool001Oooooo00?o0000ooooooooool03Oooool0013ooooo0_l00003ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool05Oooool01Ooo003ooooooooooooooooo
o`0003Gooooo00Goo`00ooooooooooooooooool0000Hooooo`05ool00?oooooooooooooooooo0000
=Oooool01?oo003ooooooooooooo000Iooooo`05ool00?oooooooooooooooooo00006_ooool00ol0
003oooooooooo`0Hooooo`04ool00?ooooooooooool001Wooooo00Goo`00ooooooooooooooooool0
000eooooo`05ool00?oooooooooooooooooo00006?ooool01?oo003ooooooooooooo000fooooo`04
ool00?ooooooooooool001Oooooo00?o0000ooooooooool03Oooool0017ooooo00?o0000oooooooo
ool00_ooool2o`0000Oooooo00?o0000ooooooooool05Oooool01Ooo003oooooooooooooooooo`00
03Gooooo00Goo`00ooooooooooooooooool0000Hooooo`05ool00?oooooooooooooooooo0000=Ooo
ool01?oo003ooooooooooooo000Iooooo`04ool00?ooooooooooool001_ooooo00?o0000oooooooo
ool06?ooool01?oo003ooooooooooooo000Iooooo`05ool00?oooooooooooooooooo0000=Oooool0
1Ooo003oooooooooooooooooo`0001Sooooo00Coo`00ooooooooooooo`00=_ooool01?oo003ooooo
oooooooo000Gooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Gooooo
00Goo`00ooooooooooooooooool0000eooooo`05ool00?oooooooooooooooooo00006?ooool01Ooo
003oooooooooooooooooo`0003Gooooo00Coo`00ooooooooooooo`006Oooool01?oo003ooooooooo
oooo000Kooooo`03o`000?oooooooooo01Sooooo00Coo`00ooooooooooooo`006Oooool01Ooo003o
ooooooooooooooooo`0003Gooooo00Goo`00ooooooooooooooooool0000Hooooo`04ool00?oooooo
ooooool003Kooooo00Coo`00ooooooooooooo`005oooool00ol0003oooooooooo`0=ooooo`007ooo
ool3o`0001Gooooo00Goo`00ooooooooooooooooool0000eooooo`04ool00?ooooooooooool001Wo
oooo00Goo`00ooooooooooooooooool0000eooooo`04ool00?ooooooooooool001Wooooo00Coo`00
ooooooooooooo`006oooool00ol0003oooooooooo`0Hooooo`04ool00?ooooooooooool001Wooooo
00Goo`00ooooooooooooooooool0000eooooo`05ool00?oooooooooooooooooo00006?ooool01?oo
003ooooooooooooo000fooooo`04ool00?ooooooooooool001Kooooo0_l0000?ooooo`007oooool0
0ol0003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo0000=Oooool01?oo003ooooooooo
oooo000Iooooo`05ool00?oooooooooooooooooo0000=Oooool01?oo003ooooooooooooo000Ioooo
o`04ool00?ooooooooooool001_ooooo00?o0000ooooooooool06?ooool01?oo003ooooooooooooo
000Iooooo`04ool00?ooooooooooool003Kooooo00Goo`00ooooooooooooooooool0000Hooooo`04
ool00?ooooooooooool003Kooooo00Coo`00ooooooooooooo`005oooool00ol0003oooooooooo`0=
ooooo`007oooool00ol0003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo0000=Oooool0
1?oo003ooooooooooooo000Iooooo`05ool00?oooooooooooooooooo0000=Oooool01?oo003ooooo
oooooooo000Iooooo`04ool00?ooooooooooool001_ooooo00?o0000ooooooooool06?ooool01?oo
003ooooooooooooo000Iooooo`04ool00?ooooooooooool003Kooooo00Goo`00oooooooooooooooo
ool0000Hooooo`04ool00?ooooooooooool003Kooooo00Coo`00ooooooooooooo`005oooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Eooooo`05ool00?oooooooooooooo
oooo0000=Oooool01?oo003ooooooooooooo000Iooooo`04ool00?ooooooooooool003Kooooo00Co
o`00ooooooooooooo`006Oooool01?oo003ooooooooooooo000Kooooo`03o`000?oooooooooo01So
oooo00Coo`00ooooooooooooo`006Oooool01?oo003ooooooooooooo000fooooo`05ool00?oooooo
oooooooooooo00006?ooool01?oo003ooooooooooooo000fooooo`04ool00?ooooooooooool001Oo
oooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool05Oooool01Ooo003ooooo
ooooooooooooo`0003Gooooo00Coo`00ooooooooooooo`006Oooool01?oo003ooooooooooooo000f
ooooo`04ool00?ooooooooooool001Wooooo00Coo`00ooooooooooooo`006oooool00ol0003ooooo
ooooo`0Hooooo`04ool00?ooooooooooool001Wooooo00Coo`00ooooooooooooo`00=_ooool01Ooo
003oooooooooooooooooo`0001Wooooo00?oo`00oooooooo0000=_ooool01?oo003ooooooooooooo
000Gooooo`03o`000?oooooooooo00gooooo000Oooooo`?o00005Oooool01Ooo003ooooooooooooo
ooooo`0003Gooooo00Coo`00ooooooooooooo`006Oooool01?oo003ooooooooooooo000fooooo`04
ool00?ooooooooooool001Wooooo00Coo`00ooooooooooooo`006oooool00ol0003oooooooooo`0H
ooooo`04ool00?ooooooooooool001Wooooo00Coo`00ooooooooooooo`00=_ooool01?oo003ooooo
oooooooo000Jooooo`03ool00?ooooooo`0003Kooooo00Coo`00ooooooooooooo`005_ooool2o`00
00oooooo000Oooooo`03o`000?oooooooooo01Gooooo00Goo`00ooooooooooooooooool0000eoooo
o`04ool00?ooooooooooool001[ooooo00?oo`00oooooooo0000=_ooool01?oo003ooooooooooooo
000Iooooo`04ool00?ooooooooooool001_ooooo00?o0000ooooooooool06?ooool01?oo003ooooo
oooooooo000Iooooo`04ool00?ooooooooooool003Kooooo00Coo`00ooooooooooooo`006_ooool0
0ooo003oooooool0000fooooo`04ool00?ooooooooooool001Oooooo00?o0000ooooooooool03Ooo
ool001oooooo00?o0000ooooooooool05Oooool01Ooo003oooooooooooooooooo`0003Gooooo00Co
o`00ooooooooooooo`006_ooool00ooo003oooooool0000fooooo`04ool00?ooooooooooool001Wo
oooo00Coo`00ooooooooooooo`006oooool00ol0003oooooooooo`0Hooooo`04ool00?oooooooooo
ool001[ooooo00?oo`00oooooooo0000=_ooool01?oo003ooooooooooooo000Jooooo`03ool00?oo
ooooo`0003Kooooo00Coo`00ooooooooooooo`005oooool00ol0003oooooooooo`0=ooooo`007ooo
ool00ol0003oooooooooo`0Eooooo`05ool00?oooooooooooooooooo0000=Oooool01?oo003ooooo
oooooooo000Jooooo`03ool00?ooooooo`0003Kooooo00Coo`00ooooooooooooo`006Oooool01?oo
003ooooooooooooo000Kooooo`03o`000?oooooooooo01Sooooo00Coo`00ooooooooooooo`006_oo
ool00ooo003oooooool0000fooooo`04ool00?ooooooooooool001[ooooo00?oo`00oooooooo0000
=_ooool01?oo003ooooooooooooo000Gooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`00
0?oooooooooo01Gooooo00Goo`00ooooooooooooooooool0000eooooo`04ool00?ooooooooooool0
01[ooooo00?oo`00oooooooo0000=_ooool01?oo003ooooooooooooo000Iooooo`04ool00?oooooo
ooooool001_ooooo00?o0000ooooooooool06?ooool01?oo003ooooooooooooo000Jooooo`03ool0
0?ooooooo`0003Kooooo00Coo`00ooooooooooooo`006_ooool00ooo003oooooool0000fooooo`04
ool00?ooooooooooool001Oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooooooo
ool05Oooool01?oo003ooooooooooooo000fooooo`04ool00?ooooooooooool001[ooooo00?oo`00
oooooooo0000=_ooool01?oo003ooooooooooooo000Iooooo`04ool00?ooooooooooool001_ooooo
00?o0000ooooooooool06?ooool01?oo003ooooooooooooo000Jooooo`03ool00?ooooooo`0003Ko
oooo00Coo`00ooooooooooooo`006_ooool00ooo003oooooool0000fooooo`04ool00?oooooooooo
ool001Oooooo00?o0000ooooooooool03Oooool001oooooo0ol0000Eooooo`04ool00?oooooooooo
ool003Kooooo00Coo`00ooooooooooooo`006_ooool00ooo003oooooool0000gooooo`03ool00?oo
ooooo`0001Wooooo00Coo`00ooooooooooooo`006oooool00ol0003oooooooooo`0Hooooo`04ool0
0?ooooooooooool001[ooooo00?oo`00oooooooo0000=_ooool01?oo003ooooooooooooo000Joooo
o`03ool00?ooooooo`0003Kooooo00Coo`00ooooooooooooo`005_ooool2o`0000oooooo000Ooooo
o`03o`000?oooooooooo01Kooooo00?oo`00oooooooo0000=_ooool01?oo003ooooooooooooo000J
ooooo`03ool00?ooooooo`0003Oooooo00?oo`00oooooooo00006_ooool00ooo003oooooool0000K
ooooo`03o`000?oooooooooo01Sooooo00Coo`00ooooooooooooo`006_ooool00ooo003oooooool0
000fooooo`04ool00?ooooooooooool001[ooooo00?oo`00oooooooo0000=_ooool01?oo003ooooo
oooooooo000Gooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Kooooo
00?oo`00oooooooo0000=_ooool01?oo003ooooooooooooo000Jooooo`03ool00?ooooooo`0003Oo
oooo00?oo`00oooooooo00006_ooool00ooo003oooooool0000Kooooo`03o`000?oooooooooo01So
oooo00Coo`00ooooooooooooo`006_ooool00ooo003oooooool0000fooooo`04ool00?oooooooooo
ool001[ooooo00?oo`00oooooooo0000=_ooool01?oo003ooooooooooooo000Gooooo`03o`000?oo
oooooooo00gooooo000Oooooo`03o`000?oooooooooo01Kooooo00?oo`00oooooooo0000=_ooool0
1?oo003ooooooooooooo000Jooooo`03ool00?ooooooo`0003Oooooo00?oo`00oooooooo00006_oo
ool00ooo003oooooool0000Kooooo`03o`000?oooooooooo01Wooooo00?oo`00oooooooo00006_oo
ool00ooo003oooooool0000gooooo`03ool00?ooooooo`0001[ooooo00?oo`00oooooooo0000=_oo
ool01?oo003ooooooooooooo000Gooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oo
oooooooo01Kooooo00?oo`00oooooooo0000=oooool00ooo003oooooool0000Jooooo`03ool00?oo
ooooo`0003Oooooo00?oo`00oooooooo00006_ooool00ooo003oooooool0000Kooooo`03o`000?oo
oooooooo01Wooooo00?oo`00oooooooo00006_ooool00ooo003oooooool0000gooooo`03ool00?oo
ooooo`0001[ooooo00?oo`00oooooooo0000=oooool00ooo003oooooool0000Gooooo`03o`000?oo
oooooooo00gooooo000Oooooo`03o`000?oooooooooo01Kooooo00?oo`00oooooooo0000=oooool0
0ooo003oooooool0000Jooooo`03ool00?ooooooo`0003Oooooo00?oo`00oooooooo00006_ooool0
0ooo003oooooool0000Kooooo`03o`000?oooooooooo01Wooooo00?oo`00oooooooo00006_ooool0
0ooo003oooooool0000gooooo`03ool00?ooooooo`0001[ooooo00?oo`00oooooooo0000=oooool0
0ooo003oooooool0000Gooooo`03o`000?oooooooooo00gooooo000Oooooo`?o00005_ooool00ooo
003oooooool0000gooooo`03ool00?ooooooo`0001[ooooo00?oo`00oooooooo0000=oooool00ooo
003oooooool0000Jooooo`03ool00?ooooooo`0001_ooooo00?o0000ooooooooool06Oooool00ooo
003oooooool0000Jooooo`03ool00?ooooooo`0003Oooooo00?oo`00oooooooo00006_ooool00ooo
003oooooool0000gooooo`03ool00?ooooooo`0001Kooooo0_l0000?ooooo`007oooool00ol0003o
ooooooooo`0Fooooo`03ool00?ooooooo`0003Oooooo00?oo`00oooooooo00006_ooool00ooo003o
ooooool0000gooooo`03ool00?ooooooo`0001[ooooo00?oo`00oooooooo00006oooool00ol0003o
ooooooooo`0Iooooo`03ool00?ooooooo`0001[ooooo00?oo`00oooooooo0000=oooool00ooo003o
ooooool0000Jooooo`03ool00?ooooooo`0003Oooooo00?oo`00oooooooo00005oooool00ol0003o
ooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0Fooooo`03ool00?ooooooo`0003Oooooo
00?oo`00oooooooo00006_ooool00ooo003oooooool0000gooooo`03ool00?ooooooo`0001[ooooo
00?oo`00oooooooo00006oooool00ol0003oooooooooo`0Iooooo`03ool00?ooooooo`0001[ooooo
00?oo`00oooooooo0000=oooool00ooo003oooooool0000Jooooo`03ool00?ooooooo`0003Oooooo
00?oo`00oooooooo00005oooool00ol0003oooooooooo`0=ooooo`003oooool3o`0000Cooooo0_l0
0007ooooo`03o`000?oooooooooo01Kooooo00?oo`00oooooooo0000=oooool00ooo003oooooool0
000Jooooo`03ool00?ooooooo`0003Oooooo00?oo`00oooooooo00006_ooool00ooo003oooooool0
000Kooooo`03o`000?oooooooooo01Wooooo00?oo`00oooooooo00006_ooool00ooo003oooooool0
000gooooo`03ool00?ooooooo`0001[ooooo00?oo`00oooooooo0000=oooool00ooo003oooooool0
000Gooooo`03o`000?oooooooooo00gooooo000>ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo01Kooooo00?oo`00oooooooo0000
=oooool2ool001_ooooo00?oo`00oooooooo0000=oooool00ooo003oooooool0000Jooooo`03ool0
0?ooooooo`0001_ooooo00?o0000ooooooooool06Oooool00ooo003oooooool0000Jooooo`03ool0
0?ooooooo`0003Oooooo00?oo`00oooooooo00006_ooool00ooo003oooooool0000gooooo`03ool0
0?ooooooo`0001Oooooo00?o0000ooooooooool03Oooool001;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`04ooooo`Co00005Oooool00ooo003oooooool0000gooooo`;oo`00
6oooool00ooo003oooooool0000gooooo`03ool00?ooooooo`0001[ooooo00?oo`00oooooooo0000
6oooool00ol0003oooooooooo`0Iooooo`03ool00?ooooooo`0001[ooooo00?oo`00oooooooo0000
=oooool00ooo003oooooool0000Jooooo`03ool00?ooooooo`0003Oooooo00?oo`00oooooooo0000
5?ooool4o`0000oooooo000Booooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Fooooo`;oo`00>?ooool2ool001_ooooo00?oo`00oooooooo0000
=oooool00ooo003oooooool0000Jooooo`03ool00?ooooooo`0001_ooooo00?o0000ooooooooool0
6Oooool2ool001_ooooo00?oo`00oooooooo0000=oooool00ooo003oooooool0000Jooooo`03ool0
0?ooooooo`0003Oooooo00?oo`00oooooooo00005oooool00ol0003oooooooooo`0=ooooo`003_oo
ool4o`0000?ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Fooooo`;oo`00
>?ooool2ool001_ooooo00?oo`00oooooooo0000=oooool2ool001_ooooo00?oo`00oooooooo0000
6oooool00ol0003oooooooooo`0Iooooo`;oo`006oooool00ooo003oooooool0000gooooo`;oo`00
6oooool00ooo003oooooool0000gooooo`;oo`006?ooool00ol0003oooooooooo`0=ooooo`003_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
5_ooool2ool003Sooooo0_oo000Kooooo`;oo`00>?ooool2ool001_ooooo0_oo000Looooo`03o`00
0?oooooooooo01Wooooo0_oo000Kooooo`;oo`00>?ooool2ool001_ooooo00?oo`00oooooooo0000
=oooool2ool001Sooooo00?o0000ooooooooool03Oooool000kooooo1Ol00003ooooo`;o00001ooo
ool00ol0003oooooooooo`0Fooooo`;oo`00>?ooool2ool001_ooooo0_oo000hooooo`;oo`006ooo
ool2ool001cooooo00?o0000ooooooooool06Oooool2ool001cooooo00?oo`00ooooooooool0=_oo
ool2ool001_ooooo0_oo000hooooo`;oo`006?ooool00ol0003oooooooooo`0=ooooo`007oooool0
0ol0003oooooooooo`0Gooooo`03ool00?oooooooooo03Kooooo0_oo000Looooo`03ool00?oooooo
oooo03Kooooo0_oo000Looooo`03ool00?oooooooooo01[ooooo00?o0000ooooooooool06Oooool2
ool001cooooo00?oo`00ooooooooool0=_ooool2ool001cooooo00?oo`00ooooooooool0=_ooool2
ool001Sooooo00?o0000ooooooooool03Oooool001oooooo0ol0000Gooooo`03ool00?oooooooooo
03Kooooo0_oo000Looooo`03ool00?oooooooooo03Oooooo00?oo`00ooooooooool06_ooool00ooo
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool06_ooool00ooo
003oooooooooo`0gooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool0=oooool00ooo
003oooooooooo`0Eooooo`;o00003oooool001oooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`007oooooooo`000<_o00003ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-8.97331, -6.57821, 0.0344739, \
0.358729}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show all", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ga\  = \ 
        Show[GraphicsArray[{{gxt, gxn}, {gX, \ gXXs}}], 
          ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0634921 0.00393652 0.196826 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.24603 -0.0125 -6 -9 ]
[.24603 -0.0125 6 0 ]
[.37302 -0.0125 -6 -9 ]
[.37302 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.62698 -0.0125 -3 -9 ]
[.62698 -0.0125 3 0 ]
[.75397 -0.0125 -3 -9 ]
[.75397 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-6)] .11905 -0.0125 0 1 Mshowa
.24603 0 m
.24603 .00625 L
s
[(-4)] .24603 -0.0125 0 1 Mshowa
.37302 0 m
.37302 .00625 L
s
[(-2)] .37302 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.62698 0 m
.62698 .00625 L
s
[(2)] .62698 -0.0125 0 1 Mshowa
.75397 0 m
.75397 .00625 L
s
[(4)] .75397 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(6)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.15079 0 m
.15079 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.05556 0 m
.05556 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.24603 .61178 m
.24603 .61803 L
s
.37302 .61178 m
.37302 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.62698 .61178 m
.62698 .61803 L
s
.75397 .61178 m
.75397 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.15079 .61428 m
.15079 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.05556 .61428 m
.05556 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.02381 .00394 m
.02474 .00394 L
.02575 .00394 L
.0267 .00394 L
.02761 .00394 L
.02859 .00394 L
.02952 .00394 L
.03052 .00394 L
.03148 .00394 L
.0324 .00394 L
.03338 .00394 L
.03433 .00394 L
.03524 .00394 L
.03621 .00394 L
.03714 .00394 L
.03813 .00394 L
.03908 .00394 L
.04 .00394 L
.04098 .00394 L
.04192 .00394 L
.04292 .00394 L
.04388 .00394 L
.0448 .00394 L
.04579 .00394 L
.04674 .00394 L
.04765 .00394 L
.04862 .00394 L
.04956 .00394 L
.05055 .00394 L
.05151 .00394 L
.05243 .00394 L
.05341 .00394 L
.05435 .00394 L
.05526 .00394 L
.05622 .00394 L
.05715 .00394 L
.05814 .00394 L
.05909 .00394 L
.06001 .00394 L
.06098 .00394 L
.06192 .00394 L
.06292 .00394 L
.06388 .00394 L
.0648 .00394 L
.06579 .00394 L
.06673 .00394 L
.06764 .00394 L
.06861 .00394 L
.06954 .00394 L
.07054 .00394 L
Mistroke
.07149 .00394 L
.07241 .00394 L
.07339 .00394 L
.07433 .00394 L
.07533 .00394 L
.07629 .00394 L
.07722 .00394 L
.07821 .00394 L
.07916 .00394 L
.08007 .00394 L
.08104 .00394 L
.08198 .00394 L
.08297 .00394 L
.08393 .00394 L
.08485 .00394 L
.08584 .00394 L
.08678 .00394 L
.08769 .00394 L
.08866 .00394 L
.08959 .00394 L
.09058 .00394 L
.09153 .00394 L
.09245 .00394 L
.09342 .00394 L
.09436 .00394 L
.09536 .00394 L
.09632 .00394 L
.09725 .00394 L
.09823 .00394 L
.09918 .00394 L
.10009 .00394 L
.10106 .00394 L
.10199 .00394 L
.10299 .00394 L
.10394 .00394 L
.10486 .00394 L
.10584 .00394 L
.10678 .00394 L
.10769 .00394 L
.10866 .00394 L
.10958 .00394 L
.11057 .00394 L
.11152 .00394 L
.11244 .00394 L
.11341 .00394 L
.11435 .00394 L
.11535 .00394 L
.1163 .00394 L
.11723 .00394 L
.11821 .00394 L
Mistroke
.11916 .00394 L
.12007 .00394 L
.12103 .00394 L
.12197 .00394 L
.12296 .00394 L
.12391 .00394 L
.12483 .00394 L
.12581 .00394 L
.12675 .00394 L
.12775 .00394 L
.12871 .00394 L
.12964 .00394 L
.13062 .00394 L
.13157 .00394 L
.13248 .00394 L
.13345 .00394 L
.13439 .00394 L
.13538 .00394 L
.13634 .00394 L
.13726 .00394 L
.13824 .00394 L
.13919 .00394 L
.14009 .00394 L
.14106 .00394 L
.14199 .00394 L
.14298 .00394 L
.14393 .00394 L
.14485 .00394 L
.14582 .00394 L
.14676 .00394 L
.14776 .00394 L
.14872 .00394 L
.14964 .00394 L
.15063 .00394 L
.15158 .00394 L
.15249 .00394 L
.15346 .00394 L
.15439 .00394 L
.15538 .00394 L
.15634 .00394 L
.15726 .00394 L
.15823 .00394 L
.15918 .00394 L
.16018 .00394 L
.16114 .00394 L
.16207 .00394 L
.16306 .00394 L
.16401 .00394 L
.16492 .00394 L
.16589 .00394 L
Mistroke
.16683 .00394 L
.16782 .00394 L
.16878 .00394 L
.16971 .00394 L
.17069 .00394 L
.17163 .00394 L
.17254 .00394 L
.17351 .00394 L
.17444 .00394 L
.17543 .00394 L
.17638 .00394 L
.1773 .00394 L
.17828 .00394 L
.17922 .00394 L
.18022 .00394 L
.18118 .00394 L
.1821 .00394 L
.18309 .00394 L
.18404 .00394 L
.18495 .00394 L
.18592 .00394 L
.18685 .00394 L
.18785 .00394 L
.1888 .00394 L
.18972 .00394 L
.1907 .00394 L
.19165 .00394 L
.19255 .00394 L
.19352 .00394 L
.19445 .00394 L
.19544 .00394 L
.19639 .00394 L
.1973 .00394 L
.19828 .00394 L
.19922 .00394 L
.20021 .00394 L
.20117 .00394 L
.2021 .00394 L
.20308 .00394 L
.20403 .00394 L
.20494 .00394 L
.2059 .00394 L
.20684 .00394 L
.20783 .00394 L
.20878 .00394 L
.2097 .00394 L
.21068 .00394 L
.21162 .00394 L
.21262 .00394 L
.21358 .00394 L
Mistroke
.21451 .00394 L
.2155 .00394 L
.21645 .00394 L
.21736 .00394 L
.21833 .00394 L
.21927 .00394 L
.22026 .00394 L
.22122 .00394 L
.22214 .00394 L
.22312 .00394 L
.22407 .00394 L
.22497 .00394 L
.22594 .00394 L
.22687 .00394 L
.22786 .00394 L
.22881 .00394 L
.22973 .00394 L
.23071 .00394 L
.23164 .00394 L
.23264 .00394 L
.2336 .00394 L
.23453 .00394 L
.23551 .00394 L
.23646 .00394 L
.23737 .00394 L
.23834 .00394 L
.23928 .00394 L
.24027 .00394 L
.24122 .00394 L
.24214 .00394 L
.24312 .00394 L
.24406 .00394 L
.24497 .00394 L
.24594 .00394 L
.24686 .00394 L
.24785 .00394 L
.2488 .00394 L
.24972 .00394 L
.25069 .00394 L
.25163 .00394 L
.25262 .00394 L
.25358 .00394 L
.25451 .00394 L
.25549 .00394 L
.25643 .00394 L
.25734 .00394 L
.25831 .00394 L
.25924 .00394 L
.26023 .00394 L
.26119 .00394 L
Mistroke
.2621 .00394 L
.26308 .00394 L
.26402 .00394 L
.26502 .00394 L
.26598 .00394 L
.26691 .00394 L
.26789 .00394 L
.26884 .00394 L
.26976 .00394 L
.27073 .00394 L
.27166 .00394 L
.27266 .00394 L
.27361 .00394 L
.27453 .00394 L
.27551 .00394 L
.27646 .00394 L
.27736 .00394 L
.27833 .00394 L
.27926 .00394 L
.28025 .00394 L
.2812 .00394 L
.28212 .00394 L
.28309 .00394 L
.28403 .00394 L
.28503 .00394 L
.28599 .00394 L
.28691 .00394 L
.28789 .00394 L
.28884 .00394 L
.28975 .00394 L
.29072 .00394 L
.29165 .00394 L
.29265 .00394 L
.2936 .00394 L
.29452 .00394 L
.2955 .00394 L
.29644 .00394 L
.29744 .00394 L
.2984 .00394 L
.29933 .00394 L
.30032 .00394 L
.30127 .00394 L
.30218 .00394 L
.30315 .00394 L
.30409 .00394 L
.30509 .00394 L
.30604 .00394 L
.30697 .00394 L
.30795 .00394 L
.30889 .00394 L
Mistroke
.3098 .00394 L
.31077 .00394 L
.3117 .00394 L
.31269 .00394 L
.31364 .00394 L
.31456 .00394 L
.31554 .00394 L
.31647 .00394 L
.31747 .00394 L
.31844 .00394 L
.31936 .00394 L
.32035 .00394 L
.32129 .00394 L
.3222 .00394 L
.32318 .00394 L
.32411 .00394 L
.3251 .00394 L
.32606 .00394 L
.32698 .00394 L
.32796 .00394 L
.3289 .00394 L
.32981 .00394 L
.33077 .00394 L
.3317 .00394 L
.33269 .00394 L
.33364 .00394 L
.33456 .00394 L
.33553 .00394 L
.33647 .00394 L
.33746 .00394 L
.33842 .00394 L
.33935 .00394 L
.34033 .00394 L
.34128 .00394 L
.34218 .00394 L
.34315 .00394 L
.34409 .00394 L
.34508 .00394 L
.34603 .00394 L
.34695 .00394 L
.34793 .00394 L
.34887 .00394 L
.34987 .00394 L
.35083 .00394 L
.35176 .00394 L
.35274 .00394 L
.35369 .00394 L
.3546 .00394 L
.35558 .00394 L
.35651 .00394 L
Mistroke
.35751 .00394 L
.35846 .00394 L
.35939 .00394 L
.36037 .00394 L
.36131 .00394 L
.36222 .00394 L
.36318 .00394 L
.36411 .00394 L
.3651 .00394 L
.36606 .00394 L
.36697 .00394 L
.36795 .00394 L
.36889 .00394 L
.36988 .00394 L
.37038 .00394 L
.37084 .00394 L
.37129 .00394 L
.37152 .00394 L
.37158 .00394 L
.37165 .00394 L
.37168 .00394 L
.37171 .00394 L
.37174 .00394 L
.37177 .39759 L
.37179 .39759 L
.3718 .39759 L
.37183 .39759 L
.3719 .39759 L
.37202 .39759 L
.37224 .39759 L
.37275 .39759 L
.37366 .39759 L
.3739 .39759 L
.37413 .39759 L
.37419 .39759 L
.37423 .39759 L
.37426 .39759 L
.37427 .39759 L
.37429 .00394 L
.37431 .00394 L
.37433 .00394 L
.3744 .00394 L
.37464 .00394 L
.37559 .00394 L
.37651 .00394 L
.37748 .00394 L
.37842 .00394 L
.37942 .00394 L
.38038 .00394 L
.38131 .00394 L
Mistroke
.3823 .00394 L
.38324 .00394 L
.38416 .00394 L
.38513 .00394 L
.38606 .00394 L
.38705 .00394 L
.38801 .00394 L
.38893 .00394 L
.38991 .00394 L
.39086 .00394 L
.39176 .00394 L
.39273 .00394 L
.39366 .00394 L
.39465 .00394 L
.3956 .00394 L
.39651 .00394 L
.39749 .00394 L
.39843 .00394 L
.39942 .00394 L
.40038 .00394 L
.40131 .00394 L
.40229 .00394 L
.40324 .00394 L
.40415 .00394 L
.40511 .00394 L
.40605 .00394 L
.40704 .00394 L
.40799 .00394 L
.40891 .00394 L
.40989 .00394 L
.41083 .00394 L
.41183 .00394 L
.4128 .00394 L
.41372 .00394 L
.41471 .00394 L
.41566 .00394 L
.41657 .00394 L
.41754 .00394 L
.41848 .00394 L
.41948 .00394 L
.42043 .00394 L
.42136 .00394 L
.42234 .00394 L
.42328 .00394 L
.42419 .00394 L
.42516 .00394 L
.42609 .00394 L
.42708 .00394 L
.42803 .00394 L
.42895 .00394 L
Mistroke
.42992 .00394 L
.43086 .00394 L
.43186 .00394 L
.43282 .00394 L
.43375 .00394 L
.43421 .00394 L
.43473 .00394 L
.43497 .00394 L
.4351 .00394 L
.43516 .00394 L
.43519 .00394 L
.43522 .00394 L
.43525 .20076 L
.43528 .20076 L
.43533 .20076 L
.43546 .20076 L
.43568 .20076 L
.43661 .20076 L
.43708 .20076 L
.43733 .20076 L
.43746 .20076 L
.43759 .20076 L
.43765 .20076 L
.43772 .20076 L
.43775 .20076 L
.43777 .20076 L
.43779 .00394 L
.43782 .00394 L
.43785 .00394 L
.43809 .00394 L
.43854 .00394 L
.43954 .00394 L
.44049 .00394 L
.44141 .00394 L
.44238 .00394 L
.44332 .00394 L
.44432 .00394 L
.44529 .00394 L
.44621 .00394 L
.4472 .00394 L
.44815 .00394 L
.44906 .00394 L
.45003 .00394 L
.45097 .00394 L
.45196 .00394 L
.45292 .00394 L
.45384 .00394 L
.45482 .00394 L
.45576 .00394 L
.45667 .00394 L
Mistroke
.45764 .00394 L
.45857 .00394 L
.45956 .00394 L
.46051 .00394 L
.46142 .00394 L
.4624 .00394 L
.46334 .00394 L
.46433 .00394 L
.4653 .00394 L
.46622 .00394 L
.4672 .00394 L
.46815 .00394 L
.46906 .00394 L
.47003 .00394 L
.47096 .00394 L
.47196 .00394 L
.47291 .00394 L
.47383 .00394 L
.47481 .00394 L
.47575 .00394 L
.47675 .00394 L
.47771 .00394 L
.47864 .00394 L
.47963 .00394 L
.48058 .00394 L
.48149 .00394 L
.48247 .00394 L
.4834 .00394 L
.4844 .00394 L
.48536 .00394 L
.48628 .00394 L
.48726 .00394 L
.48821 .00394 L
.48911 .00394 L
.49008 .00394 L
.49101 .00394 L
.492 .00394 L
.49296 .00394 L
.49387 .00394 L
.49485 .00394 L
.49579 .00394 L
.49679 .00394 L
.49775 .00394 L
.49819 .00394 L
.49844 .00394 L
.49856 .00394 L
.49862 .00394 L
.49867 .00394 L
.4987 .00394 L
.49873 .20076 L
Mistroke
.49876 .20076 L
.49879 .20076 L
.49891 .20076 L
.49915 .20076 L
.49966 .20076 L
.50016 .20076 L
.50063 .20076 L
.50086 .20076 L
.50108 .20076 L
.50119 .20076 L
.50122 .20076 L
.50125 .20076 L
.50128 .00394 L
.50131 .00394 L
.50155 .00394 L
.50254 .00394 L
.50348 .00394 L
.50439 .00394 L
.50536 .00394 L
.50629 .00394 L
.50728 .00394 L
.50824 .00394 L
.50916 .00394 L
.51014 .00394 L
.51108 .00394 L
.51208 .00394 L
.51304 .00394 L
.51397 .00394 L
.51495 .00394 L
.5159 .00394 L
.51682 .00394 L
.51779 .00394 L
.51872 .00394 L
.51972 .00394 L
.52068 .00394 L
.5216 .00394 L
.52258 .00394 L
.52352 .00394 L
.52443 .00394 L
.5254 .00394 L
.52633 .00394 L
.52732 .00394 L
.52827 .00394 L
.52918 .00394 L
.53016 .00394 L
.5311 .00394 L
.5321 .00394 L
.53306 .00394 L
.53398 .00394 L
.53497 .00394 L
Mistroke
.53591 .00394 L
.53683 .00394 L
.5378 .00394 L
.53873 .00394 L
.53972 .00394 L
.54068 .00394 L
.5416 .00394 L
.54258 .00394 L
.54352 .00394 L
.54442 .00394 L
.54539 .00394 L
.54632 .00394 L
.5473 .00394 L
.54825 .00394 L
.54917 .00394 L
.55014 .00394 L
.55108 .00394 L
.55207 .00394 L
.55303 .00394 L
.55396 .00394 L
.55494 .00394 L
.55588 .00394 L
.55679 .00394 L
.55776 .00394 L
.55869 .00394 L
.55968 .00394 L
.56064 .00394 L
.56155 .00394 L
.5618 .00394 L
.56203 .00394 L
.56209 .00394 L
.56215 .00394 L
.56219 .00394 L
.56221 .00394 L
.56223 .20076 L
.56226 .20076 L
.56229 .20076 L
.56253 .20076 L
.56352 .20076 L
.56402 .20076 L
.56424 .20076 L
.56448 .20076 L
.56459 .20076 L
.56465 .20076 L
.56468 .20076 L
.56471 .20076 L
.56474 .20076 L
.56477 .00394 L
.5648 .00394 L
.56483 .00394 L
Mistroke
.56493 .00394 L
.5654 .00394 L
.56636 .00394 L
.56729 .00394 L
.56827 .00394 L
.56922 .00394 L
.57013 .00394 L
.5711 .00394 L
.57203 .00394 L
.57302 .00394 L
.57398 .00394 L
.5749 .00394 L
.57587 .00394 L
.57682 .00394 L
.57782 .00394 L
.57878 .00394 L
.57971 .00394 L
.58069 .00394 L
.58164 .00394 L
.58256 .00394 L
.58353 .00394 L
.58447 .00394 L
.58546 .00394 L
.58642 .00394 L
.58734 .00394 L
.58832 .00394 L
.58927 .00394 L
.59017 .00394 L
.59114 .00394 L
.59207 .00394 L
.59306 .00394 L
.59402 .00394 L
.59493 .00394 L
.59591 .00394 L
.59685 .00394 L
.59785 .00394 L
.59881 .00394 L
.59973 .00394 L
.60072 .00394 L
.60167 .00394 L
.60258 .00394 L
.60355 .00394 L
.60448 .00394 L
.60547 .00394 L
.60643 .00394 L
.60735 .00394 L
.60833 .00394 L
.60927 .00394 L
.61018 .00394 L
.61114 .00394 L
Mistroke
.61207 .00394 L
.61306 .00394 L
.61401 .00394 L
.61493 .00394 L
.6159 .00394 L
.61684 .00394 L
.61783 .00394 L
.61879 .00394 L
.61972 .00394 L
.6207 .00394 L
.62165 .00394 L
.62255 .00394 L
.62352 .00394 L
.62446 .00394 L
.62493 .00394 L
.62518 .00394 L
.62545 .00394 L
.62558 .00394 L
.62565 .00394 L
.62567 .00394 L
.62571 .00394 L
.62573 .39759 L
.62576 .39759 L
.62582 .39759 L
.62594 .39759 L
.6264 .39759 L
.62734 .39759 L
.62758 .39759 L
.62785 .39759 L
.62797 .39759 L
.6281 .39759 L
.62815 .39759 L
.62821 .39759 L
.62822 .39759 L
.62824 .39759 L
.62827 .00394 L
.6283 .00394 L
.62833 .00394 L
.62931 .00394 L
.63024 .00394 L
.63124 .00394 L
.6322 .00394 L
.63313 .00394 L
.63411 .00394 L
.63506 .00394 L
.63597 .00394 L
.63694 .00394 L
.63787 .00394 L
.63886 .00394 L
.63982 .00394 L
Mistroke
.64074 .00394 L
.64172 .00394 L
.64266 .00394 L
.64366 .00394 L
.64462 .00394 L
.64555 .00394 L
.64654 .00394 L
.64749 .00394 L
.6484 .00394 L
.64938 .00394 L
.65031 .00394 L
.65131 .00394 L
.65227 .00394 L
.65319 .00394 L
.65417 .00394 L
.65512 .00394 L
.65603 .00394 L
.65699 .00394 L
.65792 .00394 L
.65891 .00394 L
.65987 .00394 L
.66079 .00394 L
.66176 .00394 L
.6627 .00394 L
.6637 .00394 L
.66466 .00394 L
.66559 .00394 L
.66657 .00394 L
.66752 .00394 L
.66843 .00394 L
.6694 .00394 L
.67034 .00394 L
.67133 .00394 L
.67229 .00394 L
.67321 .00394 L
.67419 .00394 L
.67513 .00394 L
.67604 .00394 L
.67701 .00394 L
.67793 .00394 L
.67892 .00394 L
.67987 .00394 L
.68079 .00394 L
.68176 .00394 L
.6827 .00394 L
.6837 .00394 L
.68466 .00394 L
.68558 .00394 L
.68657 .00394 L
.68751 .00394 L
Mistroke
.68842 .00394 L
.68939 .00394 L
.69032 .00394 L
.69131 .00394 L
.69227 .00394 L
.69319 .00394 L
.69417 .00394 L
.69511 .00394 L
.69611 .00394 L
.69707 .00394 L
.698 .00394 L
.69898 .00394 L
.69993 .00394 L
.70085 .00394 L
.70182 .00394 L
.70275 .00394 L
.70375 .00394 L
.70471 .00394 L
.70563 .00394 L
.70661 .00394 L
.70755 .00394 L
.70846 .00394 L
.70943 .00394 L
.71036 .00394 L
.71135 .00394 L
.7123 .00394 L
.71322 .00394 L
.71419 .00394 L
.71513 .00394 L
.71613 .00394 L
.71709 .00394 L
.71802 .00394 L
.719 .00394 L
.71995 .00394 L
.72086 .00394 L
.72183 .00394 L
.72276 .00394 L
.72376 .00394 L
.72471 .00394 L
.72563 .00394 L
.72661 .00394 L
.72755 .00394 L
.72846 .00394 L
.72942 .00394 L
.73035 .00394 L
.73134 .00394 L
.73229 .00394 L
.73321 .00394 L
.73418 .00394 L
.73512 .00394 L
Mistroke
.73611 .00394 L
.73707 .00394 L
.738 .00394 L
.73898 .00394 L
.73992 .00394 L
.74083 .00394 L
.7418 .00394 L
.74273 .00394 L
.74372 .00394 L
.74468 .00394 L
.74559 .00394 L
.74657 .00394 L
.74751 .00394 L
.74851 .00394 L
.74947 .00394 L
.7504 .00394 L
.75139 .00394 L
.75233 .00394 L
.75325 .00394 L
.75422 .00394 L
.75515 .00394 L
.75615 .00394 L
.7571 .00394 L
.75803 .00394 L
.75901 .00394 L
.75995 .00394 L
.76086 .00394 L
.76182 .00394 L
.76275 .00394 L
.76374 .00394 L
.76469 .00394 L
.76561 .00394 L
.76658 .00394 L
.76752 .00394 L
.76852 .00394 L
.76948 .00394 L
.7704 .00394 L
.77139 .00394 L
.77233 .00394 L
.77324 .00394 L
.77421 .00394 L
.77515 .00394 L
.77614 .00394 L
.77709 .00394 L
.77801 .00394 L
.77899 .00394 L
.77993 .00394 L
.78093 .00394 L
.7819 .00394 L
.78283 .00394 L
Mistroke
.78381 .00394 L
.78476 .00394 L
.78568 .00394 L
.78665 .00394 L
.78758 .00394 L
.78858 .00394 L
.78954 .00394 L
.79046 .00394 L
.79144 .00394 L
.79239 .00394 L
.7933 .00394 L
.79426 .00394 L
.79519 .00394 L
.79618 .00394 L
.79714 .00394 L
.79805 .00394 L
.79903 .00394 L
.79997 .00394 L
.80097 .00394 L
.80193 .00394 L
.80286 .00394 L
.80384 .00394 L
.80479 .00394 L
.8057 .00394 L
.80667 .00394 L
.8076 .00394 L
.8086 .00394 L
.80955 .00394 L
.81047 .00394 L
.81145 .00394 L
.8124 .00394 L
.8133 .00394 L
.81427 .00394 L
.8152 .00394 L
.81619 .00394 L
.81714 .00394 L
.81805 .00394 L
.81903 .00394 L
.81996 .00394 L
.82096 .00394 L
.82192 .00394 L
.82284 .00394 L
.82383 .00394 L
.82477 .00394 L
.82568 .00394 L
.82665 .00394 L
.82758 .00394 L
.82857 .00394 L
.82953 .00394 L
.83045 .00394 L
Mistroke
.83142 .00394 L
.83236 .00394 L
.83336 .00394 L
.83433 .00394 L
.83525 .00394 L
.83624 .00394 L
.83719 .00394 L
.8381 .00394 L
.83907 .00394 L
.84001 .00394 L
.841 .00394 L
.84196 .00394 L
.84288 .00394 L
.84386 .00394 L
.84481 .00394 L
.84572 .00394 L
.84668 .00394 L
.84761 .00394 L
.8486 .00394 L
.84955 .00394 L
.85047 .00394 L
.85145 .00394 L
.85238 .00394 L
.85338 .00394 L
.85434 .00394 L
.85527 .00394 L
.85625 .00394 L
.8572 .00394 L
.85811 .00394 L
.85908 .00394 L
.86001 .00394 L
.86101 .00394 L
.86196 .00394 L
.86288 .00394 L
.86386 .00394 L
.8648 .00394 L
.8658 .00394 L
.86677 .00394 L
.8677 .00394 L
.86868 .00394 L
.86963 .00394 L
.87055 .00394 L
.87152 .00394 L
.87246 .00394 L
.87345 .00394 L
.87441 .00394 L
.87533 .00394 L
.87632 .00394 L
.87726 .00394 L
.87817 .00394 L
Mistroke
.87914 .00394 L
.88007 .00394 L
.88106 .00394 L
.88201 .00394 L
.88293 .00394 L
.88391 .00394 L
.88485 .00394 L
.88585 .00394 L
.88681 .00394 L
.88774 .00394 L
.88872 .00394 L
.88967 .00394 L
.89058 .00394 L
.89155 .00394 L
.89249 .00394 L
.89348 .00394 L
.89444 .00394 L
.89536 .00394 L
.89634 .00394 L
.89728 .00394 L
.89819 .00394 L
.89915 .00394 L
.90008 .00394 L
.90107 .00394 L
.90202 .00394 L
.90294 .00394 L
.90391 .00394 L
.90485 .00394 L
.90585 .00394 L
.90681 .00394 L
.90773 .00394 L
.90872 .00394 L
.90966 .00394 L
.91057 .00394 L
.91154 .00394 L
.91248 .00394 L
.91347 .00394 L
.91442 .00394 L
.91534 .00394 L
.91632 .00394 L
.91726 .00394 L
.91826 .00394 L
.91922 .00394 L
.92015 .00394 L
.92114 .00394 L
.92209 .00394 L
.923 .00394 L
.92397 .00394 L
.92491 .00394 L
.9259 .00394 L
Mistroke
.92686 .00394 L
.92778 .00394 L
.92877 .00394 L
.92971 .00394 L
.93062 .00394 L
.93158 .00394 L
.93252 .00394 L
.93351 .00394 L
.93446 .00394 L
.93537 .00394 L
.93635 .00394 L
.93729 .00394 L
.93829 .00394 L
.93925 .00394 L
.94018 .00394 L
.94116 .00394 L
.94211 .00394 L
.94302 .00394 L
.94399 .00394 L
.94492 .00394 L
.94592 .00394 L
.94687 .00394 L
.94779 .00394 L
.94877 .00394 L
.94971 .00394 L
.95062 .00394 L
.95158 .00394 L
.95251 .00394 L
.9535 .00394 L
.95445 .00394 L
.95537 .00394 L
.95634 .00394 L
.95728 .00394 L
.95827 .00394 L
.95923 .00394 L
.96016 .00394 L
.96114 .00394 L
.96208 .00394 L
.96299 .00394 L
.96396 .00394 L
.96489 .00394 L
.96588 .00394 L
.96684 .00394 L
.96776 .00394 L
.96873 .00394 L
.96967 .00394 L
.97067 .00394 L
.97164 .00394 L
.97256 .00394 L
.97355 .00394 L
Mistroke
.9745 .00394 L
.97541 .00394 L
.97619 .00394 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0634921 0.00393652 0.196826 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.24603 -0.0125 -6 -9 ]
[.24603 -0.0125 6 0 ]
[.37302 -0.0125 -6 -9 ]
[.37302 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.62698 -0.0125 -3 -9 ]
[.62698 -0.0125 3 0 ]
[.75397 -0.0125 -3 -9 ]
[.75397 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-6)] .11905 -0.0125 0 1 Mshowa
.24603 0 m
.24603 .00625 L
s
[(-4)] .24603 -0.0125 0 1 Mshowa
.37302 0 m
.37302 .00625 L
s
[(-2)] .37302 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.62698 0 m
.62698 .00625 L
s
[(2)] .62698 -0.0125 0 1 Mshowa
.75397 0 m
.75397 .00625 L
s
[(4)] .75397 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(6)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.15079 0 m
.15079 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.05556 0 m
.05556 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.24603 .61178 m
.24603 .61803 L
s
.37302 .61178 m
.37302 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.62698 .61178 m
.62698 .61803 L
s
.75397 .61178 m
.75397 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.15079 .61428 m
.15079 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.05556 .61428 m
.05556 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .00394 m
.02567 .00394 L
.02769 .00394 L
.0296 .00394 L
.03143 .00394 L
.03338 .00394 L
.03525 .00394 L
.03724 .00394 L
.03917 .00394 L
.04101 .00394 L
.04298 .00394 L
.04487 .00394 L
.04669 .00394 L
.04863 .00394 L
.05049 .00394 L
.05144 .00394 L
.05248 .00394 L
.05296 .00394 L
.05347 .00394 L
.05371 .00394 L
.05384 .00394 L
.05389 .00394 L
.05395 .00394 L
.054 .59441 L
.05405 .59441 L
.05416 .59441 L
.05439 .59441 L
.05528 .59441 L
.05626 .59441 L
.05651 .59441 L
.05679 .59441 L
.0569 .59441 L
.05702 .59441 L
.05706 .59441 L
.05709 .59441 L
.05715 .00394 L
.05721 .00394 L
.05728 .00394 L
.05825 .00394 L
.0602 .00394 L
.06208 .00394 L
.06407 .00394 L
.06599 .00394 L
.06784 .00394 L
.06981 .00394 L
.07171 .00394 L
.07353 .00394 L
.07547 .00394 L
.07734 .00394 L
.07932 .00394 L
Mistroke
.08123 .00394 L
.08307 .00394 L
.08503 .00394 L
.08692 .00394 L
.08892 .00394 L
.09085 .00394 L
.0927 .00394 L
.09468 .00394 L
.09658 .00394 L
.09841 .00394 L
.10036 .00394 L
.10223 .00394 L
.10422 .00394 L
.10614 .00394 L
.10799 .00394 L
.10995 .00394 L
.11184 .00394 L
.11366 .00394 L
.1156 .00394 L
.11649 .00394 L
.11699 .00394 L
.11724 .00394 L
.11735 .00394 L
.1174 .00394 L
.11746 .00394 L
.11752 .20076 L
.11758 .20076 L
.1177 .20076 L
.11793 .20076 L
.11843 .20076 L
.11944 .20076 L
.11992 .20076 L
.12038 .20076 L
.1205 .20076 L
.12057 .20076 L
.12063 .20076 L
.12066 .00394 L
.1207 .00394 L
.12077 .00394 L
.1209 .00394 L
.12138 .00394 L
.12336 .00394 L
.12527 .00394 L
.1271 .00394 L
.12905 .00394 L
.13092 .00394 L
.13292 .00394 L
.13484 .00394 L
.13669 .00394 L
.13865 .00394 L
Mistroke
.14055 .00394 L
.14237 .00394 L
.14431 .00394 L
.14617 .00394 L
.14816 .00394 L
.15007 .00394 L
.1519 .00394 L
.15386 .00394 L
.15574 .00394 L
.15774 .00394 L
.15967 .00394 L
.16153 .00394 L
.1635 .00394 L
.1654 .00394 L
.16723 .00394 L
.16917 .00394 L
.17104 .00394 L
.17303 .00394 L
.17495 .00394 L
.1768 .00394 L
.17876 .00394 L
.17973 .00394 L
.18021 .00394 L
.18042 .00394 L
.18065 .00394 L
.18076 .00394 L
.18081 .00394 L
.18087 .00394 L
.18092 .00394 L
.18098 .59441 L
.18103 .59441 L
.18107 .59441 L
.18152 .59441 L
.18247 .59441 L
.18337 .59441 L
.18362 .59441 L
.18375 .59441 L
.18388 .59441 L
.184 .59441 L
.18403 .59441 L
.18407 .59441 L
.18413 .00394 L
.18419 .00394 L
.18425 .00394 L
.18436 .00394 L
.18622 .00394 L
.18819 .00394 L
.1901 .00394 L
.19193 .00394 L
.19387 .00394 L
Mistroke
.19575 .00394 L
.19774 .00394 L
.19966 .00394 L
.20151 .00394 L
.20347 .00394 L
.20537 .00394 L
.20719 .00394 L
.20912 .00394 L
.21099 .00394 L
.21297 .00394 L
.21488 .00394 L
.21671 .00394 L
.21867 .00394 L
.22055 .00394 L
.22255 .00394 L
.22448 .00394 L
.22633 .00394 L
.2283 .00394 L
.2302 .00394 L
.23203 .00394 L
.23397 .00394 L
.23584 .00394 L
.23783 .00394 L
.23974 .00394 L
.24159 .00394 L
.24252 .00394 L
.24301 .00394 L
.24355 .00394 L
.2438 .00394 L
.24406 .00394 L
.24428 .00394 L
.24434 .00394 L
.24437 .00394 L
.2444 .00394 L
.24447 .59441 L
.24452 .59441 L
.24544 .59441 L
.24632 .59441 L
.24682 .59441 L
.24706 .59441 L
.24729 .59441 L
.2474 .59441 L
.24746 .59441 L
.24752 .59441 L
.24758 .59441 L
.24764 .00394 L
.24769 .00394 L
.24775 .00394 L
.24824 .00394 L
.24925 .00394 L
Mistroke
.25111 .00394 L
.25308 .00394 L
.25498 .00394 L
.25681 .00394 L
.25876 .00394 L
.26063 .00394 L
.26262 .00394 L
.26454 .00394 L
.26639 .00394 L
.26835 .00394 L
.27024 .00394 L
.27206 .00394 L
.27399 .00394 L
.27586 .00394 L
.27784 .00394 L
.27974 .00394 L
.28158 .00394 L
.28353 .00394 L
.28541 .00394 L
.28741 .00394 L
.28933 .00394 L
.29119 .00394 L
.29316 .00394 L
.29505 .00394 L
.29688 .00394 L
.29882 .00394 L
.30069 .00394 L
.30268 .00394 L
.30459 .00394 L
.30643 .00394 L
.30738 .00394 L
.30761 .00394 L
.30773 .00394 L
.30786 .00394 L
.30789 .00394 L
.30793 .00394 L
.30797 .20076 L
.308 .20076 L
.30813 .20076 L
.30839 .20076 L
.30935 .20076 L
.30985 .20076 L
.31038 .20076 L
.31061 .20076 L
.31086 .20076 L
.31093 .20076 L
.311 .20076 L
.31106 .20076 L
.3111 .20076 L
.31113 .00394 L
Mistroke
.31116 .00394 L
.31119 .00394 L
.31125 .00394 L
.31138 .00394 L
.31231 .00394 L
.31416 .00394 L
.31613 .00394 L
.31803 .00394 L
.31986 .00394 L
.3218 .00394 L
.32368 .00394 L
.32567 .00394 L
.32758 .00394 L
.32943 .00394 L
.33139 .00394 L
.33328 .00394 L
.33509 .00394 L
.33703 .00394 L
.33889 .00394 L
.34087 .00394 L
.34277 .00394 L
.34461 .00394 L
.34656 .00394 L
.34844 .00394 L
.35043 .00394 L
.35236 .00394 L
.35421 .00394 L
.35617 .00394 L
.35807 .00394 L
.35989 .00394 L
.36183 .00394 L
.3637 .00394 L
.36569 .00394 L
.3676 .00394 L
.36944 .00394 L
.37047 .00394 L
.37095 .00394 L
.37116 .00394 L
.37128 .00394 L
.37134 .00394 L
.3714 .00394 L
.37145 .59441 L
.37151 .59441 L
.37162 .59441 L
.37186 .59441 L
.37237 .59441 L
.37328 .59441 L
.37375 .59441 L
.374 .59441 L
.37424 .59441 L
Mistroke
.37444 .59441 L
.3745 .59441 L
.37456 .59441 L
.37461 .00394 L
.37466 .00394 L
.37513 .00394 L
.37708 .00394 L
.37896 .00394 L
.38096 .00394 L
.38289 .00394 L
.38474 .00394 L
.38671 .00394 L
.38861 .00394 L
.39043 .00394 L
.39238 .00394 L
.39425 .00394 L
.39623 .00394 L
.39815 .00394 L
.39999 .00394 L
.40195 .00394 L
.40384 .00394 L
.40565 .00394 L
.40759 .00394 L
.40945 .00394 L
.41142 .00394 L
.41333 .00394 L
.41516 .00394 L
.41711 .00394 L
.41899 .00394 L
.42098 .00394 L
.4229 .00394 L
.42475 .00394 L
.42672 .00394 L
.42861 .00394 L
.43043 .00394 L
.43237 .00394 L
.43327 .00394 L
.43424 .00394 L
.43449 .00394 L
.43463 .00394 L
.43477 .00394 L
.43483 .00394 L
.43489 .00394 L
.43492 .59441 L
.43496 .59441 L
.43502 .59441 L
.43526 .59441 L
.43622 .59441 L
.43716 .59441 L
.43743 .59441 L
Mistroke
.43769 .59441 L
.43792 .59441 L
.43798 .59441 L
.43802 .59441 L
.43805 .59441 L
.43811 .00394 L
.43817 .00394 L
.44003 .00394 L
.44201 .00394 L
.44392 .00394 L
.44575 .00394 L
.4477 .00394 L
.44958 .00394 L
.45158 .00394 L
.4535 .00394 L
.45536 .00394 L
.45733 .00394 L
.45922 .00394 L
.46105 .00394 L
.46299 .00394 L
.46486 .00394 L
.46684 .00394 L
.46876 .00394 L
.4706 .00394 L
.47256 .00394 L
.47444 .00394 L
.47645 .00394 L
.47838 .00394 L
.48023 .00394 L
.48221 .00394 L
.48411 .00394 L
.48594 .00394 L
.48789 .00394 L
.48977 .00394 L
.49176 .00394 L
.49368 .00394 L
.49553 .00394 L
.49646 .00394 L
.49696 .00394 L
.49749 .00394 L
.49775 .00394 L
.498 .00394 L
.49823 .00394 L
.49829 .00394 L
.49832 .00394 L
.49835 .00394 L
.49841 .20076 L
.49847 .20076 L
.49938 .20076 L
.50027 .20076 L
Mistroke
.50077 .20076 L
.50102 .20076 L
.50124 .20076 L
.50135 .20076 L
.50141 .20076 L
.50148 .20076 L
.50153 .20076 L
.50159 .00394 L
.50165 .00394 L
.5017 .00394 L
.5022 .00394 L
.50321 .00394 L
.50507 .00394 L
.50705 .00394 L
.50896 .00394 L
.51079 .00394 L
.51274 .00394 L
.51462 .00394 L
.51661 .00394 L
.51853 .00394 L
.52038 .00394 L
.52235 .00394 L
.52425 .00394 L
.52607 .00394 L
.52801 .00394 L
.52988 .00394 L
.53186 .00394 L
.53377 .00394 L
.53561 .00394 L
.53757 .00394 L
.53945 .00394 L
.54146 .00394 L
.54339 .00394 L
.54524 .00394 L
.54722 .00394 L
.54912 .00394 L
.55095 .00394 L
.55289 .00394 L
.55477 .00394 L
.55676 .00394 L
.55868 .00394 L
.56052 .00394 L
.56101 .00394 L
.56148 .00394 L
.56171 .00394 L
.56177 .00394 L
.56184 .00394 L
.56189 .00394 L
.56196 .59441 L
.56199 .59441 L
Mistroke
.56203 .59441 L
.56209 .59441 L
.56223 .59441 L
.56249 .59441 L
.56337 .59441 L
.56387 .59441 L
.56434 .59441 L
.5648 .59441 L
.56493 .59441 L
.565 .59441 L
.56506 .59441 L
.56511 .00394 L
.56517 .00394 L
.5653 .00394 L
.56631 .00394 L
.56812 .00394 L
.57005 .00394 L
.57191 .00394 L
.57389 .00394 L
.57579 .00394 L
.57763 .00394 L
.57957 .00394 L
.58145 .00394 L
.58344 .00394 L
.58537 .00394 L
.58721 .00394 L
.58918 .00394 L
.59107 .00394 L
.59289 .00394 L
.59483 .00394 L
.5967 .00394 L
.59868 .00394 L
.60059 .00394 L
.60243 .00394 L
.60439 .00394 L
.60627 .00394 L
.60827 .00394 L
.6102 .00394 L
.61205 .00394 L
.61402 .00394 L
.61592 .00394 L
.61775 .00394 L
.6197 .00394 L
.62157 .00394 L
.62252 .00394 L
.62356 .00394 L
.62404 .00394 L
.62455 .00394 L
.62499 .00394 L
.62511 .00394 L
Mistroke
.62524 .00394 L
.6253 .00394 L
.62536 .00394 L
.62542 .59441 L
.62548 .59441 L
.6265 .59441 L
.62743 .59441 L
.62789 .59441 L
.62814 .59441 L
.62827 .59441 L
.62839 .59441 L
.6285 .59441 L
.62856 .59441 L
.62862 .00394 L
.62868 .00394 L
.62875 .00394 L
.62887 .00394 L
.62931 .00394 L
.63126 .00394 L
.63315 .00394 L
.63515 .00394 L
.63708 .00394 L
.63894 .00394 L
.64092 .00394 L
.64282 .00394 L
.64465 .00394 L
.6466 .00394 L
.64847 .00394 L
.65046 .00394 L
.65238 .00394 L
.65423 .00394 L
.65619 .00394 L
.65809 .00394 L
.6599 .00394 L
.66184 .00394 L
.6637 .00394 L
.66569 .00394 L
.6676 .00394 L
.66943 .00394 L
.67139 .00394 L
.67327 .00394 L
.67527 .00394 L
.67719 .00394 L
.67905 .00394 L
.68102 .00394 L
.68292 .00394 L
.68474 .00394 L
.68668 .00394 L
.68758 .00394 L
.68805 .00394 L
Mistroke
.68855 .00394 L
.68868 .00394 L
.68881 .00394 L
.68884 .00394 L
.68888 .00394 L
.68891 .20076 L
.68895 .20076 L
.68909 .20076 L
.68958 .20076 L
.69054 .20076 L
.69149 .20076 L
.69176 .20076 L
.69189 .20076 L
.69195 .20076 L
.69198 .20076 L
.69201 .20076 L
.69207 .00394 L
.69213 .00394 L
.69224 .00394 L
.69249 .00394 L
.69448 .00394 L
.69639 .00394 L
.69823 .00394 L
.70018 .00394 L
.70207 .00394 L
.70407 .00394 L
.706 .00394 L
.70785 .00394 L
.70983 .00394 L
.71173 .00394 L
.71356 .00394 L
.7155 .00394 L
.71738 .00394 L
.71937 .00394 L
.72129 .00394 L
.72313 .00394 L
.72509 .00394 L
.72698 .00394 L
.7288 .00394 L
.73074 .00394 L
.7326 .00394 L
.73458 .00394 L
.73649 .00394 L
.73832 .00394 L
.74027 .00394 L
.74215 .00394 L
.74415 .00394 L
.74608 .00394 L
.74793 .00394 L
.7499 .00394 L
Mistroke
.75088 .00394 L
.75136 .00394 L
.75179 .00394 L
.75201 .00394 L
.75212 .00394 L
.75225 .00394 L
.7523 .00394 L
.75235 .00394 L
.75241 .59441 L
.75247 .59441 L
.75267 .59441 L
.75362 .59441 L
.75458 .59441 L
.75506 .59441 L
.7552 .59441 L
.75534 .59441 L
.75541 .59441 L
.75547 .59441 L
.75553 .59441 L
.75559 .00394 L
.75565 .00394 L
.75571 .00394 L
.75583 .00394 L
.75605 .00394 L
.75655 .00394 L
.75756 .00394 L
.75947 .00394 L
.76131 .00394 L
.76326 .00394 L
.76514 .00394 L
.76714 .00394 L
.76907 .00394 L
.77093 .00394 L
.7729 .00394 L
.7748 .00394 L
.77662 .00394 L
.77857 .00394 L
.78044 .00394 L
.78243 .00394 L
.78435 .00394 L
.78619 .00394 L
.78815 .00394 L
.79004 .00394 L
.79186 .00394 L
.79379 .00394 L
.79565 .00394 L
.79763 .00394 L
.79953 .00394 L
.80137 .00394 L
.80332 .00394 L
Mistroke
.8052 .00394 L
.80719 .00394 L
.80912 .00394 L
.81097 .00394 L
.81293 .00394 L
.81391 .00394 L
.81483 .00394 L
.81528 .00394 L
.8155 .00394 L
.81571 .00394 L
.81577 .00394 L
.81582 .00394 L
.81585 .00394 L
.81589 .59441 L
.81594 .59441 L
.8162 .59441 L
.81665 .59441 L
.81759 .59441 L
.81809 .59441 L
.81837 .59441 L
.81863 .59441 L
.81887 .59441 L
.81894 .59441 L
.81898 .59441 L
.81901 .59441 L
.81907 .00394 L
.81911 .00394 L
.81914 .00394 L
.81961 .00394 L
.82053 .00394 L
.82251 .00394 L
.82442 .00394 L
.82625 .00394 L
.82821 .00394 L
.83009 .00394 L
.83209 .00394 L
.83401 .00394 L
.83586 .00394 L
.83784 .00394 L
.83973 .00394 L
.84156 .00394 L
.8435 .00394 L
.84537 .00394 L
.84736 .00394 L
.84927 .00394 L
.85112 .00394 L
.85308 .00394 L
.85496 .00394 L
.85678 .00394 L
.85871 .00394 L
Mistroke
.86057 .00394 L
.86255 .00394 L
.86445 .00394 L
.86628 .00394 L
.86823 .00394 L
.87011 .00394 L
.8721 .00394 L
.87402 .00394 L
.87587 .00394 L
.87681 .00394 L
.87784 .00394 L
.87831 .00394 L
.87882 .00394 L
.87906 .00394 L
.87918 .00394 L
.87924 .00394 L
.8793 .00394 L
.87935 .00394 L
.8794 .20076 L
.87945 .20076 L
.8795 .20076 L
.87973 .20076 L
.88067 .20076 L
.88117 .20076 L
.88171 .20076 L
.88197 .20076 L
.88222 .20076 L
.88233 .20076 L
.88244 .20076 L
.88251 .20076 L
.88254 .20076 L
.88257 .00394 L
.88263 .00394 L
.88269 .00394 L
.88361 .00394 L
.88559 .00394 L
.88749 .00394 L
.88933 .00394 L
.89128 .00394 L
.89316 .00394 L
.89515 .00394 L
.89708 .00394 L
.89893 .00394 L
.9009 .00394 L
.9028 .00394 L
.90462 .00394 L
.90656 .00394 L
.90843 .00394 L
.91041 .00394 L
.91233 .00394 L
Mistroke
.91417 .00394 L
.91613 .00394 L
.91801 .00394 L
.92002 .00394 L
.92195 .00394 L
.9238 .00394 L
.92578 .00394 L
.92768 .00394 L
.92951 .00394 L
.93146 .00394 L
.93334 .00394 L
.93533 .00394 L
.93725 .00394 L
.9391 .00394 L
.94003 .00394 L
.94106 .00394 L
.94153 .00394 L
.94204 .00394 L
.94228 .00394 L
.94252 .00394 L
.94273 .00394 L
.94278 .00394 L
.94284 .00394 L
.9429 .59441 L
.94295 .59441 L
.94396 .59441 L
.94488 .59441 L
.94535 .59441 L
.94578 .59441 L
.94589 .59441 L
.94595 .59441 L
.946 .59441 L
.94606 .00394 L
.94609 .00394 L
.94612 .00394 L
.94624 .00394 L
.94673 .00394 L
.94855 .00394 L
.95048 .00394 L
.95234 .00394 L
.95432 .00394 L
.95623 .00394 L
.95806 .00394 L
.96001 .00394 L
.96189 .00394 L
.96388 .00394 L
.9658 .00394 L
.96765 .00394 L
.96962 .00394 L
.97152 .00394 L
Mistroke
.97334 .00394 L
.97528 .00394 L
.97619 .00394 L
Mfstroke
0 0 1 r
.005 w
.02381 .00394 m
.02474 .00394 L
.02575 .00394 L
.0267 .00394 L
.02761 .00394 L
.02859 .00394 L
.02952 .00394 L
.03052 .00394 L
.03148 .00394 L
.0324 .00394 L
.03338 .00394 L
.03433 .00394 L
.03524 .00394 L
.03621 .00394 L
.03714 .00394 L
.03813 .00394 L
.03908 .00394 L
.04 .00394 L
.04098 .00394 L
.04192 .00394 L
.04292 .00394 L
.04388 .00394 L
.0448 .00394 L
.04579 .00394 L
.04674 .00394 L
.04765 .00394 L
.04862 .00394 L
.04956 .00394 L
.05055 .00394 L
.05151 .00394 L
.05243 .00394 L
.05341 .00394 L
.05435 .00394 L
.05526 .00394 L
.05622 .00394 L
.05715 .00394 L
.05814 .00394 L
.05909 .00394 L
.06001 .00394 L
.06098 .00394 L
.06192 .00394 L
.06292 .00394 L
.06388 .00394 L
.0648 .00394 L
.06579 .00394 L
.06673 .00394 L
.06764 .00394 L
.06861 .00394 L
.06954 .00394 L
.07054 .00394 L
Mistroke
.07149 .00394 L
.07241 .00394 L
.07339 .00394 L
.07433 .00394 L
.07533 .00394 L
.07629 .00394 L
.07722 .00394 L
.07821 .00394 L
.07916 .00394 L
.08007 .00394 L
.08104 .00394 L
.08198 .00394 L
.08297 .00394 L
.08393 .00394 L
.08485 .00394 L
.08584 .00394 L
.08678 .00394 L
.08769 .00394 L
.08866 .00394 L
.08959 .00394 L
.09058 .00394 L
.09153 .00394 L
.09245 .00394 L
.09342 .00394 L
.09436 .00394 L
.09536 .00394 L
.09632 .00394 L
.09725 .00394 L
.09823 .00394 L
.09918 .00394 L
.10009 .00394 L
.10106 .00394 L
.10199 .00394 L
.10299 .00394 L
.10394 .00394 L
.10486 .00394 L
.10584 .00394 L
.10678 .00394 L
.10769 .00394 L
.10866 .00394 L
.10958 .00394 L
.11057 .00394 L
.11152 .00394 L
.11244 .00394 L
.11341 .00394 L
.11435 .00394 L
.11535 .00394 L
.1163 .00394 L
.11723 .00394 L
.11821 .00394 L
Mistroke
.11916 .00394 L
.12007 .00394 L
.12103 .00394 L
.12197 .00394 L
.12296 .00394 L
.12391 .00394 L
.12483 .00394 L
.12581 .00394 L
.12675 .00394 L
.12775 .00394 L
.12871 .00394 L
.12964 .00394 L
.13062 .00394 L
.13157 .00394 L
.13248 .00394 L
.13345 .00394 L
.13439 .00394 L
.13538 .00394 L
.13634 .00394 L
.13726 .00394 L
.13824 .00394 L
.13919 .00394 L
.14009 .00394 L
.14106 .00394 L
.14199 .00394 L
.14298 .00394 L
.14393 .00394 L
.14485 .00394 L
.14582 .00394 L
.14676 .00394 L
.14776 .00394 L
.14872 .00394 L
.14964 .00394 L
.15063 .00394 L
.15158 .00394 L
.15249 .00394 L
.15346 .00394 L
.15439 .00394 L
.15538 .00394 L
.15634 .00394 L
.15726 .00394 L
.15823 .00394 L
.15918 .00394 L
.16018 .00394 L
.16114 .00394 L
.16207 .00394 L
.16306 .00394 L
.16401 .00394 L
.16492 .00394 L
.16589 .00394 L
Mistroke
.16683 .00394 L
.16782 .00394 L
.16878 .00394 L
.16971 .00394 L
.17069 .00394 L
.17163 .00394 L
.17254 .00394 L
.17351 .00394 L
.17444 .00394 L
.17543 .00394 L
.17638 .00394 L
.1773 .00394 L
.17828 .00394 L
.17922 .00394 L
.18022 .00394 L
.18118 .00394 L
.1821 .00394 L
.18309 .00394 L
.18404 .00394 L
.18495 .00394 L
.18592 .00394 L
.18685 .00394 L
.18785 .00394 L
.1888 .00394 L
.18972 .00394 L
.1907 .00394 L
.19165 .00394 L
.19255 .00394 L
.19352 .00394 L
.19445 .00394 L
.19544 .00394 L
.19639 .00394 L
.1973 .00394 L
.19828 .00394 L
.19922 .00394 L
.20021 .00394 L
.20117 .00394 L
.2021 .00394 L
.20308 .00394 L
.20403 .00394 L
.20494 .00394 L
.2059 .00394 L
.20684 .00394 L
.20783 .00394 L
.20878 .00394 L
.2097 .00394 L
.21068 .00394 L
.21162 .00394 L
.21262 .00394 L
.21358 .00394 L
Mistroke
.21451 .00394 L
.2155 .00394 L
.21645 .00394 L
.21736 .00394 L
.21833 .00394 L
.21927 .00394 L
.22026 .00394 L
.22122 .00394 L
.22214 .00394 L
.22312 .00394 L
.22407 .00394 L
.22497 .00394 L
.22594 .00394 L
.22687 .00394 L
.22786 .00394 L
.22881 .00394 L
.22973 .00394 L
.23071 .00394 L
.23164 .00394 L
.23264 .00394 L
.2336 .00394 L
.23453 .00394 L
.23551 .00394 L
.23646 .00394 L
.23737 .00394 L
.23834 .00394 L
.23928 .00394 L
.24027 .00394 L
.24122 .00394 L
.24214 .00394 L
.24312 .00394 L
.24406 .00394 L
.24497 .00394 L
.24594 .00394 L
.24686 .00394 L
.24785 .00394 L
.2488 .00394 L
.24972 .00394 L
.25069 .00394 L
.25163 .00394 L
.25262 .00394 L
.25358 .00394 L
.25451 .00394 L
.25549 .00394 L
.25643 .00394 L
.25734 .00394 L
.25831 .00394 L
.25924 .00394 L
.26023 .00394 L
.26119 .00394 L
Mistroke
.2621 .00394 L
.26308 .00394 L
.26402 .00394 L
.26502 .00394 L
.26598 .00394 L
.26691 .00394 L
.26789 .00394 L
.26884 .00394 L
.26976 .00394 L
.27073 .00394 L
.27166 .00394 L
.27266 .00394 L
.27361 .00394 L
.27453 .00394 L
.27551 .00394 L
.27646 .00394 L
.27736 .00394 L
.27833 .00394 L
.27926 .00394 L
.28025 .00394 L
.2812 .00394 L
.28212 .00394 L
.28309 .00394 L
.28403 .00394 L
.28503 .00394 L
.28599 .00394 L
.28691 .00394 L
.28789 .00394 L
.28884 .00394 L
.28975 .00394 L
.29072 .00394 L
.29165 .00394 L
.29265 .00394 L
.2936 .00394 L
.29452 .00394 L
.2955 .00394 L
.29644 .00394 L
.29744 .00394 L
.2984 .00394 L
.29933 .00394 L
.30032 .00394 L
.30127 .00394 L
.30218 .00394 L
.30315 .00394 L
.30409 .00394 L
.30509 .00394 L
.30604 .00394 L
.30697 .00394 L
.30795 .00394 L
.30889 .00394 L
Mistroke
.3098 .00394 L
.31077 .00394 L
.3117 .00394 L
.31269 .00394 L
.31364 .00394 L
.31456 .00394 L
.31554 .00394 L
.31647 .00394 L
.31747 .00394 L
.31844 .00394 L
.31936 .00394 L
.32035 .00394 L
.32129 .00394 L
.3222 .00394 L
.32318 .00394 L
.32411 .00394 L
.3251 .00394 L
.32606 .00394 L
.32698 .00394 L
.32796 .00394 L
.3289 .00394 L
.32981 .00394 L
.33077 .00394 L
.3317 .00394 L
.33269 .00394 L
.33364 .00394 L
.33456 .00394 L
.33553 .00394 L
.33647 .00394 L
.33746 .00394 L
.33842 .00394 L
.33935 .00394 L
.34033 .00394 L
.34128 .00394 L
.34218 .00394 L
.34315 .00394 L
.34409 .00394 L
.34508 .00394 L
.34603 .00394 L
.34695 .00394 L
.34793 .00394 L
.34887 .00394 L
.34987 .00394 L
.35083 .00394 L
.35176 .00394 L
.35274 .00394 L
.35369 .00394 L
.3546 .00394 L
.35558 .00394 L
.35651 .00394 L
Mistroke
.35751 .00394 L
.35846 .00394 L
.35939 .00394 L
.36037 .00394 L
.36131 .00394 L
.36222 .00394 L
.36318 .00394 L
.36411 .00394 L
.3651 .00394 L
.36606 .00394 L
.36697 .00394 L
.36795 .00394 L
.36889 .00394 L
.36988 .00394 L
.37038 .00394 L
.37084 .00394 L
.37129 .00394 L
.37152 .00394 L
.37158 .00394 L
.37165 .00394 L
.37168 .00394 L
.37171 .00394 L
.37174 .00394 L
.37177 .39759 L
.37179 .39759 L
.3718 .39759 L
.37183 .39759 L
.3719 .39759 L
.37202 .39759 L
.37224 .39759 L
.37275 .39759 L
.37366 .39759 L
.3739 .39759 L
.37413 .39759 L
.37419 .39759 L
.37423 .39759 L
.37426 .39759 L
.37427 .39759 L
.37429 .00394 L
.37431 .00394 L
.37433 .00394 L
.3744 .00394 L
.37464 .00394 L
.37559 .00394 L
.37651 .00394 L
.37748 .00394 L
.37842 .00394 L
.37942 .00394 L
.38038 .00394 L
.38131 .00394 L
Mistroke
.3823 .00394 L
.38324 .00394 L
.38416 .00394 L
.38513 .00394 L
.38606 .00394 L
.38705 .00394 L
.38801 .00394 L
.38893 .00394 L
.38991 .00394 L
.39086 .00394 L
.39176 .00394 L
.39273 .00394 L
.39366 .00394 L
.39465 .00394 L
.3956 .00394 L
.39651 .00394 L
.39749 .00394 L
.39843 .00394 L
.39942 .00394 L
.40038 .00394 L
.40131 .00394 L
.40229 .00394 L
.40324 .00394 L
.40415 .00394 L
.40511 .00394 L
.40605 .00394 L
.40704 .00394 L
.40799 .00394 L
.40891 .00394 L
.40989 .00394 L
.41083 .00394 L
.41183 .00394 L
.4128 .00394 L
.41372 .00394 L
.41471 .00394 L
.41566 .00394 L
.41657 .00394 L
.41754 .00394 L
.41848 .00394 L
.41948 .00394 L
.42043 .00394 L
.42136 .00394 L
.42234 .00394 L
.42328 .00394 L
.42419 .00394 L
.42516 .00394 L
.42609 .00394 L
.42708 .00394 L
.42803 .00394 L
.42895 .00394 L
Mistroke
.42992 .00394 L
.43086 .00394 L
.43186 .00394 L
.43282 .00394 L
.43375 .00394 L
.43421 .00394 L
.43473 .00394 L
.43497 .00394 L
.4351 .00394 L
.43516 .00394 L
.43519 .00394 L
.43522 .00394 L
.43525 .20076 L
.43528 .20076 L
.43533 .20076 L
.43546 .20076 L
.43568 .20076 L
.43661 .20076 L
.43708 .20076 L
.43733 .20076 L
.43746 .20076 L
.43759 .20076 L
.43765 .20076 L
.43772 .20076 L
.43775 .20076 L
.43777 .20076 L
.43779 .00394 L
.43782 .00394 L
.43785 .00394 L
.43809 .00394 L
.43854 .00394 L
.43954 .00394 L
.44049 .00394 L
.44141 .00394 L
.44238 .00394 L
.44332 .00394 L
.44432 .00394 L
.44529 .00394 L
.44621 .00394 L
.4472 .00394 L
.44815 .00394 L
.44906 .00394 L
.45003 .00394 L
.45097 .00394 L
.45196 .00394 L
.45292 .00394 L
.45384 .00394 L
.45482 .00394 L
.45576 .00394 L
.45667 .00394 L
Mistroke
.45764 .00394 L
.45857 .00394 L
.45956 .00394 L
.46051 .00394 L
.46142 .00394 L
.4624 .00394 L
.46334 .00394 L
.46433 .00394 L
.4653 .00394 L
.46622 .00394 L
.4672 .00394 L
.46815 .00394 L
.46906 .00394 L
.47003 .00394 L
.47096 .00394 L
.47196 .00394 L
.47291 .00394 L
.47383 .00394 L
.47481 .00394 L
.47575 .00394 L
.47675 .00394 L
.47771 .00394 L
.47864 .00394 L
.47963 .00394 L
.48058 .00394 L
.48149 .00394 L
.48247 .00394 L
.4834 .00394 L
.4844 .00394 L
.48536 .00394 L
.48628 .00394 L
.48726 .00394 L
.48821 .00394 L
.48911 .00394 L
.49008 .00394 L
.49101 .00394 L
.492 .00394 L
.49296 .00394 L
.49387 .00394 L
.49485 .00394 L
.49579 .00394 L
.49679 .00394 L
.49775 .00394 L
.49819 .00394 L
.49844 .00394 L
.49856 .00394 L
.49862 .00394 L
.49867 .00394 L
.4987 .00394 L
.49873 .20076 L
Mistroke
.49876 .20076 L
.49879 .20076 L
.49891 .20076 L
.49915 .20076 L
.49966 .20076 L
.50016 .20076 L
.50063 .20076 L
.50086 .20076 L
.50108 .20076 L
.50119 .20076 L
.50122 .20076 L
.50125 .20076 L
.50128 .00394 L
.50131 .00394 L
.50155 .00394 L
.50254 .00394 L
.50348 .00394 L
.50439 .00394 L
.50536 .00394 L
.50629 .00394 L
.50728 .00394 L
.50824 .00394 L
.50916 .00394 L
.51014 .00394 L
.51108 .00394 L
.51208 .00394 L
.51304 .00394 L
.51397 .00394 L
.51495 .00394 L
.5159 .00394 L
.51682 .00394 L
.51779 .00394 L
.51872 .00394 L
.51972 .00394 L
.52068 .00394 L
.5216 .00394 L
.52258 .00394 L
.52352 .00394 L
.52443 .00394 L
.5254 .00394 L
.52633 .00394 L
.52732 .00394 L
.52827 .00394 L
.52918 .00394 L
.53016 .00394 L
.5311 .00394 L
.5321 .00394 L
.53306 .00394 L
.53398 .00394 L
.53497 .00394 L
Mistroke
.53591 .00394 L
.53683 .00394 L
.5378 .00394 L
.53873 .00394 L
.53972 .00394 L
.54068 .00394 L
.5416 .00394 L
.54258 .00394 L
.54352 .00394 L
.54442 .00394 L
.54539 .00394 L
.54632 .00394 L
.5473 .00394 L
.54825 .00394 L
.54917 .00394 L
.55014 .00394 L
.55108 .00394 L
.55207 .00394 L
.55303 .00394 L
.55396 .00394 L
.55494 .00394 L
.55588 .00394 L
.55679 .00394 L
.55776 .00394 L
.55869 .00394 L
.55968 .00394 L
.56064 .00394 L
.56155 .00394 L
.5618 .00394 L
.56203 .00394 L
.56209 .00394 L
.56215 .00394 L
.56219 .00394 L
.56221 .00394 L
.56223 .20076 L
.56226 .20076 L
.56229 .20076 L
.56253 .20076 L
.56352 .20076 L
.56402 .20076 L
.56424 .20076 L
.56448 .20076 L
.56459 .20076 L
.56465 .20076 L
.56468 .20076 L
.56471 .20076 L
.56474 .20076 L
.56477 .00394 L
.5648 .00394 L
.56483 .00394 L
Mistroke
.56493 .00394 L
.5654 .00394 L
.56636 .00394 L
.56729 .00394 L
.56827 .00394 L
.56922 .00394 L
.57013 .00394 L
.5711 .00394 L
.57203 .00394 L
.57302 .00394 L
.57398 .00394 L
.5749 .00394 L
.57587 .00394 L
.57682 .00394 L
.57782 .00394 L
.57878 .00394 L
.57971 .00394 L
.58069 .00394 L
.58164 .00394 L
.58256 .00394 L
.58353 .00394 L
.58447 .00394 L
.58546 .00394 L
.58642 .00394 L
.58734 .00394 L
.58832 .00394 L
.58927 .00394 L
.59017 .00394 L
.59114 .00394 L
.59207 .00394 L
.59306 .00394 L
.59402 .00394 L
.59493 .00394 L
.59591 .00394 L
.59685 .00394 L
.59785 .00394 L
.59881 .00394 L
.59973 .00394 L
.60072 .00394 L
.60167 .00394 L
.60258 .00394 L
.60355 .00394 L
.60448 .00394 L
.60547 .00394 L
.60643 .00394 L
.60735 .00394 L
.60833 .00394 L
.60927 .00394 L
.61018 .00394 L
.61114 .00394 L
Mistroke
.61207 .00394 L
.61306 .00394 L
.61401 .00394 L
.61493 .00394 L
.6159 .00394 L
.61684 .00394 L
.61783 .00394 L
.61879 .00394 L
.61972 .00394 L
.6207 .00394 L
.62165 .00394 L
.62255 .00394 L
.62352 .00394 L
.62446 .00394 L
.62493 .00394 L
.62518 .00394 L
.62545 .00394 L
.62558 .00394 L
.62565 .00394 L
.62567 .00394 L
.62571 .00394 L
.62573 .39759 L
.62576 .39759 L
.62582 .39759 L
.62594 .39759 L
.6264 .39759 L
.62734 .39759 L
.62758 .39759 L
.62785 .39759 L
.62797 .39759 L
.6281 .39759 L
.62815 .39759 L
.62821 .39759 L
.62822 .39759 L
.62824 .39759 L
.62827 .00394 L
.6283 .00394 L
.62833 .00394 L
.62931 .00394 L
.63024 .00394 L
.63124 .00394 L
.6322 .00394 L
.63313 .00394 L
.63411 .00394 L
.63506 .00394 L
.63597 .00394 L
.63694 .00394 L
.63787 .00394 L
.63886 .00394 L
.63982 .00394 L
Mistroke
.64074 .00394 L
.64172 .00394 L
.64266 .00394 L
.64366 .00394 L
.64462 .00394 L
.64555 .00394 L
.64654 .00394 L
.64749 .00394 L
.6484 .00394 L
.64938 .00394 L
.65031 .00394 L
.65131 .00394 L
.65227 .00394 L
.65319 .00394 L
.65417 .00394 L
.65512 .00394 L
.65603 .00394 L
.65699 .00394 L
.65792 .00394 L
.65891 .00394 L
.65987 .00394 L
.66079 .00394 L
.66176 .00394 L
.6627 .00394 L
.6637 .00394 L
.66466 .00394 L
.66559 .00394 L
.66657 .00394 L
.66752 .00394 L
.66843 .00394 L
.6694 .00394 L
.67034 .00394 L
.67133 .00394 L
.67229 .00394 L
.67321 .00394 L
.67419 .00394 L
.67513 .00394 L
.67604 .00394 L
.67701 .00394 L
.67793 .00394 L
.67892 .00394 L
.67987 .00394 L
.68079 .00394 L
.68176 .00394 L
.6827 .00394 L
.6837 .00394 L
.68466 .00394 L
.68558 .00394 L
.68657 .00394 L
.68751 .00394 L
Mistroke
.68842 .00394 L
.68939 .00394 L
.69032 .00394 L
.69131 .00394 L
.69227 .00394 L
.69319 .00394 L
.69417 .00394 L
.69511 .00394 L
.69611 .00394 L
.69707 .00394 L
.698 .00394 L
.69898 .00394 L
.69993 .00394 L
.70085 .00394 L
.70182 .00394 L
.70275 .00394 L
.70375 .00394 L
.70471 .00394 L
.70563 .00394 L
.70661 .00394 L
.70755 .00394 L
.70846 .00394 L
.70943 .00394 L
.71036 .00394 L
.71135 .00394 L
.7123 .00394 L
.71322 .00394 L
.71419 .00394 L
.71513 .00394 L
.71613 .00394 L
.71709 .00394 L
.71802 .00394 L
.719 .00394 L
.71995 .00394 L
.72086 .00394 L
.72183 .00394 L
.72276 .00394 L
.72376 .00394 L
.72471 .00394 L
.72563 .00394 L
.72661 .00394 L
.72755 .00394 L
.72846 .00394 L
.72942 .00394 L
.73035 .00394 L
.73134 .00394 L
.73229 .00394 L
.73321 .00394 L
.73418 .00394 L
.73512 .00394 L
Mistroke
.73611 .00394 L
.73707 .00394 L
.738 .00394 L
.73898 .00394 L
.73992 .00394 L
.74083 .00394 L
.7418 .00394 L
.74273 .00394 L
.74372 .00394 L
.74468 .00394 L
.74559 .00394 L
.74657 .00394 L
.74751 .00394 L
.74851 .00394 L
.74947 .00394 L
.7504 .00394 L
.75139 .00394 L
.75233 .00394 L
.75325 .00394 L
.75422 .00394 L
.75515 .00394 L
.75615 .00394 L
.7571 .00394 L
.75803 .00394 L
.75901 .00394 L
.75995 .00394 L
.76086 .00394 L
.76182 .00394 L
.76275 .00394 L
.76374 .00394 L
.76469 .00394 L
.76561 .00394 L
.76658 .00394 L
.76752 .00394 L
.76852 .00394 L
.76948 .00394 L
.7704 .00394 L
.77139 .00394 L
.77233 .00394 L
.77324 .00394 L
.77421 .00394 L
.77515 .00394 L
.77614 .00394 L
.77709 .00394 L
.77801 .00394 L
.77899 .00394 L
.77993 .00394 L
.78093 .00394 L
.7819 .00394 L
.78283 .00394 L
Mistroke
.78381 .00394 L
.78476 .00394 L
.78568 .00394 L
.78665 .00394 L
.78758 .00394 L
.78858 .00394 L
.78954 .00394 L
.79046 .00394 L
.79144 .00394 L
.79239 .00394 L
.7933 .00394 L
.79426 .00394 L
.79519 .00394 L
.79618 .00394 L
.79714 .00394 L
.79805 .00394 L
.79903 .00394 L
.79997 .00394 L
.80097 .00394 L
.80193 .00394 L
.80286 .00394 L
.80384 .00394 L
.80479 .00394 L
.8057 .00394 L
.80667 .00394 L
.8076 .00394 L
.8086 .00394 L
.80955 .00394 L
.81047 .00394 L
.81145 .00394 L
.8124 .00394 L
.8133 .00394 L
.81427 .00394 L
.8152 .00394 L
.81619 .00394 L
.81714 .00394 L
.81805 .00394 L
.81903 .00394 L
.81996 .00394 L
.82096 .00394 L
.82192 .00394 L
.82284 .00394 L
.82383 .00394 L
.82477 .00394 L
.82568 .00394 L
.82665 .00394 L
.82758 .00394 L
.82857 .00394 L
.82953 .00394 L
.83045 .00394 L
Mistroke
.83142 .00394 L
.83236 .00394 L
.83336 .00394 L
.83433 .00394 L
.83525 .00394 L
.83624 .00394 L
.83719 .00394 L
.8381 .00394 L
.83907 .00394 L
.84001 .00394 L
.841 .00394 L
.84196 .00394 L
.84288 .00394 L
.84386 .00394 L
.84481 .00394 L
.84572 .00394 L
.84668 .00394 L
.84761 .00394 L
.8486 .00394 L
.84955 .00394 L
.85047 .00394 L
.85145 .00394 L
.85238 .00394 L
.85338 .00394 L
.85434 .00394 L
.85527 .00394 L
.85625 .00394 L
.8572 .00394 L
.85811 .00394 L
.85908 .00394 L
.86001 .00394 L
.86101 .00394 L
.86196 .00394 L
.86288 .00394 L
.86386 .00394 L
.8648 .00394 L
.8658 .00394 L
.86677 .00394 L
.8677 .00394 L
.86868 .00394 L
.86963 .00394 L
.87055 .00394 L
.87152 .00394 L
.87246 .00394 L
.87345 .00394 L
.87441 .00394 L
.87533 .00394 L
.87632 .00394 L
.87726 .00394 L
.87817 .00394 L
Mistroke
.87914 .00394 L
.88007 .00394 L
.88106 .00394 L
.88201 .00394 L
.88293 .00394 L
.88391 .00394 L
.88485 .00394 L
.88585 .00394 L
.88681 .00394 L
.88774 .00394 L
.88872 .00394 L
.88967 .00394 L
.89058 .00394 L
.89155 .00394 L
.89249 .00394 L
.89348 .00394 L
.89444 .00394 L
.89536 .00394 L
.89634 .00394 L
.89728 .00394 L
.89819 .00394 L
.89915 .00394 L
.90008 .00394 L
.90107 .00394 L
.90202 .00394 L
.90294 .00394 L
.90391 .00394 L
.90485 .00394 L
.90585 .00394 L
.90681 .00394 L
.90773 .00394 L
.90872 .00394 L
.90966 .00394 L
.91057 .00394 L
.91154 .00394 L
.91248 .00394 L
.91347 .00394 L
.91442 .00394 L
.91534 .00394 L
.91632 .00394 L
.91726 .00394 L
.91826 .00394 L
.91922 .00394 L
.92015 .00394 L
.92114 .00394 L
.92209 .00394 L
.923 .00394 L
.92397 .00394 L
.92491 .00394 L
.9259 .00394 L
Mistroke
.92686 .00394 L
.92778 .00394 L
.92877 .00394 L
.92971 .00394 L
.93062 .00394 L
.93158 .00394 L
.93252 .00394 L
.93351 .00394 L
.93446 .00394 L
.93537 .00394 L
.93635 .00394 L
.93729 .00394 L
.93829 .00394 L
.93925 .00394 L
.94018 .00394 L
.94116 .00394 L
.94211 .00394 L
.94302 .00394 L
.94399 .00394 L
.94492 .00394 L
.94592 .00394 L
.94687 .00394 L
.94779 .00394 L
.94877 .00394 L
.94971 .00394 L
.95062 .00394 L
.95158 .00394 L
.95251 .00394 L
.9535 .00394 L
.95445 .00394 L
.95537 .00394 L
.95634 .00394 L
.95728 .00394 L
.95827 .00394 L
.95923 .00394 L
.96016 .00394 L
.96114 .00394 L
.96208 .00394 L
.96299 .00394 L
.96396 .00394 L
.96489 .00394 L
.96588 .00394 L
.96684 .00394 L
.96776 .00394 L
.96873 .00394 L
.96967 .00394 L
.97067 .00394 L
.97164 .00394 L
.97256 .00394 L
.97355 .00394 L
Mistroke
.9745 .00394 L
.97541 .00394 L
.97619 .00394 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.196383 0.0581337 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -12 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .31265 -6 -4.5 ]
[-0.0125 .31265 0 4.5 ]
[-0.0125 .42892 -6 -4.5 ]
[-0.0125 .42892 0 4.5 ]
[-0.0125 .54519 -6 -4.5 ]
[-0.0125 .54519 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(1)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(2)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(3)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(4)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(-2)] -0.0125 .08012 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(0)] -0.0125 .19638 1 0 Mshowa
0 .31265 m
.00625 .31265 L
s
[(2)] -0.0125 .31265 1 0 Mshowa
0 .42892 m
.00625 .42892 L
s
[(4)] -0.0125 .42892 1 0 Mshowa
0 .54519 m
.00625 .54519 L
s
[(6)] -0.0125 .54519 1 0 Mshowa
.125 Mabswid
0 .10918 m
.00375 .10918 L
s
0 .13825 m
.00375 .13825 L
s
0 .16732 m
.00375 .16732 L
s
0 .22545 m
.00375 .22545 L
s
0 .25452 m
.00375 .25452 L
s
0 .28358 m
.00375 .28358 L
s
0 .34172 m
.00375 .34172 L
s
0 .37078 m
.00375 .37078 L
s
0 .39985 m
.00375 .39985 L
s
0 .45798 m
.00375 .45798 L
s
0 .48705 m
.00375 .48705 L
s
0 .51612 m
.00375 .51612 L
s
0 .05105 m
.00375 .05105 L
s
0 .02198 m
.00375 .02198 L
s
0 .57425 m
.00375 .57425 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .31265 m
1 .31265 L
s
.99375 .42892 m
1 .42892 L
s
.99375 .54519 m
1 .54519 L
s
.125 Mabswid
.99625 .10918 m
1 .10918 L
s
.99625 .13825 m
1 .13825 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .22545 m
1 .22545 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .28358 m
1 .28358 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .37078 m
1 .37078 L
s
.99625 .39985 m
1 .39985 L
s
.99625 .45798 m
1 .45798 L
s
.99625 .48705 m
1 .48705 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .02198 m
1 .02198 L
s
.99625 .57425 m
1 .57425 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .19638 m
1 .19638 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.02381 .60332 m
.02409 .60327 L
.02435 .60315 L
.02465 .60291 L
.02494 .6026 L
.02544 .60181 L
.02599 .60063 L
.02659 .59894 L
.02722 .5967 L
.02837 .59157 L
.03066 .57704 L
.03318 .55482 L
.03845 .48973 L
.04339 .4114 L
.05279 .24379 L
.05757 .16395 L
.06278 .0915 L
.0652 .06507 L
.06778 .04268 L
.06903 .0341 L
.07021 .02743 L
.07126 .02263 L
.07241 .01871 L
.07298 .01724 L
.0733 .01658 L
.0736 .01604 L
.07388 .01562 L
.07418 .01526 L
.07446 .01501 L
.07471 .01485 L
.07501 .01474 L
.0753 .01472 L
.07561 .01479 L
.07578 .01487 L
.07594 .01497 L
.07624 .01523 L
.07657 .01561 L
.07724 .01672 L
.07791 .01826 L
.07852 .02003 L
.07989 .02524 L
.08115 .03157 L
.08235 .03879 L
.0872 .07912 L
.09167 .12835 L
.10123 .24727 L
.10603 .30069 L
.11041 .33874 L
.11157 .34657 L
.11283 .35393 L
Mistroke
.11404 .35977 L
.11513 .36402 L
.11574 .36596 L
.1164 .36769 L
.1171 .3691 L
.11741 .3696 L
.11775 .37004 L
.11807 .37036 L
.11837 .37058 L
.11869 .37073 L
.11886 .37077 L
.11902 .37078 L
.11931 .37075 L
.11962 .37064 L
.11992 .37045 L
.12019 .37021 L
.12048 .36988 L
.12078 .36946 L
.12132 .36851 L
.1219 .3672 L
.12253 .36544 L
.12367 .36141 L
.12473 .35669 L
.12714 .34252 L
.12972 .32259 L
.13491 .27024 L
.1398 .21108 L
.14913 .0974 L
.15396 .05168 L
.15639 .03472 L
.15778 .02724 L
.15907 .02176 L
.16028 .01801 L
.16096 .01651 L
.16129 .01595 L
.1616 .01552 L
.16186 .01522 L
.16215 .01497 L
.16247 .0148 L
.16276 .01472 L
.16305 .01473 L
.16336 .01484 L
.16352 .01493 L
.16369 .01505 L
.16399 .01535 L
.1643 .01574 L
.16457 .01618 L
.1652 .01746 L
.16576 .01892 L
.16635 .02081 L
Mistroke
.16737 .02492 L
.16849 .03065 L
.17095 .04758 L
.1732 .06811 L
.17826 .13016 L
.18789 .29 L
.19716 .45192 L
.20233 .52571 L
.20477 .5533 L
.20702 .57375 L
.20936 .58964 L
.2106 .59562 L
.21123 .59802 L
.2119 .60009 L
.2125 .6015 L
.21304 .60243 L
.2133 .60277 L
.21358 .60304 L
.21385 .60321 L
.2141 .6033 L
.21438 .60331 L
.21465 .60324 L
.21495 .60307 L
.21527 .60277 L
.21558 .60236 L
.21591 .60181 L
.21651 .60052 L
.21713 .59872 L
.21772 .59663 L
.21882 .59168 L
.22001 .58487 L
.2213 .5758 L
.22575 .53171 L
.23057 .46515 L
.23567 .38002 L
.24486 .21607 L
.24998 .13491 L
.25465 .0757 L
.25696 .05313 L
.25818 .04321 L
.25948 .03424 L
.26073 .02719 L
.26186 .02216 L
.26241 .02019 L
.263 .0184 L
.26356 .01703 L
.26406 .01606 L
.26434 .01564 L
.26464 .01528 L
.26496 .01499 L
Mistroke
.26526 .01481 L
.26554 .01473 L
.26584 .01472 L
.2661 .01479 L
.26638 .01494 L
.26655 .01507 L
.26671 .01521 L
.26701 .01556 L
.26769 .01665 L
.26827 .01795 L
.26891 .01975 L
.27019 .0245 L
.27156 .03118 L
.27402 .04717 L
.27921 .09495 L
.2841 .15207 L
.29344 .26771 L
.29818 .31668 L
.30087 .33859 L
.30216 .34728 L
.30338 .35432 L
.30454 .35988 L
.30579 .36466 L
.30635 .36634 L
.30694 .36783 L
.30749 .36896 L
.308 .36975 L
.30828 .3701 L
.30858 .37039 L
.30888 .3706 L
.30905 .37069 L
.30921 .37074 L
.3095 .37078 L
.30976 .37076 L
.31006 .37065 L
.31035 .37048 L
.31067 .37021 L
.311 .36982 L
.3116 .36888 L
.31224 .36752 L
.31295 .36561 L
.31421 .36114 L
.31541 .35565 L
.31766 .34223 L
.32008 .32358 L
.32273 .29887 L
.33259 .18173 L
.33715 .12531 L
.34208 .07219 L
.34479 .04892 L
Mistroke
.34598 .04039 L
.34728 .03232 L
.34843 .02639 L
.34966 .02133 L
.35034 .01913 L
.35096 .01751 L
.35159 .01624 L
.35187 .01579 L
.35217 .01539 L
.35247 .01509 L
.35275 .01489 L
.35301 .01477 L
.35329 .01472 L
.35359 .01475 L
.35388 .01486 L
.35419 .01507 L
.35436 .01523 L
.35452 .01541 L
.35513 .01632 L
.35548 .01701 L
.3558 .01775 L
.35701 .02147 L
.35804 .02584 L
.35918 .03188 L
.36148 .04798 L
.36394 .07087 L
.3662 .09647 L
.37127 .16804 L
.38091 .33603 L
.39019 .49078 L
.39498 .55056 L
.3974 .57301 L
.3987 .58265 L
.40007 .59088 L
.40124 .59627 L
.40185 .59851 L
.40251 .60044 L
.40282 .60118 L
.40312 .60178 L
.40341 .60227 L
.40367 .60264 L
.40392 .60292 L
.40419 .60313 L
.40446 .60327 L
.40475 .60332 L
.40491 .60331 L
.40509 .60326 L
.40541 .60308 L
.40572 .6028 L
.40601 .60243 L
Mistroke
.40635 .60188 L
.40666 .60126 L
.40736 .59948 L
.40797 .59749 L
.40862 .59488 L
.40981 .58896 L
.41211 .57312 L
.41464 .54953 L
.41975 .48471 L
.42955 .31903 L
.43898 .15677 L
.44145 .12088 L
.44413 .08679 L
.44645 .06212 L
.44901 .04059 L
.4502 .03272 L
.45149 .02582 L
.4527 .02082 L
.45381 .01754 L
.45442 .01626 L
.45472 .01579 L
.45499 .01542 L
.45515 .01525 L
.45532 .01508 L
.45562 .01487 L
.45579 .01479 L
.45597 .01474 L
.45612 .01472 L
.45629 .01472 L
.45646 .01476 L
.45663 .01482 L
.45694 .015 L
.45711 .01515 L
.45727 .01531 L
.45764 .01577 L
.45825 .01683 L
.4589 .01835 L
.4602 .0226 L
.4614 .02787 L
.4641 .04428 L
.46648 .06342 L
.469 .08767 L
.47822 .19798 L
.48335 .26118 L
.48803 .31092 L
.49036 .33113 L
.49289 .34882 L
.49404 .3553 L
.49527 .36097 L
.49632 .36482 L
Mistroke
.49748 .36797 L
.49808 .36915 L
.4984 .36965 L
.49874 .37008 L
.49906 .37039 L
.49936 .3706 L
.49965 .37073 L
.49993 .37078 L
.5002 .37077 L
.50049 .37068 L
.50074 .37054 L
.50101 .37033 L
.5013 .37003 L
.50161 .36963 L
.50218 .36869 L
.50283 .36725 L
.50354 .36527 L
.50482 .36058 L
.50724 .34807 L
.50951 .33214 L
.51203 .31037 L
.51712 .25564 L
.52686 .13451 L
.53133 .08427 L
.53387 .06032 L
.53623 .04192 L
.53858 .02797 L
.53989 .02224 L
.54109 .01839 L
.54174 .01684 L
.54235 .01579 L
.54266 .01538 L
.54301 .01504 L
.54319 .01491 L
.54337 .01481 L
.54355 .01475 L
.54371 .01472 L
.54403 .01474 L
.54432 .01484 L
.54449 .01494 L
.54465 .01506 L
.54499 .0154 L
.54529 .0158 L
.54561 .01633 L
.5462 .01756 L
.54678 .01911 L
.54739 .02114 L
.54851 .02578 L
.54983 .03293 L
.55104 .04095 L
Mistroke
.55366 .06324 L
.55615 .09009 L
.56544 .22957 L
.57534 .40593 L
.58025 .48472 L
.58266 .51787 L
.58486 .5442 L
.58697 .56528 L
.58927 .5833 L
.59047 .59048 L
.59159 .59576 L
.59219 .59806 L
.59276 .59984 L
.59342 .60145 L
.59371 .60199 L
.59402 .60248 L
.59433 .60284 L
.5946 .60309 L
.59488 .60325 L
.59515 .60331 L
.59545 .60329 L
.59574 .60318 L
.59605 .60294 L
.59622 .60277 L
.59638 .60257 L
.597 .60155 L
.59735 .60079 L
.59767 .59996 L
.59888 .59581 L
.59992 .59094 L
.60106 .58426 L
.60335 .56664 L
.60584 .54171 L
.6081 .51423 L
.61317 .43891 L
.62285 .26805 L
.63216 .11766 L
.63697 .06173 L
.6394 .04126 L
.64077 .0322 L
.64207 .02532 L
.64324 .02058 L
.64391 .01851 L
.64453 .01699 L
.64482 .01641 L
.6451 .01593 L
.64535 .01557 L
.64561 .01526 L
.6459 .015 L
.64617 .01483 L
Mistroke
.64646 .01473 L
.64677 .01472 L
.64694 .01475 L
.64711 .01482 L
.64728 .01491 L
.64743 .01502 L
.64773 .01528 L
.64804 .01566 L
.64868 .01673 L
.64939 .01839 L
.65065 .02249 L
.65183 .02766 L
.65422 .04173 L
.65673 .06136 L
.66121 .10646 L
.67045 .22014 L
.6756 .28122 L
.68028 .32665 L
.68262 .34411 L
.68385 .35167 L
.68515 .35836 L
.68629 .36307 L
.68689 .36512 L
.68754 .36698 L
.68814 .36836 L
.68868 .36936 L
.68894 .36974 L
.68923 .37009 L
.68948 .37034 L
.68975 .37055 L
.6899 .37064 L
.69007 .37071 L
.69037 .37078 L
.69053 .37078 L
.69071 .37076 L
.69088 .37071 L
.69104 .37064 L
.69134 .37046 L
.69151 .37031 L
.69166 .37016 L
.69225 .36939 L
.69278 .36845 L
.69335 .36713 L
.69452 .36358 L
.69579 .35843 L
.69715 .35142 L
.69961 .33506 L
.70448 .29062 L
.7096 .23143 L
.71885 .11665 L
Mistroke
.7215 .08744 L
.72401 .0633 L
.72644 .04377 L
.72751 .03661 L
.72869 .02983 L
.72976 .02471 L
.7309 .02035 L
.73153 .01846 L
.73211 .01707 L
.73269 .01599 L
.73297 .01558 L
.73324 .01527 L
.73352 .01501 L
.73383 .01482 L
.73414 .01473 L
.73431 .01472 L
.73446 .01473 L
.73473 .01481 L
.73502 .01497 L
.73532 .01524 L
.7356 .01556 L
.73625 .01663 L
.73684 .01797 L
.73752 .01995 L
.73817 .02226 L
.74052 .03423 L
.74171 .04236 L
.74301 .05288 L
.74748 .1006 L
.75219 .16762 L
.75725 .25296 L
.76725 .4302 L
.77225 .50611 L
.77468 .53673 L
.77688 .56004 L
.77919 .57943 L
.78025 .58648 L
.78136 .59262 L
.78194 .59523 L
.78256 .59768 L
.78314 .59954 L
.78366 .60092 L
.78428 .60215 L
.78462 .60264 L
.78478 .60282 L
.78495 .60298 L
.78524 .60319 L
.78552 .6033 L
.78582 .60331 L
.78598 .60328 L
Mistroke
.78614 .60321 L
.78643 .60303 L
.78673 .60273 L
.78702 .60235 L
.78728 .60192 L
.78792 .60054 L
.78853 .59882 L
.78973 .59417 L
.79104 .58733 L
.79337 .57056 L
.79553 .55024 L
.80008 .4937 L
.80508 .41503 L
.81486 .24079 L
.81937 .16554 L
.82428 .09644 L
.82695 .06664 L
.82942 .04468 L
.83178 .02917 L
.8331 .02292 L
.83367 .02076 L
.83429 .01877 L
.83486 .0173 L
.83548 .01609 L
.83582 .01558 L
.83613 .01522 L
.83644 .01496 L
.83673 .0148 L
.837 .01472 L
.83729 .01473 L
.83753 .01479 L
.8378 .01494 L
.83809 .01517 L
.8384 .01552 L
.83897 .01638 L
.83961 .01775 L
.84032 .01969 L
.84161 .02443 L
.84286 .03047 L
.84402 .03728 L
.84899 .07799 L
.8535 .12742 L
.86321 .24822 L
.86766 .29799 L
.87019 .32185 L
.87255 .34042 L
.87488 .35471 L
.87619 .36083 L
.87738 .36517 L
.87799 .36692 L
Mistroke
.87864 .36842 L
.87898 .36906 L
.87935 .36964 L
.87969 .37008 L
.88 .37039 L
.8803 .3706 L
.88062 .37074 L
.88094 .37078 L
.88112 .37077 L
.88129 .37073 L
.88159 .3706 L
.88187 .37041 L
.88219 .37011 L
.88249 .36974 L
.88307 .36881 L
.88361 .36767 L
.88484 .36412 L
.88605 .35942 L
.88734 .35303 L
.88967 .33812 L
.89181 .32102 L
.90144 .21431 L
.91071 .10096 L
.91549 .05473 L
.91816 .03559 L
.91931 .02909 L
.92057 .02329 L
.92176 .01917 L
.9224 .01747 L
.92301 .01625 L
.9233 .01579 L
.92357 .01543 L
.92382 .01516 L
.92409 .01495 L
.92438 .01479 L
.92464 .01472 L
.92493 .01473 L
.92525 .01483 L
.92556 .01503 L
.92573 .01517 L
.9259 .01535 L
.9265 .01621 L
.92684 .01686 L
.9272 .01768 L
.92785 .01948 L
.92913 .02429 L
.9303 .03009 L
.93272 .04649 L
.93495 .06658 L
.94 .12776 L
Mistroke
.94956 .28566 L
.95875 .44693 L
.96387 .52113 L
.9661 .54732 L
.96854 .57063 L
.97058 .58557 L
.97147 .59075 L
.97247 .59546 L
.9734 .59888 L
.97427 .60122 L
.97475 .60214 L
.97519 .60275 L
.97543 .60299 L
.97568 .60317 L
.97594 .60328 L
.97619 .60332 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0.196383 0.0581337 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15079 -0.0125 -3 -9 ]
[.15079 -0.0125 3 0 ]
[.27778 -0.0125 -3 -9 ]
[.27778 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.53175 -0.0125 -3 -9 ]
[.53175 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.9127 -0.0125 -6 -9 ]
[.9127 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -12 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .31265 -6 -4.5 ]
[-0.0125 .31265 0 4.5 ]
[-0.0125 .42892 -6 -4.5 ]
[-0.0125 .42892 0 4.5 ]
[-0.0125 .54519 -6 -4.5 ]
[-0.0125 .54519 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15079 0 m
.15079 .00625 L
s
[(2)] .15079 -0.0125 0 1 Mshowa
.27778 0 m
.27778 .00625 L
s
[(4)] .27778 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(6)] .40476 -0.0125 0 1 Mshowa
.53175 0 m
.53175 .00625 L
s
[(8)] .53175 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(12)] .78571 -0.0125 0 1 Mshowa
.9127 0 m
.9127 .00625 L
s
[(14)] .9127 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.5 0 m
.5 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(-2)] -0.0125 .08012 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(0)] -0.0125 .19638 1 0 Mshowa
0 .31265 m
.00625 .31265 L
s
[(2)] -0.0125 .31265 1 0 Mshowa
0 .42892 m
.00625 .42892 L
s
[(4)] -0.0125 .42892 1 0 Mshowa
0 .54519 m
.00625 .54519 L
s
[(6)] -0.0125 .54519 1 0 Mshowa
.125 Mabswid
0 .10918 m
.00375 .10918 L
s
0 .13825 m
.00375 .13825 L
s
0 .16732 m
.00375 .16732 L
s
0 .22545 m
.00375 .22545 L
s
0 .25452 m
.00375 .25452 L
s
0 .28358 m
.00375 .28358 L
s
0 .34172 m
.00375 .34172 L
s
0 .37078 m
.00375 .37078 L
s
0 .39985 m
.00375 .39985 L
s
0 .45798 m
.00375 .45798 L
s
0 .48705 m
.00375 .48705 L
s
0 .51612 m
.00375 .51612 L
s
0 .05105 m
.00375 .05105 L
s
0 .02198 m
.00375 .02198 L
s
0 .57425 m
.00375 .57425 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15079 .61178 m
.15079 .61803 L
s
.27778 .61178 m
.27778 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.53175 .61178 m
.53175 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.9127 .61178 m
.9127 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .31265 m
1 .31265 L
s
.99375 .42892 m
1 .42892 L
s
.99375 .54519 m
1 .54519 L
s
.125 Mabswid
.99625 .10918 m
1 .10918 L
s
.99625 .13825 m
1 .13825 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .22545 m
1 .22545 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .28358 m
1 .28358 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .37078 m
1 .37078 L
s
.99625 .39985 m
1 .39985 L
s
.99625 .45798 m
1 .45798 L
s
.99625 .48705 m
1 .48705 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .02198 m
1 .02198 L
s
.99625 .57425 m
1 .57425 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .19638 m
1 .19638 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .19638 m
.02381 .60332 L
s
.0873 .19638 m
.0873 .08012 L
s
.15079 .19638 m
.15079 .08012 L
s
.21429 .19638 m
.21429 .60332 L
s
.27778 .19638 m
.27778 .08012 L
s
.34127 .19638 m
.34127 .08012 L
s
.40476 .19638 m
.40476 .60332 L
s
.46825 .19638 m
.46825 .08012 L
s
.53175 .19638 m
.53175 .08012 L
s
.59524 .19638 m
.59524 .60332 L
s
.65873 .19638 m
.65873 .08012 L
s
.72222 .19638 m
.72222 .08012 L
s
.78571 .19638 m
.78571 .60332 L
s
.84921 .19638 m
.84921 .08012 L
s
.9127 .19638 m
.9127 .08012 L
s
.97619 .19638 m
.97619 .60332 L
s
.015 w
.02381 .60332 Mdot
.0873 .08012 Mdot
.15079 .08012 Mdot
.21429 .60332 Mdot
.27778 .08012 Mdot
.34127 .08012 Mdot
.40476 .60332 Mdot
.46825 .08012 Mdot
.53175 .08012 Mdot
.59524 .60332 Mdot
.65873 .08012 Mdot
.72222 .08012 Mdot
.78571 .60332 Mdot
.84921 .08012 Mdot
.9127 .08012 Mdot
.97619 .60332 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00>_ooool3o`0001Sooooo0ol0
000Fooooo`Go00005?ooool2o`0001Kooooo1Ol0000Hooooo`?o00005_ooool3o`0005gooooo0ol0
000Hooooo`?o00005Oooool5o`0001Gooooo0_l0000Fooooo`Go00005oooool3o`0001Kooooo0ol0
000Vooooo`00>Oooool01Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool05_oo
ool01?l0003oooooooooool0000Cooooo`04o`000?ooooooooooo`0001Kooooo00Co0000oooooooo
oooo00006Oooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool00000Foooool0
1Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool05Oooool01?l0003ooooooooo
ool0000Dooooo`04o`000?ooooooooooo`0001Kooooo00Co0000oooooooooooo00006?ooool00ol0
003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000009Oooool003?ooooo1Ol000000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo1Ol000000ooooooo0000o`000003o`00
013ooooo1Ol00003ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00005oooool0
0ol0003oooooooooo`0Fooooo`Go00005Oooool01Ol0003ooooooooooooooooo000005Gooooo1Ol0
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo1Ol000000ooooooo0000o`00
0003o`0000oooooo1Ol00003ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo0000
5oooool00ol0003oooooooooo`0Eooooo`Go00005Oooool01Ol0003ooooooooooooooooo000002Go
oooo000iooooo`Co00005_ooool01?l0003oooooooooool0000Jooooo`03o`000?oooooooooo01;o
oooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`0Eooooo`04o`000?oooooooooo
o`0001Kooooo1?l0001Looooo`Co00005_ooool01?l0003oooooooooool0000Iooooo`03o`000?oo
oooooooo01?ooooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`0Dooooo`04o`00
0?ooooooooooo`0001Kooooo1?l0000Vooooo`00>Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooo000001Oooooo00Go0000ooooooooooooooooo`00000Cooooo`04o`000?ooooooooooo`00
01Gooooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooo000001Kooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000001Kooooo00Go0000
ooooooooooooooooo`00000Dooooo`04o`000?ooooooooooo`0001Gooooo00Go0000oooooooooooo
ooooo`00000Fooooo`03o`000?oooooo000001Kooooo00?o0000ooooooooool09oooool003[ooooo
00?o0000ooooooooool06?ooool2o`0001Oooooo00Go0000ooooooooooooooooo`00000Cooooo`04
o`000?ooooooooooo`0001Gooooo00Go0000ooooooooooooooooo`00000Hooooo`;o00005oooool0
0ol0003oooooooooo`1Mooooo`03o`000?oooooooooo01Sooooo0_l0000Fooooo`05o`000?oooooo
ooooooooool000005?ooool01?l0003oooooooooool0000Eooooo`05o`000?ooooooooooooooool0
00005oooool2o`0001Oooooo00?o0000ooooooooool09_ooool003_ooooo0_l0000Iooooo`03o`00
0?oooooooooo01Kooooo0ol0000Eooooo`;o00005oooool3o`0001[ooooo00?o0000ooooooooool0
5_ooool2o`0005kooooo0_l0000Iooooo`03o`000?oooooooooo01Gooooo0ol0000Fooooo`;o0000
5oooool3o`0001Wooooo00?o0000ooooooooool05_ooool2o`0002Kooooo003oooooooWooooo003o
ooooooWooooo000Jooooo`;o0000n?ooool2o`000>;ooooo000Iooooo`04o`000?ooooooooooo`00
0?Kooooo00Co0000oooooooooooo0000hOooool001Wooooo00Co0000oooooooooooo00000oooooo@
o`0002?ooooo00Co0000oooooooooooo00001?ooool4o`000003ool00?l00?oo003o0<Co003o1Ol0
000=ooooo`006Oooool01?l0003oooooooooool00003ooooo`?o00000_ooooo7o`00o`;ooooo0_l0
000Sooooo`04o`000?ooooooooooo`0000Cooooo00Co0000ooooooooooooooooBOoo00000ol00?oo
o`00ool0000:ool000;o003o2ooo0002o`00o`_oo`000_l00?l<ool00003o`00oooo003oo`0004Ko
o`001?ooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo04[ooooo0_l00?l<ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04[ooooo00?o0000oooooooo
ool08Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Oooooo0ooo000:oooo
o`?oo`002_ooool3ool000_ooooo0_oo000;ooooo`;oo`002oooool00ooo003o003oool0000:oooo
o`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:oooo
o`;oo`0000?o003oooooooooool02Oooool2ool000_ooooo0_oo000;ooooo`?oo`002_ooool3ool0
00[ooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0B_ooool2o`00o`cooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0B_ooool00ol0
003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01oooool3
ool000[ooooo0ooo000:ooooo`?oo`002oooool2ool000_ooooo0_oo000;ooooo`03ool00?l00?oo
o`0000[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:ooooo`03ool00?l00?oo
003o00[ooooo0_oo00000ol00?ooooooooooo`09ooooo`;oo`002oooool2ool000_ooooo0ooo000:
ooooo`?oo`002_ooool3ool000[ooooo00?o0000ooooooooool02oooool001[ooooo0_l00004oooo
o`03o`000?oooooooooo04[ooooo0_l00?l<ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04[ooooo00?o0000oooo
ooooool08_ooool2o`0000Gooooo00?o0000ooooooooool01oooool3ool000[ooooo0ooo000:oooo
o`?oo`002oooool2ool000_ooooo0_oo000;ooooo`03ool00?l00?ooo`0000[ooooo00?oo`00o`00
ool00?l02_ooool00ooo003o003oo`00o`0:ooooo`03ool00?l00?oo003o00[ooooo0_oo00000ol0
0?ooooooooooo`09ooooo`;oo`002oooool2ool000_ooooo0ooo000:ooooo`?oo`002_ooool3ool0
00[ooooo00?o0000ooooooooool02oooool0023ooooo0_l0001;ooooo`;o003o3?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo0_l00008ooooo`?oo`002_ooool3ool000[o
oooo0ooo000;ooooo`;oo`002oooool2ool000_ooooo00?oo`00o`00oooo00002_ooool00ooo003o
003oo`00o`0:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool2ool00003
o`00oooooooooooo00Wooooo0_oo000;ooooo`;oo`002oooool3ool000[ooooo0ooo000:ooooo`?o
o`002Oooool2o`0000gooooo000Pooooo`03o`000?oooooooooo04[ooooo0_l00?l<ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo04[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`?oo`00
2_ooool3ool000[ooooo0ooo000;ooooo`;oo`002oooool2ool000_ooooo00?oo`00o`00oooo0000
2_ooool00ooo003o003oo`00o`0:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l0
2_ooool2ool00003o`00oooooooooooo00Wooooo0_oo000;ooooo`;oo`002oooool3ool000[ooooo
0ooo000:ooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003ooooooooo
o`1:ooooo`;o003o3?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool01oooool3ool000[ooooo0ooo000:ooooo`?oo`002oooool2ool000_ooooo0_oo
000;ooooo`03ool00?l00?ooo`0000[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o003oo`00
o`0:ooooo`03ool00?l00?oo003o00[ooooo0_oo00000ol00?ooooooooooo`09ooooo`;oo`002ooo
ool2ool000_ooooo0ooo000:ooooo`?oo`002_ooool3ool000[ooooo00?o0000ooooooooool02ooo
ool0023ooooo00?o0000ooooooooool0B_ooool2o`00o`cooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0B_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo0ooo000:ooooo`?oo`002_ooool3
ool000_ooooo0_oo000;ooooo`;oo`002oooool00ooo003o003oool0000:ooooo`03ool00?l00?oo
003o00[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:ooooo`;oo`0000?o003o
ooooooooool02Oooool2ool000_ooooo0_oo000;ooooo`?oo`002_ooool3ool000[ooooo0ooo000:
ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000Boooool2o`00o`cooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool0B_ooool00ol0003oooooooooo`0Yooooo`;o00002?ooool3ool000[ooooo0ooo000:oooo
o`?oo`002oooool2ool000_ooooo0_oo000;ooooo`03ool00?l00?ooo`0000[ooooo00?oo`00o`00
ool00?l02_ooool00ooo003o003oo`00o`0:ooooo`03ool00?l00?oo003o00[ooooo0_oo00000ol0
0?ooooooooooo`09ooooo`;oo`002oooool2ool000_ooooo0ooo000:ooooo`?oo`002_ooool3ool0
00Wooooo0_l0000=ooooo`008?ooool00ol0003oooooooooo`1:ooooo`;o003o3?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool000[o
oooo0ooo000:ooooo`?oo`002oooool2ool000_ooooo0_oo000;ooooo`03ool00?l00?ooo`0000[o
oooo00?oo`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:ooooo`03ool00?l00?oo003o00[o
oooo0_oo00000ol00?ooooooooooo`09ooooo`;oo`002oooool2ool000_ooooo0ooo000:ooooo`?o
o`002_ooool3ool000[ooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0
B_ooool2o`00o`cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00Oooooo0ooo000:ooooo`?oo`002_ooool3ool000_ooooo0_oo000;ooooo`;oo`00
2oooool00ooo003o003oool0000:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l0
2_ooool00ooo003o003oo`00o`0:ooooo`;oo`0000?o003oooooooooool02Oooool2ool000_ooooo
0_oo000;ooooo`?oo`002_ooool3ool000[ooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo
000Pooooo`03o`000?oooooooooo04[ooooo0_l00?l<ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04[ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`?oo`002_ooool3ool000[ooooo0ooo
000;ooooo`;oo`002oooool2ool000_ooooo00?oo`00o`00oooo00002_ooool00ooo003o003oo`00
o`0:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool2ool00003o`00oooo
oooooooo00Wooooo0_oo000;ooooo`;oo`002oooool3ool000[ooooo0ooo000:ooooo`?oo`002_oo
ool00ol0003oooooooooo`0;ooooo`008?ooool2o`0004_ooooo0_l00?l<ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo04[ooooo00?o0000ooooooooool0:Oooool2o`0000Sooooo0ooo000:ooooo`?oo`002_ooool3
ool000_ooooo0_oo000;ooooo`;oo`002oooool00ooo003o003oool0000:ooooo`03ool00?l00?oo
003o00[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:ooooo`;oo`0000?o003o
ooooooooool02Oooool2ool000_ooooo0_oo000;ooooo`?oo`002_ooool3ool000[ooooo0ooo0009
ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0B_ooool2o`00o`cooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool0B_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo0ooo000:oooo
o`?oo`002_ooool3ool000_ooooo0_oo000;ooooo`;oo`002oooool00ooo003o003oool0000:oooo
o`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:oooo
o`;oo`0000?o003oooooooooool02Oooool2ool000_ooooo0_oo000;ooooo`?oo`002_ooool3ool0
00[ooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo04[o
oooo0_l00?l<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`07ooooo`?oo`002_ooool3ool000[ooooo0ooo000;ooooo`;oo`002oooool2ool000_o
oooo00?oo`00o`00oooo00002_ooool00ooo003o003oo`00o`0:ooooo`03ool00?l00?oo003o00[o
oooo00?oo`00o`00ool00?l02_ooool2ool00003o`00oooooooooooo00Wooooo0_oo000;ooooo`;o
o`002oooool3ool000[ooooo0ooo000:ooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`00
8?ooool00ol0003oooooooooo`1:ooooo`;o003o3?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`1:ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool000[ooooo0ooo000:ooooo`?oo`00
2oooool2ool000_ooooo0_oo000;ooooo`03ool00?l00?ooo`0000[ooooo00?oo`00o`00ool00?l0
2_ooool00ooo003o003oo`00o`0:ooooo`03ool00?l00?oo003o00[ooooo0_oo00000ol00?oooooo
ooooo`09ooooo`;oo`002oooool2ool000_ooooo0ooo000:ooooo`?oo`002_ooool3ool000[ooooo
00?o0000ooooooooool02oooool0023ooooo0_l0001;ooooo`;o003o3?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`1:ooooo`03o`000?oooooooooo02Wooooo0_l00008ooooo`?oo`002_ooool3ool000[ooooo0ooo
000;ooooo`;oo`002oooool2ool000_ooooo00?oo`00o`00oooo00002_ooool00ooo003o003oo`00
o`0:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool2ool00003o`00oooo
oooooooo00Wooooo0_oo000;ooooo`;oo`002oooool3ool000[ooooo0ooo000:ooooo`?oo`002Ooo
ool2o`0000gooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool0
0ol0003oooooooooo`1:ooooo`;o003o3?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooo
oooo01Kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooo
oooo00Oooooo0ooo000:ooooo`?oo`002_ooool3ool000_ooooo0_oo000;ooooo`;oo`002oooool0
0ooo003o003oool0000:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool0
0ooo003o003oo`00o`0:ooooo`;oo`0000?o003oooooooooool02Oooool2ool000_ooooo0_oo000;
ooooo`?oo`002_ooool3ool000[ooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000=oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo04[ooooo0_l00?l<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool05Ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`07ooooo`?oo`002_ooool3ool000[ooooo0ooo000;ooooo`;oo`002oooool2ool000_o
oooo00?oo`00o`00oooo00002_ooool00ooo003o003oo`00o`0:ooooo`03ool00?l00?oo003o00[o
oooo00?oo`00o`00ool00?l02_ooool2ool00003o`00oooooooooooo00Wooooo0_oo000;ooooo`;o
o`002oooool3ool000[ooooo0ooo000:ooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`00
3Oooool01?l0003oooooooooool0000;ooooo`05o`000?ooooooooooooooool00000C?ooool2o`00
o`cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Eooooo`04o`000?oooooooooo
o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`?oo`002_ooool3
ool000[ooooo0ooo000;ooooo`;oo`002oooool2ool000_ooooo00?oo`00o`00oooo00002_ooool0
0ooo003o003oo`00o`0:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool2
ool00003o`00oooooooooooo00Wooooo0_oo000;ooooo`;oo`002oooool3ool000[ooooo0ooo000:
ooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0000;
ooooo`04o`000?ooooooooooooooo`?o0000B_ooool2o`00o`cooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0BOoo
ool2o`0001Oooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`;o0000
2?ooool3ool000[ooooo0ooo000:ooooo`?oo`002oooool2ool000_ooooo0_oo000;ooooo`03ool0
0?l00?ooo`0000[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:ooooo`03ool0
0?l00?oo003o00[ooooo0_oo00000ol00?ooooooooooo`09ooooo`;oo`002oooool2ool000_ooooo
0ooo000:ooooo`?oo`002_ooool3ool000Wooooo0_l0000=ooooo`003Oooool01?l0003ooooooooo
ool00007ooooo`Co00001?ooool00ol0003oooooooooo`1:ooooo`;o003o3?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`1:ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00001oooool4o`0000Go
oooo00?o0000ooooooooool01oooool3ool000[ooooo0ooo000:ooooo`?oo`002oooool2ool000_o
oooo0_oo000;ooooo`03ool00?l00?ooo`0000[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o
003oo`00o`0:ooooo`03ool00?l00?oo003o00[ooooo0_oo00000ol00?ooooooooooo`09ooooo`;o
o`002oooool2ool000_ooooo0ooo000:ooooo`?oo`002_ooool3ool000[ooooo00?o0000oooooooo
ool02oooool000gooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04[ooooo0_l00?l<ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04[ooooo00?o0000oooooooo
ool05Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool3ool000[ooooo0ooo000:ooooo`?oo`002oooool2ool000_ooooo0_oo000;oooo
o`03ool00?l00?ooo`0000[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:oooo
o`03ool00?l00?oo003o00[ooooo0_oo00000ol00?ooooooooooo`09ooooo`;oo`002oooool2ool0
00_ooooo0ooo000:ooooo`?oo`002_ooool3ool000[ooooo00?o0000ooooooooool02oooool000ko
oooo0_l00008ooooo`Go00000oooool00ol0003oooooooooo`1:ooooo`;o003o3?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`1:ooooo`03o`000?oooooooooo01Kooooo0_l00008ooooo`Go00001?ooool00ol0003o
ooooooooo`07ooooo`?oo`002_ooool3ool000[ooooo0ooo000;ooooo`;oo`002oooool2ool000_o
oooo00?oo`00o`00oooo00002_ooool00ooo003o003oo`00o`0:ooooo`03ool00?l00?oo003o00[o
oooo00?oo`00o`00ool00?l02_ooool2ool00003o`00oooooooooooo00Wooooo0_oo000;ooooo`;o
o`002oooool3ool000[ooooo0ooo000:ooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`00
8?ooool2o`0004_ooooo0_l00?l<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool0
:Oooool2o`0000Sooooo0ooo000:ooooo`?oo`002_ooool3ool000_ooooo0_oo000;ooooo`;oo`00
2oooool00ooo003o003oool0000:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l0
2_ooool00ooo003o003oo`00o`0:ooooo`;oo`0000?o003oooooooooool02Oooool2ool000_ooooo
0_oo000;ooooo`?oo`002_ooool3ool000[ooooo0ooo0009ooooo`;o00003Oooool0023ooooo00?o
0000ooooooooool0B_ooool2o`00o`cooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0B_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00Oooooo0ooo000:ooooo`?oo`002_ooool3ool000_ooooo0_oo
000;ooooo`;oo`002oooool00ooo003o003oool0000:ooooo`03ool00?l00?oo003o00[ooooo00?o
o`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:ooooo`;oo`0000?o003oooooooooool02Ooo
ool2ool000_ooooo0_oo000;ooooo`?oo`002_ooool3ool000[ooooo0ooo000:ooooo`03o`000?oo
oooooooo00_ooooo000Pooooo`03o`000?oooooooooo04[ooooo0_l00?l<ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo04[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`?oo`002_ooool3
ool000[ooooo0ooo000;ooooo`;oo`002oooool2ool000_ooooo00?oo`00o`00oooo00002_ooool0
0ooo003o003oo`00o`0:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool2
ool00003o`00oooooooooooo00Wooooo0_oo000;ooooo`;oo`002oooool3ool000[ooooo0ooo000:
ooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1:oooo
o`;o003o3?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01oooool3ool000[ooooo0ooo000:ooooo`?oo`002oooool2ool000_ooooo0_oo000;oooo
o`03ool00?l00?ooo`0000[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:oooo
o`03ool00?l00?oo003o00[ooooo0_oo00000ol00?ooooooooooo`09ooooo`;oo`002oooool2ool0
00_ooooo0ooo000:ooooo`?oo`002_ooool3ool000[ooooo00?o0000ooooooooool02oooool0023o
oooo0_l0001;ooooo`;o003o3?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wo
oooo0_l00008ooooo`?oo`002_ooool3ool000[ooooo0ooo000;ooooo`;oo`002oooool2ool000_o
oooo00?oo`00o`00oooo00002_ooool00ooo003o003oo`00o`0:ooooo`03ool00?l00?oo003o00[o
oooo00?oo`00o`00ool00?l02_ooool2ool00003o`00oooooooooooo00Wooooo0_oo000;ooooo`;o
o`002oooool3ool000[ooooo0ooo000:ooooo`?oo`002Oooool2o`0000gooooo000Pooooo`03o`00
0?oooooooooo04[ooooo0_l00?l<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`07ooooo`?oo`002_ooool3ool000[ooooo0ooo000;ooooo`;oo`00
2oooool2ool000_ooooo00?oo`00o`00oooo00002_ooool00ooo003o003oo`00o`0:ooooo`03ool0
0?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool2ool00003o`00oooooooooooo00Wooooo
0_oo000;ooooo`;oo`002oooool3ool000[ooooo0ooo000:ooooo`?oo`002_ooool00ol0003ooooo
ooooo`0;ooooo`008?ooool00ol0003oooooooooo`1:ooooo`;o003o3?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`1:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool000[ooooo0ooo
000:ooooo`?oo`002oooool2ool000_ooooo0_oo000;ooooo`03ool00?l00?ooo`0000[ooooo00?o
o`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:ooooo`03ool00?l00?oo003o00[ooooo0_oo
00000ol00?ooooooooooo`09ooooo`;oo`002oooool2ool000_ooooo0ooo000:ooooo`?oo`002_oo
ool3ool000[ooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0B_ooool2
o`00o`cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00Oooooo0ooo000:ooooo`?oo`002_ooool3ool000_ooooo0_oo000;ooooo`;oo`002oooool0
0ooo003o003oool0000:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool0
0ooo003o003oo`00o`0:ooooo`;oo`0000?o003oooooooooool02Oooool2ool000_ooooo0_oo000;
ooooo`?oo`002_ooool3ool000[ooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Poooo
o`;o0000Boooool2o`00o`cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Yoooo
o`;o00002?ooool3ool000[ooooo0ooo000:ooooo`?oo`002oooool2ool000_ooooo0_oo000;oooo
o`03ool00?l00?ooo`0000[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:oooo
o`03ool00?l00?oo003o00[ooooo0_oo00000ol00?ooooooooooo`09ooooo`;oo`002oooool2ool0
00_ooooo0ooo000:ooooo`?oo`002_ooool3ool000Wooooo0_l0000=ooooo`008?ooool00ol0003o
ooooooooo`1:ooooo`;o003o3?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool01oooool3ool000[ooooo0ooo000:ooooo`?oo`002oooool2ool000_o
oooo0_oo000;ooooo`03ool00?l00?ooo`0000[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o
003oo`00o`0:ooooo`03ool00?l00?oo003o00[ooooo0_oo00000ol00?ooooooooooo`09ooooo`;o
o`002oooool2ool000_ooooo0ooo000:ooooo`?oo`002_ooool3ool000[ooooo00?o0000oooooooo
ool02oooool0023ooooo00?o0000ooooooooool0B_ooool2o`00o`cooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
B_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo0ooo000:ooooo`?oo`00
2_ooool3ool000_ooooo0_oo000;ooooo`;oo`002oooool00ooo003o003oool0000:ooooo`03ool0
0?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:ooooo`;oo`00
00?o003oooooooooool02Oooool2ool000_ooooo0_oo000;ooooo`?oo`002_ooool3ool000[ooooo
0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo04[ooooo0_l0
0?l<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`07ooooo`?oo`002_ooool3ool000[ooooo0ooo000;ooooo`;oo`002oooool2ool000_ooooo00?o
o`00o`00oooo00002_ooool00ooo003o003oo`00o`0:ooooo`03ool00?l00?oo003o00[ooooo00?o
o`00o`00ool00?l02_ooool2ool00003o`00oooooooooooo00Wooooo0_oo000;ooooo`;oo`002ooo
ool3ool000[ooooo0ooo000:ooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`008?ooool2
o`0004_ooooo0_l00?l<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool0:Oooool2
o`0000Sooooo0ooo000:ooooo`?oo`002_ooool3ool000_ooooo0_oo000;ooooo`;oo`002oooool0
0ooo003o003oool0000:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool0
0ooo003o003oo`00o`0:ooooo`;oo`0000?o003oooooooooool02Oooool2ool000_ooooo0_oo000;
ooooo`?oo`002_ooool3ool000[ooooo0ooo0009ooooo`;o00003Oooool0023ooooo00?o0000oooo
ooooool0B_ooool2o`00o`cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00Oooooo0ooo000:ooooo`?oo`002_ooool3ool000_ooooo0_oo000;oooo
o`;oo`002oooool00ooo003o003oool0000:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00
ool00?l02_ooool00ooo003o003oo`00o`0:ooooo`;oo`0000?o003oooooooooool02Oooool2ool0
00_ooooo0_oo000;ooooo`?oo`002_ooool3ool000[ooooo0ooo000:ooooo`03o`000?oooooooooo
00_ooooo000Iooooo`?o00001?ooool00ol0003oooooooooo`1:ooooo`;o003o3?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`1:ooooo`03o`000?oooooooooo027ooooo0ol00005ooooo`03o`000?oooooooooo00Oo
oooo0ooo000:ooooo`?oo`002_ooool3ool000_ooooo0_oo000;ooooo`;oo`002oooool00ooo003o
003oool0000:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o
003oo`00o`0:ooooo`;oo`0000?o003oooooooooool02Oooool2ool000_ooooo0_oo000;ooooo`?o
o`002_ooool3ool000[ooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0B_ooool2o`00o`cooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
B_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool3ool000[ooooo0ooo000:ooooo`?oo`002oooool2ool000_ooooo0_oo000;ooooo`03ool0
0?l00?ooo`0000[ooooo00?oo`00o`00ool00?l02_ooool00ooo003o003oo`00o`0:ooooo`03ool0
0?l00?oo003o00[ooooo0_oo00000ol00?ooooooooooo`09ooooo`;oo`002oooool2ool000_ooooo
0ooo000:ooooo`?oo`002_ooool3ool000[ooooo00?o0000ooooooooool02oooool001[ooooo00?o
0000ooooooooool00oooool3o`0004[ooooo0_l00?l<ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo04Wooooo0_l0
000Tooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`?oo`002_ooool3ool000[ooooo0ooo
000;ooooo`;oo`002oooool3ool000[ooooo00?oo`00o`00oooo00002_ooool00ooo003o003oo`00
o`0:ooooo`03ool00?l00?oo003o00[ooooo00?oo`00o`00ool00?l02_ooool2ool00003o`00oooo
oooooooo00Wooooo0ooo000:ooooo`;oo`002oooool3ool000[ooooo0ooo000:ooooo`?oo`002Ooo
ool2o`0000gooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B_ooool2
o`00oaWooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`?oo`002_ooool3
ool000[ooooo0ooo000;ooooo`;oo`002oooool3ool000[ooooo00?oo`00o`00oooo00002_ooool3
ool000[ooooo0ooo000:ooooo`?oo`002_ooool2ool00003o`00oooooooooooo00Wooooo0ooo000:
ooooo`;oo`002oooool3ool000[ooooo0ooo000:ooooo`?oo`002_ooool00ol0003oooooooooo`0;
ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04[ooooo0_l00?lIoooo
o`03o`000?oooooooooo01Oooooo00?o003oooooooooool0B_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;oooo
o`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool00ol0003oooooooooo`08oooo
o`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool0
00[ooooo00?o0000ooooooooool02oooool001Wooooo0_l00005ooooo`03o`000?oooooooooo04[o
oooo0_l00?lIooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool0B_ooool00ol0003o
ooooooooo`0Qooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`?oo`005oooool3ool000_o
oooo0_oo000Hooooo`03ool00?l00?ooo`0000[ooooo0ooo000<ooooo`03o`000?oooooooooo00So
oooo0ooo000:ooooo`;oo`0000?o003oooooooooool05_ooool2ool000_ooooo0ooo000Gooooo`?o
o`002_ooool00ol0003oooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`03ooooo`;o0000
Boooool2o`00oaWooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1:ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool01?ooool2o`0000Sooooo0ooo000Gooooo`?oo`00
2oooool2ool001Sooooo00?oo`00o`00oooo00002_ooool3ool000cooooo00?o0000ooooooooool0
2?ooool3ool000[ooooo0_oo00000ol00?ooooooooooo`0Fooooo`;oo`002oooool3ool001Oooooo
0ooo0009ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0B_ooool2o`00oaWooooo00?o
0000ooooooooool05oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o003oool0
000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003o`00oooo
oooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02ooo
ool0023ooooo00?o0000ooooooooool0B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool0
0ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3
ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool0
0ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;
ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02oooool0023ooooo00?o0000oooo
ooooool0B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1:oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;oooo
o`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool00ol0003oooooooooo`08oooo
o`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool0
00[ooooo00?o0000ooooooooool02oooool0023ooooo0_l0001;ooooo`;o003o6Oooool00ol0003o
ooooooooo`0Gooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool0:Oooool2o`0000So
oooo0ooo000Gooooo`?oo`002oooool2ool001Sooooo00?oo`00o`00oooo00002_ooool3ool000co
oooo00?o0000ooooooooool02?ooool3ool000[ooooo0_oo00000ol00?ooooooooooo`0Fooooo`;o
o`002oooool3ool001Oooooo0ooo0009ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0
B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1:ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`00
6?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`00
2_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo
00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0B_ooool2o`00oaWooooo00?o
0000ooooooooool05oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o003oool0
000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003o`00oooo
oooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02ooo
ool0023ooooo00?o0000ooooooooool0B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool0
0ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3
ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool0
0ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;
ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02oooool0023ooooo0_l0001;oooo
o`;o003o6Oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo04[ooooo00?o0000oooo
ooooool0:Oooool2o`0000Sooooo0ooo000Gooooo`?oo`002oooool2ool001Sooooo00?oo`00o`00
oooo00002_ooool3ool000cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0_oo00000ol0
0?ooooooooooo`0Fooooo`;oo`002oooool3ool001Oooooo0ooo0009ooooo`;o00003Oooool0023o
oooo00?o0000ooooooooool0B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool00ol00?oo
ooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool001Oo
oooo0ooo000;ooooo`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool00ol0003o
ooooooooo`08ooooo`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;ooooo`?o
o`005oooool3ool000[ooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0
B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1:ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`00
6?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`00
2_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo
00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0B_ooool2o`00oaWooooo00?o
0000ooooooooool05oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o003oool0
000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003o`00oooo
oooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02ooo
ool0023ooooo00?o0000ooooooooool0B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool0
0ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3
ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool0
0ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;
ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02oooool0023ooooo0_l0001;oooo
o`;o003o6Oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo04[ooooo00?o0000oooo
ooooool0:Oooool2o`0000Sooooo0ooo000Gooooo`?oo`002oooool2ool001Sooooo00?oo`00o`00
oooo00002_ooool3ool000cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0_oo00000ol0
0?ooooooooooo`0Fooooo`;oo`002oooool3ool001Oooooo0ooo0009ooooo`;o00003Oooool000go
oooo0ol00004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo04[o
oooo0_l00?lIooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool0B_ooool00ol0003o
ooooooooo`0Eooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003o
ooooooooo`07ooooo`?oo`005oooool3ool000_ooooo0_oo000Hooooo`03ool00?l00?ooo`0000[o
oooo0ooo000<ooooo`03o`000?oooooooooo00Sooooo0ooo000:ooooo`;oo`0000?o003ooooooooo
ool05_ooool2ool000_ooooo0ooo000Gooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`00
3_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`1:ooooo`;o003o6Oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo04[o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`07ooooo`?oo`005oooool3ool000_ooooo0_oo000Hoooo
o`03ool00?l00?ooo`0000[ooooo0ooo000<ooooo`03o`000?oooooooooo00Sooooo0ooo000:oooo
o`;oo`0000?o003oooooooooool05_ooool2ool000_ooooo0ooo000Gooooo`?oo`002_ooool00ol0
003oooooooooo`0;ooooo`003_ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooooooo
ool00000C?ooool2o`00oaWooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1:oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo0ooo000Gooooo`?oo`002oooool2ool001Sooooo00?oo`00o`00
oooo00002_ooool3ool000cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0_oo00000ol0
0?ooooooooooo`0Fooooo`;oo`002oooool3ool001Oooooo0ooo000:ooooo`03o`000?oooooooooo
00_ooooo000>ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0ol0001:oooo
o`;o003o6Oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo04Wooooo0_l0000Hoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool2o`0000Sooooo0ooo000Goooo
o`?oo`002oooool2ool001Sooooo00?oo`00o`00oooo00002_ooool3ool000cooooo00?o0000oooo
ooooool02?ooool3ool000[ooooo0_oo00000ol00?ooooooooooo`0Fooooo`;oo`002oooool3ool0
01Oooooo0ooo0009ooooo`;o00003Oooool000kooooo00?o0000ooooooooool01oooool4o`0000Co
oooo00?o0000ooooooooool0B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool00ol00?oo
ooooooooo`1:ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool4o`0000Go
oooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o
003oool0000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003
o`00oooooooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000oooooooo
ool02oooool000gooooo0_l00009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1:ooooo`03o`00
0?oooooooooo01Gooooo0_l00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`00
3?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo
0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02oooool000kooooo00?o
0000ooooooooool01oooool5o`0000?ooooo00?o0000ooooooooool0B_ooool2o`00oaWooooo00?o
0000ooooooooool05oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01oooool5o`0000Cooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo
000;ooooo`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool00ol0003ooooooooo
o`08ooooo`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;ooooo`?oo`005ooo
ool3ool000[ooooo00?o0000ooooooooool02oooool0023ooooo0_l0001;ooooo`;o003o6Oooool0
0ol0003oooooooooo`0Gooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool0:Oooool2
o`0000Sooooo0ooo000Gooooo`?oo`002oooool2ool001Sooooo00?oo`00o`00oooo00002_ooool3
ool000cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0_oo00000ol00?ooooooooooo`0F
ooooo`;oo`002oooool3ool001Oooooo0ooo0009ooooo`;o00003Oooool0023ooooo00?o0000oooo
ooooool0B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1:oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;oooo
o`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool00ol0003oooooooooo`08oooo
o`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool0
00[ooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0B_ooool2o`00oaWo
oooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o
003oool0000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003
o`00oooooooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000oooooooo
ool02oooool0023ooooo00?o0000ooooooooool0B_ooool2o`00oaWooooo00?o0000ooooooooool0
5oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
1oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`00
3?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo
0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02oooool0023ooooo0_l0
001;ooooo`;o003o6Oooool00ol0003oooooooooo`0Gooooo`03o`00oooooooooooo04[ooooo00?o
0000ooooooooool0:Oooool2o`0000Sooooo0ooo000Gooooo`?oo`002oooool2ool001Sooooo00?o
o`00o`00oooo00002_ooool3ool000cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0_oo
00000ol00?ooooooooooo`0Fooooo`;oo`002oooool3ool001Oooooo0ooo0009ooooo`;o00003Ooo
ool0023ooooo00?o0000ooooooooool0B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool0
0ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3
ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool0
0ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;
ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02oooool0023ooooo00?o0000oooo
ooooool0B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1:oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;oooo
o`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool00ol0003oooooooooo`08oooo
o`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool0
00[ooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0B_ooool2o`00oaWo
oooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o
003oool0000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003
o`00oooooooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000oooooooo
ool02oooool0023ooooo0_l0001;ooooo`;o003o6Oooool00ol0003oooooooooo`0Gooooo`03o`00
oooooooooooo04[ooooo00?o0000ooooooooool0:Oooool2o`0000Sooooo0ooo000Gooooo`?oo`00
2oooool2ool001Sooooo00?oo`00o`00oooo00002_ooool3ool000cooooo00?o0000ooooooooool0
2?ooool3ool000[ooooo0_oo00000ol00?ooooooooooo`0Fooooo`;oo`002oooool3ool001Oooooo
0ooo0009ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0B_ooool2o`00oaWooooo00?o
0000ooooooooool05oooool00ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o003oool0
000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003o`00oooo
oooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02ooo
ool0023ooooo00?o0000ooooooooool0B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool0
0ol00?ooooooooooo`1:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3
ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool0
0ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;
ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02oooool0023ooooo00?o0000oooo
ooooool0B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1:oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;oooo
o`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool00ol0003oooooooooo`08oooo
o`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool0
00[ooooo00?o0000ooooooooool02oooool0023ooooo0_l0001;ooooo`;o003o6Oooool00ol0003o
ooooooooo`0Gooooo`03o`00oooooooooooo04[ooooo00?o0000ooooooooool0:Oooool2o`0000So
oooo0ooo000Gooooo`?oo`002oooool2ool001Sooooo00?oo`00o`00oooo00002_ooool3ool000co
oooo00?o0000ooooooooool02?ooool3ool000[ooooo0_oo00000ol00?ooooooooooo`0Fooooo`;o
o`002oooool3ool001Oooooo0ooo0009ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0
B_ooool2o`00oaWooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`1:ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`00
6?ooool00ooo003o003oool0000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`00
2_ooool2ool00003o`00oooooooooooo01Kooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo
00?o0000ooooooooool02oooool001Sooooo1Ol00003ooooo`03o`000?oooooooooo04[ooooo0_l0
0?lIooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool0B_ooool00ol0003ooooooooo
o`0Pooooo`Go00001?ooool00ol0003oooooooooo`07ooooo`?oo`005oooool3ool000_ooooo0_oo
000Hooooo`03ool00?l00?ooo`0000[ooooo0ooo000<ooooo`03o`000?oooooooooo00Sooooo0ooo
000:ooooo`;oo`0000?o003oooooooooool05_ooool2ool000_ooooo0ooo000Gooooo`?oo`002_oo
ool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo04[ooooo0_l00?lIooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool0B_oo
ool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool00ooo003o003oool0000:ooooo`?oo`00
3?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool2ool00003o`00oooooooooooo01Kooooo
0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02oooool001[ooooo00?o
0000ooooooooool00oooool3o`0004[ooooo0_l00?lIooooo`03o`000?oooooooooo01Oooooo00?o
003oooooooooool0BOooool2o`0002Cooooo00?o0000ooooooooool01?ooool2o`0000Sooooo0ooo
000Gooooo`?oo`002oooool2ool001Sooooo00?oo`00o`00oooo00002_ooool3ool000cooooo00?o
0000ooooooooool02?ooool3ool000[ooooo0_oo00000ol00?ooooooooooo`0Fooooo`;oo`002ooo
ool3ool001Oooooo0ooo0009ooooo`;o00003Oooool001_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo0ooo000Gooooo`?oo`002oooool2
ool001Sooooo0ooo000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool3
ool001Sooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02oooool0
01Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`07ooooo`?oo`005oooool3ool000_ooooo0_oo000Hooooo`?oo`002_oo
ool3ool000cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0ooo000Hooooo`;oo`002ooo
ool3ool001Oooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Hooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
1oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool3ool000[ooooo0ooo000<ooooo`03o`00
0?oooooooooo00Sooooo0ooo000:ooooo`?oo`006?ooool2ool000_ooooo0ooo000Gooooo`?oo`00
2_ooool00ol0003oooooooooo`0;ooooo`006Oooool3o`0000Cooooo0_l0001Vooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool08Oooool3o`0000Gooooo0_l00008ooooo`?oo`005ooo
ool3ool000_ooooo0_oo000Hooooo`?oo`002_ooool3ool000cooooo00?o0000ooooooooool02?oo
ool3ool000[ooooo0ooo000Hooooo`;oo`002oooool3ool001Oooooo0ooo0009ooooo`;o00003Ooo
ool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool3
ool000[ooooo0ooo000<ooooo`03o`000?oooooooooo00Sooooo0ooo000:ooooo`?oo`006?ooool2
ool000_ooooo0ooo000Gooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`07ooooo`?oo`005oooool3ool000_ooooo0_oo000Hooooo`?oo`002_ooool3ool0
00cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0ooo000Hooooo`;oo`002oooool3ool0
01Oooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo06Go
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oo
oooo0ooo000Gooooo`?oo`002oooool2ool001Sooooo0ooo000:ooooo`?oo`003?ooool00ol0003o
ooooooooo`08ooooo`?oo`002_ooool3ool001Sooooo0_oo000;ooooo`?oo`005oooool3ool000[o
oooo00?o0000ooooooooool02oooool0023ooooo0_l0001Vooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0:Oooool2o`0000Sooooo0ooo000Gooooo`?oo`002oooool2ool001Sooooo
0ooo000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool3ool001Sooooo
0_oo000;ooooo`?oo`005oooool3ool000Wooooo0_l0000=ooooo`008?ooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`07ooooo`?oo`005oooool3ool000_ooooo0_oo000Hooooo`?oo`002_ooool3ool000cooooo00?o
0000ooooooooool02?ooool3ool000[ooooo0ooo000Hooooo`;oo`002oooool3ool001Oooooo0ooo
000:ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo0ooo000G
ooooo`?oo`002oooool2ool001Sooooo0ooo000:ooooo`?oo`003?ooool00ol0003oooooooooo`08
ooooo`?oo`002_ooool3ool001Sooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000
ooooooooool02oooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;oooo
o`;oo`006?ooool3ool000[ooooo0ooo000<ooooo`03o`000?oooooooooo00Sooooo0ooo000:oooo
o`?oo`006?ooool2ool000_ooooo0ooo000Gooooo`?oo`002_ooool00ol0003oooooooooo`0;oooo
o`008?ooool2o`0006Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`;o
00002?ooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool3ool000[ooooo0ooo000<ooooo`03
o`000?oooooooooo00Sooooo0ooo000:ooooo`?oo`006?ooool2ool000_ooooo0ooo000Gooooo`?o
o`002Oooool2o`0000gooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo0ooo000Gooooo`?oo`00
2oooool2ool001Sooooo0ooo000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`00
2_ooool3ool001Sooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool0
2oooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`006?oo
ool3ool000[ooooo0ooo000<ooooo`03o`000?oooooooooo00Sooooo0ooo000:ooooo`?oo`006?oo
ool2ool000_ooooo0ooo000Gooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`008?ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`07ooooo`?oo`005oooool3ool000_ooooo0_oo000Hooooo`?oo`002_ooool3
ool000cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0ooo000Hooooo`;oo`002oooool3
ool001Oooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000I_ooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo0_l00008ooooo`?oo`005oooool3ool0
00_ooooo0_oo000Hooooo`?oo`002_ooool3ool000cooooo00?o0000ooooooooool02?ooool3ool0
00[ooooo0ooo000Hooooo`;oo`002oooool3ool001Oooooo0ooo0009ooooo`;o00003Oooool0023o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool3ool000[o
oooo0ooo000<ooooo`03o`000?oooooooooo00Sooooo0ooo000:ooooo`?oo`006?ooool2ool000_o
oooo0ooo000Gooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`003?ooool5o`0000?ooooo
00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo01Cooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo
0ol00005ooooo`03o`000?oooooooooo00Oooooo0ooo000Gooooo`?oo`002oooool2ool001Sooooo
0ooo000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool3ool001Sooooo
0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02oooool000gooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01oooool3
ool001Oooooo0ooo000;ooooo`;oo`006?ooool3ool000[ooooo0ooo000<ooooo`03o`000?oooooo
oooo00Sooooo0ooo000:ooooo`?oo`006?ooool2ool000_ooooo0ooo000Gooooo`?oo`002_ooool0
0ol0003oooooooooo`0;ooooo`003_ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooooooo
ooooo`?o0000IOooool00ol0003oooooooooo`1Sooooo`;o00006?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`?oo`005oooool3ool000_ooooo0_oo000H
ooooo`?oo`002_ooool3ool000cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0ooo000H
ooooo`;oo`002oooool3ool001Oooooo0ooo0009ooooo`;o00003Oooool000oooooo00?o0000oooo
ooooool02_ooool01Ol0003ooooooooooooooooo000006Oooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`?oo`005oooool3ool000_ooooo0_oo000Hooooo`?oo`002_ooool3
ool000cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0ooo000Hooooo`;oo`002oooool3
ool001Oooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000<ooooo`05o`000?oooooooooo
ooooool000001oooool4o`0000Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000007ooooo`Co00001Ooo
ool00ol0003oooooooooo`07ooooo`?oo`005oooool3ool000_ooooo0_oo000Hooooo`?oo`002_oo
ool3ool000cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0ooo000Hooooo`;oo`002ooo
ool3ool001Oooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000<ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo0ooo000Gooooo`?oo`00
2oooool2ool001Sooooo0ooo000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`00
2_ooool3ool001Sooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool0
2oooool000gooooo0ol00008ooooo`Go00000oooool2o`0006Kooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`0Eooooo`?o00002?ooool5o`0000Cooooo0_l00008ooooo`?oo`005ooo
ool3ool000_ooooo0_oo000Hooooo`?oo`002_ooool3ool000cooooo00?o0000ooooooooool02?oo
ool3ool000[ooooo0ooo000Hooooo`;oo`002oooool3ool001Oooooo0ooo0009ooooo`;o00003Ooo
ool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool3
ool000[ooooo0ooo000<ooooo`03o`000?oooooooooo00Sooooo0ooo000:ooooo`?oo`006?ooool2
ool000_ooooo0ooo000Gooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`07ooooo`?oo`005oooool3ool000_ooooo0_oo000Hooooo`?oo`002_ooool3ool0
00cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0ooo000Hooooo`;oo`002oooool3ool0
01Oooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo06Go
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oo
oooo0ooo000Gooooo`?oo`002oooool2ool001Sooooo0ooo000:ooooo`?oo`003?ooool00ol0003o
ooooooooo`08ooooo`?oo`002_ooool3ool001Sooooo0_oo000;ooooo`?oo`005oooool3ool000[o
oooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo
0ooo000;ooooo`;oo`006?ooool3ool000[ooooo0ooo000<ooooo`03o`000?oooooooooo00Sooooo
0ooo000:ooooo`?oo`006?ooool2ool000_ooooo0ooo000Gooooo`?oo`002_ooool00ol0003ooooo
ooooo`0;ooooo`008?ooool2o`0006Kooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0Yooooo`;o00002?ooool3ool001Oooooo0ooo000;ooooo`;oo`006?ooool3ool000[ooooo0ooo
000<ooooo`03o`000?oooooooooo00Sooooo0ooo000:ooooo`?oo`006?ooool2ool000_ooooo0ooo
000Gooooo`?oo`002Oooool2o`0000gooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo0ooo000G
ooooo`?oo`002oooool2ool001Sooooo0ooo000:ooooo`?oo`003?ooool00ol0003oooooooooo`08
ooooo`?oo`002_ooool3ool001Sooooo0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000
ooooooooool02oooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;oooo
o`;oo`006?ooool3ool000[ooooo0ooo000<ooooo`03o`000?oooooooooo00Sooooo0ooo000:oooo
o`?oo`006?ooool2ool000_ooooo0ooo000Gooooo`?oo`002_ooool00ol0003oooooooooo`0;oooo
o`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`07ooooo`?oo`005oooool3ool000_ooooo0_oo000Hooooo`?o
o`002_ooool3ool000cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0ooo000Hooooo`;o
o`002oooool3ool001Oooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000
I_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo0_l00008ooooo`?oo`00
5oooool3ool000_ooooo0_oo000Hooooo`?oo`002_ooool3ool000cooooo00?o0000ooooooooool0
2?ooool3ool000[ooooo0ooo000Hooooo`;oo`002oooool3ool001Oooooo0ooo0009ooooo`;o0000
3Oooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01oooool3ool001Oooooo0ooo000;ooooo`;oo`006?oo
ool3ool000[ooooo0ooo000<ooooo`03o`000?oooooooooo00Sooooo0ooo000:ooooo`?oo`006?oo
ool2ool000_ooooo0ooo000Gooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`008?ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`07ooooo`?oo`005oooool3ool000_ooooo0_oo000Hooooo`?oo`002_ooool3
ool000cooooo00?o0000ooooooooool02?ooool3ool000[ooooo0ooo000Hooooo`;oo`002oooool3
ool001Oooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00Oooooo0ooo000Gooooo`?oo`002oooool2ool001Sooooo0ooo000:ooooo`?oo`003?ooool00ol0
003oooooooooo`08ooooo`?oo`002_ooool3ool001Sooooo0_oo000;ooooo`?oo`005oooool3ool0
00[ooooo00?o0000ooooooooool02oooool0023ooooo0_l0001Vooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool0:Oooool2o`0000Sooooo0ooo000Gooooo`?oo`002oooool2ool001So
oooo0ooo000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool3ool001So
oooo0_oo000;ooooo`?oo`005oooool3ool000Wooooo0_l0000=ooooo`006Oooool3o`0000Cooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo027ooooo
0ol00005ooooo`03o`000?oooooooooo00Oooooo0ooo000Gooooo`?oo`002oooool2ool001Sooooo
0ooo000:ooooo`?oo`003?ooool00ol0003oooooooooo`08ooooo`?oo`002_ooool3ool001Sooooo
0_oo000;ooooo`?oo`005oooool3ool000[ooooo00?o0000ooooooooool02oooool001Sooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`07ooooo`?oo`005oooool3ool000_ooooo0_oo000Hooooo`?oo`002_ooool3ool000co
oooo00?o0000ooooooooool02?ooool3ool000[ooooo0ooo000Hooooo`;oo`002oooool3ool001Oo
oooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Looooo`05o`000?ooooooooooooooool0
0000Ioooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`?oo`005oooool4ool000[ooooo0ooo000Gooooo`?o
o`002_ooool3ool000cooooo00?o0000ooooooooool02?ooool3ool000[ooooo1?oo000Gooooo`?o
o`002_ooool3ool001Oooooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Jooooo`;o0000
1?ooool3o`0006Gooooo00?o0000ooooooooool0Hoooool2o`0002Cooooo0_l00005ooooo`;o0000
2?ooool3ool001Oooooo1?oo000:ooooo`?oo`005oooool3ool000[ooooo0ooo000<ooooo`03o`00
0?oooooooooo00Sooooo0ooo000:ooooo`Coo`005oooool3ool000[ooooo0ooo000Gooooo`?oo`00
2Oooool2o`0000gooooo000Looooo`05o`000?ooooooooooooooool00000Ioooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`?oo`005oooool3ool000_ooooo0_oo000Hooooo`?oo`002_ooool3ool000cooooo
00?o0000ooooooooool02?ooool3ool000[ooooo0ooo000Hooooo`;oo`002oooool3ool001Oooooo
0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Hooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
8?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo00_ooooo000Iooooo`?o00001?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08Oooool3o`0000Gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo
000Pooooo`;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000002_ooooo0_l00003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooooooo`;o00003Oooool0023oooood?l0000[ooooom3o00003Oooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool0023ooooo0_l0000Uooooo`?o0000
9?ooool5o`0002Cooooo0ol0000Vooooo`?o00008oooool3o`0003;ooooo0_l0000Gooooo`Go0000
5oooool3o`0001Oooooo0ol0000Gooooo`?o00005Oooool3o`0000Cooooo0_l0000Aooooo`?o0000
0_ooool5o`00017ooooo0ol00004ooooo`?o00007Oooool001oooooo00Co0000oooooooooooo0000
9Oooool00ol0003oooooooooo`0Tooooo`04o`000?ooooooooooo`0002?ooooo00Go0000oooooooo
ooooooooo`00000Vooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000`
ooooo`04o`000?ooooooooooo`0001Oooooo00Co0000oooooooooooo00006?ooool00ol0003ooooo
ooooo`0Eooooo`05o`000?ooooooooooooooool000005Oooool01Ol0003ooooooooooooooooo0000
01Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01cooooo000Oooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo027ooooo1Ol0000Vooooo`03o`000?oo
oooooooo02kooooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`0Eooooo`Go0000
5_ooool01Ol0003ooooooooooooooooo000001Gooooo00Go0000ooooooooooooooooo`00000Eoooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooooooo1Ol0000Mooooo`007oooool0
1?l0003oooooooooool0000Uooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09?oo
ool2o`0002Cooooo00Co0000oooooooooooo00009oooool00ol0003oooooooooo`0^ooooo`04o`00
0?ooooooooooo`0001Wooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool0000Goooo
o`Co00005oooool3o`0001Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000A
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool07?ooool001oooooo00Co0000oooooooooooo00009Ooo
ool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000009oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooo000002?ooooo1?l0000aooooo`04o`000?ooooooooooo`0001Ko
oooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooo000001Oooooo00?o0000oooo
ooooool05oooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Aooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000007_ooool001oooooo00Co
0000oooooooooooo00009?ooool2o`0002Gooooo00Go0000ooooooooooooooooo`00000Sooooo`05
o`000?ooooooooooooooool000009Oooool2o`0002?ooooo00?o0000ooooooooool0<_ooool01?l0
003oooooooooool0000Fooooo`05o`000?ooooooooooooooool000005oooool2o`0001Sooooo00?o
0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000001Cooooo0_l00004ooooo`04o`00
0?ooooooooooo`00013ooooo0_l00003ooooo`05o`000?ooooooooooooooool000004Oooool2o`00
00Gooooo0_l0000Nooooo`008?ooool2o`0002Kooooo00?o0000ooooooooool09?ooool3o`0002Go
oooo0ol0000Wooooo`03o`000?oooooooooo027ooooo1Ol0000aooooo`;o00006?ooool3o`0001Wo
oooo00?o0000ooooooooool05oooool2o`0001Oooooo0ol0000Fooooo`03o`000?oooooooooo00?o
oooo0_l0000Booooo`03o`000?oooooooooo00;ooooo0ol0000Cooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool07?ooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool001coooood_l0000Yooooom;o00003oooool001cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3Oooool001cooooo00?o0000ooooooooool0c_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo0<kooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool03Oooool2
o`00oa3ooooo0_l00?lDooooo`03o`00oooooooooooo00oooooo0_l00?lCooooo`;o003o4Oooool0
0ol00?ooooooooooo`0Booooo`;o003o4Oooool00ol00?ooooooooooo`0Booooo`;o003o4?ooool2
o`00o`kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3>ooooo`03o`000?oooooo
oooo00gooooo000Looooo`03o`000?oooooooooo00gooooo0_l00?l@ooooo`;o003o4oooool3o`00
oa3ooooo0_l00?lCooooo`;o003o4Oooool2o`00oa?ooooo0_l00?l@ooooo`?o003o4oooool2o`00
oa3ooooo0_l00?l>ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0c_ooool00ol0
003oooooooooo`0=ooooo`007?ooool2o`0000gooooo00?o003oooooool00?l04?ooool2o`00oa?o
oooo00?o003oooooool00?l03oooool00ol00?ooooooo`00o`0Cooooo`03o`00oooooooo003o00oo
oooo00?o003oooooool00?l04oooool2o`00oa3ooooo00?o003oooooool00?l04oooool2o`00oa3o
oooo00?o003oooooool00?l03Oooool00ol0003oooooooooo`0Wooooo`;o0000c_ooool2o`0000oo
oooo000Looooo`03o`000?oooooooooo00cooooo00?o003oooooool00?l03oooool01?l00?oooooo
ooooool00?lBooooo`03o`00oooooooo003o00oooooo00?o003oooooool00?l04oooool00ol00?oo
ooooo`00o`0?ooooo`03o`00oooooooo003o01?ooooo00?o003oooooool00?l03oooool00ol00?oo
ooooo`00o`0Booooo`04o`00ooooooooooooo`00o`oooooo00?o003oooooool00?l03Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo0<kooooo00?o0000ooooooooool03Oooool001co
oooo00?o0000ooooooooool03?ooool00ol00?ooooooo`00o`0?ooooo`04o`00ooooooooooooo`00
oa;ooooo00?o003oooooool00?l03oooool01?l00?ooooooooooool00?lBooooo`03o`00oooooooo
003o00oooooo00?o003oooooool00?l04_ooool01?l00?ooooooooooool00?l?ooooo`03o`00oooo
oooo003o01;ooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l=ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0c_ooool00ol0003oooooooooo`0=ooooo`00
7?ooool00ol0003oooooooooo`0<ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooo
oooo003o4_ooool00ol00?ooooooo`00o`0?ooooo`04o`00ooooooooooooo`00oa7ooooo00Co003o
oooooooooooo003o3oooool00ol00?ooooooo`00o`0Booooo`04o`00ooooooooooooo`00o`kooooo
00Co003ooooooooooooo003o4_ooool01?l00?ooooooooooool00?l>ooooo`04o`00oooooooooooo
o`00o`gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3>ooooo`03o`000?oooooo
oooo00gooooo000Looooo`03o`000?oooooooooo00cooooo00Co003ooooooooooooo003o3_ooool0
1?l00?ooooooooooool00?lAooooo`05o`00ooooooooooooooooool00?l03_ooool01?l00?oooooo
ooooool00?lAooooo`04o`00ooooooooooooo`00o`oooooo00Co003ooooooooooooo003o4Oooool0
1?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00oa;ooooo00Co003ooooooooooooo
003o3_ooool01?l00?ooooooooooool00?l=ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0c_ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0<ooooo`04
o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o4Oooool01Ol00?oooooooooooooo
oooo003o00kooooo00Co003ooooooooooooo003o4Oooool01?l00?ooooooooooool00?l?ooooo`04
o`00ooooooooooooo`00oa7ooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool0
0?lBooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o3Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo0<kooooo00?o0000ooooooooool03Oooool001cooooo
0_l0000=ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o4Oooool01Ol0
0?oooooooooooooooooo003o00kooooo00Co003ooooooooooooo003o4Oooool01?l00?oooooooooo
ool00?l?ooooo`04o`00ooooooooooooo`00oa7ooooo00Co003ooooooooooooo003o3_ooool01Ol0
0?oooooooooooooooooo003o017ooooo00Co003ooooooooooooo003o3_ooool01?l00?oooooooooo
ool00?l=ooooo`03o`000?oooooooooo02Oooooo0_l0003>ooooo`;o00003oooool001cooooo00?o
0000ooooooooool02oooool01Ol00?oooooooooooooooooo003o00kooooo00Co003ooooooooooooo
003o4Oooool01Ol00?oooooooooooooooooo003o00kooooo00Co003ooooooooooooo003o4Oooool0
1Ol00?oooooooooooooooooo003o00gooooo00Go003oooooooooooooooooo`00o`0Aooooo`05o`00
ooooooooooooooooool00?l03Oooool01Ol00?oooooooooooooooooo003o013ooooo00Go003ooooo
ooooooooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`gooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooo
oooo00_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`05o`00oooooooo
ooooooooool00?l04?ooool01Ol00?oooooooooooooooooo003o00gooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l03Oooool01Ol00?oo
oooooooooooooooo003o017ooooo00Go003oooooooooooooooooo`00o`0=ooooo`05o`00oooooooo
ooooooooool00?l04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00_ooooo00Go
003oooooooooooooooooo`00o`0<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
c_ooool00ol0003oooooooooo`0=ooooo`005?ooool5o`0000?ooooo00?o0000ooooooooool02ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00_ooooo00Go003ooooooooooooooooo
o`00o`0@ooooo`05o`00ooooooooooooooooool00?l03Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00kooooo00Go003oooooooooooooooooo`00o`0=ooooo`05o`00oooooooooooo
ooooool00?l04Oooool01Ol00?oooooooooooooooooo003o00gooooo00Go003ooooooooooooooooo
o`00o`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02oooool01Ol00?oooooo
oooooooooooo003o00cooooo00?o0000ooooooooool07_ooool5o`0000Cooooo00?o0000oooooooo
ool0c_ooool00ol0003oooooooooo`0=ooooo`005Oooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`05
o`00ooooooooooooooooool00?l04?ooool01Ol00?oooooooooooooooooo003o00gooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l03Ooo
ool01Ol00?oooooooooooooooooo003o017ooooo00Go003oooooooooooooooooo`00o`0=ooooo`05
o`00ooooooooooooooooool00?l04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00_ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`000?oooooooooo01oooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo00gooooo000>
ooooo`Go00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00oooooo00Go003o
ooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00_ooooo00Go003ooooooooooooooooo
o`00o`0<ooooo`03o`000?oooooooooo01Sooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03_ooool3o`00o`[ooooo0ol00?lHooooo`?o003o2_ooool3o`00oaSooooo
0ol00?l:ooooo`?o003o6?ooool3o`00o`[ooooo0ol00?lGooooo`?o003o2oooool3o`00oa3ooooo
00?o0000ooooooooool03Oooool001Oooooo00?o0000ooooooooool00_ooool3o`0000_ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00kooooo00Go
003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`09ooooo`;o00008oooool00ol0003oooooooooo`03ooooo`;o0000
3oooool3o`00o`[ooooo0ol00?lHooooo`?o003o2_ooool3o`00oaSooooo0ol00?l:ooooo`?o003o
6?ooool3o`00o`[ooooo0ol00?lGooooo`?o003o2oooool3o`00o`oooooo0_l0000?ooooo`005?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool07_ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool03_ooool3o`00o`[ooooo0ol00?lHooooo`?o
003o2_ooool3o`00oaSooooo0ol00?l:ooooo`?o003o6?ooool3o`00o`[ooooo0ol00?lGooooo`?o
003o2oooool3o`00oa3ooooo00?o0000ooooooooool03Oooool001Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo01Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool03oooool00ol0003oooooooooo`0=oooo
o`005Oooool3o`0000Cooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00[ooooo00?o0000ooooooooool07oooool3o`0000Gooooo00?o0000oooooooo
ool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`00
0?oooooooooo00_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo01Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`00
0?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool06?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000Looooo`;o00003?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool09oooool2
o`00013ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo01Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool03_ooool2o`0000oooooo000Looooo`03o`000?oooooooooo
00[ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
01Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
01Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo
00gooooo000Looooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0Hooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00[ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00gooooo
000Looooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0?ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00[ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Oooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000Loooo
o`;o00002oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o0000oooo
ooooool09oooool2o`00013ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo01Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool03_ooool2o`0000oooooo000Looooo`03
o`000?oooooooooo00[ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo01Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Hooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo01Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03
o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
3oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oo
oooooooo00Wooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo01Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`000?oo
oooooooo00gooooo000Looooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo
00Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
01Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
01Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo
00gooooo000Looooo`;o00002_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wo
oooo00?o0000ooooooooool09oooool2o`00013ooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0Gooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0Gooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03_ooool2o`0000oo
oooo000Looooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`08ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`0?ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Wooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool03oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo01Oooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool06?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Oooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo00gooooo000L
ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`08
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0H
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?
ooooo`03o`000?oooooooooo00gooooo000Fooooo`;o00001?ooool00ol0003oooooooooo`09oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0Poooo
o`;o00001Oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool05oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00oooooo00?o0000oooo
ooooool03Oooool001Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`09oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0Ooooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0H
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0?
ooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo3?l00000
0ol00?oo0000o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l00000
0ol00?oo0000o`00000:o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l00000
0ol00?oo0000o`000005o`000003o`00ool0003o000000_o000000?o003oo`000?l000001Ol00000
0ol00?oo0000o`000007o`000003o`00ool0003o000000Go000000?o003oo`000?l000002ol00000
0ol00?oo0000o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001Ol00000
0ol00?oo0000o`00000;o`000003o`00ool0003o000000Go000000?o003oo`000?l000001_l00000
0ol00?oo0000o`000006o`000003o`00ool0003o000000Wo00008Oooool01?l0003oooooooooool0
0004ooooo`Go000000?o003oo`000?l000002_l000000ol00?oo0000o`00000;o`000003o`00ool0
003o000000[o000000?o003oo`000?l000002_l000000ol00?oo0000o`00000:o`000003o`00ool0
003o000000_o000000?o003oo`000?l000002_l000000ol00?oo0000o`00000:o`000003o`00ool0
003o000000[o000000?o003oo`000?l000002ol000000ol00?oo0000o`00000:o`000003o`00ool0
003o000000[o000000?o003oo`000?l000002_l000000ol00?oo0000o`00000;o`000003o`00ool0
003o000000[o000000?o003oo`000?l000000ol0000?ooooo`005Oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`08ooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?oooooo
ooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?oooooo
ooooo`02ooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo
00?o0000ooooooooool07oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;o
oooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Co
oooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00;o
oooo00?o0000ooooooooool03Oooool001Gooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`0Oooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool00ol0
0?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09?ooool00ol0
0?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool00_ooool00ol0
003oooooooooo`0=ooooo`005_ooool2o`0000Cooooo00?o0000ooooooooool02?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool08?ooool2o`0000Go
oooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Go
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Go
oooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003ooooo
ooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool09Oooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool09Oooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03Oooool001cooooo0_l0
0009ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`0Wooooo`;o00000oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o
003oooooooooool09?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00Co
003ooooooooooooooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00;ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooo
oooooooo02Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooo
oooooooo00;ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02?ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool0
0ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool0
0ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo
00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo
02Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo
02Gooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003o
ooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`0Uooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`0Uooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03Oooool001cooooo
00?o0000ooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Sooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Gooooo
00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo
00?o003oooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo
000Looooo`;o00002Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o
0000ooooooooool09oooool2o`0000?ooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`0Uooooo`04o`00ooooooooooooooooo`;o00003oooool001cooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooo
oooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooo
oooo02Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooo
oooo02Gooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0
003oooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool09Oooool00ol0
0?ooooooooooo`0Uooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool09Oooool00ol0
0?ooooooooooo`0Uooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03Oooool001co
oooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Go
oooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Go
oooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00go
oooo000Looooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09?ooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool00_ooool00ol0003ooooo
ooooo`0=ooooo`007?ooool2o`0000Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`07ooooo`03o`000?oooooooooo02Oooooo0_l00003ooooo`03o`00oooooooooooo02Gooooo00?o
003oooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o
003oooooooooool09Oooool01?l00?ooooooooooooooool2o`0000oooooo000Looooo`03o`000?oo
oooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooo
oooooooo02Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooo
oooooooo02Gooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool0
0ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool09Oooool0
0ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool09Oooool0
0ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03Oooool0
01cooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo
02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo
02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo
00gooooo000Dooooo`Go00000oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool01oooool00ol0003oooooooooo`0Nooooo`Go00001?ooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oo
oooo00?o0000ooooooooool07oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00;ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo
02Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo
00;ooooo00?o0000ooooooooool03Oooool001Kooooo00?o0000ooooooooool00oooool3o`0000So
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`06ooooo`;o00008_ooool00ol0003o
ooooooooo`04ooooo`;o00000oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Go
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Go
oooo00Co003ooooooooooooooooo0_l0000?ooooo`005oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`05
o`00ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Doooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02Oooool01Ol00?oooooooooooooooooo003o00cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00Go
003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
1oooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Dooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00Go003ooooooooo
ooooooooo`00o`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool01Ol0
0?oooooooooooooooooo003o00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:
ooooo`05o`00ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00[ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool01oooool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Eooooo`?o0000
1?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00Go003ooooooooooooo
ooooo`00o`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool01Ol00?oo
oooooooooooooooo003o00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:oooo
o`05o`00ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00[ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool01_ooool00ol0003oooooooooo`0Oooooo`?o00001Oooool00ol0003ooooooooo
o`02ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`0Tooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`02ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Oooooo00?o003o
ooooooooool02oooool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02Oooool01Ol00?oooooooooooooooooo003o00cooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l03?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`0<oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool01?l00?ooooooooooool00?l=
ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02
ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`02
ooooo`03o`000?oooooooooo00gooooo000Looooo`;o00002?ooool00ol00?ooooooooooo`0;oooo
o`04o`00ooooooooooooo`00o`gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:
ooooo`05o`00ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00[ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00cooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0:ooooo`04o`00ooooooooooooo`00o`gooooo00?o003ooooo
ooooool01_ooool00ol0003oooooooooo`0Wooooo`;o00000oooool00ol00?ooooooooooo`0Uoooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Uoooo
o`03o`00oooooooooooo02Gooooo00Co003ooooooooooooooooo0_l0000?ooooo`007?ooool00ol0
003oooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooooooo003o3Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00
o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool01?l00?oooooooooo
ool00?l=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool01?l00?oooooo
ooooool00?l=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool01?l00?oo
ooooooooool00?l=ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol0
0?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol0
0?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Oo
oooo00?o003oooooooooool02oooool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool02oooool00ol00?ooooooo`00o`0=ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02_ooool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool02_ooool01?l00?ooooooooooool00?l=ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02_ooool01?l00?ooooooooooool00?l=ooooo`03o`00
oooooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00
oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00
oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`00
0?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool02ooo
ool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
2oooool00ol00?ooooooo`00o`0=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2oooool00ol00?ooooooo`00o`0=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2_ooool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool02_ooool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003ooooo
ooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003ooooo
ooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Looooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool02oooool01?l00?ooooooooooool00?l=oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool02oooool00ol00?ooooooo`00o`0=oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooo`00o`0=oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooo`00o`0=oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooo`00o`0=oooo
o`03o`00oooooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02oooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Toooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`02oooo
o`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool03?ooool2o`00o`kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooo003o00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooo003o00gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooo003o00gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`;o
003o3_ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool09?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0000Sooooo00?o003oooooooooool0
3?ooool2o`00o`kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`?o003o
3Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo0ol00?l>ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool02oooool2o`00o`kooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0;ooooo`;o003o3_ooool00ol00?ooooooooooo`06ooooo`03o`00
0?oooooooooo02Oooooo0_l00003ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0
9Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0
9Oooool01?l00?ooooooooooooooool2o`0000oooooo000Looooo`03o`000?oooooooooo00Oooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01_ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01_ooooo
00?o003oooooooooool01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo
00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Cooooo
00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00;ooooo
00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01oooool00ol00?oooooooooo
o`0Looooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0Kooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09?ooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool00_ooool00ol0003ooooooooo
o`0=ooooo`007?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Kooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Loooo
o`03o`000?oooooooooo00Oooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00;ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uoooo
o`03o`00oooooooooooo02Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uoooo
o`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000oooooooo
ool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool09?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`07ooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00
oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00
oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`00
0?oooooooooo00gooooo000Looooo`;o00002?ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`06ooooo`03o`000?oo
oooooooo02Oooooo0_l00003ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Ooo
ool01?l00?ooooooooooooooool2o`0000oooooo000Looooo`03o`000?oooooooooo00Oooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o
003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Cooooo00?o
003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00;ooooo00?o
0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0U
ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0U
ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0=
ooooo`005_ooool3o`0000?ooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05oooo
o`03o`000?oooooooooo023ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Cooooo00?o003ooooo
ooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00;ooooo00?o0000oooo
ooooool03Oooool001Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03
o`00oooooooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03
o`00oooooooooooo02Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03
o`00oooooooooooo00;ooooo00?o0000ooooooooool03Oooool001Cooooo1Ol00003ooooo`03o`00
0?oooooooooo00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0Nooooo`Go0000
1?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0
9Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0
9Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Dooooo`04o`000?oo
ooooooooo`0000Cooooo0ol00007ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Cooooo0_l0000Pooooo`04o`00
0?ooooooooooo`0000Gooooo0_l00003ooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool09Oooool01?l00?ooooooooooooooool2o`0000oooooo000Eooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Go
oooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Go
oooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00go
oooo000Fooooo`;o00001?ooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo01kooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo
00?o0000ooooooooool08?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09?ooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool00_ooool00ol0003ooooo
ooooo`0=ooooo`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o
003oooooooooool07_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool01Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o
003oooooooooool09?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o
003oooooooooool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`06
ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02
ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0T
ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`02
ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Kooooo00?o003ooooo
ooooool07_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Cooooo00?o003ooooo
ooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00;ooooo00?o0000oooo
ooooool03Oooool001cooooo0_l00007ooooo`03o`00oooooooooooo01kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool07oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00Gooooo00?o0000oooooooo
ool09oooool2o`0000?ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03
o`00oooooooooooo02Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`04
o`00ooooooooooooooooo`;o00003oooool001cooooo00?o0000ooooooooool01_ooool00ol00?oo
ooooooooo`0Nooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0Mooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07_ooool00ol00?oo
ooooooooo`05ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?oo
ooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09?ooool00ol00?oo
ooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool00_ooool00ol0003o
ooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo01kooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool07oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00Gooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Gooooo
00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo
00?o003oooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo
000Looooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool07oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0Oooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool01Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000
ooooooooool01Oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool07_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool07_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool09?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`05oooo
o`03o`00oooooooooooo01oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Noooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo01oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Noooo
o`03o`00oooooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02oooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Toooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`02oooo
o`03o`000?oooooooooo00gooooo000Looooo`;o00001_ooool00ol00?ooooooooooo`0Oooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo01oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo02Oooooo0_l00003ooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool09Oooool01?l00?ooooooooooooooool2o`0000oooooo000Looooo`03o`000?oooooooooo00Go
oooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01ko
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool07oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;o
oooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Co
oooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00;o
oooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`0Pooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?oooooo
ooooo`04ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09?ooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool00_ooool00ol0003ooooo
ooooo`0=ooooo`007?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo023ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool07oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00Cooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o
003oooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o
003oooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo000L
ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0O
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0U
ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0U
ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000oooo
ooooool01Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool07oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool07oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003ooooo
ooooool09?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003ooooo
ooooool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0000Kooooo00?o003ooooooooo
ool08?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool07oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`0Wooooo`;o00000oooool00ol00?ooooooooooo`0Uooooo`03
o`00oooooooooooo02Gooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Uooooo`03
o`00oooooooooooo02Gooooo00Co003ooooooooooooooooo0_l0000?ooooo`007?ooool00ol0003o
ooooooooo`05ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool08?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Oooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Cooooo
00?o003oooooooooool08Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo023ooooo
00Go003oooooooooooooooooo`00o`0Rooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool07oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo023ooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Cooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00;ooooo00?o0000oooooooo
ool03Oooool001Gooooo0ol00004ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
8Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo023ooooo00Go003ooooooooooooo
ooooo`00o`0Rooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool08?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01?ooool00ol0003o
ooooooooo`0Oooooo`?o00001Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Go
oooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Go
oooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00go
oooo000Dooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`03
o`00oooooooooooo027ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Pooooo`05
o`00ooooooooooooooooool00?l08oooool01Ol00?oooooooooooooooooo003o02;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Cooooo00?o0000
ooooooooool07_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_oo
ool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09?oo
ool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool00_oo
ool00ol0003oooooooooo`0=ooooo`005?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool08?ooool01Ol00?oooooooooooooooooo003o02?ooooo00Go003ooooooooooooo
ooooo`00o`0Rooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool08?ooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00;ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uoooo
o`03o`00oooooooooooo02Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uoooo
o`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03Oooool001Cooooo1?l00004ooooo`?o
00001?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool08?ooool01Ol00?oooooooooooooooooo003o02?ooooo00Go003oooooooooooooooooo`00o`0R
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`03
ooooo`;o00008?ooool4o`0000Gooooo0_l00003ooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool09Oooool01?l00?ooooooooooooooool2o`0000oooooo000Dooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool08?ooool01Ol00?oooooooooooooooooo003o02?ooooo00Go
003oooooooooooooooooo`00o`0Sooooo`05o`00ooooooooooooooooool00?l08_ooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Eooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Qooooo`05o`00ooooooooooooooooool0
0?l08oooool01Ol00?oooooooooooooooooo003o02?ooooo00Go003oooooooooooooooooo`00o`0S
ooooo`05o`00ooooooooooooooooool00?l08_ooool00ol00?ooooooooooo`04ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00oooo
oooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooo
oooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oo
oooooooo00gooooo000Fooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooo
oooo027ooooo00Go003oooooooooooooooooo`00o`0Sooooo`05o`00ooooooooooooooooool00?l0
8oooool01Ol00?oooooooooooooooooo003o02?ooooo00Go003oooooooooooooooooo`00o`0Soooo
o`03o`00oooooooooooo00?ooooo00?o0000ooooooooool08?ooool2o`0000Gooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003ooooo
ooooool09?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003ooooo
ooooool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`04ooooo`03
o`00oooooooooooo027ooooo00Go003oooooooooooooooooo`00o`0Sooooo`05o`00oooooooooooo
ooooool00?l08oooool01Ol00?oooooooooooooooooo003o02?ooooo00Co003ooooooooooooo003o
9?ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
0_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0
9?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00oooo
oooooooo02;ooooo00Co003ooooooooooooo003o8oooool01Ol00?oooooooooooooooooo003o02?o
oooo00Go003oooooooooooooooooo`00o`0Sooooo`04o`00ooooooooooooo`00obCooooo00?o003o
ooooooooool00oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Cooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00;ooooo00?o0000
ooooooooool03Oooool001cooooo0_l00005ooooo`03o`00oooooooooooo02;ooooo00Co003ooooo
oooooooo003o8oooool01Ol00?oooooooooooooooooo003o02?ooooo00Go003ooooooooooooooooo
o`00o`0Sooooo`04o`00ooooooooooooo`00obCooooo00?o003oooooooooool00oooool00ol0003o
ooooooooo`0Wooooo`;o00000oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Go
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Go
oooo00Co003ooooooooooooooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`04ooooo`03
o`00oooooooooooo02;ooooo00Co003ooooooooooooo003o8oooool01Ol00?oooooooooooooooooo
003o02Cooooo00?o003oooooool00?l09?ooool01?l00?ooooooooooool00?lTooooo`03o`00oooo
oooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooo
oooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooo
oooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oo
oooooooo00gooooo000Looooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool08_ooool0
0ol00?ooooooo`00o`0Uooooo`03o`00oooooooo003o02Gooooo00?o003oooooool00?l09?ooool0
1?l00?ooooooooooool00?lTooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooo
oooo00?ooooo00?o003oooooooooool08oooool00ol00?ooooooo`00o`0Uooooo`03o`00oooooooo
003o02Gooooo00?o003oooooool00?l09?ooool01?l00?ooooooooooool00?lTooooo`03o`00oooo
oooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooo
oooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Tooooo`03o`00oooo
oooooooo02Gooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`02ooooo`03o`000?oo
oooooooo00gooooo000Looooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool08oooool0
0ol00?ooooooo`00o`0Uooooo`03o`00oooooooo003o02Gooooo00?o003oooooool00?l09Oooool2
o`00obKooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00;ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooo
oooo02Cooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooo
oooo00;ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool00oooool00ol0
0?ooooooooooo`0Tooooo`;o003o9Oooool3o`00obGooooo0_l00?lVooooo`;o003o9_ooool00ol0
0?ooooooooooo`02ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooooooo0ol00?lU
ooooo`?o003o9Oooool3o`00obCooooo0ol00?lUooooo`?o003o9Oooool3o`00o`?ooooo00?o0000
ooooooooool03Oooool001cooooo0_l00003ooooo`;o003o9_ooool2o`00obKooooo00?o003ooooo
ooooool09?ooool2o`00obKooooo0_l00?lVooooo`03o`00oooooooooooo00;ooooo00?o0000oooo
ooooool09oooool2o`0000;ooooo0ol00?lUooooo`?o003o9Oooool3o`00obCooooo0ol00?lUoooo
o`?o003o9Oooool3o`00o`;ooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`3>ooooo`03
o`000?oooooooooo02Oooooo00Co0000oooooooooooooooo0ol00?lUooooo`?o003o9Oooool3o`00
obCooooo0ol00?lUooooo`?o003o9Oooool3o`00o`?ooooo00?o0000ooooooooool03Oooool001co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03Oooool001coooood_l0000Yooooom;o00003oooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-10.3779, \
-0.501709, 0.0760741, 0.02454}, {{262.875, 490.688}, {303, 162.25}} -> \
{-29.4329, -0.501107, 0.0760514, 0.0245326}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-0.852551, -17.6965, 0.0251258, 0.082325}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-21.4467, -17.6965, 0.0753772, 0.082325}}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Undersampling and the DTFT: Example #2", "Section"],

Cell[CellGroupData[{

Cell["Sampling frequency", "Subsection"],

Cell[BoxData[
    \(\(fs = 3.5\  (*\ Hz\ *) ;\)\)], "Input",
  Background->RGBColor[1, 1, 0]]
}, Closed]],

Cell[CellGroupData[{

Cell["Continuous-time signal", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := 
        1\  + \ 2\ Cos[2  \[Pi]\ t]\  + \ 4\ Cos[4  \[Pi]\ t];\)\), "\n", 
    \(\(gxt = 
        Plot[x[t], {t, 0, 5}, PlotStyle \[Rule] {Blue, Thickness[ .005]}, \ 
          PlotPoints \[Rule] 100];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.196383 0.0581337 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -12 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .31265 -6 -4.5 ]
[-0.0125 .31265 0 4.5 ]
[-0.0125 .42892 -6 -4.5 ]
[-0.0125 .42892 0 4.5 ]
[-0.0125 .54519 -6 -4.5 ]
[-0.0125 .54519 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(1)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(2)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(3)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(4)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(-2)] -0.0125 .08012 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(0)] -0.0125 .19638 1 0 Mshowa
0 .31265 m
.00625 .31265 L
s
[(2)] -0.0125 .31265 1 0 Mshowa
0 .42892 m
.00625 .42892 L
s
[(4)] -0.0125 .42892 1 0 Mshowa
0 .54519 m
.00625 .54519 L
s
[(6)] -0.0125 .54519 1 0 Mshowa
.125 Mabswid
0 .10918 m
.00375 .10918 L
s
0 .13825 m
.00375 .13825 L
s
0 .16732 m
.00375 .16732 L
s
0 .22545 m
.00375 .22545 L
s
0 .25452 m
.00375 .25452 L
s
0 .28358 m
.00375 .28358 L
s
0 .34172 m
.00375 .34172 L
s
0 .37078 m
.00375 .37078 L
s
0 .39985 m
.00375 .39985 L
s
0 .45798 m
.00375 .45798 L
s
0 .48705 m
.00375 .48705 L
s
0 .51612 m
.00375 .51612 L
s
0 .05105 m
.00375 .05105 L
s
0 .02198 m
.00375 .02198 L
s
0 .57425 m
.00375 .57425 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .31265 m
1 .31265 L
s
.99375 .42892 m
1 .42892 L
s
.99375 .54519 m
1 .54519 L
s
.125 Mabswid
.99625 .10918 m
1 .10918 L
s
.99625 .13825 m
1 .13825 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .22545 m
1 .22545 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .28358 m
1 .28358 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .37078 m
1 .37078 L
s
.99625 .39985 m
1 .39985 L
s
.99625 .45798 m
1 .45798 L
s
.99625 .48705 m
1 .48705 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .02198 m
1 .02198 L
s
.99625 .57425 m
1 .57425 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .19638 m
1 .19638 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.02381 .60332 m
.02409 .60327 L
.02435 .60315 L
.02465 .60291 L
.02494 .6026 L
.02544 .60181 L
.02599 .60063 L
.02659 .59894 L
.02722 .5967 L
.02837 .59157 L
.03066 .57704 L
.03318 .55482 L
.03845 .48973 L
.04339 .4114 L
.05279 .24379 L
.05757 .16395 L
.06278 .0915 L
.0652 .06507 L
.06778 .04268 L
.06903 .0341 L
.07021 .02743 L
.07126 .02263 L
.07241 .01871 L
.07298 .01724 L
.0733 .01658 L
.0736 .01604 L
.07388 .01562 L
.07418 .01526 L
.07446 .01501 L
.07471 .01485 L
.07501 .01474 L
.0753 .01472 L
.07561 .01479 L
.07578 .01487 L
.07594 .01497 L
.07624 .01523 L
.07657 .01561 L
.07724 .01672 L
.07791 .01826 L
.07852 .02003 L
.07989 .02524 L
.08115 .03157 L
.08235 .03879 L
.0872 .07912 L
.09167 .12835 L
.10123 .24727 L
.10603 .30069 L
.11041 .33874 L
.11157 .34657 L
.11283 .35393 L
Mistroke
.11404 .35977 L
.11513 .36402 L
.11574 .36596 L
.1164 .36769 L
.1171 .3691 L
.11741 .3696 L
.11775 .37004 L
.11807 .37036 L
.11837 .37058 L
.11869 .37073 L
.11886 .37077 L
.11902 .37078 L
.11931 .37075 L
.11962 .37064 L
.11992 .37045 L
.12019 .37021 L
.12048 .36988 L
.12078 .36946 L
.12132 .36851 L
.1219 .3672 L
.12253 .36544 L
.12367 .36141 L
.12473 .35669 L
.12714 .34252 L
.12972 .32259 L
.13491 .27024 L
.1398 .21108 L
.14913 .0974 L
.15396 .05168 L
.15639 .03472 L
.15778 .02724 L
.15907 .02176 L
.16028 .01801 L
.16096 .01651 L
.16129 .01595 L
.1616 .01552 L
.16186 .01522 L
.16215 .01497 L
.16247 .0148 L
.16276 .01472 L
.16305 .01473 L
.16336 .01484 L
.16352 .01493 L
.16369 .01505 L
.16399 .01535 L
.1643 .01574 L
.16457 .01618 L
.1652 .01746 L
.16576 .01892 L
.16635 .02081 L
Mistroke
.16737 .02492 L
.16849 .03065 L
.17095 .04758 L
.1732 .06811 L
.17826 .13016 L
.18789 .29 L
.19716 .45192 L
.20233 .52571 L
.20477 .5533 L
.20702 .57375 L
.20936 .58964 L
.2106 .59562 L
.21123 .59802 L
.2119 .60009 L
.2125 .6015 L
.21304 .60243 L
.2133 .60277 L
.21358 .60304 L
.21385 .60321 L
.2141 .6033 L
.21438 .60331 L
.21465 .60324 L
.21495 .60307 L
.21527 .60277 L
.21558 .60236 L
.21591 .60181 L
.21651 .60052 L
.21713 .59872 L
.21772 .59663 L
.21882 .59168 L
.22001 .58487 L
.2213 .5758 L
.22575 .53171 L
.23057 .46515 L
.23567 .38002 L
.24486 .21607 L
.24998 .13491 L
.25465 .0757 L
.25696 .05313 L
.25818 .04321 L
.25948 .03424 L
.26073 .02719 L
.26186 .02216 L
.26241 .02019 L
.263 .0184 L
.26356 .01703 L
.26406 .01606 L
.26434 .01564 L
.26464 .01528 L
.26496 .01499 L
Mistroke
.26526 .01481 L
.26554 .01473 L
.26584 .01472 L
.2661 .01479 L
.26638 .01494 L
.26655 .01507 L
.26671 .01521 L
.26701 .01556 L
.26769 .01665 L
.26827 .01795 L
.26891 .01975 L
.27019 .0245 L
.27156 .03118 L
.27402 .04717 L
.27921 .09495 L
.2841 .15207 L
.29344 .26771 L
.29818 .31668 L
.30087 .33859 L
.30216 .34728 L
.30338 .35432 L
.30454 .35988 L
.30579 .36466 L
.30635 .36634 L
.30694 .36783 L
.30749 .36896 L
.308 .36975 L
.30828 .3701 L
.30858 .37039 L
.30888 .3706 L
.30905 .37069 L
.30921 .37074 L
.3095 .37078 L
.30976 .37076 L
.31006 .37065 L
.31035 .37048 L
.31067 .37021 L
.311 .36982 L
.3116 .36888 L
.31224 .36752 L
.31295 .36561 L
.31421 .36114 L
.31541 .35565 L
.31766 .34223 L
.32008 .32358 L
.32273 .29887 L
.33259 .18173 L
.33715 .12531 L
.34208 .07219 L
.34479 .04892 L
Mistroke
.34598 .04039 L
.34728 .03232 L
.34843 .02639 L
.34966 .02133 L
.35034 .01913 L
.35096 .01751 L
.35159 .01624 L
.35187 .01579 L
.35217 .01539 L
.35247 .01509 L
.35275 .01489 L
.35301 .01477 L
.35329 .01472 L
.35359 .01475 L
.35388 .01486 L
.35419 .01507 L
.35436 .01523 L
.35452 .01541 L
.35513 .01632 L
.35548 .01701 L
.3558 .01775 L
.35701 .02147 L
.35804 .02584 L
.35918 .03188 L
.36148 .04798 L
.36394 .07087 L
.3662 .09647 L
.37127 .16804 L
.38091 .33603 L
.39019 .49078 L
.39498 .55056 L
.3974 .57301 L
.3987 .58265 L
.40007 .59088 L
.40124 .59627 L
.40185 .59851 L
.40251 .60044 L
.40282 .60118 L
.40312 .60178 L
.40341 .60227 L
.40367 .60264 L
.40392 .60292 L
.40419 .60313 L
.40446 .60327 L
.40475 .60332 L
.40491 .60331 L
.40509 .60326 L
.40541 .60308 L
.40572 .6028 L
.40601 .60243 L
Mistroke
.40635 .60188 L
.40666 .60126 L
.40736 .59948 L
.40797 .59749 L
.40862 .59488 L
.40981 .58896 L
.41211 .57312 L
.41464 .54953 L
.41975 .48471 L
.42955 .31903 L
.43898 .15677 L
.44145 .12088 L
.44413 .08679 L
.44645 .06212 L
.44901 .04059 L
.4502 .03272 L
.45149 .02582 L
.4527 .02082 L
.45381 .01754 L
.45442 .01626 L
.45472 .01579 L
.45499 .01542 L
.45515 .01525 L
.45532 .01508 L
.45562 .01487 L
.45579 .01479 L
.45597 .01474 L
.45612 .01472 L
.45629 .01472 L
.45646 .01476 L
.45663 .01482 L
.45694 .015 L
.45711 .01515 L
.45727 .01531 L
.45764 .01577 L
.45825 .01683 L
.4589 .01835 L
.4602 .0226 L
.4614 .02787 L
.4641 .04428 L
.46648 .06342 L
.469 .08767 L
.47822 .19798 L
.48335 .26118 L
.48803 .31092 L
.49036 .33113 L
.49289 .34882 L
.49404 .3553 L
.49527 .36097 L
.49632 .36482 L
Mistroke
.49748 .36797 L
.49808 .36915 L
.4984 .36965 L
.49874 .37008 L
.49906 .37039 L
.49936 .3706 L
.49965 .37073 L
.49993 .37078 L
.5002 .37077 L
.50049 .37068 L
.50074 .37054 L
.50101 .37033 L
.5013 .37003 L
.50161 .36963 L
.50218 .36869 L
.50283 .36725 L
.50354 .36527 L
.50482 .36058 L
.50724 .34807 L
.50951 .33214 L
.51203 .31037 L
.51712 .25564 L
.52686 .13451 L
.53133 .08427 L
.53387 .06032 L
.53623 .04192 L
.53858 .02797 L
.53989 .02224 L
.54109 .01839 L
.54174 .01684 L
.54235 .01579 L
.54266 .01538 L
.54301 .01504 L
.54319 .01491 L
.54337 .01481 L
.54355 .01475 L
.54371 .01472 L
.54403 .01474 L
.54432 .01484 L
.54449 .01494 L
.54465 .01506 L
.54499 .0154 L
.54529 .0158 L
.54561 .01633 L
.5462 .01756 L
.54678 .01911 L
.54739 .02114 L
.54851 .02578 L
.54983 .03293 L
.55104 .04095 L
Mistroke
.55366 .06324 L
.55615 .09009 L
.56544 .22957 L
.57534 .40593 L
.58025 .48472 L
.58266 .51787 L
.58486 .5442 L
.58697 .56528 L
.58927 .5833 L
.59047 .59048 L
.59159 .59576 L
.59219 .59806 L
.59276 .59984 L
.59342 .60145 L
.59371 .60199 L
.59402 .60248 L
.59433 .60284 L
.5946 .60309 L
.59488 .60325 L
.59515 .60331 L
.59545 .60329 L
.59574 .60318 L
.59605 .60294 L
.59622 .60277 L
.59638 .60257 L
.597 .60155 L
.59735 .60079 L
.59767 .59996 L
.59888 .59581 L
.59992 .59094 L
.60106 .58426 L
.60335 .56664 L
.60584 .54171 L
.6081 .51423 L
.61317 .43891 L
.62285 .26805 L
.63216 .11766 L
.63697 .06173 L
.6394 .04126 L
.64077 .0322 L
.64207 .02532 L
.64324 .02058 L
.64391 .01851 L
.64453 .01699 L
.64482 .01641 L
.6451 .01593 L
.64535 .01557 L
.64561 .01526 L
.6459 .015 L
.64617 .01483 L
Mistroke
.64646 .01473 L
.64677 .01472 L
.64694 .01475 L
.64711 .01482 L
.64728 .01491 L
.64743 .01502 L
.64773 .01528 L
.64804 .01566 L
.64868 .01673 L
.64939 .01839 L
.65065 .02249 L
.65183 .02766 L
.65422 .04173 L
.65673 .06136 L
.66121 .10646 L
.67045 .22014 L
.6756 .28122 L
.68028 .32665 L
.68262 .34411 L
.68385 .35167 L
.68515 .35836 L
.68629 .36307 L
.68689 .36512 L
.68754 .36698 L
.68814 .36836 L
.68868 .36936 L
.68894 .36974 L
.68923 .37009 L
.68948 .37034 L
.68975 .37055 L
.6899 .37064 L
.69007 .37071 L
.69037 .37078 L
.69053 .37078 L
.69071 .37076 L
.69088 .37071 L
.69104 .37064 L
.69134 .37046 L
.69151 .37031 L
.69166 .37016 L
.69225 .36939 L
.69278 .36845 L
.69335 .36713 L
.69452 .36358 L
.69579 .35843 L
.69715 .35142 L
.69961 .33506 L
.70448 .29062 L
.7096 .23143 L
.71885 .11665 L
Mistroke
.7215 .08744 L
.72401 .0633 L
.72644 .04377 L
.72751 .03661 L
.72869 .02983 L
.72976 .02471 L
.7309 .02035 L
.73153 .01846 L
.73211 .01707 L
.73269 .01599 L
.73297 .01558 L
.73324 .01527 L
.73352 .01501 L
.73383 .01482 L
.73414 .01473 L
.73431 .01472 L
.73446 .01473 L
.73473 .01481 L
.73502 .01497 L
.73532 .01524 L
.7356 .01556 L
.73625 .01663 L
.73684 .01797 L
.73752 .01995 L
.73817 .02226 L
.74052 .03423 L
.74171 .04236 L
.74301 .05288 L
.74748 .1006 L
.75219 .16762 L
.75725 .25296 L
.76725 .4302 L
.77225 .50611 L
.77468 .53673 L
.77688 .56004 L
.77919 .57943 L
.78025 .58648 L
.78136 .59262 L
.78194 .59523 L
.78256 .59768 L
.78314 .59954 L
.78366 .60092 L
.78428 .60215 L
.78462 .60264 L
.78478 .60282 L
.78495 .60298 L
.78524 .60319 L
.78552 .6033 L
.78582 .60331 L
.78598 .60328 L
Mistroke
.78614 .60321 L
.78643 .60303 L
.78673 .60273 L
.78702 .60235 L
.78728 .60192 L
.78792 .60054 L
.78853 .59882 L
.78973 .59417 L
.79104 .58733 L
.79337 .57056 L
.79553 .55024 L
.80008 .4937 L
.80508 .41503 L
.81486 .24079 L
.81937 .16554 L
.82428 .09644 L
.82695 .06664 L
.82942 .04468 L
.83178 .02917 L
.8331 .02292 L
.83367 .02076 L
.83429 .01877 L
.83486 .0173 L
.83548 .01609 L
.83582 .01558 L
.83613 .01522 L
.83644 .01496 L
.83673 .0148 L
.837 .01472 L
.83729 .01473 L
.83753 .01479 L
.8378 .01494 L
.83809 .01517 L
.8384 .01552 L
.83897 .01638 L
.83961 .01775 L
.84032 .01969 L
.84161 .02443 L
.84286 .03047 L
.84402 .03728 L
.84899 .07799 L
.8535 .12742 L
.86321 .24822 L
.86766 .29799 L
.87019 .32185 L
.87255 .34042 L
.87488 .35471 L
.87619 .36083 L
.87738 .36517 L
.87799 .36692 L
Mistroke
.87864 .36842 L
.87898 .36906 L
.87935 .36964 L
.87969 .37008 L
.88 .37039 L
.8803 .3706 L
.88062 .37074 L
.88094 .37078 L
.88112 .37077 L
.88129 .37073 L
.88159 .3706 L
.88187 .37041 L
.88219 .37011 L
.88249 .36974 L
.88307 .36881 L
.88361 .36767 L
.88484 .36412 L
.88605 .35942 L
.88734 .35303 L
.88967 .33812 L
.89181 .32102 L
.90144 .21431 L
.91071 .10096 L
.91549 .05473 L
.91816 .03559 L
.91931 .02909 L
.92057 .02329 L
.92176 .01917 L
.9224 .01747 L
.92301 .01625 L
.9233 .01579 L
.92357 .01543 L
.92382 .01516 L
.92409 .01495 L
.92438 .01479 L
.92464 .01472 L
.92493 .01473 L
.92525 .01483 L
.92556 .01503 L
.92573 .01517 L
.9259 .01535 L
.9265 .01621 L
.92684 .01686 L
.9272 .01768 L
.92785 .01948 L
.92913 .02429 L
.9303 .03009 L
.93272 .04649 L
.93495 .06658 L
.94 .12776 L
Mistroke
.94956 .28566 L
.95875 .44693 L
.96387 .52113 L
.9661 .54732 L
.96854 .57063 L
.97058 .58557 L
.97147 .59075 L
.97247 .59546 L
.9734 .59888 L
.97427 .60122 L
.97475 .60214 L
.97519 .60275 L
.97543 .60299 L
.97568 .60317 L
.97594 .60328 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`00033ooooo0ol0000^ooooo`Go0000;oooool3o`00037ooooo0ol0000^oooo
o`?o00002_ooool001Kooooo00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`0^oooo
o`04o`000?ooooooooooo`0002kooooo00Go0000ooooooooooooooooo`00000aooooo`03o`000?oo
oooooooo02cooooo00Go0000ooooooooooooooooo`000009ooooo`005_ooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0/ooooo`Go0000<Oooool00ol0003oooooooooo`07ooooo`005_ooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool2o`0002oooooo
00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`07ooooo`005_ooool01?l0003ooooo
ooooool0000`ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000boooo
o`03o`000?oooooooooo02gooooo00?o0000ooooool00000;_ooool4o`0000[ooooo000Fooooo`04
o`000?ooooooooooo`0002oooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;_ooool0
1Ol0003ooooooooooooooooo0000033ooooo0_l0000^ooooo`03o`000?oooooooooo00_ooooo000G
ooooo`;o0000<Oooool00ol0003oooooooooo`0^ooooo`?o0000<?ooool3o`0003;ooooo00?o0000
ooooooooool0;?ooool5o`0000Wooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo000Aoooooooo00003Ol00003ooooo`004Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo0?oooooo2Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`0Aooooo`;o003o5Oooool2o`00oa[ooooo0_l00?lEooooo`;o003o6Oooool2o`00oaKooooo0_l0
0?lIooooo`;o003o5Oooool3o`00oaWooooo0_l00?lEooooo`;o003o4oooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`0Aooooo`03o`00o`000?oooooo01Cooooo0_l00?l0
0`000?ooooooooooo`0Fooooo`03o`00oooooooo003o01Gooooo0_l00?lIooooo`03o`00oooooooo
003o01Gooooo0_l00?lIooooo`;o003o5Oooool00ol00?ooooooo`00o`0Hooooo`?o003o5Oooool3
o`00oa;ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000Aooooo`03o`00ooooool0003o
01Gooooo00?o003oooooo`000?l06?ooool00ol00?oooooo0000o`0Eooooo`03o`00oooooooo003o
01Sooooo00<0003oooooool00?l05?ooool00ol00?ooooooo`00o`0Iooooo`030000oooooooo003o
01Cooooo00?o003oooooo`000?l06?ooool01?l00?ooooooooooo`000?lDooooo`03o`00ooooool0
003o017ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0@ooooo`04o`00oooooooooooo
o`00oa?ooooo00Co003ooooooooooooo003o6?ooool00ol00?oooooo0000o`0Dooooo`04o`00oooo
ooooooooo`00oaSooooo00<0003oooooo`000?l05?ooool01?l00?ooooooooooo`000?lGooooo`04
0000oooooooooooo0000oaCooooo00<0003oooooo`000?l06?ooool010000?ooooooooooo`000?lD
ooooo`030000ooooool0003o01;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool04?ooool010000?ooooooooooo`000?lCooooo`040000oooooooooooo0000oaSooooo00@0
003oooooooooool0003o4oooool01?l00?ooooooooooo`000?lHooooo`030000ooooool0003o01Co
oooo00@0003oooooooooool0003o5oooool01?l00?ooooooooooo`000?lDooooo`040000oooooooo
oooo0000oaOooooo00@0003oooooooooool0003o4oooool010000?ooooooooooo`000?lBooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo013ooooo00@0003oooooooooool0
003o4oooool010000?ooooooooooo`000?lHooooo`040000oooooooooooo0000oa?ooooo00@0003o
ooooooooool0003o5oooool010000?ooooooooooo`000?lDooooo`040000oooooooooooo0000oaOo
oooo00@0003oooooooooool0003o5?ooool010000?ooooooooooo`000?lGooooo`040000oooooooo
oooo0000oa?ooooo00Co003oooooooooool0003o4_ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0@ooooo`040000oooooooooooo0000oa?ooooo00@0003oooooooooool0
003o6?ooool010000?ooooooooooo`000?lCooooo`040000oooooooooooo0000oaOooooo00D0003o
oooooooooooooooo0000o`0Booooo`050000ooooooooooooooooo`000?l05oooool01@000?oooooo
ooooooooool0003o01;ooooo00D0003ooooooooooooooooo0000o`0Gooooo`040000oooooooooooo
0000oa?ooooo00@0003oooooooooool0003o4_ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`0?ooooo`050000ooooooooooooooooo`000?l04oooool01@000?oooooooooo
ooooool0003o01Kooooo00D0003ooooooooooooooooo0000o`0Cooooo`050000oooooooooooooooo
o`000?l05_ooool01@000?ooooooooooooooool0003o01;ooooo00D0003ooooooooooooooooo0000
o`0Gooooo`050000ooooooooooooooooo`000?l04_ooool01@000?ooooooooooooooool0003o01Ko
oooo00D0003ooooooooooooooooo0000o`0Cooooo`050000ooooooooooooooooo`000?l04Oooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0?ooooo`050000oooooooooooo
ooooo`000?l04_ooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01Cooooo00D0003o
oooooooooooooooo0000o`0Cooooo`050000ooooooooooooooooo`000?l05_ooool01@000?oooooo
ooooooooool0003o01;ooooo00D0003ooooooooooooooooo0000o`0Gooooo`050000oooooooooooo
ooooo`000?l04_ooool01@000?ooooooooooooooool0003o01Kooooo00D0003ooooooooooooooooo
0000o`0Booooo`030000oooooooooooo00;ooooo00<0003oooooooooool03oooool00ol0003ooooo
ooooo`01ooooo`004Oooool2o`00013ooooo00D0003ooooooooooooooooo0000o`0Booooo`030000
oooooooooooo00;ooooo00<0003oooooooooool05?ooool01@000?ooooooooooooooool0003o01;o
oooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0Dooooo`050000oooooooooooooooo
o`000?l04_ooool01@000?ooooooooooooooool0003o01Oooooo00D0003ooooooooooooooooo0000
o`0Booooo`050000ooooooooooooooooo`000?l05_ooool01@000?ooooooooooooooool0003o01;o
oooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0>ooooo`;o00000oooool0017ooooo
00?o0000ooooooooool03oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00oooooo
00<0003oooooooooool00_ooool00`000?ooooooooooo`0Dooooo`050000ooooooooooooooooo`00
0?l04_ooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01?ooooo00<0003ooooooooo
ool00_ooool00`000?ooooooooooo`0@ooooo`050000ooooooooooooooooo`000?l05_ooool00`00
0?ooooooooooo`02ooooo`030000oooooooooooo013ooooo00D0003ooooooooooooooooo0000o`0F
ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool03oooool00`000?ooooooooooo`02
ooooo`030000oooooooooooo00oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool03oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00oooooo00<0003ooooo
ooooool00_ooool00`000?ooooooooooo`0Dooooo`050000ooooooooooooooooo`000?l04_ooool0
0`000?ooooooooooo`02ooooo`030000oooooooooooo01?ooooo00<0003oooooooooool00oooool0
0`000?ooooooooooo`0?ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool04oooool0
0`000?ooooooooooo`02ooooo`030000oooooooooooo00oooooo00<0003oooooooooool00_ooool0
0`000?ooooooooooo`0Dooooo`030000oooooooooooo00;ooooo00<0003oooooooooool03oooool0
0`000?ooooooooooo`02ooooo`030000oooooooooooo00oooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool03oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo
00oooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0Cooooo`030000oooooooooooo
00;ooooo00<0003oooooooooool03oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo
01?ooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0?ooooo`030000oooooooooooo
00;ooooo00<0003oooooooooool04oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo
00oooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0Dooooo`030000oooooooooooo
00;ooooo00<0003oooooooooool03oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo
00oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool03oooool00`000?oo
ooooooooo`02ooooo`030000oooooooooooo00oooooo00<0003oooooooooool00oooool00`000?oo
ooooooooo`0Cooooo`030000oooooooooooo00;ooooo00<0003oooooooooool03oooool00`000?oo
ooooooooo`02ooooo`030000oooooooooooo01?ooooo00<0003oooooooooool00oooool00`000?oo
ooooooooo`0?ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool04oooool00`000?oo
ooooooooo`02ooooo`030000oooooooooooo00oooooo00<0003oooooooooool00_ooool00`000?oo
ooooooooo`0Dooooo`030000oooooooooooo00;ooooo00<0003oooooooooool03oooool00`000?oo
ooooooooo`02ooooo`030000oooooooooooo00oooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool03oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00oooooo
00<0003oooooooooool00oooool00`000?ooooooooooo`0Booooo`030000oooooooooooo00?ooooo
00<0003oooooooooool03oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01?ooooo
00<0003oooooooooool00oooool00`000?ooooooooooo`0?ooooo`030000oooooooooooo00;ooooo
00<0003oooooooooool04oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00oooooo
00<0003oooooooooool00oooool00`000?ooooooooooo`0Cooooo`030000oooooooooooo00;ooooo
00<0003oooooooooool03oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00oooooo
00?o0000ooooooooool00Oooool000Sooooo1Ol00004ooooo`03o`000?oooooooooo00oooooo00<0
003oooooooooool00oooool00`000?ooooooooooo`0>ooooo`030000oooooooooooo00?ooooo00<0
003oooooooooool04_ooool00`000?ooooooooooo`03ooooo`030000oooooooooooo00oooooo00<0
003oooooooooool00_ooool00`000?ooooooooooo`0Cooooo`030000oooooooooooo00?ooooo00<0
003oooooooooool03oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01?ooooo00<0
003oooooooooool00_ooool00`000?ooooooooooo`0?ooooo`030000oooooooooooo00?ooooo00<0
003oooooooooool04oooool00`000?ooooooooooo`03ooooo`030000oooooooooooo00kooooo00<0
003oooooooooool00_ooool00`000?ooooooooooo`0?ooooo`03o`000?oooooooooo007ooooo0009
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03oooool00`000?oooooooooo
o`03ooooo`030000oooooooooooo00kooooo00<0003oooooooooool00oooool00`000?oooooooooo
o`0Booooo`030000oooooooooooo00?ooooo00<0003oooooooooool03oooool00`000?oooooooooo
o`02ooooo`030000oooooooooooo01?ooooo00<0003oooooooooool00oooool00`000?oooooooooo
o`0>ooooo`030000oooooooooooo00?ooooo00<0003oooooooooool04oooool00`000?oooooooooo
o`03ooooo`030000oooooooooooo00kooooo00<0003oooooooooool00oooool00`000?oooooooooo
o`0Cooooo`030000oooooooooooo00?ooooo00<0003oooooooooool03_ooool00`000?oooooooooo
o`02ooooo`030000oooooooooooo00oooooo00?o0000ooooooooool00Oooool000;ooooo1Ol00003
ooooo`03o`000?oooooooooo00Cooooo0ol0000>ooooo`030000oooooooooooo00Cooooo00<0003o
ooooooooool03Oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo01;ooooo00<0003o
ooooooooool00oooool00`000?ooooooooooo`0?ooooo`030000oooooooooooo00;ooooo00<0003o
ooooooooool04oooool00`000?ooooooooooo`03ooooo`030000oooooooooooo00kooooo00<0003o
ooooooooool01?ooool00`000?ooooooooooo`0Booooo`030000oooooooooooo00?ooooo00<0003o
ooooooooool03_ooool00`000?ooooooooooo`03ooooo`030000oooooooooooo01?ooooo00<0003o
ooooooooool00oooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00?ooooo00<0003o
ooooooooool03Oooool3o`0000?ooooo000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00gooooo00<0003ooooo
ooooool01?ooool00`000?ooooooooooo`0Booooo`030000oooooooooooo00?ooooo00<0003ooooo
ooooool03oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01?ooooo00<0003ooooo
ooooool00oooool00`000?ooooooooooo`0>ooooo`030000oooooooooooo00Cooooo00<0003ooooo
ooooool04_ooool00`000?ooooooooooo`03ooooo`030000oooooooooooo00kooooo00<0003ooooo
ooooool00oooool00`000?ooooooooooo`0Cooooo`030000oooooooooooo00?ooooo00<0003ooooo
ooooool03Oooool00`000?ooooooooooo`03ooooo`030000oooooooooooo00oooooo00?o0000oooo
ooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00kooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo
00Cooooo00<0003oooooooooool04_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo
00gooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0Booooo`030000oooooooooooo
00?ooooo00<0003oooooooooool03_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo
01;ooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0>ooooo`030000oooooooooooo
00?ooooo00<0003oooooooooool04_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo
00gooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0>ooooo`03o`000?oooooooooo
007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0>oooo
o`030000oooooooooooo00Cooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`04oooo
o`030000oooooooooooo01;ooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0=oooo
o`030000oooooooooooo00Cooooo00<0003oooooooooool04_ooool00`000?ooooooooooo`03oooo
o`030000oooooooooooo00kooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0Aoooo
o`030000oooooooooooo00Cooooo00<0003oooooooooool03_ooool00`000?ooooooooooo`03oooo
o`030000oooooooooooo01;ooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0=oooo
o`030000oooooooooooo00Cooooo00<0003oooooooooool03_ooool00ol0003oooooooooo`01oooo
o`002Oooool3o`0000Gooooo00?o0000ooooooooool03_ooool00`000?ooooooooooo`04ooooo`03
0000oooooooooooo00gooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0Booooo`03
0000oooooooooooo00Cooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`04ooooo`03
0000oooooooooooo01;ooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0>ooooo`03
0000oooooooooooo00Cooooo00<0003oooooooooool04Oooool00`000?ooooooooooo`04ooooo`03
0000oooooooooooo00kooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0Aooooo`03
0000oooooooooooo00Cooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`04ooooo`03
0000oooooooooooo00kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
3_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00gooooo00<0003oooooooooool0
1?ooool00`000?ooooooooooo`0Booooo`030000oooooooooooo00Cooooo00<0003oooooooooool0
3Oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo01;ooooo00<0003oooooooooool0
0oooool00`000?ooooooooooo`0>ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool0
4Oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00gooooo00<0003oooooooooool0
1?ooool00`000?ooooooooooo`0Aooooo`030000oooooooooooo00Cooooo00<0003oooooooooool0
3Oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00kooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool03_ooool00`000?ooooooooooo`04ooooo`030000oooo
oooooooo00gooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0Aooooo`030000oooo
oooooooo00Cooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`04ooooo`030000oooo
oooooooo01;ooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0>ooooo`030000oooo
oooooooo00Cooooo00<0003oooooooooool04Oooool00`000?ooooooooooo`05ooooo`030000oooo
oooooooo00gooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0Aooooo`030000oooo
oooooooo00Cooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`04ooooo`030000oooo
oooooooo00kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool03_ooool0
0`000?ooooooooooo`05ooooo`030000oooooooooooo00cooooo00<0003oooooooooool01Oooool0
0`000?ooooooooooo`0Aooooo`030000oooooooooooo00Cooooo00<0003oooooooooool03Oooool0
0`000?ooooooooooo`04ooooo`030000oooooooooooo017ooooo00<0003oooooooooool01?ooool0
0`000?ooooooooooo`0>ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool04Oooool0
0`000?ooooooooooo`05ooooo`030000oooooooooooo00cooooo00<0003oooooooooool01Oooool0
0`000?ooooooooooo`0Aooooo`030000oooooooooooo00Gooooo00<0003oooooooooool03?ooool0
0`000?ooooooooooo`04ooooo`030000oooooooooooo00kooooo00?o0000ooooooooool00Oooool0
017ooooo0_l0000?ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool03?ooool00`00
0?ooooooooooo`05ooooo`030000oooooooooooo013ooooo00<0003oooooooooool01Oooool00`00
0?ooooooooooo`0=ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool04Oooool00`00
0?ooooooooooo`05ooooo`030000oooooooooooo00gooooo00<0003oooooooooool01?ooool00`00
0?ooooooooooo`0Aooooo`030000oooooooooooo00Gooooo00<0003oooooooooool03?ooool00`00
0?ooooooooooo`05ooooo`030000oooooooooooo017ooooo00<0003oooooooooool01Oooool00`00
0?ooooooooooo`0<ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool03Oooool2o`00
00?ooooo000Aooooo`03o`000?oooooooooo00kooooo00<0003oooooooooool01Oooool00`000?oo
ooooooooo`0<ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool04?ooool00`000?oo
ooooooooo`05ooooo`030000oooooooooooo00cooooo00<0003oooooooooool01Oooool00`000?oo
ooooooooo`0Aooooo`030000oooooooooooo00Gooooo00<0003oooooooooool03?ooool00`000?oo
ooooooooo`05ooooo`030000oooooooooooo017ooooo00<0003oooooooooool01Oooool00`000?oo
ooooooooo`0<ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool04Oooool00`000?oo
ooooooooo`05ooooo`030000oooooooooooo00cooooo00<0003oooooooooool01?ooool00`000?oo
ooooooooo`0>ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00kooooo
00<0003oooooooooool01Oooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00Gooooo
00<0003oooooooooool04?ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00cooooo
00<0003oooooooooool01Oooool00`000?ooooooooooo`0Aooooo`030000oooooooooooo00Gooooo
00<0003oooooooooool03?ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo017ooooo
00<0003oooooooooool01Oooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00Gooooo
00<0003oooooooooool04Oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00cooooo
00<0003oooooooooool01Oooool00`000?ooooooooooo`0=ooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo00kooooo00<0003oooooooooool01Oooool00`000?oooooooooo
o`0<ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool04?ooool00`000?oooooooooo
o`05ooooo`030000oooooooooooo00cooooo00<0003oooooooooool01Oooool00`000?oooooooooo
o`0Aooooo`030000oooooooooooo00Gooooo00<0003oooooooooool03?ooool00`000?oooooooooo
o`05ooooo`030000oooooooooooo017ooooo00<0003oooooooooool01Oooool00`000?oooooooooo
o`0<ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool04Oooool00`000?oooooooooo
o`05ooooo`030000oooooooooooo00cooooo00<0003oooooooooool01Oooool00`000?oooooooooo
o`0=ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00kooooo00<0003o
ooooooooool01Oooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00Gooooo00<0003o
ooooooooool04?ooool00`000?ooooooooooo`06ooooo`030000oooooooooooo00_ooooo00<0003o
ooooooooool01Oooool00`000?ooooooooooo`0Aooooo`030000oooooooooooo00Gooooo00<0003o
ooooooooool03?ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo017ooooo00<0003o
ooooooooool01Oooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00Gooooo00<0003o
ooooooooool04Oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00cooooo00<0003o
ooooooooool01Oooool00`000?ooooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00kooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0;oooo
o`030000oooooooooooo00Kooooo00<0003oooooooooool04?ooool00`000?ooooooooooo`06oooo
o`030000oooooooooooo00_ooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0Aoooo
o`030000oooooooooooo00Gooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`06oooo
o`030000oooooooooooo013ooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0<oooo
o`030000oooooooooooo00Gooooo00<0003oooooooooool04Oooool00`000?ooooooooooo`05oooo
o`030000oooooooooooo00cooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0=oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00gooooo00<0003ooooooooo
ool01_ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Kooooo00<0003ooooooooo
ool04?ooool00`000?ooooooooooo`06ooooo`030000oooooooooooo00_ooooo00<0003ooooooooo
ool01Oooool00`000?ooooooooooo`0Aooooo`030000oooooooooooo00Gooooo00<0003ooooooooo
ool03?ooool00`000?ooooooooooo`06ooooo`030000oooooooooooo013ooooo00<0003ooooooooo
ool01Oooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00Gooooo00<0003ooooooooo
ool04Oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00_ooooo00<0003ooooooooo
ool01_ooool00`000?ooooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo00gooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0;ooooo`030000
oooooooooooo00Kooooo00<0003oooooooooool04?ooool00`000?ooooooooooo`06ooooo`030000
oooooooooooo00_ooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0@ooooo`030000
oooooooooooo00Gooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`06ooooo`030000
oooooooooooo013ooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0<ooooo`030000
oooooooooooo00Gooooo00<0003oooooooooool04?ooool00`000?ooooooooooo`06ooooo`030000
oooooooooooo00_ooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0=ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`;o00003_ooool00`000?ooooooooooo`06ooooo`030000oooo
oooooooo00_ooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0@ooooo`030000oooo
oooooooo00Kooooo00<0003oooooooooool02oooool00`000?ooooooooooo`06ooooo`030000oooo
oooooooo013ooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0<ooooo`030000oooo
oooooooo00Kooooo00<0003oooooooooool04?ooool00`000?ooooooooooo`06ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0?ooooo`030000oooo
oooooooo00Kooooo00<0003oooooooooool02oooool00`000?ooooooooooo`06ooooo`030000oooo
oooooooo00cooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0=ooooo`030000oooooooo
oooo00Kooooo00<0003oooooooooool02oooool00`000?ooooooooooo`06ooooo`030000oooooooo
oooo013ooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0;ooooo`030000oooooooo
oooo00Kooooo00<0003oooooooooool03oooool00`000?ooooooooooo`06ooooo`030000oooooooo
oooo00cooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0@ooooo`030000oooooooo
oooo00Kooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`07ooooo`030000oooooooo
oooo00oooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0;ooooo`030000oooooooo
oooo00Kooooo00<0003oooooooooool03Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`0=ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool02oooool00`00
0?ooooooooooo`06ooooo`030000oooooooooooo013ooooo00<0003oooooooooool01_ooool00`00
0?ooooooooooo`0;ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool03oooool00`00
0?ooooooooooo`07ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool01_ooool00`00
0?ooooooooooo`0?ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`07ooooo`030000oooooooooooo00oooooo00<0003oooooooooool01_ooool00`00
0?ooooooooooo`0;ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool03Oooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0=ooooo`030000oooooooooooo00Ko
oooo00<0003oooooooooool02oooool00`000?ooooooooooo`06ooooo`030000oooooooooooo013o
oooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Ko
oooo00<0003oooooooooool03oooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00_o
oooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0?ooooo`030000oooooooooooo00Oo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00oo
oooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Ko
oooo00<0003oooooooooool03Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`0=ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool02oooool00`000?oooooo
ooooo`06ooooo`030000oooooooooooo013ooooo00<0003oooooooooool01_ooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool03oooool00`000?oooooo
ooooo`07ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool01_ooool00`000?oooooo
ooooo`0?ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`07ooooo`030000oooooooooooo00oooooo00<0003oooooooooool01_ooool00`000?oooooo
ooooo`0;ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool03Oooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`0=ooooo`030000oooooooooooo00Kooooo00<0
003oooooooooool02oooool00`000?ooooooooooo`06ooooo`030000oooooooooooo013ooooo00<0
003oooooooooool01_ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Oooooo00<0
003oooooooooool03oooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool01oooool00`000?ooooooooooo`0?ooooo`030000oooooooooooo00Oooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00oooooo00<0
003oooooooooool01_ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Kooooo00<0
003oooooooooool03Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0=
ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`06
ooooo`030000oooooooooooo013ooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool03oooool00`000?ooooooooooo`07
ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0?
ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`07
ooooo`030000oooooooooooo00oooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool03Oooool00ol0003oooooooooo`01
ooooo`004Oooool2o`0000kooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Kooooo00<0003oooooooooool04?ooool00`000?ooooooooooo`06oooo
o`030000oooooooooooo00[ooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0?oooo
o`030000oooooooooooo00Oooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`07oooo
o`030000oooooooooooo00oooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Oooooo00<0003oooooooooool03oooool00`000?ooooooooooo`07oooo
o`030000oooooooooooo00[ooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0<oooo
o`;o00000oooool0017ooooo00?o0000ooooooooool03Oooool00`000?ooooooooooo`07ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0@ooooo`03
0000oooooooooooo00Kooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`07ooooo`03
0000oooooooooooo00oooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Oooooo00<0003oooooooooool03oooool00`000?ooooooooooo`07ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0?ooooo`03
0000oooooooooooo00Oooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`07ooooo`03
0000oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
3Oooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
1oooool00`000?ooooooooooo`0?ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00oooooo00<0003oooooooooool0
1oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool0
3oooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
1oooool00`000?ooooooooooo`0?ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00cooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool03Oooool00`000?ooooooooooo`07ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0>ooooo`030000oooo
oooooooo00Sooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`07ooooo`030000oooo
oooooooo00oooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Oooooo00<0003oooooooooool03oooool00`000?ooooooooooo`07ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0?ooooo`030000oooo
oooooooo00Oooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`07ooooo`030000oooo
oooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool03Oooool0
0`000?ooooooooooo`07ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool01oooool0
0`000?ooooooooooo`0>ooooo`030000oooooooooooo00Sooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`07ooooo`030000oooooooooooo00oooooo00<0003oooooooooool01oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool03oooool0
0`000?ooooooooooo`07ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02?ooool0
0`000?ooooooooooo`0?ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool02_ooool0
0`000?ooooooooooo`07ooooo`030000oooooooooooo00cooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool03Oooool00`000?ooooooooooo`07ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0>ooooo`030000oooooooooooo
00Sooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`07ooooo`030000oooooooooooo
00oooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Oooooo00<0003oooooooooool03oooool00`000?ooooooooooo`07ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0?ooooo`030000oooooooooooo
00Oooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo
00cooooo00?o0000ooooooooool00Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo00co
oooo00<0003oooooooooool02?ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00So
oooo00<0003oooooooooool03_ooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool01oooool00`000?ooooooooooo`0?ooooo`030000oooooooooooo00So
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00oo
oooo00<0003oooooooooool01oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00So
oooo00<0003oooooooooool03_ooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0<ooooo`03o`000?oooooooooo007o
oooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03?ooool00`000?oo
ooooooooo`08ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02?ooool00`000?oo
ooooooooo`0>ooooo`030000oooooooooooo00Sooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`07ooooo`030000oooooooooooo00oooooo00<0003oooooooooool02?ooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool03oooool00`000?oo
ooooooooo`07ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02?ooool00`000?oo
ooooooooo`0>ooooo`030000oooooooooooo00Sooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`08ooooo`030000oooooooooooo00cooooo00?o0000ooooooooool00Oooool000Wooooo
00Co0000oooooooooooo00001?ooool?o`0000030000ool0003o000000So000000<0003oo`000?l0
00002Ol000000`000?oo0000o`000008o`0000030000ool0003o000000ko000000<0003oo`000?l0
00002?l000000`000?oo0000o`000009o`0000030000ool0003o000000Oo000000<0003oo`000?l0
00003ol000000`000?oo0000o`000008o`0000030000ool0003o000000Wo000000<0003oo`000?l0
00001ol000000`000?oo0000o`00000>o`0000030000ool0003o000000Wo000000<0003oo`000?l0
00002?l000000`000?oo0000o`000008o`0000030000ool0003o000000ko000000<0003oo`000?l0
00002?l000000`000?oo0000o`000009o`0000030000ool0003o000000So000000<0003oo`000?l0
00003Ol00003ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00co
oooo00<0003oooooooooool02?ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00So
oooo00<0003oooooooooool03_ooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0>ooooo`030000oooooooooooo00So
oooo00<0003oooooooooool02?ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00go
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00So
oooo00<0003oooooooooool03_ooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0<ooooo`03o`000?oooooooooo007o
oooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03?ooool00`000?oo
ooooooooo`08ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02?ooool00`000?oo
ooooooooo`0>ooooo`030000oooooooooooo00Sooooo00<0003oooooooooool02?ooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00gooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`08ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00Sooooo00<0003oooooooooool02?ooool00`000?oo
ooooooooo`0>ooooo`030000oooooooooooo00Sooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`08ooooo`030000oooooooooooo00cooooo00?o0000ooooooooool00Oooool000Wooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0<ooooo`030000oooooooooooo00So
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00ko
oooo00<0003oooooooooool02?ooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool03Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00So
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02?ooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00ko
oooo00<0003oooooooooool02?ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00So
oooo00<0003oooooooooool03?ooool00ol0003oooooooooo`01ooooo`002_ooool2o`0000Gooooo
00?o0000ooooooooool03?ooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02?ooool00`000?ooooooooooo`0>ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool01oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00gooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool03Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Sooooo
00<0003oooooooooool02?ooool00`000?ooooooooooo`0>ooooo`030000oooooooooooo00Sooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00cooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool03?ooool00`000?oooooooooo
o`08ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02?ooool00`000?oooooooooo
o`0>ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool01oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00gooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`08ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03Oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00Sooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0=ooooo`030000oooooooooooo00Sooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`08ooooo`030000oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool03?ooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02?ooool00`000?ooooooooooo`0>ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool01oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00gooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool03Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Oooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00Sooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00cooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool03?ooool00`000?ooooooooooo`09oooo
o`030000oooooooooooo00Sooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0>oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool01oooool00`000?ooooooooooo`09oooo
o`030000oooooooooooo00gooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`08oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`09oooo
o`030000oooooooooooo00Oooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0=oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`08oooo
o`030000oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000=ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`08ooooo`03
0000oooooooooooo00kooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`07ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00Sooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0=ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00cooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`08ooooo`03
0000oooooooooooo00Sooooo00<0003oooooooooool02oooool2o`0000?ooooo000Aooooo`03o`00
0?oooooooooo00_ooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`07ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool03_ooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00Oooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0=ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00gooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`07ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Sooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0<ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00_ooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`07ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool01ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00gooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`07ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03?oo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Sooooo00<0003oooooooooool02?oo
ool00`000?ooooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00_ooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`07ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool03_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Oooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0=ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool01oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00gooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`07ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Oooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0<ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00_ooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`07ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03_ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`0=ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool01_ooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00gooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`07ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03?ooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00_o
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool03Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Ko
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00co
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Oo
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0<ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo00_ooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`07ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`0=ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool01_ooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00cooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`07ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03?ooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`0;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00_ooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool03?ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Gooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool01_ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00cooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool03?ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Oooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000A
ooooo`;o00003?ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Oooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00_ooooo00<0003o
ooooooooool01Oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00cooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`06ooooo`030000oooooooooooo00[ooooo00<0003o
ooooooooool03?ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Kooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00[ooooo00<0003o
ooooooooool01oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00[ooooo0_l00003
ooooo`004Oooool00ol0003oooooooooo`0;ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool01_ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00cooooo00<0003ooooo
ooooool02oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00_ooooo00<0003ooooo
ooooool03?ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Kooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00_ooooo00<0003ooooo
ooooool01_ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00cooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0;ooooo`03
0000oooooooooooo00_ooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0;ooooo`03
0000oooooooooooo00cooooo00<0003oooooooooool02oooool00`000?ooooooooooo`05ooooo`03
0000oooooooooooo00_ooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Kooooo00<0003oooooooooool02oooool00`000?ooooooooooo`0;ooooo`03
0000oooooooooooo00_ooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0;ooooo`03
0000oooooooooooo00cooooo00<0003oooooooooool02oooool00`000?ooooooooooo`06ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool02oooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`0;ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool0
1Oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00cooooo00<0003oooooooooool0
2oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool0
3?ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool0
2oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool0
1Oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00cooooo00<0003oooooooooool0
2oooool00`000?ooooooooooo`06ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0;ooooo`030000oooo
oooooooo00_ooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0;ooooo`030000oooo
oooooooo00cooooo00<0003oooooooooool02oooool00`000?ooooooooooo`05ooooo`030000oooo
oooooooo00_ooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Kooooo00<0003oooooooooool02oooool00`000?ooooooooooo`0;ooooo`030000oooo
oooooooo00_ooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0;ooooo`030000oooo
oooooooo00cooooo00<0003oooooooooool02oooool00`000?ooooooooooo`05ooooo`030000oooo
oooooooo00_ooooo00<0003oooooooooool02oooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`0;ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool01Oooool0
0`000?ooooooooooo`0;ooooo`030000oooooooooooo00cooooo00<0003oooooooooool02oooool0
0`000?ooooooooooo`05ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool03?ooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool02oooool0
0`000?ooooooooooo`0;ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool01Oooool0
0`000?ooooooooooo`0;ooooo`030000oooooooooooo00cooooo00<0003oooooooooool02oooool0
0`000?ooooooooooo`05ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool02oooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0;ooooo`030000oooooooooooo
00_ooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo
00cooooo00<0003oooooooooool02oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo
00_ooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Kooooo00<0003oooooooooool02oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo
00_ooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo
00cooooo00<0003oooooooooool02oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo
00_ooooo00<0003oooooooooool02oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000co
oooo00<0003oooooooooool02oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00_o
oooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Co
oooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00_o
oooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00_o
oooo00<0003oooooooooool02oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00_o
oooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Go
oooo00<0003oooooooooool02oooool00`000?ooooooooooo`0:ooooo`;o00000oooool0017ooooo
00?o0000ooooooooool02oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Gooooo
00<0003oooooooooool02oooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00_ooooo
00<0003oooooooooool01?ooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00_ooooo
00<0003oooooooooool02oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00cooooo
00<0003oooooooooool02oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Gooooo
00<0003oooooooooool03?ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00cooooo
00<0003oooooooooool01Oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00_ooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02_ooool00`000?oooooooooo
o`0=ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool02oooool00`000?oooooooooo
o`0<ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool01?ooool00`000?oooooooooo
o`0<ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool03?ooool00`000?oooooooooo
o`04ooooo`030000oooooooooooo00cooooo00<0003oooooooooool02oooool00`000?oooooooooo
o`0;ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool03?ooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00gooooo00<0003oooooooooool01?ooool00`000?oooooooooo
o`0;ooooo`030000oooooooooooo00_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool02_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00Cooooo00<0003o
ooooooooool02oooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00cooooo00<0003o
ooooooooool00oooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00_ooooo00<0003o
ooooooooool03?ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00cooooo00<0003o
ooooooooool02oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Gooooo00<0003o
ooooooooool03?ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00gooooo00<0003o
ooooooooool01?ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00_ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool02_ooool00`000?ooooooooooo`0=oooo
o`030000oooooooooooo00Cooooo00<0003oooooooooool02oooool00`000?ooooooooooo`0<oooo
o`030000oooooooooooo00cooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0<oooo
o`030000oooooooooooo00_ooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`04oooo
o`030000oooooooooooo00cooooo00<0003oooooooooool02oooool00`000?ooooooooooo`0<oooo
o`030000oooooooooooo00Cooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00gooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0;oooo
o`030000oooooooooooo00_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool02_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00?ooooo00<0003ooooooooo
ool03?ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00gooooo00<0003ooooooooo
ool00oooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00_ooooo00<0003ooooooooo
ool03?ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00cooooo00<0003ooooooooo
ool02oooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00Cooooo00<0003ooooooooo
ool03?ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00gooooo00<0003ooooooooo
ool01?ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00_ooooo00?o0000oooooooo
ool00Oooool000Sooooo1Ol00004ooooo`03o`000?oooooooooo00[ooooo00<0003oooooooooool0
3Oooool00`000?ooooooooooo`03ooooo`030000oooooooooooo00cooooo00<0003oooooooooool0
2oooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00?ooooo00<0003oooooooooool0
3?ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00cooooo00<0003oooooooooool0
1?ooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool0
3?ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00cooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00?ooooo00<0003oooooooooool0
3?ooool00`000?ooooooooooo`0;ooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool02_ooool00`000?ooooooooooo`0=ooooo`030000
oooooooooooo00?ooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0;ooooo`030000
oooooooooooo00gooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0<ooooo`030000
oooooooooooo00_ooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`04ooooo`030000
oooooooooooo00cooooo00<0003oooooooooool02oooool00`000?ooooooooooo`0<ooooo`030000
oooooooooooo00Cooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00gooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0<ooooo`030000
oooooooooooo00_ooooo00?o0000ooooooooool00Oooool000[ooooo00?o0000ooooooooool01?oo
ool3o`0000[ooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`03ooooo`030000oooo
oooooooo00cooooo00<0003oooooooooool02oooool00`000?ooooooooooo`0=ooooo`030000oooo
oooooooo00?ooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00cooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0<ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`04ooooo`030000oooo
oooooooo00cooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0=ooooo`030000oooo
oooooooo00?ooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`09ooooo`?o00000ooo
ool000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`030000oooooooo
oooo00gooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0<ooooo`030000oooooooo
oooo00_ooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`03ooooo`030000oooooooo
oooo00gooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0<ooooo`030000oooooooo
oooo00Cooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00gooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0=ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`03ooooo`030000oooooooo
oooo00gooooo00<0003oooooooooool02_ooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02_ooool00`000?ooooooooooo`0=
ooooo`030000oooooooooooo00?ooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00gooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0=
ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`04
ooooo`030000oooooooooooo00gooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0>
ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00gooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0=
ooooo`030000oooooooooooo00[ooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00[ooooo00<0003oooooooooool03_ooool0
0`000?ooooooooooo`02ooooo`030000oooooooooooo00gooooo00<0003oooooooooool02_ooool0
0`000?ooooooooooo`0=ooooo`030000oooooooooooo00?ooooo00<0003oooooooooool03Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00gooooo00<0003oooooooooool00_ooool0
0`000?ooooooooooo`0>ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03_ooool0
0`000?ooooooooooo`02ooooo`030000oooooooooooo00gooooo00<0003oooooooooool02_ooool0
0`000?ooooooooooo`0=ooooo`030000oooooooooooo00?ooooo00<0003oooooooooool03Oooool0
0`000?ooooooooooo`0:ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0
003oooooooooo`0:ooooo`030000oooooooooooo00kooooo00<0003oooooooooool00_ooool00`00
0?ooooooooooo`0=ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03Oooool00`00
0?ooooooooooo`03ooooo`030000oooooooooooo00gooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`0=ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool03_ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00kooooo00<0003oooooooooool00_ooool00`00
0?ooooooooooo`0=ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03Oooool00`00
0?ooooooooooo`03ooooo`030000oooooooooooo00gooooo00<0003oooooooooool02_ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`030000oooooooooooo00ko
oooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool03_ooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00go
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00;o
oooo00<0003oooooooooool03_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00ko
oooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool03Oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00ko
oooo00<0003oooooooooool02_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`0:ooooo`030000oooooooooooo00kooooo00D0003ooooooooooooooooo0000o`0@ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool03_ooool01@000?ooooooooooooooool0003o
013ooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo
00;ooooo00<0003oooooooooool03_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00kooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool03_ooool01@000?ooooooooooooooool0003o013ooooo00<0003o
ooooooooool02_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0:oooo
o`030000oooooooooooo00kooooo00D0003ooooooooooooooooo0000o`0@ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool03_ooool01@000?ooooooooooooooool0003o013ooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00;ooooo00<0
003oooooooooool03_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00kooooo00<0
003oooooooooool00_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool03_ooool01@000?ooooooooooooooool0003o013ooooo00<0003oooooooooool0
2_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000_ooooo00<0003oooooooooool03_oo
ool01@000?ooooooooooooooool0003o013ooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`0>ooooo`050000ooooooooooooooooo`000?l04?ooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00kooooo00D0003ooooooooooooooooo0000o`0@ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool03_ooool00`000?ooooooooooo`02ooooo`030000oooooooooooo
00kooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0>ooooo`050000oooooooooooo
ooooo`000?l04?ooool00`000?ooooooooooo`09ooooo`;o00000oooool0017ooooo00?o0000oooo
ooooool02_ooool00`000?ooooooooooo`0>ooooo`050000ooooooooooooooooo`000?l04?ooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00kooooo00D0003ooooooooooooooooo0000
o`0@ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03_ooool01@000?oooooooooo
ooooool0003o013ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0>ooooo`050000
ooooooooooooooooo`000?l04Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00ko
oooo00D0003ooooooooooooooooo0000o`0@ooooo`030000oooooooooooo00[ooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool02_ooool00`000?ooooooooooo`0>ooooo`05
0000ooooooooooooooooo`000?l04?ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00kooooo00D0003ooooooooooooooooo0000o`0@ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool03oooool01@000?ooooooooooooooool0003o013ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0>ooooo`050000ooooooooooooooooo`000?l04Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00kooooo00D0003ooooooooooooooooo0000o`0@ooooo`03
0000oooooooooooo00[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
2_ooool00`000?ooooooooooo`0>ooooo`050000ooooooooooooooooo`000?l04?ooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00kooooo00@0003oooooooooool0003o4Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00oooooo00D0003ooooooooooooooooo0000o`0@
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03oooool01?l00?ooooooooooo`00
0?lAooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03_ooool01@000?oooooooooo
ooooool0003o013ooooo00<0003oooooooooool02_ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0:ooooo`030000oooooooooooo00kooooo00D0003ooooooooooooooooo
0000o`0@ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03oooool010000?oooooo
ooooo`000?lAooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03oooool01?l00?oo
ooooooooo`000?lAooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03oooool01000
0?ooooooooooo`000?lAooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03_ooool0
1@000?ooooooooooooooool0003o013ooooo00<0003oooooooooool02_ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`030000oooooooooooo00oooooo00?o003o
ooooool00?l04Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo013ooooo00?o003o
ooooool00?l04Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00oooooo00Co003o
ooooooooool0003o4Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00oooooo00@0
003oooooooooool0003o4Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00oooooo
00?o003oooooo`000?l04Oooool00`000?ooooooooooo`0:ooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo00[ooooo00<0003oooooooooool03oooool00ol00?ooooooo`00
o`0Aooooo`030000oooooooooooo00Wooooo00<0003oooooooooool04?ooool00ol00?ooooooo`00
o`0Aooooo`030000oooooooooooo00Wooooo00<0003oooooooooool04?ooool00ol00?ooooooo`00
o`0Aooooo`030000oooooooooooo00Wooooo00<0003oooooooooool03oooool00ol00?oooooo0000
o`0Booooo`030000oooooooooooo00Wooooo00<0003oooooooooool03oooool00ol00?ooooooo`00
o`0Aooooo`030000oooooooooooo00[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool02_ooool00`000?ooooooooooo`0?ooooo`?o003o4Oooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo013ooooo0ol00?lAooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool04?ooool2o`00oa;ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0@
ooooo`;o003o4_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00oooooo0ol00?lB
ooooo`030000oooooooooooo00Wooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000:oooo
o`030000oooooooooooo017ooooo00?o003oooooooooool04Oooool00`000?ooooooooooo`08oooo
o`030000oooooooooooo017ooooo00?o003oooooooooool04?ooool00`000?ooooooooooo`09oooo
o`030000oooooooooooo013ooooo0_l00?lBooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool04?ooool2o`00oa;ooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0Aoooo
o`03o`00oooooooooooo017ooooo00<0003oooooooooool02?ooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo00Wooooo00<0003oooooooooool09Oooool00`000?ooooooooooo`08ooooo`03
0000oooooooooooo02Gooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0Tooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool09?ooool00`000?ooooooooooo`08ooooo`03
0000oooooooooooo02Gooooo00<0003oooooooooool02Oooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`09ooooo`030000oooooooooooo02Gooooo00<0003oooooooooool0
2?ooool00`000?ooooooooooo`0Uooooo`030000oooooooooooo00Sooooo00<0003oooooooooool0
9Oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo02Cooooo00<0003oooooooooool0
2?ooool00`000?ooooooooooo`0Uooooo`030000oooooooooooo00Wooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool02Oooool00`000?ooooooooooo`0Uooooo`030000oooo
oooooooo00Sooooo00<0003oooooooooool09Oooool00`000?ooooooooooo`08ooooo`030000oooo
oooooooo02Gooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0Tooooo`030000oooo
oooooooo00Sooooo00<0003oooooooooool09Oooool00`000?ooooooooooo`09ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Wooooo00<0003oooooooooool09Oooool0
0`000?ooooooooooo`08ooooo`030000oooooooooooo02Gooooo00<0003oooooooooool02?ooool0
0`000?ooooooooooo`0Uooooo`030000oooooooooooo00Sooooo00<0003oooooooooool09?ooool0
0`000?ooooooooooo`08ooooo`030000oooooooooooo02Gooooo00<0003oooooooooool02Oooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`09ooooo`030000oooooooooooo
02Gooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0Uooooo`030000oooooooooooo
00Sooooo00<0003oooooooooool09Oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo
02Cooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0Uooooo`030000oooooooooooo
00Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02Oooool00`000?oo
ooooooooo`0Uooooo`030000oooooooooooo00Sooooo00<0003oooooooooool09Oooool00`000?oo
ooooooooo`08ooooo`030000oooooooooooo02Gooooo00<0003oooooooooool02?ooool00`000?oo
ooooooooo`0Tooooo`030000oooooooooooo00Sooooo00<0003oooooooooool09Oooool00`000?oo
ooooooooo`09ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00002_ooool00`000?oooooo
ooooo`0Uooooo`030000oooooooooooo00Sooooo00<0003oooooooooool09Oooool00`000?oooooo
ooooo`08ooooo`030000oooooooooooo02Gooooo00<0003oooooooooool01oooool00`000?oooooo
ooooo`0Uooooo`030000oooooooooooo00Sooooo00<0003oooooooooool09Oooool00`000?oooooo
ooooo`08ooooo`;o00000oooool0017ooooo00?o0000ooooooooool02Oooool00`000?oooooooooo
o`0Uooooo`030000oooooooooooo00Sooooo00<0003oooooooooool09Oooool00`000?oooooooooo
o`08ooooo`030000oooooooooooo02Gooooo00<0003oooooooooool01oooool00`000?oooooooooo
o`0Vooooo`030000oooooooooooo00Oooooo00<0003oooooooooool09Oooool00`000?oooooooooo
o`09ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Wooooo00<0003o
ooooooooool09Oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo02Gooooo00<0003o
ooooooooool01oooool00`000?ooooooooooo`0Vooooo`030000oooooooooooo00Oooooo00<0003o
ooooooooool09_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo02Gooooo00<0003o
ooooooooool02Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`09oooo
o`030000oooooooooooo02Gooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0Uoooo
o`030000oooooooooooo00Oooooo00<0003oooooooooool09_ooool00`000?ooooooooooo`07oooo
o`030000oooooooooooo02Kooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0Uoooo
o`030000oooooooooooo00Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool02Oooool00`000?ooooooooooo`0Uooooo`030000oooooooooooo00Sooooo00<0003ooooooooo
ool09Oooool00`000?ooooooooooo`07ooooo`030000oooooooooooo02Kooooo00<0003ooooooooo
ool01oooool00`000?ooooooooooo`0Vooooo`030000oooooooooooo00Oooooo00<0003ooooooooo
ool09Oooool00`000?ooooooooooo`09ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo00Wooooo00<0003oooooooooool09Oooool00`000?ooooooooooo`08ooooo`030000
oooooooooooo02Gooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0Vooooo`030000
oooooooooooo00Oooooo00<0003oooooooooool09_ooool00`000?ooooooooooo`07ooooo`030000
oooooooooooo02Gooooo00<0003oooooooooool02Oooool00ol0003oooooooooo`01ooooo`002_oo
ool3o`0000Cooooo00?o0000ooooooooool02Oooool00`000?ooooooooooo`0Uooooo`030000oooo
oooooooo00Sooooo00<0003oooooooooool09Oooool00`000?ooooooooooo`07ooooo`030000oooo
oooooooo02Kooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0Vooooo`030000oooo
oooooooo00Oooooo00<0003oooooooooool09Oooool00`000?ooooooooooo`09ooooo`03o`000?oo
oooooooo007ooooo000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool0
0`000?ooooooooooo`0Uooooo`030000oooooooooooo00Oooooo00<0003oooooooooool09_ooool0
0`000?ooooooooooo`07ooooo`030000oooooooooooo02Kooooo00<0003oooooooooool01oooool0
0`000?ooooooooooo`0Vooooo`030000oooooooooooo00Oooooo00<0003oooooooooool09_ooool0
0`000?ooooooooooo`08ooooo`03o`000?oooooooooo007ooooo0008ooooo`Go00001?ooool3o`00
00Wooooo00<0003oooooooooool09_ooool00`000?ooooooooooo`06ooooo`030000oooooooooooo
02Kooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0Vooooo`030000oooooooooooo
00Oooooo00<0003oooooooooool09_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo
02Kooooo00<0003oooooooooool01_ooool3o`0000?ooooo0008ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool02Oooool00`000?ooooooooooo`0Vooooo`030000oooooooooooo
00Kooooo00<0003oooooooooool09_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo
02Kooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0Vooooo`030000oooooooooooo
00Oooooo00<0003oooooooooool09_ooool00`000?ooooooooooo`08ooooo`03o`000?oooooooooo
007ooooo0009ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool02Oooool00`000?oo
ooooooooo`0Vooooo`030000oooooooooooo00Kooooo00<0003oooooooooool09_ooool00`000?oo
ooooooooo`07ooooo`030000oooooooooooo02Kooooo00<0003oooooooooool01oooool00`000?oo
ooooooooo`0Vooooo`030000oooooooooooo00Oooooo00<0003oooooooooool09_ooool00`000?oo
ooooooooo`08ooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003ooooo
ooooo`09ooooo`030000oooooooooooo02Kooooo00<0003oooooooooool01_ooool00`000?oooooo
ooooo`0Vooooo`030000oooooooooooo00Oooooo00<0003oooooooooool09_ooool00`000?oooooo
ooooo`07ooooo`030000oooooooooooo02Kooooo00<0003oooooooooool01oooool00`000?oooooo
ooooo`0Vooooo`030000oooooooooooo00Sooooo00?o0000ooooooooool00Oooool000_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`030000oooooooooooo02Kooooo00<0
003oooooooooool01_ooool00`000?ooooooooooo`0Vooooo`030000oooooooooooo00Oooooo00<0
003oooooooooool09_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo02Kooooo00<0
003oooooooooool01oooool00`000?ooooooooooo`0Vooooo`030000oooooooooooo00Sooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02Oooool00`000?ooooooooooo`0V
ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool09_ooool00`000?ooooooooooo`07
ooooo`030000oooooooooooo02Oooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0V
ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool09_ooool00`000?ooooooooooo`08
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Sooooo00<0003ooooo
ooooool09oooool00`000?ooooooooooo`06ooooo`030000oooooooooooo02Kooooo00<0003ooooo
ooooool01oooool00`000?ooooooooooo`0Wooooo`030000oooooooooooo00Kooooo00<0003ooooo
ooooool09_ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo02Kooooo00<0003ooooo
ooooool02?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`08ooooo`03
0000oooooooooooo02Oooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0Wooooo`03
0000oooooooooooo00Kooooo00<0003oooooooooool09oooool00`000?ooooooooooo`06ooooo`03
0000oooooooooooo02Kooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0Wooooo`03
0000oooooooooooo00Sooooo00?o0000ooooooooool00Oooool0017ooooo0_l00009ooooo`030000
oooooooooooo02Oooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0Wooooo`030000
oooooooooooo00Kooooo00<0003oooooooooool09oooool00`000?ooooooooooo`06ooooo`030000
oooooooooooo02Kooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0Wooooo`030000
oooooooooooo00Oooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`08ooooo`030000oooo
oooooooo02Oooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0Wooooo`030000oooo
oooooooo00Gooooo00<0003oooooooooool0:?ooool00`000?ooooooooooo`05ooooo`030000oooo
oooooooo02Oooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0Wooooo`030000oooo
oooooooo00Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02?ooool0
0`000?ooooooooooo`0Wooooo`030000oooooooooooo00Kooooo00<0003oooooooooool09oooool0
0`000?ooooooooooo`05ooooo`030000oooooooooooo02Sooooo00<0003oooooooooool01Oooool0
0`000?ooooooooooo`0Wooooo`030000oooooooooooo00Kooooo00<0003oooooooooool09oooool0
0`000?ooooooooooo`08ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
00Sooooo00<0003oooooooooool09oooool00`000?ooooooooooo`06ooooo`030000oooooooooooo
02Oooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0Xooooo`030000oooooooooooo
00Gooooo00<0003oooooooooool0:?ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo
02Oooooo00<0003oooooooooool02?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`08ooooo`030000oooooooooooo02Oooooo00<0003oooooooooool01_ooool00`000?oo
ooooooooo`0Wooooo`030000oooooooooooo00Gooooo00<0003oooooooooool0:?ooool00`000?oo
ooooooooo`05ooooo`030000oooooooooooo02Sooooo00<0003oooooooooool01Oooool00`000?oo
ooooooooo`0Wooooo`030000oooooooooooo00Sooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool02?ooool00`000?ooooooooooo`0Wooooo`030000oooooooooooo00Kooooo
00<0003oooooooooool09oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo02Sooooo
00<0003oooooooooool01Oooool00`000?ooooooooooo`0Xooooo`030000oooooooooooo00Gooooo
00<0003oooooooooool09oooool00`000?ooooooooooo`08ooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo00Sooooo00<0003oooooooooool09oooool00`000?oooooooooo
o`06ooooo`030000oooooooooooo02Oooooo00<0003oooooooooool01Oooool00`000?oooooooooo
o`0Xooooo`030000oooooooooooo00Gooooo00<0003oooooooooool0:?ooool00`000?oooooooooo
o`05ooooo`030000oooooooooooo02Oooooo00<0003oooooooooool02?ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`08ooooo`030000oooooooooooo02Oooooo00<0003o
ooooooooool01_ooool00`000?ooooooooooo`0Wooooo`030000oooooooooooo00Gooooo00<0003o
ooooooooool0:?ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo02Sooooo00<0003o
ooooooooool01Oooool00`000?ooooooooooo`0Wooooo`030000oooooooooooo00Sooooo00?o0000
ooooooooool00Oooool0017ooooo0_l00009ooooo`030000oooooooooooo02Oooooo00<0003ooooo
ooooool01_ooool00`000?ooooooooooo`0Wooooo`030000oooooooooooo00Gooooo00<0003ooooo
ooooool0:?ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo02Sooooo00<0003ooooo
ooooool01Oooool00`000?ooooooooooo`0Xooooo`030000oooooooooooo00Kooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`08ooooo`030000oooooooooooo02Sooooo00<0003ooooooooo
ool01Oooool00`000?ooooooooooo`0Wooooo`030000oooooooooooo00Gooooo00<0003ooooooooo
ool0:?ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo02Sooooo00<0003ooooooooo
ool01Oooool00`000?ooooooooooo`0Xooooo`030000oooooooooooo00Oooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool02?ooool00`000?ooooooooooo`0Xooooo`030000
oooooooooooo00Gooooo00<0003oooooooooool09oooool00`000?ooooooooooo`05ooooo`030000
oooooooooooo02Sooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0Xooooo`030000
oooooooooooo00Gooooo00<0003oooooooooool0:?ooool00`000?ooooooooooo`07ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Sooooo00<0003oooooooooool0:?oo
ool00`000?ooooooooooo`05ooooo`030000oooooooooooo02Oooooo00<0003oooooooooool01Ooo
ool00`000?ooooooooooo`0Xooooo`030000oooooooooooo00Cooooo00<0003oooooooooool0:Ooo
ool00`000?ooooooooooo`05ooooo`030000oooooooooooo02Sooooo00<0003oooooooooool01ooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`08ooooo`030000oooooooo
oooo02Sooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0Xooooo`030000oooooooo
oooo00Gooooo00<0003oooooooooool0:Oooool00`000?ooooooooooo`03ooooo`030000oooooooo
oooo02Wooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0Xooooo`030000oooooooo
oooo00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01oooool00`00
0?ooooooooooo`0Yooooo`030000oooooooooooo00Cooooo00<0003oooooooooool0:?ooool00`00
0?ooooooooooo`05ooooo`030000oooooooooooo02Wooooo00<0003oooooooooool00oooool00`00
0?ooooooooooo`0Yooooo`030000oooooooooooo00Gooooo00<0003oooooooooool0:?ooool00`00
0?ooooooooooo`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Oo
oooo00<0003oooooooooool0:Oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo02Wo
oooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0Yooooo`030000oooooooooooo00?o
oooo00<0003oooooooooool0:Oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo02Wo
oooo00<0003oooooooooool01oooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Sooooo
00<0003oooooooooool0:Oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo02Wooooo
00<0003oooooooooool01?ooool00`000?ooooooooooo`0Yooooo`030000oooooooooooo00?ooooo
00<0003oooooooooool0:Oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo02Wooooo
00<0003oooooooooool01_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Oooooo00<0
003oooooooooool0:Oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo02Wooooo00<0
003oooooooooool00oooool00`000?ooooooooooo`0Zooooo`030000oooooooooooo00?ooooo00<0
003oooooooooool0:Oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo02Wooooo00<0
003oooooooooool01oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`07
ooooo`030000oooooooooooo02Wooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0Y
ooooo`030000oooooooooooo00?ooooo00<0003oooooooooool0:_ooool00`000?ooooooooooo`03
ooooo`030000oooooooooooo02Wooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0Y
ooooo`030000oooooooooooo00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool01oooool00`000?ooooooooooo`0Yooooo`030000oooooooooooo00Cooooo00<0003ooooo
ooooool0:Oooool00`000?ooooooooooo`03ooooo`030000oooooooooooo02[ooooo00<0003ooooo
ooooool00oooool00`000?ooooooooooo`0Zooooo`030000oooooooooooo00?ooooo00<0003ooooo
ooooool0:Oooool00`000?ooooooooooo`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Oooooo00<0003oooooooooool0:Oooool00`000?ooooooooooo`04ooooo`03
0000oooooooooooo02Wooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0Zooooo`03
0000oooooooooooo00?ooooo00<0003oooooooooool0:_ooool00`000?ooooooooooo`03ooooo`03
0000oooooooooooo02Wooooo00<0003oooooooooool01oooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`07ooooo`030000oooooooooooo02Wooooo00<0003oooooooooool0
1?ooool00`000?ooooooooooo`0Yooooo`030000oooooooooooo00?ooooo00<0003oooooooooool0
:_ooool00`000?ooooooooooo`03ooooo`030000oooooooooooo02[ooooo00<0003oooooooooool0
0oooool00`000?ooooooooooo`0Yooooo`030000oooooooooooo00Oooooo00?o0000ooooooooool0
0Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo00Oooooo00<0003oooooooooool0:Ooo
ool00`000?ooooooooooo`04ooooo`030000oooooooooooo02Wooooo00<0003oooooooooool00ooo
ool00`000?ooooooooooo`0Zooooo`030000oooooooooooo00?ooooo00<0003oooooooooool0:_oo
ool00`000?ooooooooooo`02ooooo`030000oooooooooooo02_ooooo00<0003oooooooooool01_oo
ool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool01_ooool00`000?ooooooooooo`0[ooooo`030000oooooooooooo00?ooooo00<0
003oooooooooool0:_ooool00`000?ooooooooooo`02ooooo`030000oooooooooooo02[ooooo00<0
003oooooooooool00oooool00`000?ooooooooooo`0Zooooo`030000oooooooooooo00;ooooo00<0
003oooooooooool0:oooool00`000?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo0008
ooooo`05o`000?ooooooooooooooool000001?ooool3o`0000Kooooo00<0003oooooooooool0:ooo
ool00`000?ooooooooooo`03ooooo`030000oooooooooooo02[ooooo00<0003oooooooooool00_oo
ool00`000?ooooooooooo`0Zooooo`030000oooooooooooo00?ooooo00<0003oooooooooool0:_oo
ool00`000?ooooooooooo`02ooooo`030000oooooooooooo02_ooooo00<0003oooooooooool01?oo
ool3o`0000?ooooo0008ooooo`Co00001Oooool00ol0003oooooooooo`06ooooo`030000oooooooo
oooo02_ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0[ooooo`030000oooooooo
oooo00;ooooo00<0003oooooooooool0:_ooool00`000?ooooooooooo`03ooooo`030000oooooooo
oooo02[ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0[ooooo`030000oooooooo
oooo00Kooooo00?o0000ooooooooool00Oooool000Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`030000oooooooooooo02_ooooo00<0003oooooooooool00_ooool00`00
0?ooooooooooo`0[ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool0:_ooool00`00
0?ooooooooooo`03ooooo`030000oooooooooooo02[ooooo00<0003oooooooooool00_ooool00`00
0?ooooooooooo`0[ooooo`030000oooooooooooo00Kooooo00?o0000ooooooooool00Oooool000Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`030000oooooooooooo02_o
oooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0[ooooo`030000oooooooooooo00;o
oooo00<0003oooooooooool0:oooool01@000?ooooooooooooooool0003o02gooooo00<0003ooooo
ooooool00_ooool00`000?ooooooooooo`0[ooooo`030000oooooooooooo00Kooooo00?o0000oooo
ooooool00Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo00Kooooo00<0003ooooooooo
ool0:oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo02_ooooo00<0003ooooooooo
ool00_ooool00`000?ooooooooooo`0[ooooo`050000ooooooooooooooooo`000?l0;Oooool00`00
0?ooooooooooo`02ooooo`030000oooooooooooo02_ooooo00<0003oooooooooool01_ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06ooooo`030000oooooooooooo02_o
oooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0[ooooo`050000oooooooooooooooo
o`000?l0;_ooool01@000?ooooooooooooooool0003o02gooooo00<0003oooooooooool00_ooool0
0`000?ooooooooooo`0[ooooo`030000oooooooooooo00Kooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool01_ooool00`000?ooooooooooo`0/ooooo`040000oooooooooooo
0000obkooooo00D0003ooooooooooooooooo0000o`0^ooooo`050000ooooooooooooooooo`000?l0
;Oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo02_ooooo00<0003oooooooooool0
1_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06ooooo`030000oooo
oooooooo02cooooo00@0003oooooooooool0003o;_ooool01@000?ooooooooooooooool0003o02ko
oooo00D0003ooooooooooooooooo0000o`0^ooooo`050000ooooooooooooooooo`000?l0;Oooool0
0`000?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001oooool00`00
0?ooooooooooo`0/ooooo`040000oooooooooooo0000obkooooo00D0003ooooooooooooooooo0000
o`0^ooooo`050000ooooooooooooooooo`000?l0;_ooool01@000?ooooooooooooooool0003o02go
oooo00<0003oooooooooool01Oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Kooooo
00<0003oooooooooool0;?ooool010000?ooooooooooo`000?l^ooooo`050000oooooooooooooooo
o`000?l0;_ooool01@000?ooooooooooooooool0003o02kooooo00D0003ooooooooooooooooo0000
o`0]ooooo`030000oooooooooooo00Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool01_ooool00`000?ooooooooooo`0/ooooo`040000oooooooooooo0000oboooooo00@0
003oooooooooool0003o;_ooool01@000?ooooooooooooooool0003o02kooooo00@0003ooooooooo
ool0003o;oooool00`000?ooooooooooo`05ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Gooooo00<0003oooooooooool0;Oooool010000?ooooooooooo`000?l_oooo
o`040000oooooooooooo0000obkooooo00D0003ooooooooooooooooo0000o`0^ooooo`040000oooo
oooooooo0000oboooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`05ooooo`030000oooooooooooo02gooooo00@0003ooooooooooooo003o
;oooool010000?ooooooooooo`000?l_ooooo`030000oooooooo003o02oooooo00@0003ooooooooo
ool0003o;oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Gooooo00<0003oooooooooool0;Oooool010000?ooooooooooo`000?l_oooo
o`030000oooooooo003o033ooooo00<0003oooooo`000?l0<?ooool00ol00?oooooo0000o`0_oooo
o`03o`00oooooooooooo00Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool01Oooool00`000?ooooooooooo`0^ooooo`03o`00o`000?oooooo02oooooo00?o003oooooool0
0?l0<?ooool00ol00?oooooo0000o`0`ooooo`;o003o<Oooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
;oooool2o`00oc7ooooo0_l00?l`ooooo`?o003o<?ooool2o`00oc7ooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Gooooo00?o003oooooooooool0;ooo
ool2o`00oc7ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0_ooooo`030000ool0
0?oooooo033ooooo00?o003oooooooooool00oooool2o`0000?ooooo000Aooooo`03o`000?oooooo
oooo0?oooooo2Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01oooo
o`004Oooooooo`0000go00000oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.478464, -4.17447, \
0.0197116, 0.0645854}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CTFT of infinite-length x(t)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X[f_] = 
        FourierTransform[x[t], t, 
            f]\  /. {\[Delta][b_\ a_ + f_\ a_] \[Rule] \[Delta][b + f]/
                a, \[Delta][\ a_ + f_\ a_] \[Rule] \[Delta][1 + f]/
                a};\)\), "\[IndentingNewLine]", 
    \(X[f]\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", 
          RowBox[{
            InterpretationBox["\[Delta]",
              DiracDelta,
              Editable->False,
              Selectable->False], "(", \(f - 2\), ")"}]}], "+", 
        RowBox[{
          InterpretationBox["\[Delta]",
            DiracDelta,
            Editable->False,
            Selectable->False], "(", \(f - 1\), ")"}], "+", 
        RowBox[{
          InterpretationBox["\[Delta]",
            DiracDelta,
            Editable->False,
            Selectable->False], "(", "f", ")"}], "+", 
        RowBox[{
          InterpretationBox["\[Delta]",
            DiracDelta,
            Editable->False,
            Selectable->False], "(", \(f + 1\), ")"}], "+", 
        RowBox[{"2", " ", 
          RowBox[{
            InterpretationBox["\[Delta]",
              DiracDelta,
              Editable->False,
              Selectable->False], "(", \(f + 2\), ")"}]}]}], 
      TraditionalForm]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gX = 
        Plot[Evaluate[PlotConvert[X[f],  .04]], {f, \(-2.5\) fs, 2.5  fs}, 
          PlotStyle \[Rule] {Blue, Thickness[ .005]}, \ 
          PlotPoints \[Rule] 1000, \ 
          PlotRange \[Rule] {\(- .02\), 3.12}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0544218 0.00393652 0.196826 [
[.09184 -0.0125 -12 -9 ]
[.09184 -0.0125 12 0 ]
[.22789 -0.0125 -6 -9 ]
[.22789 -0.0125 6 0 ]
[.36395 -0.0125 -12 -9 ]
[.36395 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.63605 -0.0125 -9 -9 ]
[.63605 -0.0125 9 0 ]
[.77211 -0.0125 -3 -9 ]
[.77211 -0.0125 3 0 ]
[.90816 -0.0125 -9 -9 ]
[.90816 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09184 0 m
.09184 .00625 L
s
[(-7.5)] .09184 -0.0125 0 1 Mshowa
.22789 0 m
.22789 .00625 L
s
[(-5)] .22789 -0.0125 0 1 Mshowa
.36395 0 m
.36395 .00625 L
s
[(-2.5)] .36395 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.63605 0 m
.63605 .00625 L
s
[(2.5)] .63605 -0.0125 0 1 Mshowa
.77211 0 m
.77211 .00625 L
s
[(5)] .77211 -0.0125 0 1 Mshowa
.90816 0 m
.90816 .00625 L
s
[(7.5)] .90816 -0.0125 0 1 Mshowa
.125 Mabswid
.11905 0 m
.11905 .00375 L
s
.14626 0 m
.14626 .00375 L
s
.17347 0 m
.17347 .00375 L
s
.20068 0 m
.20068 .00375 L
s
.2551 0 m
.2551 .00375 L
s
.28231 0 m
.28231 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.33673 0 m
.33673 .00375 L
s
.39116 0 m
.39116 .00375 L
s
.41837 0 m
.41837 .00375 L
s
.44558 0 m
.44558 .00375 L
s
.47279 0 m
.47279 .00375 L
s
.52721 0 m
.52721 .00375 L
s
.55442 0 m
.55442 .00375 L
s
.58163 0 m
.58163 .00375 L
s
.60884 0 m
.60884 .00375 L
s
.66327 0 m
.66327 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.71769 0 m
.71769 .00375 L
s
.7449 0 m
.7449 .00375 L
s
.79932 0 m
.79932 .00375 L
s
.82653 0 m
.82653 .00375 L
s
.85374 0 m
.85374 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.06463 0 m
.06463 .00375 L
s
.03741 0 m
.03741 .00375 L
s
.0102 0 m
.0102 .00375 L
s
.93537 0 m
.93537 .00375 L
s
.96259 0 m
.96259 .00375 L
s
.9898 0 m
.9898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09184 .61178 m
.09184 .61803 L
s
.22789 .61178 m
.22789 .61803 L
s
.36395 .61178 m
.36395 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.63605 .61178 m
.63605 .61803 L
s
.77211 .61178 m
.77211 .61803 L
s
.90816 .61178 m
.90816 .61803 L
s
.125 Mabswid
.11905 .61428 m
.11905 .61803 L
s
.14626 .61428 m
.14626 .61803 L
s
.17347 .61428 m
.17347 .61803 L
s
.20068 .61428 m
.20068 .61803 L
s
.2551 .61428 m
.2551 .61803 L
s
.28231 .61428 m
.28231 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.33673 .61428 m
.33673 .61803 L
s
.39116 .61428 m
.39116 .61803 L
s
.41837 .61428 m
.41837 .61803 L
s
.44558 .61428 m
.44558 .61803 L
s
.47279 .61428 m
.47279 .61803 L
s
.52721 .61428 m
.52721 .61803 L
s
.55442 .61428 m
.55442 .61803 L
s
.58163 .61428 m
.58163 .61803 L
s
.60884 .61428 m
.60884 .61803 L
s
.66327 .61428 m
.66327 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.71769 .61428 m
.71769 .61803 L
s
.7449 .61428 m
.7449 .61803 L
s
.79932 .61428 m
.79932 .61803 L
s
.82653 .61428 m
.82653 .61803 L
s
.85374 .61428 m
.85374 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.06463 .61428 m
.06463 .61803 L
s
.03741 .61428 m
.03741 .61803 L
s
.0102 .61428 m
.0102 .61803 L
s
.93537 .61428 m
.93537 .61803 L
s
.96259 .61428 m
.96259 .61803 L
s
.9898 .61428 m
.9898 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.02381 .00394 m
.02474 .00394 L
.02575 .00394 L
.0267 .00394 L
.02761 .00394 L
.02859 .00394 L
.02952 .00394 L
.03052 .00394 L
.03148 .00394 L
.0324 .00394 L
.03338 .00394 L
.03433 .00394 L
.03524 .00394 L
.03621 .00394 L
.03714 .00394 L
.03813 .00394 L
.03908 .00394 L
.04 .00394 L
.04098 .00394 L
.04192 .00394 L
.04292 .00394 L
.04388 .00394 L
.0448 .00394 L
.04579 .00394 L
.04674 .00394 L
.04765 .00394 L
.04862 .00394 L
.04956 .00394 L
.05055 .00394 L
.05151 .00394 L
.05243 .00394 L
.05341 .00394 L
.05435 .00394 L
.05526 .00394 L
.05622 .00394 L
.05715 .00394 L
.05814 .00394 L
.05909 .00394 L
.06001 .00394 L
.06098 .00394 L
.06192 .00394 L
.06292 .00394 L
.06388 .00394 L
.0648 .00394 L
.06579 .00394 L
.06673 .00394 L
.06764 .00394 L
.06861 .00394 L
.06954 .00394 L
.07054 .00394 L
Mistroke
.07149 .00394 L
.07241 .00394 L
.07339 .00394 L
.07433 .00394 L
.07533 .00394 L
.07629 .00394 L
.07722 .00394 L
.07821 .00394 L
.07916 .00394 L
.08007 .00394 L
.08104 .00394 L
.08198 .00394 L
.08297 .00394 L
.08393 .00394 L
.08485 .00394 L
.08584 .00394 L
.08678 .00394 L
.08769 .00394 L
.08866 .00394 L
.08959 .00394 L
.09058 .00394 L
.09153 .00394 L
.09245 .00394 L
.09342 .00394 L
.09436 .00394 L
.09536 .00394 L
.09632 .00394 L
.09725 .00394 L
.09823 .00394 L
.09918 .00394 L
.10009 .00394 L
.10106 .00394 L
.10199 .00394 L
.10299 .00394 L
.10394 .00394 L
.10486 .00394 L
.10584 .00394 L
.10678 .00394 L
.10769 .00394 L
.10866 .00394 L
.10958 .00394 L
.11057 .00394 L
.11152 .00394 L
.11244 .00394 L
.11341 .00394 L
.11435 .00394 L
.11535 .00394 L
.1163 .00394 L
.11723 .00394 L
.11821 .00394 L
Mistroke
.11916 .00394 L
.12007 .00394 L
.12103 .00394 L
.12197 .00394 L
.12296 .00394 L
.12391 .00394 L
.12483 .00394 L
.12581 .00394 L
.12675 .00394 L
.12775 .00394 L
.12871 .00394 L
.12964 .00394 L
.13062 .00394 L
.13157 .00394 L
.13248 .00394 L
.13345 .00394 L
.13439 .00394 L
.13538 .00394 L
.13634 .00394 L
.13726 .00394 L
.13824 .00394 L
.13919 .00394 L
.14009 .00394 L
.14106 .00394 L
.14199 .00394 L
.14298 .00394 L
.14393 .00394 L
.14485 .00394 L
.14582 .00394 L
.14676 .00394 L
.14776 .00394 L
.14872 .00394 L
.14964 .00394 L
.15063 .00394 L
.15158 .00394 L
.15249 .00394 L
.15346 .00394 L
.15439 .00394 L
.15538 .00394 L
.15634 .00394 L
.15726 .00394 L
.15823 .00394 L
.15918 .00394 L
.16018 .00394 L
.16114 .00394 L
.16207 .00394 L
.16306 .00394 L
.16401 .00394 L
.16492 .00394 L
.16589 .00394 L
Mistroke
.16683 .00394 L
.16782 .00394 L
.16878 .00394 L
.16971 .00394 L
.17069 .00394 L
.17163 .00394 L
.17254 .00394 L
.17351 .00394 L
.17444 .00394 L
.17543 .00394 L
.17638 .00394 L
.1773 .00394 L
.17828 .00394 L
.17922 .00394 L
.18022 .00394 L
.18118 .00394 L
.1821 .00394 L
.18309 .00394 L
.18404 .00394 L
.18495 .00394 L
.18592 .00394 L
.18685 .00394 L
.18785 .00394 L
.1888 .00394 L
.18972 .00394 L
.1907 .00394 L
.19165 .00394 L
.19255 .00394 L
.19352 .00394 L
.19445 .00394 L
.19544 .00394 L
.19639 .00394 L
.1973 .00394 L
.19828 .00394 L
.19922 .00394 L
.20021 .00394 L
.20117 .00394 L
.2021 .00394 L
.20308 .00394 L
.20403 .00394 L
.20494 .00394 L
.2059 .00394 L
.20684 .00394 L
.20783 .00394 L
.20878 .00394 L
.2097 .00394 L
.21068 .00394 L
.21162 .00394 L
.21262 .00394 L
.21358 .00394 L
Mistroke
.21451 .00394 L
.2155 .00394 L
.21645 .00394 L
.21736 .00394 L
.21833 .00394 L
.21927 .00394 L
.22026 .00394 L
.22122 .00394 L
.22214 .00394 L
.22312 .00394 L
.22407 .00394 L
.22497 .00394 L
.22594 .00394 L
.22687 .00394 L
.22786 .00394 L
.22881 .00394 L
.22973 .00394 L
.23071 .00394 L
.23164 .00394 L
.23264 .00394 L
.2336 .00394 L
.23453 .00394 L
.23551 .00394 L
.23646 .00394 L
.23737 .00394 L
.23834 .00394 L
.23928 .00394 L
.24027 .00394 L
.24122 .00394 L
.24214 .00394 L
.24312 .00394 L
.24406 .00394 L
.24497 .00394 L
.24594 .00394 L
.24686 .00394 L
.24785 .00394 L
.2488 .00394 L
.24972 .00394 L
.25069 .00394 L
.25163 .00394 L
.25262 .00394 L
.25358 .00394 L
.25451 .00394 L
.25549 .00394 L
.25643 .00394 L
.25734 .00394 L
.25831 .00394 L
.25924 .00394 L
.26023 .00394 L
.26119 .00394 L
Mistroke
.2621 .00394 L
.26308 .00394 L
.26402 .00394 L
.26502 .00394 L
.26598 .00394 L
.26691 .00394 L
.26789 .00394 L
.26884 .00394 L
.26976 .00394 L
.27073 .00394 L
.27166 .00394 L
.27266 .00394 L
.27361 .00394 L
.27453 .00394 L
.27551 .00394 L
.27646 .00394 L
.27736 .00394 L
.27833 .00394 L
.27926 .00394 L
.28025 .00394 L
.2812 .00394 L
.28212 .00394 L
.28309 .00394 L
.28403 .00394 L
.28503 .00394 L
.28599 .00394 L
.28691 .00394 L
.28789 .00394 L
.28884 .00394 L
.28975 .00394 L
.29072 .00394 L
.29165 .00394 L
.29265 .00394 L
.2936 .00394 L
.29452 .00394 L
.2955 .00394 L
.29644 .00394 L
.29744 .00394 L
.2984 .00394 L
.29933 .00394 L
.30032 .00394 L
.30127 .00394 L
.30218 .00394 L
.30315 .00394 L
.30409 .00394 L
.30509 .00394 L
.30604 .00394 L
.30697 .00394 L
.30795 .00394 L
.30889 .00394 L
Mistroke
.3098 .00394 L
.31077 .00394 L
.3117 .00394 L
.31269 .00394 L
.31364 .00394 L
.31456 .00394 L
.31554 .00394 L
.31647 .00394 L
.31747 .00394 L
.31844 .00394 L
.31936 .00394 L
.32035 .00394 L
.32129 .00394 L
.3222 .00394 L
.32318 .00394 L
.32411 .00394 L
.3251 .00394 L
.32606 .00394 L
.32698 .00394 L
.32796 .00394 L
.3289 .00394 L
.32981 .00394 L
.33077 .00394 L
.3317 .00394 L
.33269 .00394 L
.33364 .00394 L
.33456 .00394 L
.33553 .00394 L
.33647 .00394 L
.33746 .00394 L
.33842 .00394 L
.33935 .00394 L
.34033 .00394 L
.34128 .00394 L
.34218 .00394 L
.34315 .00394 L
.34409 .00394 L
.34508 .00394 L
.34603 .00394 L
.34695 .00394 L
.34793 .00394 L
.34887 .00394 L
.34987 .00394 L
.35083 .00394 L
.35176 .00394 L
.35274 .00394 L
.35369 .00394 L
.3546 .00394 L
.35558 .00394 L
.35651 .00394 L
Mistroke
.35751 .00394 L
.35846 .00394 L
.35939 .00394 L
.36037 .00394 L
.36131 .00394 L
.36222 .00394 L
.36318 .00394 L
.36411 .00394 L
.3651 .00394 L
.36606 .00394 L
.36697 .00394 L
.36795 .00394 L
.36889 .00394 L
.36988 .00394 L
.37084 .00394 L
.37177 .00394 L
.37275 .00394 L
.3737 .00394 L
.37461 .00394 L
.37558 .00394 L
.37651 .00394 L
.37751 .00394 L
.37846 .00394 L
.37938 .00394 L
.38036 .00394 L
.3813 .00394 L
.3823 .00394 L
.38327 .00394 L
.3842 .00394 L
.38518 .00394 L
.38613 .00394 L
.38705 .00394 L
.38802 .00394 L
.38896 .00394 L
.38943 .00394 L
.38969 .00394 L
.38982 .00394 L
.38995 .00394 L
.39001 .00394 L
.39004 .00394 L
.39007 .00394 L
.3901 .39759 L
.39011 .39759 L
.39013 .39759 L
.39019 .39759 L
.39045 .39759 L
.39091 .39759 L
.39139 .39759 L
.39164 .39759 L
.39191 .39759 L
Mistroke
.39203 .39759 L
.39215 .39759 L
.39219 .39759 L
.3922 .39759 L
.39222 .39759 L
.39225 .00394 L
.39227 .00394 L
.39229 .00394 L
.39241 .00394 L
.39287 .00394 L
.39378 .00394 L
.39475 .00394 L
.39568 .00394 L
.39666 .00394 L
.39762 .00394 L
.39853 .00394 L
.39951 .00394 L
.40044 .00394 L
.40144 .00394 L
.4024 .00394 L
.40332 .00394 L
.40431 .00394 L
.40525 .00394 L
.40616 .00394 L
.40713 .00394 L
.40807 .00394 L
.40906 .00394 L
.41001 .00394 L
.41093 .00394 L
.41191 .00394 L
.41285 .00394 L
.41385 .00394 L
.41481 .00394 L
.41574 .00394 L
.41673 .00394 L
.41768 .00394 L
.41859 .00394 L
.41956 .00394 L
.4205 .00394 L
.42149 .00394 L
.42245 .00394 L
.42337 .00394 L
.42435 .00394 L
.4253 .00394 L
.42621 .00394 L
.42717 .00394 L
.4281 .00394 L
.42909 .00394 L
.43005 .00394 L
.43096 .00394 L
Mistroke
.43194 .00394 L
.43288 .00394 L
.43388 .00394 L
.43484 .00394 L
.43576 .00394 L
.43675 .00394 L
.4377 .00394 L
.43861 .00394 L
.43958 .00394 L
.44051 .00394 L
.4415 .00394 L
.44246 .00394 L
.44338 .00394 L
.44384 .00394 L
.44409 .00394 L
.44422 .00394 L
.44436 .00394 L
.44442 .00394 L
.44445 .00394 L
.44448 .00394 L
.4445 .20076 L
.44452 .20076 L
.44455 .20076 L
.44461 .20076 L
.44484 .20076 L
.4453 .20076 L
.44577 .20076 L
.44602 .20076 L
.44628 .20076 L
.44641 .20076 L
.44654 .20076 L
.44659 .20076 L
.44662 .20076 L
.44665 .20076 L
.44667 .20076 L
.44668 .00394 L
.44671 .00394 L
.44677 .00394 L
.44723 .00394 L
.44821 .00394 L
.44916 .00394 L
.45008 .00394 L
.45105 .00394 L
.45198 .00394 L
.45298 .00394 L
.45393 .00394 L
.45486 .00394 L
.45584 .00394 L
.45678 .00394 L
.45769 .00394 L
Mistroke
.45865 .00394 L
.45958 .00394 L
.46057 .00394 L
.46152 .00394 L
.46244 .00394 L
.46341 .00394 L
.46435 .00394 L
.46535 .00394 L
.46631 .00394 L
.46724 .00394 L
.46822 .00394 L
.46917 .00394 L
.47008 .00394 L
.47105 .00394 L
.47198 .00394 L
.47297 .00394 L
.47393 .00394 L
.47485 .00394 L
.47582 .00394 L
.47677 .00394 L
.47777 .00394 L
.47873 .00394 L
.47966 .00394 L
.48064 .00394 L
.48159 .00394 L
.48251 .00394 L
.48348 .00394 L
.48442 .00394 L
.48541 .00394 L
.48637 .00394 L
.48729 .00394 L
.48828 .00394 L
.48922 .00394 L
.49013 .00394 L
.4911 .00394 L
.49203 .00394 L
.49302 .00394 L
.49397 .00394 L
.49489 .00394 L
.49586 .00394 L
.4968 .00394 L
.4978 .00394 L
.4983 .00394 L
.49852 .00394 L
.49864 .00394 L
.49876 .00394 L
.49883 .00394 L
.49886 .00394 L
.49889 .00394 L
.49891 .20076 L
Mistroke
.49894 .20076 L
.499 .20076 L
.49921 .20076 L
.49969 .20076 L
.5006 .20076 L
.50082 .20076 L
.50095 .20076 L
.50101 .20076 L
.50103 .20076 L
.50106 .20076 L
.50109 .00394 L
.50112 .00394 L
.50119 .00394 L
.50132 .00394 L
.50156 .00394 L
.50255 .00394 L
.50349 .00394 L
.5044 .00394 L
.50537 .00394 L
.5063 .00394 L
.50729 .00394 L
.50825 .00394 L
.50917 .00394 L
.51014 .00394 L
.51108 .00394 L
.51208 .00394 L
.51305 .00394 L
.51397 .00394 L
.51496 .00394 L
.51591 .00394 L
.51682 .00394 L
.5178 .00394 L
.51873 .00394 L
.51973 .00394 L
.52068 .00394 L
.52161 .00394 L
.52259 .00394 L
.52353 .00394 L
.52444 .00394 L
.5254 .00394 L
.52633 .00394 L
.52732 .00394 L
.52828 .00394 L
.52919 .00394 L
.53017 .00394 L
.53111 .00394 L
.53211 .00394 L
.53307 .00394 L
.53399 .00394 L
.53498 .00394 L
Mistroke
.53592 .00394 L
.53683 .00394 L
.5378 .00394 L
.53874 .00394 L
.53973 .00394 L
.54069 .00394 L
.54161 .00394 L
.54258 .00394 L
.54353 .00394 L
.54443 .00394 L
.5454 .00394 L
.54632 .00394 L
.54731 .00394 L
.54826 .00394 L
.54918 .00394 L
.55015 .00394 L
.55109 .00394 L
.55208 .00394 L
.55258 .00394 L
.5528 .00394 L
.55304 .00394 L
.55315 .00394 L
.55322 .00394 L
.55327 .00394 L
.5533 .00394 L
.55333 .00394 L
.55336 .20076 L
.55339 .20076 L
.55349 .20076 L
.55397 .20076 L
.55445 .20076 L
.55496 .20076 L
.55521 .20076 L
.55534 .20076 L
.55541 .20076 L
.55543 .20076 L
.55547 .20076 L
.55549 .20076 L
.55552 .00394 L
.55555 .00394 L
.55557 .00394 L
.55569 .00394 L
.55593 .00394 L
.55683 .00394 L
.5578 .00394 L
.55873 .00394 L
.55972 .00394 L
.56067 .00394 L
.56159 .00394 L
.56256 .00394 L
Mistroke
.5635 .00394 L
.56449 .00394 L
.56546 .00394 L
.56638 .00394 L
.56736 .00394 L
.56831 .00394 L
.56922 .00394 L
.57019 .00394 L
.57112 .00394 L
.57211 .00394 L
.57307 .00394 L
.57399 .00394 L
.57497 .00394 L
.57591 .00394 L
.57691 .00394 L
.57787 .00394 L
.5788 .00394 L
.57978 .00394 L
.58073 .00394 L
.58165 .00394 L
.58262 .00394 L
.58356 .00394 L
.58455 .00394 L
.58551 .00394 L
.58643 .00394 L
.58741 .00394 L
.58836 .00394 L
.58927 .00394 L
.59023 .00394 L
.59116 .00394 L
.59215 .00394 L
.59311 .00394 L
.59402 .00394 L
.595 .00394 L
.59594 .00394 L
.59694 .00394 L
.5979 .00394 L
.59882 .00394 L
.59981 .00394 L
.60076 .00394 L
.60167 .00394 L
.60264 .00394 L
.60357 .00394 L
.60457 .00394 L
.60552 .00394 L
.60644 .00394 L
.60691 .00394 L
.60716 .00394 L
.60742 .00394 L
.60755 .00394 L
Mistroke
.60761 .00394 L
.60768 .00394 L
.6077 .00394 L
.60773 .00394 L
.60776 .39759 L
.60779 .39759 L
.60791 .39759 L
.60836 .39759 L
.60929 .39759 L
.60953 .39759 L
.60976 .39759 L
.60982 .39759 L
.60988 .39759 L
.60991 .39759 L
.60993 .39759 L
.60995 .00394 L
.60997 .00394 L
.61001 .00394 L
.61027 .00394 L
.61127 .00394 L
.61223 .00394 L
.61316 .00394 L
.61415 .00394 L
.61509 .00394 L
.61601 .00394 L
.61698 .00394 L
.61791 .00394 L
.61891 .00394 L
.61987 .00394 L
.62079 .00394 L
.62177 .00394 L
.62271 .00394 L
.62362 .00394 L
.62459 .00394 L
.62552 .00394 L
.6265 .00394 L
.62746 .00394 L
.62837 .00394 L
.62935 .00394 L
.63029 .00394 L
.63128 .00394 L
.63225 .00394 L
.63317 .00394 L
.63415 .00394 L
.6351 .00394 L
.63601 .00394 L
.63698 .00394 L
.63791 .00394 L
.63891 .00394 L
.63986 .00394 L
Mistroke
.64078 .00394 L
.64176 .00394 L
.6427 .00394 L
.6437 .00394 L
.64467 .00394 L
.64559 .00394 L
.64658 .00394 L
.64753 .00394 L
.64845 .00394 L
.64942 .00394 L
.65036 .00394 L
.65135 .00394 L
.65231 .00394 L
.65323 .00394 L
.65421 .00394 L
.65516 .00394 L
.65607 .00394 L
.65704 .00394 L
.65797 .00394 L
.65896 .00394 L
.65991 .00394 L
.66083 .00394 L
.6618 .00394 L
.66274 .00394 L
.66374 .00394 L
.66471 .00394 L
.66563 .00394 L
.66662 .00394 L
.66756 .00394 L
.66848 .00394 L
.66945 .00394 L
.67038 .00394 L
.67138 .00394 L
.67233 .00394 L
.67325 .00394 L
.67423 .00394 L
.67518 .00394 L
.67608 .00394 L
.67705 .00394 L
.67798 .00394 L
.67897 .00394 L
.67992 .00394 L
.68083 .00394 L
.68181 .00394 L
.68274 .00394 L
.68374 .00394 L
.6847 .00394 L
.68563 .00394 L
.68661 .00394 L
.68755 .00394 L
Mistroke
.68846 .00394 L
.68943 .00394 L
.69037 .00394 L
.69136 .00394 L
.69231 .00394 L
.69323 .00394 L
.69421 .00394 L
.69515 .00394 L
.69615 .00394 L
.69711 .00394 L
.69804 .00394 L
.69903 .00394 L
.69998 .00394 L
.70089 .00394 L
.70186 .00394 L
.7028 .00394 L
.70379 .00394 L
.70475 .00394 L
.70567 .00394 L
.70665 .00394 L
.7076 .00394 L
.7085 .00394 L
.70947 .00394 L
.7104 .00394 L
.71139 .00394 L
.71234 .00394 L
.71326 .00394 L
.71424 .00394 L
.71518 .00394 L
.71617 .00394 L
.71714 .00394 L
.71806 .00394 L
.71904 .00394 L
.71999 .00394 L
.7209 .00394 L
.72187 .00394 L
.72281 .00394 L
.7238 .00394 L
.72476 .00394 L
.72568 .00394 L
.72665 .00394 L
.7276 .00394 L
.7285 .00394 L
.72947 .00394 L
.7304 .00394 L
.73138 .00394 L
.73233 .00394 L
.73325 .00394 L
.73422 .00394 L
.73516 .00394 L
Mistroke
.73616 .00394 L
.73711 .00394 L
.73804 .00394 L
.73902 .00394 L
.73997 .00394 L
.74087 .00394 L
.74184 .00394 L
.74277 .00394 L
.74377 .00394 L
.74472 .00394 L
.74564 .00394 L
.74661 .00394 L
.74755 .00394 L
.74855 .00394 L
.74952 .00394 L
.75044 .00394 L
.75143 .00394 L
.75238 .00394 L
.75329 .00394 L
.75426 .00394 L
.7552 .00394 L
.75619 .00394 L
.75715 .00394 L
.75807 .00394 L
.75905 .00394 L
.75999 .00394 L
.7609 .00394 L
.76187 .00394 L
.76279 .00394 L
.76378 .00394 L
.76474 .00394 L
.76565 .00394 L
.76663 .00394 L
.76756 .00394 L
.76856 .00394 L
.76952 .00394 L
.77045 .00394 L
.77143 .00394 L
.77238 .00394 L
.77329 .00394 L
.77426 .00394 L
.77519 .00394 L
.77618 .00394 L
.77714 .00394 L
.77806 .00394 L
.77903 .00394 L
.77998 .00394 L
.78098 .00394 L
.78194 .00394 L
.78287 .00394 L
Mistroke
.78385 .00394 L
.7848 .00394 L
.78572 .00394 L
.78669 .00394 L
.78763 .00394 L
.78862 .00394 L
.78958 .00394 L
.7905 .00394 L
.79148 .00394 L
.79243 .00394 L
.79334 .00394 L
.79431 .00394 L
.79524 .00394 L
.79623 .00394 L
.79718 .00394 L
.7981 .00394 L
.79907 .00394 L
.80001 .00394 L
.80101 .00394 L
.80197 .00394 L
.8029 .00394 L
.80388 .00394 L
.80483 .00394 L
.80574 .00394 L
.80671 .00394 L
.80765 .00394 L
.80864 .00394 L
.8096 .00394 L
.81052 .00394 L
.8115 .00394 L
.81244 .00394 L
.81335 .00394 L
.81431 .00394 L
.81524 .00394 L
.81623 .00394 L
.81718 .00394 L
.81809 .00394 L
.81907 .00394 L
.82001 .00394 L
.821 .00394 L
.82196 .00394 L
.82289 .00394 L
.82387 .00394 L
.82481 .00394 L
.82572 .00394 L
.82669 .00394 L
.82762 .00394 L
.82862 .00394 L
.82957 .00394 L
.83049 .00394 L
Mistroke
.83147 .00394 L
.83241 .00394 L
.83341 .00394 L
.83437 .00394 L
.8353 .00394 L
.83628 .00394 L
.83723 .00394 L
.83815 .00394 L
.83912 .00394 L
.84005 .00394 L
.84105 .00394 L
.842 .00394 L
.84293 .00394 L
.84391 .00394 L
.84485 .00394 L
.84576 .00394 L
.84673 .00394 L
.84766 .00394 L
.84864 .00394 L
.8496 .00394 L
.85051 .00394 L
.85149 .00394 L
.85243 .00394 L
.85342 .00394 L
.85439 .00394 L
.85531 .00394 L
.85629 .00394 L
.85724 .00394 L
.85815 .00394 L
.85912 .00394 L
.86006 .00394 L
.86105 .00394 L
.862 .00394 L
.86292 .00394 L
.8639 .00394 L
.86484 .00394 L
.86585 .00394 L
.86681 .00394 L
.86774 .00394 L
.86873 .00394 L
.86968 .00394 L
.87059 .00394 L
.87156 .00394 L
.8725 .00394 L
.8735 .00394 L
.87445 .00394 L
.87538 .00394 L
.87636 .00394 L
.8773 .00394 L
.87821 .00394 L
Mistroke
.87918 .00394 L
.88011 .00394 L
.8811 .00394 L
.88206 .00394 L
.88297 .00394 L
.88395 .00394 L
.88489 .00394 L
.88589 .00394 L
.88685 .00394 L
.88778 .00394 L
.88876 .00394 L
.88971 .00394 L
.89062 .00394 L
.8916 .00394 L
.89253 .00394 L
.89352 .00394 L
.89448 .00394 L
.8954 .00394 L
.89638 .00394 L
.89732 .00394 L
.89823 .00394 L
.8992 .00394 L
.90013 .00394 L
.90112 .00394 L
.90207 .00394 L
.90298 .00394 L
.90396 .00394 L
.9049 .00394 L
.90589 .00394 L
.90685 .00394 L
.90778 .00394 L
.90876 .00394 L
.90971 .00394 L
.91062 .00394 L
.91159 .00394 L
.91252 .00394 L
.91351 .00394 L
.91446 .00394 L
.91538 .00394 L
.91636 .00394 L
.9173 .00394 L
.9183 .00394 L
.91927 .00394 L
.92019 .00394 L
.92118 .00394 L
.92213 .00394 L
.92304 .00394 L
.92402 .00394 L
.92495 .00394 L
.92595 .00394 L
Mistroke
.9269 .00394 L
.92783 .00394 L
.92881 .00394 L
.92975 .00394 L
.93066 .00394 L
.93163 .00394 L
.93256 .00394 L
.93355 .00394 L
.9345 .00394 L
.93542 .00394 L
.93639 .00394 L
.93733 .00394 L
.93833 .00394 L
.93929 .00394 L
.94022 .00394 L
.9412 .00394 L
.94215 .00394 L
.94306 .00394 L
.94403 .00394 L
.94497 .00394 L
.94596 .00394 L
.94691 .00394 L
.94783 .00394 L
.94881 .00394 L
.94976 .00394 L
.95066 .00394 L
.95163 .00394 L
.95256 .00394 L
.95354 .00394 L
.95449 .00394 L
.95541 .00394 L
.95638 .00394 L
.95732 .00394 L
.95832 .00394 L
.95928 .00394 L
.9602 .00394 L
.96118 .00394 L
.96213 .00394 L
.96304 .00394 L
.96401 .00394 L
.96494 .00394 L
.96593 .00394 L
.96688 .00394 L
.9678 .00394 L
.96878 .00394 L
.96972 .00394 L
.97072 .00394 L
.97168 .00394 L
.97261 .00394 L
.97359 .00394 L
Mistroke
.97454 .00394 L
.97545 .00394 L
.97619 .00394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Koooo
o`?o00006_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001[ooooo0_l0000Joooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006oooool3o`0001cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00004oooool002Wooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Wooooo00Go0000ooooooooooooooooo`00000J
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Hooooo`04o`00
0?ooooooooooo`0001[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Wooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Booooo`008Oooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Aooooo`Go00001Oooool00ol0003oooooooooo`0Aooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000
6oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000Zooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool05_ooool01?l0003oooooooooool0000Looooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04?ooool002_ooooo00?o0000ooooooooool01Ooo
ool4o`0001[ooooo1?l0000Jooooo`05o`000?ooooooooooooooool000001oooool4o`0001Wooooo
00Co0000oooooooooooo00006Oooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Joooo
o`Co00007_ooool00ol0003oooooooooo`05ooooo`Co00004oooool002Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0
000Iooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01_ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Co
oooo000Wooooo`Go00001oooool5o`0001Wooooo1Ol0000Jooooo`?o00002?ooool5o`0001Wooooo
0_l0000Kooooo`?o00002?ooool5o`0001Wooooo1Ol0000Iooooo`Go00001oooool5o`0001;ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000>ooooo`;o0000oooooolAooooo`00
3Oooool01?l0003oooooooooool00004ooooo`03o`000000000000000880000000?o000000000000
0000P@000001o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo0_l000001?oooooo
0000oooooooooomQo`00o`030000ool00?oo003o01[o003o00<0003oo`00ool00?l06_l00?l00`00
0?oo003oo`00o`1Po`00o`?ooooo0ol00001ooooo`003Oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08Oooool00`00003oooooooooo`0Qoooo
o`03o`000?oooooooooo00Cooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?l=oooo
o`030000oooooooooooo00_ooooo0P000?l6ooooo`03o`000?oooooooooo027ooooo00<00000oooo
ooooool08Oooool00ol0003oooooooooo`0Eooooo`7o00000Oooool000gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`1Tooooo`80003o3Oooool00`000?ooooooooooo`0;oooo
o`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003oI_ooool1o`00007ooooo000=ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0I?ooool20000o`gooooo00<0003ooooo
ooooool02oooool20000o`gooooo00<0003oooooooooool02oooool20000ofKooooo0Ol00001oooo
o`003_ooool2o`0000Gooooo00?o0000ooooooooool0I?ooool20000o`gooooo00<0003ooooooooo
ool02oooool20000o`gooooo00<0003oooooooooool02oooool20000ofKooooo0Ol00001ooooo`00
5Oooool2o`0006Gooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?l=ooooo`030000
oooooooooooo00_ooooo0P000?mUooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0I?oo
ool20000o`gooooo00<0003oooooooooool02oooool20000o`gooooo00<0003oooooooooool02ooo
ool20000ofKooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`80003o3Oooool0
0`000?ooooooooooo`0;ooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003oI_ooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo0P000?l=ooooo`030000oooooooooooo
00_ooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?mVooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0I?ooool20000o`gooooo00<0003oooooooooool02oooool20000o`go
oooo00<0003oooooooooool02oooool20000ofKooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`1Tooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003o3Oooool00`000?oooooo
ooooo`0;ooooo`80003oI_ooool1o`00007ooooo000Eooooo`;o0000IOooool20000o`gooooo00<0
003oooooooooool02oooool20000o`gooooo00<0003oooooooooool02oooool20000ofGooooo0_l0
0001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`80003o3Oooool00`000?ooooooooooo`0;
ooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003oI_ooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo06Cooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?l=oooo
o`030000oooooooooooo00_ooooo0P000?mVooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0I?ooool20000o`gooooo00<0003oooooooooool02oooool20000o`gooooo00<0003ooooooooo
ool02oooool20000ofKooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`80003o
3Oooool00`000?ooooooooooo`0;ooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003o
I_ooool1o`00007ooooo000Eooooo`;o0000IOooool20000o`gooooo00<0003oooooooooool02ooo
ool20000o`gooooo00<0003oooooooooool02oooool20000ofGooooo0_l00001ooooo`005Oooool0
0ol0003oooooooooo`1Tooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003o3Oooool0
0`000?ooooooooooo`0;ooooo`80003oI_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
06Cooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?l=ooooo`030000oooooooooooo
00_ooooo0P000?mVooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool20000o`go
oooo00<0003oooooooooool02oooool20000o`gooooo00<0003oooooooooool02oooool20000ofKo
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`80003o3Oooool00`000?oooooo
ooooo`0;ooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003oI_ooool1o`00007ooooo
000Eooooo`;o0000IOooool20000o`gooooo00<0003oooooooooool02oooool20000o`gooooo00<0
003oooooooooool02oooool20000ofGooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`1T
ooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003o3Oooool00`000?ooooooooooo`0;
ooooo`80003oI_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo0P000?l=oooo
o`030000oooooooooooo00_ooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?mVoooo
o`7o00000Oooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo06Cooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?l=ooooo`03
0000oooooooooooo00_ooooo0P000?mVooooo`7o00000Oooool00005ooooool0003oooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0I?ooool20000
o`gooooo00<0003oooooooooool02oooool20000o`gooooo00<0003oooooooooool02oooool20000
ofKooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`00000;ooooo`03o`000?oooooooooo
00;ooooo0_l0001Uooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003o3Oooool00`00
0?ooooooooooo`0;ooooo`80003oIOooool2o`00007ooooo00001Ooooooo0000oooooooooooo0000
00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Tooooo`80003o3Oooool00`00
0?ooooooooooo`0;ooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003oI_ooool1o`00
007ooooo00001Ooooooo0000oooooooooooo000000Oooooo1?l00005ooooo`03o`000?oooooooooo
06Cooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?l=ooooo`030000oooooooooooo
00_ooooo0P000?mVooooo`7o00000Oooool00005ooooool0003oooooooooool000001oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo06Cooooo0P000?l=ooooo`030000oooooooooooo
00_ooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?mVooooo`7o00000Oooool000;o
oooo0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`1Tooooo`80003o3Oooool00`000?oo
ooooooooo`0;ooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003oI_ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo06Cooooo0P000?l=ooooo`030000oooooooooooo00_ooooo
0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?mVooooo`7o00000Oooool001Gooooo0_l0
001Uooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003o3Oooool00`000?oooooooooo
o`0;ooooo`80003oIOooool2o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo0P000?l=
ooooo`030000oooooooooooo00_ooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?mV
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool20000o`gooooo00<0003ooooo
ooooool02oooool20000o`gooooo00<0003oooooooooool02oooool20000ofKooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`1Tooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80
003o3Oooool00`000?ooooooooooo`0;ooooo`80003oI_ooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo06Cooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?l=ooooo`030000
oooooooooooo00_ooooo0P000?mVooooo`7o00000Oooool001Gooooo0_l0001Uooooo`80003o3Ooo
ool00`000?ooooooooooo`0;ooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003oIOoo
ool2o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo0P000?l=ooooo`030000oooooooo
oooo00_ooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?mVooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0I?ooool20000o`gooooo00<0003oooooooooool02oooool20000
o`gooooo00<0003oooooooooool02oooool20000ofKooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`1Tooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003o3Oooool00`000?oo
ooooooooo`0;ooooo`80003oI_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo
0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?l=ooooo`030000oooooooooooo00_ooooo
0P000?mVooooo`7o00000Oooool001Gooooo0_l0001Uooooo`80003o3Oooool00`000?oooooooooo
o`0;ooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003oIOooool2o`00007ooooo000E
ooooo`03o`000?oooooooooo06Cooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?l=
ooooo`030000oooooooooooo00_ooooo0P000?mVooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0I?ooool20000o`gooooo00<0003oooooooooool02oooool20000o`gooooo00<0003ooooo
ooooool02oooool20000ofKooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`80
003o3Oooool00`000?ooooooooooo`0;ooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80
003oI_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo0P000?l=ooooo`030000
oooooooooooo00_ooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?mVooooo`7o0000
0Oooool001Gooooo0_l0001Uooooo`80003o3Oooool00`000?ooooooooooo`0;ooooo`80003o3Ooo
ool00`000?ooooooooooo`0;ooooo`80003oIOooool2o`00007ooooo000Eooooo`03o`000?oooooo
oooo06Cooooo0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?l=ooooo`030000oooooooo
oooo00_ooooo0P000?mVooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool20000
o`gooooo00<0003oooooooooool02oooool20000o`gooooo00<0003oooooooooool02oooool20000
ofKooooo0Ol00001ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0I?ooool20000o`go
oooo00<0003oooooooooool02oooool20000o`gooooo00<0003oooooooooool02oooool20000ofKo
oooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Cooooo
0P000?l=ooooo`030000oooooooooooo00_ooooo0P000?l=ooooo`030000oooooooooooo00_ooooo
0P000?mVooooo`7o00000Oooool000kooooo00?o0000ooooooooool01?ooool2o`0006Gooooo0P00
0?l=ooooo`030000oooooooooooo00_ooooo00?o003o0000ooooool03?ooool00`000?oooooooooo
o`0;ooooo`80003oIOooool2o`00007ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0I?ooool20000o`gooooo00<0003oooooooooool02oooool20000o`gooooo00<0003o
ooooooooool02oooool20000ofKooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo06Cooooo0P000?lLooooo`03o`000?oooooooooo01Wooooo0P000?mVoooo
o`7o00000Oooool000gooooo0_l00006ooooo`03o`000?oooooooooo06Cooooo0P000?lLooooo`03
o`000?oooooooooo01Wooooo0P000?mVooooo`7o00000Oooool000kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Tooooo`80003o7?ooool00ol0003oooooooooo`0Iooooo`80003o
I_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo0P000?lLooooo`03o`000?oo
oooooooo01Wooooo0P000?mVooooo`7o00000Oooool001Gooooo0_l0001Uooooo`80003o7?ooool0
0ol0003oooooooooo`0Iooooo`80003oIOooool2o`00007ooooo000Eooooo`03o`000?oooooooooo
06Cooooo0P000?lLooooo`03o`000?oooooooooo01Wooooo0P000?mVooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0I?ooool20000oacooooo00?o0000ooooooooool06Oooool20000ofKo
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`80003o7?ooool00ol0003ooooo
ooooo`0Iooooo`80003oI_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo0P00
0?lLooooo`03o`000?oooooooooo01Wooooo0P000?mVooooo`7o00000Oooool001Gooooo0_l0001U
ooooo`80003o7?ooool00ol0003oooooooooo`0Iooooo`80003oIOooool2o`00007ooooo000Eoooo
o`03o`000?oooooooooo06Cooooo0P000?lLooooo`03o`000?oooooooooo01Wooooo0P000?mVoooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool20000oacooooo00?o0000oooooooo
ool06Oooool20000ofKooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`80003o
7?ooool00ol0003oooooooooo`0Iooooo`80003oI_ooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo06Cooooo0P000?lLooooo`03o`000?oooooooooo01Wooooo0P000?mVooooo`7o00000Ooo
ool001Gooooo0_l0001Uooooo`80003o7?ooool00ol0003oooooooooo`0Iooooo`80003oIOooool2
o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo0P000?lLooooo`03o`000?oooooooooo
01Wooooo0P000?mVooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool20000oaco
oooo00?o0000ooooooooool06Oooool20000ofKooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`1Tooooo`80003o7?ooool00ol0003oooooooooo`0Iooooo`80003oI_ooool1o`00007ooooo
000Eooooo`03o`000?oooooooooo06Cooooo0P000?lLooooo`03o`000?oooooooooo01Wooooo0P00
0?mVooooo`7o00000Oooool001Gooooo0_l0001Uooooo`80003o7?ooool00ol0003oooooooooo`0I
ooooo`80003oIOooool2o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo0P000?lLoooo
o`03o`000?oooooooooo01Wooooo0P000?mVooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0I?ooool20000oacooooo00?o0000ooooooooool06Oooool20000ofKooooo0Ol00001ooooo`00
00Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003o
ooooooooo`1Tooooo`80003o7?ooool00ol0003oooooooooo`0Iooooo`80003oI_ooool1o`00007o
oooo0002ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo06Cooooo0P000?lLooooo`03o`000?oooooooooo01Wooooo0P000?mVooooo`7o
00000Oooool000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo06Cooooo0P000?lLooooo`03o`000?oooooooooo01Wooooo0P000?mVooooo`7o0000
0Oooool000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`;o0000IOoo
ool20000oacooooo00?o0000ooooooooool06Oooool20000ofGooooo0_l00001ooooo`000_ooool0
0ol0003oooooooooo`07ooooo`Co00001Oooool00ol0003oooooooooo`1Tooooo`80003o7?ooool0
0ol0003oooooooooo`0Iooooo`80003oI_ooool1o`00007ooooo00000ooooooo0000o`000009oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0I?ooool20000oacooooo00?o0000oooo
ooooool06Oooool20000ofKooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`07ooooo`Go
00001?ooool00ol0003oooooooooo`1Tooooo`80003o7?ooool00ol0003oooooooooo`0Iooooo`80
003oI_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo0P000?lLooooo`03o`00
0?oooooooooo01Wooooo0P000?mVooooo`7o00000Oooool001Gooooo0_l0001Uooooo`80003o7?oo
ool00ol0003oooooooooo`0Iooooo`80003oIOooool2o`00007ooooo000Eooooo`03o`000?oooooo
oooo06Cooooo0P000?lLooooo`03o`000?oooooooooo01Wooooo0P000?mVooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0I?ooool20000oacooooo00?o0000ooooooooool06Oooool20000
ofKooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`80003o7?ooool00ol0003o
ooooooooo`0Iooooo`80003oI_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo
0P000?lLooooo`03o`000?oooooooooo01Wooooo0P000?mVooooo`7o00000Oooool001Gooooo0_l0
001Uooooo`80003o7?ooool00ol0003oooooooooo`0Iooooo`80003oIOooool2o`00007ooooo000E
ooooo`03o`000?oooooooooo06Cooooo0P000?lLooooo`03o`000?oooooooooo01Wooooo0P000?mV
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool20000oacooooo00?o0000oooo
ooooool06Oooool20000ofKooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Tooooo`80
003o7?ooool00ol0003oooooooooo`0Iooooo`80003oI_ooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo06Cooooo0P000?lLooooo`03o`000?oooooooooo01Wooooo0P000?mVooooo`7o0000
0Oooool001Gooooo0_l0001Uooooo`80003o7?ooool00ol0003oooooooooo`0Iooooo`80003oIOoo
ool2o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo0P000?lLooooo`03o`000?oooooo
oooo01Wooooo0P000?mVooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0I?ooool20000
oacooooo00?o0000ooooooooool06Oooool20000ofKooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`1Tooooo`80003o7?ooool00ol0003oooooooooo`0Iooooo`80003oI_ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo06Cooooo0P000?lLooooo`03o`000?oooooooooo01Wooooo
0P000?mVooooo`7o00000Oooool001Gooooo0_l0001Uooooo`80003o7?ooool00ol0003ooooooooo
o`0Iooooo`80003oIOooool2o`00007ooooo000Eooooo`03o`000?oooooooooo06Cooooo0P000?lL
ooooo`03o`000?oooooooooo01Wooooo0P000?mVooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0I?ooool20000oacooooo00?o0000ooooooooool06Oooool20000ofKooooo0Ol00001oooo
o`003?ooool5o`0000Cooooo00?o0000ooooooooool0I?ooool20000oacooooo00?o0000oooooooo
ool06Oooool20000ofKooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo06Cooooo0P000?lLooooo`03o`000?oooooooooo01Wooooo0P000?mVooooo`7o
00000Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Tooooo`80003o
7?ooool00ol0003oooooooooo`0Iooooo`80003oI_ooool1o`00007ooooo000?ooooo`03o`000?oo
oooooooo00?ooooo0_l0001Uooooo`03o`00o`000?oooooo01_ooooo00?o0000ooooooooool06Ooo
ool00ol00?l0003oooooo`1Tooooo`;o00000Oooool000cooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000<
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo087ooooo0Ol00001ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083o
oooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001oooo
o`005Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003o
ooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o
00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`005Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0POooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POoo
ool1o`00007ooooo0002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`000oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0_l00023ooooo`03o`000?oooooooooo
083ooooo0_l00001ooooo`0000Go0000ooooooooooooooooo`000007ooooo`Co00001Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`0000Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`21ooooo`7o00000Oooool00004ooooool0003o0000o`0000Sooooo1Ol00004oooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000
Poooool00ol0003oooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083ooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Ooo
ool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003ooooooooo
o`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0POooool1o`00007ooooo000<ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`004?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007o
oooo000>ooooo`;o00001Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo
000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`21ooooo`7o00000Oooool000cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000=ooooo`?o00001Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`000003
ooooool0003ooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`?o
00000Oooool001Goooooool0000;o`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.6628, -0.260466, \
0.0691952, 0.0191323}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CTFT of finite-length x(t)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xf\  = \ 
        Integrate[x[t]\ Exp[\(-I\)\ 2  \[Pi]\ f\ t], {t, 0, \ 5}]\  // \ 
          FullSimplify;\)\), "\[IndentingNewLine]", 
    \(xf\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(\[ExponentialE]\^\(\(-5\)\ \[ImaginaryI]\ f\ \[Pi]\)\
\ \((7\ f\^4 - 17\ f\^2 + 4)\)\ \(sin(5\ f\ \[Pi])\)\)\/\(\((f - 2)\)\ \((f - \
1)\)\ f\ \((f + 1)\)\ \((f + 2)\)\ \[Pi]\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gX2 = 
        Plot[Abs[xf], {f, \(-5\), 5}, \ PlotStyle \[Rule] {Blue}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147151 0.0583928 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1315 -6 -4.5 ]
[-0.0125 .1315 0 4.5 ]
[-0.0125 .24829 -6 -4.5 ]
[-0.0125 .24829 0 4.5 ]
[-0.0125 .36507 -6 -4.5 ]
[-0.0125 .36507 0 4.5 ]
[-0.0125 .48186 -6 -4.5 ]
[-0.0125 .48186 0 4.5 ]
[-0.0125 .59864 -12 -4.5 ]
[-0.0125 .59864 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1315 m
.00625 .1315 L
s
[(2)] -0.0125 .1315 1 0 Mshowa
0 .24829 m
.00625 .24829 L
s
[(4)] -0.0125 .24829 1 0 Mshowa
0 .36507 m
.00625 .36507 L
s
[(6)] -0.0125 .36507 1 0 Mshowa
0 .48186 m
.00625 .48186 L
s
[(8)] -0.0125 .48186 1 0 Mshowa
0 .59864 m
.00625 .59864 L
s
[(10)] -0.0125 .59864 1 0 Mshowa
.125 Mabswid
0 .04391 m
.00375 .04391 L
s
0 .07311 m
.00375 .07311 L
s
0 .1023 m
.00375 .1023 L
s
0 .1607 m
.00375 .1607 L
s
0 .18989 m
.00375 .18989 L
s
0 .21909 m
.00375 .21909 L
s
0 .27748 m
.00375 .27748 L
s
0 .30668 m
.00375 .30668 L
s
0 .33588 m
.00375 .33588 L
s
0 .39427 m
.00375 .39427 L
s
0 .42346 m
.00375 .42346 L
s
0 .45266 m
.00375 .45266 L
s
0 .51105 m
.00375 .51105 L
s
0 .54025 m
.00375 .54025 L
s
0 .56945 m
.00375 .56945 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1315 m
1 .1315 L
s
.99375 .24829 m
1 .24829 L
s
.99375 .36507 m
1 .36507 L
s
.99375 .48186 m
1 .48186 L
s
.99375 .59864 m
1 .59864 L
s
.125 Mabswid
.99625 .04391 m
1 .04391 L
s
.99625 .07311 m
1 .07311 L
s
.99625 .1023 m
1 .1023 L
s
.99625 .1607 m
1 .1607 L
s
.99625 .18989 m
1 .18989 L
s
.99625 .21909 m
1 .21909 L
s
.99625 .27748 m
1 .27748 L
s
.99625 .30668 m
1 .30668 L
s
.99625 .33588 m
1 .33588 L
s
.99625 .39427 m
1 .39427 L
s
.99625 .42346 m
1 .42346 L
s
.99625 .45266 m
1 .45266 L
s
.99625 .51105 m
1 .51105 L
s
.99625 .54025 m
1 .54025 L
s
.99625 .56945 m
1 .56945 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02608 .02544 L
.02847 .03524 L
.02972 .03925 L
.03089 .04206 L
.03157 .04323 L
.03188 .04367 L
.03218 .044 L
.03252 .04429 L
.03269 .04441 L
.03288 .04451 L
.03296 .04454 L
.03305 .04457 L
.0332 .04461 L
.03329 .04463 L
.03338 .04463 L
.03346 .04463 L
.03355 .04463 L
.03363 .04462 L
.03371 .0446 L
.03386 .04456 L
.03402 .0445 L
.03419 .0444 L
.0345 .04417 L
.0348 .04388 L
.03534 .04316 L
.03592 .04214 L
.03725 .03887 L
.03845 .03487 L
.04095 .02417 L
.04205 .0188 L
.04235 .01729 L
.04251 .0165 L
.04267 .01566 L
.04282 .01492 L
.0429 .01493 L
.04298 .01532 L
.04326 .01675 L
.0455 .02778 L
.04788 .03767 L
.04915 .04164 L
.04977 .04318 L
.05035 .04434 L
.05087 .04516 L
.05114 .0455 L
.05142 .04579 L
.05157 .04592 L
.05171 .04602 L
.05185 .0461 L
.05198 .04616 L
Mistroke
.05213 .04622 L
.05221 .04624 L
.05229 .04626 L
.05245 .04627 L
.05259 .04627 L
.05274 .04625 L
.05287 .04621 L
.05302 .04615 L
.05318 .04607 L
.05351 .04583 L
.0538 .04553 L
.05437 .04475 L
.05492 .04377 L
.05612 .04074 L
.05743 .03627 L
.05977 .02583 L
.06101 .01945 L
.06135 .01765 L
.06154 .01666 L
.06171 .01574 L
.06186 .01495 L
.06202 .01533 L
.06211 .01581 L
.06219 .01626 L
.06235 .01711 L
.0648 .02976 L
.06709 .03961 L
.06827 .04341 L
.06891 .04505 L
.06951 .04628 L
.07003 .04709 L
.07029 .04742 L
.07057 .04771 L
.07074 .04784 L
.07089 .04794 L
.07103 .04801 L
.07118 .04807 L
.07132 .04811 L
.07145 .04813 L
.07159 .04813 L
.07174 .04811 L
.07189 .04807 L
.07203 .04802 L
.07219 .04794 L
.07234 .04784 L
.0726 .04762 L
.07289 .0473 L
.07355 .04631 L
.07415 .04506 L
.07539 .04158 L
Mistroke
.0767 .03664 L
.07908 .0251 L
.08013 .01938 L
.08041 .01778 L
.08057 .01689 L
.08072 .01606 L
.08085 .01527 L
.081 .015 L
.08114 .01577 L
.08126 .01648 L
.08246 .02326 L
.08361 .02943 L
.08491 .03589 L
.08612 .04109 L
.08731 .04519 L
.0884 .04794 L
.08869 .04851 L
.08901 .04905 L
.08929 .04943 L
.0896 .04977 L
.08976 .04991 L
.08992 .05003 L
.0901 .05013 L
.09018 .05016 L
.09027 .0502 L
.09043 .05023 L
.09051 .05024 L
.09059 .05025 L
.09074 .05024 L
.09089 .05021 L
.09104 .05015 L
.09112 .05012 L
.0912 .05007 L
.09153 .04983 L
.09182 .04953 L
.09213 .04912 L
.09283 .04787 L
.09347 .04633 L
.09471 .04231 L
.0959 .03738 L
.09714 .0312 L
.09832 .0247 L
.09937 .01849 L
.09966 .01676 L
.09982 .01581 L
.09997 .01492 L
.10009 .01527 L
.10023 .01609 L
.10051 .01781 L
.10289 .03173 L
Mistroke
.10542 .04389 L
.10665 .04816 L
.10735 .04999 L
.10799 .05127 L
.10826 .05169 L
.10855 .05206 L
.10872 .05224 L
.10887 .05237 L
.10901 .05248 L
.10917 .05257 L
.10933 .05264 L
.10948 .05268 L
.10957 .05269 L
.10965 .05269 L
.10981 .05268 L
.10996 .05265 L
.1101 .05259 L
.11026 .05251 L
.11042 .05239 L
.11073 .05211 L
.11102 .05174 L
.11156 .05083 L
.11215 .04952 L
.11279 .04771 L
.11393 .04354 L
.115 .03872 L
.11617 .03249 L
.11744 .02497 L
.11802 .02132 L
.11834 .01929 L
.11863 .01739 L
.11889 .01575 L
.11903 .01483 L
.11916 .01543 L
.11973 .01915 L
.1221 .03391 L
.12428 .04523 L
.12541 .04967 L
.12598 .05149 L
.1266 .0531 L
.12692 .05378 L
.12721 .05431 L
.12751 .05476 L
.12779 .05508 L
.12796 .05524 L
.12811 .05536 L
.12828 .05546 L
.12838 .0555 L
.12846 .05553 L
.12854 .05554 L
Mistroke
.12862 .05556 L
.12877 .05556 L
.12893 .05554 L
.12902 .05551 L
.1291 .05548 L
.12926 .0554 L
.12942 .05529 L
.12971 .05502 L
.13002 .05462 L
.13037 .05406 L
.13098 .05273 L
.13156 .05112 L
.13264 .04723 L
.1338 .04185 L
.13617 .02784 L
.13682 .02351 L
.13752 .01875 L
.13768 .01762 L
.13785 .0164 L
.13793 .01584 L
.13802 .01524 L
.13817 .01525 L
.13832 .01628 L
.13846 .01724 L
.13877 .01942 L
.14127 .03622 L
.14355 .04876 L
.1447 .05344 L
.14535 .0555 L
.14596 .057 L
.14648 .05797 L
.14678 .05838 L
.14706 .05867 L
.14721 .05878 L
.14736 .05887 L
.14749 .05893 L
.14763 .05897 L
.14778 .05898 L
.14787 .05898 L
.14794 .05897 L
.14809 .05892 L
.14824 .05886 L
.14838 .05877 L
.14852 .05865 L
.14879 .05837 L
.14911 .05792 L
.14941 .0574 L
.15004 .05592 L
.15065 .05409 L
.15171 .04991 L
Mistroke
.15287 .04406 L
.1542 .03602 L
.15544 .02741 L
.15656 .01912 L
.15687 .01679 L
.15702 .01562 L
.15711 .01495 L
.15719 .0151 L
.15734 .01622 L
.15747 .01724 L
.15777 .01953 L
.16023 .03755 L
.16249 .05135 L
.16361 .05647 L
.16418 .05858 L
.1648 .06042 L
.16512 .0612 L
.16541 .0618 L
.16571 .0623 L
.16599 .06266 L
.16615 .06283 L
.16629 .06295 L
.16645 .06305 L
.16654 .06309 L
.16663 .06312 L
.16671 .06314 L
.1668 .06315 L
.16695 .06315 L
.16704 .06313 L
.16712 .06311 L
.16721 .06307 L
.1673 .06302 L
.16746 .06291 L
.16761 .06278 L
.16793 .06238 L
.16824 .06189 L
.16852 .06132 L
.16916 .05965 L
.16985 .05727 L
.17112 .05148 L
.17228 .04467 L
.17347 .03645 L
.17475 .02661 L
.17537 .02157 L
.17567 .01905 L
.17595 .01671 L
.17608 .01561 L
.17621 .01486 L
.17634 .01594 L
.17648 .01713 L
Mistroke
.17705 .02193 L
.1794 .04086 L
.18164 .05571 L
.1828 .0615 L
.18346 .06406 L
.18408 .06593 L
.18437 .06664 L
.18464 .0672 L
.18489 .06762 L
.18516 .06796 L
.18529 .0681 L
.18544 .06822 L
.18558 .06831 L
.18571 .06836 L
.18586 .06839 L
.186 .06839 L
.18616 .06835 L
.18631 .06829 L
.18645 .0682 L
.18659 .06807 L
.18686 .06776 L
.18718 .06725 L
.18747 .06665 L
.18807 .06504 L
.18871 .06279 L
.18977 .05783 L
.19093 .05081 L
.19225 .04114 L
.19349 .0307 L
.19461 .0206 L
.19491 .01776 L
.19508 .0162 L
.19524 .01473 L
.19537 .01595 L
.19551 .01729 L
.19582 .02015 L
.19807 .04074 L
.20052 .0597 L
.20116 .06364 L
.20185 .06728 L
.20244 .06991 L
.20307 .07219 L
.20342 .07316 L
.20373 .07389 L
.20403 .07444 L
.20418 .07467 L
.20435 .07487 L
.2045 .07501 L
.20463 .07511 L
.20477 .07518 L
Mistroke
.2049 .07522 L
.20505 .07523 L
.20518 .07521 L
.20534 .07515 L
.20541 .0751 L
.2055 .07504 L
.20578 .07474 L
.20594 .07452 L
.20609 .07427 L
.20672 .07284 L
.20726 .0711 L
.20783 .06872 L
.20915 .06142 L
.21035 .05273 L
.21157 .04219 L
.21286 .02962 L
.21339 .02415 L
.21396 .01814 L
.21413 .01636 L
.21429 .01477 L
.21443 .0163 L
.21459 .01797 L
.21518 .02425 L
.21761 .04936 L
.21982 .06818 L
.22104 .07601 L
.22161 .07882 L
.2222 .08121 L
.2225 .0822 L
.22283 .0831 L
.22313 .08374 L
.22342 .08419 L
.22359 .08439 L
.22367 .08446 L
.22375 .08452 L
.22389 .08461 L
.22405 .08465 L
.22421 .08465 L
.2243 .08463 L
.22438 .08459 L
.22447 .08454 L
.22455 .08448 L
.22473 .0843 L
.22488 .0841 L
.22503 .08386 L
.2253 .08332 L
.22592 .08158 L
.22645 .07951 L
.22702 .07669 L
.22832 .06816 L
Mistroke
.22952 .05793 L
.23071 .04587 L
.23198 .03133 L
.2326 .02385 L
.2329 .0201 L
.23304 .01844 L
.23318 .0166 L
.23331 .01495 L
.23344 .01603 L
.23357 .01767 L
.23371 .01943 L
.23428 .02665 L
.23647 .05346 L
.23886 .07822 L
.24011 .08792 L
.24071 .09156 L
.24128 .09435 L
.24158 .0956 L
.24192 .09673 L
.24222 .09754 L
.24251 .09811 L
.24266 .09835 L
.24281 .09852 L
.24289 .0986 L
.24297 .09866 L
.24306 .09871 L
.24314 .09874 L
.24323 .09876 L
.24331 .09876 L
.24347 .09871 L
.24356 .09866 L
.24365 .09859 L
.24382 .09841 L
.24396 .0982 L
.24411 .09794 L
.24438 .09732 L
.24471 .09637 L
.245 .0953 L
.24564 .09228 L
.24625 .08859 L
.24731 .08017 L
.24847 .06845 L
.25082 .03821 L
.25146 .02879 L
.2518 .02371 L
.25198 .02091 L
.25215 .01829 L
.2523 .01596 L
.25238 .01477 L
.25246 .01596 L
Mistroke
.2528 .02127 L
.2534 .03063 L
.25587 .06828 L
.25814 .09746 L
.25927 .10852 L
.25984 .11308 L
.26046 .11707 L
.26078 .11877 L
.26108 .12007 L
.26138 .12116 L
.26165 .12194 L
.26181 .12229 L
.26198 .12258 L
.26206 .12269 L
.26214 .12279 L
.26224 .12287 L
.26233 .12293 L
.26241 .12296 L
.26249 .12297 L
.26258 .12296 L
.26266 .12293 L
.26281 .12282 L
.26297 .12264 L
.26312 .1224 L
.26328 .12206 L
.26361 .12114 L
.26391 .11999 L
.2642 .11866 L
.26485 .11477 L
.26554 .10922 L
.26681 .09553 L
.26797 .0793 L
.27026 .03865 L
.27089 .026 L
.27107 .02226 L
.27124 .01872 L
.27139 .01551 L
.27148 .01573 L
.27156 .01741 L
.27276 .04334 L
.27522 .09604 L
.27643 .11953 L
.27752 .13853 L
.27858 .15399 L
.27973 .16687 L
.28037 .17195 L
.28065 .1737 L
.28095 .17528 L
.28124 .17642 L
.28137 .17682 L
Mistroke
.28151 .17717 L
.28166 .17745 L
.2818 .17763 L
.28194 .17773 L
.28203 .17774 L
.2821 .17773 L
.28226 .17762 L
.28234 .17752 L
.28242 .17739 L
.28257 .17707 L
.28271 .17668 L
.28303 .17547 L
.28337 .17365 L
.2837 .17144 L
.284 .1689 L
.28457 .16295 L
.28565 .1476 L
.28682 .12471 L
.28919 .05931 L
.28988 .03622 L
.29021 .02429 L
.29036 .01893 L
.29045 .01586 L
.29052 .01645 L
.29066 .02153 L
.2908 .02704 L
.2911 .03847 L
.29173 .06337 L
.29672 .28613 L
.29922 .39594 L
.30154 .48366 L
.30378 .54913 L
.30492 .57304 L
.30556 .58365 L
.30617 .59156 L
.30676 .59741 L
.3071 .59984 L
.30726 .60078 L
.30742 .60153 L
.30756 .60212 L
.30772 .60263 L
.30786 .60297 L
.30799 .60318 L
.30814 .60331 L
.30829 .60331 L
.30837 .60327 L
.30845 .60318 L
.30861 .60291 L
.30876 .60253 L
.30889 .60207 L
Mistroke
.30921 .60064 L
.30948 .59894 L
.30977 .59668 L
.31028 .5917 L
.31084 .58464 L
.31206 .56391 L
.31317 .53887 L
.31569 .46467 L
.32046 .28396 L
.32506 .11293 L
.32627 .07479 L
.32742 .04268 L
.32806 .02671 L
.32823 .02257 L
.32841 .01828 L
.32857 .01472 L
.32866 .0167 L
.32874 .01854 L
.32995 .04234 L
.3312 .06188 L
.33182 .06954 L
.33239 .07551 L
.33295 .08033 L
.33346 .08385 L
.33403 .08683 L
.33434 .08808 L
.33463 .089 L
.33477 .08936 L
.33492 .08969 L
.33505 .08992 L
.33519 .09013 L
.33528 .09023 L
.33536 .0903 L
.33551 .0904 L
.33566 .09044 L
.33581 .09043 L
.33595 .09036 L
.33611 .09023 L
.33626 .09006 L
.3364 .08986 L
.33672 .08923 L
.33705 .08834 L
.3376 .0864 L
.33812 .0841 L
.33928 .07743 L
.34399 .04002 L
.34523 .03031 L
.34588 .02557 L
.34657 .02093 L
.34717 .01722 L
Mistroke
.34734 .01627 L
.34743 .01575 L
.34752 .01527 L
.3476 .01483 L
.34768 .01507 L
.34784 .01587 L
.349 .0212 L
.34955 .02317 L
.35013 .02493 L
.35078 .02641 L
.35138 .0274 L
.35169 .02775 L
.35187 .02791 L
.35203 .02803 L
.3522 .02812 L
.35229 .02816 L
.35238 .02819 L
.35253 .02823 L
.35262 .02824 L
.3527 .02824 L
.35285 .02823 L
.35298 .02821 L
.35313 .02816 L
.35322 .02813 L
.35329 .02809 L
.35361 .02788 L
.35392 .02761 L
.35452 .02687 L
.35507 .02599 L
.3563 .02346 L
.35852 .01795 L
.35911 .01649 L
.35943 .01573 L
.35959 .01537 L
.35973 .01505 L
.35986 .01475 L
.35999 .01495 L
.36026 .01552 L
.36084 .01663 L
.36143 .01756 L
.36205 .01833 L
.36237 .01863 L
.36254 .01876 L
.36273 .01888 L
.3629 .01896 L
.36305 .01902 L
.3632 .01905 L
.36335 .01908 L
.3635 .01908 L
.36359 .01907 L
Mistroke
.36367 .01906 L
.36381 .01903 L
.36396 .01897 L
.36409 .01891 L
.36422 .01883 L
.36451 .01862 L
.36482 .0183 L
.3651 .01794 L
.36574 .01688 L
.36628 .0157 L
.36643 .01534 L
.36659 .01493 L
.36674 .01491 L
.36687 .01529 L
.36795 .01885 L
.37028 .02909 L
.37279 .04217 L
.37515 .05343 L
.3758 .0559 L
.37649 .05811 L
.37683 .059 L
.37715 .05972 L
.37743 .06025 L
.37774 .06072 L
.37789 .06089 L
.37804 .06104 L
.37818 .06115 L
.37832 .06123 L
.37846 .06127 L
.37862 .06129 L
.37869 .06129 L
.37878 .06127 L
.37893 .06121 L
.37907 .06113 L
.37923 .061 L
.37937 .06083 L
.37951 .06066 L
.38003 .05966 L
.38032 .05887 L
.3806 .05799 L
.38123 .05545 L
.38185 .05224 L
.38251 .04795 L
.38374 .03767 L
.38438 .03102 L
.38507 .02304 L
.38536 .01942 L
.38551 .01746 L
.38567 .01534 L
.38575 .01524 L
Mistroke
.38585 .01651 L
.38601 .01878 L
.38633 .02338 L
.3875 .04166 L
.39238 .13711 L
.39709 .23263 L
.39832 .25362 L
.39966 .27313 L
.40092 .28785 L
.40209 .29787 L
.40265 .30139 L
.40296 .30296 L
.40326 .3042 L
.40353 .30513 L
.40367 .30554 L
.40383 .30591 L
.40397 .30618 L
.4041 .30639 L
.40423 .30654 L
.40435 .30665 L
.4045 .30671 L
.40465 .30672 L
.40473 .30669 L
.40482 .30665 L
.40497 .30651 L
.40513 .3063 L
.40527 .30604 L
.40555 .3054 L
.40587 .30436 L
.40617 .30315 L
.40684 .29949 L
.4074 .29551 L
.408 .2903 L
.40909 .27855 L
.41158 .24205 L
.41654 .1445 L
.41902 .09396 L
.42132 .05168 L
.42247 .03338 L
.42303 .02518 L
.42355 .01811 L
.4237 .01615 L
.42384 .01507 L
.42398 .0169 L
.42414 .01887 L
.42479 .0263 L
.42592 .03736 L
.42652 .04224 L
.42718 .04677 L
.42776 .05009 L
Mistroke
.42837 .05294 L
.42898 .0551 L
.42953 .0565 L
.4298 .05699 L
.42994 .05721 L
.43009 .0574 L
.43022 .05754 L
.43036 .05766 L
.43049 .05775 L
.43061 .0578 L
.43076 .05785 L
.43084 .05786 L
.43092 .05785 L
.43107 .05783 L
.43121 .05778 L
.4313 .05773 L
.43138 .05768 L
.43153 .05756 L
.43187 .05717 L
.43217 .05673 L
.43244 .05622 L
.43307 .05475 L
.43415 .05133 L
.43531 .04673 L
.43772 .03546 L
.44032 .02349 L
.44155 .01878 L
.44221 .01657 L
.44254 .01559 L
.44268 .01519 L
.44284 .01477 L
.44298 .01504 L
.44311 .01537 L
.44337 .01599 L
.44394 .01718 L
.44453 .01817 L
.44483 .01858 L
.44515 .01894 L
.44543 .0192 L
.44574 .01941 L
.44588 .01949 L
.44602 .01955 L
.44616 .0196 L
.44628 .01963 L
.44644 .01966 L
.44658 .01967 L
.44674 .01967 L
.44682 .01966 L
.44691 .01965 L
.44706 .01961 L
Mistroke
.44721 .01956 L
.4475 .01943 L
.44778 .01926 L
.44809 .01902 L
.44865 .01846 L
.44971 .01705 L
.45035 .016 L
.45066 .01545 L
.4508 .0152 L
.45095 .01493 L
.45109 .01476 L
.45122 .01499 L
.45149 .01551 L
.45208 .01663 L
.45338 .01902 L
.45461 .02096 L
.45518 .02167 L
.45579 .02227 L
.45611 .0225 L
.45627 .0226 L
.45646 .02269 L
.45662 .02276 L
.45677 .02281 L
.45692 .02284 L
.45707 .02286 L
.45721 .02286 L
.45734 .02285 L
.45749 .02283 L
.45763 .02279 L
.45775 .02275 L
.45787 .0227 L
.45814 .02254 L
.45841 .02233 L
.45871 .02204 L
.45931 .02125 L
.45994 .02013 L
.46054 .01879 L
.46108 .01733 L
.46166 .01555 L
.4618 .01507 L
.46196 .0149 L
.46205 .01521 L
.46213 .0155 L
.46229 .01608 L
.46287 .01835 L
.46418 .0242 L
.46665 .03696 L
.46895 .04889 L
.47009 .054 L
.47117 .05794 L
Mistroke
.47177 .05963 L
.47208 .06037 L
.47241 .06102 L
.47269 .06145 L
.47284 .06164 L
.473 .06182 L
.47315 .06194 L
.47328 .06203 L
.47342 .06209 L
.47354 .06213 L
.47369 .06214 L
.47378 .06213 L
.47386 .06212 L
.474 .06206 L
.47415 .06197 L
.47429 .06185 L
.47441 .06172 L
.4747 .06131 L
.47501 .06072 L
.4753 .06003 L
.47593 .05797 L
.47648 .05562 L
.47707 .05243 L
.47815 .04488 L
.47929 .03449 L
.47994 .02737 L
.48054 .02012 L
.4807 .01809 L
.48084 .01615 L
.481 .01534 L
.48108 .01645 L
.48117 .01764 L
.48185 .02742 L
.48307 .04705 L
.48808 .14521 L
.49059 .19721 L
.4929 .24055 L
.49516 .27455 L
.49629 .28757 L
.49693 .29352 L
.49754 .29818 L
.49813 .30173 L
.49844 .30323 L
.49877 .30453 L
.49907 .30546 L
.49935 .30608 L
.49948 .3063 L
.49963 .30648 L
.49976 .3066 L
.49989 .30666 L
Mistroke
.50003 .30668 L
.50019 .30663 L
.50034 .30652 L
.50047 .30636 L
.50063 .30611 L
.5008 .30577 L
.50111 .30492 L
.50144 .30374 L
.50179 .30217 L
.50241 .29852 L
.50354 .28921 L
.50476 .2756 L
.50697 .24278 L
.51194 .14489 L
.51442 .09366 L
.51672 .05055 L
.51787 .03175 L
.51843 .0233 L
.51868 .01977 L
.51881 .01794 L
.51895 .01602 L
.5191 .01544 L
.51924 .0173 L
.51955 .02123 L
.5202 .02893 L
.52133 .04043 L
.52255 .05007 L
.52325 .05423 L
.52389 .05727 L
.52445 .05929 L
.52477 .0602 L
.52506 .06088 L
.52537 .06143 L
.52554 .06166 L
.52571 .06185 L
.52586 .06197 L
.526 .06206 L
.52615 .06212 L
.52624 .06214 L
.52631 .06214 L
.52646 .06213 L
.52659 .06209 L
.52674 .06202 L
.5269 .06191 L
.52706 .06175 L
.52722 .06157 L
.52752 .06113 L
.52805 .06008 L
.52862 .05856 L
.52993 .05392 L
Mistroke
.53113 .04847 L
.5334 .03667 L
.53586 .02403 L
.53651 .02102 L
.5372 .01808 L
.53779 .0158 L
.53795 .01521 L
.53805 .01489 L
.53813 .01483 L
.5382 .01509 L
.53829 .01537 L
.53844 .01587 L
.5396 .01912 L
.54026 .02051 L
.54087 .02152 L
.54117 .0219 L
.54147 .02223 L
.54174 .02246 L
.54202 .02264 L
.54218 .02272 L
.54233 .02278 L
.54248 .02282 L
.54261 .02285 L
.54269 .02285 L
.54278 .02286 L
.54293 .02286 L
.54301 .02285 L
.54309 .02284 L
.54317 .02282 L
.54326 .0228 L
.54343 .02274 L
.54359 .02267 L
.54394 .02247 L
.54425 .02223 L
.54459 .02192 L
.5458 .02037 L
.54704 .01827 L
.5477 .01705 L
.54839 .01574 L
.54868 .01519 L
.54876 .01503 L
.54884 .01488 L
.54899 .01482 L
.54908 .01498 L
.54916 .01512 L
.54934 .01544 L
.54966 .016 L
.55082 .01781 L
.55138 .0185 L
.55169 .01882 L
Mistroke
.55199 .01909 L
.55226 .01929 L
.55256 .01946 L
.55269 .01952 L
.55283 .01958 L
.55296 .01962 L
.55308 .01964 L
.55323 .01967 L
.55331 .01967 L
.5534 .01967 L
.55355 .01966 L
.55369 .01964 L
.55378 .01962 L
.55386 .01959 L
.55402 .01954 L
.55418 .01946 L
.55436 .01935 L
.55466 .01911 L
.55499 .01879 L
.55557 .01803 L
.55616 .017 L
.5567 .01583 L
.55698 .01514 L
.55706 .01494 L
.55714 .01472 L
.55729 .01511 L
.55791 .01697 L
.56012 .02537 L
.56252 .03661 L
.56378 .04265 L
.56512 .04854 L
.56632 .05294 L
.56695 .05481 L
.5673 .05567 L
.56763 .05637 L
.56793 .05689 L
.56826 .05734 L
.5684 .05749 L
.56855 .05763 L
.5687 .05773 L
.56883 .05779 L
.56897 .05784 L
.5691 .05786 L
.56925 .05785 L
.5694 .0578 L
.56954 .05773 L
.56966 .05765 L
.5698 .05752 L
.56995 .05736 L
.57026 .0569 L
Mistroke
.57058 .05624 L
.57118 .05461 L
.57181 .05217 L
.57251 .04863 L
.57376 .03999 L
.57494 .02915 L
.57556 .02241 L
.57586 .01886 L
.57599 .01727 L
.57613 .0155 L
.57628 .01582 L
.57642 .01765 L
.57673 .02178 L
.57738 .03108 L
.57961 .06806 L
.58455 .1673 L
.58701 .2166 L
.58931 .25648 L
.59044 .2727 L
.59152 .28548 L
.59211 .29134 L
.59276 .2967 L
.5933 .30035 L
.59361 .30205 L
.59389 .30338 L
.59417 .3045 L
.59447 .30544 L
.59473 .30605 L
.59488 .30631 L
.59502 .3065 L
.5951 .30658 L
.59518 .30665 L
.59533 .30672 L
.59548 .30672 L
.59562 .30666 L
.59577 .30654 L
.59586 .30645 L
.59594 .30634 L
.5961 .30606 L
.59627 .30568 L
.59659 .30474 L
.59695 .30337 L
.59759 .29997 L
.59822 .29556 L
.5988 .29053 L
.60008 .2765 L
.60128 .25984 L
.60352 .22134 L
.60817 .12531 L
.61053 .07729 L
Mistroke
.61178 .05409 L
.61312 .03172 L
.61344 .02685 L
.61378 .02175 L
.61394 .01949 L
.61411 .01714 L
.61425 .01517 L
.61441 .01638 L
.61456 .01839 L
.6147 .02018 L
.61502 .02409 L
.61559 .03067 L
.61678 .04235 L
.61789 .05063 L
.61845 .05392 L
.61899 .05644 L
.61929 .0576 L
.61961 .05867 L
.6199 .05948 L
.62017 .06009 L
.62047 .06062 L
.62063 .06084 L
.6208 .06102 L
.62089 .0611 L
.62098 .06116 L
.62107 .06121 L
.62115 .06125 L
.6213 .06129 L
.62139 .06129 L
.62147 .06129 L
.62162 .06125 L
.62177 .06118 L
.62192 .06107 L
.62209 .06092 L
.62236 .06058 L
.62267 .06009 L
.6233 .05868 L
.6239 .05692 L
.62503 .05269 L
.62755 .04039 L
.62975 .02894 L
.63101 .02307 L
.63218 .01837 L
.63277 .01637 L
.63306 .01548 L
.6332 .01507 L
.63333 .01472 L
.63348 .01511 L
.63364 .01551 L
.63398 .0163 L
Mistroke
.63457 .01744 L
.63488 .01791 L
.6352 .01832 L
.63555 .01867 L
.63571 .01879 L
.63588 .01889 L
.63604 .01897 L
.63618 .01902 L
.63633 .01906 L
.63646 .01908 L
.63654 .01908 L
.63662 .01908 L
.63677 .01906 L
.63693 .01902 L
.63702 .01899 L
.63711 .01896 L
.6374 .0188 L
.63767 .0186 L
.63829 .01794 L
.6389 .01707 L
.63954 .01591 L
.63983 .01533 L
.63998 .01501 L
.64006 .01483 L
.64014 .01477 L
.64028 .01508 L
.64044 .01543 L
.64071 .01606 L
.64177 .01869 L
.64401 .02417 L
.64462 .02543 L
.64528 .02657 L
.6456 .02703 L
.64589 .02741 L
.64616 .02769 L
.64645 .02793 L
.6466 .02803 L
.64676 .02812 L
.64685 .02816 L
.64693 .02818 L
.64709 .02822 L
.64724 .02824 L
.64739 .02824 L
.64754 .02821 L
.64768 .02817 L
.64784 .0281 L
.64799 .02802 L
.64832 .02774 L
.64865 .02735 L
.64901 .02681 L
Mistroke
.64962 .02554 L
.65027 .02376 L
.65143 .0194 L
.65171 .0181 L
.65202 .01659 L
.65216 .01586 L
.65231 .01508 L
.65244 .01505 L
.65258 .01583 L
.65323 .01966 L
.65381 .02348 L
.65603 .04022 L
.65858 .06142 L
.6609 .07858 L
.66205 .0849 L
.6627 .08754 L
.66301 .08853 L
.6633 .08928 L
.66356 .08978 L
.66369 .08999 L
.66383 .09017 L
.66398 .09031 L
.66413 .09041 L
.66428 .09044 L
.66441 .09043 L
.66456 .09036 L
.66471 .09024 L
.66484 .09009 L
.66498 .08988 L
.66529 .08921 L
.66559 .08835 L
.66615 .08601 L
.66675 .08246 L
.66732 .07808 L
.66785 .07317 L
.66912 .05737 L
.67033 .03724 L
.67093 .0255 L
.67107 .02252 L
.67122 .0193 L
.67135 .01649 L
.67149 .01608 L
.67157 .01785 L
.67165 .01976 L
.6718 .02327 L
.67214 .0314 L
.67272 .04646 L
.67494 .11285 L
.67993 .29954 L
.68243 .39703 L
Mistroke
.68473 .47859 L
.68698 .54252 L
.68811 .56715 L
.68872 .57794 L
.68936 .58733 L
.68994 .59404 L
.69025 .59687 L
.69058 .59933 L
.69088 .60108 L
.69115 .60224 L
.69129 .60266 L
.69143 .60299 L
.69157 .6032 L
.69169 .60331 L
.69184 .60332 L
.69199 .6032 L
.69214 .60297 L
.69227 .60265 L
.69243 .60214 L
.6926 .60144 L
.69291 .59974 L
.69324 .59738 L
.69359 .59423 L
.69421 .58691 L
.69486 .57703 L
.69545 .56599 L
.6968 .53447 L
.69923 .45659 L
.704 .25311 L
.7064 .14364 L
.70745 .09789 L
.70859 .05084 L
.70889 .03878 L
.70922 .02629 L
.70935 .02125 L
.70949 .01589 L
.70965 .01934 L
.7098 .02471 L
.71094 .06373 L
.71215 .09924 L
.71347 .13083 L
.71408 .14272 L
.71472 .1535 L
.71528 .16121 L
.71589 .16788 L
.71625 .17101 L
.71658 .17335 L
.71689 .17511 L
.71705 .17584 L
.71722 .17649 L
Mistroke
.71738 .17695 L
.71752 .17729 L
.71767 .17753 L
.7178 .17767 L
.71796 .17774 L
.71811 .1777 L
.71818 .17765 L
.71827 .17756 L
.71835 .17743 L
.71844 .17728 L
.71858 .17696 L
.71873 .17652 L
.719 .17549 L
.71933 .17387 L
.71962 .17204 L
.72026 .1669 L
.72087 .16068 L
.72194 .14679 L
.7231 .12808 L
.72545 .0821 L
.72669 .0553 L
.72738 .04034 L
.72803 .02623 L
.72833 .01989 L
.72841 .01807 L
.72849 .01637 L
.72864 .01623 L
.72873 .01805 L
.72881 .01972 L
.72899 .02346 L
.72931 .03006 L
.73048 .05289 L
.73167 .0736 L
.73278 .09015 L
.73397 .10444 L
.73505 .11404 L
.73567 .11798 L
.73626 .12066 L
.73658 .1217 L
.73687 .12238 L
.73703 .12264 L
.73712 .12275 L
.7372 .12283 L
.73728 .1229 L
.73738 .12295 L
.73746 .12297 L
.73754 .12297 L
.73769 .12292 L
.73778 .12286 L
.73786 .12279 L
Mistroke
.738 .12261 L
.73815 .12236 L
.73841 .12178 L
.7387 .12091 L
.73933 .11819 L
.73993 .11468 L
.741 .10618 L
.74214 .09427 L
.74453 .06251 L
.74579 .04338 L
.74648 .03259 L
.74681 .02728 L
.74713 .02241 L
.74743 .01763 L
.74759 .01524 L
.74767 .01554 L
.74775 .0168 L
.74843 .02716 L
.74962 .04434 L
.75192 .07275 L
.75319 .08443 L
.75381 .08897 L
.75439 .09242 L
.75491 .09492 L
.75546 .09689 L
.75575 .09763 L
.75601 .09816 L
.75617 .09839 L
.75631 .09855 L
.75639 .09862 L
.75647 .09868 L
.75663 .09875 L
.7567 .09876 L
.75679 .09876 L
.75693 .09872 L
.75709 .09862 L
.75718 .09853 L
.75727 .09844 L
.75756 .098 L
.75772 .09766 L
.75787 .09731 L
.75845 .09548 L
.759 .09309 L
.76021 .0857 L
.76153 .07473 L
.76386 .04958 L
.76511 .03438 L
.76576 .02618 L
.76611 .02168 L
.76629 .0195 L
Mistroke
.76644 .01751 L
.7666 .01561 L
.76674 .01561 L
.76689 .0175 L
.76705 .01954 L
.76772 .02771 L
.76889 .04138 L
.77118 .06414 L
.77232 .07271 L
.77298 .07666 L
.77358 .0796 L
.77421 .08199 L
.77456 .08298 L
.77489 .08371 L
.77503 .08397 L
.77519 .0842 L
.77533 .08436 L
.77547 .0845 L
.77556 .08456 L
.77565 .0846 L
.77573 .08463 L
.77581 .08465 L
.77595 .08465 L
.77611 .0846 L
.77627 .08451 L
.77642 .08438 L
.77658 .0842 L
.77675 .08395 L
.77703 .08341 L
.77735 .08264 L
.77793 .08076 L
.77847 .07847 L
.77969 .07161 L
.78099 .06187 L
.78337 .03959 L
.78462 .02641 L
.78498 .02254 L
.78532 .01889 L
.78547 .0173 L
.78563 .01561 L
.78571 .01474 L
.7858 .01566 L
.78596 .01735 L
.78844 .0423 L
.79075 .06075 L
.79138 .06465 L
.79197 .06782 L
.79252 .07023 L
.7931 .07229 L
.79339 .07314 L
Mistroke
.79372 .07391 L
.79402 .07446 L
.7943 .07485 L
.79446 .07501 L
.79455 .07507 L
.79463 .07513 L
.79478 .07519 L
.79493 .07523 L
.79502 .07523 L
.79511 .07522 L
.79526 .07517 L
.79535 .07512 L
.79543 .07507 L
.79562 .07491 L
.79577 .07473 L
.79591 .07453 L
.79618 .07407 L
.79678 .07262 L
.79731 .07091 L
.79788 .06858 L
.79917 .06167 L
.80036 .05348 L
.80263 .03453 L
.80382 .02351 L
.80443 .01787 L
.80459 .01633 L
.80468 .01548 L
.80477 .01476 L
.80485 .0155 L
.80493 .01631 L
.80508 .01773 L
.80643 .02999 L
.80767 .04045 L
.80882 .04913 L
.8101 .05711 L
.81069 .06016 L
.81133 .06295 L
.81188 .0649 L
.81249 .06656 L
.81282 .06725 L
.81313 .06775 L
.8133 .06796 L
.81346 .06812 L
.81355 .06819 L
.81364 .06826 L
.81373 .06831 L
.81381 .06834 L
.81396 .06838 L
.81403 .06839 L
.81412 .06839 L
Mistroke
.8142 .06838 L
.81428 .06836 L
.81444 .0683 L
.81458 .0682 L
.81472 .06809 L
.81502 .06774 L
.81534 .06723 L
.81564 .06663 L
.8163 .06485 L
.81688 .06279 L
.8175 .06015 L
.81975 .04701 L
.82098 .03794 L
.82215 .02859 L
.8232 .01986 L
.82348 .01745 L
.82364 .01612 L
.82379 .01489 L
.82391 .01559 L
.82405 .01672 L
.82434 .01911 L
.82669 .03766 L
.828 .04645 L
.82922 .0532 L
.83044 .05835 L
.83108 .06034 L
.83141 .06116 L
.83177 .0619 L
.83211 .06244 L
.83226 .06263 L
.83242 .0628 L
.83256 .06293 L
.83272 .06303 L
.8328 .06308 L
.83288 .06311 L
.83304 .06315 L
.83318 .06315 L
.83332 .06314 L
.83347 .06309 L
.83363 .063 L
.83376 .06291 L
.83389 .06279 L
.83419 .06245 L
.83448 .062 L
.83475 .06148 L
.83537 .05996 L
.83598 .05803 L
.83662 .05552 L
.83885 .04363 L
.84125 .02691 L
Mistroke
.84191 .02195 L
.84227 .01921 L
.84261 .01664 L
.84275 .01551 L
.84289 .01498 L
.84297 .01557 L
.84305 .01621 L
.8432 .01732 L
.84385 .02225 L
.84638 .03969 L
.84748 .04598 L
.84867 .05156 L
.84931 .05395 L
.8499 .05576 L
.85046 .05712 L
.85077 .05772 L
.85105 .05816 L
.85135 .05853 L
.85152 .05869 L
.85167 .0588 L
.85182 .05889 L
.85195 .05894 L
.8521 .05897 L
.85226 .05898 L
.85241 .05896 L
.8525 .05893 L
.85258 .0589 L
.85273 .05882 L
.85289 .05871 L
.85322 .05838 L
.85358 .05787 L
.85422 .05661 L
.85482 .05499 L
.85595 .05095 L
.85716 .04526 L
.85848 .03781 L
.86088 .02192 L
.86146 .01784 L
.86163 .01666 L
.86179 .01554 L
.86193 .01489 L
.86209 .01598 L
.86277 .02075 L
.86341 .02511 L
.86575 .03947 L
.86699 .04563 L
.86764 .04834 L
.86833 .05077 L
.86893 .05252 L
.86925 .05329 L
Mistroke
.8696 .05399 L
.86991 .05452 L
.8702 .05491 L
.87034 .05507 L
.87049 .05521 L
.87062 .05532 L
.87076 .05541 L
.87091 .05548 L
.87104 .05553 L
.8712 .05556 L
.87134 .05556 L
.87149 .05554 L
.87158 .05551 L
.87166 .05548 L
.8718 .05541 L
.87196 .05531 L
.87225 .05504 L
.87253 .0547 L
.87306 .05383 L
.87362 .05258 L
.87423 .05085 L
.87548 .04627 L
.87771 .03504 L
.87891 .02779 L
.88006 .02051 L
.88037 .01853 L
.88069 .01641 L
.88086 .01531 L
.88096 .01475 L
.88105 .01534 L
.88138 .01747 L
.88258 .02509 L
.88481 .03775 L
.88607 .04357 L
.88669 .04594 L
.88725 .04782 L
.88781 .0494 L
.88842 .05078 L
.88875 .05139 L
.88906 .05184 L
.88935 .05219 L
.88952 .05234 L
.88966 .05246 L
.88982 .05255 L
.88997 .05262 L
.89012 .05267 L
.89021 .05268 L
.89029 .05269 L
.89044 .05269 L
.89057 .05267 L
Mistroke
.89073 .05262 L
.89088 .05255 L
.89104 .05244 L
.89121 .05231 L
.89152 .05199 L
.89185 .05153 L
.89221 .05092 L
.89284 .04953 L
.89344 .04787 L
.89457 .04393 L
.89709 .03183 L
.89826 .02518 L
.8989 .02138 L
.8995 .01776 L
.89974 .01626 L
.89988 .01544 L
.90001 .01475 L
.90014 .01558 L
.90029 .01648 L
.90055 .01806 L
.90172 .02493 L
.90398 .03683 L
.90518 .04189 L
.90644 .04605 L
.90708 .04765 L
.90741 .04835 L
.90778 .04898 L
.90811 .04945 L
.90842 .04978 L
.90856 .04991 L
.90872 .05003 L
.90887 .05011 L
.90901 .05018 L
.90915 .05022 L
.9093 .05024 L
.90944 .05025 L
.90957 .05023 L
.90972 .0502 L
.90988 .05014 L
.91004 .05005 L
.91019 .04995 L
.91051 .04966 L
.9108 .04931 L
.91145 .04825 L
.91203 .04698 L
.91265 .04531 L
.91376 .04155 L
.91626 .03011 L
.9174 .024 L
.91803 .0205 L
Mistroke
.91834 .01876 L
.91862 .01713 L
.91889 .01561 L
.91904 .01477 L
.91917 .01543 L
.91978 .01883 L
.92083 .02464 L
.92206 .03095 L
.92335 .03684 L
.92455 .04136 L
.92513 .0432 L
.92566 .04463 L
.92618 .04579 L
.92674 .04679 L
.92704 .04722 L
.92733 .04755 L
.9276 .04779 L
.92775 .0479 L
.92788 .04798 L
.92802 .04804 L
.92817 .04809 L
.92832 .04812 L
.9284 .04813 L
.92848 .04813 L
.92862 .04812 L
.92875 .04809 L
.9289 .04804 L
.92904 .04798 L
.9292 .04788 L
.92936 .04776 L
.92965 .04748 L
.92997 .0471 L
.93032 .04658 L
.93095 .04537 L
.93154 .04392 L
.93266 .04047 L
.93518 .02984 L
.93634 .024 L
.93698 .02066 L
.93758 .01748 L
.93785 .01602 L
.93799 .01528 L
.93814 .01495 L
.93822 .01538 L
.9383 .01583 L
.93846 .01664 L
.93874 .01818 L
.9398 .02367 L
.9422 .03478 L
.94355 .03971 L
Mistroke
.94419 .04163 L
.9448 .04314 L
.94538 .04433 L
.94591 .04517 L
.94619 .04553 L
.9465 .04583 L
.94667 .04597 L
.94682 .04607 L
.94697 .04615 L
.94713 .04621 L
.94721 .04624 L
.9473 .04626 L
.94745 .04627 L
.94754 .04628 L
.94762 .04627 L
.94771 .04626 L
.9478 .04624 L
.94788 .04622 L
.94797 .04619 L
.94813 .04611 L
.94829 .04602 L
.94843 .04591 L
.949 .04533 L
.94929 .04493 L
.94961 .04441 L
.95083 .0417 L
.95194 .03829 L
.95446 .02797 L
.95556 .02267 L
.95617 .01965 L
.95674 .01676 L
.9569 .01596 L
.95706 .01511 L
.95715 .01476 L
.95725 .01525 L
.95742 .0161 L
.95803 .01919 L
.95924 .02505 L
.96054 .03088 L
.96178 .0357 L
.96298 .03952 L
.96357 .04103 L
.9641 .04218 L
.96462 .0431 L
.96518 .04386 L
.96549 .04417 L
.96563 .04428 L
.96578 .04438 L
.96591 .04446 L
.96605 .04453 L
Mistroke
.9662 .04458 L
.96634 .04461 L
.96642 .04463 L
.9665 .04463 L
.96665 .04463 L
.96674 .04462 L
.96682 .04461 L
.9669 .04459 L
.96699 .04456 L
.96715 .0445 L
.96732 .04441 L
.96762 .04419 L
.9679 .04391 L
.96817 .04359 L
.96878 .04267 L
.96939 .04146 L
.97005 .03986 L
.97125 .03621 L
.97349 .02735 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<oooool3o`0002kooooo1Ol0000]ooooo`;o0000;_ooool5o`00033ooooo0ol0000Roooo
o`00=?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo0000;_ooool01?l0003oooooooooool0000aooooo`03o`000?oooooooooo027ooooo000[
ooooo`Go000000?oooooo`000?l000000ol0000Xooooo`Go00000oooool00ol0003oooooooooo`0/
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0;_ooool5o`0002;ooooo000a
ooooo`04o`000?ooooooooooo`0003;ooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00008oooool003;ooooo
00?o0000ooooool00000;oooool01Ol0003ooooooooooooooooo000002cooooo00Co0000oooooooo
oooo0000;Oooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooool000008oooool0
03?ooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;?ooool01?l0003oooooooooool0
000]ooooo`05o`000?ooooooooooooooool00000<?ooool2o`0002?ooooo000dooooo`03o`000?oo
oooooooo02kooooo0ol0000^ooooo`;o0000;oooool3o`0003;ooooo00?o0000ooooooooool08Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017oooooool0
000=o`0000?ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00Oooool0
00Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool3
o`0000Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo0_l00?l3ooooo`;o003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00ol00?l4ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool00_ooool4o`00o`03ooooool00?oo003o00Cooooo00?o003oooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Ko003oooooool00?oo003ooooo
ool00?l4ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool00_ooool00ol00?oooooo
o`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`02ooooo`;o003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`?o00000oooool000Wooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`;o003o0oooool2o`00o`?ooooo
0_l00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00ol00?l4ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool00_ooool7o`00o`?ooooo0_l00?l4ooooo`03o`00
0?oooooooooo00;ooooo00Co003ooooooooooooooooo0_l00?l00ooooooo003oo`00o`02o`00o`Co
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`02ooooo`?o003o0_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool00_ooool2o`00o`Co
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`;o003o0oooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01?ooool01ol00?oooooooooooooooooo003oooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool2
o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l4ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`02ooooo`?o003o0_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooooooool3o`00o`?ooooo0_l00?l4ooooo`03o`000?oooooooooo00;ooooo00Co
003ooooooooooooooooo0ol00?l4ooooo`05o`00ooooooooooooooooool00?l02Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Co003oooooool00?oo003o0oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00;ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool00ol00?ooooooooooo`04
ooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`04oooo
o`07o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00;ooooo0_l0
0?l4ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l0
0?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`02ooooo`?o003o0oooool01Ol00?oooooooooooooooooo003o00Wooooo0_l00?l3ooooo`03o`00
oooooooooooo00?ooooo00Co003ooooooooooooooooo0_l00?l4ooooo`03o`000?oooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`06ooooo`05o`00ooooooooooooooooool00?l02Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo0_l00?l00ooooooo003oooooo`02ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool00_ooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0ooo
ool2o`00o`Cooooo00Co003ooooooooooooooooo0_l00?l3ooooo`;o003o1?ooool00ol00?oooooo
ooooo`02ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`04ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00;o
oooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`03ooooo`;o003o0oooool2o`00o`?o
oooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`Co
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`07ooooo`05o`00oooooooooooooooo
ool00?l01_ooool01Ol00?oooooooooooooooooo003o00Wooooo0_l00?l2ooooo`03o`00oooooooo
oooo00Cooooo00Co003ooooooooooooooooo0_l00?l4ooooo`04o`000?ooooooooooooooo`;o003o
0oooool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l02Oooool01Ol00?oo
oooooooooooooooo003o00Kooooo00Go003oooooooooooooooooo`00o`09ooooo`03o`00oooooooo
oooo00;ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool0
0ol00?ooooooo`00o`02ooooo`;o003o1?ooool00ol00?ooooooooooo`02ooooo`;o003o0_ooool0
0ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo0_l00?l3ooooo`;o003o0oooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
00Gooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`03o`00oooooooo003o00;ooooo00?o
003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo0_l0
0?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l0
0?l3ooooo`;o003o1?ooool00ol00?ooooooooooo`07ooooo`05o`00ooooooooooooooooool00?l0
1_ooool01?l00?ooooooooooooooool2o`00o`Sooooo0_l00?l2ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool00_l00?l4ooooo`04o`000?ooooooooooooooo`;o003o0_ooool00ol0
0?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l02Oooool01Ol00?oooooooooooooo
oooo003o00Kooooo00Go003oooooooooooooooooo`00o`09ooooo`03o`00oooooooooooo00;ooooo
0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool00ol00?oooooo
o`00o`02ooooo`03o`00oooooooo003o00;ooooo00?o003oooooool00?l00_ooool00ol00?oooooo
o`00o`02ooooo`03o`00oooooooo003o00;ooooo00?o003oooooool00?l00oooool2o`00o`;ooooo
00Ko003ooooooooooooo003oooooool00?l7ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Gooooo00?o003oooooool00?l00_ooool01_l00?ooooooooooool00?oooooo
o`00o`;ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo
003o00;ooooo00?o003oooooool00?l00oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2
o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`Cooooo00?o003oooooooooool01oooool0
1Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00_l00?l8ooooo`;o003o0_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;o003o1?ooool01?l0003ooooooooo
ooooool2o`00o`;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02o`00o`Wooooo
0_l00?l2ooooo`03o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`09ooooo`03
o`00oooooooooooo00;ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`03
o`00oooooooo003o00;ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03
o`00oooooooo003o00;ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03
o`00oooooooo003o00;ooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`03o`00oooooooo
003o00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01_ooool2o`00
o`?ooooo0_l00?l3ooooo`05o`00oooooooo003oooooool00?l00_ooool01_l00?ooooooooooool0
0?ooooooo`00o`;ooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?o
oooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`Co
oooo00?o003oooooooooool01oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003ooooo
ooooool00_l00?l8ooooo`;o003o00?oooooo`00ooooool01oooool00ol00?ooooooooooo`02o`00
o`Cooooo00Co0000oooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00Kooooo00Co003o
ooooool00?oo003o2Oooool2o`00o`;ooooo00?o003oooooooooool01?ooool01?l00?oooooooooo
ooooool2o`00o`Sooooo00?o003oooooooooool00_ooool2o`00o`?ooooo0_l00?l3ooooo`;o003o
0oooool2o`00o`?ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03o`00
oooooooo003o00;ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`06o`00
ooooooooooooo`00oooooooo003o0_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o
00;ooooo0ol00?l7ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001oooool2o`00o`?o
oooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo00?o003oooooool00?l00_ooool00ol00?oo
ooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`03oooo
o`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`Cooooo00?o003ooooo
ooooool01oooool01Ol00?oooooooooooooooooo003o00Oooooo00Go003oooooool00?ooooooo`00
o`08ooooo`;o003o00?oooooo`00ooooool01oooool00ol00?ooooooooooo`02o`00o`Cooooo00Co
0000oooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00Kooooo00Co003oooooool00?oo
003o2?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooo
oooooooo0_l00?l8ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o0oooool2o`00
o`?ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooool00?l00_ooool01_l00?ooooooooooool00?ooooooo`00o`;ooooo0ol0
0?l2ooooo`?o003o0_ooool2o`00o`Cooooo00?o003oooooooooool01Oooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo013ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo00?o003o
ooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l00_oo
ool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo0_l00?l3ooooo`;o003o0ooo
ool2o`00o`Cooooo00?o003oooooooooool01oooool01Ol00?oooooooooooooooooo003o00Oooooo
00Go003oooooool00?ooooooo`00o`08ooooo`;o003o00?oooooo`00ooooool01oooool00ol00?oo
ooooooooo`02o`00o`Cooooo00Wo0000ooooooooooooooooo`00oooooooo003oooooool00?l02?oo
ool01?l00?ooooooo`00ool00?l8ooooo`05o`00oooooooo003oooooool00?l01oooool01?l00?oo
ooooooooooooool2o`00o`Sooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3oooo
o`;o003o0oooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00;ooooo00Go003ooooo
ool00?ooooooo`00o`03ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o4_ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Jooooo`;o003o0oooool2o`00
o`?ooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o
00;ooooo00Go003oooooool00?ooooooo`00o`03ooooo`;o003o0oooool00ol00?ooooooo`00o`02
ooooo`;o003o0oooool2o`00o`Wooooo0_l00?l2ooooo`03o`00oooooooooooo00Gooooo00Go003o
ooooool00?ooooooo`00o`08ooooo`04o`00oooooooo003oo`00o`Wooooo0_l00?l00ooooooo003o
ooooo`03ooooo`09o`000?ooooooooooooooool00?ooooooo`00oooooooo003o00Sooooo00Go003o
ooooool00?ooooooo`00o`07ooooo`05o`00oooooooo003oooooool00?l02?ooool00ol00?oooooo
ooooo`02o`00o`Sooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l2ooooo`04o`00
ooooooooooooo`00o`;ooooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o
00;ooooo0ol00?l3ooooo`;o003o0oooool2o`00oacooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool07oooool2o`00o`?ooooo0_l00?l3ooooo`03o`00oooooooo003o00;o
oooo00?o003oooooool00?l00_ooool01Ol00?ooooooo`00oooooooo003o00?ooooo0_l00?l3oooo
o`03o`00oooooooo003o00;ooooo0_l00?l3ooooo`;o003o2Oooool2o`00o`;ooooo00?o003ooooo
ooooool01_ooool2o`00o`03ooooool00?oooooo00Oooooo00Co003oooooool00?oo003o2Oooool2
o`00o`03ooooool00?oooooo00?ooooo00Ko0000ooooooooooooooooo`00ooooool2o`00o`[ooooo
00Co003ooooooooooooo003o1oooool01Ol00?ooooooo`00oooooooo003o00Sooooo00?o003ooooo
ooooool00_l00?l8ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l3ooooo`05o`00oooooooo003o
ooooool00?l00_ooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o0oooool2o`00o`?o
oooo0_l00?l3ooooo`;o003o8Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`0Uooooo`04o`00ooooooooooooooooo`;o003o0oooool00ol00?ooooooo`00o`02ooooo`03
o`00oooooooo003o00;ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooo003o00;o
oooo0_l00?l3ooooo`;o003o2?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00Ko
oooo0_l00?l00ooooooo003oooooo`07ooooo`03o`00oooooooooooo00[ooooo0_l00?l00ooooooo
003oooooo`03ooooo`06o`000?ooooooooooooooool00?oooooo0_l00?l=ooooo`03o`00oooooooo
oooo00Gooooo00Co003oooooool00?oo003o2Oooool00ol00?ooooooooooo`02o`00o`Sooooo0_l0
0?l3ooooo`;o003o0oooool00ol00?ooooooo`00o`02ooooo`05o`00oooooooo003oooooool00?l0
0_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo0_l00?l3ooooo`;o003o
9_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Zooooo`07o`00oooo
ooooooooooooool00?ooooooo`00o`02ooooo`03o`00oooooooo003o00;ooooo00Go003oooooool0
0?ooooooo`00o`03ooooo`03o`00oooooooo003o00;ooooo0_l00?l3ooooo`;o003o2?ooool01Ol0
0?ooooooo`00oooooooo003o00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`0@ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`02o`00o`Sooooo0_l0
0?l3ooooo`;o003o0oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l0
0_ooool00ol00?ooooooo`00o`03ooooo`;o003o0oooool2o`00ob_ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0;oooool01ol00?oooooooooooooooooo003oooooool0
0?l00_ooool00ol00?ooooooo`00o`02ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool2
o`00o`?ooooo0_l00?l8ooooo`05o`00oooooooo003oooooool00?l03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool01Ol0003ooooooooo
oooooooo003o013ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0:ooooo`05o`00
oooooooo003oooooool00?l02?ooool2o`00o`?ooooo0_l00?l3ooooo`05o`00oooooooo003ooooo
ool00?l00_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo0_l00?l`oooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o0000=?ooool3o`00o`;ooooo00?o003oooooool0
0?l00_ooool01_l00?ooooooooooool00?ooooooo`00o`;ooooo00?o003oooooool00?l00_ooool2
o`00o`Sooooo00Go003oooooool00?ooooooo`00o`0<ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`05o`000?ooooooooooooooool00?l0
4?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00[ooooo00Go003oooooool00?oo
ooooo`00o`08ooooo`;o003o0oooool2o`00o`?ooooo00Go003oooooool00?ooooooo`00o`02oooo
o`03o`00oooooooo003o00?ooooo0_l00?ldooooo`;o00000oooool0017ooooo00?o0000oooooooo
ool0=?ooool01ol00?oooooooooooooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`02
ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool2o`00o`Sooooo00Go003oooooool00?oo
ooooo`00o`0<ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`02ooooo`04o`000?ooooooooooo`00oa7ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0:ooooo`05o`00oooooooo003oooooool00?l02?ooool2o`00o`?ooooo0_l00?l3
ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`03ooooo`;o003o=Ooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0hooooo`03o`00oooooooo
003o00;ooooo00?o003oooooool00?l00_ooool01_l00?ooooooooooool00?ooooooo`00o`;ooooo
0_l00?l8ooooo`05o`00oooooooo003oooooool00?l03?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool01?l0003oooooooooool00?lAoooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool01Ol00?ooooooo`00oooooooo
003o00Sooooo0_l00?l3ooooo`;o003o0oooool01Ol00?ooooooo`00oooooooo003o00;ooooo00?o
003oooooool00?l0>_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0i
ooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`06o`00ooooooooooooo`00oooooooo003o
0_ooool2o`00o`Sooooo00Co003oooooool00?oo003o3Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool01?l0003oooooooooool00?lAoooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool01Ol00?ooooooo`00oooooooo
003o00Sooooo0_l00?l3ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00
o`03ooooo`03o`00oooooooooooo03Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0?Oooool00ol00?ooooooo`00o`02ooooo`06o`00ooooooooooooo`00oooooooo003o
0_ooool2o`00o`Sooooo00Co003oooooool00?oo003o3Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool01?l0003oooooooooool00?lAoooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool2o`00o`03ooooool00?oooooo
00Oooooo0_l00?l3ooooo`05o`00oooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`0o
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo03kooooo0_l00?l2oooo
o`03o`00oooooooo003o00;ooooo00?o003oooooooooool00_l00?l8ooooo`04o`00oooooooooooo
o`00o`kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo00;ooooo00Co0000oooooooooooo003o4Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00_ooooo0_l00?l00ooooooo003oooooo`07ooooo`;o003o0oooool01Ol00?ooooooo`00
oooooooo003o00;ooooo00?o003oooooool00?l0?oooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0nooooo`;o003o0_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooo
oooooooo00;o003o2?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`04o`000?ooooooooooo`00oa7ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo
0_l00?l3ooooo`05o`00oooooooo003oooooool00?l00_ooool3o`00ocoooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0?_ooool2o`00o`;ooooo00?o003oooooool00?l0
0_ooool00ol00?ooooooooooo`02o`00o`Sooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00oooooo00Go003oooooooooooooooooo`000002ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Kooooo0_l00?l3ooooo`05o`00oooooooo003oooooool00?l00oooool00ol0
0?ooooooooooo`0nooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000@oooool00ol00?oo
ooooo`00o`02ooooo`03o`00oooooooooooo00;o003o2?ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool01Ol00?oooooooooooooooooo0000
00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool01_ooool2o`00o`?ooooo00Go003oooooool00?ooooooo`00o`13
ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0@_ooool00ol00?ooooooo`00o`02oooo
o`03o`00oooooooooooo00;o003o2?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03oooool01Ol00?oooooooooooooooooo000000;ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01_ooool2o`00o`?ooooo00Go003oooooool00?ooooooo`00o`14ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo04;ooooo00?o003oooooool00?l00_ooool0
0ol00?ooooooooooo`02o`00o`Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00oooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Kooooo0_l00?l2ooooo`06o`00ooooooooooooo`00oooooooo003oA?ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`13ooooo`;o003o0_ooool00ol00?oooooo
ooooo`02o`00o`Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00oooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Ko
oooo0_l00?l2ooooo`06o`00ooooooooooooo`00oooooooo003oA?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`13ooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00
o`Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Kooooo0_l00?l2
ooooo`03o`00oooooooooooo00;o003oAOooool00ol0003oooooooooo`01ooooo`002?ooool5o`00
00Cooooo00?o0000ooooooooool0@oooool2o`00o`;ooooo00?o003oooooooooool00_l00?l8oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`05o`00ooooooooooooooooool000000_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06ooooo`;o003o0_ooool0
1Ol00?oooooooooooooooooo003o04Gooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`13ooooo`05o`00ooooooooooooooooool00?l0
0_ooool2o`00o`Sooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo013ooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Ko
oooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l0AOooool00ol0003oooooooooo`01oooo
o`002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Oooooo00?o003ooooooooo
ool00_l00?l8ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0@ooooo`05o`00ooooooooooooooooool000000_ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06oooo
o`;o003o0_ooool00ol00?ooooooooooo`17ooooo`03o`000?oooooooooo007ooooo000;ooooo`03
o`000?oooooooooo00?ooooo0ol00017ooooo`03o`00oooooooooooo00;o003o2?ooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool01Ol00?oo
oooooooooooooooo000000;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool01_ooool2o`00o`;ooooo00?o003ooooo
ooooool0AOooool3o`0000?ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`17ooooo`03o`00oooooooooooo00;o003o2?ooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool01Ol00?oooooooooooooooooo
000000;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool01_ooool2o`00o`;ooooo00?o003oooooooooool0Aoooool0
0ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0Aoooool00ol00?ooooooooooo`02o`00o`Sooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00Go003oooooooooooooooooo`00
0002ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo00Kooooo00Go003oooooool00?ooooooo`00o`19ooooo`03o`00
0?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`17ooooo`03o`00oooo
oooooooo00;o003o2?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04?ooool01Ol00?oooooooooooooooooo000000;ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
1_ooool01Ol00?ooooooo`00oooooooo003o04Wooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0Aoooool00ol00?ooooooooooo`02o`00o`Sooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00Go003ooooooooooooo
ooooo`000002ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00Kooooo00Go003oooooool00?ooooooo`00o`19oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04Sooooo00Co003oooooool0
0?oo003o2?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool04?ooool01Ol00?oooooooooooooooooo000000;ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01_ooool0
1Ol00?ooooooo`00oooooooo003o04Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0B?ooool01?l00?ooooooo`00ool00?l8ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`05o`00ooooooooooooooooool00000
0_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`06ooooo`05o`00oooooooo003oooooool00?l0BOooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`18ooooo`;o003o00?oooooo`00ooooool0
1oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
4?ooool01Ol00?oooooooooooooooooo000000;ooooo00?o003oooooooooool04?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01_ooool01?l00?oo
ooooo`00ool00?m:ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000BOooool2o`00o`03
ooooool00?oooooo00Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo013ooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00Gooooo00Co003oooooool00?oo003oBOooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo
04Sooooo0_l00?l00ooooooo003oooooo`07ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0@ooooo`05o`00ooooooooooooooooool000000_ooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`05ooooo`04o`00oooooooo003oo`00od[ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0B?ooool2o`00o`03ooooool00?oooooo00Oooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00Go003o
ooooooooooooooooo`000002ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Gooooo00Co003oooooool00?oo003o
B_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`18ooooo`;o003o00?o
ooooo`00ooooool01oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04Oooool01_l00?ooooooooooool0003oooooo`00oa?ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Gooooo00Co003oooooool0
0?oo003oB_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`18ooooo`;o
003o0_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0Aooooo`06o`00ooooooooooooo`000?oooooo003o4oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01Oooool0
1?l00?ooooooo`00ool00?m:ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo04cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool04Oooool01_l00?ooooooooooool0003oooooo`00oa?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool0Boooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1<ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo017ooooo00Ko003ooooooooooooo0000ooooool00?lCooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo04_ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo017ooooo00Ko003ooooooooooooo0000ooooool00?lCooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
04[ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017o
oooo00Ko003ooooooooooooo0000ooooool00?lCooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo04_ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo013ooooo00Go003oooooooooooooooooo`00o`0Dooooo`06o`00oooooooo
ooooo`000?oooooo003o5?ooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`1;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo04cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0@ooooo`05o`00
ooooooooooooooooool00?l05?ooool01_l00?ooooooooooool0003oooooo`00oaCooooo00Go003o
ooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0C?oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01Cooooo00Ko
003ooooooooooooo0000ooooool00?lDooooo`05o`00ooooooooooooooooool00?l04oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo017o
oooo00Go003oooooooooooooooooo`00o`0Dooooo`06o`00ooooooooooooo`000?oooooo003o5?oo
ool01Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l0
5?ooool01_l00?ooooooooooool0003oooooo`00oaCooooo00Go003oooooooooooooooooo`00o`0C
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool04Oooool01Ol00?oooooooooooooooooo003o01Cooooo00Ko003ooooooooooooo0000oooo
ool00?lDooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001=ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01Co
oooo00Ko003ooooooooooooo0000ooooool00?lDooooo`05o`00ooooooooooooooooool00?l04ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04_ooooo0_l00003ooooo`004Oooool0
0ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04Oooool0
1Ol00?oooooooooooooooooo003o01Gooooo00Co003oooooool0003o003o5Oooool01Ol00?oooooo
oooooooooooo003o01?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1<ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l05Oooool01?l00?oo
ooooo`000?l00?lEooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo017ooooo00Go003ooooo
ooooooooooooo`00o`0Eooooo`04o`00oooooooo0000o`00oaGooooo00Go003ooooooooooooooooo
o`00o`0Cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0C?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01Gooooo00Co003oooooool0003o
003o5Oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Aooooo`05o`00oooooooooooooooo
ool00?l05Oooool01?l00?ooooooo`000?l00?lEooooo`05o`00ooooooooooooooooool00?l04ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Ooo
ool000[ooooo0ol00004ooooo`03o`000?oooooooooo04cooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l05Oooool01?l00?ooooooo`00
0?l00?lEooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool000_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
4_ooool01?l00?ooooooooooool00?lEooooo`04o`00oooooooo0000o`00oaGooooo00Go003ooooo
ooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0C?ooool0
0ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo0ol0001<ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool04_ooool01?l00?ooooooooooool00?lEooooo`04o`00oooooooo
0000o`00oaGooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool0B_ooool3o`0000?ooooo0008ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01;ooooo
00Co003ooooooooooooo003o5Oooool01?l00?ooooooo`000?l00?lEooooo`05o`00oooooooooooo
ooooool00?l04oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo04cooooo00?o0000
ooooooooool00Oooool000Wooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`1<oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool01?l00?ooooooooooool00?lE
ooooo`04o`00oooooooo0000o`00oaGooooo00Go003oooooooooooooooooo`00o`0Dooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`01ooooo`002_oo
ool2o`0000Gooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo01;ooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooo`000?l00?lEooooo`05
o`00ooooooooooooooooool00?l05?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
04cooooo00?o0000ooooooooool00Oooool000_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol00?oo
ooooo`00o`0Fooooo`04o`00oooooooo0000o`00oaGooooo00Go003oooooooooooooooooo`00o`0D
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooo`00o`0Fooooo`04o`00oooooooo0000o`00oaKooooo00Co003o
oooooooooooo003o5?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04cooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooool00?l05_ooool01?l00?ooooooo`000?l0
0?lFooooo`03o`00oooooooo003o01Gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo003o01Kooooo00Co003o
ooooool0003o003o5_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool0C?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0004gooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo003o01Kooooo00Co003o
ooooool0003o003o5_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool0Boooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo003o01Oooooo00?o003o
o`000?l00?l05_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0C?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1<oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol00?ooooooo`00o`0Goooo
o`03o`00ool0003o003o01Kooooo00?o003oooooool00?l05Oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01;ooooo00?o003oooooool0
0?l05oooool00ol00?oo0000o`00o`0Fooooo`03o`00oooooooo003o01Gooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo04cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooo003o01Oooooo00?o003oo`000?l00?l05_ooool00ol00?ooooooo`00o`0Eooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool0C?ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04ooo
ool2o`00oaOooooo0_l00?lGooooo`03o`00oooooooo003o01Gooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo04cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Cooooo`;o003o5oooool2
o`00oaOooooo0ol00?lEooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0C?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1<ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool04oooool2o`00oaOooooo0_l00?lHooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo
007ooooo000Aooooo`;o0000COooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01?o
oooo00?o003oooooooooool05oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo01Co
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1;ooooo`;o00000oooool0017ooooo
00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo
00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04cooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo00?o0000
ooooooooool0;Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04cooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02gooooo00?o0000oooooooo
ool0;Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo04cooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo04cooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001=ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool0Boooool2o`0000?ooooo000Aooooo`03o`000?oooooo
oooo04cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooo
oooo02gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo02go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`1<ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04gooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`1<ooooo`03o`000?oooooooooo007ooooo0009
ooooo`?o00001Oooool00ol0003oooooooooo`1=ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0COooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo02gooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo04gooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004
ooooo`?o0000COooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02gooooo00?o0000
ooooooooool0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04_ooooo0ol00003
ooooo`002?ooool4o`0000Gooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo04gooooo00?o0000ooooooooool00Oooool000Sooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1=ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool0;Oooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0COooool00ol0003oooooooooo`01ooooo`002Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0]ooooo`03o`00
0?oooooooooo02gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1=ooooo`03o`00
0?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`1=ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0COooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`1=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0;_ooool0
0ol0003oooooooooo`0]ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0COooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1=ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0COooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0;_ooool00ol0003o
ooooooooo`0]ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0COooool00ol0003o
ooooooooo`01ooooo`004Oooool2o`0004kooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1<ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0COooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo02kooooo00?o0000ooooooooool0;Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo04gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0COooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02kooooo00?o0000
ooooooooool0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04gooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo02kooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo04gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0COooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02kooooo00?o0000oooooooo
ool0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04gooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo02kooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo04gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0COoo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02kooooo00?o0000ooooooooool0;Ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo04gooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo02kooooo00?o0000ooooooooool0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo04gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001>ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool0C?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo04go
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo02go
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`1=ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo02gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`1=ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo04gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0^
ooooo`03o`000?oooooooooo02kooooo00Go003oooooooooooooooooo`00o`1?ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo04kooooo00Go003oooooooooooooooooo`00
o`0`ooooo`03o`000?oooooooooo02kooooo00Go003oooooooooooooooooo`00o`1?ooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04kooooo00Go003ooooooooooooooooo
o`00o`0`ooooo`03o`000?oooooooooo02kooooo00Go003oooooooooooooooooo`00o`1?ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o0000Coooool01Ol00?oooooooooooooooooo003o033o
oooo00?o0000ooooooooool0;_ooool01Ol00?oooooooooooooooooo003o04kooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool00?l0<?ooool00ol0
003oooooooooo`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool00?l0<?ooool0
0ol0003oooooooooo`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool00?l0<?oo
ool00ol0003oooooooooo`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool00?l0
<?ooool00ol0003oooooooooo`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool0
0?l0<?ooool00ol0003oooooooooo`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0
003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool0C_ooool01Ol00?oo
oooooooooooooooo003o033ooooo00?o0000ooooooooool0;_ooool01Ol00?oooooooooooooooooo
003o04oooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo04kooooo00Go003oooooooooooooooooo`00o`0`ooooo`03o`000?oo
oooooooo02kooooo00Go003oooooooooooooooooo`00o`1?ooooo`03o`000?oooooooooo007ooooo
0008ooooo`05o`000?ooooooooooooooool000001?ooool3o`0004kooooo00Go003ooooooooooooo
ooooo`00o`0`ooooo`03o`000?oooooooooo02kooooo00Go003oooooooooooooooooo`00o`1=oooo
o`?o00000oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo04kooooo00Go003ooooooooo
ooooooooo`00o`0`ooooo`03o`000?oooooooooo02kooooo00Go003oooooooooooooooooo`00o`1?
ooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`1>ooooo`05o`00ooooooooooooooooool00?l0<?ooool00ol0003ooooooooo
o`0^ooooo`05o`00ooooooooooooooooool00?l0Coooool00ol0003oooooooooo`01ooooo`002?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0C_ooool01Ol00?oooooo
oooooooooooo003o033ooooo00?o0000ooooooooool0;_ooool01Ol00?oooooooooooooooooo003o
04oooooo00?o0000ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo04ko
oooo00Go003oooooooooooooooooo`00o`0`ooooo`03o`000?oooooooooo02kooooo00Co003ooooo
oooooooo003oD?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>oooo
o`05o`00ooooooooooooooooool00?l0<?ooool00ol0003oooooooooo`0^ooooo`04o`00oooooooo
ooooo`00oe3ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C_ooool0
1?l00?ooooooooooool00?laooooo`03o`000?oooooooooo02kooooo00Co003ooooooooooooo003o
D?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`04o`00oooo
ooooooooo`00oc7ooooo00?o0000ooooooooool0;_ooool01?l00?ooooooooooool00?m@ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o0000Coooool01?l00?ooooooooooool00?laooooo`03
o`000?oooooooooo02kooooo00Co003ooooooooooooo003oCoooool2o`0000?ooooo000Aooooo`03
o`000?oooooooooo04kooooo00Co003ooooooooooooo003o<Oooool00ol0003oooooooooo`0^oooo
o`04o`00ooooooooooooo`00oe3ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0C_ooool01?l00?ooooooooooool00?laooooo`03o`000?oooooooooo02kooooo00Co003o
oooooooooooo003oD?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>
ooooo`04o`00ooooooooooooo`00oc7ooooo00?o0000ooooooooool0;_ooool01?l00?oooooooooo
ool00?m@ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04kooooo00Co
003ooooooooooooo003o<Oooool00ol0003oooooooooo`0^ooooo`04o`00ooooooooooooo`00oe3o
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C_ooool01?l00?oooooo
ooooool00?laooooo`03o`000?oooooooooo02kooooo00Co003ooooooooooooo003oD?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`04o`00ooooooooooooo`00
oc7ooooo00?o0000ooooooooool0;_ooool01?l00?ooooooooooool00?m@ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo04kooooo00Co003ooooooooooooo003o<Oooool0
0ol0003oooooooooo`0^ooooo`04o`00ooooooooooooo`00oe3ooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l0001?ooooo`04o`00ooooooooooooo`00oc7ooooo00?o0000ooooooooool0;_oo
ool01?l00?ooooooooooool00?m?ooooo`;o00000oooool0017ooooo00?o0000ooooooooool0C_oo
ool01?l00?ooooooooooool00?laooooo`03o`000?oooooooooo02kooooo00Co003ooooooooooooo
003oD?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1>ooooo`04o`00
ooooooooooooo`00oc7ooooo00?o0000ooooooooool0;_ooool01?l00?ooooooooooool00?m@oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo04kooooo00Co003ooooooooo
oooo003o<Oooool00ol0003oooooooooo`0^ooooo`04o`00ooooooooooooo`00oe3ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0C_ooool01?l00?ooooooooooool00?la
ooooo`03o`000?oooooooooo02oooooo00?o003oooooool00?l0D?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1>ooooo`04o`00ooooooooooooo`00oc7ooooo00?o0000
ooooooooool0;oooool00ol00?ooooooo`00o`1@ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo04oooooo00?o003oooooool00?l0<Oooool00ol0003oooooooooo`0_oooo
o`03o`00oooooooo003o053ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0Coooool00ol00?ooooooo`00o`0aooooo`03o`000?oooooooooo02oooooo00?o003oooooool0
0?l0D?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`00053ooooo00?o003oooooool00?l0
<Oooool00ol0003oooooooooo`0_ooooo`03o`00oooooooo003o04oooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`1?ooooo`03o`00oooooooo003o037ooooo00?o0000ooooooooool0;ooo
ool00ol00?ooooooo`00o`1@ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo04oooooo0_l00?lbooooo`03o`000?oooooooooo02oooooo00?o003oooooool00?l0D?ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1?ooooo`;o003o<_ooool00ol0
003oooooooooo`0_ooooo`03o`00oooooooo003o053ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0Coooool2o`00oc;ooooo00?o0000ooooooooool0;oooool2o`00oe7o
oooo00?o0000ooooooooool00Oooool000?ooooo0ol00004ooooo`;o00001Oooool00ol0003ooooo
ooooo`1?ooooo`;o003o<_ooool00ol0003oooooooooo`0_ooooo`;o003oDOooool00ol0003ooooo
ooooo`01ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0Coooool2o`00oc;ooooo00?o0000ooooooooool0;oooool2o`00oe7ooooo
00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00004ooooo`?o0000Coooool2o`00oc;ooooo00?o0000ooooooooool0;oooool2o`00odoooooo
0ol00003ooooo`001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0Coooool2o`00oc;ooooo00?o0000ooooooooool0;oooool2o`00oe7ooooo
00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo04oooooo0_l00?lbooooo`03o`000?oooooooooo033ooooo
00?o003oooooooooool0Coooool00ol0003oooooooooo`01ooooo`000oooool2o`0000Cooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooooooo`0000go00000oooool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.95693, -1.04481, \
0.0394232, 0.0642988}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampled waveform (finite-length)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(xd = \ sampler[x, fs]; \ 
    If[OddQ[Length[xd]], \ xd\  = \ Drop[xd, \(-1\)]];\), "\n", 
    \(\(gxn\  = \ 
        DiscreteListPlot[xd, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, 
          PlotRange -> {All, 
              Evaluate[\(AbsoluteOptions[gxt, PlotRange]\)[\([1, 2, 
                    2]\)]]}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0560224 0.196383 0.0581337 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.16387 -0.0125 -9 -9 ]
[.16387 -0.0125 9 0 ]
[.30392 -0.0125 -3 -9 ]
[.30392 -0.0125 3 0 ]
[.44398 -0.0125 -9 -9 ]
[.44398 -0.0125 9 0 ]
[.58403 -0.0125 -6 -9 ]
[.58403 -0.0125 6 0 ]
[.72409 -0.0125 -12 -9 ]
[.72409 -0.0125 12 0 ]
[.86415 -0.0125 -6 -9 ]
[.86415 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -12 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .31265 -6 -4.5 ]
[-0.0125 .31265 0 4.5 ]
[-0.0125 .42892 -6 -4.5 ]
[-0.0125 .42892 0 4.5 ]
[-0.0125 .54519 -6 -4.5 ]
[-0.0125 .54519 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.16387 0 m
.16387 .00625 L
s
[(2.5)] .16387 -0.0125 0 1 Mshowa
.30392 0 m
.30392 .00625 L
s
[(5)] .30392 -0.0125 0 1 Mshowa
.44398 0 m
.44398 .00625 L
s
[(7.5)] .44398 -0.0125 0 1 Mshowa
.58403 0 m
.58403 .00625 L
s
[(10)] .58403 -0.0125 0 1 Mshowa
.72409 0 m
.72409 .00625 L
s
[(12.5)] .72409 -0.0125 0 1 Mshowa
.86415 0 m
.86415 .00625 L
s
[(15)] .86415 -0.0125 0 1 Mshowa
.125 Mabswid
.05182 0 m
.05182 .00375 L
s
.07983 0 m
.07983 .00375 L
s
.10784 0 m
.10784 .00375 L
s
.13585 0 m
.13585 .00375 L
s
.19188 0 m
.19188 .00375 L
s
.21989 0 m
.21989 .00375 L
s
.2479 0 m
.2479 .00375 L
s
.27591 0 m
.27591 .00375 L
s
.33193 0 m
.33193 .00375 L
s
.35994 0 m
.35994 .00375 L
s
.38796 0 m
.38796 .00375 L
s
.41597 0 m
.41597 .00375 L
s
.47199 0 m
.47199 .00375 L
s
.5 0 m
.5 .00375 L
s
.52801 0 m
.52801 .00375 L
s
.55602 0 m
.55602 .00375 L
s
.61204 0 m
.61204 .00375 L
s
.64006 0 m
.64006 .00375 L
s
.66807 0 m
.66807 .00375 L
s
.69608 0 m
.69608 .00375 L
s
.7521 0 m
.7521 .00375 L
s
.78011 0 m
.78011 .00375 L
s
.80812 0 m
.80812 .00375 L
s
.83613 0 m
.83613 .00375 L
s
.89216 0 m
.89216 .00375 L
s
.92017 0 m
.92017 .00375 L
s
.94818 0 m
.94818 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(-2)] -0.0125 .08012 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(0)] -0.0125 .19638 1 0 Mshowa
0 .31265 m
.00625 .31265 L
s
[(2)] -0.0125 .31265 1 0 Mshowa
0 .42892 m
.00625 .42892 L
s
[(4)] -0.0125 .42892 1 0 Mshowa
0 .54519 m
.00625 .54519 L
s
[(6)] -0.0125 .54519 1 0 Mshowa
.125 Mabswid
0 .10918 m
.00375 .10918 L
s
0 .13825 m
.00375 .13825 L
s
0 .16732 m
.00375 .16732 L
s
0 .22545 m
.00375 .22545 L
s
0 .25452 m
.00375 .25452 L
s
0 .28358 m
.00375 .28358 L
s
0 .34172 m
.00375 .34172 L
s
0 .37078 m
.00375 .37078 L
s
0 .39985 m
.00375 .39985 L
s
0 .45798 m
.00375 .45798 L
s
0 .48705 m
.00375 .48705 L
s
0 .51612 m
.00375 .51612 L
s
0 .05105 m
.00375 .05105 L
s
0 .02198 m
.00375 .02198 L
s
0 .57425 m
.00375 .57425 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.16387 .61178 m
.16387 .61803 L
s
.30392 .61178 m
.30392 .61803 L
s
.44398 .61178 m
.44398 .61803 L
s
.58403 .61178 m
.58403 .61803 L
s
.72409 .61178 m
.72409 .61803 L
s
.86415 .61178 m
.86415 .61803 L
s
.125 Mabswid
.05182 .61428 m
.05182 .61803 L
s
.07983 .61428 m
.07983 .61803 L
s
.10784 .61428 m
.10784 .61803 L
s
.13585 .61428 m
.13585 .61803 L
s
.19188 .61428 m
.19188 .61803 L
s
.21989 .61428 m
.21989 .61803 L
s
.2479 .61428 m
.2479 .61803 L
s
.27591 .61428 m
.27591 .61803 L
s
.33193 .61428 m
.33193 .61803 L
s
.35994 .61428 m
.35994 .61803 L
s
.38796 .61428 m
.38796 .61803 L
s
.41597 .61428 m
.41597 .61803 L
s
.47199 .61428 m
.47199 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52801 .61428 m
.52801 .61803 L
s
.55602 .61428 m
.55602 .61803 L
s
.61204 .61428 m
.61204 .61803 L
s
.64006 .61428 m
.64006 .61803 L
s
.66807 .61428 m
.66807 .61803 L
s
.69608 .61428 m
.69608 .61803 L
s
.7521 .61428 m
.7521 .61803 L
s
.78011 .61428 m
.78011 .61803 L
s
.80812 .61428 m
.80812 .61803 L
s
.83613 .61428 m
.83613 .61803 L
s
.89216 .61428 m
.89216 .61803 L
s
.92017 .61428 m
.92017 .61803 L
s
.94818 .61428 m
.94818 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .31265 m
1 .31265 L
s
.99375 .42892 m
1 .42892 L
s
.99375 .54519 m
1 .54519 L
s
.125 Mabswid
.99625 .10918 m
1 .10918 L
s
.99625 .13825 m
1 .13825 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .22545 m
1 .22545 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .28358 m
1 .28358 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .37078 m
1 .37078 L
s
.99625 .39985 m
1 .39985 L
s
.99625 .45798 m
1 .45798 L
s
.99625 .48705 m
1 .48705 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .02198 m
1 .02198 L
s
.99625 .57425 m
1 .57425 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .19638 m
1 .19638 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .19638 m
.02381 .60332 L
s
.07983 .19638 m
.07983 .01914 L
s
.13585 .19638 m
.13585 .29475 L
s
.19188 .19638 m
.19188 .27526 L
s
.2479 .19638 m
.2479 .27526 L
s
.30392 .19638 m
.30392 .29475 L
s
.35994 .19638 m
.35994 .01914 L
s
.41597 .19638 m
.41597 .60332 L
s
.47199 .19638 m
.47199 .01914 L
s
.52801 .19638 m
.52801 .29475 L
s
.58403 .19638 m
.58403 .27526 L
s
.64006 .19638 m
.64006 .27526 L
s
.69608 .19638 m
.69608 .29475 L
s
.7521 .19638 m
.7521 .01914 L
s
.80812 .19638 m
.80812 .60332 L
s
.86415 .19638 m
.86415 .01914 L
s
.92017 .19638 m
.92017 .29475 L
s
.97619 .19638 m
.97619 .27526 L
s
.015 w
.02381 .60332 Mdot
.07983 .01914 Mdot
.13585 .29475 Mdot
.19188 .27526 Mdot
.2479 .27526 Mdot
.30392 .29475 Mdot
.35994 .01914 Mdot
.41597 .60332 Mdot
.47199 .01914 Mdot
.52801 .29475 Mdot
.58403 .27526 Mdot
.64006 .27526 Mdot
.69608 .29475 Mdot
.7521 .01914 Mdot
.80812 .60332 Mdot
.86415 .01914 Mdot
.92017 .29475 Mdot
.97619 .27526 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`0001_ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0000Loooo
o`?o00007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Ioooo
o`?o00001?ooool2o`0001Kooooo0ol00002ooooo`Go00000oooool00ol0003oooooooooo`02oooo
o`?o00005oooool3o`0000?ooooo0ol0000Tooooo`005_ooool01?l0003oooooooooool0000Koooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Jooooo`05o`000?oo
ooooooooooooool000007Oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool0
00006Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Kooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000005ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08Oooool001Kooooo00Co
0000oooooooooooo00007?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool08Oooool001Kooooo00Co0000oooooooooooo00007Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool001Ko
oooo00Co0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000K
ooooo`Co00008?ooool00ol0003oooooooooo`05ooooo`Co00006_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0001Kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Gooooo1?l0000Hooooo`04o`000?ooooooooooooooo`Co00009?ooool001Kooooo
00Co0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`0Jooooo`;o00001?ooool01?l0003oooooooooool0000Eooooo`;o00000ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool06?ooool2o`0000?ooooo
00?o0000ooooooooool09Oooool001Oooooo0_l0000Looooo`?o00002?ooool5o`0001[ooooo1Ol0
000Kooooo`Go00001oooool5o`0001Wooooo00?o0000ooooooooool00oooool2o`0001Oooooo00?o
0000ooooooooool00_ooool3o`0000Sooooo1Ol0000Gooooo`04o`000?ooooooooooooooo`Go0000
8oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0017ooooo
ool0000=o`0000?ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`3oooooo`Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool04Oooool3o`00odSooooo0ol00?lKooooo`?o003oAoooool3o`00oa_ooooo0ol00?lSooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo017ooooo0ol00?m8ooooo`?o003o
6oooool3o`00odOooooo0ol00?lKooooo`?o003o8oooool00ol0003oooooooooo`01ooooo`004Ooo
ool2o`0001;ooooo0ol00?m8ooooo`?o003o6oooool3o`00odOooooo0ol00?lKooooo`?o003o8_oo
ool2o`0000?ooooo000Aooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0Aoooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Qooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
01?ooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
04Sooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Qooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0Aoooool00ol00?oo
ooooooooo`0Kooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool06oooool00ol00?oo
ooooooooo`0Qooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01?ooooo
00?o003oooooooooool0Aoooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo04Sooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`0Qooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0Aoooool00ol00?oooooooooo
o`0Kooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool06oooool00ol00?oooooooooo
o`0Qooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01?ooooo00?o003o
ooooooooool0Aoooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo04Sooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0Qooooo`03o`000?oooooooooo007ooooo000Aoooo
o`;o00005?ooool00ol00?ooooooooooo`17ooooo`03o`00oooooooooooo01_ooooo00?o003ooooo
ooooool0B?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo023ooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04Oooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool08Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Cooooo`03o`00
oooooooooooo04Oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`18ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool08Oooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool06ooo
ool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool08Ooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooo
oooo04Oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`18ooooo`03o`00oooooooo
oooo01_ooooo00?o003oooooooooool08Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`0Cooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`18ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool08Oooool00ol0
003oooooooooo`01ooooo`002?ooool5o`0000Cooooo00?o0000ooooooooool04oooool00ol00?oo
ooooooooo`17ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0B?ooool00ol00?oo
ooooooooo`0Kooooo`03o`00oooooooooooo027ooooo00?o0000ooooooooool00Oooool000Wooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04Oo
oooo00?o003oooooooooool06oooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo01_o
oooo00?o003oooooooooool08Oooool00ol0003oooooooooo`01ooooo`000_ooool5o`0000?ooooo
00?o0000ooooooooool01?ooool3o`0001?ooooo00?o003oooooooooool0Aoooool00ol00?oooooo
ooooo`0Kooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`0Oooooo`?o00000oooool000_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Cooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool06oooool00ol00?oooooooooo
o`18ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool08Oooool00ol0003ooooooooo
o`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool04ooo
ool00ol00?ooooooooooo`17ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0B?oo
ool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo027ooooo00?o0000ooooooooool00Ooo
ool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01?ooooo00?o
003oooooooooool0Aoooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo04Sooooo00?o
003oooooooooool06oooool00ol00?ooooooooooo`0Qooooo`03o`000?oooooooooo007ooooo0009
ooooo`?o00001Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04Oooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool08Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Coooo
o`03o`00oooooooooooo04Oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`18oooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool08Oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04Oooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool08Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Cooooo`03o`00
oooooooooooo04Oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`18ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool08Oooool00ol0003oooooooooo`01ooooo`004Ooo
ool2o`0001Cooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo04Sooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Pooooo`;o00000ooo
ool0017ooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`17ooooo`03o`00oooooooo
oooo01_ooooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooo
oooo027ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool04oooool00ol0
0?ooooooooooo`17ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0B?ooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo027ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`17ooooo`03o`00oooooooooooo01_o
oooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo027o
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool04oooool00ol00?oooooo
ooooo`17ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0B?ooool00ol00?oooooo
ooooo`0Kooooo`03o`00oooooooooooo027ooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool04oooool00ol00?ooooooooooo`17ooooo`03o`00oooooooooooo01_ooooo00?o
003oooooooooool0B?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo027ooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`17
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0B?ooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo027ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool04oooool00ol00?ooooooooooo`17ooooo`03o`00oooooooooooo01_ooooo00?o003ooooo
ooooool0B?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo027ooooo00?o0000oooo
ooooool00Oooool0017ooooo0_l0000Dooooo`03o`00oooooooooooo04Oooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool08?ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0
Aoooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`0Qooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo01?ooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo04Sooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Qooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0Aoooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Qooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
01?ooooo00?o003oooooooooool0Aoooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
04Sooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Qooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0Aoooool00ol00?oo
ooooooooo`0Kooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool06oooool00ol00?oo
ooooooooo`0Qooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01?ooooo
00?o003oooooooooool0Aoooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo04Sooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`0Qooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o00005?ooool00ol00?ooooooooooo`17ooooo`03o`00oooooooooooo01_ooooo00?o
003oooooooooool0B?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo023ooooo0_l0
0003ooooo`004Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04Oooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool08Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Coooo
o`03o`00oooooooooooo04Oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`18oooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool08Oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04Oooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool08Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Cooooo`03o`00
oooooooooooo04Oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`18ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool08Oooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo04Oooooo00?o003oooooooooool06ooo
ool00ol00?ooooooooooo`18ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool08Ooo
ool00ol0003oooooooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool04oooool0
0ol00?ooooooooooo`17ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0B?ooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo027ooooo00?o0000ooooooooool00Oooool0
00Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Cooooo`03o`00oooooooo
oooo04Oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`18ooooo`03o`00oooooooo
oooo01_ooooo00?o003oooooooooool08Oooool00ol0003oooooooooo`01ooooo`002Oooool01?l0
003oooooooooool00004ooooo`Oo000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<
o`000003o`00ool0003o000000co000000?o003oo`000?l000002ol000000ol00?oo0000o`00000<
o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<
o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<
o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000<
o`000003o`00ool0003o000000co000000?o003oo`000?l000003?l000000ol00?oo0000o`00000;
o`000003o`00ool0003o000000Go00000oooool000Wooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0
00Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooo
oooo01_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo01_ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Cooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0
00[ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo01_o
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01_o
oooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Co
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?oooooo
ooooo`0Kooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0Kooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o
003oooooooooool06oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01_ooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool06oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Gooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool00oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01_ooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03
o`00oooooooooooo01_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Kooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo01_ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
1?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo00Cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
01_ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
01_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool06oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0Kooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool06oooool00ol00?oo
ooooooooo`0Kooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol0003o
ooooooooo`01ooooo`004Oooool2o`0000Gooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0Kooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`0Kooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool00oooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool06oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0Kooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool06oooool00ol00?oooooooooo
o`0Kooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Koooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Koooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool02_ooool3o`00o`cooooo0ol00?l=ooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0;ooooo`?o003o
2oooool3o`00o`kooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Kooooo`03o`00
oooooooooooo00[ooooo0ol00?l5ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo00Cooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0:ooooo`?o003o3?oo
ool3o`00o`gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo00_ooooo0ol00?l;ooooo`?o003o3_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool02_ooool3o`00o`Gooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l00005ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool02_ooool3
o`00o`cooooo0ol00?l=ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0;ooooo`?o003o2oooool3o`00o`kooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00[ooooo0ol00?l4ooooo`;o00000oooool0
017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
02Wooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
02[ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
01;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?oo
ooooooooo`0Kooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool06oooool00ol00?oo
ooooooooo`0Kooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool06oooool00ol00?oo
ooooooooo`0Kooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Iooooo`?o003o:_ooool3o`00oacooooo
00?o003oooooooooool06_ooool3o`00obWooooo0ol00?lMooooo`03o`00oooooooooooo01Wooooo
0ol00?lDooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o
003oooooooooool06Oooool3o`00ob[ooooo0ol00?lLooooo`03o`00oooooooooooo01[ooooo0ol0
0?lYooooo`?o003o7Oooool00ol00?ooooooooooo`0Iooooo`?o003o5?ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo01Wooooo0ol00?lZ
ooooo`?o003o7?ooool00ol00?ooooooooooo`0Jooooo`?o003o:Oooool3o`00oagooooo00?o003o
ooooooooool06Oooool3o`00oaCooooo00?o0000ooooooooool00Oooool000Sooooo1Ol00004oooo
o`03o`000?oooooooooo00Cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`1Voooo
o`03o`00oooooooooooo033ooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003ooooo
ooooool0I_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo000:ooooo`03
o`000?oooooooooo00Cooooo0ol00004ooooo`03o`00oooooooooooo06Gooooo00?o003ooooooooo
ool0I_ooool00ol00?ooooooooooo`0^ooooo`?o00000oooool000_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0
I_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo
00?o003oooooooooool0I_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo
0008ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`00
oooooooooooo06Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`0`ooooo`03o`00
0?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`04ooooo`03o`00oooo
oooooooo06Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0IOooool0
0ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo033ooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo
06Kooooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0I_ooool00ol00?oo
ooooooooo`0`ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001Oooool00ol00?oooooo
ooooo`1Uooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool0;oooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0IOooool00ol00?oooooooooo
o`1Vooooo`03o`00oooooooooooo033ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool01?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo06Kooooo00?o003o
ooooooooool0<?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04oooo
o`03o`00oooooooooooo06Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`0`oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003ooooooooo
ool0IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo033ooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Uooooo`03o`00
oooooooooooo06Kooooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0I_oo
ool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00Cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooo
oooo033ooooo00?o0000ooooooooool00Oooool0017ooooo0_l00005ooooo`03o`00oooooooooooo
06Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`0_ooooo`;o00000oooool0017o
oooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo06Ko
oooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0I_ooool00ol00?oooooo
ooooo`0`ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o
003oooooooooool0IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo033ooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1U
ooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003ooooo
ooooool0I_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`1Vooooo`03
o`00oooooooooooo033ooooo00?o0000ooooooooool00Oooool0017ooooo0_l00005ooooo`03o`00
oooooooooooo06Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`0_ooooo`;o0000
0oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooo
oooooooo06Kooooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0I_ooool0
0ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
00Cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo
033ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?oo
ooooooooo`1Uooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool0<?ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo
00?o003oooooooooool0I_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo
000:ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o
003oooooooooool0I_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo000;
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1U
ooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`01
ooooo`002?ooool5o`0000Cooooo0ol00004ooooo`03o`00oooooooooooo06Gooooo00?o003ooooo
ooooool0I_ooool00ol00?ooooooooooo`0^ooooo`?o00000oooool000Sooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003ooooo
ooooool0I_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo0009ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Uooooo`03
o`00oooooooooooo06Kooooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`01ooooo`00
2_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Uooooo`03o`00
oooooooooooo06Kooooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`01ooooo`002ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0IOoo
ool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo033ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooo
oooo06Kooooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0I_ooool00ol0
0?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Co
oooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo033o
oooo00?o0000ooooooooool00Oooool0017ooooo0_l00005ooooo`03o`00oooooooooooo06Gooooo
00?o003oooooooooool0I_ooool00ol00?ooooooooooo`0_ooooo`;o00000oooool0017ooooo00?o
0000ooooooooool01?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo06Kooooo00?o
003oooooooooool0<?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04
ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`0`
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003ooooo
ooooool0IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo033ooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Uooooo`03
o`00oooooooooooo06Kooooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0
I_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo00Cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooo
oooooooo033ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool0
0ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool0<?ooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0000Gooooo00?o003oooooooooool0IOooool00ol0
0?ooooooooooo`1Vooooo`03o`00oooooooooooo02oooooo0_l00003ooooo`004Oooool00ol0003o
ooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0I_ooool00ol00?oo
ooooooooo`0`ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo
00?o003oooooooooool0IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo033ooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?oooooooooo
o`1Uooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool0<?ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003o
ooooooooool0I_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00Cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`1Voooo
o`03o`00oooooooooooo033ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool01?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo06Kooooo00?o003ooooooooo
ool0<?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Gooooo00?o003oooooooooool0
IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo02oooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0I_oo
ool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00Cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooo
oooo033ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol0
0?ooooooooooo`1Uooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool0<?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Go
oooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0IOooool00ol00?oooooo
ooooo`1Vooooo`03o`00oooooooooooo033ooooo00?o0000ooooooooool00Oooool000Wooooo0ol0
0005ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0IOooool00ol00?oooooooooo
o`1Vooooo`03o`00oooooooooooo033ooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0IOoo
ool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo033ooooo00?o0000ooooooooool00Ooo
ool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`?o00001?ooool00ol00?oooooooooo
o`1Uooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool0;_ooool3o`0000?ooooo0008
ooooo`Co00001Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003o
ooooooooool0I_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo0008oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Uoooo
o`03o`00oooooooooooo06Kooooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`01oooo
o`002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o003ooooooooo
ool0IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo033ooooo00?o0000oooooooo
ool00Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo033ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooo
oooooooo06Kooooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0I_ooool0
0ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
00Cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo
033ooooo00?o0000ooooooooool00Oooool0017ooooo0_l00005ooooo`03o`00oooooooooooo06Go
oooo00?o003oooooooooool0I_ooool00ol00?ooooooooooo`0_ooooo`;o00000oooool0017ooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooooooo06Kooooo
00?o003oooooooooool0<?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`04ooooo`03o`00oooooooooooo06Gooooo00?o003oooooooooool0I_ooool00ol00?oooooooooo
o`0`ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003o
ooooooooool0IOooool00ol00?ooooooooooo`1Vooooo`03o`00oooooooooooo033ooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`1Uoooo
o`03o`00oooooooooooo06Kooooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo06Gooooo00?o003ooooooooo
ool0I_ooool00ol00?ooooooooooo`0`ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo00Cooooo00?o003oooooooooool0IOooool00ol00?ooooooooooo`1Vooooo`03o`00
oooooooooooo033ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool00_oo
ool3o`00ofKooooo0ol00?mUooooo`?o003o<_ooool00ol0003oooooooooo`01ooooo`004Oooool2
o`0000?ooooo0ol00?mVooooo`?o003oIOooool3o`00oc7ooooo0_l00003ooooo`004Oooool00ol0
003oooooooooo`02ooooo`?o003oI_ooool3o`00ofGooooo0ol00?lbooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aoooooooo00003Ol00003ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.62678, -4.17447, \
0.0670194, 0.0645854}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CTFT of infinite-length sampled signal", "Subsection"],

Cell[BoxData[
    \(\(Xs[f_, fs_, n_:  5] := SampledSpectrum[X, f, fs, n];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gXs = 
        Plot[Evaluate[PlotConvert[Xs[f, fs, 10],  .05]], {f, \(-2.5\) fs, 
            2.5  fs}, PlotStyle \[Rule] {Red, Thickness[ .01]}, \ 
          PlotPoints \[Rule] 500, \ 
          PlotRange \[Rule] {\(- .02\), 3.12}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0544218 0.00393652 0.196826 [
[.09184 -0.0125 -12 -9 ]
[.09184 -0.0125 12 0 ]
[.22789 -0.0125 -6 -9 ]
[.22789 -0.0125 6 0 ]
[.36395 -0.0125 -12 -9 ]
[.36395 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.63605 -0.0125 -9 -9 ]
[.63605 -0.0125 9 0 ]
[.77211 -0.0125 -3 -9 ]
[.77211 -0.0125 3 0 ]
[.90816 -0.0125 -9 -9 ]
[.90816 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09184 0 m
.09184 .00625 L
s
[(-7.5)] .09184 -0.0125 0 1 Mshowa
.22789 0 m
.22789 .00625 L
s
[(-5)] .22789 -0.0125 0 1 Mshowa
.36395 0 m
.36395 .00625 L
s
[(-2.5)] .36395 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.63605 0 m
.63605 .00625 L
s
[(2.5)] .63605 -0.0125 0 1 Mshowa
.77211 0 m
.77211 .00625 L
s
[(5)] .77211 -0.0125 0 1 Mshowa
.90816 0 m
.90816 .00625 L
s
[(7.5)] .90816 -0.0125 0 1 Mshowa
.125 Mabswid
.11905 0 m
.11905 .00375 L
s
.14626 0 m
.14626 .00375 L
s
.17347 0 m
.17347 .00375 L
s
.20068 0 m
.20068 .00375 L
s
.2551 0 m
.2551 .00375 L
s
.28231 0 m
.28231 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.33673 0 m
.33673 .00375 L
s
.39116 0 m
.39116 .00375 L
s
.41837 0 m
.41837 .00375 L
s
.44558 0 m
.44558 .00375 L
s
.47279 0 m
.47279 .00375 L
s
.52721 0 m
.52721 .00375 L
s
.55442 0 m
.55442 .00375 L
s
.58163 0 m
.58163 .00375 L
s
.60884 0 m
.60884 .00375 L
s
.66327 0 m
.66327 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.71769 0 m
.71769 .00375 L
s
.7449 0 m
.7449 .00375 L
s
.79932 0 m
.79932 .00375 L
s
.82653 0 m
.82653 .00375 L
s
.85374 0 m
.85374 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.06463 0 m
.06463 .00375 L
s
.03741 0 m
.03741 .00375 L
s
.0102 0 m
.0102 .00375 L
s
.93537 0 m
.93537 .00375 L
s
.96259 0 m
.96259 .00375 L
s
.9898 0 m
.9898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09184 .61178 m
.09184 .61803 L
s
.22789 .61178 m
.22789 .61803 L
s
.36395 .61178 m
.36395 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.63605 .61178 m
.63605 .61803 L
s
.77211 .61178 m
.77211 .61803 L
s
.90816 .61178 m
.90816 .61803 L
s
.125 Mabswid
.11905 .61428 m
.11905 .61803 L
s
.14626 .61428 m
.14626 .61803 L
s
.17347 .61428 m
.17347 .61803 L
s
.20068 .61428 m
.20068 .61803 L
s
.2551 .61428 m
.2551 .61803 L
s
.28231 .61428 m
.28231 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.33673 .61428 m
.33673 .61803 L
s
.39116 .61428 m
.39116 .61803 L
s
.41837 .61428 m
.41837 .61803 L
s
.44558 .61428 m
.44558 .61803 L
s
.47279 .61428 m
.47279 .61803 L
s
.52721 .61428 m
.52721 .61803 L
s
.55442 .61428 m
.55442 .61803 L
s
.58163 .61428 m
.58163 .61803 L
s
.60884 .61428 m
.60884 .61803 L
s
.66327 .61428 m
.66327 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.71769 .61428 m
.71769 .61803 L
s
.7449 .61428 m
.7449 .61803 L
s
.79932 .61428 m
.79932 .61803 L
s
.82653 .61428 m
.82653 .61803 L
s
.85374 .61428 m
.85374 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.06463 .61428 m
.06463 .61803 L
s
.03741 .61428 m
.03741 .61803 L
s
.0102 .61428 m
.0102 .61803 L
s
.93537 .61428 m
.93537 .61803 L
s
.96259 .61428 m
.96259 .61803 L
s
.9898 .61428 m
.9898 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .00394 m
.02567 .00394 L
.02769 .00394 L
.0296 .00394 L
.03143 .00394 L
.03338 .00394 L
.03428 .00394 L
.03525 .00394 L
.03551 .00394 L
.03578 .00394 L
.0359 .00394 L
.03596 .00394 L
.03602 .00394 L
.03605 .00394 L
.03609 .39759 L
.03615 .39759 L
.03628 .39759 L
.03724 .39759 L
.03819 .39759 L
.03846 .39759 L
.0386 .39759 L
.03866 .39759 L
.03869 .39759 L
.03872 .39759 L
.03878 .00394 L
.03883 .00394 L
.03895 .00394 L
.0392 .00394 L
.04119 .00394 L
.04311 .00394 L
.04495 .00394 L
.04691 .00394 L
.0488 .00394 L
.05061 .00394 L
.05255 .00394 L
.05441 .00394 L
.05639 .00394 L
.05829 .00394 L
.06013 .00394 L
.06115 .00394 L
.06208 .00394 L
.06254 .00394 L
.06278 .00394 L
.06292 .00394 L
.06304 .00394 L
.06315 .00394 L
.06321 .00394 L
.06327 .20076 L
.06333 .20076 L
.0634 .20076 L
Mistroke
.06352 .20076 L
.06396 .20076 L
.06498 .20076 L
.06547 .20076 L
.06568 .20076 L
.0658 .20076 L
.06586 .20076 L
.06591 .20076 L
.06597 .20076 L
.06602 .00394 L
.06608 .00394 L
.06614 .00394 L
.06638 .00394 L
.06688 .00394 L
.0678 .00394 L
.06976 .00394 L
.07165 .00394 L
.07347 .00394 L
.07541 .00394 L
.07727 .00394 L
.07925 .00394 L
.08116 .00394 L
.08299 .00394 L
.08495 .00394 L
.08683 .00394 L
.08883 .00394 L
.09075 .00394 L
.0926 .00394 L
.09458 .00394 L
.09647 .00394 L
.0983 .00394 L
.10024 .00394 L
.10211 .00394 L
.1041 .00394 L
.10601 .00394 L
.10785 .00394 L
.10981 .00394 L
.1117 .00394 L
.11352 .00394 L
.11545 .00394 L
.11634 .00394 L
.11684 .00394 L
.11708 .00394 L
.11731 .00394 L
.11742 .00394 L
.11755 .00394 L
.1176 .00394 L
.11766 .00394 L
.11772 .20076 L
.11777 .20076 L
Mistroke
.11827 .20076 L
.11928 .20076 L
.11976 .20076 L
.12 .20076 L
.12022 .20076 L
.12034 .20076 L
.12037 .20076 L
.12041 .20076 L
.12047 .00394 L
.1205 .00394 L
.12054 .00394 L
.1206 .00394 L
.12074 .00394 L
.12122 .00394 L
.12305 .00394 L
.125 .00394 L
.12687 .00394 L
.12886 .00394 L
.13078 .00394 L
.13262 .00394 L
.13458 .00394 L
.13647 .00394 L
.13829 .00394 L
.14022 .00394 L
.14208 .00394 L
.14406 .00394 L
.14597 .00394 L
.1478 .00394 L
.14976 .00394 L
.15164 .00394 L
.15363 .00394 L
.15556 .00394 L
.15741 .00394 L
.15938 .00394 L
.16127 .00394 L
.1631 .00394 L
.16504 .00394 L
.1669 .00394 L
.16889 .00394 L
.16988 .00394 L
.1708 .00394 L
.17126 .00394 L
.1717 .00394 L
.17194 .00394 L
.172 .00394 L
.17204 .00394 L
.17207 .00394 L
.17213 .20076 L
.17216 .20076 L
.17219 .20076 L
Mistroke
.17264 .20076 L
.1736 .20076 L
.1741 .20076 L
.17438 .20076 L
.17451 .20076 L
.17464 .20076 L
.17469 .20076 L
.17475 .20076 L
.17481 .20076 L
.17487 .00394 L
.17493 .00394 L
.17499 .00394 L
.17511 .00394 L
.17564 .00394 L
.17656 .00394 L
.17848 .00394 L
.18034 .00394 L
.18231 .00394 L
.18421 .00394 L
.18603 .00394 L
.18798 .00394 L
.18985 .00394 L
.19184 .00394 L
.19375 .00394 L
.1956 .00394 L
.19653 .00394 L
.19756 .00394 L
.19802 .00394 L
.19853 .00394 L
.19876 .00394 L
.19901 .00394 L
.19911 .00394 L
.19922 .00394 L
.19928 .00394 L
.19933 .39759 L
.19939 .39759 L
.19944 .39759 L
.20032 .39759 L
.20083 .39759 L
.20129 .39759 L
.20175 .39759 L
.20189 .39759 L
.20195 .39759 L
.20201 .39759 L
.20207 .00394 L
.20213 .00394 L
.20225 .00394 L
.20326 .00394 L
.20526 .00394 L
.20719 .00394 L
Mistroke
.20905 .00394 L
.21102 .00394 L
.21292 .00394 L
.21475 .00394 L
.2167 .00394 L
.21857 .00394 L
.22056 .00394 L
.22248 .00394 L
.22433 .00394 L
.22526 .00394 L
.22576 .00394 L
.22602 .00394 L
.22616 .00394 L
.22629 .00394 L
.22641 .00394 L
.22644 .00394 L
.22647 .00394 L
.22653 .39759 L
.22656 .39759 L
.2266 .39759 L
.22666 .39759 L
.2268 .39759 L
.22726 .39759 L
.22818 .39759 L
.22863 .39759 L
.22888 .39759 L
.22901 .39759 L
.22912 .39759 L
.22918 .39759 L
.22923 .39759 L
.22928 .00394 L
.22934 .00394 L
.22958 .00394 L
.23 .00394 L
.23186 .00394 L
.23384 .00394 L
.23574 .00394 L
.23757 .00394 L
.23952 .00394 L
.2414 .00394 L
.24339 .00394 L
.24531 .00394 L
.24716 .00394 L
.24913 .00394 L
.25102 .00394 L
.25197 .00394 L
.25284 .00394 L
.25307 .00394 L
.25332 .00394 L
.25343 .00394 L
Mistroke
.25355 .00394 L
.25361 .00394 L
.25367 .00394 L
.25372 .00394 L
.25377 .20076 L
.25384 .20076 L
.25389 .20076 L
.25403 .20076 L
.2543 .20076 L
.25478 .20076 L
.25528 .20076 L
.25576 .20076 L
.25618 .20076 L
.2563 .20076 L
.25637 .20076 L
.25643 .20076 L
.25648 .00394 L
.25653 .00394 L
.25665 .00394 L
.25863 .00394 L
.26053 .00394 L
.26237 .00394 L
.26432 .00394 L
.2662 .00394 L
.26819 .00394 L
.27012 .00394 L
.27197 .00394 L
.27394 .00394 L
.27583 .00394 L
.27765 .00394 L
.27959 .00394 L
.28146 .00394 L
.28345 .00394 L
.28536 .00394 L
.2872 .00394 L
.28916 .00394 L
.29104 .00394 L
.29304 .00394 L
.29497 .00394 L
.29683 .00394 L
.29881 .00394 L
.30071 .00394 L
.30254 .00394 L
.30449 .00394 L
.30636 .00394 L
.30685 .00394 L
.30738 .00394 L
.30763 .00394 L
.30789 .00394 L
.30799 .00394 L
Mistroke
.30805 .00394 L
.30811 .00394 L
.30814 .00394 L
.30817 .20076 L
.30823 .20076 L
.30835 .20076 L
.30938 .20076 L
.31031 .20076 L
.31053 .20076 L
.31065 .20076 L
.31077 .20076 L
.31083 .20076 L
.31086 .20076 L
.3109 .00394 L
.31093 .00394 L
.31097 .00394 L
.31103 .00394 L
.31127 .00394 L
.31219 .00394 L
.31415 .00394 L
.31603 .00394 L
.31785 .00394 L
.31978 .00394 L
.32164 .00394 L
.32362 .00394 L
.32552 .00394 L
.32735 .00394 L
.3293 .00394 L
.33118 .00394 L
.33318 .00394 L
.3351 .00394 L
.33695 .00394 L
.33891 .00394 L
.34081 .00394 L
.34263 .00394 L
.34457 .00394 L
.34643 .00394 L
.34842 .00394 L
.35033 .00394 L
.35217 .00394 L
.35412 .00394 L
.35601 .00394 L
.35801 .00394 L
.35994 .00394 L
.36082 .00394 L
.36132 .00394 L
.36179 .00394 L
.36225 .00394 L
.36239 .00394 L
.36245 .00394 L
Mistroke
.36251 .00394 L
.36257 .00394 L
.36263 .20076 L
.36269 .20076 L
.36275 .20076 L
.36376 .20076 L
.3647 .20076 L
.36495 .20076 L
.36509 .20076 L
.36516 .20076 L
.36522 .20076 L
.36528 .20076 L
.36533 .00394 L
.36539 .00394 L
.36545 .00394 L
.3657 .00394 L
.36767 .00394 L
.36957 .00394 L
.37139 .00394 L
.37333 .00394 L
.3752 .00394 L
.37719 .00394 L
.3791 .00394 L
.38094 .00394 L
.3829 .00394 L
.38478 .00394 L
.38679 .00394 L
.38779 .00394 L
.38872 .00394 L
.38919 .00394 L
.38942 .00394 L
.38962 .00394 L
.38968 .00394 L
.38974 .00394 L
.38979 .00394 L
.38984 .39759 L
.3899 .39759 L
.38996 .39759 L
.39008 .39759 L
.39058 .39759 L
.39159 .39759 L
.39207 .39759 L
.3923 .39759 L
.3924 .39759 L
.39246 .39759 L
.39251 .39759 L
.39257 .00394 L
.39263 .00394 L
.39274 .00394 L
.39297 .00394 L
Mistroke
.39347 .00394 L
.39438 .00394 L
.39621 .00394 L
.39815 .00394 L
.40002 .00394 L
.40201 .00394 L
.40393 .00394 L
.40577 .00394 L
.40773 .00394 L
.40962 .00394 L
.41143 .00394 L
.41337 .00394 L
.41523 .00394 L
.41619 .00394 L
.41668 .00394 L
.41681 .00394 L
.41688 .00394 L
.41692 .00394 L
.41695 .00394 L
.41698 .00394 L
.41701 .39759 L
.41705 .39759 L
.41708 .39759 L
.41721 .39759 L
.41822 .39759 L
.41915 .39759 L
.41937 .39759 L
.41949 .39759 L
.4196 .39759 L
.41967 .39759 L
.41971 .39759 L
.41974 .00394 L
.4198 .00394 L
.41986 .00394 L
.4201 .00394 L
.42101 .00394 L
.42284 .00394 L
.42479 .00394 L
.42666 .00394 L
.42865 .00394 L
.43057 .00394 L
.43242 .00394 L
.43438 .00394 L
.43627 .00394 L
.43809 .00394 L
.44003 .00394 L
.44189 .00394 L
.44284 .00394 L
.44334 .00394 L
.44361 .00394 L
Mistroke
.44387 .00394 L
.44399 .00394 L
.44412 .00394 L
.44415 .00394 L
.44419 .00394 L
.44422 .20076 L
.44426 .20076 L
.44439 .20076 L
.44486 .20076 L
.44578 .20076 L
.44627 .20076 L
.44652 .20076 L
.44667 .20076 L
.4468 .20076 L
.44685 .20076 L
.44691 .20076 L
.44694 .00394 L
.44698 .00394 L
.44704 .00394 L
.4473 .00394 L
.44777 .00394 L
.44972 .00394 L
.45159 .00394 L
.45359 .00394 L
.45551 .00394 L
.45735 .00394 L
.45932 .00394 L
.46121 .00394 L
.46303 .00394 L
.46497 .00394 L
.46684 .00394 L
.46882 .00394 L
.47073 .00394 L
.47257 .00394 L
.47453 .00394 L
.47641 .00394 L
.47841 .00394 L
.48034 .00394 L
.48219 .00394 L
.48416 .00394 L
.48606 .00394 L
.48789 .00394 L
.48984 .00394 L
.49171 .00394 L
.4937 .00394 L
.49562 .00394 L
.49746 .00394 L
.49795 .00394 L
.49819 .00394 L
.49841 .00394 L
Mistroke
.49852 .00394 L
.49858 .00394 L
.49864 .20076 L
.49871 .20076 L
.49877 .20076 L
.49889 .20076 L
.49942 .20076 L
.49992 .20076 L
.50045 .20076 L
.50069 .20076 L
.50095 .20076 L
.50118 .20076 L
.50124 .20076 L
.50127 .20076 L
.5013 .20076 L
.50136 .00394 L
.50142 .00394 L
.50326 .00394 L
.50522 .00394 L
.5071 .00394 L
.50911 .00394 L
.51104 .00394 L
.51289 .00394 L
.51487 .00394 L
.51677 .00394 L
.5186 .00394 L
.52055 .00394 L
.52242 .00394 L
.52442 .00394 L
.52634 .00394 L
.52818 .00394 L
.53015 .00394 L
.53204 .00394 L
.53386 .00394 L
.53579 .00394 L
.53766 .00394 L
.53964 .00394 L
.54155 .00394 L
.54339 .00394 L
.54534 .00394 L
.54722 .00394 L
.54922 .00394 L
.55115 .00394 L
.55203 .00394 L
.55253 .00394 L
.55278 .00394 L
.55289 .00394 L
.553 .00394 L
.55305 .00394 L
.55311 .20076 L
Mistroke
.55317 .20076 L
.55324 .20076 L
.55346 .20076 L
.55396 .20076 L
.55449 .20076 L
.55497 .20076 L
.55542 .20076 L
.55565 .20076 L
.55571 .20076 L
.55575 .20076 L
.55578 .20076 L
.55584 .00394 L
.5559 .00394 L
.5569 .00394 L
.55875 .00394 L
.56072 .00394 L
.56261 .00394 L
.56444 .00394 L
.56637 .00394 L
.56824 .00394 L
.57023 .00394 L
.57214 .00394 L
.57398 .00394 L
.57593 .00394 L
.57782 .00394 L
.57878 .00394 L
.57928 .00394 L
.57956 .00394 L
.57982 .00394 L
.58005 .00394 L
.58012 .00394 L
.58018 .00394 L
.58024 .00394 L
.5803 .39759 L
.58036 .39759 L
.58043 .39759 L
.58057 .39759 L
.58082 .39759 L
.58175 .39759 L
.5822 .39759 L
.58268 .39759 L
.5828 .39759 L
.58287 .39759 L
.58293 .39759 L
.58296 .39759 L
.583 .00394 L
.58304 .00394 L
.58307 .00394 L
.5832 .00394 L
.58368 .00394 L
Mistroke
.58558 .00394 L
.5874 .00394 L
.58934 .00394 L
.59121 .00394 L
.5932 .00394 L
.59511 .00394 L
.59696 .00394 L
.59891 .00394 L
.6008 .00394 L
.60261 .00394 L
.60455 .00394 L
.6064 .00394 L
.6069 .00394 L
.60714 .00394 L
.60725 .00394 L
.60737 .00394 L
.60743 .00394 L
.60749 .39759 L
.60754 .39759 L
.6076 .39759 L
.60785 .39759 L
.60838 .39759 L
.60933 .39759 L
.60975 .39759 L
.60997 .39759 L
.61009 .39759 L
.61015 .39759 L
.6102 .39759 L
.61026 .00394 L
.6103 .00394 L
.61033 .00394 L
.61045 .00394 L
.61068 .00394 L
.61113 .00394 L
.61214 .00394 L
.61396 .00394 L
.61591 .00394 L
.61778 .00394 L
.61977 .00394 L
.62169 .00394 L
.62353 .00394 L
.62549 .00394 L
.62738 .00394 L
.6292 .00394 L
.63113 .00394 L
.63299 .00394 L
.63395 .00394 L
.63419 .00394 L
.63444 .00394 L
.63451 .00394 L
Mistroke
.63458 .00394 L
.63465 .00394 L
.63468 .00394 L
.63471 .20076 L
.63477 .20076 L
.63484 .20076 L
.63497 .20076 L
.63598 .20076 L
.63691 .20076 L
.63713 .20076 L
.63725 .20076 L
.63731 .20076 L
.63737 .20076 L
.6374 .20076 L
.63743 .00394 L
.63747 .00394 L
.6375 .00394 L
.63763 .00394 L
.63787 .00394 L
.63878 .00394 L
.64072 .00394 L
.6426 .00394 L
.64459 .00394 L
.64651 .00394 L
.64836 .00394 L
.65032 .00394 L
.65221 .00394 L
.65403 .00394 L
.65597 .00394 L
.65783 .00394 L
.65981 .00394 L
.66172 .00394 L
.66355 .00394 L
.66551 .00394 L
.66739 .00394 L
.66939 .00394 L
.67131 .00394 L
.67316 .00394 L
.67514 .00394 L
.67703 .00394 L
.67886 .00394 L
.6808 .00394 L
.68267 .00394 L
.68466 .00394 L
.68657 .00394 L
.68745 .00394 L
.68795 .00394 L
.68842 .00394 L
.68864 .00394 L
.68887 .00394 L
Mistroke
.689 .00394 L
.68903 .00394 L
.68907 .00394 L
.6891 .00394 L
.68913 .20076 L
.68919 .20076 L
.68925 .20076 L
.68937 .20076 L
.69038 .20076 L
.69133 .20076 L
.69156 .20076 L
.69169 .20076 L
.69175 .20076 L
.69181 .20076 L
.69185 .00394 L
.69188 .00394 L
.69196 .00394 L
.69209 .00394 L
.69234 .00394 L
.69434 .00394 L
.69627 .00394 L
.69813 .00394 L
.7001 .00394 L
.702 .00394 L
.70383 .00394 L
.70577 .00394 L
.70765 .00394 L
.70964 .00394 L
.71155 .00394 L
.7134 .00394 L
.71536 .00394 L
.71725 .00394 L
.71907 .00394 L
.721 .00394 L
.72286 .00394 L
.72484 .00394 L
.72675 .00394 L
.72858 .00394 L
.73054 .00394 L
.73242 .00394 L
.73441 .00394 L
.73634 .00394 L
.73819 .00394 L
.74016 .00394 L
.74114 .00394 L
.74205 .00394 L
.74293 .00394 L
.74319 .00394 L
.74331 .00394 L
.74343 .00394 L
Mistroke
.74348 .00394 L
.74353 .00394 L
.74359 .20076 L
.74364 .20076 L
.74388 .20076 L
.74476 .20076 L
.74527 .20076 L
.74573 .20076 L
.74597 .20076 L
.74609 .20076 L
.74614 .20076 L
.7462 .20076 L
.74626 .00394 L
.74629 .00394 L
.74632 .00394 L
.74646 .00394 L
.7467 .00394 L
.74771 .00394 L
.74957 .00394 L
.75156 .00394 L
.75347 .00394 L
.7553 .00394 L
.75726 .00394 L
.75914 .00394 L
.76114 .00394 L
.76306 .00394 L
.76492 .00394 L
.76689 .00394 L
.76879 .00394 L
.76974 .00394 L
.77016 .00394 L
.77038 .00394 L
.77061 .00394 L
.77067 .00394 L
.77073 .00394 L
.77077 .39759 L
.7708 .39759 L
.77086 .39759 L
.7711 .39759 L
.77155 .39759 L
.77256 .39759 L
.773 .39759 L
.77324 .39759 L
.77336 .39759 L
.77341 .39759 L
.77347 .39759 L
.77353 .00394 L
.77357 .00394 L
.7736 .00394 L
.77374 .00394 L
Mistroke
.77398 .00394 L
.77446 .00394 L
.77633 .00394 L
.77831 .00394 L
.78023 .00394 L
.78207 .00394 L
.78402 .00394 L
.78591 .00394 L
.78791 .00394 L
.78984 .00394 L
.79169 .00394 L
.79367 .00394 L
.79557 .00394 L
.79653 .00394 L
.7974 .00394 L
.79763 .00394 L
.79775 .00394 L
.79782 .00394 L
.79788 .00394 L
.79793 .00394 L
.79799 .39759 L
.79803 .39759 L
.79806 .39759 L
.79812 .39759 L
.79834 .39759 L
.79934 .39759 L
.7998 .39759 L
.80006 .39759 L
.8003 .39759 L
.80052 .39759 L
.80058 .39759 L
.80061 .39759 L
.80064 .39759 L
.8007 .00394 L
.80076 .00394 L
.80118 .00394 L
.80305 .00394 L
.80504 .00394 L
.80695 .00394 L
.80879 .00394 L
.81075 .00394 L
.81264 .00394 L
.81445 .00394 L
.81638 .00394 L
.81824 .00394 L
.82022 .00394 L
.82212 .00394 L
.82395 .00394 L
.82444 .00394 L
.82489 .00394 L
Mistroke
.82502 .00394 L
.82508 .00394 L
.82515 .00394 L
.82518 .20076 L
.82522 .20076 L
.82529 .20076 L
.82542 .20076 L
.8259 .20076 L
.82685 .20076 L
.82735 .20076 L
.82763 .20076 L
.82776 .20076 L
.82782 .20076 L
.82785 .20076 L
.82788 .20076 L
.82795 .00394 L
.82801 .00394 L
.82813 .00394 L
.8284 .00394 L
.82888 .00394 L
.8298 .00394 L
.83179 .00394 L
.8337 .00394 L
.83555 .00394 L
.83751 .00394 L
.8394 .00394 L
.84121 .00394 L
.84315 .00394 L
.84501 .00394 L
.84699 .00394 L
.84889 .00394 L
.85073 .00394 L
.85268 .00394 L
.85456 .00394 L
.85655 .00394 L
.85848 .00394 L
.86033 .00394 L
.8623 .00394 L
.86419 .00394 L
.86601 .00394 L
.86796 .00394 L
.86982 .00394 L
.87181 .00394 L
.87372 .00394 L
.87556 .00394 L
.87752 .00394 L
.87843 .00394 L
.8789 .00394 L
.87916 .00394 L
.8794 .00394 L
Mistroke
.87947 .00394 L
.87953 .00394 L
.87956 .00394 L
.8796 .20076 L
.87966 .20076 L
.87994 .20076 L
.88044 .20076 L
.8809 .20076 L
.88141 .20076 L
.88164 .20076 L
.8819 .20076 L
.88202 .20076 L
.88214 .20076 L
.88225 .20076 L
.88231 .20076 L
.88236 .00394 L
.88242 .00394 L
.88249 .00394 L
.88262 .00394 L
.88285 .00394 L
.88337 .00394 L
.88534 .00394 L
.88724 .00394 L
.88907 .00394 L
.89101 .00394 L
.89288 .00394 L
.89487 .00394 L
.89678 .00394 L
.89863 .00394 L
.90059 .00394 L
.90247 .00394 L
.90429 .00394 L
.90622 .00394 L
.90808 .00394 L
.91006 .00394 L
.91196 .00394 L
.91379 .00394 L
.91574 .00394 L
.91762 .00394 L
.91962 .00394 L
.92154 .00394 L
.92339 .00394 L
.92535 .00394 L
.92725 .00394 L
.92907 .00394 L
.93101 .00394 L
.93288 .00394 L
.93336 .00394 L
.93362 .00394 L
.93376 .00394 L
Mistroke
.93383 .00394 L
.93389 .00394 L
.93395 .00394 L
.93399 .00394 L
.93402 .20076 L
.93405 .20076 L
.93409 .20076 L
.93416 .20076 L
.93439 .20076 L
.93486 .20076 L
.93535 .20076 L
.93588 .20076 L
.93613 .20076 L
.93638 .20076 L
.93661 .20076 L
.93667 .20076 L
.9367 .20076 L
.93673 .20076 L
.93679 .00394 L
.93685 .00394 L
.93868 .00394 L
.94064 .00394 L
.94252 .00394 L
.94451 .00394 L
.94644 .00394 L
.94829 .00394 L
.95026 .00394 L
.95216 .00394 L
.95398 .00394 L
.95592 .00394 L
.95779 .00394 L
.95874 .00394 L
.95978 .00394 L
.96026 .00394 L
.96052 .00394 L
.96077 .00394 L
.961 .00394 L
.96107 .00394 L
.96113 .00394 L
.96119 .00394 L
.96125 .39759 L
.96131 .39759 L
.96136 .39759 L
.96148 .39759 L
.96169 .39759 L
.96269 .39759 L
.96313 .39759 L
.96336 .39759 L
.96361 .39759 L
.96373 .39759 L
Mistroke
.9638 .39759 L
.96385 .39759 L
.9639 .39759 L
.96396 .00394 L
.96402 .00394 L
.96407 .00394 L
.96451 .00394 L
.96546 .00394 L
.96738 .00394 L
.96924 .00394 L
.97121 .00394 L
.97311 .00394 L
.97494 .00394 L
.97619 .00394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Koooo
o`?o00006_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001[ooooo0_l0000Joooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006oooool3o`0001cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00004oooool002Wooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Wooooo00Go0000ooooooooooooooooo`00000J
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Hooooo`04o`00
0?ooooooooooo`0001[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Wooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Booooo`008Oooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Aooooo`Go00001Oooool00ol0003oooooooooo`0Aooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000
6oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000Zooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool05_ooool01?l0003oooooooooool0000Looooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04?ooool002_ooooo00?o0000ooooooooool01Ooo
ool4o`0001[ooooo1?l0000Jooooo`05o`000?ooooooooooooooool000001oooool4o`0001Wooooo
00Co0000oooooooooooo00006Oooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Joooo
o`Co00007_ooool00ol0003oooooooooo`05ooooo`Co00004oooool002Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0
000Iooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01_ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Co
oooo000Wooooo`Go00001oooool5o`0001Wooooo1Ol0000Jooooo`?o00002?ooool5o`0001Wooooo
0_l0000Kooooo`?o00002?ooool5o`0001Wooooo1Ol0000Iooooo`Go00001oooool5o`0001;ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000>ooooo`;o0000oooooolAooooo`00
3Oooool01?l0003oooooooooool00004oooooooo00002ol00001ooooo`003Oooool01?l0003ooooo
ooooool00004ooooo`;o000000?oooooo`000?ooool0oooo0003ooooo`?o00000Oooool000gooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooooooo`001Oooool1o`00007o
oooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool3ool000Go
oooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000co
oooo0_oo000<ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000co
oooo0_oo0005ooooo`?oo`001?ooool3ool000Cooooo0ooo000<ooooo`?oo`002oooool3ool000Co
oooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000So
oooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Go
oooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Co
oooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_o
oooo0ooo000<ooooo`;oo`001Oooool3ool000Cooooo0ooo0004ooooo`?oo`003?ooool3ool000_o
oooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Co
oooo0ooo0008ooooo`7o00000Oooool000kooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo
0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo
0ooo000<ooooo`;oo`003?ooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo
0ooo000<ooooo`;oo`001Oooool3ool000Cooooo0ooo0004ooooo`?oo`003?ooool3ool000_ooooo
0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Cooooo
0ooo0008ooooo`7o00000Oooool001Gooooo0_l00006ooooo`?oo`001Oooool2ool000cooooo0ooo
000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo
0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool2ool000Gooooo0ooo
0004ooooo`?oo`001?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo
0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`001oooool2o`00007ooooo000E
ooooo`03o`000?oooooooooo00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005
ooooo`;oo`001Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo0ooo0005
ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`;oo`001Oooool3ool000Cooooo0ooo0004
ooooo`?oo`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;
ooooo`?oo`003?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool01Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005oooo
o`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool3ool000Gooooo0_oo0005oooo
o`?oo`002oooool3ool000cooooo0_oo0005ooooo`?oo`001?ooool3ool000Cooooo0ooo000<oooo
o`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<oooo
o`?oo`001?ooool3ool000Sooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?o
o`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?o
o`003?ooool2ool000cooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?o
o`003?ooool2ool000Gooooo0ooo0004ooooo`?oo`001?ooool3ool000cooooo0ooo000;ooooo`?o
o`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?o
o`002?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo0005ooooo`;oo`00
3?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo0ooo000<ooooo`;oo`00
3?ooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`;oo`00
1Oooool3ool000Cooooo0ooo0004ooooo`?oo`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`00
1Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Cooooo0ooo0008ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool01Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?oo
ool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?oo
ool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0_oo0005ooooo`?oo`001?oo
ool3ool000Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Ooo
ool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Sooooo0Ol00001ooooo`005Oooool2
o`0000Kooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3
ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3
ool000_ooooo0ooo000<ooooo`;oo`001Oooool3ool000Cooooo0ooo0004ooooo`?oo`003?ooool3
ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3
ool000Cooooo0ooo0007ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool0
00Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool0
00cooooo0_oo000<ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool0
00cooooo0_oo0005ooooo`?oo`001?ooool3ool000Cooooo0ooo000<ooooo`?oo`002oooool3ool0
00Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool0
00Sooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000co
oooo0ooo000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000co
oooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool2ool000Go
oooo0ooo0004ooooo`?oo`001?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Go
oooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo
0_oo0005ooooo`;oo`001Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo
0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`;oo`001Oooool3ool000Cooooo
0ooo0004ooooo`?oo`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo
0ooo000;ooooo`?oo`003?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool01Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo
0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool3ool000Gooooo0_oo
0005ooooo`?oo`002oooool3ool000cooooo0_oo0005ooooo`?oo`001?ooool3ool000Cooooo0ooo
000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo
000<ooooo`?oo`001?ooool3ool000Sooooo0Ol00001ooooo`005Oooool2o`0000Kooooo0ooo0005
ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo0ooo000<
ooooo`;oo`003?ooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<
ooooo`;oo`001Oooool3ool000Cooooo0ooo0004ooooo`?oo`003?ooool3ool000_ooooo0ooo0004
ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Cooooo0ooo0007
ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool000Gooooo0_oo000<oooo
o`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<oooo
o`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0_oo0005oooo
o`?oo`001?ooool3ool000Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005oooo
o`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Sooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;o
o`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`?o
o`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool2ool000Gooooo0ooo0004ooooo`?o
o`001?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?o
o`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`00
1Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo0ooo0005ooooo`;oo`00
1Oooool3ool000_ooooo0ooo000<ooooo`;oo`001Oooool3ool000Cooooo0ooo0004ooooo`?oo`00
3?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`00
3?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01Ooo
ool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?oo
ool3ool000cooooo0_oo000<ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002ooo
ool3ool000cooooo0_oo0005ooooo`?oo`001?ooool3ool000Cooooo0ooo000<ooooo`?oo`002ooo
ool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?oo
ool3ool000Sooooo0Ol00001ooooo`005Oooool2o`0000Kooooo0ooo0005ooooo`;oo`003?ooool3
ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3
ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`;oo`001Oooool3
ool000Cooooo0ooo0004ooooo`?oo`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2
ool000Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Cooooo0ooo0007ooooo`;o00000Oooool0
01Gooooo00?o0000ooooooooool01Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool0
00Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool3ool0
00Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0_oo0005ooooo`?oo`001?ooool3ool0
00Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool0
00_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Sooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2ool000Go
oooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`?oo`001Oooool2ool000Go
oooo0ooo000;ooooo`?oo`003?ooool2ool000Gooooo0ooo0004ooooo`?oo`001?ooool3ool000co
oooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000co
oooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo0002ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo
0ooo000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo
0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool2ool000Gooooo
0ooo0004ooooo`?oo`001?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo
0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo
00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;o
o`001Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo0ooo0005ooooo`;o
o`001Oooool3ool000_ooooo0ooo000<ooooo`;oo`001Oooool3ool000Cooooo0ooo0004ooooo`?o
o`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?o
o`003?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool00005ooooool0003oooooooooool0
00002oooool00ol0003oooooooooo`02ooooo`;o00001_ooool3ool000Gooooo0_oo000<ooooo`?o
o`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?o
o`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0_oo0005ooooo`?o
o`001?ooool3ool000Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;o
o`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Oooooo0_l00001ooooo`00
00Goooooo`000?ooooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?o
o`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?o
o`002oooool3ool000cooooo0_oo0005ooooo`?oo`001?ooool3ool000Cooooo0ooo000<ooooo`?o
o`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?o
o`001?ooool3ool000Sooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Co
00001Oooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;o
o`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`?o
o`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool2ool000Gooooo0ooo0004ooooo`?o
o`001?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?o
o`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo00001Ooooooo0000
oooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`?o
o`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?o
o`003?ooool2ool000cooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?o
o`003?ooool2ool000Gooooo0ooo0004ooooo`?oo`001?ooool3ool000cooooo0ooo000;ooooo`?o
o`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?o
o`002?ooool1o`00007ooooo0002ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool0
1Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`00
1?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`00
2oooool3ool000cooooo0_oo0005ooooo`?oo`001?ooool3ool000Cooooo0ooo000<ooooo`?oo`00
2oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`00
1?ooool3ool000Sooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`001Ooo
ool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?oo
ool2ool000cooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?oo
ool2ool000Gooooo0ooo0004ooooo`?oo`001?ooool3ool000cooooo0ooo000;ooooo`?oo`001?oo
ool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?oo
ool1o`00007ooooo000Eooooo`;o00001_ooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2
ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool3
ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0_oo0005ooooo`?oo`001?ooool3
ool000Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3
ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Oooooo0_l00001ooooo`005Oooool00ol0
003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2ool0
00Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`?oo`001Oooool2ool0
00Gooooo0ooo000;ooooo`?oo`003?ooool2ool000Gooooo0ooo0004ooooo`?oo`001?ooool3ool0
00cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool0
00cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Go
oooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Co
oooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_o
oooo0ooo000<ooooo`;oo`001Oooool3ool000Cooooo0ooo0004ooooo`?oo`003?ooool3ool000_o
oooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Co
oooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool000Gooooo
0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo
0_oo000<ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo
0_oo0005ooooo`?oo`001?ooool3ool000Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo
0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Sooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo
000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo
0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool2ool000Gooooo0ooo
0004ooooo`?oo`001?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo
0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo000E
ooooo`;o00001_ooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005
ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool3ool000Gooooo0_oo0005
ooooo`?oo`002oooool3ool000cooooo0_oo0005ooooo`?oo`001?ooool3ool000Cooooo0ooo000<
ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<
ooooo`?oo`001?ooool3ool000Oooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`05oooo
o`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004oooo
o`?oo`003?ooool2ool000cooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;oooo
o`?oo`003?ooool2ool000Gooooo0ooo0004ooooo`?oo`001?ooool3ool000cooooo0ooo000;oooo
o`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004oooo
o`?oo`002?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo0005ooooo`;o
o`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo0ooo000<ooooo`;o
o`003?ooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`;o
o`001Oooool3ool000Cooooo0ooo0004ooooo`?oo`003?ooool3ool000_ooooo0ooo0004ooooo`?o
o`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Cooooo0ooo0008ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool000Gooooo0_oo000<ooooo`?oo`00
3?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`00
1?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0_oo0005ooooo`?oo`00
1?ooool3ool000Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`00
1Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Sooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Ooo
ool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`?oo`001Ooo
ool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool2ool000Gooooo0ooo0004ooooo`?oo`001?oo
ool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002ooo
ool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo000Eooooo`;o00001_ooool3
ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3
ool000cooooo0_oo000<ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3
ool000cooooo0_oo0005ooooo`?oo`001?ooool3ool000Cooooo0ooo000<ooooo`?oo`002oooool3
ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3
ool000Oooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool0
00cooooo0ooo000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool0
00cooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool2ool0
00Gooooo0ooo0004ooooo`?oo`001?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool0
00Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000co
oooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Co
oooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`;oo`001Oooool3ool000Co
oooo0ooo0004ooooo`?oo`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Go
oooo0ooo000;ooooo`?oo`003?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool01Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo
0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool3ool000Gooooo
0_oo0005ooooo`?oo`002oooool3ool000cooooo0_oo0005ooooo`?oo`001?ooool3ool000Cooooo
0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo
0ooo000<ooooo`?oo`001?ooool3ool000Sooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2ool000Gooooo0ooo
0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo
000;ooooo`?oo`003?ooool2ool000Gooooo0ooo0004ooooo`?oo`001?ooool3ool000cooooo0ooo
000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo
0004ooooo`?oo`002?ooool1o`00007ooooo000Eooooo`;o00001_ooool3ool000Gooooo0_oo000<
ooooo`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<
ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0_oo0005
ooooo`?oo`001?ooool3ool000Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005
ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Oooooo0_l00001
ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<oooo
o`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004oooo
o`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool2ool000Gooooo0ooo0004oooo
o`?oo`001?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005oooo
o`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;o
o`001Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo0ooo0005ooooo`;o
o`001Oooool3ool000_ooooo0ooo000<ooooo`;oo`001Oooool3ool000Cooooo0ooo0004ooooo`?o
o`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?o
o`003?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool000gooooo0ol00005ooooo`03o`00
0?oooooooooo00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`00
1Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo0ooo0005ooooo`;oo`00
1Oooool3ool000_ooooo0ooo000<ooooo`;oo`001Oooool3ool000Cooooo0ooo0004ooooo`?oo`00
3?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`00
3?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool000kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Ooo
ool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`?oo`001Ooo
ool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool2ool000Gooooo0ooo0004ooooo`?oo`001?oo
ool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002ooo
ool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo000>ooooo`03o`000?oooooo
oooo00Cooooo0_l00006ooooo`?oo`001Oooool3ool000_ooooo0ooo000<ooooo`;oo`001Oooool2
ool000Gooooo0ooo0004ooooo`?oo`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2
ool000Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Cooooo0ooo0004ooooo`?oo`001?ooool3
ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3
ool000cooooo0ooo0004ooooo`?oo`001oooool2o`00007ooooo000>ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool3ool000Gooooo0ooo000;ooooo`?oo`003?ooool2ool0
00Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool0
00Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`001?ooool3ool0
00Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool0
00_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Sooooo0Ol00001ooooo`003_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002So
oooo0ooo0005ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool3ool002Wo
oooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`003Oooool2o`0000Kooooo
00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool3ool000Gooooo
0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`?oo`00:Oooool2ool000Gooooo
0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool3ool000Gooooo0_oo
000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`?oo`00:Oooool2ool000Gooooo0_oo
000Yooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo000Y
ooooo`;oo`001Oooool3ool002Sooooo0ooo0005ooooo`;oo`005Oooool00ol0003oooooooooo`0A
ooooo`?oo`001?ooool3ool002Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001
ooooo`005Oooool2o`0000Kooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo0ooo0005oooo
o`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool3ool002Wooooo0_oo0005oooo
o`;oo`00:Oooool3ool000Oooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?o
o`00:Oooool2ool000Gooooo0ooo000Xooooo`?oo`001Oooool2ool001Gooooo00?o0000oooooooo
ool04Oooool3ool000Cooooo0ooo000Yooooo`;oo`001Oooool2ool002Wooooo0ooo0008ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005ooooo`?oo`00
:?ooool3ool000Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`?oo`00
:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo0ooo0005ooooo`;oo`005Ooo
ool00ol0003oooooooooo`0Aooooo`?oo`001?ooool3ool002Wooooo0_oo0005ooooo`;oo`00:Ooo
ool3ool000Sooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2
ool000Gooooo0ooo000Xooooo`?oo`001Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3
ool000Cooooo0ooo000Yooooo`;oo`001Oooool2ool002Wooooo0ooo0008ooooo`7o00000Oooool0
01Gooooo0_l00006ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xooooo`?oo`001Oooool2ool0
01Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo0ooo000Yooooo`;oo`001Oooool2ool0
02Wooooo0ooo0007ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool002Wo
oooo0_oo0005ooooo`?oo`00:?ooool3ool000Gooooo0_oo000Eooooo`03o`000?oooooooooo017o
oooo0ooo0004ooooo`?oo`00:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo
0ooo0005ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool3ool002Wooooo
0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xooooo`?oo`001Oooool2ool001Gooooo00?o
0000ooooooooool04Oooool3ool000Cooooo0ooo000Yooooo`;oo`001Oooool2ool002Wooooo0ooo
0008ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005
ooooo`?oo`00:?ooool3ool000Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004
ooooo`?oo`00:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000Eoooo
o`;o00001_ooool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool3ool000Gooooo0_oo000Eoooo
o`03o`000?oooooooooo017ooooo0ooo0004ooooo`?oo`00:Oooool2ool000Gooooo0_oo000Yoooo
o`?oo`001oooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo000Yooooo`;o
o`001Oooool3ool002Sooooo0ooo0005ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?o
o`001?ooool3ool002Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xooooo`?oo`00
1Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo0ooo000Yooooo`;oo`00
1Oooool2ool002Wooooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01Ooo
ool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool3ool000Gooooo0_oo000Eooooo`03o`000?oo
oooooooo017ooooo0ooo0004ooooo`?oo`00:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?oo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3
ool002Sooooo0ooo0005ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool3
ool002Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`005Oooool2o`00
00Kooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo0ooo0005ooooo`;oo`005Oooool00ol0
003oooooooooo`0Aooooo`?oo`001?ooool3ool002Wooooo0_oo0005ooooo`;oo`00:Oooool3ool0
00Oooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Go
oooo0ooo000Xooooo`?oo`001Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Co
oooo0ooo000Yooooo`;oo`001Oooool2ool002Wooooo0ooo0008ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool3ool000Gooooo
0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`?oo`00:Oooool2ool000Gooooo
0_oo000Yooooo`?oo`002?ooool1o`00007ooooo00001?oooooo0000o`000?l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo0ooo000Yooooo`;oo`00
1Oooool3ool002Sooooo0ooo0005ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`00
1?ooool3ool002Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`000_oo
ool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xooooo`?oo`001Oooool2ool001Gooooo
00?o0000ooooooooool04Oooool3ool000Cooooo0ooo000Yooooo`;oo`001Oooool2ool002Wooooo
0ooo0008ooooo`7o00000Oooool000;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo0ooo
0005ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool3ool002Wooooo0_oo
0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`?oo`00:Oooool2ool000Gooooo0ooo000X
ooooo`?oo`001Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo0ooo000Y
ooooo`;oo`001Oooool2ool002Wooooo0ooo0007ooooo`;o00000Oooool000;ooooo00?o0000oooo
ooooool01oooool4o`0000Gooooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005oooo
o`?oo`00:?ooool3ool000Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004oooo
o`?oo`00:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo00000ooooooo
0000o`000009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool3ool002Wo
oooo0_oo0005ooooo`?oo`00:?ooool3ool000Gooooo0_oo000Eooooo`03o`000?oooooooooo017o
oooo0ooo0004ooooo`?oo`00:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007o
oooo0002ooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo00Gooooo
0ooo000Yooooo`;oo`001Oooool3ool002Sooooo0ooo0005ooooo`;oo`005Oooool00ol0003ooooo
ooooo`0Aooooo`?oo`001?ooool3ool002Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo
000Xooooo`?oo`001Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo0ooo
000Yooooo`;oo`001Oooool2ool002Wooooo0ooo0008ooooo`7o00000Oooool001Gooooo0_l00006
ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xooooo`?oo`001Oooool2ool001Gooooo00?o0000
ooooooooool04Oooool3ool000Cooooo0ooo000Yooooo`;oo`001Oooool2ool002Wooooo0ooo0007
ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005oooo
o`?oo`00:?ooool3ool000Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004oooo
o`?oo`00:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo0ooo0005ooooo`;o
o`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool3ool002Wooooo0_oo0005ooooo`;o
o`00:Oooool3ool000Sooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`00
:Oooool2ool000Gooooo0ooo000Xooooo`?oo`001Oooool2ool001Gooooo00?o0000ooooooooool0
4Oooool3ool000Cooooo0ooo000Yooooo`;oo`001Oooool2ool002Wooooo0ooo0008ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005ooooo`?oo`00:?oo
ool3ool000Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`?oo`00:Ooo
ool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000Eooooo`;o00001_ooool3
ool002Wooooo0_oo0005ooooo`?oo`00:?ooool3ool000Gooooo0_oo000Eooooo`03o`000?oooooo
oooo017ooooo0ooo0004ooooo`?oo`00:Oooool2ool000Gooooo0_oo000Yooooo`?oo`001oooool2
o`00007ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool0
02Sooooo0ooo0005ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool3ool0
02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xooooo`?oo`001Oooool2ool001Go
oooo00?o0000ooooooooool04Oooool3ool000Cooooo0ooo000Yooooo`;oo`001Oooool2ool002Wo
oooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool002Wooooo
0_oo0005ooooo`?oo`00:?ooool3ool000Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo
0ooo0004ooooo`?oo`00:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo
000Eooooo`03o`000?oooooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo0ooo
0005ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool3ool002Wooooo0_oo
0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`005Oooool2o`0000Kooooo0ooo000Y
ooooo`;oo`001Oooool3ool002Sooooo0ooo0005ooooo`;oo`005Oooool00ol0003oooooooooo`0A
ooooo`?oo`001?ooool3ool002Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Oooooo0_l00001
ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xoooo
o`?oo`001Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo0ooo000Yoooo
o`;oo`001Oooool2ool002Wooooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool01Oooool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool3ool000Gooooo0_oo000Eooooo`03
o`000?oooooooooo017ooooo0ooo0004ooooo`?oo`00:Oooool2ool000Gooooo0_oo000Yooooo`?o
o`002?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo000Yooooo`;oo`00
1Oooool3ool002Sooooo0ooo0005ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`00
1?ooool3ool002Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xooooo`?oo`001Ooo
ool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo0ooo000Yooooo`;oo`001Ooo
ool2ool002Wooooo0ooo0008ooooo`7o00000Oooool001Gooooo0_l00006ooooo`?oo`00:Oooool2
ool000Gooooo0ooo000Xooooo`?oo`001Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3
ool000Cooooo0ooo000Yooooo`;oo`001Oooool2ool002Wooooo0ooo0007ooooo`;o00000Oooool0
01Gooooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool3ool0
00Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`?oo`00:Oooool2ool0
00Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Go
oooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo0ooo0005ooooo`;oo`005Oooool00ol0003o
ooooooooo`0Aooooo`?oo`001?ooool3ool002Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000So
oooo0Ol00001ooooo`003?ooool5o`0000Cooooo00?o0000ooooooooool01Oooool3ool002Wooooo
0_oo0005ooooo`?oo`00:?ooool3ool000Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo
0ooo0004ooooo`?oo`00:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo
000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool3ool002Wooooo
0_oo0005ooooo`?oo`00:?ooool3ool000Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo
0ooo0004ooooo`?oo`00:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo
000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo
0005ooooo`?oo`00:?ooool3ool000Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo
0004ooooo`?oo`00:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000?
ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`?oo`00:Oooool3ool000Cooooo0ooo000X
ooooo`?oo`001Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo0ooo000Y
ooooo`;oo`001Oooool3ool002Sooooo0ooo0007ooooo`;o00000Oooool000cooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo0ooo000Yooooo`?oo`001?ooool3
ool002Sooooo0ooo0005ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool3
ool002Wooooo0_oo0005ooooo`?oo`00:?ooool3ool000Sooooo0Ol00001ooooo`003?ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003oooooooooo`20ooooo`;o0000
0Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo
0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`005Oooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22
ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?ooooo00?o0000ooooooooool0
P?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POoo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo
000Eooooo`;o0000Poooool00ol0003oooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool000Go00000oooool00ol0
003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
087ooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool000?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02ooooo`;o0000Poooool00ol0003oooooooooo`20ooooo`;o
00000Oooool00005o`000?ooooooooooooooool000001oooool4o`0000Gooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool00005o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool0POooool1o`00007ooooo00001?oooooo0000o`000?l00008ooooo`Go00001?ooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?ooooo00?o
0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003oooooooooo`20ooooo`;o00000Ooo
ool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023
ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2
o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00
007ooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087o
oooo0Ol00001ooooo`003?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool0013ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`003_oo
ool2o`0000Gooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`004?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1
o`00007ooooo000<ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`22
ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`003Oooool3o`0000Gooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l000000ooooooo0000
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool3o`00007ooooo
000Eoooooooo00002ol00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.6628, -0.260466, \
0.0691952, 0.0191323}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gXXs = Show[gXs, gX];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0544218 0.00393652 0.196826 [
[.09184 -0.0125 -12 -9 ]
[.09184 -0.0125 12 0 ]
[.22789 -0.0125 -6 -9 ]
[.22789 -0.0125 6 0 ]
[.36395 -0.0125 -12 -9 ]
[.36395 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.63605 -0.0125 -9 -9 ]
[.63605 -0.0125 9 0 ]
[.77211 -0.0125 -3 -9 ]
[.77211 -0.0125 3 0 ]
[.90816 -0.0125 -9 -9 ]
[.90816 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09184 0 m
.09184 .00625 L
s
[(-7.5)] .09184 -0.0125 0 1 Mshowa
.22789 0 m
.22789 .00625 L
s
[(-5)] .22789 -0.0125 0 1 Mshowa
.36395 0 m
.36395 .00625 L
s
[(-2.5)] .36395 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.63605 0 m
.63605 .00625 L
s
[(2.5)] .63605 -0.0125 0 1 Mshowa
.77211 0 m
.77211 .00625 L
s
[(5)] .77211 -0.0125 0 1 Mshowa
.90816 0 m
.90816 .00625 L
s
[(7.5)] .90816 -0.0125 0 1 Mshowa
.125 Mabswid
.11905 0 m
.11905 .00375 L
s
.14626 0 m
.14626 .00375 L
s
.17347 0 m
.17347 .00375 L
s
.20068 0 m
.20068 .00375 L
s
.2551 0 m
.2551 .00375 L
s
.28231 0 m
.28231 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.33673 0 m
.33673 .00375 L
s
.39116 0 m
.39116 .00375 L
s
.41837 0 m
.41837 .00375 L
s
.44558 0 m
.44558 .00375 L
s
.47279 0 m
.47279 .00375 L
s
.52721 0 m
.52721 .00375 L
s
.55442 0 m
.55442 .00375 L
s
.58163 0 m
.58163 .00375 L
s
.60884 0 m
.60884 .00375 L
s
.66327 0 m
.66327 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.71769 0 m
.71769 .00375 L
s
.7449 0 m
.7449 .00375 L
s
.79932 0 m
.79932 .00375 L
s
.82653 0 m
.82653 .00375 L
s
.85374 0 m
.85374 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.06463 0 m
.06463 .00375 L
s
.03741 0 m
.03741 .00375 L
s
.0102 0 m
.0102 .00375 L
s
.93537 0 m
.93537 .00375 L
s
.96259 0 m
.96259 .00375 L
s
.9898 0 m
.9898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09184 .61178 m
.09184 .61803 L
s
.22789 .61178 m
.22789 .61803 L
s
.36395 .61178 m
.36395 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.63605 .61178 m
.63605 .61803 L
s
.77211 .61178 m
.77211 .61803 L
s
.90816 .61178 m
.90816 .61803 L
s
.125 Mabswid
.11905 .61428 m
.11905 .61803 L
s
.14626 .61428 m
.14626 .61803 L
s
.17347 .61428 m
.17347 .61803 L
s
.20068 .61428 m
.20068 .61803 L
s
.2551 .61428 m
.2551 .61803 L
s
.28231 .61428 m
.28231 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.33673 .61428 m
.33673 .61803 L
s
.39116 .61428 m
.39116 .61803 L
s
.41837 .61428 m
.41837 .61803 L
s
.44558 .61428 m
.44558 .61803 L
s
.47279 .61428 m
.47279 .61803 L
s
.52721 .61428 m
.52721 .61803 L
s
.55442 .61428 m
.55442 .61803 L
s
.58163 .61428 m
.58163 .61803 L
s
.60884 .61428 m
.60884 .61803 L
s
.66327 .61428 m
.66327 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.71769 .61428 m
.71769 .61803 L
s
.7449 .61428 m
.7449 .61803 L
s
.79932 .61428 m
.79932 .61803 L
s
.82653 .61428 m
.82653 .61803 L
s
.85374 .61428 m
.85374 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.06463 .61428 m
.06463 .61803 L
s
.03741 .61428 m
.03741 .61803 L
s
.0102 .61428 m
.0102 .61803 L
s
.93537 .61428 m
.93537 .61803 L
s
.96259 .61428 m
.96259 .61803 L
s
.9898 .61428 m
.9898 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .00394 m
.02567 .00394 L
.02769 .00394 L
.0296 .00394 L
.03143 .00394 L
.03338 .00394 L
.03428 .00394 L
.03525 .00394 L
.03551 .00394 L
.03578 .00394 L
.0359 .00394 L
.03596 .00394 L
.03602 .00394 L
.03605 .00394 L
.03609 .39759 L
.03615 .39759 L
.03628 .39759 L
.03724 .39759 L
.03819 .39759 L
.03846 .39759 L
.0386 .39759 L
.03866 .39759 L
.03869 .39759 L
.03872 .39759 L
.03878 .00394 L
.03883 .00394 L
.03895 .00394 L
.0392 .00394 L
.04119 .00394 L
.04311 .00394 L
.04495 .00394 L
.04691 .00394 L
.0488 .00394 L
.05061 .00394 L
.05255 .00394 L
.05441 .00394 L
.05639 .00394 L
.05829 .00394 L
.06013 .00394 L
.06115 .00394 L
.06208 .00394 L
.06254 .00394 L
.06278 .00394 L
.06292 .00394 L
.06304 .00394 L
.06315 .00394 L
.06321 .00394 L
.06327 .20076 L
.06333 .20076 L
.0634 .20076 L
Mistroke
.06352 .20076 L
.06396 .20076 L
.06498 .20076 L
.06547 .20076 L
.06568 .20076 L
.0658 .20076 L
.06586 .20076 L
.06591 .20076 L
.06597 .20076 L
.06602 .00394 L
.06608 .00394 L
.06614 .00394 L
.06638 .00394 L
.06688 .00394 L
.0678 .00394 L
.06976 .00394 L
.07165 .00394 L
.07347 .00394 L
.07541 .00394 L
.07727 .00394 L
.07925 .00394 L
.08116 .00394 L
.08299 .00394 L
.08495 .00394 L
.08683 .00394 L
.08883 .00394 L
.09075 .00394 L
.0926 .00394 L
.09458 .00394 L
.09647 .00394 L
.0983 .00394 L
.10024 .00394 L
.10211 .00394 L
.1041 .00394 L
.10601 .00394 L
.10785 .00394 L
.10981 .00394 L
.1117 .00394 L
.11352 .00394 L
.11545 .00394 L
.11634 .00394 L
.11684 .00394 L
.11708 .00394 L
.11731 .00394 L
.11742 .00394 L
.11755 .00394 L
.1176 .00394 L
.11766 .00394 L
.11772 .20076 L
.11777 .20076 L
Mistroke
.11827 .20076 L
.11928 .20076 L
.11976 .20076 L
.12 .20076 L
.12022 .20076 L
.12034 .20076 L
.12037 .20076 L
.12041 .20076 L
.12047 .00394 L
.1205 .00394 L
.12054 .00394 L
.1206 .00394 L
.12074 .00394 L
.12122 .00394 L
.12305 .00394 L
.125 .00394 L
.12687 .00394 L
.12886 .00394 L
.13078 .00394 L
.13262 .00394 L
.13458 .00394 L
.13647 .00394 L
.13829 .00394 L
.14022 .00394 L
.14208 .00394 L
.14406 .00394 L
.14597 .00394 L
.1478 .00394 L
.14976 .00394 L
.15164 .00394 L
.15363 .00394 L
.15556 .00394 L
.15741 .00394 L
.15938 .00394 L
.16127 .00394 L
.1631 .00394 L
.16504 .00394 L
.1669 .00394 L
.16889 .00394 L
.16988 .00394 L
.1708 .00394 L
.17126 .00394 L
.1717 .00394 L
.17194 .00394 L
.172 .00394 L
.17204 .00394 L
.17207 .00394 L
.17213 .20076 L
.17216 .20076 L
.17219 .20076 L
Mistroke
.17264 .20076 L
.1736 .20076 L
.1741 .20076 L
.17438 .20076 L
.17451 .20076 L
.17464 .20076 L
.17469 .20076 L
.17475 .20076 L
.17481 .20076 L
.17487 .00394 L
.17493 .00394 L
.17499 .00394 L
.17511 .00394 L
.17564 .00394 L
.17656 .00394 L
.17848 .00394 L
.18034 .00394 L
.18231 .00394 L
.18421 .00394 L
.18603 .00394 L
.18798 .00394 L
.18985 .00394 L
.19184 .00394 L
.19375 .00394 L
.1956 .00394 L
.19653 .00394 L
.19756 .00394 L
.19802 .00394 L
.19853 .00394 L
.19876 .00394 L
.19901 .00394 L
.19911 .00394 L
.19922 .00394 L
.19928 .00394 L
.19933 .39759 L
.19939 .39759 L
.19944 .39759 L
.20032 .39759 L
.20083 .39759 L
.20129 .39759 L
.20175 .39759 L
.20189 .39759 L
.20195 .39759 L
.20201 .39759 L
.20207 .00394 L
.20213 .00394 L
.20225 .00394 L
.20326 .00394 L
.20526 .00394 L
.20719 .00394 L
Mistroke
.20905 .00394 L
.21102 .00394 L
.21292 .00394 L
.21475 .00394 L
.2167 .00394 L
.21857 .00394 L
.22056 .00394 L
.22248 .00394 L
.22433 .00394 L
.22526 .00394 L
.22576 .00394 L
.22602 .00394 L
.22616 .00394 L
.22629 .00394 L
.22641 .00394 L
.22644 .00394 L
.22647 .00394 L
.22653 .39759 L
.22656 .39759 L
.2266 .39759 L
.22666 .39759 L
.2268 .39759 L
.22726 .39759 L
.22818 .39759 L
.22863 .39759 L
.22888 .39759 L
.22901 .39759 L
.22912 .39759 L
.22918 .39759 L
.22923 .39759 L
.22928 .00394 L
.22934 .00394 L
.22958 .00394 L
.23 .00394 L
.23186 .00394 L
.23384 .00394 L
.23574 .00394 L
.23757 .00394 L
.23952 .00394 L
.2414 .00394 L
.24339 .00394 L
.24531 .00394 L
.24716 .00394 L
.24913 .00394 L
.25102 .00394 L
.25197 .00394 L
.25284 .00394 L
.25307 .00394 L
.25332 .00394 L
.25343 .00394 L
Mistroke
.25355 .00394 L
.25361 .00394 L
.25367 .00394 L
.25372 .00394 L
.25377 .20076 L
.25384 .20076 L
.25389 .20076 L
.25403 .20076 L
.2543 .20076 L
.25478 .20076 L
.25528 .20076 L
.25576 .20076 L
.25618 .20076 L
.2563 .20076 L
.25637 .20076 L
.25643 .20076 L
.25648 .00394 L
.25653 .00394 L
.25665 .00394 L
.25863 .00394 L
.26053 .00394 L
.26237 .00394 L
.26432 .00394 L
.2662 .00394 L
.26819 .00394 L
.27012 .00394 L
.27197 .00394 L
.27394 .00394 L
.27583 .00394 L
.27765 .00394 L
.27959 .00394 L
.28146 .00394 L
.28345 .00394 L
.28536 .00394 L
.2872 .00394 L
.28916 .00394 L
.29104 .00394 L
.29304 .00394 L
.29497 .00394 L
.29683 .00394 L
.29881 .00394 L
.30071 .00394 L
.30254 .00394 L
.30449 .00394 L
.30636 .00394 L
.30685 .00394 L
.30738 .00394 L
.30763 .00394 L
.30789 .00394 L
.30799 .00394 L
Mistroke
.30805 .00394 L
.30811 .00394 L
.30814 .00394 L
.30817 .20076 L
.30823 .20076 L
.30835 .20076 L
.30938 .20076 L
.31031 .20076 L
.31053 .20076 L
.31065 .20076 L
.31077 .20076 L
.31083 .20076 L
.31086 .20076 L
.3109 .00394 L
.31093 .00394 L
.31097 .00394 L
.31103 .00394 L
.31127 .00394 L
.31219 .00394 L
.31415 .00394 L
.31603 .00394 L
.31785 .00394 L
.31978 .00394 L
.32164 .00394 L
.32362 .00394 L
.32552 .00394 L
.32735 .00394 L
.3293 .00394 L
.33118 .00394 L
.33318 .00394 L
.3351 .00394 L
.33695 .00394 L
.33891 .00394 L
.34081 .00394 L
.34263 .00394 L
.34457 .00394 L
.34643 .00394 L
.34842 .00394 L
.35033 .00394 L
.35217 .00394 L
.35412 .00394 L
.35601 .00394 L
.35801 .00394 L
.35994 .00394 L
.36082 .00394 L
.36132 .00394 L
.36179 .00394 L
.36225 .00394 L
.36239 .00394 L
.36245 .00394 L
Mistroke
.36251 .00394 L
.36257 .00394 L
.36263 .20076 L
.36269 .20076 L
.36275 .20076 L
.36376 .20076 L
.3647 .20076 L
.36495 .20076 L
.36509 .20076 L
.36516 .20076 L
.36522 .20076 L
.36528 .20076 L
.36533 .00394 L
.36539 .00394 L
.36545 .00394 L
.3657 .00394 L
.36767 .00394 L
.36957 .00394 L
.37139 .00394 L
.37333 .00394 L
.3752 .00394 L
.37719 .00394 L
.3791 .00394 L
.38094 .00394 L
.3829 .00394 L
.38478 .00394 L
.38679 .00394 L
.38779 .00394 L
.38872 .00394 L
.38919 .00394 L
.38942 .00394 L
.38962 .00394 L
.38968 .00394 L
.38974 .00394 L
.38979 .00394 L
.38984 .39759 L
.3899 .39759 L
.38996 .39759 L
.39008 .39759 L
.39058 .39759 L
.39159 .39759 L
.39207 .39759 L
.3923 .39759 L
.3924 .39759 L
.39246 .39759 L
.39251 .39759 L
.39257 .00394 L
.39263 .00394 L
.39274 .00394 L
.39297 .00394 L
Mistroke
.39347 .00394 L
.39438 .00394 L
.39621 .00394 L
.39815 .00394 L
.40002 .00394 L
.40201 .00394 L
.40393 .00394 L
.40577 .00394 L
.40773 .00394 L
.40962 .00394 L
.41143 .00394 L
.41337 .00394 L
.41523 .00394 L
.41619 .00394 L
.41668 .00394 L
.41681 .00394 L
.41688 .00394 L
.41692 .00394 L
.41695 .00394 L
.41698 .00394 L
.41701 .39759 L
.41705 .39759 L
.41708 .39759 L
.41721 .39759 L
.41822 .39759 L
.41915 .39759 L
.41937 .39759 L
.41949 .39759 L
.4196 .39759 L
.41967 .39759 L
.41971 .39759 L
.41974 .00394 L
.4198 .00394 L
.41986 .00394 L
.4201 .00394 L
.42101 .00394 L
.42284 .00394 L
.42479 .00394 L
.42666 .00394 L
.42865 .00394 L
.43057 .00394 L
.43242 .00394 L
.43438 .00394 L
.43627 .00394 L
.43809 .00394 L
.44003 .00394 L
.44189 .00394 L
.44284 .00394 L
.44334 .00394 L
.44361 .00394 L
Mistroke
.44387 .00394 L
.44399 .00394 L
.44412 .00394 L
.44415 .00394 L
.44419 .00394 L
.44422 .20076 L
.44426 .20076 L
.44439 .20076 L
.44486 .20076 L
.44578 .20076 L
.44627 .20076 L
.44652 .20076 L
.44667 .20076 L
.4468 .20076 L
.44685 .20076 L
.44691 .20076 L
.44694 .00394 L
.44698 .00394 L
.44704 .00394 L
.4473 .00394 L
.44777 .00394 L
.44972 .00394 L
.45159 .00394 L
.45359 .00394 L
.45551 .00394 L
.45735 .00394 L
.45932 .00394 L
.46121 .00394 L
.46303 .00394 L
.46497 .00394 L
.46684 .00394 L
.46882 .00394 L
.47073 .00394 L
.47257 .00394 L
.47453 .00394 L
.47641 .00394 L
.47841 .00394 L
.48034 .00394 L
.48219 .00394 L
.48416 .00394 L
.48606 .00394 L
.48789 .00394 L
.48984 .00394 L
.49171 .00394 L
.4937 .00394 L
.49562 .00394 L
.49746 .00394 L
.49795 .00394 L
.49819 .00394 L
.49841 .00394 L
Mistroke
.49852 .00394 L
.49858 .00394 L
.49864 .20076 L
.49871 .20076 L
.49877 .20076 L
.49889 .20076 L
.49942 .20076 L
.49992 .20076 L
.50045 .20076 L
.50069 .20076 L
.50095 .20076 L
.50118 .20076 L
.50124 .20076 L
.50127 .20076 L
.5013 .20076 L
.50136 .00394 L
.50142 .00394 L
.50326 .00394 L
.50522 .00394 L
.5071 .00394 L
.50911 .00394 L
.51104 .00394 L
.51289 .00394 L
.51487 .00394 L
.51677 .00394 L
.5186 .00394 L
.52055 .00394 L
.52242 .00394 L
.52442 .00394 L
.52634 .00394 L
.52818 .00394 L
.53015 .00394 L
.53204 .00394 L
.53386 .00394 L
.53579 .00394 L
.53766 .00394 L
.53964 .00394 L
.54155 .00394 L
.54339 .00394 L
.54534 .00394 L
.54722 .00394 L
.54922 .00394 L
.55115 .00394 L
.55203 .00394 L
.55253 .00394 L
.55278 .00394 L
.55289 .00394 L
.553 .00394 L
.55305 .00394 L
.55311 .20076 L
Mistroke
.55317 .20076 L
.55324 .20076 L
.55346 .20076 L
.55396 .20076 L
.55449 .20076 L
.55497 .20076 L
.55542 .20076 L
.55565 .20076 L
.55571 .20076 L
.55575 .20076 L
.55578 .20076 L
.55584 .00394 L
.5559 .00394 L
.5569 .00394 L
.55875 .00394 L
.56072 .00394 L
.56261 .00394 L
.56444 .00394 L
.56637 .00394 L
.56824 .00394 L
.57023 .00394 L
.57214 .00394 L
.57398 .00394 L
.57593 .00394 L
.57782 .00394 L
.57878 .00394 L
.57928 .00394 L
.57956 .00394 L
.57982 .00394 L
.58005 .00394 L
.58012 .00394 L
.58018 .00394 L
.58024 .00394 L
.5803 .39759 L
.58036 .39759 L
.58043 .39759 L
.58057 .39759 L
.58082 .39759 L
.58175 .39759 L
.5822 .39759 L
.58268 .39759 L
.5828 .39759 L
.58287 .39759 L
.58293 .39759 L
.58296 .39759 L
.583 .00394 L
.58304 .00394 L
.58307 .00394 L
.5832 .00394 L
.58368 .00394 L
Mistroke
.58558 .00394 L
.5874 .00394 L
.58934 .00394 L
.59121 .00394 L
.5932 .00394 L
.59511 .00394 L
.59696 .00394 L
.59891 .00394 L
.6008 .00394 L
.60261 .00394 L
.60455 .00394 L
.6064 .00394 L
.6069 .00394 L
.60714 .00394 L
.60725 .00394 L
.60737 .00394 L
.60743 .00394 L
.60749 .39759 L
.60754 .39759 L
.6076 .39759 L
.60785 .39759 L
.60838 .39759 L
.60933 .39759 L
.60975 .39759 L
.60997 .39759 L
.61009 .39759 L
.61015 .39759 L
.6102 .39759 L
.61026 .00394 L
.6103 .00394 L
.61033 .00394 L
.61045 .00394 L
.61068 .00394 L
.61113 .00394 L
.61214 .00394 L
.61396 .00394 L
.61591 .00394 L
.61778 .00394 L
.61977 .00394 L
.62169 .00394 L
.62353 .00394 L
.62549 .00394 L
.62738 .00394 L
.6292 .00394 L
.63113 .00394 L
.63299 .00394 L
.63395 .00394 L
.63419 .00394 L
.63444 .00394 L
.63451 .00394 L
Mistroke
.63458 .00394 L
.63465 .00394 L
.63468 .00394 L
.63471 .20076 L
.63477 .20076 L
.63484 .20076 L
.63497 .20076 L
.63598 .20076 L
.63691 .20076 L
.63713 .20076 L
.63725 .20076 L
.63731 .20076 L
.63737 .20076 L
.6374 .20076 L
.63743 .00394 L
.63747 .00394 L
.6375 .00394 L
.63763 .00394 L
.63787 .00394 L
.63878 .00394 L
.64072 .00394 L
.6426 .00394 L
.64459 .00394 L
.64651 .00394 L
.64836 .00394 L
.65032 .00394 L
.65221 .00394 L
.65403 .00394 L
.65597 .00394 L
.65783 .00394 L
.65981 .00394 L
.66172 .00394 L
.66355 .00394 L
.66551 .00394 L
.66739 .00394 L
.66939 .00394 L
.67131 .00394 L
.67316 .00394 L
.67514 .00394 L
.67703 .00394 L
.67886 .00394 L
.6808 .00394 L
.68267 .00394 L
.68466 .00394 L
.68657 .00394 L
.68745 .00394 L
.68795 .00394 L
.68842 .00394 L
.68864 .00394 L
.68887 .00394 L
Mistroke
.689 .00394 L
.68903 .00394 L
.68907 .00394 L
.6891 .00394 L
.68913 .20076 L
.68919 .20076 L
.68925 .20076 L
.68937 .20076 L
.69038 .20076 L
.69133 .20076 L
.69156 .20076 L
.69169 .20076 L
.69175 .20076 L
.69181 .20076 L
.69185 .00394 L
.69188 .00394 L
.69196 .00394 L
.69209 .00394 L
.69234 .00394 L
.69434 .00394 L
.69627 .00394 L
.69813 .00394 L
.7001 .00394 L
.702 .00394 L
.70383 .00394 L
.70577 .00394 L
.70765 .00394 L
.70964 .00394 L
.71155 .00394 L
.7134 .00394 L
.71536 .00394 L
.71725 .00394 L
.71907 .00394 L
.721 .00394 L
.72286 .00394 L
.72484 .00394 L
.72675 .00394 L
.72858 .00394 L
.73054 .00394 L
.73242 .00394 L
.73441 .00394 L
.73634 .00394 L
.73819 .00394 L
.74016 .00394 L
.74114 .00394 L
.74205 .00394 L
.74293 .00394 L
.74319 .00394 L
.74331 .00394 L
.74343 .00394 L
Mistroke
.74348 .00394 L
.74353 .00394 L
.74359 .20076 L
.74364 .20076 L
.74388 .20076 L
.74476 .20076 L
.74527 .20076 L
.74573 .20076 L
.74597 .20076 L
.74609 .20076 L
.74614 .20076 L
.7462 .20076 L
.74626 .00394 L
.74629 .00394 L
.74632 .00394 L
.74646 .00394 L
.7467 .00394 L
.74771 .00394 L
.74957 .00394 L
.75156 .00394 L
.75347 .00394 L
.7553 .00394 L
.75726 .00394 L
.75914 .00394 L
.76114 .00394 L
.76306 .00394 L
.76492 .00394 L
.76689 .00394 L
.76879 .00394 L
.76974 .00394 L
.77016 .00394 L
.77038 .00394 L
.77061 .00394 L
.77067 .00394 L
.77073 .00394 L
.77077 .39759 L
.7708 .39759 L
.77086 .39759 L
.7711 .39759 L
.77155 .39759 L
.77256 .39759 L
.773 .39759 L
.77324 .39759 L
.77336 .39759 L
.77341 .39759 L
.77347 .39759 L
.77353 .00394 L
.77357 .00394 L
.7736 .00394 L
.77374 .00394 L
Mistroke
.77398 .00394 L
.77446 .00394 L
.77633 .00394 L
.77831 .00394 L
.78023 .00394 L
.78207 .00394 L
.78402 .00394 L
.78591 .00394 L
.78791 .00394 L
.78984 .00394 L
.79169 .00394 L
.79367 .00394 L
.79557 .00394 L
.79653 .00394 L
.7974 .00394 L
.79763 .00394 L
.79775 .00394 L
.79782 .00394 L
.79788 .00394 L
.79793 .00394 L
.79799 .39759 L
.79803 .39759 L
.79806 .39759 L
.79812 .39759 L
.79834 .39759 L
.79934 .39759 L
.7998 .39759 L
.80006 .39759 L
.8003 .39759 L
.80052 .39759 L
.80058 .39759 L
.80061 .39759 L
.80064 .39759 L
.8007 .00394 L
.80076 .00394 L
.80118 .00394 L
.80305 .00394 L
.80504 .00394 L
.80695 .00394 L
.80879 .00394 L
.81075 .00394 L
.81264 .00394 L
.81445 .00394 L
.81638 .00394 L
.81824 .00394 L
.82022 .00394 L
.82212 .00394 L
.82395 .00394 L
.82444 .00394 L
.82489 .00394 L
Mistroke
.82502 .00394 L
.82508 .00394 L
.82515 .00394 L
.82518 .20076 L
.82522 .20076 L
.82529 .20076 L
.82542 .20076 L
.8259 .20076 L
.82685 .20076 L
.82735 .20076 L
.82763 .20076 L
.82776 .20076 L
.82782 .20076 L
.82785 .20076 L
.82788 .20076 L
.82795 .00394 L
.82801 .00394 L
.82813 .00394 L
.8284 .00394 L
.82888 .00394 L
.8298 .00394 L
.83179 .00394 L
.8337 .00394 L
.83555 .00394 L
.83751 .00394 L
.8394 .00394 L
.84121 .00394 L
.84315 .00394 L
.84501 .00394 L
.84699 .00394 L
.84889 .00394 L
.85073 .00394 L
.85268 .00394 L
.85456 .00394 L
.85655 .00394 L
.85848 .00394 L
.86033 .00394 L
.8623 .00394 L
.86419 .00394 L
.86601 .00394 L
.86796 .00394 L
.86982 .00394 L
.87181 .00394 L
.87372 .00394 L
.87556 .00394 L
.87752 .00394 L
.87843 .00394 L
.8789 .00394 L
.87916 .00394 L
.8794 .00394 L
Mistroke
.87947 .00394 L
.87953 .00394 L
.87956 .00394 L
.8796 .20076 L
.87966 .20076 L
.87994 .20076 L
.88044 .20076 L
.8809 .20076 L
.88141 .20076 L
.88164 .20076 L
.8819 .20076 L
.88202 .20076 L
.88214 .20076 L
.88225 .20076 L
.88231 .20076 L
.88236 .00394 L
.88242 .00394 L
.88249 .00394 L
.88262 .00394 L
.88285 .00394 L
.88337 .00394 L
.88534 .00394 L
.88724 .00394 L
.88907 .00394 L
.89101 .00394 L
.89288 .00394 L
.89487 .00394 L
.89678 .00394 L
.89863 .00394 L
.90059 .00394 L
.90247 .00394 L
.90429 .00394 L
.90622 .00394 L
.90808 .00394 L
.91006 .00394 L
.91196 .00394 L
.91379 .00394 L
.91574 .00394 L
.91762 .00394 L
.91962 .00394 L
.92154 .00394 L
.92339 .00394 L
.92535 .00394 L
.92725 .00394 L
.92907 .00394 L
.93101 .00394 L
.93288 .00394 L
.93336 .00394 L
.93362 .00394 L
.93376 .00394 L
Mistroke
.93383 .00394 L
.93389 .00394 L
.93395 .00394 L
.93399 .00394 L
.93402 .20076 L
.93405 .20076 L
.93409 .20076 L
.93416 .20076 L
.93439 .20076 L
.93486 .20076 L
.93535 .20076 L
.93588 .20076 L
.93613 .20076 L
.93638 .20076 L
.93661 .20076 L
.93667 .20076 L
.9367 .20076 L
.93673 .20076 L
.93679 .00394 L
.93685 .00394 L
.93868 .00394 L
.94064 .00394 L
.94252 .00394 L
.94451 .00394 L
.94644 .00394 L
.94829 .00394 L
.95026 .00394 L
.95216 .00394 L
.95398 .00394 L
.95592 .00394 L
.95779 .00394 L
.95874 .00394 L
.95978 .00394 L
.96026 .00394 L
.96052 .00394 L
.96077 .00394 L
.961 .00394 L
.96107 .00394 L
.96113 .00394 L
.96119 .00394 L
.96125 .39759 L
.96131 .39759 L
.96136 .39759 L
.96148 .39759 L
.96169 .39759 L
.96269 .39759 L
.96313 .39759 L
.96336 .39759 L
.96361 .39759 L
.96373 .39759 L
Mistroke
.9638 .39759 L
.96385 .39759 L
.9639 .39759 L
.96396 .00394 L
.96402 .00394 L
.96407 .00394 L
.96451 .00394 L
.96546 .00394 L
.96738 .00394 L
.96924 .00394 L
.97121 .00394 L
.97311 .00394 L
.97494 .00394 L
.97619 .00394 L
Mfstroke
0 0 1 r
.005 w
.02381 .00394 m
.02474 .00394 L
.02575 .00394 L
.0267 .00394 L
.02761 .00394 L
.02859 .00394 L
.02952 .00394 L
.03052 .00394 L
.03148 .00394 L
.0324 .00394 L
.03338 .00394 L
.03433 .00394 L
.03524 .00394 L
.03621 .00394 L
.03714 .00394 L
.03813 .00394 L
.03908 .00394 L
.04 .00394 L
.04098 .00394 L
.04192 .00394 L
.04292 .00394 L
.04388 .00394 L
.0448 .00394 L
.04579 .00394 L
.04674 .00394 L
.04765 .00394 L
.04862 .00394 L
.04956 .00394 L
.05055 .00394 L
.05151 .00394 L
.05243 .00394 L
.05341 .00394 L
.05435 .00394 L
.05526 .00394 L
.05622 .00394 L
.05715 .00394 L
.05814 .00394 L
.05909 .00394 L
.06001 .00394 L
.06098 .00394 L
.06192 .00394 L
.06292 .00394 L
.06388 .00394 L
.0648 .00394 L
.06579 .00394 L
.06673 .00394 L
.06764 .00394 L
.06861 .00394 L
.06954 .00394 L
.07054 .00394 L
Mistroke
.07149 .00394 L
.07241 .00394 L
.07339 .00394 L
.07433 .00394 L
.07533 .00394 L
.07629 .00394 L
.07722 .00394 L
.07821 .00394 L
.07916 .00394 L
.08007 .00394 L
.08104 .00394 L
.08198 .00394 L
.08297 .00394 L
.08393 .00394 L
.08485 .00394 L
.08584 .00394 L
.08678 .00394 L
.08769 .00394 L
.08866 .00394 L
.08959 .00394 L
.09058 .00394 L
.09153 .00394 L
.09245 .00394 L
.09342 .00394 L
.09436 .00394 L
.09536 .00394 L
.09632 .00394 L
.09725 .00394 L
.09823 .00394 L
.09918 .00394 L
.10009 .00394 L
.10106 .00394 L
.10199 .00394 L
.10299 .00394 L
.10394 .00394 L
.10486 .00394 L
.10584 .00394 L
.10678 .00394 L
.10769 .00394 L
.10866 .00394 L
.10958 .00394 L
.11057 .00394 L
.11152 .00394 L
.11244 .00394 L
.11341 .00394 L
.11435 .00394 L
.11535 .00394 L
.1163 .00394 L
.11723 .00394 L
.11821 .00394 L
Mistroke
.11916 .00394 L
.12007 .00394 L
.12103 .00394 L
.12197 .00394 L
.12296 .00394 L
.12391 .00394 L
.12483 .00394 L
.12581 .00394 L
.12675 .00394 L
.12775 .00394 L
.12871 .00394 L
.12964 .00394 L
.13062 .00394 L
.13157 .00394 L
.13248 .00394 L
.13345 .00394 L
.13439 .00394 L
.13538 .00394 L
.13634 .00394 L
.13726 .00394 L
.13824 .00394 L
.13919 .00394 L
.14009 .00394 L
.14106 .00394 L
.14199 .00394 L
.14298 .00394 L
.14393 .00394 L
.14485 .00394 L
.14582 .00394 L
.14676 .00394 L
.14776 .00394 L
.14872 .00394 L
.14964 .00394 L
.15063 .00394 L
.15158 .00394 L
.15249 .00394 L
.15346 .00394 L
.15439 .00394 L
.15538 .00394 L
.15634 .00394 L
.15726 .00394 L
.15823 .00394 L
.15918 .00394 L
.16018 .00394 L
.16114 .00394 L
.16207 .00394 L
.16306 .00394 L
.16401 .00394 L
.16492 .00394 L
.16589 .00394 L
Mistroke
.16683 .00394 L
.16782 .00394 L
.16878 .00394 L
.16971 .00394 L
.17069 .00394 L
.17163 .00394 L
.17254 .00394 L
.17351 .00394 L
.17444 .00394 L
.17543 .00394 L
.17638 .00394 L
.1773 .00394 L
.17828 .00394 L
.17922 .00394 L
.18022 .00394 L
.18118 .00394 L
.1821 .00394 L
.18309 .00394 L
.18404 .00394 L
.18495 .00394 L
.18592 .00394 L
.18685 .00394 L
.18785 .00394 L
.1888 .00394 L
.18972 .00394 L
.1907 .00394 L
.19165 .00394 L
.19255 .00394 L
.19352 .00394 L
.19445 .00394 L
.19544 .00394 L
.19639 .00394 L
.1973 .00394 L
.19828 .00394 L
.19922 .00394 L
.20021 .00394 L
.20117 .00394 L
.2021 .00394 L
.20308 .00394 L
.20403 .00394 L
.20494 .00394 L
.2059 .00394 L
.20684 .00394 L
.20783 .00394 L
.20878 .00394 L
.2097 .00394 L
.21068 .00394 L
.21162 .00394 L
.21262 .00394 L
.21358 .00394 L
Mistroke
.21451 .00394 L
.2155 .00394 L
.21645 .00394 L
.21736 .00394 L
.21833 .00394 L
.21927 .00394 L
.22026 .00394 L
.22122 .00394 L
.22214 .00394 L
.22312 .00394 L
.22407 .00394 L
.22497 .00394 L
.22594 .00394 L
.22687 .00394 L
.22786 .00394 L
.22881 .00394 L
.22973 .00394 L
.23071 .00394 L
.23164 .00394 L
.23264 .00394 L
.2336 .00394 L
.23453 .00394 L
.23551 .00394 L
.23646 .00394 L
.23737 .00394 L
.23834 .00394 L
.23928 .00394 L
.24027 .00394 L
.24122 .00394 L
.24214 .00394 L
.24312 .00394 L
.24406 .00394 L
.24497 .00394 L
.24594 .00394 L
.24686 .00394 L
.24785 .00394 L
.2488 .00394 L
.24972 .00394 L
.25069 .00394 L
.25163 .00394 L
.25262 .00394 L
.25358 .00394 L
.25451 .00394 L
.25549 .00394 L
.25643 .00394 L
.25734 .00394 L
.25831 .00394 L
.25924 .00394 L
.26023 .00394 L
.26119 .00394 L
Mistroke
.2621 .00394 L
.26308 .00394 L
.26402 .00394 L
.26502 .00394 L
.26598 .00394 L
.26691 .00394 L
.26789 .00394 L
.26884 .00394 L
.26976 .00394 L
.27073 .00394 L
.27166 .00394 L
.27266 .00394 L
.27361 .00394 L
.27453 .00394 L
.27551 .00394 L
.27646 .00394 L
.27736 .00394 L
.27833 .00394 L
.27926 .00394 L
.28025 .00394 L
.2812 .00394 L
.28212 .00394 L
.28309 .00394 L
.28403 .00394 L
.28503 .00394 L
.28599 .00394 L
.28691 .00394 L
.28789 .00394 L
.28884 .00394 L
.28975 .00394 L
.29072 .00394 L
.29165 .00394 L
.29265 .00394 L
.2936 .00394 L
.29452 .00394 L
.2955 .00394 L
.29644 .00394 L
.29744 .00394 L
.2984 .00394 L
.29933 .00394 L
.30032 .00394 L
.30127 .00394 L
.30218 .00394 L
.30315 .00394 L
.30409 .00394 L
.30509 .00394 L
.30604 .00394 L
.30697 .00394 L
.30795 .00394 L
.30889 .00394 L
Mistroke
.3098 .00394 L
.31077 .00394 L
.3117 .00394 L
.31269 .00394 L
.31364 .00394 L
.31456 .00394 L
.31554 .00394 L
.31647 .00394 L
.31747 .00394 L
.31844 .00394 L
.31936 .00394 L
.32035 .00394 L
.32129 .00394 L
.3222 .00394 L
.32318 .00394 L
.32411 .00394 L
.3251 .00394 L
.32606 .00394 L
.32698 .00394 L
.32796 .00394 L
.3289 .00394 L
.32981 .00394 L
.33077 .00394 L
.3317 .00394 L
.33269 .00394 L
.33364 .00394 L
.33456 .00394 L
.33553 .00394 L
.33647 .00394 L
.33746 .00394 L
.33842 .00394 L
.33935 .00394 L
.34033 .00394 L
.34128 .00394 L
.34218 .00394 L
.34315 .00394 L
.34409 .00394 L
.34508 .00394 L
.34603 .00394 L
.34695 .00394 L
.34793 .00394 L
.34887 .00394 L
.34987 .00394 L
.35083 .00394 L
.35176 .00394 L
.35274 .00394 L
.35369 .00394 L
.3546 .00394 L
.35558 .00394 L
.35651 .00394 L
Mistroke
.35751 .00394 L
.35846 .00394 L
.35939 .00394 L
.36037 .00394 L
.36131 .00394 L
.36222 .00394 L
.36318 .00394 L
.36411 .00394 L
.3651 .00394 L
.36606 .00394 L
.36697 .00394 L
.36795 .00394 L
.36889 .00394 L
.36988 .00394 L
.37084 .00394 L
.37177 .00394 L
.37275 .00394 L
.3737 .00394 L
.37461 .00394 L
.37558 .00394 L
.37651 .00394 L
.37751 .00394 L
.37846 .00394 L
.37938 .00394 L
.38036 .00394 L
.3813 .00394 L
.3823 .00394 L
.38327 .00394 L
.3842 .00394 L
.38518 .00394 L
.38613 .00394 L
.38705 .00394 L
.38802 .00394 L
.38896 .00394 L
.38943 .00394 L
.38969 .00394 L
.38982 .00394 L
.38995 .00394 L
.39001 .00394 L
.39004 .00394 L
.39007 .00394 L
.3901 .39759 L
.39011 .39759 L
.39013 .39759 L
.39019 .39759 L
.39045 .39759 L
.39091 .39759 L
.39139 .39759 L
.39164 .39759 L
.39191 .39759 L
Mistroke
.39203 .39759 L
.39215 .39759 L
.39219 .39759 L
.3922 .39759 L
.39222 .39759 L
.39225 .00394 L
.39227 .00394 L
.39229 .00394 L
.39241 .00394 L
.39287 .00394 L
.39378 .00394 L
.39475 .00394 L
.39568 .00394 L
.39666 .00394 L
.39762 .00394 L
.39853 .00394 L
.39951 .00394 L
.40044 .00394 L
.40144 .00394 L
.4024 .00394 L
.40332 .00394 L
.40431 .00394 L
.40525 .00394 L
.40616 .00394 L
.40713 .00394 L
.40807 .00394 L
.40906 .00394 L
.41001 .00394 L
.41093 .00394 L
.41191 .00394 L
.41285 .00394 L
.41385 .00394 L
.41481 .00394 L
.41574 .00394 L
.41673 .00394 L
.41768 .00394 L
.41859 .00394 L
.41956 .00394 L
.4205 .00394 L
.42149 .00394 L
.42245 .00394 L
.42337 .00394 L
.42435 .00394 L
.4253 .00394 L
.42621 .00394 L
.42717 .00394 L
.4281 .00394 L
.42909 .00394 L
.43005 .00394 L
.43096 .00394 L
Mistroke
.43194 .00394 L
.43288 .00394 L
.43388 .00394 L
.43484 .00394 L
.43576 .00394 L
.43675 .00394 L
.4377 .00394 L
.43861 .00394 L
.43958 .00394 L
.44051 .00394 L
.4415 .00394 L
.44246 .00394 L
.44338 .00394 L
.44384 .00394 L
.44409 .00394 L
.44422 .00394 L
.44436 .00394 L
.44442 .00394 L
.44445 .00394 L
.44448 .00394 L
.4445 .20076 L
.44452 .20076 L
.44455 .20076 L
.44461 .20076 L
.44484 .20076 L
.4453 .20076 L
.44577 .20076 L
.44602 .20076 L
.44628 .20076 L
.44641 .20076 L
.44654 .20076 L
.44659 .20076 L
.44662 .20076 L
.44665 .20076 L
.44667 .20076 L
.44668 .00394 L
.44671 .00394 L
.44677 .00394 L
.44723 .00394 L
.44821 .00394 L
.44916 .00394 L
.45008 .00394 L
.45105 .00394 L
.45198 .00394 L
.45298 .00394 L
.45393 .00394 L
.45486 .00394 L
.45584 .00394 L
.45678 .00394 L
.45769 .00394 L
Mistroke
.45865 .00394 L
.45958 .00394 L
.46057 .00394 L
.46152 .00394 L
.46244 .00394 L
.46341 .00394 L
.46435 .00394 L
.46535 .00394 L
.46631 .00394 L
.46724 .00394 L
.46822 .00394 L
.46917 .00394 L
.47008 .00394 L
.47105 .00394 L
.47198 .00394 L
.47297 .00394 L
.47393 .00394 L
.47485 .00394 L
.47582 .00394 L
.47677 .00394 L
.47777 .00394 L
.47873 .00394 L
.47966 .00394 L
.48064 .00394 L
.48159 .00394 L
.48251 .00394 L
.48348 .00394 L
.48442 .00394 L
.48541 .00394 L
.48637 .00394 L
.48729 .00394 L
.48828 .00394 L
.48922 .00394 L
.49013 .00394 L
.4911 .00394 L
.49203 .00394 L
.49302 .00394 L
.49397 .00394 L
.49489 .00394 L
.49586 .00394 L
.4968 .00394 L
.4978 .00394 L
.4983 .00394 L
.49852 .00394 L
.49864 .00394 L
.49876 .00394 L
.49883 .00394 L
.49886 .00394 L
.49889 .00394 L
.49891 .20076 L
Mistroke
.49894 .20076 L
.499 .20076 L
.49921 .20076 L
.49969 .20076 L
.5006 .20076 L
.50082 .20076 L
.50095 .20076 L
.50101 .20076 L
.50103 .20076 L
.50106 .20076 L
.50109 .00394 L
.50112 .00394 L
.50119 .00394 L
.50132 .00394 L
.50156 .00394 L
.50255 .00394 L
.50349 .00394 L
.5044 .00394 L
.50537 .00394 L
.5063 .00394 L
.50729 .00394 L
.50825 .00394 L
.50917 .00394 L
.51014 .00394 L
.51108 .00394 L
.51208 .00394 L
.51305 .00394 L
.51397 .00394 L
.51496 .00394 L
.51591 .00394 L
.51682 .00394 L
.5178 .00394 L
.51873 .00394 L
.51973 .00394 L
.52068 .00394 L
.52161 .00394 L
.52259 .00394 L
.52353 .00394 L
.52444 .00394 L
.5254 .00394 L
.52633 .00394 L
.52732 .00394 L
.52828 .00394 L
.52919 .00394 L
.53017 .00394 L
.53111 .00394 L
.53211 .00394 L
.53307 .00394 L
.53399 .00394 L
.53498 .00394 L
Mistroke
.53592 .00394 L
.53683 .00394 L
.5378 .00394 L
.53874 .00394 L
.53973 .00394 L
.54069 .00394 L
.54161 .00394 L
.54258 .00394 L
.54353 .00394 L
.54443 .00394 L
.5454 .00394 L
.54632 .00394 L
.54731 .00394 L
.54826 .00394 L
.54918 .00394 L
.55015 .00394 L
.55109 .00394 L
.55208 .00394 L
.55258 .00394 L
.5528 .00394 L
.55304 .00394 L
.55315 .00394 L
.55322 .00394 L
.55327 .00394 L
.5533 .00394 L
.55333 .00394 L
.55336 .20076 L
.55339 .20076 L
.55349 .20076 L
.55397 .20076 L
.55445 .20076 L
.55496 .20076 L
.55521 .20076 L
.55534 .20076 L
.55541 .20076 L
.55543 .20076 L
.55547 .20076 L
.55549 .20076 L
.55552 .00394 L
.55555 .00394 L
.55557 .00394 L
.55569 .00394 L
.55593 .00394 L
.55683 .00394 L
.5578 .00394 L
.55873 .00394 L
.55972 .00394 L
.56067 .00394 L
.56159 .00394 L
.56256 .00394 L
Mistroke
.5635 .00394 L
.56449 .00394 L
.56546 .00394 L
.56638 .00394 L
.56736 .00394 L
.56831 .00394 L
.56922 .00394 L
.57019 .00394 L
.57112 .00394 L
.57211 .00394 L
.57307 .00394 L
.57399 .00394 L
.57497 .00394 L
.57591 .00394 L
.57691 .00394 L
.57787 .00394 L
.5788 .00394 L
.57978 .00394 L
.58073 .00394 L
.58165 .00394 L
.58262 .00394 L
.58356 .00394 L
.58455 .00394 L
.58551 .00394 L
.58643 .00394 L
.58741 .00394 L
.58836 .00394 L
.58927 .00394 L
.59023 .00394 L
.59116 .00394 L
.59215 .00394 L
.59311 .00394 L
.59402 .00394 L
.595 .00394 L
.59594 .00394 L
.59694 .00394 L
.5979 .00394 L
.59882 .00394 L
.59981 .00394 L
.60076 .00394 L
.60167 .00394 L
.60264 .00394 L
.60357 .00394 L
.60457 .00394 L
.60552 .00394 L
.60644 .00394 L
.60691 .00394 L
.60716 .00394 L
.60742 .00394 L
.60755 .00394 L
Mistroke
.60761 .00394 L
.60768 .00394 L
.6077 .00394 L
.60773 .00394 L
.60776 .39759 L
.60779 .39759 L
.60791 .39759 L
.60836 .39759 L
.60929 .39759 L
.60953 .39759 L
.60976 .39759 L
.60982 .39759 L
.60988 .39759 L
.60991 .39759 L
.60993 .39759 L
.60995 .00394 L
.60997 .00394 L
.61001 .00394 L
.61027 .00394 L
.61127 .00394 L
.61223 .00394 L
.61316 .00394 L
.61415 .00394 L
.61509 .00394 L
.61601 .00394 L
.61698 .00394 L
.61791 .00394 L
.61891 .00394 L
.61987 .00394 L
.62079 .00394 L
.62177 .00394 L
.62271 .00394 L
.62362 .00394 L
.62459 .00394 L
.62552 .00394 L
.6265 .00394 L
.62746 .00394 L
.62837 .00394 L
.62935 .00394 L
.63029 .00394 L
.63128 .00394 L
.63225 .00394 L
.63317 .00394 L
.63415 .00394 L
.6351 .00394 L
.63601 .00394 L
.63698 .00394 L
.63791 .00394 L
.63891 .00394 L
.63986 .00394 L
Mistroke
.64078 .00394 L
.64176 .00394 L
.6427 .00394 L
.6437 .00394 L
.64467 .00394 L
.64559 .00394 L
.64658 .00394 L
.64753 .00394 L
.64845 .00394 L
.64942 .00394 L
.65036 .00394 L
.65135 .00394 L
.65231 .00394 L
.65323 .00394 L
.65421 .00394 L
.65516 .00394 L
.65607 .00394 L
.65704 .00394 L
.65797 .00394 L
.65896 .00394 L
.65991 .00394 L
.66083 .00394 L
.6618 .00394 L
.66274 .00394 L
.66374 .00394 L
.66471 .00394 L
.66563 .00394 L
.66662 .00394 L
.66756 .00394 L
.66848 .00394 L
.66945 .00394 L
.67038 .00394 L
.67138 .00394 L
.67233 .00394 L
.67325 .00394 L
.67423 .00394 L
.67518 .00394 L
.67608 .00394 L
.67705 .00394 L
.67798 .00394 L
.67897 .00394 L
.67992 .00394 L
.68083 .00394 L
.68181 .00394 L
.68274 .00394 L
.68374 .00394 L
.6847 .00394 L
.68563 .00394 L
.68661 .00394 L
.68755 .00394 L
Mistroke
.68846 .00394 L
.68943 .00394 L
.69037 .00394 L
.69136 .00394 L
.69231 .00394 L
.69323 .00394 L
.69421 .00394 L
.69515 .00394 L
.69615 .00394 L
.69711 .00394 L
.69804 .00394 L
.69903 .00394 L
.69998 .00394 L
.70089 .00394 L
.70186 .00394 L
.7028 .00394 L
.70379 .00394 L
.70475 .00394 L
.70567 .00394 L
.70665 .00394 L
.7076 .00394 L
.7085 .00394 L
.70947 .00394 L
.7104 .00394 L
.71139 .00394 L
.71234 .00394 L
.71326 .00394 L
.71424 .00394 L
.71518 .00394 L
.71617 .00394 L
.71714 .00394 L
.71806 .00394 L
.71904 .00394 L
.71999 .00394 L
.7209 .00394 L
.72187 .00394 L
.72281 .00394 L
.7238 .00394 L
.72476 .00394 L
.72568 .00394 L
.72665 .00394 L
.7276 .00394 L
.7285 .00394 L
.72947 .00394 L
.7304 .00394 L
.73138 .00394 L
.73233 .00394 L
.73325 .00394 L
.73422 .00394 L
.73516 .00394 L
Mistroke
.73616 .00394 L
.73711 .00394 L
.73804 .00394 L
.73902 .00394 L
.73997 .00394 L
.74087 .00394 L
.74184 .00394 L
.74277 .00394 L
.74377 .00394 L
.74472 .00394 L
.74564 .00394 L
.74661 .00394 L
.74755 .00394 L
.74855 .00394 L
.74952 .00394 L
.75044 .00394 L
.75143 .00394 L
.75238 .00394 L
.75329 .00394 L
.75426 .00394 L
.7552 .00394 L
.75619 .00394 L
.75715 .00394 L
.75807 .00394 L
.75905 .00394 L
.75999 .00394 L
.7609 .00394 L
.76187 .00394 L
.76279 .00394 L
.76378 .00394 L
.76474 .00394 L
.76565 .00394 L
.76663 .00394 L
.76756 .00394 L
.76856 .00394 L
.76952 .00394 L
.77045 .00394 L
.77143 .00394 L
.77238 .00394 L
.77329 .00394 L
.77426 .00394 L
.77519 .00394 L
.77618 .00394 L
.77714 .00394 L
.77806 .00394 L
.77903 .00394 L
.77998 .00394 L
.78098 .00394 L
.78194 .00394 L
.78287 .00394 L
Mistroke
.78385 .00394 L
.7848 .00394 L
.78572 .00394 L
.78669 .00394 L
.78763 .00394 L
.78862 .00394 L
.78958 .00394 L
.7905 .00394 L
.79148 .00394 L
.79243 .00394 L
.79334 .00394 L
.79431 .00394 L
.79524 .00394 L
.79623 .00394 L
.79718 .00394 L
.7981 .00394 L
.79907 .00394 L
.80001 .00394 L
.80101 .00394 L
.80197 .00394 L
.8029 .00394 L
.80388 .00394 L
.80483 .00394 L
.80574 .00394 L
.80671 .00394 L
.80765 .00394 L
.80864 .00394 L
.8096 .00394 L
.81052 .00394 L
.8115 .00394 L
.81244 .00394 L
.81335 .00394 L
.81431 .00394 L
.81524 .00394 L
.81623 .00394 L
.81718 .00394 L
.81809 .00394 L
.81907 .00394 L
.82001 .00394 L
.821 .00394 L
.82196 .00394 L
.82289 .00394 L
.82387 .00394 L
.82481 .00394 L
.82572 .00394 L
.82669 .00394 L
.82762 .00394 L
.82862 .00394 L
.82957 .00394 L
.83049 .00394 L
Mistroke
.83147 .00394 L
.83241 .00394 L
.83341 .00394 L
.83437 .00394 L
.8353 .00394 L
.83628 .00394 L
.83723 .00394 L
.83815 .00394 L
.83912 .00394 L
.84005 .00394 L
.84105 .00394 L
.842 .00394 L
.84293 .00394 L
.84391 .00394 L
.84485 .00394 L
.84576 .00394 L
.84673 .00394 L
.84766 .00394 L
.84864 .00394 L
.8496 .00394 L
.85051 .00394 L
.85149 .00394 L
.85243 .00394 L
.85342 .00394 L
.85439 .00394 L
.85531 .00394 L
.85629 .00394 L
.85724 .00394 L
.85815 .00394 L
.85912 .00394 L
.86006 .00394 L
.86105 .00394 L
.862 .00394 L
.86292 .00394 L
.8639 .00394 L
.86484 .00394 L
.86585 .00394 L
.86681 .00394 L
.86774 .00394 L
.86873 .00394 L
.86968 .00394 L
.87059 .00394 L
.87156 .00394 L
.8725 .00394 L
.8735 .00394 L
.87445 .00394 L
.87538 .00394 L
.87636 .00394 L
.8773 .00394 L
.87821 .00394 L
Mistroke
.87918 .00394 L
.88011 .00394 L
.8811 .00394 L
.88206 .00394 L
.88297 .00394 L
.88395 .00394 L
.88489 .00394 L
.88589 .00394 L
.88685 .00394 L
.88778 .00394 L
.88876 .00394 L
.88971 .00394 L
.89062 .00394 L
.8916 .00394 L
.89253 .00394 L
.89352 .00394 L
.89448 .00394 L
.8954 .00394 L
.89638 .00394 L
.89732 .00394 L
.89823 .00394 L
.8992 .00394 L
.90013 .00394 L
.90112 .00394 L
.90207 .00394 L
.90298 .00394 L
.90396 .00394 L
.9049 .00394 L
.90589 .00394 L
.90685 .00394 L
.90778 .00394 L
.90876 .00394 L
.90971 .00394 L
.91062 .00394 L
.91159 .00394 L
.91252 .00394 L
.91351 .00394 L
.91446 .00394 L
.91538 .00394 L
.91636 .00394 L
.9173 .00394 L
.9183 .00394 L
.91927 .00394 L
.92019 .00394 L
.92118 .00394 L
.92213 .00394 L
.92304 .00394 L
.92402 .00394 L
.92495 .00394 L
.92595 .00394 L
Mistroke
.9269 .00394 L
.92783 .00394 L
.92881 .00394 L
.92975 .00394 L
.93066 .00394 L
.93163 .00394 L
.93256 .00394 L
.93355 .00394 L
.9345 .00394 L
.93542 .00394 L
.93639 .00394 L
.93733 .00394 L
.93833 .00394 L
.93929 .00394 L
.94022 .00394 L
.9412 .00394 L
.94215 .00394 L
.94306 .00394 L
.94403 .00394 L
.94497 .00394 L
.94596 .00394 L
.94691 .00394 L
.94783 .00394 L
.94881 .00394 L
.94976 .00394 L
.95066 .00394 L
.95163 .00394 L
.95256 .00394 L
.95354 .00394 L
.95449 .00394 L
.95541 .00394 L
.95638 .00394 L
.95732 .00394 L
.95832 .00394 L
.95928 .00394 L
.9602 .00394 L
.96118 .00394 L
.96213 .00394 L
.96304 .00394 L
.96401 .00394 L
.96494 .00394 L
.96593 .00394 L
.96688 .00394 L
.9678 .00394 L
.96878 .00394 L
.96972 .00394 L
.97072 .00394 L
.97168 .00394 L
.97261 .00394 L
.97359 .00394 L
Mistroke
.97454 .00394 L
.97545 .00394 L
.97619 .00394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00:Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Koooo
o`?o00006_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001[ooooo0_l0000Joooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o00006oooool3o`0001cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o00004oooool002Wooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000001Wooooo00Go0000ooooooooooooooooo`00000J
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Hooooo`04o`00
0?ooooooooooo`0001[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001Wooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000Booooo`008Oooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Aooooo`Go00001Oooool00ol0003oooooooooo`0Aooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000
6oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000Zooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool05_ooool01?l0003oooooooooool0000Looooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04?ooool002_ooooo00?o0000ooooooooool01Ooo
ool4o`0001[ooooo1?l0000Jooooo`05o`000?ooooooooooooooool000001oooool4o`0001Wooooo
00Co0000oooooooooooo00006Oooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Joooo
o`Co00007_ooool00ol0003oooooooooo`05ooooo`Co00004oooool002Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0
000Iooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01_ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Co
oooo000Wooooo`Go00001oooool5o`0001Wooooo1Ol0000Jooooo`?o00002?ooool5o`0001Wooooo
0_l0000Kooooo`?o00002?ooool5o`0001Wooooo1Ol0000Iooooo`Go00001oooool5o`0001;ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000>ooooo`;o0000oooooolAooooo`00
3Oooool01?l0003oooooooooool00004oooooooo00002ol00001ooooo`003Oooool01?l0003ooooo
ooooool00004ooooo`;o000000Coooooo`000?ooooooo`00o_l00?l3ooooo`?o00000Oooool000go
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooof;oo`000_l00?l=ool0
0003o`00oooo003oo`0000_oo`000_l00?l=ool00003o`00oooo003oo`0000_oo`000_l00?mQool0
00Gooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool0
00Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo00?oo`00o`00ool00?l01Oooool2ool0
00Gooooo00?oo`00o`00oooo00002oooool00ooo003o003oo`00o`0<ooooo`03ool00?l00?oooooo
00Cooooo0ooo0004ooooo`03ool00?l00?oo003o00Cooooo0ooo000<ooooo`?oo`002oooool3ool0
00Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool0
00Sooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool0
00Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo00?oo`00o`00ool00?l01Oooool2ool0
00Gooooo00?oo`00o`00oooo00002oooool00ooo003o003oo`00o`0<ooooo`03ool00?l00?oooooo
00Cooooo0ooo0004ooooo`03ool00?l00?oo003o00Cooooo0ooo000<ooooo`?oo`002oooool3ool0
00Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool0
00Sooooo0Ol00001ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool01Oooool3ool000Go
oooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000co
oooo0_oo000<ooooo`?oo`001?ooool00ooo003o003oo`00o`05ooooo`;oo`001Oooool00ooo003o
003oool0000;ooooo`03ool00?l00?oo003o00cooooo00?oo`00o`00ooooool01?ooool3ool000Co
oooo00?oo`00o`00ool00?l01?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Go
oooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007o
oooo000Eooooo`;o00001_ooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo
0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool00ooo003o003o
o`00o`05ooooo`;oo`001Oooool00ooo003o003oool0000;ooooo`03ool00?l00?oo003o00cooooo
00?oo`00o`00ooooool01?ooool3ool000Cooooo00?oo`00o`00ool00?l01?ooool3ool000cooooo
0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo
0ooo0004ooooo`?oo`001oooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo
0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo0ooo
000<ooooo`;oo`003?ooool3ool000Cooooo00?oo`00o`00ool00?l01Oooool2ool000Gooooo00?o
o`00o`00oooo00002oooool00ooo003o003oo`00o`0<ooooo`03ool00?l00?oooooo00Cooooo0ooo
0004ooooo`03ool00?l00?oo003o00Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo
0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Sooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<
ooooo`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004
ooooo`03ool00?l00?oo003o00Gooooo0_oo0005ooooo`03ool00?l00?ooo`0000_ooooo00?oo`00
o`00ool00?l03?ooool00ooo003o003oooooo`04ooooo`?oo`001?ooool00ooo003o003oo`00o`04
ooooo`?oo`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;
ooooo`?oo`003?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool01Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005oooo
o`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool00ooo003o003oo`00o`05oooo
o`;oo`001Oooool00ooo003o003oool0000;ooooo`03ool00?l00?oo003o00cooooo00?oo`00o`00
ooooool01?ooool3ool000Cooooo00?oo`00o`00ool00?l01?ooool3ool000cooooo0ooo000;oooo
o`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004oooo
o`?oo`002?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo0005ooooo`;o
o`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo0ooo000<ooooo`;o
o`003?ooool3ool000Cooooo00?oo`00o`00ool00?l01Oooool2ool000Gooooo00?oo`00o`00oooo
00002oooool00ooo003o003oo`00o`0<ooooo`03ool00?l00?oooooo00Cooooo0ooo0004ooooo`03
ool00?l00?oo003o00Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;o
o`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Sooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`00
1Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`03ool0
0?l00?oo003o00Gooooo0_oo0005ooooo`03ool00?l00?ooo`0000_ooooo00?oo`00o`00ool00?l0
3?ooool00ooo003o003oooooo`04ooooo`?oo`001?ooool00ooo003o003oo`00o`04ooooo`?oo`00
3?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`00
3?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool001Gooooo0_l00006ooooo`?oo`001Ooo
ool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?oo
ool2ool000cooooo0ooo0004ooooo`03ool00?l00?oo003o00Gooooo0_oo0005ooooo`03ool00?l0
0?ooo`0000_ooooo00?oo`00o`00ool00?l03?ooool00ooo003o003oooooo`04ooooo`?oo`001?oo
ool00ooo003o003oo`00o`04ooooo`?oo`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Ooo
ool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Cooooo0ooo0007ooooo`;o00000Ooo
ool001Gooooo00?o0000ooooooooool01Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2
ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool0
0ooo003o003oo`00o`05ooooo`;oo`001Oooool00ooo003o003oool0000;ooooo`03ool00?l00?oo
003o00cooooo00?oo`00o`00ooooool01?ooool3ool000Cooooo00?oo`00o`00ool00?l01?ooool3
ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3
ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool0
00Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo00?oo`00o`00ool00?l01Oooool2ool0
00Gooooo00?oo`00o`00oooo00002oooool00ooo003o003oo`00o`0<ooooo`03ool00?l00?oooooo
00Cooooo0ooo0004ooooo`03ool00?l00?oo003o00Cooooo0ooo000<ooooo`?oo`002oooool3ool0
00Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool0
00Sooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000co
oooo0ooo000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000co
oooo0ooo0004ooooo`03ool00?l00?oo003o00Gooooo0_oo0005ooooo`03ool00?l00?ooo`0000_o
oooo00?oo`00o`00ool00?l03?ooool00ooo003o003oooooo`04ooooo`?oo`001?ooool00ooo003o
003oo`00o`04ooooo`?oo`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Go
oooo0ooo000;ooooo`?oo`003?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool01Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo
0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool00ooo003o003o
o`00o`05ooooo`;oo`001Oooool00ooo003o003oool0000;ooooo`03ool00?l00?oo003o00cooooo
00?oo`00o`00ooooool01?ooool3ool000Cooooo00?oo`00o`00ool00?l01?ooool3ool000cooooo
0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo
0ooo0004ooooo`?oo`002?ooool1o`00007ooooo000Eooooo`;o00001_ooool3ool000Gooooo0_oo
000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo
000<ooooo`?oo`001?ooool00ooo003o003oo`00o`05ooooo`;oo`001Oooool00ooo003o003oool0
000;ooooo`03ool00?l00?oo003o00cooooo00?oo`00o`00ooooool01?ooool3ool000Cooooo00?o
o`00o`00ool00?l01?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo
0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`001oooool2o`00007ooooo000E
ooooo`03o`000?oooooooooo00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005
ooooo`;oo`001Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo00?oo`00
o`00ool00?l01Oooool2ool000Gooooo00?oo`00o`00oooo00002oooool00ooo003o003oo`00o`0<
ooooo`03ool00?l00?oooooo00Cooooo0ooo0004ooooo`03ool00?l00?oo003o00Cooooo0ooo000<
ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<
ooooo`?oo`001?ooool3ool000Sooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`05oooo
o`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004oooo
o`?oo`003?ooool2ool000cooooo0ooo0004ooooo`03ool00?l00?oo003o00Gooooo0_oo0005oooo
o`03ool00?l00?ooo`0000_ooooo00?oo`00o`00ool00?l03?ooool00ooo003o003oooooo`04oooo
o`?oo`001?ooool00ooo003o003oo`00o`04ooooo`?oo`003?ooool3ool000_ooooo0ooo0004oooo
o`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Cooooo0ooo0008oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool000Gooooo0_oo000<ooooo`?o
o`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?o
o`001?ooool00ooo003o003oo`00o`05ooooo`;oo`001Oooool00ooo003o003oool0000;ooooo`03
ool00?l00?oo003o00cooooo00?oo`00o`00ooooool01?ooool3ool000Cooooo00?oo`00o`00ool0
0?l01?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?o
o`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`00
1Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo00?oo`00o`00ool00?l0
1Oooool2ool000Gooooo00?oo`00o`00oooo00002oooool00ooo003o003oo`00o`0<ooooo`03ool0
0?l00?oooooo00Cooooo0ooo0004ooooo`03ool00?l00?oo003o00Cooooo0ooo000<ooooo`?oo`00
2oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`00
1?ooool3ool000Sooooo0Ol00001ooooo`005Oooool2o`0000Kooooo0ooo0005ooooo`;oo`003?oo
ool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?oo
ool3ool000Cooooo00?oo`00o`00ool00?l01Oooool2ool000Gooooo00?oo`00o`00oooo00002ooo
ool00ooo003o003oo`00o`0<ooooo`03ool00?l00?oooooo00Cooooo0ooo0004ooooo`03ool00?l0
0?oo003o00Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Ooo
ool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Oooooo0_l00001ooooo`005Oooool0
0ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2
ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`03ool00?l00?oo
003o00Gooooo0_oo0005ooooo`03ool00?l00?ooo`0000_ooooo00?oo`00o`00ool00?l03?ooool0
0ooo003o003oooooo`04ooooo`?oo`001?ooool00ooo003o003oo`00o`04ooooo`?oo`003?ooool3
ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3
ool000Cooooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool0
00Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool0
00cooooo0_oo000<ooooo`?oo`001?ooool00ooo003o003oo`00o`05ooooo`;oo`001Oooool00ooo
003o003oool0000;ooooo`03ool00?l00?oo003o00cooooo00?oo`00o`00ooooool01?ooool3ool0
00Cooooo00?oo`00o`00ool00?l01?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool0
00Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00
007ooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003o
ooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2ool000Go
oooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`03ool00?l00?oo003o00Go
oooo0_oo0005ooooo`03ool00?l00?ooo`0000_ooooo00?oo`00o`00ool00?l03?ooool00ooo003o
003oooooo`04ooooo`?oo`001?ooool00ooo003o003oo`00o`04ooooo`?oo`003?ooool3ool000_o
oooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Co
oooo0ooo0008ooooo`7o00000Oooool00005ooooool0003oooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool01Oooool3ool000Gooooo0_oo000<oooo
o`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<oooo
o`?oo`001?ooool00ooo003o003oo`00o`05ooooo`;oo`001Oooool00ooo003o003oool0000;oooo
o`03ool00?l00?oo003o00cooooo00?oo`00o`00ooooool01?ooool3ool000Cooooo00?oo`00o`00
ool00?l01?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005oooo
o`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo00001Ooooooo
0000oooooooooooo000000_ooooo00?o0000ooooooooool00_ooool2o`0000Kooooo0ooo0005oooo
o`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo0ooo000<oooo
o`;oo`003?ooool3ool000Cooooo00?oo`00o`00ool00?l01Oooool2ool000Gooooo00?oo`00o`00
oooo00002oooool00ooo003o003oo`00o`0<ooooo`03ool00?l00?oooooo00Cooooo0ooo0004oooo
o`03ool00?l00?oo003o00Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005oooo
o`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Oooooo0_l00001oooo
o`0000Goooooo`000?ooooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005oooo
o`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool00ooo003o003oo`00o`05oooo
o`;oo`001Oooool00ooo003o003oool0000;ooooo`03ool00?l00?oo003o00cooooo00?oo`00o`00
ooooool01?ooool3ool000Cooooo00?oo`00o`00ool00?l01?ooool3ool000cooooo0ooo000;oooo
o`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004oooo
o`?oo`002?ooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Oooooo1?l00005oooo
o`03o`000?oooooooooo00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005oooo
o`;oo`001Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo00?oo`00o`00
ool00?l01Oooool2ool000Gooooo00?oo`00o`00oooo00002oooool00ooo003o003oo`00o`0<oooo
o`03ool00?l00?oooooo00Cooooo0ooo0004ooooo`03ool00?l00?oo003o00Cooooo0ooo000<oooo
o`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<oooo
o`?oo`001?ooool3ool000Sooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000007oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool3ool000Gooooo0_oo000<oooo
o`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<oooo
o`?oo`001?ooool00ooo003o003oo`00o`05ooooo`;oo`001Oooool00ooo003o003oool0000;oooo
o`03ool00?l00?oo003o00cooooo00?oo`00o`00ooooool01?ooool3ool000Cooooo00?oo`00o`00
ool00?l01?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005oooo
o`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo0002ooooo`;o
00002?ooool5o`0000Cooooo00?o0000ooooooooool01Oooool3ool000Gooooo0_oo000<ooooo`?o
o`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?o
o`001?ooool00ooo003o003oo`00o`05ooooo`;oo`001Oooool00ooo003o003oool0000;ooooo`03
ool00?l00?oo003o00cooooo00?oo`00o`00ooooool01?ooool3ool000Cooooo00?oo`00o`00ool0
0?l01?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?o
o`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`00
1Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo00?oo`00o`00ool00?l0
1Oooool2ool000Gooooo00?oo`00o`00oooo00002oooool00ooo003o003oo`00o`0<ooooo`03ool0
0?l00?oooooo00Cooooo0ooo0004ooooo`03ool00?l00?oo003o00Cooooo0ooo000<ooooo`?oo`00
2oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`00
1?ooool3ool000Sooooo0Ol00001ooooo`005Oooool2o`0000Kooooo0ooo0005ooooo`;oo`003?oo
ool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?oo
ool3ool000Cooooo00?oo`00o`00ool00?l01Oooool2ool000Gooooo00?oo`00o`00oooo00002ooo
ool00ooo003o003oo`00o`0<ooooo`03ool00?l00?oooooo00Cooooo0ooo0004ooooo`03ool00?l0
0?oo003o00Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Ooo
ool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Oooooo0_l00001ooooo`005Oooool0
0ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2
ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`03ool00?l00?oo
003o00Gooooo0_oo0005ooooo`03ool00?l00?ooo`0000_ooooo00?oo`00o`00ool00?l03?ooool0
0ooo003o003oooooo`04ooooo`?oo`001?ooool00ooo003o003oo`00o`04ooooo`?oo`003?ooool3
ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3
ool000Cooooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool0
00Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool0
00cooooo0_oo000<ooooo`?oo`001?ooool00ooo003o003oo`00o`05ooooo`;oo`001Oooool00ooo
003o003oool0000;ooooo`03ool00?l00?oo003o00cooooo00?oo`00o`00ooooool01?ooool3ool0
00Cooooo00?oo`00o`00ool00?l01?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool0
00Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000co
oooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Co
oooo00?oo`00o`00ool00?l01Oooool2ool000Gooooo00?oo`00o`00oooo00002oooool00ooo003o
003oo`00o`0<ooooo`03ool00?l00?oooooo00Cooooo0ooo0004ooooo`03ool00?l00?oo003o00Co
oooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_o
oooo0ooo000<ooooo`?oo`001?ooool3ool000Sooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2ool000Gooooo
0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`03ool00?l00?oo003o00Gooooo
0_oo0005ooooo`03ool00?l00?ooo`0000_ooooo00?oo`00o`00ool00?l03?ooool00ooo003o003o
ooooo`04ooooo`?oo`001?ooool00ooo003o003oo`00o`04ooooo`?oo`003?ooool3ool000_ooooo
0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Cooooo
0ooo0008ooooo`7o00000Oooool001Gooooo0_l00006ooooo`?oo`001Oooool2ool000cooooo0ooo
000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo
0004ooooo`03ool00?l00?oo003o00Gooooo0_oo0005ooooo`03ool00?l00?ooo`0000_ooooo00?o
o`00o`00ool00?l03?ooool00ooo003o003oooooo`04ooooo`?oo`001?ooool00ooo003o003oo`00
o`04ooooo`?oo`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo
000;ooooo`?oo`003?ooool3ool000Cooooo0ooo0007ooooo`;o00000Oooool001Gooooo00?o0000
ooooooooool01Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005
ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool00ooo003o003oo`00o`05
ooooo`;oo`001Oooool00ooo003o003oool0000;ooooo`03ool00?l00?oo003o00cooooo00?oo`00
o`00ooooool01?ooool3ool000Cooooo00?oo`00o`00ool00?l01?ooool3ool000cooooo0ooo000;
ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004
ooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Gooooo0ooo0005oooo
o`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo0ooo000<oooo
o`;oo`003?ooool3ool000Cooooo00?oo`00o`00ool00?l01Oooool2ool000Gooooo00?oo`00o`00
oooo00002oooool00ooo003o003oo`00o`0<ooooo`03ool00?l00?oooooo00Cooooo0ooo0004oooo
o`03ool00?l00?oo003o00Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005oooo
o`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Sooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;o
o`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`03
ool00?l00?oo003o00Gooooo0_oo0005ooooo`03ool00?l00?ooo`0000_ooooo00?oo`00o`00ool0
0?l03?ooool00ooo003o003oooooo`04ooooo`?oo`001?ooool00ooo003o003oo`00o`04ooooo`?o
o`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?o
o`003?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
1Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`00
1?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool00ooo003o003oo`00o`05ooooo`;oo`00
1Oooool00ooo003o003oool0000;ooooo`03ool00?l00?oo003o00cooooo00?oo`00o`00ooooool0
1?ooool3ool000Cooooo00?oo`00o`00ool00?l01?ooool3ool000cooooo0ooo000;ooooo`?oo`00
1?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`00
2?ooool1o`00007ooooo000Eooooo`;o00001_ooool3ool000Gooooo0_oo000<ooooo`?oo`003?oo
ool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?oo
ool00ooo003o003oo`00o`05ooooo`;oo`001Oooool00ooo003o003oool0000;ooooo`03ool00?l0
0?oo003o00cooooo00?oo`00o`00ooooool01?ooool3ool000Cooooo00?oo`00o`00ool00?l01?oo
ool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002ooo
ool3ool000cooooo0ooo0004ooooo`?oo`001oooool2o`00007ooooo000Eooooo`03o`000?oooooo
oooo00Gooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3
ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo00?oo`00o`00ool00?l01Oooool2
ool000Gooooo00?oo`00o`00oooo00002oooool00ooo003o003oo`00o`0<ooooo`03ool00?l00?oo
oooo00Cooooo0ooo0004ooooo`03ool00?l00?oo003o00Cooooo0ooo000<ooooo`?oo`002oooool3
ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3
ool000Sooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool0
00cooooo0ooo000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool0
00cooooo0ooo0004ooooo`03ool00?l00?oo003o00Gooooo0_oo0005ooooo`03ool00?l00?ooo`00
00_ooooo00?oo`00o`00ool00?l03?ooool00ooo003o003oooooo`04ooooo`?oo`001?ooool00ooo
003o003oo`00o`04ooooo`?oo`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool0
00Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool01Oooool3ool000Gooooo0_oo000<ooooo`?oo`003?ooool2ool000Go
oooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<ooooo`?oo`001?ooool00ooo003o
003oo`00o`05ooooo`;oo`001Oooool00ooo003o003oool0000;ooooo`03ool00?l00?oo003o00co
oooo00?oo`00o`00ooooool01?ooool3ool000Cooooo00?oo`00o`00ool00?l01?ooool3ool000co
oooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005ooooo`?oo`002oooool3ool000co
oooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Gooooo
0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3ool000Cooooo
0ooo000<ooooo`;oo`003?ooool3ool000Cooooo00?oo`00o`00ool00?l01Oooool2ool000Gooooo
00?oo`00o`00oooo00002oooool00ooo003o003oo`00o`0<ooooo`03ool00?l00?oooooo00Cooooo
0ooo0004ooooo`03ool00?l00?oo003o00Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo
0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3ool000Sooooo
0Ol00001ooooo`005Oooool2o`0000Kooooo0ooo0005ooooo`;oo`003?ooool3ool000cooooo0_oo
0005ooooo`;oo`001Oooool3ool000Cooooo0ooo000<ooooo`;oo`003?ooool3ool000Cooooo00?o
o`00o`00ool00?l01Oooool2ool000Gooooo00?oo`00o`00oooo00002oooool00ooo003o003oo`00
o`0<ooooo`03ool00?l00?oooooo00Cooooo0ooo0004ooooo`03ool00?l00?oo003o00Cooooo0ooo
000<ooooo`?oo`002oooool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo
000<ooooo`?oo`001?ooool3ool000Oooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`05
ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`001Oooool2ool000Gooooo0ooo0004
ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`03ool00?l00?oo003o00Gooooo0_oo0005
ooooo`03ool00?l00?ooo`0000_ooooo00?oo`00o`00ool00?l03?ooool00ooo003o003oooooo`04
ooooo`?oo`001?ooool00ooo003o003oo`00o`04ooooo`?oo`003?ooool3ool000_ooooo0ooo0004
ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`003?ooool3ool000Cooooo0ooo0008
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool000Gooooo0_oo000<oooo
o`?oo`003?ooool2ool000Gooooo0_oo0005ooooo`?oo`001?ooool3ool000cooooo0_oo000<oooo
o`?oo`001?ooool00ooo003o003oo`00o`05ooooo`;oo`001Oooool00ooo003o003oool0000;oooo
o`03ool00?l00?oo003o00cooooo00?oo`00o`00ooooool01?ooool3ool000Cooooo00?oo`00o`00
ool00?l01?ooool3ool000cooooo0ooo000;ooooo`?oo`001?ooool3ool000Gooooo0_oo0005oooo
o`?oo`002oooool3ool000cooooo0ooo0004ooooo`?oo`002?ooool1o`00007ooooo000=ooooo`?o
00001Oooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;o
o`001Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`03
ool00?l00?oo003o00Gooooo0_oo0005ooooo`03ool00?l00?ooo`0000_ooooo00?oo`00o`00ool0
0?l03?ooool00ooo003o003oooooo`04ooooo`?oo`001?ooool00ooo003o003oo`00o`04ooooo`?o
o`003?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?o
o`003?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool000kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`?oo`001Oooool2ool000cooooo0ooo000<ooooo`;oo`00
1Oooool2ool000Gooooo0ooo0004ooooo`?oo`003?ooool2ool000cooooo0ooo0004ooooo`03ool0
0?l00?oo003o00Gooooo0_oo0005ooooo`03ool00?l00?ooo`0000_ooooo00?oo`00o`00ool00?l0
3?ooool00ooo003o003oooooo`04ooooo`?oo`001?ooool00ooo003o003oo`00o`04ooooo`?oo`00
3?ooool3ool000_ooooo0ooo0004ooooo`?oo`001Oooool2ool000Gooooo0ooo000;ooooo`?oo`00
3?ooool3ool000Cooooo0ooo0008ooooo`7o00000Oooool000kooooo00?o0000ooooooooool01?oo
ool2o`0000Kooooo0ooo0005ooooo`?oo`002oooool3ool000cooooo0_oo0005ooooo`;oo`001Ooo
ool3ool000Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo00?oo`00o`00ool00?l01Ooo
ool2ool000Gooooo00?oo`00o`00oooo00002oooool00ooo003o003oo`00o`0<ooooo`03ool00?l0
0?ooo`0000Cooooo0ooo0004ooooo`03ool00?l00?oo003o00Cooooo0ooo000<ooooo`?oo`002ooo
ool3ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?oo
ool3ool000Oooooo0_l00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo0ooo0005ooooo`?oo`002oooool3ool000cooooo0_oo0005ooooo`;oo`001Oooool3
ool000Cooooo0ooo000<ooooo`?oo`002oooool3ool000Cooooo00?oo`00o`00ool00?l01Oooool2
ool000Gooooo00?oo`00o`00oooo00002oooool00ooo003o003oo`00o`0<ooooo`03ool00?l00?oo
o`0000Cooooo0ooo0004ooooo`03ool00?l00?oo003o00Cooooo0ooo000<ooooo`?oo`002oooool3
ool000Cooooo0ooo0005ooooo`;oo`001Oooool3ool000_ooooo0ooo000<ooooo`?oo`001?ooool3
ool000Sooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?oo`00o`00ool00?l01Oooool2ool0
01Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo00?oo`00o`00ool00?l0:Oooool2ool0
00Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000=ooooo`;o00001_ooool00ol0003o
ooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xooooo`03ool00?l00?oo003o00Go
oooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`03ool00?l00?oo003o02Wo
oooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`003_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo
00?oo`00o`00ool00?l01Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo
00?oo`00o`00ool00?l0:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo
000Eooooo`03o`000?oooooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?o
o`00o`00ool00?l01Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo00?o
o`00o`00ool00?l0:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000E
ooooo`;o00001_ooool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool00ooo003o003oo`00o`05
ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool00ooo003o003oo`00o`0Y
ooooo`;oo`001Oooool2ool002Wooooo0ooo0007ooooo`;o00000Oooool001Gooooo00?o0000oooo
ooooool01Oooool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool00ooo003o003oo`00o`05oooo
o`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool00ooo003o003oo`00o`0Yoooo
o`;oo`001Oooool2ool002Wooooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool01Oooool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool00ooo003o003oo`00o`05ooooo`;o
o`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool00ooo003o003oo`00o`0Yooooo`;o
o`001Oooool2ool002Wooooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
1Oooool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool00ooo003o003oo`00o`05ooooo`;oo`00
5Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool00ooo003o003oo`00o`0Yooooo`;oo`00
1Oooool2ool002Wooooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01Ooo
ool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool00ooo003o003oo`00o`05ooooo`;oo`005Ooo
ool00ol0003oooooooooo`0Aooooo`?oo`001?ooool00ooo003o003oo`00o`0Yooooo`;oo`001Ooo
ool2ool002Wooooo0ooo0008ooooo`7o00000Oooool001Gooooo0_l00006ooooo`?oo`00:Oooool2
ool000Gooooo0ooo000Xooooo`03ool00?l00?oo003o00Gooooo0_oo000Eooooo`03o`000?oooooo
oooo017ooooo0ooo0004ooooo`03ool00?l00?oo003o02Wooooo0_oo0005ooooo`;oo`00:Oooool3
ool000Oooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool0
00Gooooo0ooo000Xooooo`03ool00?l00?oo003o00Gooooo0_oo000Eooooo`03o`000?oooooooooo
017ooooo0ooo0004ooooo`03ool00?l00?oo003o02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool0
00Sooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Go
oooo0ooo000Xooooo`03ool00?l00?oo003o00Gooooo0_oo000Eooooo`03o`000?oooooooooo017o
oooo0ooo0004ooooo`03ool00?l00?oo003o02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000So
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo
0ooo000Xooooo`03ool00?l00?oo003o00Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo
0ooo0004ooooo`03ool00?l00?oo003o02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo
000Xooooo`03ool00?l00?oo003o00Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo
0004ooooo`03ool00?l00?oo003o02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol0
0001ooooo`005Oooool2o`0000Kooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?oo`00
o`00ool00?l01Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo00?oo`00
o`00ool00?l0:Oooool2ool000Gooooo0_oo000Yooooo`?oo`001oooool2o`00007ooooo000Eoooo
o`03o`000?oooooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?oo`00o`00
ool00?l01Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo00?oo`00o`00
ool00?l0:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?oo`00o`00ool0
0?l01Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo00?oo`00o`00ool0
0?l0:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?oo`00o`00ool00?l0
1Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo00?oo`00o`00ool00?l0
:Oooool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?oo`00o`00ool00?l01Ooo
ool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo00?oo`00o`00ool00?l0:Ooo
ool2ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000Eooooo`;o00001_ooool3
ool002Wooooo0_oo0005ooooo`?oo`00:?ooool00ooo003o003oo`00o`05ooooo`;oo`005Oooool0
0ol0003oooooooooo`0Aooooo`?oo`001?ooool00ooo003o003oo`00o`0Yooooo`;oo`001Oooool2
ool002Wooooo0ooo0007ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool0
02Wooooo0_oo0005ooooo`?oo`00:?ooool00ooo003o003oo`00o`05ooooo`;oo`005Oooool00ol0
003oooooooooo`0Aooooo`?oo`001?ooool00ooo003o003oo`00o`0Yooooo`;oo`001Oooool2ool0
02Wooooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool002Wo
oooo0_oo0005ooooo`?oo`00:?ooool00ooo003o003oo`00o`05ooooo`;oo`005Oooool00ol0003o
ooooooooo`0Aooooo`?oo`001?ooool00ooo003o003oo`00o`0Yooooo`;oo`001Oooool2ool002Wo
oooo0ooo0008ooooo`7o00000Oooool00004ooooool0003o0000o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005ooooo`?o
o`00:?ooool00ooo003o003oo`00o`05ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?o
o`001?ooool00ooo003o003oo`00o`0Yooooo`;oo`001Oooool2ool002Wooooo0ooo0008ooooo`7o
00000Oooool000;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool00ooo003o
003oo`00o`05ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool00ooo003o
003oo`00o`0Yooooo`;oo`001Oooool2ool002Wooooo0ooo0008ooooo`7o00000Oooool000;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?oo`00o`00ool00?l01Oooool2ool001Gooooo
00?o0000ooooooooool04Oooool3ool000Cooooo00?oo`00o`00ool00?l0:Oooool2ool000Gooooo
0_oo000Yooooo`?oo`002?ooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00_ooool2o`0000Kooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?o
o`00o`00ool00?l01Oooool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo00?o
o`00o`00ool00?l0:Oooool2ool000Gooooo0_oo000Yooooo`?oo`001oooool2o`00007ooooo0002
ooooo`03o`000?oooooooooo00Oooooo1?l00005ooooo`03o`000?oooooooooo00Gooooo0ooo000Y
ooooo`;oo`001Oooool3ool002Sooooo00?oo`00o`00ool00?l01Oooool2ool001Gooooo00?o0000
ooooooooool04Oooool3ool000Cooooo00?oo`00o`00ool00?l0:Oooool2ool000Gooooo0_oo000Y
ooooo`?oo`002?ooool1o`00007ooooo00000ooooooo0000o`000009ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool00ooo
003o003oo`00o`05ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool00ooo
003o003oo`00o`0Yooooo`;oo`001Oooool2ool002Wooooo0ooo0008ooooo`7o00000Oooool000;o
oooo00?o0000ooooooooool01oooool5o`0000Cooooo00?o0000ooooooooool01Oooool3ool002Wo
oooo0_oo0005ooooo`?oo`00:?ooool00ooo003o003oo`00o`05ooooo`;oo`005Oooool00ol0003o
ooooooooo`0Aooooo`?oo`001?ooool00ooo003o003oo`00o`0Yooooo`;oo`001Oooool2ool002Wo
oooo0ooo0008ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool002Wooooo
0_oo0005ooooo`?oo`00:?ooool00ooo003o003oo`00o`05ooooo`;oo`005Oooool00ol0003ooooo
ooooo`0Aooooo`?oo`001?ooool00ooo003o003oo`00o`0Yooooo`;oo`001Oooool2ool002Wooooo
0ooo0008ooooo`7o00000Oooool001Gooooo0_l00006ooooo`?oo`00:Oooool2ool000Gooooo0ooo
000Xooooo`03ool00?l00?oo003o00Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo
0004ooooo`03ool00?l00?oo003o02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Oooooo0_l0
0001ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo000X
ooooo`03ool00?l00?oo003o00Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004
ooooo`03ool00?l00?oo003o02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xoooo
o`03ool00?l00?oo003o00Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004oooo
o`03ool00?l00?oo003o02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xooooo`03
ool00?l00?oo003o00Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`03
ool00?l00?oo003o02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xooooo`03ool0
0?l00?oo003o00Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`03ool0
0?l00?oo003o02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`005Ooo
ool2o`0000Kooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?oo`00o`00ool00?l01Ooo
ool2ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo00?oo`00o`00ool00?l0:Ooo
ool2ool000Gooooo0_oo000Yooooo`?oo`001oooool2o`00007ooooo000Eooooo`03o`000?oooooo
oooo00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?oo`00o`00ool00?l01Oooool2
ool001Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo00?oo`00o`00ool00?l0:Oooool2
ool000Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
00Gooooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?oo`00o`00ool00?l01Oooool2ool0
01Gooooo00?o0000ooooooooool04Oooool3ool000Cooooo00?oo`00o`00ool00?l0:Oooool2ool0
00Gooooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Go
oooo0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?oo`00o`00ool00?l01Oooool2ool001Go
oooo00?o0000ooooooooool04Oooool3ool000Cooooo00?oo`00o`00ool00?l0:Oooool2ool000Go
oooo0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Gooooo
0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?oo`00o`00ool00?l01Oooool2ool001Gooooo
00?o0000ooooooooool04Oooool3ool000Cooooo00?oo`00o`00ool00?l0:Oooool2ool000Gooooo
0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000Eooooo`;o00001_ooool3ool002Wooooo0_oo
0005ooooo`?oo`00:?ooool00ooo003o003oo`00o`05ooooo`;oo`005Oooool00ol0003ooooooooo
o`0Aooooo`?oo`001?ooool00ooo003o003oo`00o`0Yooooo`;oo`001Oooool2ool002Wooooo0ooo
0007ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005
ooooo`?oo`00:?ooool00ooo003o003oo`00o`05ooooo`;oo`005Oooool00ol0003oooooooooo`0A
ooooo`?oo`001?ooool00ooo003o003oo`00o`0Yooooo`;oo`001Oooool2ool002Wooooo0ooo0008
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005oooo
o`?oo`00:?ooool00ooo003o003oo`00o`05ooooo`;oo`005Oooool00ol0003oooooooooo`0Aoooo
o`?oo`001?ooool00ooo003o003oo`00o`0Yooooo`;oo`001Oooool2ool002Wooooo0ooo0008oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005ooooo`?o
o`00:?ooool00ooo003o003oo`00o`05ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?o
o`001?ooool00ooo003o003oo`00o`0Yooooo`;oo`001Oooool2ool002Wooooo0ooo0008ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005ooooo`?oo`00
:?ooool00ooo003o003oo`00o`05ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`00
1?ooool00ooo003o003oo`00o`0Yooooo`;oo`001Oooool2ool002Wooooo0ooo0008ooooo`7o0000
0Oooool001Gooooo0_l00006ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xooooo`03ool00?l0
0?oo003o00Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`03ool00?l0
0?oo003o02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Oooooo0_l00001ooooo`005Oooool0
0ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xooooo`03ool00?l00?oo
003o00Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`03ool00?l00?oo
003o02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`05ooooo`?oo`00:Oooool2ool000Gooooo0ooo000Xooooo`03ool00?l00?oo003o
00Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`03ool00?l00?oo003o
02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000Sooooo0Ol00001ooooo`003?ooool5o`0000Co
oooo00?o0000ooooooooool01Oooool3ool002Wooooo0_oo0005ooooo`?oo`00:?ooool00ooo003o
003oo`00o`05ooooo`;oo`005Oooool00ol0003oooooooooo`0Aooooo`?oo`001?ooool00ooo003o
003oo`00o`0Yooooo`;oo`001Oooool2ool002Wooooo0ooo0008ooooo`7o00000Oooool000gooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`?oo`00:Oooool2ool000Go
oooo0ooo000Xooooo`03ool00?l00?oo003o00Gooooo0_oo000Eooooo`03o`000?oooooooooo017o
oooo0ooo0004ooooo`03ool00?l00?oo003o02Wooooo0_oo0005ooooo`;oo`00:Oooool3ool000So
oooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
0ooo000Yooooo`;oo`001Oooool3ool002Sooooo00?oo`00o`00ool00?l01Oooool2ool001Gooooo
00?o0000ooooooooool04Oooool3ool000Cooooo00?oo`00o`00ool00?l0:Oooool2ool000Gooooo
0_oo000Yooooo`?oo`002?ooool1o`00007ooooo000?ooooo`03o`000?oooooooooo00?ooooo0_l0
0006ooooo`?oo`00:Oooool3ool000Cooooo0ooo000Xooooo`03ool00?l00?oo003o00Gooooo0_oo
000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`03ool00?l00?oo003o02Wooooo0_oo
0005ooooo`?oo`00:?ooool3ool000Oooooo0_l00001ooooo`003?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool01Oooool3ool002Wooooo0ooo0004ooooo`?oo`00:?oo
ool3ool000Gooooo0_oo000Eooooo`03o`000?oooooooooo017ooooo0ooo0004ooooo`?oo`00:Ooo
ool2ool000Gooooo0ooo000Xooooo`?oo`002?ooool1o`00007ooooo000<ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`00
5Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?o
oooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003oooooooooo`20ooooo`;o
00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo
0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`005Oooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`001Ol00003ooooo`03o`000?oooooo
oooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1
o`00007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo0002
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`22
ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`000oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00;ooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001oooo
o`0000Go0000ooooooooooooooooo`000007ooooo`Co00001Oooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo087ooooo0Ol00001ooooo`0000Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool00004ooooool0003o0000o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003ooooo
ooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o
00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`005Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?ooooo00?o
0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003oooooooooo`20ooooo`;o00000Ooo
ool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool0
00gooooo0ol00005ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00
007ooooo000<ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo087ooooo0Ol00001ooooo`004?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000>ooooo`;o0000
1Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo000@ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Ooo
ool000cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0POooool1o`00007ooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`22
ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`000003ooooool0003ooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`?o00000Oooool001Gooooo
ool0000;o`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.6628, -0.260466, \
0.0691952, 0.0191323}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DTFT of finite-length sampled signal", "Subsection"],

Cell[BoxData[
    \(\(X\[Theta]\  = DTFT[xd, \[Theta]]\  // \ Simplify;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gX\[Theta] = 
        Plot[Abs[
            X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-2.5\) 
              fs, 2.5  fs}, \ PlotStyle \[Rule] {Red}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200, \ 
          AspectRatio \[Rule] 1/3, \ ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0544218 0.00395481 0.00833439 [
[.09184 -0.0125 -12 -9 ]
[.09184 -0.0125 12 0 ]
[.22789 -0.0125 -6 -9 ]
[.22789 -0.0125 6 0 ]
[.36395 -0.0125 -12 -9 ]
[.36395 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.63605 -0.0125 -9 -9 ]
[.63605 -0.0125 9 0 ]
[.77211 -0.0125 -3 -9 ]
[.77211 -0.0125 3 0 ]
[.90816 -0.0125 -9 -9 ]
[.90816 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00395 -6 -4.5 ]
[-0.0125 .00395 0 4.5 ]
[-0.0125 .04563 -6 -4.5 ]
[-0.0125 .04563 0 4.5 ]
[-0.0125 .0873 -12 -4.5 ]
[-0.0125 .0873 0 4.5 ]
[-0.0125 .12897 -12 -4.5 ]
[-0.0125 .12897 0 4.5 ]
[-0.0125 .17064 -12 -4.5 ]
[-0.0125 .17064 0 4.5 ]
[-0.0125 .21231 -12 -4.5 ]
[-0.0125 .21231 0 4.5 ]
[-0.0125 .25399 -12 -4.5 ]
[-0.0125 .25399 0 4.5 ]
[-0.0125 .29566 -12 -4.5 ]
[-0.0125 .29566 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09184 0 m
.09184 .00625 L
s
[(-7.5)] .09184 -0.0125 0 1 Mshowa
.22789 0 m
.22789 .00625 L
s
[(-5)] .22789 -0.0125 0 1 Mshowa
.36395 0 m
.36395 .00625 L
s
[(-2.5)] .36395 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.63605 0 m
.63605 .00625 L
s
[(2.5)] .63605 -0.0125 0 1 Mshowa
.77211 0 m
.77211 .00625 L
s
[(5)] .77211 -0.0125 0 1 Mshowa
.90816 0 m
.90816 .00625 L
s
[(7.5)] .90816 -0.0125 0 1 Mshowa
.125 Mabswid
.11905 0 m
.11905 .00375 L
s
.14626 0 m
.14626 .00375 L
s
.17347 0 m
.17347 .00375 L
s
.20068 0 m
.20068 .00375 L
s
.2551 0 m
.2551 .00375 L
s
.28231 0 m
.28231 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.33673 0 m
.33673 .00375 L
s
.39116 0 m
.39116 .00375 L
s
.41837 0 m
.41837 .00375 L
s
.44558 0 m
.44558 .00375 L
s
.47279 0 m
.47279 .00375 L
s
.52721 0 m
.52721 .00375 L
s
.55442 0 m
.55442 .00375 L
s
.58163 0 m
.58163 .00375 L
s
.60884 0 m
.60884 .00375 L
s
.66327 0 m
.66327 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.71769 0 m
.71769 .00375 L
s
.7449 0 m
.7449 .00375 L
s
.79932 0 m
.79932 .00375 L
s
.82653 0 m
.82653 .00375 L
s
.85374 0 m
.85374 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.06463 0 m
.06463 .00375 L
s
.03741 0 m
.03741 .00375 L
s
.0102 0 m
.0102 .00375 L
s
.93537 0 m
.93537 .00375 L
s
.96259 0 m
.96259 .00375 L
s
.9898 0 m
.9898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00395 m
.00625 .00395 L
s
[(0)] -0.0125 .00395 1 0 Mshowa
0 .04563 m
.00625 .04563 L
s
[(5)] -0.0125 .04563 1 0 Mshowa
0 .0873 m
.00625 .0873 L
s
[(10)] -0.0125 .0873 1 0 Mshowa
0 .12897 m
.00625 .12897 L
s
[(15)] -0.0125 .12897 1 0 Mshowa
0 .17064 m
.00625 .17064 L
s
[(20)] -0.0125 .17064 1 0 Mshowa
0 .21231 m
.00625 .21231 L
s
[(25)] -0.0125 .21231 1 0 Mshowa
0 .25399 m
.00625 .25399 L
s
[(30)] -0.0125 .25399 1 0 Mshowa
0 .29566 m
.00625 .29566 L
s
[(35)] -0.0125 .29566 1 0 Mshowa
.125 Mabswid
0 .01229 m
.00375 .01229 L
s
0 .02062 m
.00375 .02062 L
s
0 .02896 m
.00375 .02896 L
s
0 .03729 m
.00375 .03729 L
s
0 .05396 m
.00375 .05396 L
s
0 .0623 m
.00375 .0623 L
s
0 .07063 m
.00375 .07063 L
s
0 .07896 m
.00375 .07896 L
s
0 .09563 m
.00375 .09563 L
s
0 .10397 m
.00375 .10397 L
s
0 .1123 m
.00375 .1123 L
s
0 .12064 m
.00375 .12064 L
s
0 .13731 m
.00375 .13731 L
s
0 .14564 m
.00375 .14564 L
s
0 .15397 m
.00375 .15397 L
s
0 .16231 m
.00375 .16231 L
s
0 .17898 m
.00375 .17898 L
s
0 .18731 m
.00375 .18731 L
s
0 .19565 m
.00375 .19565 L
s
0 .20398 m
.00375 .20398 L
s
0 .22065 m
.00375 .22065 L
s
0 .22898 m
.00375 .22898 L
s
0 .23732 m
.00375 .23732 L
s
0 .24565 m
.00375 .24565 L
s
0 .26232 m
.00375 .26232 L
s
0 .27066 m
.00375 .27066 L
s
0 .27899 m
.00375 .27899 L
s
0 .28732 m
.00375 .28732 L
s
0 .30399 m
.00375 .30399 L
s
0 .31233 m
.00375 .31233 L
s
0 .32066 m
.00375 .32066 L
s
0 .329 m
.00375 .329 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.09184 .32708 m
.09184 .33333 L
s
.22789 .32708 m
.22789 .33333 L
s
.36395 .32708 m
.36395 .33333 L
s
.5 .32708 m
.5 .33333 L
s
.63605 .32708 m
.63605 .33333 L
s
.77211 .32708 m
.77211 .33333 L
s
.90816 .32708 m
.90816 .33333 L
s
.125 Mabswid
.11905 .32958 m
.11905 .33333 L
s
.14626 .32958 m
.14626 .33333 L
s
.17347 .32958 m
.17347 .33333 L
s
.20068 .32958 m
.20068 .33333 L
s
.2551 .32958 m
.2551 .33333 L
s
.28231 .32958 m
.28231 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.33673 .32958 m
.33673 .33333 L
s
.39116 .32958 m
.39116 .33333 L
s
.41837 .32958 m
.41837 .33333 L
s
.44558 .32958 m
.44558 .33333 L
s
.47279 .32958 m
.47279 .33333 L
s
.52721 .32958 m
.52721 .33333 L
s
.55442 .32958 m
.55442 .33333 L
s
.58163 .32958 m
.58163 .33333 L
s
.60884 .32958 m
.60884 .33333 L
s
.66327 .32958 m
.66327 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.71769 .32958 m
.71769 .33333 L
s
.7449 .32958 m
.7449 .33333 L
s
.79932 .32958 m
.79932 .33333 L
s
.82653 .32958 m
.82653 .33333 L
s
.85374 .32958 m
.85374 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.06463 .32958 m
.06463 .33333 L
s
.03741 .32958 m
.03741 .33333 L
s
.0102 .32958 m
.0102 .33333 L
s
.93537 .32958 m
.93537 .33333 L
s
.96259 .32958 m
.96259 .33333 L
s
.9898 .32958 m
.9898 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00395 m
1 .00395 L
s
.99375 .04563 m
1 .04563 L
s
.99375 .0873 m
1 .0873 L
s
.99375 .12897 m
1 .12897 L
s
.99375 .17064 m
1 .17064 L
s
.99375 .21231 m
1 .21231 L
s
.99375 .25399 m
1 .25399 L
s
.99375 .29566 m
1 .29566 L
s
.125 Mabswid
.99625 .01229 m
1 .01229 L
s
.99625 .02062 m
1 .02062 L
s
.99625 .02896 m
1 .02896 L
s
.99625 .03729 m
1 .03729 L
s
.99625 .05396 m
1 .05396 L
s
.99625 .0623 m
1 .0623 L
s
.99625 .07063 m
1 .07063 L
s
.99625 .07896 m
1 .07896 L
s
.99625 .09563 m
1 .09563 L
s
.99625 .10397 m
1 .10397 L
s
.99625 .1123 m
1 .1123 L
s
.99625 .12064 m
1 .12064 L
s
.99625 .13731 m
1 .13731 L
s
.99625 .14564 m
1 .14564 L
s
.99625 .15397 m
1 .15397 L
s
.99625 .16231 m
1 .16231 L
s
.99625 .17898 m
1 .17898 L
s
.99625 .18731 m
1 .18731 L
s
.99625 .19565 m
1 .19565 L
s
.99625 .20398 m
1 .20398 L
s
.99625 .22065 m
1 .22065 L
s
.99625 .22898 m
1 .22898 L
s
.99625 .23732 m
1 .23732 L
s
.99625 .24565 m
1 .24565 L
s
.99625 .26232 m
1 .26232 L
s
.99625 .27066 m
1 .27066 L
s
.99625 .27899 m
1 .27899 L
s
.99625 .28732 m
1 .28732 L
s
.99625 .30399 m
1 .30399 L
s
.99625 .31233 m
1 .31233 L
s
.99625 .32066 m
1 .32066 L
s
.99625 .329 m
1 .329 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
.5 0 m
.5 .33333 L
s
1 0 0 r
.5 Mabswid
.02381 .0905 m
.02608 .06623 L
.02723 .03977 L
.02739 .03628 L
.02757 .03295 L
.02765 .03167 L
.02773 .03053 L
.02788 .02922 L
.02802 .02902 L
.02816 .02986 L
.02831 .03189 L
.02839 .03348 L
.02847 .03518 L
.02911 .05555 L
.02972 .07991 L
.03089 .13108 L
.03218 .18792 L
.03355 .24302 L
.0342 .26539 L
.0348 .28375 L
.03539 .29872 L
.03594 .30974 L
.03646 .3176 L
.03672 .32055 L
.037 .32299 L
.03715 .32394 L
.03729 .32459 L
.03745 .32511 L
.0376 .32536 L
.03774 .32538 L
.03787 .32523 L
.03801 .32486 L
.03816 .32424 L
.03829 .32347 L
.03844 .3224 L
.03875 .31954 L
.03903 .31607 L
.03929 .31214 L
.03988 .30084 L
.04051 .28524 L
.04166 .24827 L
.04271 .20715 L
.04522 .09452 L
.04632 .04584 L
.04662 .03326 L
.04695 .02034 L
.0471 .01446 L
.04725 .00959 L
.04739 .00807 L
.04753 .01152 L
Mistroke
.04862 .04623 L
.04922 .06189 L
.04979 .07386 L
.0501 .07929 L
.05043 .08416 L
.05074 .08768 L
.05102 .09013 L
.05115 .09101 L
.05129 .09178 L
.05144 .09242 L
.05158 .09283 L
.05174 .09307 L
.05189 .09309 L
.05202 .09293 L
.05217 .09257 L
.05232 .09203 L
.05245 .09136 L
.05276 .08929 L
.05303 .08683 L
.05331 .08363 L
.05391 .07492 L
.05456 .06291 L
.0552 .04965 L
.05555 .04236 L
.05587 .03616 L
.05602 .03383 L
.05618 .03187 L
.05626 .03111 L
.05636 .03052 L
.05651 .03017 L
.05666 .03066 L
.05681 .03202 L
.05696 .03403 L
.0571 .03636 L
.05767 .05006 L
.05829 .06766 L
.05939 .10054 L
.0606 .13324 L
.06123 .14789 L
.0619 .16091 L
.06248 .17004 L
.06279 .17395 L
.06312 .1774 L
.06342 .17991 L
.0637 .18162 L
.06383 .18225 L
.06398 .1828 L
.06412 .18317 L
.06424 .18341 L
.06437 .18353 L
Mistroke
.06451 .18353 L
.06463 .18342 L
.06475 .18322 L
.06489 .18286 L
.06504 .18233 L
.06531 .18098 L
.0656 .17906 L
.0659 .17646 L
.06645 .17042 L
.06769 .15109 L
.06903 .12396 L
.07019 .09832 L
.07146 .07161 L
.07206 .06081 L
.0724 .05565 L
.07271 .05141 L
.073 .04809 L
.07332 .04522 L
.07346 .04421 L
.0736 .0433 L
.07373 .04265 L
.07387 .04211 L
.07403 .04165 L
.07417 .04137 L
.07432 .04122 L
.07441 .04119 L
.07449 .0412 L
.07464 .04129 L
.07478 .04146 L
.07493 .04173 L
.07508 .04204 L
.07571 .04376 L
.07605 .04471 L
.07641 .04562 L
.07673 .04627 L
.07702 .04671 L
.07716 .04687 L
.07731 .047 L
.07745 .04708 L
.07758 .04712 L
.07766 .04713 L
.07775 .04713 L
.0779 .04709 L
.07805 .04701 L
.07819 .0469 L
.07833 .04675 L
.0785 .04654 L
.07883 .04601 L
.07997 .04342 L
.08053 .04206 L
Mistroke
.08105 .04095 L
.08133 .04046 L
.08164 .04001 L
.08196 .03967 L
.08213 .03953 L
.08229 .03943 L
.08243 .03936 L
.08257 .03932 L
.08269 .0393 L
.08283 .03928 L
.08298 .03929 L
.08313 .0393 L
.08328 .03933 L
.08341 .03936 L
.08372 .03945 L
.08404 .03954 L
.0842 .03958 L
.0843 .0396 L
.08439 .03961 L
.08454 .03962 L
.08463 .03962 L
.08471 .03961 L
.08487 .03958 L
.08501 .03954 L
.08517 .03947 L
.08534 .03936 L
.08562 .03911 L
.08594 .03873 L
.08622 .03829 L
.08653 .03769 L
.08715 .03617 L
.08827 .03285 L
.0889 .03108 L
.08925 .0303 L
.08942 .03001 L
.08957 .02979 L
.08972 .02964 L
.08987 .02953 L
.09002 .02948 L
.09011 .02948 L
.09019 .02949 L
.09034 .02957 L
.09048 .02969 L
.09064 .02989 L
.09078 .03014 L
.0911 .03082 L
.09139 .03165 L
.09194 .03354 L
.09258 .03598 L
.09318 .03813 L
Mistroke
.09368 .03969 L
.09395 .04036 L
.09424 .04093 L
.09439 .04116 L
.09453 .04132 L
.09467 .04145 L
.0948 .04153 L
.09495 .04156 L
.09509 .04155 L
.09524 .04149 L
.09539 .04136 L
.09553 .0412 L
.09568 .04096 L
.09599 .04032 L
.09627 .03951 L
.09653 .03859 L
.09712 .03593 L
.09775 .03236 L
.0983 .02882 L
.09889 .02516 L
.09914 .02385 L
.0994 .0227 L
.09955 .0222 L
.09968 .02186 L
.09982 .02164 L
.09995 .02157 L
.1001 .02164 L
.10026 .0219 L
.1004 .02228 L
.10054 .02284 L
.10088 .0246 L
.10119 .02674 L
.10253 .03802 L
.1031 .04261 L
.1037 .04673 L
.10401 .04848 L
.10436 .05004 L
.10451 .05059 L
.10467 .05108 L
.10482 .05145 L
.10496 .05172 L
.10511 .05191 L
.10519 .05197 L
.10527 .05201 L
.10536 .05202 L
.10545 .05199 L
.1056 .05186 L
.10575 .05164 L
.10589 .05134 L
.10604 .05092 L
Mistroke
.10619 .05036 L
.10656 .04864 L
.1069 .04645 L
.10753 .04089 L
.10871 .02604 L
.10902 .02152 L
.1092 .0191 L
.10936 .017 L
.10951 .01537 L
.10959 .01467 L
.10967 .01423 L
.10981 .01402 L
.10996 .01467 L
.1101 .016 L
.11024 .01803 L
.11051 .0227 L
.11112 .03573 L
.11238 .06698 L
.11461 .12237 L
.11586 .14833 L
.11647 .15858 L
.11703 .16626 L
.11762 .17252 L
.11794 .17509 L
.11824 .17693 L
.11841 .17767 L
.11858 .17827 L
.11872 .17864 L
.11881 .17879 L
.11888 .17889 L
.11897 .17896 L
.11906 .17898 L
.11922 .17889 L
.1193 .17877 L
.11939 .17861 L
.11948 .17839 L
.11957 .1781 L
.11972 .17752 L
.11989 .17673 L
.12022 .17461 L
.12053 .17205 L
.12082 .16915 L
.12147 .16088 L
.12216 .14958 L
.1246 .09547 L
.12583 .06405 L
.12648 .04778 L
.12716 .03156 L
.12745 .02535 L
.12776 .01945 L
Mistroke
.12794 .01671 L
.12803 .01567 L
.12811 .0149 L
.12818 .01435 L
.12827 .01404 L
.12843 .01425 L
.12858 .0153 L
.12872 .01682 L
.12899 .02037 L
.12959 .02901 L
.1302 .03689 L
.13077 .04288 L
.13136 .04755 L
.13167 .04935 L
.13185 .05015 L
.13201 .05076 L
.13215 .05118 L
.1323 .05154 L
.13245 .0518 L
.13253 .0519 L
.13261 .05197 L
.13275 .05202 L
.13288 .05198 L
.13302 .05187 L
.13318 .05165 L
.1333 .05139 L
.13344 .05105 L
.13368 .05025 L
.13397 .04901 L
.13424 .04764 L
.13546 .03895 L
.13612 .03322 L
.13674 .02797 L
.13727 .02425 L
.13743 .02342 L
.13757 .02275 L
.1377 .02227 L
.13785 .02188 L
.13793 .02172 L
.138 .02163 L
.13815 .02157 L
.13831 .02168 L
.13839 .02182 L
.13847 .022 L
.13861 .02239 L
.13876 .02294 L
.13906 .02436 L
.1403 .03208 L
.14092 .03561 L
.14148 .03825 L
Mistroke
.142 .04002 L
.14226 .04066 L
.14241 .04095 L
.14254 .04117 L
.14268 .04134 L
.14283 .04147 L
.14297 .04154 L
.14306 .04156 L
.14314 .04157 L
.14328 .04153 L
.14341 .04146 L
.14355 .04133 L
.14369 .04117 L
.14398 .0407 L
.14428 .04003 L
.14482 .03845 L
.14605 .03393 L
.14663 .03189 L
.14695 .03096 L
.14725 .03025 L
.14742 .02995 L
.14751 .02982 L
.14761 .0297 L
.1477 .02961 L
.14778 .02955 L
.14793 .02948 L
.14809 .02948 L
.14818 .02951 L
.14826 .02955 L
.14841 .02967 L
.14857 .02986 L
.14872 .03008 L
.14888 .03038 L
.14917 .03103 L
.14972 .03253 L
.15095 .03619 L
.15151 .03756 L
.15181 .03817 L
.1521 .03864 L
.15236 .03899 L
.1526 .03924 L
.15273 .03935 L
.15287 .03944 L
.15302 .03951 L
.15316 .03957 L
.15324 .03959 L
.15332 .0396 L
.15347 .03962 L
.15363 .03962 L
.15372 .03961 L
Mistroke
.1538 .0396 L
.15395 .03957 L
.15409 .03954 L
.1544 .03945 L
.15468 .03937 L
.15483 .03933 L
.15498 .0393 L
.15512 .03929 L
.15527 .03928 L
.15541 .0393 L
.15553 .03932 L
.15568 .03937 L
.15576 .03941 L
.15584 .03945 L
.15601 .03956 L
.15617 .0397 L
.15645 .04001 L
.15675 .04044 L
.15742 .04175 L
.15806 .04327 L
.15867 .04474 L
.15923 .04595 L
.15952 .04643 L
.15983 .04682 L
.15991 .0469 L
.16 .04697 L
.16008 .04703 L
.16017 .04707 L
.16025 .04711 L
.16033 .04713 L
.16048 .04713 L
.16062 .0471 L
.16076 .04702 L
.16089 .04692 L
.16103 .04678 L
.16133 .04633 L
.16162 .04576 L
.1627 .04285 L
.16299 .04209 L
.16316 .04174 L
.16331 .04148 L
.16338 .04137 L
.16347 .04128 L
.16356 .04121 L
.16365 .04119 L
.1638 .04124 L
.16388 .04131 L
.16396 .04143 L
.16412 .04178 L
.16426 .04225 L
Mistroke
.16443 .04297 L
.16458 .04385 L
.16486 .04588 L
.16516 .04876 L
.16573 .05604 L
.16633 .0659 L
.1674 .0873 L
.16979 .13922 L
.17084 .15854 L
.17139 .16695 L
.17197 .17422 L
.17227 .17717 L
.1726 .1798 L
.17274 .18075 L
.1729 .18161 L
.17304 .18228 L
.17318 .18278 L
.17332 .18316 L
.17347 .18343 L
.17362 .18354 L
.17378 .18349 L
.17392 .18329 L
.17406 .18296 L
.17419 .18254 L
.17432 .18197 L
.17463 .18022 L
.17496 .17754 L
.17531 .17391 L
.17563 .16976 L
.17684 .14831 L
.1781 .11758 L
.17929 .08315 L
.17989 .06512 L
.18046 .04901 L
.18071 .04269 L
.18097 .03692 L
.18111 .03444 L
.18126 .03228 L
.1814 .03093 L
.18152 .03027 L
.18167 .03026 L
.18181 .03099 L
.18194 .03219 L
.18208 .03397 L
.18239 .03925 L
.18268 .04502 L
.18391 .07012 L
.18447 .07928 L
.18499 .08597 L
.18525 .08854 L
Mistroke
.18553 .0907 L
.18568 .09158 L
.18584 .0923 L
.18598 .09273 L
.18613 .09302 L
.18629 .0931 L
.18644 .09297 L
.18651 .09283 L
.1866 .0926 L
.18669 .0923 L
.18677 .09195 L
.18706 .09023 L
.18722 .08892 L
.18737 .0875 L
.18795 .08007 L
.1885 .0702 L
.18972 .03889 L
.19007 .02776 L
.19041 .0167 L
.19055 .01194 L
.1907 .00814 L
.19078 .00828 L
.19087 .01037 L
.19102 .01563 L
.19342 .11935 L
.19564 .21759 L
.19685 .26272 L
.198 .29574 L
.19863 .30909 L
.19899 .31494 L
.19932 .31921 L
.1996 .32195 L
.19975 .32316 L
.1999 .32406 L
.20006 .32475 L
.2002 .32517 L
.20028 .32531 L
.20037 .32539 L
.20052 .32533 L
.2006 .32521 L
.20068 .32501 L
.20083 .32448 L
.20099 .32366 L
.20116 .32246 L
.20147 .31953 L
.20177 .31591 L
.20231 .30691 L
.20289 .29417 L
.20422 .25477 L
.20542 .2087 L
Mistroke
.20663 .15653 L
.20792 .09936 L
.20901 .0544 L
.20931 .044 L
.20947 .03921 L
.20964 .03489 L
.20978 .03191 L
.20987 .03064 L
.20994 .02976 L
.21008 .029 L
.21023 .02928 L
.21038 .03066 L
.21045 .0317 L
.21054 .03306 L
.21082 .03888 L
.21147 .05416 L
.21204 .06662 L
.21265 .07755 L
.21295 .08185 L
.21324 .08517 L
.2135 .08748 L
.21365 .08851 L
.21378 .08926 L
.21392 .08984 L
.21405 .09023 L
.21419 .09045 L
.21433 .09049 L
.21446 .09034 L
.2146 .09001 L
.21472 .08958 L
.21485 .08896 L
.21515 .08684 L
.2153 .08544 L
.21547 .08363 L
.21583 .079 L
.21616 .07373 L
.21676 .06198 L
.2174 .04707 L
.2177 .03988 L
.21787 .03623 L
.21803 .03323 L
.21816 .03114 L
.2183 .02959 L
.21846 .02896 L
.2186 .02953 L
.21874 .03122 L
.21888 .03367 L
.21902 .03716 L
.21918 .04156 L
.21973 .06072 L
Mistroke
.22215 .16597 L
.22334 .21645 L
.22442 .25706 L
.22496 .27458 L
.22555 .29108 L
.22606 .30295 L
.22663 .31328 L
.22694 .31762 L
.22722 .32084 L
.22737 .32216 L
.22753 .32332 L
.22761 .32382 L
.2277 .32429 L
.22786 .32492 L
.22801 .32527 L
.22814 .3254 L
.2283 .3253 L
.22845 .32497 L
.22858 .32447 L
.22871 .32383 L
.229 .32177 L
.22929 .31879 L
.22956 .3153 L
.23016 .30484 L
.23072 .29209 L
.23125 .27742 L
.23374 .18327 L
.23499 .12699 L
.23616 .07364 L
.23721 .0287 L
.2375 .01743 L
.23766 .01179 L
.2378 .0081 L
.23793 .00927 L
.23806 .01328 L
.23835 .02283 L
.23893 .04136 L
.23957 .05872 L
.24013 .07126 L
.24072 .08156 L
.24105 .08584 L
.24122 .08772 L
.24141 .08942 L
.24158 .0907 L
.24174 .09163 L
.24189 .09231 L
.24204 .0928 L
.24219 .09304 L
.24234 .0931 L
.24249 .09295 L
Mistroke
.24262 .09265 L
.24278 .0921 L
.24294 .09127 L
.24325 .08915 L
.2456 .05117 L
.24624 .03803 L
.24643 .03487 L
.24652 .03353 L
.24661 .03244 L
.24676 .03093 L
.24685 .03044 L
.24694 .03018 L
.24702 .03021 L
.2471 .03046 L
.24718 .031 L
.24727 .03184 L
.24743 .03384 L
.24759 .03676 L
.24819 .05103 L
.25067 .12296 L
.25176 .14901 L
.25233 .16018 L
.25294 .16978 L
.25324 .17362 L
.25357 .17714 L
.25387 .17968 L
.25415 .18148 L
.25429 .18217 L
.25444 .18274 L
.25456 .18311 L
.2547 .18338 L
.25485 .18353 L
.25501 .18352 L
.25516 .18335 L
.2553 .18306 L
.25545 .18256 L
.25562 .18186 L
.25592 .18015 L
.25624 .17768 L
.2566 .17424 L
.25723 .16632 L
.25782 .15712 L
.26007 .11166 L
.26125 .08564 L
.26251 .06132 L
.26314 .05196 L
.2635 .04784 L
.26384 .04487 L
.26399 .04384 L
.26415 .04295 L
Mistroke
.26428 .04235 L
.26443 .04184 L
.26451 .04162 L
.26459 .04146 L
.26468 .04133 L
.26476 .04124 L
.26491 .04119 L
.26499 .0412 L
.26507 .04125 L
.26521 .0414 L
.26536 .04163 L
.26563 .04222 L
.26625 .04392 L
.26656 .0448 L
.26689 .04563 L
.26718 .04623 L
.26749 .04671 L
.26767 .0469 L
.26782 .04703 L
.26797 .0471 L
.26813 .04713 L
.26828 .04712 L
.26841 .04707 L
.26856 .04698 L
.26871 .04685 L
.26889 .04666 L
.26907 .0464 L
.26941 .04581 L
.27005 .04441 L
.2712 .04164 L
.27151 .04098 L
.27185 .04039 L
.27217 .03994 L
.27232 .03978 L
.27247 .03964 L
.27262 .03952 L
.27276 .03944 L
.27289 .03937 L
.27302 .03933 L
.27318 .0393 L
.27332 .03928 L
.27347 .03929 L
.27355 .0393 L
.27363 .03931 L
.27379 .03934 L
.27394 .03938 L
.27426 .03947 L
.27455 .03955 L
.27463 .03957 L
.27471 .03959 L
Mistroke
.27486 .03961 L
.27501 .03962 L
.2751 .03962 L
.27518 .03961 L
.27532 .03959 L
.27548 .03954 L
.27556 .03951 L
.27565 .03947 L
.2758 .03937 L
.27599 .03922 L
.27616 .03905 L
.27646 .03866 L
.27679 .03811 L
.27739 .0368 L
.27862 .03321 L
.27923 .03146 L
.27949 .0308 L
.27978 .0302 L
.27994 .02995 L
.28008 .02976 L
.28022 .02962 L
.28036 .02952 L
.28044 .02949 L
.28053 .02947 L
.28069 .0295 L
.28085 .02959 L
.28099 .02973 L
.28115 .02995 L
.2813 .03021 L
.28163 .03098 L
.28232 .03317 L
.28292 .03544 L
.28358 .03787 L
.28416 .03968 L
.28445 .0404 L
.28462 .04074 L
.28477 .04101 L
.28491 .04121 L
.28506 .04137 L
.28521 .04149 L
.28537 .04156 L
.28551 .04156 L
.28566 .04152 L
.2858 .04142 L
.28593 .04129 L
.28607 .04111 L
.2862 .04089 L
.28649 .04025 L
.28674 .03952 L
.28701 .03857 L
Mistroke
.28823 .03229 L
.28884 .02846 L
.2894 .02502 L
.28966 .02365 L
.2899 .0226 L
.29004 .02216 L
.29018 .02181 L
.29032 .02162 L
.29044 .02156 L
.29058 .02163 L
.2907 .02183 L
.29084 .02219 L
.29099 .02272 L
.2913 .02427 L
.29158 .02609 L
.2927 .0354 L
.29392 .04509 L
.29425 .04715 L
.29459 .049 L
.29489 .05025 L
.29506 .05083 L
.29522 .05127 L
.29536 .05159 L
.29552 .05183 L
.29568 .05198 L
.29577 .05201 L
.29585 .05201 L
.296 .05194 L
.29613 .05179 L
.29629 .05151 L
.29644 .05113 L
.29673 .05012 L
.297 .04881 L
.2973 .04698 L
.29762 .04454 L
.29827 .03811 L
.29886 .03069 L
.29941 .0229 L
.29969 .01881 L
.29985 .01679 L
.3 .01523 L
.30013 .01432 L
.30027 .014 L
.30042 .01457 L
.30056 .01589 L
.30069 .0175 L
.30082 .01962 L
.30109 .02466 L
.30364 .08708 L
.30597 .14132 L
Mistroke
.30713 .16127 L
.30779 .1695 L
.3081 .17257 L
.30839 .17491 L
.30864 .17652 L
.30892 .17781 L
.30907 .17833 L
.30922 .17869 L
.30936 .17889 L
.3095 .17898 L
.30965 .17892 L
.3098 .17874 L
.30987 .17859 L
.30996 .17838 L
.31011 .17788 L
.31025 .17729 L
.3104 .17651 L
.31068 .17477 L
.31127 .16936 L
.31182 .16263 L
.31305 .14192 L
.31526 .09081 L
.31637 .06225 L
.31756 .03336 L
.31818 .02053 L
.31835 .01772 L
.31844 .01647 L
.31853 .01538 L
.31861 .01466 L
.3187 .01416 L
.31886 .0141 L
.31902 .01499 L
.31916 .0164 L
.31948 .02062 L
.32006 .02895 L
.32065 .03656 L
.32127 .0431 L
.3218 .04729 L
.3221 .04908 L
.32238 .05036 L
.32253 .05091 L
.3227 .05139 L
.32278 .05156 L
.32286 .05171 L
.32301 .05191 L
.32317 .05201 L
.32331 .052 L
.32345 .05192 L
.32359 .05175 L
.32374 .05147 L
Mistroke
.32392 .05104 L
.32426 .04983 L
.32459 .04833 L
.32489 .04663 L
.32598 .03854 L
.32714 .02862 L
.32743 .02637 L
.32774 .02429 L
.32792 .02331 L
.32809 .02259 L
.32817 .0223 L
.32825 .02204 L
.32841 .02171 L
.32857 .02157 L
.32871 .0216 L
.32878 .02168 L
.32887 .02182 L
.32902 .02219 L
.32916 .02267 L
.32932 .02329 L
.32959 .02465 L
.33081 .03227 L
.33146 .03595 L
.33182 .03765 L
.33215 .039 L
.33247 .04 L
.33263 .04044 L
.33281 .04082 L
.33296 .04108 L
.33312 .0413 L
.33327 .04144 L
.33341 .04153 L
.33355 .04156 L
.3337 .04155 L
.33383 .04149 L
.33397 .04139 L
.33413 .04122 L
.33429 .04099 L
.33458 .04044 L
.33575 .03688 L
.33698 .03229 L
.33729 .03132 L
.33763 .03046 L
.33782 .03008 L
.33799 .02981 L
.33808 .02971 L
.33817 .02962 L
.33826 .02955 L
.33834 .02951 L
.33841 .02948 L
Mistroke
.3385 .02947 L
.33865 .0295 L
.3388 .02959 L
.33894 .02972 L
.33909 .02992 L
.33925 .03018 L
.33958 .03087 L
.34088 .03461 L
.34152 .03644 L
.34211 .03782 L
.34264 .03874 L
.34291 .03907 L
.34307 .03923 L
.34321 .03934 L
.34335 .03944 L
.3435 .03952 L
.34366 .03957 L
.34375 .03959 L
.34382 .03961 L
.34397 .03962 L
.3441 .03962 L
.34426 .0396 L
.3444 .03958 L
.34495 .03942 L
.3451 .03938 L
.34525 .03934 L
.3454 .03931 L
.34553 .03929 L
.34569 .03928 L
.34584 .03929 L
.34592 .0393 L
.346 .03932 L
.34608 .03934 L
.34617 .03938 L
.34633 .03946 L
.34648 .03956 L
.34676 .03981 L
.34707 .0402 L
.34739 .04072 L
.34797 .04191 L
.34866 .04357 L
.34928 .04506 L
.34957 .04567 L
.34987 .04623 L
.35016 .04666 L
.35029 .04681 L
.35043 .04694 L
.35058 .04704 L
.35071 .0471 L
.3508 .04712 L
Mistroke
.35088 .04713 L
.35103 .04712 L
.35118 .04705 L
.35133 .04695 L
.35141 .04687 L
.35149 .04679 L
.35166 .04657 L
.35194 .04608 L
.35221 .04551 L
.3528 .04393 L
.35309 .0431 L
.35336 .04236 L
.35363 .04175 L
.35374 .04154 L
.35387 .04136 L
.354 .04123 L
.35414 .04119 L
.3543 .04125 L
.35444 .04143 L
.35459 .04177 L
.35473 .04221 L
.35488 .04287 L
.35505 .04376 L
.35532 .04572 L
.35557 .04807 L
.35614 .05516 L
.35735 .07632 L
.35863 .10394 L
.3598 .12954 L
.36104 .15382 L
.36168 .16432 L
.36239 .17356 L
.3627 .17674 L
.36304 .17951 L
.3632 .1806 L
.36335 .18149 L
.36349 .18215 L
.36364 .18272 L
.3638 .18317 L
.36394 .18343 L
.36409 .18354 L
.36422 .18352 L
.36436 .18336 L
.36452 .18301 L
.3646 .18278 L
.36468 .18247 L
.36484 .18179 L
.36513 .18 L
.36542 .17772 L
.36595 .17195 L
Mistroke
.36657 .16266 L
.36715 .15186 L
.36846 .12064 L
.36955 .08965 L
.37072 .05506 L
.37104 .04623 L
.37139 .03815 L
.37153 .0354 L
.37168 .033 L
.37177 .03191 L
.37185 .03114 L
.372 .03027 L
.37215 .03027 L
.3723 .03103 L
.37245 .03259 L
.37262 .03489 L
.3732 .046 L
.37434 .06929 L
.37497 .07969 L
.37528 .08384 L
.37557 .08705 L
.37584 .08946 L
.37612 .09137 L
.37627 .09209 L
.37641 .09259 L
.37656 .09295 L
.37664 .09306 L
.37672 .0931 L
.37685 .09305 L
.37697 .09287 L
.3771 .09253 L
.37724 .09199 L
.37738 .09123 L
.37752 .09034 L
.37778 .08819 L
.37832 .0816 L
.37884 .07282 L
.37944 .05976 L
.37998 .04521 L
.38058 .02665 L
.3809 .01605 L
.38098 .01328 L
.38107 .01047 L
.38116 .00841 L
.38124 .00804 L
.38139 .01187 L
.38147 .01459 L
.38156 .01777 L
.38185 .02912 L
.38241 .05274 L
Mistroke
.38481 .16104 L
.38613 .21838 L
.38734 .26327 L
.38792 .28122 L
.38855 .29762 L
.38915 .30982 L
.3897 .31807 L
.39 .3213 L
.39028 .32348 L
.39044 .32436 L
.39059 .32494 L
.39067 .32515 L
.39075 .3253 L
.39084 .32539 L
.39092 .32539 L
.391 .32533 L
.39109 .32518 L
.39117 .32497 L
.39125 .3247 L
.3914 .32404 L
.39155 .32311 L
.39187 .32038 L
.39222 .31619 L
.39285 .30565 L
.39345 .29222 L
.39457 .25901 L
.39709 .15737 L
.39825 .10566 L
.39889 .0783 L
.39948 .05463 L
.39976 .04511 L
.40004 .03663 L
.40019 .03316 L
.40027 .03169 L
.40036 .03044 L
.40051 .02915 L
.40065 .02905 L
.40078 .02992 L
.40093 .03176 L
.40107 .03415 L
.4012 .03674 L
.4017 .04839 L
.40279 .07196 L
.4031 .07726 L
.4034 .08153 L
.40367 .08471 L
.40396 .08736 L
.40413 .08853 L
.40428 .08935 L
.40443 .08996 L
Mistroke
.40457 .09033 L
.40466 .09044 L
.40474 .0905 L
.4049 .09041 L
.40498 .09026 L
.40506 .09006 L
.40515 .08976 L
.40524 .08936 L
.4054 .08851 L
.40557 .08733 L
.40587 .08449 L
.40617 .08088 L
.40645 .07684 L
.40753 .05527 L
.4081 .04178 L
.40841 .03499 L
.40856 .03226 L
.4087 .03035 L
.40885 .02913 L
.40894 .02896 L
.40902 .02916 L
.4091 .02977 L
.40918 .03069 L
.40927 .03207 L
.40937 .03391 L
.40966 .04162 L
.40998 .05237 L
.41118 .10155 L
.41372 .21266 L
.41493 .25804 L
.41604 .29144 L
.4166 .30419 L
.41719 .31463 L
.41753 .31906 L
.4177 .32081 L
.41785 .32218 L
.41799 .3232 L
.41814 .32409 L
.41829 .32476 L
.41845 .32521 L
.4186 .32539 L
.41874 .32534 L
.41887 .32511 L
.41901 .32465 L
.41917 .32393 L
.41933 .32288 L
.41963 .32033 L
.4199 .31719 L
.42015 .31359 L
.42073 .30305 L
Mistroke
.42129 .28966 L
.42191 .27186 L
.42316 .22745 L
.4254 .13005 L
.42661 .07451 L
.42721 .04837 L
.42776 .0256 L
.42807 .01382 L
.42823 .00897 L
.42832 .00795 L
.4284 .00917 L
.42849 .01169 L
.42857 .01442 L
.42873 .01974 L
.42909 .0315 L
.42966 .04863 L
.43029 .06462 L
.43089 .07664 L
.43145 .085 L
.43176 .08835 L
.43205 .09064 L
.4322 .09155 L
.43236 .0923 L
.43244 .09258 L
.43253 .09282 L
.43269 .09306 L
.43284 .09309 L
.43298 .09293 L
.43313 .09256 L
.4332 .0923 L
.43329 .09196 L
.43358 .09028 L
.43385 .08806 L
.43436 .08233 L
.43491 .07408 L
.43613 .05008 L
.43677 .03711 L
.43696 .0341 L
.43705 .03286 L
.43713 .03189 L
.43729 .03062 L
.43737 .03027 L
.43746 .03016 L
.43761 .03064 L
.43769 .03126 L
.43777 .03204 L
.43792 .03407 L
.43806 .03655 L
.43872 .05248 L
.43988 .08681 L
Mistroke
.44105 .12019 L
.44228 .15002 L
.44279 .15989 L
.44334 .16872 L
.44365 .17289 L
.44394 .17611 L
.44423 .17879 L
.4445 .18077 L
.44465 .1816 L
.4448 .18233 L
.44495 .18284 L
.44508 .18319 L
.44522 .18344 L
.44537 .18354 L
.44545 .18354 L
.44554 .18348 L
.44569 .18325 L
.44583 .1829 L
.44598 .18237 L
.44626 .18099 L
.44654 .17917 L
.44679 .17706 L
.44742 .17012 L
.448 .16198 L
.44928 .13865 L
.45181 .08394 L
.45291 .06257 L
.45354 .05298 L
.45384 .0493 L
.45412 .04643 L
.4544 .04427 L
.45454 .04338 L
.4547 .04261 L
.45483 .0421 L
.45497 .04167 L
.4551 .04141 L
.45522 .04126 L
.45536 .04119 L
.45551 .04123 L
.45564 .04134 L
.45578 .04154 L
.45593 .04183 L
.4561 .0422 L
.45639 .04297 L
.45703 .0448 L
.45735 .04559 L
.45764 .0462 L
.45791 .04663 L
.45804 .0468 L
.45819 .04695 L
Mistroke
.45834 .04705 L
.45849 .04712 L
.45864 .04713 L
.45878 .04711 L
.45892 .04705 L
.45905 .04697 L
.4592 .04684 L
.45936 .04666 L
.45968 .04618 L
.45997 .04563 L
.46108 .04304 L
.46171 .04156 L
.4623 .04044 L
.46259 .04001 L
.46291 .03967 L
.46309 .03952 L
.46326 .03942 L
.46342 .03935 L
.4635 .03933 L
.46358 .03931 L
.46373 .03929 L
.46388 .03928 L
.464 .03929 L
.46414 .03931 L
.4643 .03935 L
.46446 .03939 L
.46475 .03948 L
.46489 .03952 L
.46505 .03956 L
.46519 .03959 L
.46532 .03961 L
.46544 .03962 L
.46558 .03962 L
.46571 .03961 L
.46584 .03958 L
.466 .03953 L
.46608 .03949 L
.46617 .03944 L
.46631 .03935 L
.46647 .03922 L
.46675 .03892 L
.46704 .0385 L
.46771 .03718 L
.46833 .03554 L
.46952 .03197 L
.46981 .03119 L
.47012 .03048 L
.47029 .03014 L
.47045 .02989 L
.47053 .02979 L
Mistroke
.47062 .02969 L
.47077 .02956 L
.47091 .02949 L
.47104 .02947 L
.47118 .0295 L
.47133 .0296 L
.47141 .02967 L
.47149 .02976 L
.47164 .02998 L
.47193 .03054 L
.4722 .03123 L
.47249 .0321 L
.473 .03393 L
.47425 .03852 L
.47459 .03955 L
.47495 .04045 L
.47525 .04102 L
.47543 .04126 L
.47551 .04135 L
.47559 .04142 L
.47574 .04152 L
.47582 .04155 L
.47591 .04156 L
.47605 .04155 L
.47621 .04148 L
.47634 .04136 L
.47649 .04118 L
.47664 .04096 L
.47677 .04071 L
.47707 .03995 L
.47741 .03885 L
.47802 .03616 L
.47925 .02889 L
.47985 .02517 L
.48011 .02376 L
.4804 .02254 L
.48047 .02228 L
.48056 .02204 L
.48071 .02173 L
.48079 .02162 L
.48088 .02157 L
.48103 .02162 L
.48112 .02172 L
.48121 .02188 L
.48136 .02233 L
.48153 .02301 L
.48172 .02397 L
.48234 .02829 L
.48293 .03321 L
.48411 .04305 L
Mistroke
.48471 .04705 L
.48505 .04889 L
.48536 .05023 L
.4855 .05071 L
.48565 .05115 L
.48578 .05146 L
.48592 .05172 L
.48607 .05191 L
.48615 .05198 L
.48623 .05201 L
.48637 .052 L
.48651 .0519 L
.48665 .05172 L
.4868 .05143 L
.48695 .05105 L
.48708 .05062 L
.48733 .04958 L
.48759 .04816 L
.48824 .04326 L
.48883 .03705 L
.48947 .02875 L
.48981 .02389 L
.49018 .01872 L
.49034 .01663 L
.4905 .01505 L
.49064 .01418 L
.49079 .01406 L
.49093 .01483 L
.49109 .01647 L
.49122 .01836 L
.49136 .02081 L
.49261 .04873 L
.49514 .11255 L
.49625 .13739 L
.49684 .14875 L
.49747 .15917 L
.49808 .16749 L
.49865 .17318 L
.49892 .17526 L
.49906 .17617 L
.49921 .17699 L
.49934 .1776 L
.49949 .17814 L
.49962 .17851 L
.49974 .17877 L
.49989 .17894 L
.49997 .17897 L
.50005 .17897 L
.50019 .17886 L
.50035 .1786 L
Mistroke
.50048 .17824 L
.50061 .1778 L
.5009 .17642 L
.50121 .17436 L
.50149 .17195 L
.50214 .16477 L
.50271 .1565 L
.50332 .14587 L
.50442 .12285 L
.50691 .0607 L
.50814 .03094 L
.50848 .0238 L
.50867 .02032 L
.50884 .01749 L
.50899 .01559 L
.50914 .01431 L
.50924 .01402 L
.50932 .01406 L
.5094 .01434 L
.50948 .01489 L
.50956 .01559 L
.50965 .0165 L
.5098 .01843 L
.51009 .02251 L
.51074 .03171 L
.51135 .0391 L
.51191 .04456 L
.51246 .04848 L
.51277 .05004 L
.51306 .05106 L
.51322 .05148 L
.51337 .05176 L
.51345 .05186 L
.51353 .05195 L
.51362 .052 L
.5137 .05202 L
.51386 .05197 L
.514 .05184 L
.51415 .0516 L
.51432 .05124 L
.51462 .0503 L
.51495 .04892 L
.51553 .04557 L
.51686 .0351 L
.51746 .02992 L
.51809 .02509 L
.51843 .02319 L
.51852 .02278 L
.51861 .02241 L
.5187 .02213 L
Mistroke
.51879 .02189 L
.51888 .02172 L
.51896 .02162 L
.51904 .02157 L
.51913 .02157 L
.51921 .02163 L
.51929 .02172 L
.51943 .02202 L
.51957 .02244 L
.51973 .02302 L
.52004 .02454 L
.5206 .02791 L
.52125 .03204 L
.52186 .03558 L
.52246 .03834 L
.52279 .03954 L
.5231 .04041 L
.52336 .04095 L
.52351 .04118 L
.52364 .04135 L
.52379 .04147 L
.52392 .04154 L
.52408 .04157 L
.52422 .04154 L
.52438 .04144 L
.52453 .04131 L
.52469 .0411 L
.52485 .04085 L
.52513 .04028 L
.52543 .03951 L
.52675 .03489 L
.5273 .03283 L
.52789 .03098 L
.52807 .03054 L
.52823 .0302 L
.52839 .02992 L
.52854 .02972 L
.52868 .02959 L
.52883 .0295 L
.52898 .02947 L
.52907 .02949 L
.52915 .02951 L
.5293 .02961 L
.52938 .02969 L
.52946 .02977 L
.52979 .03029 L
.53007 .03089 L
.53037 .03167 L
.53169 .0356 L
.53229 .03718 L
Mistroke
.53292 .03845 L
.53326 .03892 L
.53343 .03912 L
.53362 .0393 L
.53379 .03942 L
.53395 .03951 L
.53411 .03957 L
.53426 .0396 L
.53442 .03962 L
.53455 .03962 L
.53463 .03961 L
.53471 .0396 L
.53487 .03958 L
.53501 .03955 L
.53516 .03951 L
.53542 .03942 L
.53572 .03934 L
.5358 .03933 L
.53588 .03931 L
.53603 .03929 L
.53611 .03929 L
.53619 .03928 L
.53628 .03929 L
.53637 .0393 L
.53652 .03933 L
.53661 .03936 L
.53669 .0394 L
.53683 .03947 L
.53699 .03958 L
.53726 .03984 L
.53758 .04026 L
.53788 .04074 L
.53913 .04355 L
.53969 .04491 L
.54021 .046 L
.5405 .04647 L
.54076 .0468 L
.54091 .04694 L
.54105 .04704 L
.5412 .04711 L
.54128 .04713 L
.54136 .04713 L
.54151 .04712 L
.54164 .04706 L
.54179 .04697 L
.54195 .04681 L
.5421 .04661 L
.54227 .04636 L
.54257 .04577 L
.54368 .04278 L
Mistroke
.54398 .04202 L
.54414 .04167 L
.5443 .04142 L
.54444 .04126 L
.5446 .04119 L
.54474 .04123 L
.54488 .04137 L
.54503 .04168 L
.54518 .04211 L
.54534 .04277 L
.54551 .04371 L
.54587 .04634 L
.54619 .04961 L
.54676 .0573 L
.54738 .06768 L
.54848 .09002 L
.55098 .14386 L
.55222 .16521 L
.55256 .16987 L
.55292 .17411 L
.55323 .17719 L
.55356 .17985 L
.55372 .18089 L
.55387 .18172 L
.55402 .18238 L
.55416 .18287 L
.55429 .1832 L
.55443 .18344 L
.55457 .18354 L
.55472 .1835 L
.5548 .18341 L
.55488 .18327 L
.55504 .1829 L
.55512 .18262 L
.5552 .18232 L
.55538 .18146 L
.55567 .17954 L
.55599 .17678 L
.55664 .16908 L
.55723 .15954 L
.55857 .1303 L
.55982 .09559 L
.561 .06064 L
.56156 .04526 L
.56183 .03878 L
.56209 .03399 L
.56223 .03205 L
.56238 .0307 L
.56247 .03029 L
.56255 .03016 L
Mistroke
.5627 .03056 L
.56284 .03162 L
.56297 .03309 L
.56326 .03769 L
.56455 .06412 L
.56518 .07551 L
.56575 .08374 L
.56602 .0868 L
.56631 .08948 L
.56645 .09046 L
.56659 .09134 L
.56673 .09201 L
.56685 .09248 L
.56699 .09286 L
.56714 .09307 L
.56727 .09309 L
.56741 .09294 L
.56756 .09257 L
.5677 .09204 L
.56786 .09124 L
.56802 .09013 L
.56835 .08725 L
.5687 .08304 L
.56933 .07254 L
.56995 .05889 L
.57052 .04352 L
.57108 .02587 L
.5714 .01544 L
.57155 .01054 L
.57169 .00794 L
.57182 .01038 L
.57196 .01519 L
.57226 .02669 L
.57279 .04832 L
.57528 .16075 L
.57643 .21106 L
.57765 .2575 L
.57869 .28916 L
.57928 .30311 L
.57983 .31319 L
.58013 .31751 L
.58042 .32074 L
.58067 .32292 L
.58082 .32385 L
.58095 .32452 L
.5811 .32503 L
.58123 .32531 L
.58138 .3254 L
.58154 .32524 L
.58162 .32506 L
Mistroke
.5817 .3248 L
.58186 .32411 L
.58201 .32319 L
.58216 .32212 L
.58249 .31887 L
.5828 .31481 L
.58337 .30471 L
.584 .29037 L
.58467 .27116 L
.58708 .17885 L
.5883 .12434 L
.58962 .0678 L
.58992 .05597 L
.59026 .04436 L
.59041 .03971 L
.59057 .03542 L
.59071 .03246 L
.59086 .03016 L
.59101 .02907 L
.59114 .0291 L
.59129 .03018 L
.59144 .03228 L
.5917 .0373 L
.59199 .04383 L
.59253 .05677 L
.59313 .06934 L
.59369 .07887 L
.59395 .08247 L
.5942 .08525 L
.59449 .08774 L
.59464 .08875 L
.5948 .08957 L
.59489 .08989 L
.59497 .09016 L
.59506 .09034 L
.59514 .09045 L
.59528 .09049 L
.59544 .0903 L
.59559 .0899 L
.59575 .08924 L
.5959 .08839 L
.59603 .08742 L
.59629 .08508 L
.59657 .08193 L
.59719 .07229 L
.59777 .06055 L
.59841 .04575 L
.59874 .038 L
.59892 .03424 L
.59901 .03263 L
Mistroke
.59909 .03136 L
.59925 .02965 L
.59933 .02913 L
.59941 .02896 L
.59949 .02916 L
.59957 .0297 L
.59966 .03069 L
.59975 .03215 L
.59992 .03564 L
.60007 .03977 L
.60036 .04903 L
.60156 .09713 L
.6038 .19592 L
.60497 .24279 L
.60622 .28332 L
.60673 .29653 L
.60728 .30812 L
.60759 .31349 L
.60788 .31754 L
.60817 .32078 L
.60844 .32307 L
.60858 .32392 L
.60873 .32463 L
.60887 .32509 L
.609 .32533 L
.60914 .32539 L
.60929 .32523 L
.60937 .32505 L
.60946 .32478 L
.60961 .32413 L
.60977 .32317 L
.60994 .32184 L
.61026 .31863 L
.61056 .31455 L
.61084 .30996 L
.61192 .28554 L
.61307 .24911 L
.61545 .14929 L
.61763 .05075 L
.61821 .02686 L
.61851 .01515 L
.6186 .01208 L
.61868 .00955 L
.61884 .00835 L
.61898 .01227 L
.61912 .01677 L
.61943 .02705 L
.61998 .0441 L
.62061 .06097 L
.6212 .07367 L
Mistroke
.62182 .0836 L
.62215 .08745 L
.62231 .08902 L
.6225 .09046 L
.62265 .0914 L
.62281 .09218 L
.6229 .09251 L
.62298 .09275 L
.62314 .09304 L
.62327 .0931 L
.62342 .09298 L
.62358 .09263 L
.62373 .09211 L
.6239 .09125 L
.62407 .0902 L
.62437 .08763 L
.6247 .08402 L
.62506 .07918 L
.62622 .05821 L
.62683 .04527 L
.62717 .03853 L
.62734 .03561 L
.62749 .03331 L
.62764 .03157 L
.62772 .03093 L
.6278 .03044 L
.62788 .03019 L
.62798 .03021 L
.62806 .03051 L
.62814 .03101 L
.62828 .03242 L
.62843 .03463 L
.62873 .04072 L
.62989 .07282 L
.63122 .1119 L
.63243 .14283 L
.63301 .15512 L
.63364 .16617 L
.63424 .1742 L
.63451 .177 L
.63479 .17945 L
.63495 .18056 L
.63509 .18142 L
.63524 .18215 L
.63537 .18269 L
.63553 .18315 L
.63562 .18332 L
.6357 .18345 L
.63579 .18352 L
.63587 .18355 L
Mistroke
.63602 .18347 L
.63618 .18323 L
.63626 .18304 L
.63634 .18278 L
.6365 .18221 L
.63664 .18153 L
.63697 .17949 L
.63732 .17657 L
.63795 .1694 L
.63854 .16087 L
.63988 .13624 L
.64231 .08345 L
.64339 .06254 L
.644 .05319 L
.64456 .04682 L
.64486 .0444 L
.64503 .04334 L
.64518 .04256 L
.64527 .04222 L
.64535 .04194 L
.6455 .04155 L
.64558 .04139 L
.64566 .04129 L
.64575 .04122 L
.64584 .04119 L
.64598 .04122 L
.64614 .04137 L
.64628 .04158 L
.64641 .04183 L
.64704 .04347 L
.64762 .04508 L
.64794 .04583 L
.64823 .0464 L
.64851 .04679 L
.64867 .04695 L
.64881 .04705 L
.64893 .0471 L
.64907 .04713 L
.64921 .04712 L
.64934 .04708 L
.64949 .047 L
.64958 .04693 L
.64966 .04685 L
.64997 .04648 L
.65025 .04602 L
.65055 .04544 L
.65184 .04235 L
.65242 .04107 L
.65297 .04014 L
.65328 .03977 L
Mistroke
.65345 .03961 L
.65361 .03949 L
.65376 .03941 L
.65389 .03935 L
.65405 .03931 L
.65419 .03929 L
.65432 .03928 L
.65446 .03929 L
.65461 .03931 L
.65474 .03934 L
.65525 .03949 L
.65539 .03952 L
.65554 .03956 L
.65568 .03959 L
.65581 .03961 L
.65596 .03962 L
.65603 .03962 L
.65612 .03961 L
.65626 .03959 L
.6564 .03955 L
.65654 .0395 L
.65669 .03941 L
.65696 .0392 L
.65713 .03903 L
.65729 .03884 L
.65758 .0384 L
.65818 .03719 L
.65883 .03547 L
.65998 .03201 L
.66027 .03122 L
.66055 .03057 L
.66079 .0301 L
.66093 .02988 L
.66106 .02972 L
.6612 .02959 L
.66135 .0295 L
.66148 .02947 L
.66161 .02949 L
.66176 .02956 L
.6619 .02968 L
.66204 .02986 L
.6622 .03012 L
.66251 .03079 L
.6628 .03159 L
.66346 .03386 L
.66408 .03624 L
.66476 .03865 L
.66507 .03958 L
.6654 .0404 L
.66568 .04095 L
Mistroke
.66584 .04118 L
.66599 .04136 L
.66614 .04148 L
.6663 .04155 L
.66637 .04156 L
.66646 .04156 L
.66661 .04152 L
.66676 .04142 L
.66691 .04126 L
.66704 .04108 L
.66718 .04084 L
.6675 .04009 L
.66784 .03902 L
.66845 .0364 L
.66962 .02953 L
.67013 .02629 L
.6704 .02471 L
.67069 .02327 L
.67085 .02262 L
.67099 .02215 L
.67114 .02181 L
.67128 .02162 L
.67141 .02157 L
.67154 .02165 L
.67168 .02189 L
.67183 .0223 L
.67198 .02285 L
.67213 .0236 L
.67241 .02529 L
.67305 .03022 L
.6742 .04005 L
.67471 .04393 L
.67526 .04752 L
.67555 .04902 L
.67586 .05032 L
.67603 .05089 L
.67619 .05131 L
.67635 .05164 L
.67649 .05186 L
.67658 .05194 L
.67666 .05199 L
.67674 .05202 L
.67683 .05201 L
.67697 .05192 L
.67706 .05183 L
.67713 .05172 L
.6773 .05139 L
.67747 .05089 L
.67766 .05022 L
.67783 .04944 L
Mistroke
.67815 .04766 L
.67845 .04554 L
.679 .04044 L
.6796 .03346 L
.68026 .02431 L
.68055 .02015 L
.6807 .01808 L
.68086 .01615 L
.681 .01483 L
.68116 .01406 L
.6813 .01415 L
.68143 .01496 L
.6815 .01573 L
.68159 .01677 L
.68174 .01908 L
.68202 .02437 L
.68266 .03847 L
.68488 .09435 L
.68612 .12423 L
.68728 .1481 L
.68791 .15871 L
.68849 .16664 L
.68913 .17325 L
.68948 .17584 L
.68964 .17678 L
.68982 .1776 L
.68998 .1782 L
.69013 .1786 L
.69027 .17885 L
.69043 .17897 L
.69056 .17895 L
.69069 .17883 L
.69083 .17858 L
.69098 .17818 L
.69114 .17759 L
.69131 .17678 L
.69162 .17482 L
.69193 .17233 L
.69221 .16953 L
.69329 .1548 L
.69443 .13305 L
.69681 .07546 L
.69785 .04908 L
.6984 .03589 L
.69899 .02319 L
.69915 .02022 L
.6993 .01775 L
.69943 .01592 L
.69958 .01456 L
.69972 .01401 L
Mistroke
.69986 .0143 L
.69999 .01515 L
.70013 .01656 L
.70133 .03314 L
.70195 .0405 L
.7023 .04381 L
.70263 .04644 L
.70293 .04843 L
.70309 .0493 L
.70326 .05009 L
.70341 .05065 L
.70356 .05115 L
.70371 .05151 L
.70384 .05175 L
.70398 .05193 L
.70414 .05201 L
.70428 .052 L
.70441 .05191 L
.70456 .05172 L
.70465 .05157 L
.70473 .0514 L
.70503 .05055 L
.70531 .04942 L
.70563 .04784 L
.70627 .04372 L
.70742 .03437 L
.70798 .02953 L
.7085 .02552 L
.70879 .02378 L
.70893 .02305 L
.70909 .02241 L
.70918 .02212 L
.70926 .0219 L
.70934 .02175 L
.70942 .02163 L
.70957 .02157 L
.70973 .02167 L
.70987 .02193 L
.71001 .02229 L
.71016 .02284 L
.71031 .02347 L
.71085 .02645 L
.71207 .03409 L
.71274 .03751 L
.71306 .03885 L
.71337 .03984 L
.71363 .04054 L
.71392 .04108 L
.71406 .04129 L
.7142 .04142 L
Mistroke
.71435 .04152 L
.71443 .04155 L
.71451 .04156 L
.71459 .04156 L
.71467 .04155 L
.71482 .04147 L
.7149 .04141 L
.71498 .04134 L
.71516 .04112 L
.71545 .04061 L
.71577 .03988 L
.71636 .03808 L
.71693 .03602 L
.71799 .0321 L
.7183 .03115 L
.7186 .03042 L
.71886 .02993 L
.71901 .02973 L
.71915 .02959 L
.7193 .0295 L
.71944 .02947 L
.71959 .0295 L
.71967 .02954 L
.71975 .02959 L
.71991 .02974 L
.72008 .02997 L
.72038 .03053 L
.72094 .03194 L
.72154 .03371 L
.7226 .03678 L
.7232 .03809 L
.72348 .03857 L
.72374 .03893 L
.72404 .03925 L
.7242 .03937 L
.72436 .03947 L
.72444 .03951 L
.72452 .03954 L
.72468 .03959 L
.72482 .03961 L
.72496 .03962 L
.72509 .03962 L
.72522 .0396 L
.72535 .03958 L
.72547 .03955 L
.72603 .03939 L
.72617 .03935 L
.72631 .03932 L
.72647 .03929 L
.72661 .03928 L
Mistroke
.72675 .03929 L
.72688 .0393 L
.72702 .03934 L
.72717 .0394 L
.72732 .03948 L
.72745 .03957 L
.72776 .03987 L
.72805 .04024 L
.72832 .04067 L
.72958 .04349 L
.73017 .04492 L
.7308 .04619 L
.73113 .04667 L
.73132 .04688 L
.73141 .04696 L
.73149 .04702 L
.73157 .04706 L
.73165 .0471 L
.7318 .04713 L
.73188 .04713 L
.73197 .04712 L
.73213 .04706 L
.73228 .04696 L
.73236 .04688 L
.73244 .04679 L
.73277 .04631 L
.73306 .04574 L
.73337 .04499 L
.73406 .04305 L
.7344 .04215 L
.73455 .04182 L
.73471 .04152 L
.73486 .04131 L
.73501 .04121 L
.73516 .0412 L
.73524 .04125 L
.73532 .04133 L
.73548 .0416 L
.73556 .04182 L
.73564 .04207 L
.73581 .04274 L
.73598 .04367 L
.7363 .04595 L
.73659 .04881 L
.73714 .05588 L
.73832 .07671 L
.73956 .10337 L
.74179 .15021 L
.74293 .16848 L
.74326 .17258 L
Mistroke
.74357 .17592 L
.74385 .17846 L
.74415 .18062 L
.74441 .18202 L
.74456 .18262 L
.7447 .18305 L
.74483 .18333 L
.74495 .18348 L
.74507 .18355 L
.74521 .18349 L
.74535 .1833 L
.74549 .18295 L
.74563 .18248 L
.74576 .18194 L
.74607 .18012 L
.74636 .17779 L
.74692 .17169 L
.74753 .16256 L
.74877 .13701 L
.75099 .07481 L
.75162 .05638 L
.75193 .0479 L
.75222 .0408 L
.75248 .03547 L
.75262 .03314 L
.75275 .03156 L
.7529 .03048 L
.75305 .03017 L
.7532 .0307 L
.75334 .03181 L
.75348 .03358 L
.75364 .03598 L
.75392 .04118 L
.75456 .0546 L
.75523 .06812 L
.75585 .07866 L
.75645 .08631 L
.75675 .08915 L
.75692 .09045 L
.75708 .09142 L
.75724 .09218 L
.75732 .09248 L
.75741 .09274 L
.7575 .09293 L
.7576 .09306 L
.75769 .0931 L
.75777 .09308 L
.75785 .09299 L
.75793 .09285 L
.75801 .09264 L
Mistroke
.7581 .09235 L
.75825 .09169 L
.75842 .09073 L
.75873 .08817 L
.75902 .08502 L
.75967 .07513 L
.76027 .0626 L
.76084 .04786 L
.76144 .02977 L
.76173 .02009 L
.76186 .01577 L
.762 .0112 L
.76215 .00796 L
.76224 .00874 L
.76231 .01082 L
.76265 .02316 L
.76324 .04724 L
.76546 .14726 L
.76771 .24258 L
.76833 .26424 L
.76898 .28418 L
.76955 .29855 L
.77016 .31077 L
.77048 .31589 L
.77079 .31963 L
.77107 .32235 L
.77122 .32339 L
.77138 .32428 L
.77147 .32468 L
.77155 .32497 L
.77163 .32517 L
.77171 .32532 L
.7718 .32539 L
.7719 .32538 L
.77198 .32529 L
.77207 .32511 L
.77216 .32487 L
.77224 .32458 L
.77241 .32371 L
.77257 .32262 L
.77272 .32135 L
.77301 .31824 L
.77333 .31399 L
.77388 .304 L
.77449 .29004 L
.77515 .27106 L
.77748 .18199 L
.77868 .12875 L
.78 .0718 L
.7806 .04878 L
Mistroke
.78093 .03834 L
.7811 .03425 L
.78125 .03137 L
.78139 .02963 L
.78154 .02896 L
.78169 .02951 L
.78178 .03031 L
.78186 .03133 L
.78212 .0361 L
.78241 .04253 L
.78305 .05763 L
.78373 .07172 L
.78406 .07733 L
.78437 .08176 L
.78465 .08503 L
.78495 .08767 L
.7851 .08865 L
.78526 .08948 L
.7854 .09003 L
.78554 .09035 L
.78562 .09046 L
.7857 .0905 L
.78585 .09041 L
.786 .09009 L
.78609 .0898 L
.78617 .08946 L
.78633 .08863 L
.78648 .08763 L
.78682 .08455 L
.78715 .08054 L
.7875 .07513 L
.78866 .05102 L
.78927 .03675 L
.78945 .03329 L
.78954 .03186 L
.78962 .03074 L
.78977 .02933 L
.78985 .029 L
.78993 .02901 L
.79008 .02998 L
.79016 .03104 L
.79024 .0323 L
.79039 .03545 L
.79053 .03915 L
.79118 .0618 L
.79235 .11096 L
.79489 .22146 L
.79605 .26386 L
.79669 .28324 L
.79729 .29847 L
Mistroke
.79785 .30982 L
.79814 .3146 L
.79845 .31871 L
.79872 .32143 L
.79885 .32259 L
.799 .32361 L
.79914 .32435 L
.79926 .32485 L
.79939 .32519 L
.79951 .32536 L
.79965 .32538 L
.7998 .32518 L
.79994 .32477 L
.80006 .32422 L
.80021 .32336 L
.80038 .32216 L
.80068 .31926 L
.80099 .31527 L
.80132 .30997 L
.80192 .29777 L
.80308 .26492 L
.80414 .22647 L
.80666 .1159 L
.80776 .06597 L
.80834 .04081 L
.80867 .0276 L
.80882 .02135 L
.80897 .01579 L
.80911 .01096 L
.80926 .00794 L
.80942 .01097 L
.8095 .01365 L
.80958 .01629 L
.81014 .03461 L
.81123 .06432 L
.81183 .07642 L
.81238 .08468 L
.81267 .0879 L
.81298 .09054 L
.81314 .09151 L
.81323 .09195 L
.81331 .0923 L
.81339 .09257 L
.81347 .0928 L
.81362 .09304 L
.81377 .0931 L
.8139 .09297 L
.81406 .09262 L
.81421 .09209 L
.81435 .09142 L
Mistroke
.81447 .09067 L
.81476 .08845 L
.81508 .08521 L
.81537 .0816 L
.81602 .0714 L
.81666 .05896 L
.81734 .04465 L
.81762 .03906 L
.81792 .03398 L
.81801 .03279 L
.81809 .03184 L
.81825 .03059 L
.81839 .03016 L
.81848 .03027 L
.81855 .0306 L
.81869 .03167 L
.81883 .03348 L
.81897 .03572 L
.81909 .03815 L
.81968 .05287 L
.82088 .08814 L
.82218 .12503 L
.82339 .1532 L
.82396 .1636 L
.8245 .17152 L
.82479 .17507 L
.82512 .17822 L
.82541 .18045 L
.82568 .18197 L
.82582 .18258 L
.82598 .18307 L
.82612 .18337 L
.82626 .18352 L
.82641 .18353 L
.8265 .18347 L
.82658 .18336 L
.82673 .18304 L
.82689 .18253 L
.82704 .1819 L
.82721 .18104 L
.8275 .17906 L
.82785 .176 L
.82818 .17255 L
.82935 .15531 L
.83045 .1342 L
.83174 .10628 L
.83295 .07998 L
.83413 .05821 L
.83445 .05348 L
.8348 .04924 L
Mistroke
.83509 .04628 L
.83526 .04494 L
.83541 .04387 L
.83555 .04308 L
.8357 .04239 L
.83584 .04191 L
.83596 .04157 L
.83609 .04134 L
.83621 .04123 L
.83635 .04119 L
.83648 .04124 L
.83662 .04138 L
.83677 .04161 L
.83704 .04218 L
.83765 .04386 L
.83824 .04544 L
.83853 .04608 L
.8388 .04654 L
.83895 .04674 L
.8391 .04691 L
.83926 .04703 L
.83935 .04708 L
.83944 .04711 L
.83958 .04713 L
.83972 .04712 L
.83987 .04706 L
.84002 .04696 L
.84016 .04683 L
.84029 .04669 L
.84057 .04629 L
.84108 .04532 L
.84223 .04254 L
.84282 .04123 L
.84314 .04062 L
.84344 .04016 L
.84369 .03984 L
.84397 .03958 L
.84412 .03947 L
.84427 .03939 L
.8444 .03934 L
.84455 .03931 L
.84463 .03929 L
.84472 .03929 L
.8448 .03928 L
.84488 .03929 L
.84503 .0393 L
.84518 .03933 L
.84535 .03937 L
.8455 .03942 L
.84585 .03952 L
Mistroke
.84601 .03956 L
.84616 .03959 L
.84629 .03961 L
.84643 .03962 L
.84659 .03961 L
.84667 .03961 L
.84676 .03959 L
.84691 .03954 L
.84706 .03948 L
.84721 .03939 L
.84737 .03927 L
.84766 .03897 L
.848 .0385 L
.84831 .03794 L
.84892 .03654 L
.8495 .03491 L
.85056 .03172 L
.85085 .03096 L
.85117 .03028 L
.85132 .03002 L
.85146 .02981 L
.85159 .02967 L
.85173 .02955 L
.85187 .02949 L
.85203 .02948 L
.8521 .02949 L
.85219 .02953 L
.85234 .02965 L
.85249 .02981 L
.85264 .03005 L
.85291 .03059 L
.85321 .03141 L
.8535 .03231 L
.85415 .03468 L
.85522 .03859 L
.85551 .03948 L
.85582 .04028 L
.85609 .04082 L
.85624 .04107 L
.85638 .04126 L
.85646 .04134 L
.85654 .04142 L
.85669 .04152 L
.85678 .04155 L
.85687 .04157 L
.85695 .04156 L
.85703 .04154 L
.85718 .04146 L
.85727 .04139 L
.85735 .04131 L
Mistroke
.85749 .04112 L
.85765 .04086 L
.85794 .04019 L
.85822 .03936 L
.85884 .03682 L
.85992 .03064 L
.86049 .02704 L
.86108 .02365 L
.86123 .02299 L
.86139 .0224 L
.86148 .02213 L
.86156 .02192 L
.86164 .02176 L
.86172 .02165 L
.86187 .02156 L
.862 .02164 L
.86215 .02188 L
.86231 .02232 L
.8624 .02265 L
.86249 .023 L
.86267 .02396 L
.86301 .02614 L
.86365 .03123 L
.8649 .04184 L
.86552 .04618 L
.86608 .04925 L
.86634 .05035 L
.86649 .05082 L
.86664 .05125 L
.86678 .05157 L
.86691 .05179 L
.86704 .05193 L
.86717 .05201 L
.86731 .05201 L
.86746 .05191 L
.86759 .05174 L
.86773 .05148 L
.86789 .05109 L
.86805 .05055 L
.86834 .04927 L
.86866 .0474 L
.86901 .04481 L
.86965 .03866 L
.87026 .03108 L
.87083 .02293 L
.87111 .01894 L
.87125 .01714 L
.87138 .0157 L
.87153 .01449 L
.87161 .01413 L
Mistroke
.87169 .014 L
.87184 .01447 L
.87197 .01564 L
.87205 .01659 L
.87213 .01777 L
.87228 .02022 L
.87262 .02677 L
.87322 .04051 L
.87576 .10437 L
.8769 .13101 L
.87753 .14391 L
.87813 .1546 L
.87868 .16299 L
.87929 .17025 L
.87955 .17278 L
.87983 .17501 L
.88007 .17653 L
.88034 .17778 L
.88049 .17829 L
.88062 .17863 L
.88077 .17887 L
.88086 .17895 L
.88093 .17898 L
.88109 .17892 L
.88117 .17882 L
.88125 .17869 L
.8814 .17834 L
.88156 .17781 L
.88183 .17652 L
.88209 .17489 L
.88267 .16968 L
.88331 .16181 L
.88389 .15275 L
.88519 .12689 L
.88768 .06544 L
.88889 .03565 L
.88946 .02331 L
.88971 .01877 L
.88985 .01665 L
.88998 .01513 L
.89011 .01423 L
.89025 .01402 L
.8904 .01465 L
.89054 .01583 L
.89068 .01753 L
.89084 .01966 L
.89113 .02383 L
.89222 .0382 L
.89282 .04418 L
.89315 .04675 L
Mistroke
.89345 .04869 L
.89372 .04999 L
.894 .05102 L
.89415 .05143 L
.89423 .0516 L
.89431 .05174 L
.89445 .05191 L
.8946 .05201 L
.89475 .052 L
.89483 .05196 L
.89491 .05188 L
.89507 .05167 L
.89521 .05139 L
.89537 .05096 L
.89553 .05047 L
.89587 .04906 L
.89648 .04556 L
.89707 .04131 L
.89813 .03228 L
.89874 .02726 L
.89904 .02514 L
.89931 .02352 L
.89945 .02285 L
.89958 .02235 L
.89972 .02195 L
.89987 .02167 L
.90002 .02157 L
.90016 .02163 L
.90024 .02172 L
.90032 .02187 L
.90047 .02226 L
.90062 .02278 L
.90079 .02348 L
.90112 .02522 L
.90171 .02891 L
.90225 .03236 L
.90285 .03575 L
.90337 .03819 L
.90366 .03927 L
.90393 .0401 L
.90409 .0405 L
.90426 .04086 L
.90441 .04111 L
.90456 .04132 L
.90471 .04146 L
.90487 .04154 L
.90502 .04157 L
.90515 .04154 L
.9053 .04147 L
.90544 .04136 L
Mistroke
.90556 .04122 L
.90569 .04103 L
.90599 .04047 L
.90627 .03981 L
.90749 .03568 L
.90817 .03312 L
.90847 .0321 L
.90879 .03112 L
.90906 .03046 L
.90934 .02993 L
.9095 .02972 L
.90964 .02958 L
.90979 .0295 L
.90992 .02947 L
.91007 .0295 L
.91023 .02959 L
.91036 .02971 L
.91051 .0299 L
.91083 .03048 L
.91114 .03118 L
.9122 .03427 L
.91275 .03591 L
.91335 .03742 L
.91369 .03812 L
.914 .03864 L
.91431 .03904 L
.9146 .03932 L
.91475 .03942 L
.9149 .0395 L
.91503 .03956 L
.91518 .03959 L
.91533 .03962 L
.91542 .03962 L
.9155 .03962 L
.91565 .03961 L
.91579 .03958 L
.91592 .03956 L
.91607 .03952 L
.91635 .03943 L
.91662 .03936 L
.91674 .03933 L
.91687 .0393 L
.91702 .03929 L
.91716 .03928 L
.91723 .03929 L
.91732 .0393 L
.91747 .03933 L
.91762 .03939 L
.91776 .03946 L
.91789 .03954 L
Mistroke
.91803 .03966 L
.91832 .03996 L
.91862 .04039 L
.91918 .04142 L
.92043 .04442 L
.92076 .04517 L
.92112 .0459 L
.92143 .04643 L
.9216 .04667 L
.92176 .04685 L
.92191 .04697 L
.92206 .04707 L
.92215 .0471 L
.92223 .04713 L
.92239 .04713 L
.92254 .04709 L
.92267 .04702 L
.92282 .0469 L
.92297 .04672 L
.92329 .04624 L
.92362 .04556 L
.92421 .04398 L
.92454 .04303 L
.9249 .04209 L
.92507 .04172 L
.92516 .04156 L
.92524 .04144 L
.92539 .04127 L
.92546 .04121 L
.92555 .04119 L
.9257 .04123 L
.92578 .04131 L
.92586 .04142 L
.926 .04172 L
.92615 .0422 L
.92629 .04276 L
.92642 .04342 L
.9267 .04538 L
.92703 .04836 L
.92732 .05176 L
.92798 .06151 L
.93048 .11315 L
.93158 .13679 L
.93279 .15931 L
.93335 .16769 L
.93395 .17493 L
.93422 .17758 L
.93451 .17986 L
.93476 .18139 L
.93489 .18203 L
Mistroke
.93503 .1826 L
.93512 .18288 L
.93519 .18309 L
.93535 .18339 L
.93548 .18353 L
.93563 .18353 L
.93579 .18336 L
.93593 .18305 L
.93602 .18281 L
.93609 .18254 L
.93627 .18178 L
.93655 .18009 L
.93686 .17762 L
.93742 .17142 L
.938 .16271 L
.93855 .15254 L
.9398 .12313 L
.94103 .08806 L
.9417 .06793 L
.94233 .04999 L
.94262 .04262 L
.94289 .03666 L
.94304 .03401 L
.94312 .03285 L
.9432 .03183 L
.94335 .0306 L
.94349 .03017 L
.94364 .03049 L
.94372 .03101 L
.9438 .03169 L
.94395 .03347 L
.94409 .03562 L
.94476 .04868 L
.94536 .06132 L
.94593 .0721 L
.94648 .08083 L
.94699 .08697 L
.94726 .08942 L
.94754 .09134 L
.94769 .09207 L
.94783 .09258 L
.94798 .09294 L
.94807 .09305 L
.94815 .0931 L
.9483 .09303 L
.94845 .09276 L
.94852 .09254 L
.94861 .09223 L
.94878 .09142 L
.94893 .09049 L
Mistroke
.94909 .08926 L
.94938 .08641 L
.94994 .07867 L
.95053 .0674 L
.9516 .03981 L
.95188 .03096 L
.95219 .02081 L
.95233 .01605 L
.95248 .01119 L
.95261 .00815 L
.95275 .00957 L
.95283 .01215 L
.95291 .01485 L
.95308 .02135 L
.95339 .03381 L
.95398 .05861 L
.95619 .15909 L
.9574 .21163 L
.95868 .26022 L
.95931 .27988 L
.95989 .2955 L
.96042 .30684 L
.96071 .31213 L
.96099 .31628 L
.96128 .31986 L
.96155 .32236 L
.9617 .32342 L
.96184 .32421 L
.96198 .32483 L
.96207 .32508 L
.96214 .32525 L
.96227 .32539 L
.96239 .32537 L
.96252 .32518 L
.96266 .32478 L
.96281 .32414 L
.96295 .32333 L
.96321 .32127 L
.96349 .31821 L
.9638 .31402 L
.96435 .3042 L
.96501 .28887 L
.9656 .27182 L
.96792 .18357 L
.96912 .13057 L
.97043 .07346 L
.97103 .05037 L
.97136 .03969 L
.97152 .03538 L
.97167 .0322 L
Mistroke
.97181 .03013 L
.97196 .02905 L
.97211 .02919 L
.9722 .02979 L
.97228 .03064 L
.97242 .03269 L
.97255 .03503 L
.97283 .0413 L
.97405 .0687 L
.97438 .07476 L
.97473 .08023 L
.97506 .08431 L
.97537 .08723 L
.97558 .08867 L
.97569 .08929 L
.9758 .08976 L
.97589 .09006 L
.97599 .0903 L
.97609 .09045 L
.97619 .0905 L
Mfstroke
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00AOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0000eoooo
o`?o0000=Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0003?ooooo0_l0000doooo
o`Go00000oooool00ol0003oooooooooo`02ooooo`?o0000=Oooool3o`0003Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`?o0000<oooool004Gooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000e
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000aooooo`04o`00
0?ooooooooooo`0003Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000003?ooooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000booooo`00?Oooool5o`0000Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0[ooooo`Go00001Oooool00ol0003oooooooooo`0/ooooo`Go00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02oooooo00Co0000oooooooooooo0000
=Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo0016ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0;oooool01?l0003oooooooooool0000fooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool004Oooooo00?o0000ooooooooool01Ooo
ool4o`0003Cooooo1?l0000eooooo`05o`000?ooooooooooooooool000001oooool4o`0003;ooooo
00Co0000oooooooooooo0000<oooool01Ol0003ooooooooooooooooo000000Oooooo1?l0000doooo
o`Co0000>?ooool00ol0003oooooooooo`05ooooo`Co0000<oooool004?ooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0<oooool01?l0003oooooooooool0
000cooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03Gooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo03Co
oooo0013ooooo`Go00001oooool5o`0003?ooooo1Ol0000eooooo`?o00002?ooool5o`0003;ooooo
0_l0000eooooo`?o00002?ooool5o`0003?ooooo1Ol0000cooooo`Go00001oooool5o`0003;ooooo
003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo
003oooooooWooooo003oooooooWooooo000Fooooo`;o00001oooooooo`000<_o00003oooool001Go
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`05o`000?oooooooooo
ooooool000003oooool001Gooooo00Co0000oooooooooooo00001_ooool4o`000003ooooool0003o
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`Go00003oooool0
01Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool03Oooool001Gooooo00Co0000oooooooooooo00001_ooool0
0ol0003oooooooooo`0Cooooo`03ool00?oooooooooo03kooooo0_oo000Dooooo`03ool00?oooooo
oooo03oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Nooooo`03o`000?oooooo
oooo01kooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0oooooo`03ool00?oooooo
oooo01;ooooo00?oo`00ooooooooool0?oooool00ooo003oooooooooo`0Booooo`03o`000?oooooo
oooo00gooooo000Eooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04oooool0
0ooo003oooooooooo`0nooooo`;oo`005?ooool00ooo003oooooooooo`0nooooo`;oo`005?ooool0
0ooo003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo0_oo000Dooooo`03ool00?oooooo
oooo03kooooo0_oo000Dooooo`03ool00?oooooooooo03oooooo00?oo`00ooooooooool04_ooool0
0ol0003oooooooooo`0=ooooo`005_ooool2o`0000Oooooo0ol0000Cooooo`03ool00?oooooooooo
03kooooo0_oo000Dooooo`03ool00?oooooooooo03kooooo0_oo000Dooooo`03ool00?oooooooooo
01kooooo00?o0000ooooooooool07Oooool2ool001Cooooo00?oo`00ooooooooool0?_ooool2ool0
01Cooooo00?oo`00ooooooooool0?oooool00ooo003oooooooooo`0Aooooo`;o00003oooool001oo
oooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0Iooooo`;oo`001oooool00ooo003o
ooooooooo`0Iooooo`;oo`005?ooool00ooo003oooooooooo`0Iooooo`;oo`001oooool00ooo003o
ooooooooo`0Iooooo`;oo`005?ooool00ooo003oooooooooo`0Iooooo`;oo`000oooool01Ol0003o
ooooooooooooooooo`0001_ooooo0_oo000Dooooo`03ool00?oooooooooo01Wooooo0_oo0007oooo
o`03ool00?oooooooooo01Wooooo0_oo000Dooooo`03ool00?oooooooooo01Wooooo0_oo0007oooo
o`03ool00?oooooooooo01Wooooo0_oo000Dooooo`03o`000?oooooooooo00gooooo000Oooooo`03
o`000?oooooooooo01?ooooo00?oo`00ooooooooool06Oooool2ool000Oooooo00?oo`00oooooooo
ool06Oooool2ool001Cooooo00?oo`00ooooooooool06Oooool2ool000Oooooo00?oo`00oooooooo
ool06Oooool2ool001Cooooo00?oo`00ooooooooool06Oooool2ool000?ooooo00Go0000oooooooo
ooooooooool0000Kooooo`;oo`005?ooool00ooo003oooooooooo`0Iooooo`;oo`001oooool00ooo
003oooooooooo`0Iooooo`;oo`005?ooool00ooo003oooooooooo`0Iooooo`;oo`001oooool00ooo
003oooooooooo`0Iooooo`;oo`005?ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003o
ooooooooo`0Cooooo`03ool00?oooooooooo01Wooooo0_oo0007ooooo`03ool00?oooooooooo01Wo
oooo0_oo000Dooooo`03ool00?oooooooooo01Wooooo0_oo0007ooooo`03ool00?oooooooooo01Wo
oooo0_oo000Dooooo`03ool00?oooooooooo01Wooooo0_oo0003ooooo`05o`000?oooooooooooooo
oooo00006oooool2ool001Cooooo00?oo`00ooooooooool06Oooool2ool000Oooooo00?oo`00oooo
ooooool06Oooool2ool001Cooooo00?oo`00ooooooooool06Oooool2ool000Oooooo00?oo`00oooo
ooooool06Oooool2ool001Cooooo00?o0000ooooooooool03Oooool001oooooo0ol0000Cooooo`03
ool00?oooooooooo01Gooooo00Coo`00oooooooooooooooo0_oo0007ooooo`04ool00?oooooooooo
ooooo`;oo`005_ooool2ool001Cooooo00?oo`00ooooooooool05Oooool01?oo003ooooooooooooo
ool2ool000Oooooo00Coo`00oooooooooooooooo0_oo000Fooooo`;oo`005?ooool00ooo003ooooo
ooooo`0Eooooo`04ool00?ooooooooooooooo`;oo`000oooool01Ol0003oooooooooooooooooo`00
00?ooooo0_oo000Fooooo`;oo`005?ooool00ooo003oooooooooo`0Eooooo`04ool00?oooooooooo
ooooo`;oo`001oooool01?oo003oooooooooooooool2ool001Kooooo0_oo000Dooooo`03ool00?oo
oooooooo01Gooooo00Coo`00oooooooooooooooo0_oo0007ooooo`04ool00?ooooooooooooooo`;o
o`005_ooool2ool001?ooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`0Cooooo`03ool0
0?oooooooooo01Gooooo00Coo`00oooooooooooooooo0_oo0007ooooo`04ool00?oooooooooooooo
o`;oo`005_ooool2ool001Cooooo00?oo`00ooooooooool05Oooool01?oo003oooooooooooooool2
ool000Oooooo00Coo`00oooooooooooooooo0_oo000Fooooo`;oo`005?ooool00ooo003ooooooooo
o`0Eooooo`04ool00?ooooooooooooooo`;oo`000oooool01Ol0003oooooooooooooooooo`0000?o
oooo0_oo000Fooooo`;oo`005?ooool00ooo003oooooooooo`0Eooooo`04ool00?oooooooooooooo
o`;oo`001oooool01?oo003oooooooooooooool2ool001Kooooo0_oo000Dooooo`03ool00?oooooo
oooo01Gooooo00Coo`00oooooooooooooooo0_oo0007ooooo`04ool00?ooooooooooooooo`;oo`00
5_ooool2ool001Cooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool04ooo
ool00ooo003oooooooooo`0Eooooo`;oo`000_ooool2ool000Oooooo0_oo0002ooooo`;oo`005_oo
ool2ool001Cooooo00?oo`00ooooooooool05Oooool2ool000;ooooo0_oo0007ooooo`;oo`000_oo
ool2ool001Kooooo0_oo000Dooooo`03ool00?oooooooooo01Gooooo00Coo`00oooooooooooooooo
0_oo0003ooooo`05o`000?oooooooooooooooooo00000oooool2ool001Kooooo0_oo000Dooooo`03
ool00?oooooooooo01Gooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo0_oo000Fooooo`;o
o`005?ooool00ooo003oooooooooo`0Eooooo`;oo`000_ooool2ool000Oooooo00Coo`00oooooooo
oooooooo0_oo000Fooooo`;oo`005?ooool00ol0003oooooooooo`0=ooooo`007oooool3o`0000[o
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Dooooo`03ool00?ooooooo`0000;o
oooo0_oo0007ooooo`;oo`000_ooool2ool001Kooooo0_oo0007ooooo`05ool00?oooooooooooooo
oooo00002?ooool00ooo003oooooooooo`0Dooooo`03ool00?ooooooo`0000;ooooo0_oo0006oooo
o`03ool00?ooooooo`0000;ooooo0_oo000Fooooo`;oo`001oooool01Ooo003ooooooooooooooooo
o`0000Sooooo00?oo`00ooooooooool05?ooool00ooo003oooooool00002ooooo`;oo`000oooool0
1?l0003oooooooooooooool2ool000;ooooo0_oo000Fooooo`;oo`001oooool01Ooo003ooooooooo
ooooooooo`0000Sooooo00?oo`00ooooooooool05Oooool2ool000;ooooo0_oo0007ooooo`;oo`00
0_ooool2ool001Kooooo0_oo0007ooooo`05ool00?oooooooooooooooooo00002?ooool00ooo003o
ooooooooo`0Aooooo`06ool00?ooooooooooool00?ooooooo`000_ooool2ool000Oooooo00Coo`00
oooooooooooooooo0_oo000Fooooo`;oo`001oooool00ooo003oooooooooo`09ooooo`;o00003ooo
ool001oooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`06ooooo`;oo`000_ooool0
0ooo003oooooooooo`0<ooooo`;oo`000_ooool00ooo003oooooool00002ooooo`;oo`001_ooool0
0ooo003oooooool00002ooooo`;oo`000_ooool3ool000gooooo00Coo`00oooooooooooooooo0_oo
0007ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0000ko
oooo0_oo0002ooooo`03ool00?ooooooo`0000;ooooo0_oo0006ooooo`03ool00?ooooooo`0000;o
oooo0_oo0003ooooo`;oo`003Oooool01?oo003oooooooooooooool2ool000Oooooo00Goo`00oooo
ooooooooooooool00008ooooo`05ool00?oooooooooooooooooo00003_ooool2ool000;ooooo00?o
o`00oooooooo00000_ooool2ool000?ooooo00Co0000oooooooooooooooo0_oo0002ooooo`;oo`00
0oooool2ool000gooooo00Coo`00oooooooooooooooo0_oo0007ooooo`;oo`000_ooool00ooo003o
ooooooooo`06ooooo`05ool00?oooooooooooooooooo00003_ooool2ool000;ooooo00?oo`00oooo
oooo00000_ooool2ool000Oooooo0_oo0002ooooo`;oo`000oooool00ooo003oooooooooo`0<oooo
o`04ool00?ooooooooooooooo`;oo`001oooool2ool000;ooooo00?oo`00ooooooooool01_ooool0
1Ooo003oooooooooooooooooo`0000kooooo0_oo0002ooooo`03ool00?ooooooo`0000;ooooo0_oo
0006ooooo`;oo`000oooool2ool000?ooooo0_oo000=ooooo`;oo`000_ooool2ool000Oooooo0_oo
000;ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00[ooooo00?oo`00
ooooooooool01_ooool2ool000;ooooo00?oo`00ooooooooool03?ooool2ool000;ooooo00?oo`00
oooooooo00000_ooool2ool000Kooooo00?oo`00oooooooo00000_ooool2ool000;ooooo00?oo`00
oooooooo00003Oooool01?oo003oooooooooooooool2ool000Oooooo0_oo0002ooooo`03ool00?oo
oooooooo00Kooooo00Goo`00ooooooooooooooooool0000>ooooo`;oo`000_ooool00ooo003ooooo
ool00002ooooo`;oo`001_ooool00ooo003oooooool00002ooooo`;oo`000_ooool00ooo003ooooo
ool0000=ooooo`;oo`000_ooool2ool000Oooooo0_oo0002ooooo`03ool00?oooooooooo00Kooooo
00Goo`00ooooooooooooooooool0000>ooooo`;oo`000_ooool00ooo003oooooool00002ooooo`;o
o`000oooool01?l0003oooooooooooooool2ool000;ooooo00Ooo`00oooooooo003oooooool00?oo
ooooo`0000gooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo00?oo`00ooooooooool01_oo
ool01Ooo003oooooooooooooooooo`0000kooooo0_oo0002ooooo`03ool00?ooooooo`0000;ooooo
0_oo0006ooooo`03ool00?ooooooo`0000;ooooo00Ooo`00oooooooo003oooooool00?ooooooo`00
00gooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo00?oo`00ooooooooool01_ooool01Ooo
003oooooooooooooooooo`0000kooooo0_oo0002ooooo`03ool00?ooooooo`0000;ooooo0_oo0006
ooooo`03ool00?ooooooo`0000;ooooo00Ooo`00oooooooo003oooooool00?ooooooo`0000gooooo
0_oo0002ooooo`;oo`001oooool2ool000_ooooo00?o0000ooooooooool03Oooool001oooooo00?o
0000ooooooooool02_ooool00ooo003oooooooooo`06ooooo`;oo`000_ooool00ooo003ooooooooo
o`0<ooooo`;oo`000_ooool01ooo003oooooool00?ooooooo`00oooooooo00001_ooool00ooo003o
ooooool00002ooooo`07ool00?ooooooo`00oooooooo003oooooool0000=ooooo`;oo`000_ooool2
ool000Oooooo0_oo0002ooooo`03ool00?oooooooooo00Kooooo0_oo0002ooooo`03ool00?oooooo
oooo00cooooo00Ooo`00oooooooo003oooooool00?ooooooo`0000;ooooo0_oo0006ooooo`07ool0
0?ooooooo`00oooooooo003oooooool00002ooooo`03ool00?ooooooo`0000gooooo0_oo0002oooo
o`;oo`001oooool2ool000;ooooo00?oo`00ooooooooool01_ooool01Ooo003ooooooooooooooooo
o`0000gooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002ooooo`;oo`000oooool0
1?l0003oooooooooooooool2ool00009oooooooo003ooooooooooooo003oooooool00?ooooooo`00
00gooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo00?oo`00ooooooooool01_ooool01Ooo
003oooooooooooooooooo`0000gooooo00?oo`00oooooooo00000_ooool00ooo003oooooool00002
ooooo`;oo`001_ooool00ooo003oooooool00002ooooo`07ool00?ooooooo`00oooooooo003ooooo
ool0000=ooooo`;oo`000_ooool2ool000Oooooo0_oo0002ooooo`03ool00?oooooooooo00Kooooo
00Goo`00ooooooooooooooooool0000=ooooo`08ool00?ooooooooooool00?ooooooo`00oooooooo
0002ooooo`;oo`001_ooool00ooo003oooooool00002ooooo`07ool00?ooooooo`00oooooooo003o
ooooool0000=ooooo`;oo`000_ooool2ool000Oooooo0_oo000;ooooo`03o`000?oooooooooo00go
oooo000Oooooo`?o00002_ooool00ooo003oooooooooo`06ooooo`;oo`000_ooool00ooo003ooooo
ooooo`0;ooooo`0<ool00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
1_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00Coo`00oooooooo003ooooo0_oo000<oooo
o`;oo`000_ooool2ool000Oooooo0_oo0002ooooo`03ool00?oooooooooo00Kooooo0_oo0002oooo
o`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo
00;oo`001_ooool01Ooo003oooooool00?ooooooo`0000;ooooo00Coo`00oooooooo003ooooo0_oo
000<ooooo`;oo`000_ooool2ool000Oooooo0_oo0002ooooo`03ool00?oooooooooo00Kooooo00Go
o`00ooooooooooooooooool0000=ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo0000
0_ooool2ool000?ooooo00Co0000oooooooooooooooo0_oo00001oooooooo`00ooooooooooooo`00
oooooooo00000_ooool00ooo003oooooooooo`0:ooooo`;oo`000_ooool2ool000Oooooo0_oo0002
ooooo`03ool00?oooooooooo00Kooooo0_oo0002ooooo`03ool00?oooooooooo00_ooooo00Soo`00
ooooooooooooo`00oooooooo003oooooool000;ooooo0_oo0006ooooo`03ool00?ooooooo`0000;o
oooo00Ooo`00oooooooo003oooooool00?ooooooo`0000gooooo0_oo0002ooooo`;oo`001oooool2
ool000;ooooo00?oo`00ooooooooool01_ooool01?oo003oooooooooooooool2ool000cooooo00Ko
o`00ooooooooooooo`00oooooooo0002ooooo`04ool00?ooooooo`00ool000Kooooo00?oo`00oooo
oooo00000_ooool01_oo003oooooool00?ooooooo`00ooooo`;oo`003?ooool2ool000;ooooo0_oo
0007ooooo`;oo`002_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00[ooooo00?oo`00
ooooooooool01_ooool2ool000;ooooo00?oo`00ooooooooool02Oooool3ool000;ooooo0_oo0002
ooooo`05ool00?ooooooo`00oooooooo00001_ooool01Ooo003oooooool00?ooooooo`0000;ooooo
0ooo0002ooooo`?oo`002_ooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool00ooo003ooooo
ooooo`06ooooo`;oo`000_ooool00ooo003oooooooooo`09ooooo`?oo`000_ooool2ool000;ooooo
00?oo`00ooooooooool00_oo0006ooooo`05ool00?ooooooo`00oooooooo00000_ooool00ooo003o
ooooool00002ooooo`?oo`002_ooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool2ool000Oo
oooo00Goo`00ooooooooooooooooool0000;ooooo`?oo`000_ooool2ool000?ooooo00Coo`00oooo
oooo003oo`000oooool01?l0003oooooooooooooool2ool00004oooooooo003oooooooooo`;oo`00
0oooool3ool000[ooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo0_oo0007ooooo`;oo`00
0_ooool2ool000[ooooo0ooo0002ooooo`;oo`000_ooool00ooo003oooooooooo`02ool000Kooooo
00?oo`00oooooooo00000_ooool00ooo003oooooool00002ool000;ooooo0ooo000:ooooo`;oo`00
0_ooool2ool000Oooooo0_oo0002ooooo`;oo`001oooool01?oo003oooooooooooooool2ool000[o
oooo0ooo0002ooooo`;oo`000oooool01?oo003oooooool00?oo0006ooooo`05ool00?ooooooo`00
oooooooo00000_ooool2ool000?ooooo0ooo000:ooooo`;oo`000_ooool2ool000Oooooo0_oo000;
ooooo`03o`000?oooooooooo00gooooo000Eooooo`?o00001oooool00ol0003oooooooooo`0:oooo
o`03ool00?oooooooooo00Kooooo0_oo0002ooooo`03ool00?oooooooooo00Gooooo0_oo00000ooo
ooooo`00ool00004ooooo`;oo`000_ooool01Ooo003oooooool00?ooooooo`0000Kooooo00Goo`00
oooooooo003oooooool00002ooooo`;oo`001Oooool01?oo003ooooooooooooo0007ooooo`;oo`00
0_ooool2ool000Oooooo0_oo0002ooooo`03ool00?oooooooooo00Kooooo0_oo0002ooooo`03ool0
0?oooooooooo00Gooooo0_oo00000oooooooo`00ool00004ooooo`;oo`000oooool01?oo003ooooo
ool00?oo0006ooooo`05ool00?ooooooo`00oooooooo00000_ooool2ool000Gooooo00Coo`00oooo
ooooooooo`001oooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool2ool000Oooooo0_oo0002
ooooo`03ool00?oooooooooo00Gooooo0_oo00000oooooooo`00ool00004ooooo`;oo`000oooool2
ool00003oooooooo003ooooo00;ooooo00Co0000oooooooooooooooo0_oo00001?ooooooo`00oooo
ooooool2ool000Gooooo00Coo`00ooooooooooooo`001oooool2ool000;ooooo0_oo0007ooooo`;o
o`000_ooool2ool000Oooooo0_oo0002ooooo`;oo`001_ooool2ool00003oooooooo003oo`0000Co
oooo0_oo0002ooooo`03ool00?oooooooooo00;oo`001_ooool01Ooo003oooooool00?ooooooo`00
00;ooooo0_oo0005ooooo`04ool00?ooooooooooool000Oooooo0_oo0002ooooo`;oo`001oooool2
ool000;ooooo0_oo0007ooooo`04ool00?ooooooooooooooo`;oo`001_ooool2ool00003oooooooo
003oo`0000Cooooo0_oo0003ooooo`04ool00?ooooooo`00ool000Kooooo00Goo`00oooooooo003o
ooooool00002ooooo`;oo`001Oooool01?oo003ooooooooooooo0007ooooo`;oo`000_ooool2ool0
00Oooooo0_oo000;ooooo`03o`000?oooooooooo00gooooo000Dooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo00Kooooo0_oo0002oooo
o`03ool00?oooooooooo00Gooooo0_oo00000oooooooo`00ooooo`08ooooo`05ool00?ooooooo`00
oooooooo00001_ooool01Ooo003oooooool00?ooooooo`0000[ooooo00Coo`00oooooooo003oo`00
1_ooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool00ooo003oooooooooo`06ooooo`;oo`00
0_ooool00ooo003oooooooooo`05ooooo`;oo`0000?oooooool00?ooool02Oooool2ool00003oooo
oooo003ooooo00Gooooo00Goo`00oooooooo003oooooool0000:ooooo`04ool00?ooooooo`00ool0
00Kooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool00ooo
003oooooooooo`05ooooo`;oo`0000?oooooool00?ooool02Oooool2ool00003oooooooo003ooooo
00;ooooo00Co0000oooooooooooooooo0_oo00000oooooooo`00ooooo`09ooooo`04ool00?oooooo
o`00ool000Kooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo0_oo0007ooooo`;oo`000_oo
ool2ool000Kooooo0_oo00000oooooooo`00ooooo`09ooooo`04ool00?ooooooo`00ool000Kooooo
00Goo`00oooooooo003oooooool0000:ooooo`04ool00?ooooooo`00ool000Kooooo0_oo0002oooo
o`;oo`001oooool2ool000;ooooo0_oo0007ooooo`04ool00?ooooooooooooooo`;oo`001_ooool2
ool00003oooooooo003ooooo00Wooooo0_oo00000oooooooo`00ooooo`05ooooo`05ool00?oooooo
o`00oooooooo00002Oooool00ooo003oooooooooo`02ool000Kooooo0_oo0002ooooo`;oo`001ooo
ool2ool000_ooooo00?o0000ooooooooool03Oooool001Sooooo00?o0000ooooooooool01?ooool4
o`0000Wooooo00?oo`00ooooooooool01_ooool2ool000;ooooo0_oo0006ooooo`?oo`002_ooool0
1Ooo003oooooool00?ooooooo`0000Kooooo00Goo`00oooooooo003oooooool0000:ooooo`;oo`00
00?oooooool00?ooool01Oooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool00ooo003ooooo
ooooo`06ooooo`;oo`000_ooool2ool000Kooooo0ooo000;ooooo`;oo`0000?oooooool00?ooool0
1Oooool01Ooo003oooooool00?ooooooo`0000[ooooo0_oo00000oooooooo`00ooooo`05ooooo`;o
o`000_ooool2ool000Oooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo0_oo0006ooooo`Co
o`002_ooool2ool00003oooooooo003ooooo00;ooooo00Co0000oooooooooooooooo0_oo00000ooo
ooooo`00ooooo`09ooooo`;oo`0000?oooooool00?ooool01Oooool2ool000;ooooo0_oo0007oooo
o`;oo`000_ooool2ool000Oooooo0_oo0002ooooo`;oo`001_ooool4ool000[ooooo0_oo00000ooo
ooooo`00ooooo`05ooooo`05ool00?ooooooo`00oooooooo00002_ooool2ool00003oooooooo003o
oooo00Gooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo0_oo0007ooooo`04ool00?oooooo
ooooooooo`;oo`001_ooool4ool000[ooooo0_oo00000oooooooo`00ooooo`05ooooo`05ool00?oo
ooooo`00oooooooo00002_ooool2ool00003oooooooo003ooooo00Gooooo0_oo0002ooooo`;oo`00
1oooool2ool000Sooooo1?l0000?ooooo`006?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00[ooooo0_oo0007ooooo`;oo`000_ooool2ool000Kooooo00?oo`00oooooooo00002ooo
ool2ool00003oooooooo003ooooo00Gooooo00Goo`00oooooooo003oooooool0000:ooooo`;oo`00
00?oooooool00?ooool01Oooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool00ooo003ooooo
ooooo`06ooooo`;oo`000_ooool2ool000Kooooo00?oo`00oooooooo00002oooool2ool00003oooo
oooo003ooooo00Gooooo00Goo`00oooooooo003oooooool0000:ooooo`;oo`0000?oooooool00?oo
ool01Oooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool2ool000Oooooo0_oo0002ooooo`;o
o`001_ooool00ooo003oooooool0000;ooooo`;oo`0000?oooooool00?ooool00_ooool02?l0003o
oooooooooooo003oooooool00?ooooooo`002_ooool2ool00003oooooooo003ooooo00Gooooo0_oo
0002ooooo`;oo`001oooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool2ool000Kooooo00?o
o`00oooooooo00002oooool2ool00003oooooooo003ooooo00Gooooo00?oo`00ooooooooool00_oo
000:ooooo`;oo`0000?oooooool00?ooool01Oooool2ool000;ooooo0_oo0007ooooo`;oo`000_oo
ool2ool000Oooooo00Coo`00oooooooooooooooo0_oo0006ooooo`03ool00?ooooooo`0000_ooooo
0_oo00000oooooooo`00ooooo`05ooooo`03ool00?ooooooo`0000;oo`002_ooool2ool00003oooo
oooo003ooooo00Gooooo0_oo0002ooooo`;oo`001oooool2ool000_ooooo00?o0000ooooooooool0
3Oooool001Cooooo1?l00007ooooo`03o`000?oooooooooo00[ooooo0_oo0007ooooo`;oo`000_oo
ool2ool000Kooooo00?oo`00ooooooooool02oooool2ool00003oooooooo003ooooo00Gooooo00?o
o`00ooooooooool00_oo000=ooooo`03ool00?oooooooooo00Cooooo0_oo0002ooooo`;oo`001ooo
ool2ool000;ooooo00?oo`00ooooooooool01_ooool2ool000;ooooo0_oo0006ooooo`03ool00?oo
oooooooo00_ooooo0_oo00000oooooooo`00ooooo`05ooooo`03ool00?oooooooooo00;oo`003Ooo
ool00ooo003oooooooooo`04ooooo`;oo`000_ooool2ool000Oooooo0_oo0002ooooo`;oo`001ooo
ool2ool000;ooooo0_oo0006ooooo`03ool00?oooooooooo00_ooooo0_oo00000oooooooo`00oooo
o`02ooooo`04o`000?ooooooooooool000;ooooo0_oo000=ooooo`03ool00?oooooooooo00Cooooo
0_oo0002ooooo`;oo`001oooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool2ool000Kooooo
00?oo`00ooooooooool02oooool2ool00003oooooooo003ooooo00Gooooo00?oo`00ooooooooool0
0_oo000=ooooo`03ool00?oooooooooo00Cooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo
0_oo0007ooooo`04ool00?ooooooooooooooo`;oo`001_ooool00ooo003oooooooooo`0;ooooo`;o
o`0000?oooooool00?ooool01Oooool00ooo003oooooooooo`02ool000gooooo00?oo`00oooooooo
ool01?ooool2ool000;ooooo0_oo0007ooooo`;oo`002oooool00ol0003oooooooooo`0=ooooo`00
5?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo0_oo0007ooooo`;oo`00
0_ooool2ool000Kooooo00?oo`00ooooooooool02oooool2ool00003oooooooo003ooooo00Gooooo
00Coo`00ooooooooooooo`003_ooool00ooo003oooooooooo`04ooooo`;oo`000_ooool2ool000Oo
oooo0_oo0002ooooo`;oo`001_ooool00ooo003oooooool00002ooooo`;oo`001_ooool00ooo003o
ooooooooo`0;ooooo`;oo`0000?oooooool00?ooool01Oooool01?oo003ooooooooooooo000>oooo
o`03ool00?oooooooooo00Cooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo0_oo0007oooo
o`;oo`000_ooool2ool000Kooooo00?oo`00ooooooooool02oooool2ool00003oooooooo003ooooo
00;ooooo00Co0000ooooooooooooo`000_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooo
oooo00Cooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool2
ool000Kooooo00?oo`00ooooooooool02oooool2ool00003oooooooo003ooooo00Gooooo00Coo`00
ooooooooooooo`003_ooool00ooo003oooooooooo`04ooooo`;oo`000_ooool2ool000Oooooo0_oo
0002ooooo`;oo`001oooool2ool000;ooooo0_oo0006ooooo`03ool00?oooooooooo00_ooooo0_oo
00000oooooooo`00ooooo`05ooooo`04ool00?ooooooooooool000kooooo00?oo`00ooooooooool0
1?ooool2ool000;ooooo0_oo0007ooooo`;oo`002oooool00ol0003oooooooooo`0=ooooo`005?oo
ool5o`0000Kooooo0ol00009ooooo`03ool00?ooooooo`0000Oooooo0_oo0002ooooo`;oo`001_oo
ool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03ooo
ool00ooo003oooooooooo`04ooooo`;oo`000_ooool2ool000Oooooo0_oo0002ooooo`;oo`001_oo
ool00ooo003oooooool00002ooooo`;oo`001_ooool00ooo003oooooooooo`0>ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`04ooooo`;oo`000_oo
ool2ool000Oooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo0_oo0006ooooo`03ool00?oo
oooooooo00kooooo00Goo`00ooooooooooooooooo`000002ooooo`03ool00?oooooooooo00oooooo
00?oo`00ooooooooool01?ooool2ool000;ooooo0_oo0007ooooo`;oo`0000Coooooool00?oooooo
o`001oooool2ool00004oooooooo003oooooool000Kooooo00?oo`00ooooooooool03_ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool01?ooool2ool0
00;ooooo0_oo0007ooooo`;oo`000_ooool2ool000Kooooo00Ooo`00oooooooo003oooooool00?oo
ooooo`0000Kooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00oooooo00?oo`00ooooooooool01?ooool2ool000;ooooo0_oo0007ooooo`;oo`002_oo
ool2o`0000oooooo000Oooooo`03o`000?oooooooooo00Wooooo00?oo`00oooooooo00001oooool2
ool000;ooooo0_oo0005ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0?ooooo`03ool00?oooooooooo00Cooooo0_oo00001?ooooooo`00oooooooo
0007ooooo`;oo`0000Coooooool00?ooooooo`001_ooool00ooo003oooooool00002ooooo`;oo`00
1_ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
3oooool00ooo003oooooooooo`04ooooo`;oo`000_ooool2ool000Oooooo0_oo0002ooooo`;oo`00
1oooool2ool000;ooooo0_oo0006ooooo`03ool00?oooooooooo00kooooo00Goo`00oooooooooooo
ooooo`000002ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool01?ooool2ool000;o
oooo0_oo0007ooooo`;oo`0000Coooooool00?ooooooo`001oooool2ool00004oooooooo003ooooo
ool000Kooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00oooooo00?oo`00ooooooooool01?ooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool2
ool000Kooooo00Ooo`00oooooooo003oooooool00?ooooooo`0000Kooooo00?oo`00ooooooooool0
3_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0
1?ooool2ool000;ooooo0_oo0007ooooo`;oo`002oooool00ol0003oooooooooo`0=ooooo`007ooo
ool00ol0003oooooooooo`09ooooo`03ool00?ooooooo`0000Oooooo0_oo00001?ooooooo`00oooo
oooo0005ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0?ooooo`03ool00?oooooooooo00Cooooo0_oo00001?ooooooo`00oooooooo0007ooooo`;o
o`0000Coooooool00?ooooooo`001_ooool00ooo003oooooool00002ooooo`;oo`001Oooool00ooo
003oooooooooo`0@ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03oooool00ooo
003oooooooooo`04ooooo`;oo`000_ooool2ool000Oooooo0_oo0002ooooo`;oo`001oooool2ool0
00;ooooo0_oo0005ooooo`03ool00?oooooooooo00oooooo00Goo`00ooooooooooooooooo`000002
ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool01?ooool2ool000;ooooo0_oo0007
ooooo`;oo`0000Coooooool00?ooooooo`001oooool2ool00004oooooooo003oooooool000Kooooo
00?oo`00ooooooooool03_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00oooooo
00?oo`00ooooooooool01?ooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool2ool000Kooooo
00Ooo`00oooooooo003oooooool00?ooooooo`0000Gooooo00?oo`00ooooooooool03oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool01?ooool2ool0
00;ooooo0_oo0007ooooo`;oo`002oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003o
ooooooooo`09ooooo`03ool00?ooooooo`0000Oooooo0_oo00001?ooooooo`00oooooooo0005oooo
o`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0?oooo
o`03ool00?oooooooooo00Cooooo0_oo00001?ooooooo`00oooooooo0007ooooo`;oo`0000Cooooo
ool00?ooooooo`001_ooool00ooo003oooooool00002ooooo`;oo`001Oooool00ooo003ooooooooo
o`0@ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03oooool00ooo003ooooooooo
o`04ooooo`;oo`000_ooool2ool000Oooooo0_oo0002ooooo`;oo`001oooool2ool000;ooooo0_oo
0005ooooo`03ool00?oooooooooo00oooooo00Goo`00ooooooooooooooooo`000002ooooo`03ool0
0?oooooooooo00oooooo00?oo`00ooooooooool01?ooool2ool000;ooooo0_oo0007ooooo`;oo`00
00Coooooool00?ooooooo`001oooool2ool00004oooooooo003oooooool000Gooooo00?oo`00oooo
ooooool03oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00oooooo00?oo`00oooo
ooooool01?ooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool2ool000Kooooo00Ooo`00oooo
oooo003oooooool00?ooooooo`0000Gooooo00?oo`00ooooooooool03oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool01?ooool2ool000;ooooo0_oo
0007ooooo`;oo`002oooool00ol0003oooooooooo`0=ooooo`007oooool3o`0000Wooooo00?oo`00
oooooooo00001oooool2ool00004oooooooo003oooooool000Gooooo00?oo`00ooooooooool04?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool01?oo
ool2ool00004oooooooo003oooooool000Oooooo0_oo00001?ooooooo`00oooooooo0006ooooo`07
ool00?ooooooo`00oooooooo003oooooool00005ooooo`03ool00?oooooooooo013ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo00Cooooo0_oo0002
ooooo`;oo`001oooool2ool000;ooooo0_oo0006ooooo`07ool00?ooooooo`00oooooooo003ooooo
ool00005ooooo`03ool00?oooooooooo00oooooo00Goo`00ooooooooooooooooo`000002ooooo`03
ool00?oooooooooo00oooooo00?oo`00ooooooooool01?ooool2ool000;ooooo0_oo0007ooooo`;o
o`0000Coooooool00?ooooooo`001oooool2ool00004oooooooo003oooooool000Gooooo00?oo`00
ooooooooool03oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00oooooo00?oo`00
ooooooooool01?ooool2ool000;ooooo0_oo0007ooooo`;oo`000_ooool2ool000Kooooo00Ooo`00
oooooooo003oooooool00?ooooooo`0000Gooooo00?oo`00ooooooooool03oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool01?ooool2ool000;ooooo
0_oo0007ooooo`;oo`002_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00Wooooo00?o
o`00oooooooo00001oooool2ool00004oooooooo003oooooool000Gooooo00?oo`00ooooooooool0
4?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool0
1?ooool2ool00004oooooooo003oooooool000Oooooo0_oo00001?ooooooo`00oooooooo0006oooo
o`07ool00?ooooooo`00oooooooo003oooooool00005ooooo`03ool00?oooooooooo013ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo00Cooooo0_oo
0002ooooo`;oo`001oooool2ool000;ooooo0_oo0006ooooo`07ool00?ooooooo`00oooooooo003o
ooooool00005ooooo`03ool00?oooooooooo013ooooo00Coo`00oooooooooooo00000_ooool00ooo
003oooooooooo`0?ooooo`03ool00?oooooooooo00Cooooo0_oo0002ooooo`;oo`001oooool2ool0
0004oooooooo003oooooool000Oooooo0_oo00001?ooooooo`00oooooooo0005ooooo`03ool00?oo
oooooooo00oooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0?ooooo`03ool00?oo
oooooooo00Cooooo0_oo0002ooooo`;oo`001oooool2ool00004oooooooo003oooooool000Kooooo
00Ooo`00oooooooo003oooooool00?ooooooo`0000Gooooo00?oo`00ooooooooool03oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool01?ooool2ool0
00;ooooo0_oo0007ooooo`;oo`002oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003o
ooooooooo`09ooooo`03ool00?ooooooo`0000Oooooo0_oo00001?ooooooo`00oooooooo0005oooo
o`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0?oooo
o`03ool00?oooooooooo00Cooooo0_oo00001?ooooooo`00oooooooo0007ooooo`;oo`0000Cooooo
ool00?ooooooo`001_ooool01ooo003oooooool00?ooooooo`00oooooooo00001Oooool00ooo003o
ooooooooo`0@ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ooo003o
ooooooooo`03ooooo`;oo`0000Coooooool00?ooooooo`001oooool2ool00004oooooooo003ooooo
ool000Kooooo00Ooo`00oooooooo003oooooool00?ooooooo`0000Gooooo00?oo`00ooooooooool0
4?ooool01?oo003oooooooooool00002ooooo`03ool00?oooooooooo00oooooo00?oo`00oooooooo
ool01?ooool2ool00004oooooooo003oooooool000Oooooo0_oo00001?ooooooo`00oooooooo0007
ooooo`;oo`0000Coooooool00?ooooooo`001Oooool00ooo003oooooooooo`0@ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
ooooo`0000;ooooo0_oo0007ooooo`;oo`0000Coooooool00?ooooooo`001_ooool01ooo003ooooo
ool00?ooooooo`00oooooooo00001Oooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`04ooooo`04ool00?ooooooo`00
ooooo`;oo`001oooool2ool000_ooooo00?o0000ooooooooool03Oooool001oooooo0ol00009oooo
o`03ool00?ooooooo`0000Oooooo0_oo00001?ooooooo`00oooooooo0005ooooo`03ool00?oooooo
oooo013ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0?ooooo`03ool00?oooooo
oooo00Cooooo0_oo00001Oooooooo`00ooooooooooooo`0000Kooooo0_oo00001?ooooooo`00oooo
oooo0006ooooo`07ool00?ooooooo`00oooooooo003oooooool00005ooooo`03ool00?oooooooooo
013ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo
00?ooooo0_oo00001?ooooooo`00oooooooo0007ooooo`;oo`0000Coooooool00?ooooooo`001_oo
ool01ooo003oooooool00?ooooooo`00oooooooo00001Oooool00ooo003oooooooooo`0@ooooo`04
ool00?ooooooooooo`0000;ooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`04oooo
o`;oo`0000Coooooool00?ooooooo`001oooool2ool00004oooooooo003oooooool000Oooooo0_oo
00001?ooooooo`00oooooooo0005ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo0000
0_ooool2ool000Oooooo0_oo00001?ooooooo`00oooooooo0006ooooo`07ool00?ooooooo`00oooo
oooo003oooooool00005ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0?ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooooooo003ooooo0_oo
0007ooooo`;oo`002_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00Wooooo00?oo`00
oooooooo00001_ooool01ooo003oooooool00?ooooooo`00oooooooo00001Oooool00ooo003ooooo
ooooo`0@ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03oooool00ooo003ooooo
ooooo`04ooooo`;oo`0000Goooooool00?ooooooooooool00006ooooo`;oo`0000Coooooool00?oo
ooooo`001_ooool01ooo003oooooool00?ooooooo`00oooooooo00001Oooool00ooo003ooooooooo
o`0@ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ooo003ooooooooo
o`03ooooo`;oo`0000Coooooool00?ooooooo`001oooool2ool00004oooooooo003oooooool000Ko
oooo00Ooo`00oooooooo003oooooool00?ooooooo`0000Gooooo00?oo`00ooooooooool04?ooool0
1?oo003oooooooooool00002ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool01?oo
ool01_oo003oooooool00?oo003oooooool000Oooooo0_oo00001?ooooooo`00oooooooo0007oooo
o`;oo`0000Coooooool00?ooooooo`001Oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`02ooooo`07ool00?oooooo
o`00oooooooo003oooooool00007ooooo`;oo`0000Coooooool00?ooooooo`001_ooool01ooo003o
ooooool00?ooooooo`00oooooooo00001Oooool00ooo003oooooooooo`0?ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`04ooooo`04ool00?oooooo
o`00ooooo`;oo`001oooool2ool000_ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000
ooooooooool02Oooool00ooo003oooooool00006ooooo`07ool00?ooooooo`00oooooooo003ooooo
ool00005ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0?ooooo`03ool00?oooooooooo00Cooooo0_oo00001Oooooooo`00ooooooooooooo`0000Ko
oooo00Koo`00oooooooo003oo`00oooooooo0006ooooo`07ool00?ooooooo`00oooooooo003ooooo
ool00005ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0@ooooo`03ool00?oooooooooo00;ooooo00Ooo`00oooooooo003oooooool00?ooooooo`00
00Oooooo0_oo00001?ooooooo`00oooooooo0006ooooo`07ool00?ooooooo`00oooooooo003ooooo
ool00005ooooo`03ool00?oooooooooo013ooooo00Coo`00oooooooooooo00000_ooool00ooo003o
ooooooooo`0?ooooo`03ool00?oooooooooo00Cooooo00Koo`00oooooooo003oo`00oooooooo0007
ooooo`;oo`0000Coooooool00?ooooooo`001oooool2ool00004oooooooo003oooooool000Gooooo
00?oo`00ooooooooool04?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ool00003oooooooo003ooooo00Kooooo
0_oo00001?ooooooo`00oooooooo0006ooooo`07ool00?ooooooo`00oooooooo003oooooool00005
ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0?
ooooo`03ool00?oooooooooo00Cooooo00Koo`00oooooooo003oo`00oooooooo0007ooooo`03ool0
0?ooooooo`0000[ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool02Ooo
ool00ooo003oooooool00006ooooo`07ool00?ooooooo`00oooooooo003oooooool00005ooooo`03
ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0?ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo00Co
oooo00Koo`00oooooooo003oo`00oooooooo0006ooooo`07ool00?ooooooo`00oooooooo003ooooo
ool00005ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0@ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo00000oooooooo`00
ooooo`06ooooo`06ool00?ooooooo`00ool00?ooooooo`001_ooool01ooo003oooooool00?oooooo
o`00oooooooo00001Oooool00ooo003oooooooooo`0@ooooo`04ool00?ooooooooooo`0000;ooooo
00?oo`00ooooooooool03oooool00ooo003oooooooooo`04ooooo`06ool00?ooooooo`00ool00?oo
ooooo`001oooool01_oo003oooooool00?oo003oooooool000Oooooo0_oo00001?ooooooo`00oooo
oooo0005ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0@ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo00000oooooooo`00
ooooo`06ooooo`06ool00?ooooooo`00ool00?ooooooo`001_ooool01ooo003oooooool00?oooooo
o`00oooooooo00001Oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool03oooool00ooo003oooooooooo`04ooooo`06ool00?ooooooo`00ool00?oooooo
o`001oooool00ooo003oooooool0000:ooooo`03o`000?oooooooooo00gooooo000Oooooo`?o0000
2Oooool00ooo003oooooool00006ooooo`07ool00?ooooooo`00oooooooo003oooooool00005oooo
o`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0@oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo0002ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00_oo00000oooooooo`00ooooo`05ooooo`07ool00?ooooooo`00
oooooooo003oooooool00005ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
00000oooooooo`00ooooo`06ooooo`06ool00?ooooooo`00ool00?ooooooo`001_ooool01ooo003o
ooooool00?ooooooo`00oooooooo00001Oooool00ooo003oooooooooo`0@ooooo`04ool00?oooooo
ooooo`0000;ooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`04ooooo`06ool00?oo
ooooo`00ool00?ooooooo`001oooool01_oo003oooooool00?oo003oooooool000Oooooo0_oo0000
1?ooooooo`00oooooooo0005ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
00000oooooooo`00ooooo`06ooooo`06ool00?ooooooo`00ool00?ooooooo`001_ooool01ooo003o
ooooool00?ooooooo`00oooooooo00001Oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00;oo`0000?oooooool00?ooool01_ooool00ooo003oooooool00009ooooo`;o00003oooool0
01oooooo00?o0000ooooooooool02?ooool01?oo003ooooooooooooo0006ooooo`07ool00?oooooo
o`00oooooooo003oooooool00005ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo00000oooooooo`00
ooooo`05ooooo`07ool00?ooooooo`00oooooooo003oooooool00005ooooo`03ool00?oooooooooo
013ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_oo00000oooooooo`00ooooo`06ooooo`06ool00?ooooooo`00
ool00?ooooooo`001_ooool01ooo003oooooool00?ooooooo`00oooooooo00001Oooool00ooo003o
ooooooooo`0@ooooo`04ool00?ooooooooooo`0000;ooooo00?oo`00ooooooooool04?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;oo`0000?oooooool00?ooool01_ooool01_oo
003oooooool00?oo003oooooool000Oooooo0_oo00001?ooooooo`00oooooooo0005ooooo`03ool0
0?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0@ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_oo00000oooooooo`00ooooo`06ooooo`06ool0
0?ooooooo`00ool00?ooooooo`001_ooool01ooo003oooooool00?ooooooo`00oooooooo00001Ooo
ool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;oo`0000?oooooool00?ooool01_oo
ool00ooo003oooooool0000:ooooo`03o`000?oooooooooo00gooooo000?ooooo`?o00001?ooool2
o`0000Oooooo00?o0000ooooooooool02?ooool01?oo003ooooooooooooo0006ooooo`07ool00?oo
ooooo`00oooooooo003oooooool00005ooooo`03ool00?oooooooooo013ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo00000ooooooo
o`00ooooo`05ooooo`04ool00?ooooooo`00ool000;ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0@ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;oo`0000?oooooool00?ooool01_ooool01_oo
003oooooool00?oo003oooooool000Kooooo00Ooo`00oooooooo003oooooool00?ooooooo`0000Go
oooo00?oo`00ooooooooool04?ooool01?oo003oooooooooool00002ooooo`03ool00?oooooooooo
013ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ool00003oooooooo003ooooo
00Kooooo00Koo`00oooooooo003oo`00oooooooo0007ooooo`;oo`0000Coooooool00?ooooooo`00
1Oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
4?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;oo`0000?oooooool00?ooool0
1_ooool01_oo003oooooool00?oo003oooooool000Kooooo00?oo`00ooooooooool00_oo00000ooo
ooooo`00ooooo`04ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0?ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo00000ooo
ooooo`00ooooo`06ooooo`03ool00?ooooooo`0000[ooooo00?o0000ooooooooool03Oooool0013o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo
00Sooooo00Coo`00ooooooooooooo`001_ooool01ooo003oooooool00?ooooooo`00oooooooo0000
1Oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
4Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;oo`000_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;oo`0000?oooooool00?ooool01Oooool01?oo003ooooo
ool00?oo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ool00003oooooooo003ooooo00Kooooo00Koo`00oooooooo003oo`00oooooooo0006
ooooo`07ool00?ooooooo`00oooooooo003oooooool00005ooooo`03ool00?oooooooooo013ooooo
00Coo`00oooooooooooo00000_ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_oo00000oooooooo`00ooooo`06ooooo`06ool00?ooooooo`00ool0
0?ooooooo`001oooool2ool00004oooooooo003oooooool000Gooooo00?oo`00ooooooooool04?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ool00003oooooooo003ooooo00Kooooo00Koo`00oooooooo003oo`00
oooooooo0006ooooo`03ool00?oooooooooo00;oo`0000?oooooool00?ooool01?ooool00ooo003o
ooooooooo`0@ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03oooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00;oo`0000?oooooool00?ooool01_ooool00ooo003o
ooooool0000:ooooo`03o`000?oooooooooo00gooooo000@ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001_ooool4o`0000Oooooo00Coo`00ooooooooooooo`001_ooool00ooo
003oooooooooo`02ool00003oooooooo003ooooo00?ooooo00?oo`00ooooooooool04Oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ool000;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ool0
0003oooooooo003ooooo00Gooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0A
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo00000oooooooo`00ooooo`06
ooooo`06ool00?ooooooo`00ool00?ooooooo`001_ooool01ooo003oooooool00?ooooooo`00oooo
oooo00001Oooool00ooo003oooooooooo`0@ooooo`04ool00?ooooooooooo`0000;ooooo00?oo`00
ooooooooool04?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;oo`0000?ooooo
ool00?ooool01_ooool01_oo003oooooool00?oo003oooooool000Oooooo00Koo`00oooooooo003o
o`00oooooooo0005ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0@ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo00000ooo
ooooo`00ooooo`06ooooo`06ool00?ooooooo`00ool00?ooooooo`001_ooool00ooo003ooooooooo
o`02ool00003oooooooo003ooooo00Cooooo00?oo`00ooooooooool04?ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`02ool00003oooooooo003ooooo00Kooooo00?oo`00oooooooo00001oooool4o`0000oooooo000@
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooooooo
o`08ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0Aooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo0002ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo00000oooooooo`00ooooo`05ooooo`04
ool00?ooooooooooool000?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0@oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;oo`0000?oooooool00?ooool01_ooool01_oo003oooooool00?oo003o
ooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo013ooooo00Coo`00oooooooooooo00000_ooool00ooo003oooooooooo`0@ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo00000oooooooo`00ooooo`06ooooo`06
ool00?ooooooo`00ool00?ooooooo`001oooool00ooo003oooooool00002ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo013ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ool00003oooooooo003o
oooo00Kooooo00Koo`00oooooooo003oo`00oooooooo0006ooooo`03ool00?oooooooooo00;oo`00
00?oooooool00?ooool01?ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool04?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;oo`00
00?oooooool00?ooool01_ooool00ooo003oooooool0000:ooooo`03o`000?oooooooooo00gooooo
000@ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`08ooooo`04ool00?ooooooooooool000Kooooo00Coo`00ooooooooooooo`000_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`0Aooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo0002oooo
o`03ool00?oooooooooo00?ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`04
ooooo`04ool00?ooooooooooool000?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0@ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;oo`0000?oooooool00?ooool01_ooool00ooo003oooooool0
0002ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo013ooooo00Coo`00oooooooooooo00000_ooool00ooo003o
ooooooooo`0@ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo00000ooooooo
o`00ooooo`06ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooool00002ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ool00003oooooooo003ooooo00Kooooo00?oo`00oooooooo00000_ooool00ooo003o
ooooooooo`04ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0@ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;oo`0000?oooooool00?ooool01_ooool00ooo
003oooooool0000:ooooo`03o`000?oooooooooo00gooooo000?ooooo`;o00001?ooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool01?ooool01?oo
003ooooooooooooo0002ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ool000;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`000oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0Aooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo00000oooooooo`00oooo
o`05ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool01?oo003ooooooooo
oooo0002ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool01_oo003ooooo
ooooool0003oooooool001?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ool0
0003oooooooo003ooooo00Kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05oooo
o`03ool00?ooooooo`0000?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0@oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;oo`0000?oooooool00?ooool01_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0@
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo00000oooooooo`00ooooo`06
ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool03Oooool0013ooooo00?o0000oooo
ooooool00oooool2o`0000Oooooo0ol0000;ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01;ooooo00Goo`00oooo
ooooooooooooool0000Cooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04?ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0@ooooo`06ool00?ooooooooooo`000?ooooooo`004oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0@ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02Oooool2o`0000oooooo
000Oooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04_ooool01Ooo003ooooooooo
ooooooooo`0001?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0@ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo017ooooo00Goo`00ooooool0003oooooool0000Cooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04_ooool01Ooo003ooooo
ooooooooooooo`0001?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool0000Cooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
017ooooo00Goo`00ooooool0003oooooool0000Cooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool04?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool04Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo000Ooooo
o`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04_ooool01Ooo003ooooooooooooooooo
o`0001?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00Goo`00ooooooooooooooooool0000Cooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool04Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo017ooooo00Go
o`00ooooool0003oooooool0000Cooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
4?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
4Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo000Oooooo`?o00002ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0Booooo`05ool00?oooooooooooooooooo00004oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool01Ooo003ooooo
ooooooooooooo`0001?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool04Oooool01Ooo003oooooo`000?ooooooo`00
01?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
017ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00[ooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01;o
oooo00Goo`00ooooooooooooooooool0000Cooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00004oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`0Aooooo`05ool00?oooooo0000oooooooo00004oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0Aooooo`05ool00?oooooooooooooooooo00001oooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`05ool0
0?oooooooooooooooooo00004oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003ooooo
ooooo`0;ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo01;ooooo00Goo`00ooooooooooooooooool0000Cooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`05
ool00?oooooooooooooooooo00004oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
017ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`05ool00?oooooo0000
oooooooo00004oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo013ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0Aooooo`05ool00?oooooooooooooooooo00001ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00004oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02oooool00ol0003ooooo
ooooo`0=ooooo`007oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01;ooooo00Go
o`00ooooooooooooooooool0000Cooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00004oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0Aooooo`05ool00?oooooo0000oooooooo00004oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool01Ooo003ooooooooooooooooo
o`0001Cooooo00Goo`00ooooooooooooooooool0000Cooooo`05ool00?oooooooooooooooooo0000
1oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00004oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02oooool00ol0003o
ooooooooo`0=ooooo`007oooool3o`0000_ooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool04_ooool01Ooo003ooooo
ooooooooooooo`0001?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool0000Cooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0001Cooooo00Goo`00
ooooool0003oooooool0000Cooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00005?ooool01Ooo003ooooo
ooooooooooooo`0001?ooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Cooooo00Goo`00ooooooooooooooooool0000Cooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool04Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`0:ooooo`;o00003oooool001oooooo00?o0000oooo
ooooool02oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0Booooo`05ool00?oooooooooooooooooo00005?ooool0
1Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool01Ooo003ooooooooo
ooooooooo`0001Cooooo00Goo`00ooooooooooooooooool0000Cooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooo
oooo00005?ooool01Ooo003oooooo`000?ooooooo`0001?ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool0
000Dooooo`05ool00?oooooooooooooooooo00004oooool01Ooo003oooooooooooooooooo`0000Oo
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0001?ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00_ooooo00?o0000oooo
ooooool03Oooool001oooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool0000Dooooo`05ool00?oooooooooo
oooooooo00005?ooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool01Ooo003oooooooooooooooooo`0001Cooooo00Coo`00ooooooooooooo`005Oooool01Ooo003o
ooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool01Ooo003ooooooooooooooooo
o`0001Cooooo00Goo`00ooooool0003oooooool0000Dooooo`05ool00?oooooooooooooooooo0000
1_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00005?ooool01Ooo003o
ooooooooooooooooo`0001?ooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00Goo`00ooooooooooooooooool0000Cooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool04Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000O
ooooo`?o00002oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Goo`00
ooooooooooooooooool0000Dooooo`05ool00?oooooooooooooooooo00005?ooool01Ooo003ooooo
ooooooooooooo`0000Kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`00
01Cooooo00Coo`00ooooooooooooo`005Oooool01Ooo003oooooooooooooooooo`0000Kooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0001Cooooo00Goo`00ooooool0003o
ooooool0000Dooooo`05ool00?oooooooooooooooooo00001_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04oooo
o`05ool00?oooooooooooooooooo00005?ooool01Ooo003oooooooooooooooooo`0001?ooooo00Go
o`00ooooooooooooooooool00007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Goo`00oooooooooooo
ooooool0000Dooooo`05ool00?oooooooooooooooooo00004oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0:oooo
o`;o00003oooool001oooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool0000Dooooo`05ool00?oooooooooo
oooooooo00005?ooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool01Ooo003oooooooooooooooooo`0001Cooooo00Coo`00ooooooooooooo`005Oooool01Ooo003o
ooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool01Ooo003ooooooooooooooooo
o`0001Cooooo00Goo`00ooooool0003oooooool0000Dooooo`05ool00?oooooooooooooooooo0000
1_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00005?ooool01Ooo003o
ooooooooooooooooo`0001?ooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00Cooooo00Goo`00ooooooooooooooooool0000Dooooo`05ool00?oooooooooooooooooo0000
4oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000?ooooo`?o00000ooo
ool3o`0000Oooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Cooooo00Goo`00ooooooooooooooooool0000Dooooo`04ool00?ooooooooooool001Go
oooo00Goo`00ooooooooooooooooool00006ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00Goo`00oooo
ooooooooooooool0000Dooooo`04ool00?ooooooooooool001Gooooo00Goo`00oooooooooooooooo
ool00006ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool0000Dooooo`05
ool00?oooooo0000oooooooo00005?ooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool01Ooo003oooooooooooooooooo`0001Cooooo00Goo`00oooooooooooooooo
ool0000Cooooo`05ool00?oooooooooooooooooo00001oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`05
ool00?oooooooooooooooooo00005?ooool01Ooo003oooooooooooooooooo`0001?ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool02oooool00ol0003oooooooooo`0=ooooo`004?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0001Cooooo00Co
o`00ooooooooooooo`005Oooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool01?ooool01Ooo003oooooooooooooooooo`0001Cooooo00Coo`00ooooooooooooo`005Oooool0
1Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool01Ooo003ooooooooo
ooooooooo`0001Cooooo00Goo`00ooooool0003oooooool0000Dooooo`05ool00?oooooooooooooo
oooo00001_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00005?ooool0
1Ooo003oooooooooooooooooo`0001?ooooo00Goo`00ooooooooooooooooool00007ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00Goo`00ooooooooooooooooool0000Dooooo`05ool00?oooooooooooooo
oooo00005?ooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000@ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool4o`0000[ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00005?ooool01?oo003ooooooooooooo
000Eooooo`05ool00?oooooooooooooooooo00001_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`05ool0
0?oooooooooooooooooo00005?ooool01?oo003ooooooooooooo000Eooooo`05ool00?oooooooooo
oooooooo00001_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00005?oo
ool01Ooo003oooooo`000?ooooooo`0001Cooooo00Goo`00ooooooooooooooooool00006ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool0000Dooooo`05ool00?oooooooooo
oooooooo00005?ooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Go
o`00ooooooooooooooooool0000Dooooo`05ool00?oooooooooooooooooo00005?ooool01Ooo003o
ooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`08oooo
o`Co00003oooool0013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00_ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`05
ool00?oooooooooooooooooo00005?ooool01?oo003ooooooooooooo000Eooooo`05ool00?oooooo
oooooooooooo00001_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo0000
5?ooool01?oo003ooooooooooooo000Eooooo`05ool00?oooooooooooooooooo00001_ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00005?ooool01Ooo003oooooo`000?oo
ooooo`0001Cooooo00Goo`00ooooooooooooooooool00006ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo
00Goo`00ooooooooooooooooool0000Dooooo`05ool00?oooooooooooooooooo00005?ooool01?oo
003ooooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool0
000Dooooo`05ool00?oooooooooooooooooo00005?ooool01Ooo003oooooooooooooooooo`0000Ko
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00go
oooo000@ooooo`04o`000?ooooooooooooooo`Co00001oooool00ol0003oooooooooo`0;ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`00
01Cooooo00Coo`00ooooooooooooo`005Oooool01Ooo003oooooooooooooooooo`0000Kooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0001Cooooo00Coo`00oooooooooooo
o`005Oooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool01Ooo
003oooooooooooooooooo`0001Cooooo00Goo`00ooooool0003oooooool0000Dooooo`05ool00?oo
oooooooooooooooo00001_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo
00005?ooool01Ooo003oooooooooooooooooo`0001Cooooo00Coo`00ooooooooooooo`001oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00005?ooool01Ooo003ooooooooo
ooooooooo`0001Cooooo00Goo`00ooooooooooooooooool00006ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0=ooooo`003oooool2o`0000?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0001Cooooo00Coo`00oooooooo
ooooo`005Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00Coo`00
ooooooooooooo`005Oooool01?oo003ooooooooooooo000Eooooo`05ool00?oooooooooooooooooo
00001_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00005?ooool01?oo
003oooooo`000?oo000Eooooo`05ool00?oooooooooooooooooo00001_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`04ooooo`05ool00?oooooooooooooooooo00005?ooool01Ooo003oooooooooooooooooo`0001Co
oooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooo
oooooooo00005?ooool01Ooo003oooooooooooooooooo`0001Cooooo00Goo`00oooooooooooooooo
ool00006ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02oooool00ol0003ooooo
ooooo`0=ooooo`004?ooool01?l0003oooooooooooooool5o`0000Kooooo0ol0000;ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0001Co
oooo00Coo`00ooooooooooooo`005Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Cooooo00Coo`00ooooooooooooo`005Oooool01?oo003ooooooooooooo000Eooooo`04ool0
0?ooooooooooool000Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`00
01Cooooo00Coo`00ooooool0003oo`005Oooool01Ooo003oooooooooooooooooo`0000Kooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0001Cooooo00Goo`00oooooooooooo
ooooool0000Dooooo`04ool00?ooooooooooool000Oooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01?ooool01Ooo
003oooooooooooooooooo`0001Cooooo00Goo`00ooooooooooooooooool0000Dooooo`05ool00?oo
oooooooooooooooo00001_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00[ooooo
0_l0000?ooooo`007oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool01?ooool01?oo003ooooooooooooo000Eooooo`04ool00?ooooooooooool001Go
oooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`04ool00?oooooooooo
ool001Gooooo00Coo`00ooooooooooooo`005Oooool01?oo003ooooooooooooo0007ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00Cooooo00Goo`00ooooooooooooooooool0000Dooooo`04ool00?oooooo0000ool0
01Gooooo00Goo`00ooooooooooooooooool00006ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Goo`00
ooooooooooooooooool0000Dooooo`05ool00?oooooooooooooooooo00005?ooool01?oo003ooooo
oooooooo0007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`005?ooool01Ooo
003oooooooooooooooooo`0001Cooooo00Coo`00ooooooooooooo`001oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool03Oooool001oooooo00?o0000
ooooooooool02oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Coo`00
ooooooooooooo`005Oooool01?oo003ooooooooooooo000Eooooo`04ool00?ooooooooooool000Oo
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool01?ooool01?oo003ooooooooooooo000Eooooo`04ool00?oooooooooo
ool001Gooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`05ool00?oo
oooooooooooooooo00005?ooool01?oo003oooooo`000?oo000Eooooo`05ool00?oooooooooooooo
oooo00001_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00005?ooool0
1Ooo003oooooooooooooooooo`0001Cooooo00Coo`00ooooooooooooo`001oooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`05ooooo`04ool00?ooooooooooool001Cooooo00Coo`00ooooooooooooo`005Oooool01?oo
003ooooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02oooool0
0ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool01?ooool01?oo003ooooooooooooo000Eooooo`04ool00?oooooo
ooooool001Gooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`04ool0
0?ooooooooooool001Gooooo00Coo`00ooooooooooooo`005Oooool01?oo003ooooooooooooo0007
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool0000Dooooo`04ool00?oo
oooo0000ool001Gooooo00Goo`00ooooooooooooooooool00006ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Co
oooo00Goo`00ooooooooooooooooool0000Dooooo`05ool00?oooooooooooooooooo00005?ooool0
1?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`00
5?ooool01?oo003ooooooooooooo000Eooooo`04ool00?ooooooooooool000Oooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000Oooooo`?o
00002oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooooooo
ooooo`005Oooool01?oo003ooooooooooooo000Eooooo`04ool00?ooooooooooool000Oooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01?ooool01?oo003ooooooooooooo000Eooooo`04ool00?ooooooooooool001Go
oooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooo
oooooooo00005?ooool01?oo003oooooo`000?oo000Eooooo`04ool00?ooooooooooool000Oooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0001Cooooo00Coo`00oooooooo
ooooo`005Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Gooooo00?oo`00
oooooooo00005Oooool01?oo003ooooooooooooo000Eooooo`04ool00?ooooooooooool000Oooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0:ooooo`;o00003oooool001oooooo00?o
0000ooooooooool02oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Co
o`00ooooooooooooo`005Oooool01?oo003ooooooooooooo000Eooooo`04ool00?ooooooooooool0
00Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool01?ooool01?oo003ooooooooooooo000Eooooo`04ool00?oooooo
ooooool001Gooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`04ooooo`05ool0
0?oooooooooooooooooo00005?ooool01?oo003oooooo`000?oo000Eooooo`04ool00?oooooooooo
ool000Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0001Cooooo00Co
o`00ooooooooooooo`005Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Go
oooo00?oo`00oooooooo00005Oooool01?oo003ooooooooooooo000Eooooo`04ool00?oooooooooo
ool000Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooo
oooo00gooooo000Oooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`04ool00?ooooooooooool001Gooooo00Coo`00ooooooooooooo`005Ooo
ool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooooooooooo
o`005Oooool01?oo003ooooooooooooo000Eooooo`04ool00?ooooooooooool000Oooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01?ooool01Ooo003oooooooooooooooooo`0001Cooooo00Coo`00ooooool0003oo`00
5Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
00005Oooool01?oo003ooooooooooooo000Eooooo`04ool00?ooooooooooool000Oooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool01Oooool00ooo003oooooool0000Fooooo`03ool00?ooooooo`0001Kooooo00?oo`00
oooooooo00001oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00_ooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`005Oooool01?oo003ooooooooooooo
000Eooooo`04ool00?ooooooooooool000Oooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool01?oo003ooooo
oooooooo000Fooooo`03ool00?ooooooo`0001Gooooo00Coo`00ooooooooooooo`001oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`04ooooo`04ool00?ooooooooooool001Gooooo00Coo`00ooooool0003oo`005Ooo
ool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo0000
5Oooool01?oo003ooooooooooooo000Eooooo`04ool00?ooooooooooool000Oooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooool0000Fooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooo
oooo00001oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00_ooooo00?o0000oooo
ooooool03Oooool001oooooo0ol0000;ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool01Oooool01?oo003ooooooooooooo000Fooooo`03ool00?ooooooo`0001Gooooo00Coo`00oooo
ooooooooo`001oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`05ooooo`03ool00?ooooooo`0001Kooooo00?oo`00
oooooooo00005Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Cooooo00Co
o`00ooooooooooooo`005_ooool00ooo003o0000ool0000Eooooo`04ool00?ooooooooooool000Oo
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool01Oooool00ooo003oooooool0000Fooooo`03ool00?ooooooo`0001Go
oooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`05ooooo`03ool00?ooooooo`00
01Kooooo00?oo`00oooooooo00005_ooool00ooo003oooooool00007ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool02_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00_o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`06ooooo`03ool00?ooooooo`0001Ko
oooo00?oo`00oooooooo00005Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00Kooooo00?oo`00oooooooo00005_ooool00ooo003oooooool0000Eooooo`04ool00?oooooooooo
ool000Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooool0000Fooooo`03ool00?l0003o
o`0001Kooooo00?oo`00oooooooo00001oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
o`0001Kooooo00?oo`00oooooooo00005Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00oooooooo00005_ooool00ooo003oooooool0000Fooooo`03ool00?oo
ooooo`0000Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0;ooooo`03o`000?oo
oooooooo00gooooo000Oooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`06ooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00005Oooool0
1?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo00005_oo
ool00ooo003oooooool0000Fooooo`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooool0000Fooooo`03ool00?l0003oo`0001Kooooo00?oo`00oooooooo00001ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`05ooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00005Ooo
ool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo0000
5_ooool00ooo003oooooool0000Fooooo`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000Oooooo`?o00003?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo00005_oo
ool00ooo003oooooool0000Eooooo`04ool00?ooooooooooool000Oooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooool0000Fooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo0000
1oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`05ooooo`03ool00?ooooooo`0001Kooooo00?oo`00o`000?oo0000
5_ooool00ooo003oooooool00007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo0000
5_ooool00ooo003oooooool0000Fooooo`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooool0000Fooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo0000
1oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00[ooooo0_l0000?ooooo`007ooo
ool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooool0000Fooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00001ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`06ooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00005_oo
ool00ooo003oooooool00007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo00005_oo
ool00ooo003o0000ool0000Fooooo`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooool0000Fooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00001ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`05ooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00005_oo
ool00ooo003oooooool00007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02ooo
ool00ol0003oooooooooo`0=ooooo`003_ooool5o`0000?ooooo0_l00007ooooo`03o`000?oooooo
oooo00cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
o`0001Kooooo00?oo`00oooooooo00005_ooool00ooo003oooooool00007ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00oooooooo00005_ooool00ooo003oooooool0000Fooooo`03ool00?oooooo
o`0000Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool01Oooool00ooo003oooooool0000Fooooo`03ool00?l0003o
o`0001Kooooo00?oo`00oooooooo00001oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
o`0001Kooooo00?oo`00oooooooo00005_ooool00ooo003oooooool00007ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00oooooooo00005_ooool00ooo003oooooool0000Fooooo`03ool00?oooooo
o`0000Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooo
oooo00gooooo000?ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooool0000Fooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00001ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`06ooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00005_oo
ool00ooo003oooooool00007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo00005_oo
ool00ooo003o0000ool0000Fooooo`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooool0000Fooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00001ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`05ooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00005_oo
ool00ooo003oooooool00007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool02ooo
ool00ol0003oooooooooo`0=ooooo`004?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Kooooo1?l0000;ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooool0000Fooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00002?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`06ooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00005_oo
ool00ooo003oooooool00007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo00005_oo
ool2ool001Oooooo00?oo`00oooooooo00001oooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`05ooooo`03ool00?oo
ooooo`0001Kooooo00?oo`00oooooooo00005_ooool00ooo003oooooool00007ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00oooooooo00005_ooool00ooo003oooooool0000Fooooo`03ool00?oo
ooooo`0000Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`08ooooo`Co00003ooo
ool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Kooooo00?o
o`00oooooooo00005_ooool2ool001Oooooo00?oo`00oooooooo00002?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`06ooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00005_ooool00ooo003oooooool0
0007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo00005_ooool2ool001Oooooo00?o
o`00oooooooo00001oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`05ooooo`03ool00?ooooooo`0001Kooooo0_oo
000Gooooo`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01_ooool00ooo003oooooool0
000Fooooo`03ool00?ooooooo`0001Kooooo00?oo`00oooooooo00001oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool03Oooool000kooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
3?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Kooooo0_oo000Gooooo`;oo`00
5oooool2ool000Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01_ooool00ooo003oooooool0000Fooooo`;oo`00
5oooool00ooo003oooooool00007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Gooooo0_oo000Gooooo`;oo`00
5oooool2ool000Sooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01_ooool00ooo003oooooool0000Fooooo`;oo`00
5oooool00ooo003oooooool00007ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo0000
5_ooool2ool001Oooooo00?oo`00oooooooo00001oooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00_ooooo00?o0000ooooooooool03Oooool000kooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool03?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00Kooooo0_oo000Gooooo`;oo`005oooool2ool000Wo
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool01_ooool2ool001Oooooo0_oo000Gooooo`;oo`002?ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`05ooooo`;oo`005oooool2ool001Oooooo0_oo0008ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00oooooooo00005_ooool2ool001Oooooo0_oo0008ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Ko
oooo00?oo`00oooooooo00005_ooool2ool001Oooooo0_oo0008ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0=ooooo`003oooool3o`0000Cooooo
0_l00007ooooo`?o00003?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Kooooo
0_oo000Hooooo`03ool00?oooooooooo01Gooooo0_oo0009ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Kooooo
0_oo000Hooooo`03ool00?oooooooooo01Gooooo0_oo0008ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Gooooo
0_oo000Hooooo`03ool00?oooooooooo01Gooooo0_oo0008ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Kooooo
0_oo000Hooooo`03ool00?oooooooooo01Gooooo0_oo0008ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Kooooo
0_oo000Hooooo`03ool00?oooooooooo01Gooooo0_oo0008ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool02_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`06ooooo`;oo`00<?ooool2ool000Wooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool01_ooool2ool0033ooooo0_oo0008ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Kooooo0_oo
000Hooooo`03o`000?oooooooooo01Gooooo0_oo0008ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Kooooo0_oo
000`ooooo`;oo`002?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`06ooooo`;oo`00<?ooool2ool000Sooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000O
ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo02kooooo0_oo0009ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00
ooooooooool0;_ooool2ool000Sooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0F
ooooo`03o`000?oooooooooo01Gooooo0_oo0008ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00
ooooooooool0;oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Oooooo00?oo`00
ooooooooool0;oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool02oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0<oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0@oooool01Ooo003ooooooooooooooooo
o`0000Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`12ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo023ooooo00?o0000ooooooooool07oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`12ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo04;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooo
oooo00gooooo000Oooooo`?o00003?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
04?ooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool0@_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool0@_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`13ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool02_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`13ooooo`05ool00?oooooooooooooooooo00001oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo04;ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool08?ooool0
0ol0003oooooooooo`0Pooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo04;ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0@oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool03Oooool0
01oooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
04?ooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool0@oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool0@_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`13ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool02oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0<oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0@oooool01Ooo003ooooooooooooooooo
o`0000Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`13ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo023ooooo00?o0000ooooooooool08?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`12ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0004Gooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000O
ooooo`?o00003?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04?ooooo00Goo`00
ooooooooooooooooool00007ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0@ooo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0@ooo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00oooooooooooooooo
ool00015ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02_ooool2o`0000oooooo
000Oooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`13ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo04?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo04?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`05ooooo`05ool0
0?oooooooooooooooooo0000AOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00_o
oooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool03?ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo04?ooooo00Goo`00ooooooooooooooooool00007ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool0@oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Pooooo`03
o`000?oooooooooo023ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool0@oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00015ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0=ooooo`007oooool3o`0000co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`13ooooo`05ool00?oooooooooooooo
oooo00001oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04?ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool08?ooool00ol0003oooooooooo`0Pooooo`05ool00?oooooooooooooooooo00001oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo04?ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo0000AOooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00[ooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`0<
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0@oooool01Ooo003ooooooooooooo
ooooo`0000Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`13ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo023ooooo00?o0000ooooooooool08?ooool01Ooo003oooooooooooooooooo`0000Oooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`13ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0004Gooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000>ooooo`Go0000
0_ooool3o`0000Oooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo04?ooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0@oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Pooooo`03o`000?oooooooooo023o
oooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0@oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00oooo
ooooooooooooool00015ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02oooool0
0ol0003oooooooooo`0=ooooo`003oooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool0@oooool01Ooo003oooooooooooooooooo`0000Oooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`13ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo023ooooo00?o0000ooooooooool08?ooool01Ooo003o
ooooooooooooooooo`0000Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`13oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003ooooooooooooooooo
o`0004Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0;ooooo`03o`000?oooooo
oooo00gooooo000@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool4o`00
00_ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`13ooooo`05ool00?oooooooooo
oooooooo00001oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04?ooooo00Goo`00
ooooooooooooooooool00007ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool08?oo
ool00ol0003oooooooooo`0Pooooo`05ool00?oooooooooooooooooo00001oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo04?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`05ooooo`05ool00?oooooooooooooooooo0000AOooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00Sooooo1?l0000?ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo04?ooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0@oooool01Ooo003oooooooooooooooooo`0000Oooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo00Goo`00oooo
ooooooooooooool00007ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0@oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Gooooo00Goo`00ooooooooooooooooool0
0015ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02oooool00ol0003ooooooooo
o`0=ooooo`003_ooool01_l0003ooooooooooooooooo0000ooooo`Co00001oooool00ol0003ooooo
ooooo`0=ooooo`05ool00?oooooooooooooooooo0000AOooool01Ooo003oooooooooooooooooo`00
00Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`13ooooo`05ool00?oooooooooo
oooooooo00001oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo023ooooo00?o0000
ooooooooool08?ooool01Ooo003oooooooooooooooooo`0000Oooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`13ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01Ooo
ool01Ooo003oooooooooooooooooo`0004Gooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00gooooo000>ooooo`07o`000?ooooooooooooooool0003o
ooooo`00000:ooooo`03o`000?oooooooooo00gooooo00Goo`00ooooooooooooooooool00015oooo
o`05ool00?oooooooooooooooooo00001oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo04?ooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`05ool00?oooooooooooooooooo0000
1oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04?ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`05ooooo`05ool00?oooooooooooooooooo0000AOooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool03Oooool000oooooo
0ol00002ooooo`Go00001_ooool3o`0000gooooo00Goo`00ooooooooooooooooool00015ooooo`05
ool00?oooooooooooooooooo00001oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
04?ooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`05ool00?oooooooooooooooooo00002?oo
ool01Ooo003oooooooooooooooooo`0004Gooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`05ooooo`05ool00?oooooooooooooooooo0000AOooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00[ooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`0=ooooo`05ool0
0?oooooooooooooooooo0000AOooool01Ooo003oooooooooooooooooo`0000Oooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`13ooooo`05ool00?oooooooooooooooooo00001oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo023ooooo00?o0000ooooooooool08?ooool0
1Ooo003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00015ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool01Oooool01Ooo003oooooooooooooooooo`0004Go
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00go
oooo000Oooooo`03o`000?oooooooooo00gooooo00Goo`00ooooooooooooooooool00015ooooo`05
ool00?oooooooooooooooooo00001oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
04?ooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`05ool00?oooooooooooooooooo00002?oo
ool01?oo003ooooooooooooo0016ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
1Oooool01Ooo003oooooooooooooooooo`0004Gooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00gooooo
00Goo`00ooooooooooooooooool00015ooooo`05ool00?oooooooooooooooooo00001oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo04?ooooo00Goo`00ooooooooooooooooool00007
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool08?ooool00ol0003oooooooooo`0P
ooooo`05ool00?oooooooooooooooooo00002?ooool01?oo003ooooooooooooo0016ooooo`05ool0
0?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0004Gooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo000Oooooo`?o
00003Oooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo00001oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo04?ooooo00Goo`00ooooooooooooooooool0
0007ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool08?ooool00ol0003ooooooooo
o`0Pooooo`05ool00?oooooooooooooooooo00002?ooool01?oo003ooooooooooooo0016ooooo`05
ool00?oooooooooooooooooo00002?ooool01Ooo003oooooooooooooooooo`0004Gooooo00Goo`00
ooooooooooooooooool0000=ooooo`;o00003oooool001oooooo00?o0000ooooooooool03Oooool0
1?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo00001oooool01Ooo003ooooo
ooooooooooooo`0004Kooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`05ool00?oooooooooo
oooooooo00002?ooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo0000
2?ooool01Ooo003oooooooooooooooooo`0004Gooooo00Goo`00ooooooooooooooooool0000>oooo
o`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo00gooooo00Coo`00oooooooo
ooooo`00A_ooool01Ooo003oooooooooooooooooo`0000Oooooo00Goo`00ooooooooooooooooool0
0016ooooo`05ool00?oooooooooooooooooo00001oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo023ooooo00?o0000ooooooooool08?ooool01Ooo003oooooooooooooooooo`0000So
oooo00Coo`00ooooooooooooo`00A_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Goo`00
ooooooooooooooooool00015ooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003ooooo
ooooo`0=ooooo`007oooool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool004Kooooo
00Goo`00ooooooooooooooooool00007ooooo`05ool00?oooooooooooooooooo0000A_ooool01Ooo
003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool0000Rooooo`03o`000?oo
oooooooo023ooooo00Goo`00ooooooooooooooooool00008ooooo`04ool00?ooooooooooool004Ko
oooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo0000AOooool0
1Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool03Oooool001oooooo0ol0000=
ooooo`04ool00?ooooooooooool004Kooooo00Goo`00ooooooooooooooooool00008ooooo`04ool0
0?ooooooooooool004Kooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooo
oooooooo00008_ooool00ol0003oooooooooo`0Pooooo`05ool00?oooooooooooooooooo00002?oo
ool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003o
ooooooooooooooooo`0004Gooooo00Goo`00ooooooooooooooooool0000=ooooo`;o00003oooool0
01oooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooo
oooooooooooo00002?ooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo
00002?ooool01Ooo003oooooooooooooooooo`0002;ooooo00?o0000ooooooooool08?ooool01Ooo
003oooooooooooooooooo`0000Sooooo00Coo`00ooooooooooooo`00A_ooool01Ooo003ooooooooo
ooooooooo`0000Sooooo00Goo`00ooooooooooooooooool00015ooooo`05ool00?oooooooooooooo
oooo00003_ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0=ooooo`04
ool00?ooooooooooool004Kooooo00Goo`00ooooooooooooooooool00008ooooo`04ool00?oooooo
ooooool004Kooooo00Goo`00ooooooooooooooooool00008ooooo`05ool00?oooooooooooooooooo
00008_ooool00ol0003oooooooooo`0Pooooo`05ool00?oooooooooooooooooo00002?ooool01?oo
003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo00002?ooool01Ooo003ooooooooo
ooooooooo`0004Gooooo00Goo`00ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00go
oooo000Oooooo`?o00003Oooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooo
oooo00002?ooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo00002?oo
ool01Ooo003oooooooooooooooooo`0002;ooooo00?o0000ooooooooool08?ooool01Ooo003ooooo
ooooooooooooo`0000Sooooo00Coo`00ooooooooooooo`00A_ooool01Ooo003ooooooooooooooooo
o`0000Sooooo00Goo`00ooooooooooooooooool00015ooooo`05ool00?oooooooooooooooooo0000
3Oooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00gooooo00Coo`00ooooooooooooo`00
A_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Coo`00ooooooooooooo`00A_ooool01Ooo
003oooooooooooooooooo`0000Sooooo00Goo`00ooooooooooooooooool0000Rooooo`03o`000?oo
oooooooo023ooooo00Goo`00ooooooooooooooooool00008ooooo`04ool00?ooooooooooool004Ko
oooo00Goo`00ooooooooooooooooool00008ooooo`04ool00?ooooooooooool004Kooooo00Goo`00
ooooooooooooooooool0000>ooooo`03o`000?oooooooooo00gooooo000?ooooo`?o00001?ooool2
o`0000Oooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo0016ooooo`05ool00?oo
oooooooooooooooo00002?ooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooo
oooo00002?ooool01Ooo003oooooooooooooooooo`0002;ooooo00?o0000ooooooooool08?ooool0
1?oo003ooooooooooooo0009ooooo`04ool00?ooooooooooool004Kooooo00Goo`00oooooooooooo
ooooool00008ooooo`04ool00?ooooooooooool004Kooooo00Goo`00ooooooooooooooooool0000>
ooooo`03o`000?oooooooooo00gooooo000>ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooooooo00gooooo00Coo`00ooooooooooooo`00
A_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Coo`00ooooooooooooo`00A_ooool01Ooo
003oooooooooooooooooo`0000Sooooo00Coo`00ooooooooooooo`008oooool00ol0003ooooooooo
o`0Pooooo`04ool00?ooooooooooool000Wooooo00Coo`00ooooooooooooo`00A_ooool01Ooo003o
ooooooooooooooooo`0000Sooooo00Coo`00ooooooooooooo`00A_ooool01Ooo003ooooooooooooo
ooooo`0000kooooo00?o0000ooooooooool03Oooool001;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`04ooooo`Co00003?ooool01?oo003ooooooooooooo0016ooooo`05ool0
0?oooooooooooooooooo00002?ooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooo
oooooooo00002?ooool01?oo003ooooooooooooo000Sooooo`03o`000?oooooooooo023ooooo00Co
o`00ooooooooooooo`002Oooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooo
oooo00002?ooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo00002ooo
ool4o`0000oooooo000@ooooo`;o00000oooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo00gooooo00Coo`00ooooooooooooo`00A_ooool01Ooo003oooooooooooooooooo`0000So
oooo00Coo`00ooooooooooooo`00A_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Coo`00
ooooooooooooo`008oooool00ol0003oooooooooo`0Pooooo`04ool00?ooooooooooool000Wooooo
00Coo`00ooooooooooooo`00A_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Coo`00oooo
ooooooooo`00A_ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool03Ooo
ool001;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00gooooo00Coo`00ooooooooooooo`00A_ooool01Ooo003oooooooooooooooooo`0000So
oooo00Coo`00ooooooooooooo`00A_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Coo`00
ooooooooooooo`008oooool00ol0003oooooooooo`0Pooooo`04ool00?ooooooooooool000Wooooo
00Coo`00ooooooooooooo`00A_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Coo`00oooo
ooooooooo`00A_ooool01Ooo003oooooooooooooooooo`0000kooooo00?o0000ooooooooool03Ooo
ool000kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo
00?o0000ooooooooool03Oooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooo
oooo00002?ooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo00002?oo
ool01?oo003ooooooooooooo000Sooooo`03o`000?oooooooooo023ooooo00Coo`00oooooooooooo
o`002Oooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo00002?ooool0
1?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003ooooo
ooooo`0=ooooo`003oooool3o`0000Cooooo0_l00007ooooo`?o00003Oooool01?oo003ooooooooo
oooo0016ooooo`05ool00?oooooooooooooooooo00002?ooool01?oo003ooooooooooooo0016oooo
o`05ool00?oooooooooooooooooo00002?ooool01?oo003ooooooooooooo000Sooooo`03o`000?oo
oooooooo023ooooo00Coo`00ooooooooooooo`002Oooool01?oo003ooooooooooooo0016ooooo`05
ool00?oooooooooooooooooo00002?ooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooo
oooooooooooo00003Oooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00gooooo00Coo`00
ooooooooooooo`00A_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Coo`00oooooooooooo
o`00A_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Coo`00ooooooooooooo`008oooool0
0ol0003oooooooooo`0Pooooo`04ool00?ooooooooooool000Wooooo00Coo`00ooooooooooooo`00
A_ooool01Ooo003oooooooooooooooooo`0000Sooooo00Coo`00ooooooooooooo`00A_ooool01Ooo
003oooooooooooooooooo`0000kooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooo
ooooool03Oooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo00002?oo
ool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo00002?ooool01?oo003o
oooooooooooo000Sooooo`03o`000?oooooooooo023ooooo00Coo`00ooooooooooooo`002Oooool0
1?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooooooo00002?ooool01?oo003ooooo
oooooooo0016ooooo`05ool00?oooooooooooooooooo00003_ooool00ol0003oooooooooo`0=oooo
o`007oooool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool004Kooooo00Goo`00oooo
ooooooooooooool00008ooooo`04ool00?ooooooooooool004Kooooo00Goo`00oooooooooooooooo
ool00008ooooo`04ool00?ooooooooooool002?ooooo00?o0000ooooooooool08?ooool01?oo003o
oooooooooooo0009ooooo`04ool00?ooooooooooool004Kooooo00Goo`00ooooooooooooooooool0
0008ooooo`04ool00?ooooooooooool004Kooooo00Goo`00ooooooooooooooooool0000>ooooo`03
o`000?oooooooooo00gooooo000Oooooo`?o00003Oooool01?oo003ooooooooooooo0016ooooo`05
ool00?oooooooooooooooooo00002?ooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooo
oooooooooooo00002?ooool01?oo003ooooooooooooo000Sooooo`03o`000?oooooooooo023ooooo
00Coo`00ooooooooooooo`002Oooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooo
oooooooo00002?ooool01?oo003ooooooooooooo0017ooooo`04ool00?ooooooooooool000gooooo
0_l0000?ooooo`007oooool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool004Kooooo
00Goo`00ooooooooooooooooool00008ooooo`04ool00?ooooooooooool004Oooooo00Coo`00oooo
ooooooooo`002?ooool01?oo003ooooooooooooo000Sooooo`03o`000?oooooooooo023ooooo00Co
o`00ooooooooooooo`002Oooool01?oo003ooooooooooooo0016ooooo`05ool00?oooooooooooooo
oooo00002?ooool01?oo003ooooooooooooo0017ooooo`04ool00?ooooooooooool000kooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo
0016ooooo`05ool00?oooooooooooooooooo00002?ooool01?oo003ooooooooooooo0017ooooo`04
ool00?ooooooooooool000Sooooo00Coo`00ooooooooooooo`008oooool00ol0003oooooooooo`0Q
ooooo`03ool00?ooooooo`0000Wooooo00Coo`00ooooooooooooo`00Aoooool01?oo003ooooooooo
oooo0008ooooo`04ool00?ooooooooooool004Oooooo00Coo`00ooooooooooooo`003_ooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool0
04Kooooo00Coo`00ooooooooooooo`002Oooool01?oo003ooooooooooooo0017ooooo`03ool00?oo
ooooo`0000Wooooo00Coo`00ooooooooooooo`008oooool00ol0003oooooooooo`0Qooooo`03ool0
0?ooooooo`0000Wooooo00Coo`00ooooooooooooo`00Aoooool01?oo003ooooooooooooo0008oooo
o`04ool00?ooooooooooool004Oooooo00Coo`00ooooooooooooo`003_ooool00ol0003ooooooooo
o`0=ooooo`007oooool3o`0000gooooo00Coo`00ooooooooooooo`00Aoooool00ooo003oooooool0
0009ooooo`04ool00?ooooooooooool004Oooooo00?oo`00oooooooo00002Oooool01?oo003ooooo
oooooooo000Sooooo`03o`000?oooooooooo027ooooo00?oo`00oooooooo00002Oooool01?oo003o
oooooooooooo0017ooooo`04ool00?ooooooooooool000Sooooo00Coo`00ooooooooooooo`00Aooo
ool01?oo003ooooooooooooo000=ooooo`;o00003oooool001oooooo00?o0000ooooooooool03Ooo
ool01?oo003ooooooooooooo0017ooooo`03ool00?ooooooo`0000Wooooo00Coo`00oooooooooooo
o`00Aoooool00ooo003oooooool00009ooooo`04ool00?ooooooooooool002?ooooo00?o0000oooo
ooooool08Oooool00ooo003oooooool00009ooooo`04ool00?ooooooooooool004Oooooo00?oo`00
oooooooo00002Oooool01?oo003ooooooooooooo0017ooooo`03ool00?ooooooo`0000oooooo00?o
0000ooooooooool03Oooool001oooooo00?o0000ooooooooool03Oooool01?oo003ooooooooooooo
0017ooooo`03ool00?ooooooo`0000Wooooo00Coo`00ooooooooooooo`00Aoooool00ooo003ooooo
ool00009ooooo`04ool00?ooooooooooool002?ooooo00?o0000ooooooooool08Oooool00ooo003o
ooooool00009ooooo`04ool00?ooooooooooool004Oooooo00?oo`00oooooooo00002Oooool01?oo
003ooooooooooooo0017ooooo`03ool00?ooooooo`0000oooooo00?o0000ooooooooool03Oooool0
01oooooo0ol0000=ooooo`04ool00?ooooooooooool004Oooooo00?oo`00oooooooo00002Oooool0
1?oo003ooooooooooooo0017ooooo`03ool00?ooooooo`0000Wooooo00Coo`00ooooooooooooo`00
8oooool00ol0003oooooooooo`0Qooooo`03ool00?ooooooo`0000Wooooo00Coo`00oooooooooooo
o`00Aoooool00ooo003oooooool00009ooooo`04ool00?ooooooooooool004Oooooo00?oo`00oooo
oooo00003_ooool2o`0000oooooo000Oooooo`03o`000?oooooooooo00gooooo00Coo`00oooooooo
ooooo`00Aoooool00ooo003oooooool00009ooooo`04ool00?ooooooooooool004Oooooo00?oo`00
oooooooo00002Oooool01?oo003ooooooooooooo000Sooooo`03o`000?oooooooooo027ooooo00?o
o`00oooooooo00002Oooool01?oo003ooooooooooooo0017ooooo`03ool00?ooooooo`0000Wooooo
00Coo`00ooooooooooooo`00Aoooool00ooo003oooooool0000?ooooo`03o`000?oooooooooo00go
oooo000?ooooo`?o00000oooool3o`0000Oooooo00?o0000ooooooooool03Oooool01?oo003ooooo
oooooooo0017ooooo`03ool00?ooooooo`0000Wooooo00Coo`00ooooooooooooo`00Aoooool00ooo
003oooooool00009ooooo`04ool00?ooooooooooool002?ooooo00?o0000ooooooooool08Oooool0
0ooo003oooooool00009ooooo`04ool00?ooooooooooool004Oooooo00?oo`00oooooooo00002Ooo
ool01?oo003ooooooooooooo0017ooooo`03ool00?ooooooo`0000oooooo00?o0000ooooooooool0
3Oooool000kooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0>ooooo`03ool00?ooooooo`0004Oooooo00?oo`00oooooooo
00002Oooool01?oo003ooooooooooooo0017ooooo`03ool00?ooooooo`0000Wooooo00Coo`00oooo
ooooooooo`008oooool00ol0003oooooooooo`0Qooooo`03ool00?ooooooo`0000[ooooo00?oo`00
oooooooo0000Aoooool00ooo003oooooool0000:ooooo`03ool00?ooooooo`0004Oooooo00?oo`00
oooooooo00003oooool00ol0003oooooooooo`0=ooooo`004_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo1?l0000=ooooo`03ool00?ooooooo`0004Oooooo00?oo`00oooo
oooo00002Oooool01?oo003ooooooooooooo0017ooooo`03ool00?ooooooo`0000Wooooo00Coo`00
ooooooooooooo`008oooool00ol0003oooooooooo`0Qooooo`03ool00?ooooooo`0000[ooooo00?o
o`00oooooooo0000Aoooool00ooo003oooooool0000:ooooo`03ool00?ooooooo`0004Oooooo00?o
o`00oooooooo00003?ooool4o`0000oooooo000@ooooo`;o00001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00kooooo00?oo`00oooooooo0000Aoooool00ooo003oooooool00009
ooooo`04ool00?ooooooooooool004Oooooo00?oo`00oooooooo00002Oooool01?oo003ooooooooo
oooo000Sooooo`03o`000?oooooooooo027ooooo00?oo`00oooooooo00002_ooool00ooo003ooooo
ool00017ooooo`03ool00?ooooooo`0000[ooooo00?oo`00oooooooo0000Aoooool00ooo003ooooo
ool0000?ooooo`03o`000?oooooooooo00gooooo000Booooo`03o`000?oooooo000000?o00001ooo
ool00ol0003oooooooooo`0>ooooo`03ool00?ooooooo`0004Oooooo00?oo`00oooooooo00002_oo
ool00ooo003oooooool00017ooooo`03ool00?ooooooo`0000[ooooo00?oo`00oooooooo00008ooo
ool00ol0003oooooooooo`0Qooooo`03ool00?ooooooo`0000[ooooo0_oo0018ooooo`03ool00?oo
ooooo`0000[ooooo00?oo`00oooooooo0000Aoooool00ooo003oooooool0000?ooooo`03o`000?oo
oooooooo00gooooo000>ooooo`07o`000?ooooooooooooooool0003oooooo`00000:ooooo`03o`00
0?oooooooooo00kooooo00?oo`00oooooooo0000Aoooool00ooo003oooooool0000:ooooo`03ool0
0?ooooooo`0004Oooooo00?oo`00oooooooo00002_ooool00ooo003oooooool0000Sooooo`03o`00
0?oooooooooo027ooooo00?oo`00oooooooo00002_ooool2ool004Sooooo00?oo`00oooooooo0000
2_ooool00ooo003oooooool00017ooooo`03ool00?ooooooo`0000oooooo00?o0000ooooooooool0
3Oooool000oooooo0ol00002ooooo`Go00001_ooool3o`0000kooooo00?oo`00oooooooo0000Aooo
ool00ooo003oooooool0000:ooooo`03ool00?ooooooo`0004Oooooo00?oo`00oooooooo00002_oo
ool00ooo003oooooool0000Sooooo`03o`000?oooooooooo027ooooo00?oo`00oooooooo00002_oo
ool2ool004Sooooo00?oo`00oooooooo00002_ooool00ooo003oooooool00017ooooo`03ool00?oo
ooooo`0000kooooo0_l0000?ooooo`007oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooo
o`0004Oooooo00?oo`00oooooooo00002_ooool00ooo003oooooool00017ooooo`03ool00?oooooo
o`0000[ooooo00?oo`00oooooooo00008oooool00ol0003oooooooooo`0Qooooo`03ool00?oooooo
o`0000[ooooo0_oo0018ooooo`03ool00?ooooooo`0000[ooooo0_oo0018ooooo`03ool00?oooooo
o`0000oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool03_ooool2ool0
04Sooooo00?oo`00oooooooo00002_ooool00ooo003oooooool00017ooooo`03ool00?ooooooo`00
00[ooooo00?oo`00oooooooo00008oooool00ol0003oooooooooo`0Qooooo`03ool00?ooooooo`00
00[ooooo0_oo0018ooooo`03ool00?ooooooo`0000[ooooo0_oo0018ooooo`03ool00?ooooooo`00
00oooooo00?o0000ooooooooool03Oooool001oooooo00?o0000ooooooooool03_ooool2ool004So
oooo00?oo`00oooooooo00002_ooool2ool004Sooooo00?oo`00oooooooo00002_ooool2ool002Co
oooo00?o0000ooooooooool08Oooool00ooo003oooooool0000:ooooo`;oo`00B?ooool00ooo003o
ooooool0000:ooooo`;oo`00B?ooool00ooo003oooooool0000?ooooo`03o`000?oooooooooo00go
oooo000Oooooo`?o00003_ooool2ool004Sooooo00?oo`00oooooooo00002_ooool2ool004Sooooo
00?oo`00oooooooo00002_ooool2ool002Cooooo00?o0000ooooooooool08Oooool00ooo003ooooo
ool0000:ooooo`;oo`00B?ooool00ooo003oooooool0000:ooooo`;oo`00B?ooool00ooo003ooooo
ool0000>ooooo`;o00003oooool001oooooo00?o0000ooooooooool03_ooool2ool004Sooooo00?o
o`00oooooooo00002_ooool2ool004Sooooo00?oo`00oooooooo00002_ooool2ool002Cooooo00?o
0000ooooooooool08Oooool00ooo003oooooool0000:ooooo`;oo`00B?ooool00ooo003oooooool0
000:ooooo`;oo`00B?ooool00ooo003oooooool0000?ooooo`03o`000?oooooooooo00gooooo000O
ooooo`03o`000?oooooooooo00kooooo0_oo0018ooooo`03ool00?ooooooo`0000[ooooo0_oo0018
ooooo`03ool00?ooooooo`0000[ooooo0_oo000Tooooo`03o`000?oooooooooo027ooooo00?oo`00
oooooooo00002_ooool2ool004Sooooo00?oo`00oooooooo00002_ooool2ool004Sooooo00?oo`00
oooooooo00003oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0>oooo
o`;oo`00B?ooool2ool000_ooooo0_oo0018ooooo`03ool00?ooooooo`0000[ooooo0_oo000Toooo
o`03o`000?oooooooooo027ooooo0_oo000;ooooo`;oo`00BOooool2ool000[ooooo0_oo0019oooo
o`;oo`003oooool00ol0003oooooooooo`0=ooooo`007oooool3o`0000kooooo0_oo0019ooooo`03
ool00?oooooooooo00Wooooo0_oo0019ooooo`03ool00?oooooooooo00Wooooo0_oo000Tooooo`03
o`000?oooooooooo02;ooooo00?oo`00ooooooooool02Oooool2ool004Wooooo00?oo`00oooooooo
ool02Oooool2ool004Wooooo00?oo`00ooooooooool03Oooool2o`0000oooooo000Oooooo`03o`00
0?oooooooooo00kooooo0_oo0019ooooo`03ool00?oooooooooo00Wooooo0_oo0019ooooo`03ool0
0?oooooooooo00Wooooo0_oo000Tooooo`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool0
2Oooool2ool004Wooooo00?oo`00ooooooooool02Oooool2ool004Wooooo00?oo`00ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0>ooooo`;oo`00BOoo
ool00ooo003oooooooooo`09ooooo`;oo`00BOooool00ooo003oooooooooo`09ooooo`;oo`009?oo
ool00ol0003oooooooooo`0Rooooo`03ool00?oooooooooo00Wooooo0_oo0019ooooo`03ool00?oo
oooooooo00[ooooo00?oo`00ooooooooool0Aoooool00ooo003oooooooooo`0>ooooo`03o`000?oo
oooooooo00gooooo000Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0=ooooo`007oooool3o`0000;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_l0000?oooo
o`007oooooooo`000<_o00003oooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-10.4689, -4.33816, 0.0402195, \
0.262625}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show all", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ga\  = \ 
        Show[GraphicsArray[{{gxt, gxn}, {gX, \ gXXs}}], 
          ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0544218 0.00393652 0.196826 [
[.09184 -0.0125 -12 -9 ]
[.09184 -0.0125 12 0 ]
[.22789 -0.0125 -6 -9 ]
[.22789 -0.0125 6 0 ]
[.36395 -0.0125 -12 -9 ]
[.36395 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.63605 -0.0125 -9 -9 ]
[.63605 -0.0125 9 0 ]
[.77211 -0.0125 -3 -9 ]
[.77211 -0.0125 3 0 ]
[.90816 -0.0125 -9 -9 ]
[.90816 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09184 0 m
.09184 .00625 L
s
[(-7.5)] .09184 -0.0125 0 1 Mshowa
.22789 0 m
.22789 .00625 L
s
[(-5)] .22789 -0.0125 0 1 Mshowa
.36395 0 m
.36395 .00625 L
s
[(-2.5)] .36395 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.63605 0 m
.63605 .00625 L
s
[(2.5)] .63605 -0.0125 0 1 Mshowa
.77211 0 m
.77211 .00625 L
s
[(5)] .77211 -0.0125 0 1 Mshowa
.90816 0 m
.90816 .00625 L
s
[(7.5)] .90816 -0.0125 0 1 Mshowa
.125 Mabswid
.11905 0 m
.11905 .00375 L
s
.14626 0 m
.14626 .00375 L
s
.17347 0 m
.17347 .00375 L
s
.20068 0 m
.20068 .00375 L
s
.2551 0 m
.2551 .00375 L
s
.28231 0 m
.28231 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.33673 0 m
.33673 .00375 L
s
.39116 0 m
.39116 .00375 L
s
.41837 0 m
.41837 .00375 L
s
.44558 0 m
.44558 .00375 L
s
.47279 0 m
.47279 .00375 L
s
.52721 0 m
.52721 .00375 L
s
.55442 0 m
.55442 .00375 L
s
.58163 0 m
.58163 .00375 L
s
.60884 0 m
.60884 .00375 L
s
.66327 0 m
.66327 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.71769 0 m
.71769 .00375 L
s
.7449 0 m
.7449 .00375 L
s
.79932 0 m
.79932 .00375 L
s
.82653 0 m
.82653 .00375 L
s
.85374 0 m
.85374 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.06463 0 m
.06463 .00375 L
s
.03741 0 m
.03741 .00375 L
s
.0102 0 m
.0102 .00375 L
s
.93537 0 m
.93537 .00375 L
s
.96259 0 m
.96259 .00375 L
s
.9898 0 m
.9898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09184 .61178 m
.09184 .61803 L
s
.22789 .61178 m
.22789 .61803 L
s
.36395 .61178 m
.36395 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.63605 .61178 m
.63605 .61803 L
s
.77211 .61178 m
.77211 .61803 L
s
.90816 .61178 m
.90816 .61803 L
s
.125 Mabswid
.11905 .61428 m
.11905 .61803 L
s
.14626 .61428 m
.14626 .61803 L
s
.17347 .61428 m
.17347 .61803 L
s
.20068 .61428 m
.20068 .61803 L
s
.2551 .61428 m
.2551 .61803 L
s
.28231 .61428 m
.28231 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.33673 .61428 m
.33673 .61803 L
s
.39116 .61428 m
.39116 .61803 L
s
.41837 .61428 m
.41837 .61803 L
s
.44558 .61428 m
.44558 .61803 L
s
.47279 .61428 m
.47279 .61803 L
s
.52721 .61428 m
.52721 .61803 L
s
.55442 .61428 m
.55442 .61803 L
s
.58163 .61428 m
.58163 .61803 L
s
.60884 .61428 m
.60884 .61803 L
s
.66327 .61428 m
.66327 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.71769 .61428 m
.71769 .61803 L
s
.7449 .61428 m
.7449 .61803 L
s
.79932 .61428 m
.79932 .61803 L
s
.82653 .61428 m
.82653 .61803 L
s
.85374 .61428 m
.85374 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.06463 .61428 m
.06463 .61803 L
s
.03741 .61428 m
.03741 .61803 L
s
.0102 .61428 m
.0102 .61803 L
s
.93537 .61428 m
.93537 .61803 L
s
.96259 .61428 m
.96259 .61803 L
s
.9898 .61428 m
.9898 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.02381 .00394 m
.02474 .00394 L
.02575 .00394 L
.0267 .00394 L
.02761 .00394 L
.02859 .00394 L
.02952 .00394 L
.03052 .00394 L
.03148 .00394 L
.0324 .00394 L
.03338 .00394 L
.03433 .00394 L
.03524 .00394 L
.03621 .00394 L
.03714 .00394 L
.03813 .00394 L
.03908 .00394 L
.04 .00394 L
.04098 .00394 L
.04192 .00394 L
.04292 .00394 L
.04388 .00394 L
.0448 .00394 L
.04579 .00394 L
.04674 .00394 L
.04765 .00394 L
.04862 .00394 L
.04956 .00394 L
.05055 .00394 L
.05151 .00394 L
.05243 .00394 L
.05341 .00394 L
.05435 .00394 L
.05526 .00394 L
.05622 .00394 L
.05715 .00394 L
.05814 .00394 L
.05909 .00394 L
.06001 .00394 L
.06098 .00394 L
.06192 .00394 L
.06292 .00394 L
.06388 .00394 L
.0648 .00394 L
.06579 .00394 L
.06673 .00394 L
.06764 .00394 L
.06861 .00394 L
.06954 .00394 L
.07054 .00394 L
Mistroke
.07149 .00394 L
.07241 .00394 L
.07339 .00394 L
.07433 .00394 L
.07533 .00394 L
.07629 .00394 L
.07722 .00394 L
.07821 .00394 L
.07916 .00394 L
.08007 .00394 L
.08104 .00394 L
.08198 .00394 L
.08297 .00394 L
.08393 .00394 L
.08485 .00394 L
.08584 .00394 L
.08678 .00394 L
.08769 .00394 L
.08866 .00394 L
.08959 .00394 L
.09058 .00394 L
.09153 .00394 L
.09245 .00394 L
.09342 .00394 L
.09436 .00394 L
.09536 .00394 L
.09632 .00394 L
.09725 .00394 L
.09823 .00394 L
.09918 .00394 L
.10009 .00394 L
.10106 .00394 L
.10199 .00394 L
.10299 .00394 L
.10394 .00394 L
.10486 .00394 L
.10584 .00394 L
.10678 .00394 L
.10769 .00394 L
.10866 .00394 L
.10958 .00394 L
.11057 .00394 L
.11152 .00394 L
.11244 .00394 L
.11341 .00394 L
.11435 .00394 L
.11535 .00394 L
.1163 .00394 L
.11723 .00394 L
.11821 .00394 L
Mistroke
.11916 .00394 L
.12007 .00394 L
.12103 .00394 L
.12197 .00394 L
.12296 .00394 L
.12391 .00394 L
.12483 .00394 L
.12581 .00394 L
.12675 .00394 L
.12775 .00394 L
.12871 .00394 L
.12964 .00394 L
.13062 .00394 L
.13157 .00394 L
.13248 .00394 L
.13345 .00394 L
.13439 .00394 L
.13538 .00394 L
.13634 .00394 L
.13726 .00394 L
.13824 .00394 L
.13919 .00394 L
.14009 .00394 L
.14106 .00394 L
.14199 .00394 L
.14298 .00394 L
.14393 .00394 L
.14485 .00394 L
.14582 .00394 L
.14676 .00394 L
.14776 .00394 L
.14872 .00394 L
.14964 .00394 L
.15063 .00394 L
.15158 .00394 L
.15249 .00394 L
.15346 .00394 L
.15439 .00394 L
.15538 .00394 L
.15634 .00394 L
.15726 .00394 L
.15823 .00394 L
.15918 .00394 L
.16018 .00394 L
.16114 .00394 L
.16207 .00394 L
.16306 .00394 L
.16401 .00394 L
.16492 .00394 L
.16589 .00394 L
Mistroke
.16683 .00394 L
.16782 .00394 L
.16878 .00394 L
.16971 .00394 L
.17069 .00394 L
.17163 .00394 L
.17254 .00394 L
.17351 .00394 L
.17444 .00394 L
.17543 .00394 L
.17638 .00394 L
.1773 .00394 L
.17828 .00394 L
.17922 .00394 L
.18022 .00394 L
.18118 .00394 L
.1821 .00394 L
.18309 .00394 L
.18404 .00394 L
.18495 .00394 L
.18592 .00394 L
.18685 .00394 L
.18785 .00394 L
.1888 .00394 L
.18972 .00394 L
.1907 .00394 L
.19165 .00394 L
.19255 .00394 L
.19352 .00394 L
.19445 .00394 L
.19544 .00394 L
.19639 .00394 L
.1973 .00394 L
.19828 .00394 L
.19922 .00394 L
.20021 .00394 L
.20117 .00394 L
.2021 .00394 L
.20308 .00394 L
.20403 .00394 L
.20494 .00394 L
.2059 .00394 L
.20684 .00394 L
.20783 .00394 L
.20878 .00394 L
.2097 .00394 L
.21068 .00394 L
.21162 .00394 L
.21262 .00394 L
.21358 .00394 L
Mistroke
.21451 .00394 L
.2155 .00394 L
.21645 .00394 L
.21736 .00394 L
.21833 .00394 L
.21927 .00394 L
.22026 .00394 L
.22122 .00394 L
.22214 .00394 L
.22312 .00394 L
.22407 .00394 L
.22497 .00394 L
.22594 .00394 L
.22687 .00394 L
.22786 .00394 L
.22881 .00394 L
.22973 .00394 L
.23071 .00394 L
.23164 .00394 L
.23264 .00394 L
.2336 .00394 L
.23453 .00394 L
.23551 .00394 L
.23646 .00394 L
.23737 .00394 L
.23834 .00394 L
.23928 .00394 L
.24027 .00394 L
.24122 .00394 L
.24214 .00394 L
.24312 .00394 L
.24406 .00394 L
.24497 .00394 L
.24594 .00394 L
.24686 .00394 L
.24785 .00394 L
.2488 .00394 L
.24972 .00394 L
.25069 .00394 L
.25163 .00394 L
.25262 .00394 L
.25358 .00394 L
.25451 .00394 L
.25549 .00394 L
.25643 .00394 L
.25734 .00394 L
.25831 .00394 L
.25924 .00394 L
.26023 .00394 L
.26119 .00394 L
Mistroke
.2621 .00394 L
.26308 .00394 L
.26402 .00394 L
.26502 .00394 L
.26598 .00394 L
.26691 .00394 L
.26789 .00394 L
.26884 .00394 L
.26976 .00394 L
.27073 .00394 L
.27166 .00394 L
.27266 .00394 L
.27361 .00394 L
.27453 .00394 L
.27551 .00394 L
.27646 .00394 L
.27736 .00394 L
.27833 .00394 L
.27926 .00394 L
.28025 .00394 L
.2812 .00394 L
.28212 .00394 L
.28309 .00394 L
.28403 .00394 L
.28503 .00394 L
.28599 .00394 L
.28691 .00394 L
.28789 .00394 L
.28884 .00394 L
.28975 .00394 L
.29072 .00394 L
.29165 .00394 L
.29265 .00394 L
.2936 .00394 L
.29452 .00394 L
.2955 .00394 L
.29644 .00394 L
.29744 .00394 L
.2984 .00394 L
.29933 .00394 L
.30032 .00394 L
.30127 .00394 L
.30218 .00394 L
.30315 .00394 L
.30409 .00394 L
.30509 .00394 L
.30604 .00394 L
.30697 .00394 L
.30795 .00394 L
.30889 .00394 L
Mistroke
.3098 .00394 L
.31077 .00394 L
.3117 .00394 L
.31269 .00394 L
.31364 .00394 L
.31456 .00394 L
.31554 .00394 L
.31647 .00394 L
.31747 .00394 L
.31844 .00394 L
.31936 .00394 L
.32035 .00394 L
.32129 .00394 L
.3222 .00394 L
.32318 .00394 L
.32411 .00394 L
.3251 .00394 L
.32606 .00394 L
.32698 .00394 L
.32796 .00394 L
.3289 .00394 L
.32981 .00394 L
.33077 .00394 L
.3317 .00394 L
.33269 .00394 L
.33364 .00394 L
.33456 .00394 L
.33553 .00394 L
.33647 .00394 L
.33746 .00394 L
.33842 .00394 L
.33935 .00394 L
.34033 .00394 L
.34128 .00394 L
.34218 .00394 L
.34315 .00394 L
.34409 .00394 L
.34508 .00394 L
.34603 .00394 L
.34695 .00394 L
.34793 .00394 L
.34887 .00394 L
.34987 .00394 L
.35083 .00394 L
.35176 .00394 L
.35274 .00394 L
.35369 .00394 L
.3546 .00394 L
.35558 .00394 L
.35651 .00394 L
Mistroke
.35751 .00394 L
.35846 .00394 L
.35939 .00394 L
.36037 .00394 L
.36131 .00394 L
.36222 .00394 L
.36318 .00394 L
.36411 .00394 L
.3651 .00394 L
.36606 .00394 L
.36697 .00394 L
.36795 .00394 L
.36889 .00394 L
.36988 .00394 L
.37084 .00394 L
.37177 .00394 L
.37275 .00394 L
.3737 .00394 L
.37461 .00394 L
.37558 .00394 L
.37651 .00394 L
.37751 .00394 L
.37846 .00394 L
.37938 .00394 L
.38036 .00394 L
.3813 .00394 L
.3823 .00394 L
.38327 .00394 L
.3842 .00394 L
.38518 .00394 L
.38613 .00394 L
.38705 .00394 L
.38802 .00394 L
.38896 .00394 L
.38943 .00394 L
.38969 .00394 L
.38982 .00394 L
.38995 .00394 L
.39001 .00394 L
.39004 .00394 L
.39007 .00394 L
.3901 .39759 L
.39011 .39759 L
.39013 .39759 L
.39019 .39759 L
.39045 .39759 L
.39091 .39759 L
.39139 .39759 L
.39164 .39759 L
.39191 .39759 L
Mistroke
.39203 .39759 L
.39215 .39759 L
.39219 .39759 L
.3922 .39759 L
.39222 .39759 L
.39225 .00394 L
.39227 .00394 L
.39229 .00394 L
.39241 .00394 L
.39287 .00394 L
.39378 .00394 L
.39475 .00394 L
.39568 .00394 L
.39666 .00394 L
.39762 .00394 L
.39853 .00394 L
.39951 .00394 L
.40044 .00394 L
.40144 .00394 L
.4024 .00394 L
.40332 .00394 L
.40431 .00394 L
.40525 .00394 L
.40616 .00394 L
.40713 .00394 L
.40807 .00394 L
.40906 .00394 L
.41001 .00394 L
.41093 .00394 L
.41191 .00394 L
.41285 .00394 L
.41385 .00394 L
.41481 .00394 L
.41574 .00394 L
.41673 .00394 L
.41768 .00394 L
.41859 .00394 L
.41956 .00394 L
.4205 .00394 L
.42149 .00394 L
.42245 .00394 L
.42337 .00394 L
.42435 .00394 L
.4253 .00394 L
.42621 .00394 L
.42717 .00394 L
.4281 .00394 L
.42909 .00394 L
.43005 .00394 L
.43096 .00394 L
Mistroke
.43194 .00394 L
.43288 .00394 L
.43388 .00394 L
.43484 .00394 L
.43576 .00394 L
.43675 .00394 L
.4377 .00394 L
.43861 .00394 L
.43958 .00394 L
.44051 .00394 L
.4415 .00394 L
.44246 .00394 L
.44338 .00394 L
.44384 .00394 L
.44409 .00394 L
.44422 .00394 L
.44436 .00394 L
.44442 .00394 L
.44445 .00394 L
.44448 .00394 L
.4445 .20076 L
.44452 .20076 L
.44455 .20076 L
.44461 .20076 L
.44484 .20076 L
.4453 .20076 L
.44577 .20076 L
.44602 .20076 L
.44628 .20076 L
.44641 .20076 L
.44654 .20076 L
.44659 .20076 L
.44662 .20076 L
.44665 .20076 L
.44667 .20076 L
.44668 .00394 L
.44671 .00394 L
.44677 .00394 L
.44723 .00394 L
.44821 .00394 L
.44916 .00394 L
.45008 .00394 L
.45105 .00394 L
.45198 .00394 L
.45298 .00394 L
.45393 .00394 L
.45486 .00394 L
.45584 .00394 L
.45678 .00394 L
.45769 .00394 L
Mistroke
.45865 .00394 L
.45958 .00394 L
.46057 .00394 L
.46152 .00394 L
.46244 .00394 L
.46341 .00394 L
.46435 .00394 L
.46535 .00394 L
.46631 .00394 L
.46724 .00394 L
.46822 .00394 L
.46917 .00394 L
.47008 .00394 L
.47105 .00394 L
.47198 .00394 L
.47297 .00394 L
.47393 .00394 L
.47485 .00394 L
.47582 .00394 L
.47677 .00394 L
.47777 .00394 L
.47873 .00394 L
.47966 .00394 L
.48064 .00394 L
.48159 .00394 L
.48251 .00394 L
.48348 .00394 L
.48442 .00394 L
.48541 .00394 L
.48637 .00394 L
.48729 .00394 L
.48828 .00394 L
.48922 .00394 L
.49013 .00394 L
.4911 .00394 L
.49203 .00394 L
.49302 .00394 L
.49397 .00394 L
.49489 .00394 L
.49586 .00394 L
.4968 .00394 L
.4978 .00394 L
.4983 .00394 L
.49852 .00394 L
.49864 .00394 L
.49876 .00394 L
.49883 .00394 L
.49886 .00394 L
.49889 .00394 L
.49891 .20076 L
Mistroke
.49894 .20076 L
.499 .20076 L
.49921 .20076 L
.49969 .20076 L
.5006 .20076 L
.50082 .20076 L
.50095 .20076 L
.50101 .20076 L
.50103 .20076 L
.50106 .20076 L
.50109 .00394 L
.50112 .00394 L
.50119 .00394 L
.50132 .00394 L
.50156 .00394 L
.50255 .00394 L
.50349 .00394 L
.5044 .00394 L
.50537 .00394 L
.5063 .00394 L
.50729 .00394 L
.50825 .00394 L
.50917 .00394 L
.51014 .00394 L
.51108 .00394 L
.51208 .00394 L
.51305 .00394 L
.51397 .00394 L
.51496 .00394 L
.51591 .00394 L
.51682 .00394 L
.5178 .00394 L
.51873 .00394 L
.51973 .00394 L
.52068 .00394 L
.52161 .00394 L
.52259 .00394 L
.52353 .00394 L
.52444 .00394 L
.5254 .00394 L
.52633 .00394 L
.52732 .00394 L
.52828 .00394 L
.52919 .00394 L
.53017 .00394 L
.53111 .00394 L
.53211 .00394 L
.53307 .00394 L
.53399 .00394 L
.53498 .00394 L
Mistroke
.53592 .00394 L
.53683 .00394 L
.5378 .00394 L
.53874 .00394 L
.53973 .00394 L
.54069 .00394 L
.54161 .00394 L
.54258 .00394 L
.54353 .00394 L
.54443 .00394 L
.5454 .00394 L
.54632 .00394 L
.54731 .00394 L
.54826 .00394 L
.54918 .00394 L
.55015 .00394 L
.55109 .00394 L
.55208 .00394 L
.55258 .00394 L
.5528 .00394 L
.55304 .00394 L
.55315 .00394 L
.55322 .00394 L
.55327 .00394 L
.5533 .00394 L
.55333 .00394 L
.55336 .20076 L
.55339 .20076 L
.55349 .20076 L
.55397 .20076 L
.55445 .20076 L
.55496 .20076 L
.55521 .20076 L
.55534 .20076 L
.55541 .20076 L
.55543 .20076 L
.55547 .20076 L
.55549 .20076 L
.55552 .00394 L
.55555 .00394 L
.55557 .00394 L
.55569 .00394 L
.55593 .00394 L
.55683 .00394 L
.5578 .00394 L
.55873 .00394 L
.55972 .00394 L
.56067 .00394 L
.56159 .00394 L
.56256 .00394 L
Mistroke
.5635 .00394 L
.56449 .00394 L
.56546 .00394 L
.56638 .00394 L
.56736 .00394 L
.56831 .00394 L
.56922 .00394 L
.57019 .00394 L
.57112 .00394 L
.57211 .00394 L
.57307 .00394 L
.57399 .00394 L
.57497 .00394 L
.57591 .00394 L
.57691 .00394 L
.57787 .00394 L
.5788 .00394 L
.57978 .00394 L
.58073 .00394 L
.58165 .00394 L
.58262 .00394 L
.58356 .00394 L
.58455 .00394 L
.58551 .00394 L
.58643 .00394 L
.58741 .00394 L
.58836 .00394 L
.58927 .00394 L
.59023 .00394 L
.59116 .00394 L
.59215 .00394 L
.59311 .00394 L
.59402 .00394 L
.595 .00394 L
.59594 .00394 L
.59694 .00394 L
.5979 .00394 L
.59882 .00394 L
.59981 .00394 L
.60076 .00394 L
.60167 .00394 L
.60264 .00394 L
.60357 .00394 L
.60457 .00394 L
.60552 .00394 L
.60644 .00394 L
.60691 .00394 L
.60716 .00394 L
.60742 .00394 L
.60755 .00394 L
Mistroke
.60761 .00394 L
.60768 .00394 L
.6077 .00394 L
.60773 .00394 L
.60776 .39759 L
.60779 .39759 L
.60791 .39759 L
.60836 .39759 L
.60929 .39759 L
.60953 .39759 L
.60976 .39759 L
.60982 .39759 L
.60988 .39759 L
.60991 .39759 L
.60993 .39759 L
.60995 .00394 L
.60997 .00394 L
.61001 .00394 L
.61027 .00394 L
.61127 .00394 L
.61223 .00394 L
.61316 .00394 L
.61415 .00394 L
.61509 .00394 L
.61601 .00394 L
.61698 .00394 L
.61791 .00394 L
.61891 .00394 L
.61987 .00394 L
.62079 .00394 L
.62177 .00394 L
.62271 .00394 L
.62362 .00394 L
.62459 .00394 L
.62552 .00394 L
.6265 .00394 L
.62746 .00394 L
.62837 .00394 L
.62935 .00394 L
.63029 .00394 L
.63128 .00394 L
.63225 .00394 L
.63317 .00394 L
.63415 .00394 L
.6351 .00394 L
.63601 .00394 L
.63698 .00394 L
.63791 .00394 L
.63891 .00394 L
.63986 .00394 L
Mistroke
.64078 .00394 L
.64176 .00394 L
.6427 .00394 L
.6437 .00394 L
.64467 .00394 L
.64559 .00394 L
.64658 .00394 L
.64753 .00394 L
.64845 .00394 L
.64942 .00394 L
.65036 .00394 L
.65135 .00394 L
.65231 .00394 L
.65323 .00394 L
.65421 .00394 L
.65516 .00394 L
.65607 .00394 L
.65704 .00394 L
.65797 .00394 L
.65896 .00394 L
.65991 .00394 L
.66083 .00394 L
.6618 .00394 L
.66274 .00394 L
.66374 .00394 L
.66471 .00394 L
.66563 .00394 L
.66662 .00394 L
.66756 .00394 L
.66848 .00394 L
.66945 .00394 L
.67038 .00394 L
.67138 .00394 L
.67233 .00394 L
.67325 .00394 L
.67423 .00394 L
.67518 .00394 L
.67608 .00394 L
.67705 .00394 L
.67798 .00394 L
.67897 .00394 L
.67992 .00394 L
.68083 .00394 L
.68181 .00394 L
.68274 .00394 L
.68374 .00394 L
.6847 .00394 L
.68563 .00394 L
.68661 .00394 L
.68755 .00394 L
Mistroke
.68846 .00394 L
.68943 .00394 L
.69037 .00394 L
.69136 .00394 L
.69231 .00394 L
.69323 .00394 L
.69421 .00394 L
.69515 .00394 L
.69615 .00394 L
.69711 .00394 L
.69804 .00394 L
.69903 .00394 L
.69998 .00394 L
.70089 .00394 L
.70186 .00394 L
.7028 .00394 L
.70379 .00394 L
.70475 .00394 L
.70567 .00394 L
.70665 .00394 L
.7076 .00394 L
.7085 .00394 L
.70947 .00394 L
.7104 .00394 L
.71139 .00394 L
.71234 .00394 L
.71326 .00394 L
.71424 .00394 L
.71518 .00394 L
.71617 .00394 L
.71714 .00394 L
.71806 .00394 L
.71904 .00394 L
.71999 .00394 L
.7209 .00394 L
.72187 .00394 L
.72281 .00394 L
.7238 .00394 L
.72476 .00394 L
.72568 .00394 L
.72665 .00394 L
.7276 .00394 L
.7285 .00394 L
.72947 .00394 L
.7304 .00394 L
.73138 .00394 L
.73233 .00394 L
.73325 .00394 L
.73422 .00394 L
.73516 .00394 L
Mistroke
.73616 .00394 L
.73711 .00394 L
.73804 .00394 L
.73902 .00394 L
.73997 .00394 L
.74087 .00394 L
.74184 .00394 L
.74277 .00394 L
.74377 .00394 L
.74472 .00394 L
.74564 .00394 L
.74661 .00394 L
.74755 .00394 L
.74855 .00394 L
.74952 .00394 L
.75044 .00394 L
.75143 .00394 L
.75238 .00394 L
.75329 .00394 L
.75426 .00394 L
.7552 .00394 L
.75619 .00394 L
.75715 .00394 L
.75807 .00394 L
.75905 .00394 L
.75999 .00394 L
.7609 .00394 L
.76187 .00394 L
.76279 .00394 L
.76378 .00394 L
.76474 .00394 L
.76565 .00394 L
.76663 .00394 L
.76756 .00394 L
.76856 .00394 L
.76952 .00394 L
.77045 .00394 L
.77143 .00394 L
.77238 .00394 L
.77329 .00394 L
.77426 .00394 L
.77519 .00394 L
.77618 .00394 L
.77714 .00394 L
.77806 .00394 L
.77903 .00394 L
.77998 .00394 L
.78098 .00394 L
.78194 .00394 L
.78287 .00394 L
Mistroke
.78385 .00394 L
.7848 .00394 L
.78572 .00394 L
.78669 .00394 L
.78763 .00394 L
.78862 .00394 L
.78958 .00394 L
.7905 .00394 L
.79148 .00394 L
.79243 .00394 L
.79334 .00394 L
.79431 .00394 L
.79524 .00394 L
.79623 .00394 L
.79718 .00394 L
.7981 .00394 L
.79907 .00394 L
.80001 .00394 L
.80101 .00394 L
.80197 .00394 L
.8029 .00394 L
.80388 .00394 L
.80483 .00394 L
.80574 .00394 L
.80671 .00394 L
.80765 .00394 L
.80864 .00394 L
.8096 .00394 L
.81052 .00394 L
.8115 .00394 L
.81244 .00394 L
.81335 .00394 L
.81431 .00394 L
.81524 .00394 L
.81623 .00394 L
.81718 .00394 L
.81809 .00394 L
.81907 .00394 L
.82001 .00394 L
.821 .00394 L
.82196 .00394 L
.82289 .00394 L
.82387 .00394 L
.82481 .00394 L
.82572 .00394 L
.82669 .00394 L
.82762 .00394 L
.82862 .00394 L
.82957 .00394 L
.83049 .00394 L
Mistroke
.83147 .00394 L
.83241 .00394 L
.83341 .00394 L
.83437 .00394 L
.8353 .00394 L
.83628 .00394 L
.83723 .00394 L
.83815 .00394 L
.83912 .00394 L
.84005 .00394 L
.84105 .00394 L
.842 .00394 L
.84293 .00394 L
.84391 .00394 L
.84485 .00394 L
.84576 .00394 L
.84673 .00394 L
.84766 .00394 L
.84864 .00394 L
.8496 .00394 L
.85051 .00394 L
.85149 .00394 L
.85243 .00394 L
.85342 .00394 L
.85439 .00394 L
.85531 .00394 L
.85629 .00394 L
.85724 .00394 L
.85815 .00394 L
.85912 .00394 L
.86006 .00394 L
.86105 .00394 L
.862 .00394 L
.86292 .00394 L
.8639 .00394 L
.86484 .00394 L
.86585 .00394 L
.86681 .00394 L
.86774 .00394 L
.86873 .00394 L
.86968 .00394 L
.87059 .00394 L
.87156 .00394 L
.8725 .00394 L
.8735 .00394 L
.87445 .00394 L
.87538 .00394 L
.87636 .00394 L
.8773 .00394 L
.87821 .00394 L
Mistroke
.87918 .00394 L
.88011 .00394 L
.8811 .00394 L
.88206 .00394 L
.88297 .00394 L
.88395 .00394 L
.88489 .00394 L
.88589 .00394 L
.88685 .00394 L
.88778 .00394 L
.88876 .00394 L
.88971 .00394 L
.89062 .00394 L
.8916 .00394 L
.89253 .00394 L
.89352 .00394 L
.89448 .00394 L
.8954 .00394 L
.89638 .00394 L
.89732 .00394 L
.89823 .00394 L
.8992 .00394 L
.90013 .00394 L
.90112 .00394 L
.90207 .00394 L
.90298 .00394 L
.90396 .00394 L
.9049 .00394 L
.90589 .00394 L
.90685 .00394 L
.90778 .00394 L
.90876 .00394 L
.90971 .00394 L
.91062 .00394 L
.91159 .00394 L
.91252 .00394 L
.91351 .00394 L
.91446 .00394 L
.91538 .00394 L
.91636 .00394 L
.9173 .00394 L
.9183 .00394 L
.91927 .00394 L
.92019 .00394 L
.92118 .00394 L
.92213 .00394 L
.92304 .00394 L
.92402 .00394 L
.92495 .00394 L
.92595 .00394 L
Mistroke
.9269 .00394 L
.92783 .00394 L
.92881 .00394 L
.92975 .00394 L
.93066 .00394 L
.93163 .00394 L
.93256 .00394 L
.93355 .00394 L
.9345 .00394 L
.93542 .00394 L
.93639 .00394 L
.93733 .00394 L
.93833 .00394 L
.93929 .00394 L
.94022 .00394 L
.9412 .00394 L
.94215 .00394 L
.94306 .00394 L
.94403 .00394 L
.94497 .00394 L
.94596 .00394 L
.94691 .00394 L
.94783 .00394 L
.94881 .00394 L
.94976 .00394 L
.95066 .00394 L
.95163 .00394 L
.95256 .00394 L
.95354 .00394 L
.95449 .00394 L
.95541 .00394 L
.95638 .00394 L
.95732 .00394 L
.95832 .00394 L
.95928 .00394 L
.9602 .00394 L
.96118 .00394 L
.96213 .00394 L
.96304 .00394 L
.96401 .00394 L
.96494 .00394 L
.96593 .00394 L
.96688 .00394 L
.9678 .00394 L
.96878 .00394 L
.96972 .00394 L
.97072 .00394 L
.97168 .00394 L
.97261 .00394 L
.97359 .00394 L
Mistroke
.97454 .00394 L
.97545 .00394 L
.97619 .00394 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0544218 0.00393652 0.196826 [
[.09184 -0.0125 -12 -9 ]
[.09184 -0.0125 12 0 ]
[.22789 -0.0125 -6 -9 ]
[.22789 -0.0125 6 0 ]
[.36395 -0.0125 -12 -9 ]
[.36395 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.63605 -0.0125 -9 -9 ]
[.63605 -0.0125 9 0 ]
[.77211 -0.0125 -3 -9 ]
[.77211 -0.0125 3 0 ]
[.90816 -0.0125 -9 -9 ]
[.90816 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09184 0 m
.09184 .00625 L
s
[(-7.5)] .09184 -0.0125 0 1 Mshowa
.22789 0 m
.22789 .00625 L
s
[(-5)] .22789 -0.0125 0 1 Mshowa
.36395 0 m
.36395 .00625 L
s
[(-2.5)] .36395 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.63605 0 m
.63605 .00625 L
s
[(2.5)] .63605 -0.0125 0 1 Mshowa
.77211 0 m
.77211 .00625 L
s
[(5)] .77211 -0.0125 0 1 Mshowa
.90816 0 m
.90816 .00625 L
s
[(7.5)] .90816 -0.0125 0 1 Mshowa
.125 Mabswid
.11905 0 m
.11905 .00375 L
s
.14626 0 m
.14626 .00375 L
s
.17347 0 m
.17347 .00375 L
s
.20068 0 m
.20068 .00375 L
s
.2551 0 m
.2551 .00375 L
s
.28231 0 m
.28231 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.33673 0 m
.33673 .00375 L
s
.39116 0 m
.39116 .00375 L
s
.41837 0 m
.41837 .00375 L
s
.44558 0 m
.44558 .00375 L
s
.47279 0 m
.47279 .00375 L
s
.52721 0 m
.52721 .00375 L
s
.55442 0 m
.55442 .00375 L
s
.58163 0 m
.58163 .00375 L
s
.60884 0 m
.60884 .00375 L
s
.66327 0 m
.66327 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.71769 0 m
.71769 .00375 L
s
.7449 0 m
.7449 .00375 L
s
.79932 0 m
.79932 .00375 L
s
.82653 0 m
.82653 .00375 L
s
.85374 0 m
.85374 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.06463 0 m
.06463 .00375 L
s
.03741 0 m
.03741 .00375 L
s
.0102 0 m
.0102 .00375 L
s
.93537 0 m
.93537 .00375 L
s
.96259 0 m
.96259 .00375 L
s
.9898 0 m
.9898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.09184 .61178 m
.09184 .61803 L
s
.22789 .61178 m
.22789 .61803 L
s
.36395 .61178 m
.36395 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.63605 .61178 m
.63605 .61803 L
s
.77211 .61178 m
.77211 .61803 L
s
.90816 .61178 m
.90816 .61803 L
s
.125 Mabswid
.11905 .61428 m
.11905 .61803 L
s
.14626 .61428 m
.14626 .61803 L
s
.17347 .61428 m
.17347 .61803 L
s
.20068 .61428 m
.20068 .61803 L
s
.2551 .61428 m
.2551 .61803 L
s
.28231 .61428 m
.28231 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.33673 .61428 m
.33673 .61803 L
s
.39116 .61428 m
.39116 .61803 L
s
.41837 .61428 m
.41837 .61803 L
s
.44558 .61428 m
.44558 .61803 L
s
.47279 .61428 m
.47279 .61803 L
s
.52721 .61428 m
.52721 .61803 L
s
.55442 .61428 m
.55442 .61803 L
s
.58163 .61428 m
.58163 .61803 L
s
.60884 .61428 m
.60884 .61803 L
s
.66327 .61428 m
.66327 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.71769 .61428 m
.71769 .61803 L
s
.7449 .61428 m
.7449 .61803 L
s
.79932 .61428 m
.79932 .61803 L
s
.82653 .61428 m
.82653 .61803 L
s
.85374 .61428 m
.85374 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.06463 .61428 m
.06463 .61803 L
s
.03741 .61428 m
.03741 .61803 L
s
.0102 .61428 m
.0102 .61803 L
s
.93537 .61428 m
.93537 .61803 L
s
.96259 .61428 m
.96259 .61803 L
s
.9898 .61428 m
.9898 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .00394 m
.02567 .00394 L
.02769 .00394 L
.0296 .00394 L
.03143 .00394 L
.03338 .00394 L
.03428 .00394 L
.03525 .00394 L
.03551 .00394 L
.03578 .00394 L
.0359 .00394 L
.03596 .00394 L
.03602 .00394 L
.03605 .00394 L
.03609 .39759 L
.03615 .39759 L
.03628 .39759 L
.03724 .39759 L
.03819 .39759 L
.03846 .39759 L
.0386 .39759 L
.03866 .39759 L
.03869 .39759 L
.03872 .39759 L
.03878 .00394 L
.03883 .00394 L
.03895 .00394 L
.0392 .00394 L
.04119 .00394 L
.04311 .00394 L
.04495 .00394 L
.04691 .00394 L
.0488 .00394 L
.05061 .00394 L
.05255 .00394 L
.05441 .00394 L
.05639 .00394 L
.05829 .00394 L
.06013 .00394 L
.06115 .00394 L
.06208 .00394 L
.06254 .00394 L
.06278 .00394 L
.06292 .00394 L
.06304 .00394 L
.06315 .00394 L
.06321 .00394 L
.06327 .20076 L
.06333 .20076 L
.0634 .20076 L
Mistroke
.06352 .20076 L
.06396 .20076 L
.06498 .20076 L
.06547 .20076 L
.06568 .20076 L
.0658 .20076 L
.06586 .20076 L
.06591 .20076 L
.06597 .20076 L
.06602 .00394 L
.06608 .00394 L
.06614 .00394 L
.06638 .00394 L
.06688 .00394 L
.0678 .00394 L
.06976 .00394 L
.07165 .00394 L
.07347 .00394 L
.07541 .00394 L
.07727 .00394 L
.07925 .00394 L
.08116 .00394 L
.08299 .00394 L
.08495 .00394 L
.08683 .00394 L
.08883 .00394 L
.09075 .00394 L
.0926 .00394 L
.09458 .00394 L
.09647 .00394 L
.0983 .00394 L
.10024 .00394 L
.10211 .00394 L
.1041 .00394 L
.10601 .00394 L
.10785 .00394 L
.10981 .00394 L
.1117 .00394 L
.11352 .00394 L
.11545 .00394 L
.11634 .00394 L
.11684 .00394 L
.11708 .00394 L
.11731 .00394 L
.11742 .00394 L
.11755 .00394 L
.1176 .00394 L
.11766 .00394 L
.11772 .20076 L
.11777 .20076 L
Mistroke
.11827 .20076 L
.11928 .20076 L
.11976 .20076 L
.12 .20076 L
.12022 .20076 L
.12034 .20076 L
.12037 .20076 L
.12041 .20076 L
.12047 .00394 L
.1205 .00394 L
.12054 .00394 L
.1206 .00394 L
.12074 .00394 L
.12122 .00394 L
.12305 .00394 L
.125 .00394 L
.12687 .00394 L
.12886 .00394 L
.13078 .00394 L
.13262 .00394 L
.13458 .00394 L
.13647 .00394 L
.13829 .00394 L
.14022 .00394 L
.14208 .00394 L
.14406 .00394 L
.14597 .00394 L
.1478 .00394 L
.14976 .00394 L
.15164 .00394 L
.15363 .00394 L
.15556 .00394 L
.15741 .00394 L
.15938 .00394 L
.16127 .00394 L
.1631 .00394 L
.16504 .00394 L
.1669 .00394 L
.16889 .00394 L
.16988 .00394 L
.1708 .00394 L
.17126 .00394 L
.1717 .00394 L
.17194 .00394 L
.172 .00394 L
.17204 .00394 L
.17207 .00394 L
.17213 .20076 L
.17216 .20076 L
.17219 .20076 L
Mistroke
.17264 .20076 L
.1736 .20076 L
.1741 .20076 L
.17438 .20076 L
.17451 .20076 L
.17464 .20076 L
.17469 .20076 L
.17475 .20076 L
.17481 .20076 L
.17487 .00394 L
.17493 .00394 L
.17499 .00394 L
.17511 .00394 L
.17564 .00394 L
.17656 .00394 L
.17848 .00394 L
.18034 .00394 L
.18231 .00394 L
.18421 .00394 L
.18603 .00394 L
.18798 .00394 L
.18985 .00394 L
.19184 .00394 L
.19375 .00394 L
.1956 .00394 L
.19653 .00394 L
.19756 .00394 L
.19802 .00394 L
.19853 .00394 L
.19876 .00394 L
.19901 .00394 L
.19911 .00394 L
.19922 .00394 L
.19928 .00394 L
.19933 .39759 L
.19939 .39759 L
.19944 .39759 L
.20032 .39759 L
.20083 .39759 L
.20129 .39759 L
.20175 .39759 L
.20189 .39759 L
.20195 .39759 L
.20201 .39759 L
.20207 .00394 L
.20213 .00394 L
.20225 .00394 L
.20326 .00394 L
.20526 .00394 L
.20719 .00394 L
Mistroke
.20905 .00394 L
.21102 .00394 L
.21292 .00394 L
.21475 .00394 L
.2167 .00394 L
.21857 .00394 L
.22056 .00394 L
.22248 .00394 L
.22433 .00394 L
.22526 .00394 L
.22576 .00394 L
.22602 .00394 L
.22616 .00394 L
.22629 .00394 L
.22641 .00394 L
.22644 .00394 L
.22647 .00394 L
.22653 .39759 L
.22656 .39759 L
.2266 .39759 L
.22666 .39759 L
.2268 .39759 L
.22726 .39759 L
.22818 .39759 L
.22863 .39759 L
.22888 .39759 L
.22901 .39759 L
.22912 .39759 L
.22918 .39759 L
.22923 .39759 L
.22928 .00394 L
.22934 .00394 L
.22958 .00394 L
.23 .00394 L
.23186 .00394 L
.23384 .00394 L
.23574 .00394 L
.23757 .00394 L
.23952 .00394 L
.2414 .00394 L
.24339 .00394 L
.24531 .00394 L
.24716 .00394 L
.24913 .00394 L
.25102 .00394 L
.25197 .00394 L
.25284 .00394 L
.25307 .00394 L
.25332 .00394 L
.25343 .00394 L
Mistroke
.25355 .00394 L
.25361 .00394 L
.25367 .00394 L
.25372 .00394 L
.25377 .20076 L
.25384 .20076 L
.25389 .20076 L
.25403 .20076 L
.2543 .20076 L
.25478 .20076 L
.25528 .20076 L
.25576 .20076 L
.25618 .20076 L
.2563 .20076 L
.25637 .20076 L
.25643 .20076 L
.25648 .00394 L
.25653 .00394 L
.25665 .00394 L
.25863 .00394 L
.26053 .00394 L
.26237 .00394 L
.26432 .00394 L
.2662 .00394 L
.26819 .00394 L
.27012 .00394 L
.27197 .00394 L
.27394 .00394 L
.27583 .00394 L
.27765 .00394 L
.27959 .00394 L
.28146 .00394 L
.28345 .00394 L
.28536 .00394 L
.2872 .00394 L
.28916 .00394 L
.29104 .00394 L
.29304 .00394 L
.29497 .00394 L
.29683 .00394 L
.29881 .00394 L
.30071 .00394 L
.30254 .00394 L
.30449 .00394 L
.30636 .00394 L
.30685 .00394 L
.30738 .00394 L
.30763 .00394 L
.30789 .00394 L
.30799 .00394 L
Mistroke
.30805 .00394 L
.30811 .00394 L
.30814 .00394 L
.30817 .20076 L
.30823 .20076 L
.30835 .20076 L
.30938 .20076 L
.31031 .20076 L
.31053 .20076 L
.31065 .20076 L
.31077 .20076 L
.31083 .20076 L
.31086 .20076 L
.3109 .00394 L
.31093 .00394 L
.31097 .00394 L
.31103 .00394 L
.31127 .00394 L
.31219 .00394 L
.31415 .00394 L
.31603 .00394 L
.31785 .00394 L
.31978 .00394 L
.32164 .00394 L
.32362 .00394 L
.32552 .00394 L
.32735 .00394 L
.3293 .00394 L
.33118 .00394 L
.33318 .00394 L
.3351 .00394 L
.33695 .00394 L
.33891 .00394 L
.34081 .00394 L
.34263 .00394 L
.34457 .00394 L
.34643 .00394 L
.34842 .00394 L
.35033 .00394 L
.35217 .00394 L
.35412 .00394 L
.35601 .00394 L
.35801 .00394 L
.35994 .00394 L
.36082 .00394 L
.36132 .00394 L
.36179 .00394 L
.36225 .00394 L
.36239 .00394 L
.36245 .00394 L
Mistroke
.36251 .00394 L
.36257 .00394 L
.36263 .20076 L
.36269 .20076 L
.36275 .20076 L
.36376 .20076 L
.3647 .20076 L
.36495 .20076 L
.36509 .20076 L
.36516 .20076 L
.36522 .20076 L
.36528 .20076 L
.36533 .00394 L
.36539 .00394 L
.36545 .00394 L
.3657 .00394 L
.36767 .00394 L
.36957 .00394 L
.37139 .00394 L
.37333 .00394 L
.3752 .00394 L
.37719 .00394 L
.3791 .00394 L
.38094 .00394 L
.3829 .00394 L
.38478 .00394 L
.38679 .00394 L
.38779 .00394 L
.38872 .00394 L
.38919 .00394 L
.38942 .00394 L
.38962 .00394 L
.38968 .00394 L
.38974 .00394 L
.38979 .00394 L
.38984 .39759 L
.3899 .39759 L
.38996 .39759 L
.39008 .39759 L
.39058 .39759 L
.39159 .39759 L
.39207 .39759 L
.3923 .39759 L
.3924 .39759 L
.39246 .39759 L
.39251 .39759 L
.39257 .00394 L
.39263 .00394 L
.39274 .00394 L
.39297 .00394 L
Mistroke
.39347 .00394 L
.39438 .00394 L
.39621 .00394 L
.39815 .00394 L
.40002 .00394 L
.40201 .00394 L
.40393 .00394 L
.40577 .00394 L
.40773 .00394 L
.40962 .00394 L
.41143 .00394 L
.41337 .00394 L
.41523 .00394 L
.41619 .00394 L
.41668 .00394 L
.41681 .00394 L
.41688 .00394 L
.41692 .00394 L
.41695 .00394 L
.41698 .00394 L
.41701 .39759 L
.41705 .39759 L
.41708 .39759 L
.41721 .39759 L
.41822 .39759 L
.41915 .39759 L
.41937 .39759 L
.41949 .39759 L
.4196 .39759 L
.41967 .39759 L
.41971 .39759 L
.41974 .00394 L
.4198 .00394 L
.41986 .00394 L
.4201 .00394 L
.42101 .00394 L
.42284 .00394 L
.42479 .00394 L
.42666 .00394 L
.42865 .00394 L
.43057 .00394 L
.43242 .00394 L
.43438 .00394 L
.43627 .00394 L
.43809 .00394 L
.44003 .00394 L
.44189 .00394 L
.44284 .00394 L
.44334 .00394 L
.44361 .00394 L
Mistroke
.44387 .00394 L
.44399 .00394 L
.44412 .00394 L
.44415 .00394 L
.44419 .00394 L
.44422 .20076 L
.44426 .20076 L
.44439 .20076 L
.44486 .20076 L
.44578 .20076 L
.44627 .20076 L
.44652 .20076 L
.44667 .20076 L
.4468 .20076 L
.44685 .20076 L
.44691 .20076 L
.44694 .00394 L
.44698 .00394 L
.44704 .00394 L
.4473 .00394 L
.44777 .00394 L
.44972 .00394 L
.45159 .00394 L
.45359 .00394 L
.45551 .00394 L
.45735 .00394 L
.45932 .00394 L
.46121 .00394 L
.46303 .00394 L
.46497 .00394 L
.46684 .00394 L
.46882 .00394 L
.47073 .00394 L
.47257 .00394 L
.47453 .00394 L
.47641 .00394 L
.47841 .00394 L
.48034 .00394 L
.48219 .00394 L
.48416 .00394 L
.48606 .00394 L
.48789 .00394 L
.48984 .00394 L
.49171 .00394 L
.4937 .00394 L
.49562 .00394 L
.49746 .00394 L
.49795 .00394 L
.49819 .00394 L
.49841 .00394 L
Mistroke
.49852 .00394 L
.49858 .00394 L
.49864 .20076 L
.49871 .20076 L
.49877 .20076 L
.49889 .20076 L
.49942 .20076 L
.49992 .20076 L
.50045 .20076 L
.50069 .20076 L
.50095 .20076 L
.50118 .20076 L
.50124 .20076 L
.50127 .20076 L
.5013 .20076 L
.50136 .00394 L
.50142 .00394 L
.50326 .00394 L
.50522 .00394 L
.5071 .00394 L
.50911 .00394 L
.51104 .00394 L
.51289 .00394 L
.51487 .00394 L
.51677 .00394 L
.5186 .00394 L
.52055 .00394 L
.52242 .00394 L
.52442 .00394 L
.52634 .00394 L
.52818 .00394 L
.53015 .00394 L
.53204 .00394 L
.53386 .00394 L
.53579 .00394 L
.53766 .00394 L
.53964 .00394 L
.54155 .00394 L
.54339 .00394 L
.54534 .00394 L
.54722 .00394 L
.54922 .00394 L
.55115 .00394 L
.55203 .00394 L
.55253 .00394 L
.55278 .00394 L
.55289 .00394 L
.553 .00394 L
.55305 .00394 L
.55311 .20076 L
Mistroke
.55317 .20076 L
.55324 .20076 L
.55346 .20076 L
.55396 .20076 L
.55449 .20076 L
.55497 .20076 L
.55542 .20076 L
.55565 .20076 L
.55571 .20076 L
.55575 .20076 L
.55578 .20076 L
.55584 .00394 L
.5559 .00394 L
.5569 .00394 L
.55875 .00394 L
.56072 .00394 L
.56261 .00394 L
.56444 .00394 L
.56637 .00394 L
.56824 .00394 L
.57023 .00394 L
.57214 .00394 L
.57398 .00394 L
.57593 .00394 L
.57782 .00394 L
.57878 .00394 L
.57928 .00394 L
.57956 .00394 L
.57982 .00394 L
.58005 .00394 L
.58012 .00394 L
.58018 .00394 L
.58024 .00394 L
.5803 .39759 L
.58036 .39759 L
.58043 .39759 L
.58057 .39759 L
.58082 .39759 L
.58175 .39759 L
.5822 .39759 L
.58268 .39759 L
.5828 .39759 L
.58287 .39759 L
.58293 .39759 L
.58296 .39759 L
.583 .00394 L
.58304 .00394 L
.58307 .00394 L
.5832 .00394 L
.58368 .00394 L
Mistroke
.58558 .00394 L
.5874 .00394 L
.58934 .00394 L
.59121 .00394 L
.5932 .00394 L
.59511 .00394 L
.59696 .00394 L
.59891 .00394 L
.6008 .00394 L
.60261 .00394 L
.60455 .00394 L
.6064 .00394 L
.6069 .00394 L
.60714 .00394 L
.60725 .00394 L
.60737 .00394 L
.60743 .00394 L
.60749 .39759 L
.60754 .39759 L
.6076 .39759 L
.60785 .39759 L
.60838 .39759 L
.60933 .39759 L
.60975 .39759 L
.60997 .39759 L
.61009 .39759 L
.61015 .39759 L
.6102 .39759 L
.61026 .00394 L
.6103 .00394 L
.61033 .00394 L
.61045 .00394 L
.61068 .00394 L
.61113 .00394 L
.61214 .00394 L
.61396 .00394 L
.61591 .00394 L
.61778 .00394 L
.61977 .00394 L
.62169 .00394 L
.62353 .00394 L
.62549 .00394 L
.62738 .00394 L
.6292 .00394 L
.63113 .00394 L
.63299 .00394 L
.63395 .00394 L
.63419 .00394 L
.63444 .00394 L
.63451 .00394 L
Mistroke
.63458 .00394 L
.63465 .00394 L
.63468 .00394 L
.63471 .20076 L
.63477 .20076 L
.63484 .20076 L
.63497 .20076 L
.63598 .20076 L
.63691 .20076 L
.63713 .20076 L
.63725 .20076 L
.63731 .20076 L
.63737 .20076 L
.6374 .20076 L
.63743 .00394 L
.63747 .00394 L
.6375 .00394 L
.63763 .00394 L
.63787 .00394 L
.63878 .00394 L
.64072 .00394 L
.6426 .00394 L
.64459 .00394 L
.64651 .00394 L
.64836 .00394 L
.65032 .00394 L
.65221 .00394 L
.65403 .00394 L
.65597 .00394 L
.65783 .00394 L
.65981 .00394 L
.66172 .00394 L
.66355 .00394 L
.66551 .00394 L
.66739 .00394 L
.66939 .00394 L
.67131 .00394 L
.67316 .00394 L
.67514 .00394 L
.67703 .00394 L
.67886 .00394 L
.6808 .00394 L
.68267 .00394 L
.68466 .00394 L
.68657 .00394 L
.68745 .00394 L
.68795 .00394 L
.68842 .00394 L
.68864 .00394 L
.68887 .00394 L
Mistroke
.689 .00394 L
.68903 .00394 L
.68907 .00394 L
.6891 .00394 L
.68913 .20076 L
.68919 .20076 L
.68925 .20076 L
.68937 .20076 L
.69038 .20076 L
.69133 .20076 L
.69156 .20076 L
.69169 .20076 L
.69175 .20076 L
.69181 .20076 L
.69185 .00394 L
.69188 .00394 L
.69196 .00394 L
.69209 .00394 L
.69234 .00394 L
.69434 .00394 L
.69627 .00394 L
.69813 .00394 L
.7001 .00394 L
.702 .00394 L
.70383 .00394 L
.70577 .00394 L
.70765 .00394 L
.70964 .00394 L
.71155 .00394 L
.7134 .00394 L
.71536 .00394 L
.71725 .00394 L
.71907 .00394 L
.721 .00394 L
.72286 .00394 L
.72484 .00394 L
.72675 .00394 L
.72858 .00394 L
.73054 .00394 L
.73242 .00394 L
.73441 .00394 L
.73634 .00394 L
.73819 .00394 L
.74016 .00394 L
.74114 .00394 L
.74205 .00394 L
.74293 .00394 L
.74319 .00394 L
.74331 .00394 L
.74343 .00394 L
Mistroke
.74348 .00394 L
.74353 .00394 L
.74359 .20076 L
.74364 .20076 L
.74388 .20076 L
.74476 .20076 L
.74527 .20076 L
.74573 .20076 L
.74597 .20076 L
.74609 .20076 L
.74614 .20076 L
.7462 .20076 L
.74626 .00394 L
.74629 .00394 L
.74632 .00394 L
.74646 .00394 L
.7467 .00394 L
.74771 .00394 L
.74957 .00394 L
.75156 .00394 L
.75347 .00394 L
.7553 .00394 L
.75726 .00394 L
.75914 .00394 L
.76114 .00394 L
.76306 .00394 L
.76492 .00394 L
.76689 .00394 L
.76879 .00394 L
.76974 .00394 L
.77016 .00394 L
.77038 .00394 L
.77061 .00394 L
.77067 .00394 L
.77073 .00394 L
.77077 .39759 L
.7708 .39759 L
.77086 .39759 L
.7711 .39759 L
.77155 .39759 L
.77256 .39759 L
.773 .39759 L
.77324 .39759 L
.77336 .39759 L
.77341 .39759 L
.77347 .39759 L
.77353 .00394 L
.77357 .00394 L
.7736 .00394 L
.77374 .00394 L
Mistroke
.77398 .00394 L
.77446 .00394 L
.77633 .00394 L
.77831 .00394 L
.78023 .00394 L
.78207 .00394 L
.78402 .00394 L
.78591 .00394 L
.78791 .00394 L
.78984 .00394 L
.79169 .00394 L
.79367 .00394 L
.79557 .00394 L
.79653 .00394 L
.7974 .00394 L
.79763 .00394 L
.79775 .00394 L
.79782 .00394 L
.79788 .00394 L
.79793 .00394 L
.79799 .39759 L
.79803 .39759 L
.79806 .39759 L
.79812 .39759 L
.79834 .39759 L
.79934 .39759 L
.7998 .39759 L
.80006 .39759 L
.8003 .39759 L
.80052 .39759 L
.80058 .39759 L
.80061 .39759 L
.80064 .39759 L
.8007 .00394 L
.80076 .00394 L
.80118 .00394 L
.80305 .00394 L
.80504 .00394 L
.80695 .00394 L
.80879 .00394 L
.81075 .00394 L
.81264 .00394 L
.81445 .00394 L
.81638 .00394 L
.81824 .00394 L
.82022 .00394 L
.82212 .00394 L
.82395 .00394 L
.82444 .00394 L
.82489 .00394 L
Mistroke
.82502 .00394 L
.82508 .00394 L
.82515 .00394 L
.82518 .20076 L
.82522 .20076 L
.82529 .20076 L
.82542 .20076 L
.8259 .20076 L
.82685 .20076 L
.82735 .20076 L
.82763 .20076 L
.82776 .20076 L
.82782 .20076 L
.82785 .20076 L
.82788 .20076 L
.82795 .00394 L
.82801 .00394 L
.82813 .00394 L
.8284 .00394 L
.82888 .00394 L
.8298 .00394 L
.83179 .00394 L
.8337 .00394 L
.83555 .00394 L
.83751 .00394 L
.8394 .00394 L
.84121 .00394 L
.84315 .00394 L
.84501 .00394 L
.84699 .00394 L
.84889 .00394 L
.85073 .00394 L
.85268 .00394 L
.85456 .00394 L
.85655 .00394 L
.85848 .00394 L
.86033 .00394 L
.8623 .00394 L
.86419 .00394 L
.86601 .00394 L
.86796 .00394 L
.86982 .00394 L
.87181 .00394 L
.87372 .00394 L
.87556 .00394 L
.87752 .00394 L
.87843 .00394 L
.8789 .00394 L
.87916 .00394 L
.8794 .00394 L
Mistroke
.87947 .00394 L
.87953 .00394 L
.87956 .00394 L
.8796 .20076 L
.87966 .20076 L
.87994 .20076 L
.88044 .20076 L
.8809 .20076 L
.88141 .20076 L
.88164 .20076 L
.8819 .20076 L
.88202 .20076 L
.88214 .20076 L
.88225 .20076 L
.88231 .20076 L
.88236 .00394 L
.88242 .00394 L
.88249 .00394 L
.88262 .00394 L
.88285 .00394 L
.88337 .00394 L
.88534 .00394 L
.88724 .00394 L
.88907 .00394 L
.89101 .00394 L
.89288 .00394 L
.89487 .00394 L
.89678 .00394 L
.89863 .00394 L
.90059 .00394 L
.90247 .00394 L
.90429 .00394 L
.90622 .00394 L
.90808 .00394 L
.91006 .00394 L
.91196 .00394 L
.91379 .00394 L
.91574 .00394 L
.91762 .00394 L
.91962 .00394 L
.92154 .00394 L
.92339 .00394 L
.92535 .00394 L
.92725 .00394 L
.92907 .00394 L
.93101 .00394 L
.93288 .00394 L
.93336 .00394 L
.93362 .00394 L
.93376 .00394 L
Mistroke
.93383 .00394 L
.93389 .00394 L
.93395 .00394 L
.93399 .00394 L
.93402 .20076 L
.93405 .20076 L
.93409 .20076 L
.93416 .20076 L
.93439 .20076 L
.93486 .20076 L
.93535 .20076 L
.93588 .20076 L
.93613 .20076 L
.93638 .20076 L
.93661 .20076 L
.93667 .20076 L
.9367 .20076 L
.93673 .20076 L
.93679 .00394 L
.93685 .00394 L
.93868 .00394 L
.94064 .00394 L
.94252 .00394 L
.94451 .00394 L
.94644 .00394 L
.94829 .00394 L
.95026 .00394 L
.95216 .00394 L
.95398 .00394 L
.95592 .00394 L
.95779 .00394 L
.95874 .00394 L
.95978 .00394 L
.96026 .00394 L
.96052 .00394 L
.96077 .00394 L
.961 .00394 L
.96107 .00394 L
.96113 .00394 L
.96119 .00394 L
.96125 .39759 L
.96131 .39759 L
.96136 .39759 L
.96148 .39759 L
.96169 .39759 L
.96269 .39759 L
.96313 .39759 L
.96336 .39759 L
.96361 .39759 L
.96373 .39759 L
Mistroke
.9638 .39759 L
.96385 .39759 L
.9639 .39759 L
.96396 .00394 L
.96402 .00394 L
.96407 .00394 L
.96451 .00394 L
.96546 .00394 L
.96738 .00394 L
.96924 .00394 L
.97121 .00394 L
.97311 .00394 L
.97494 .00394 L
.97619 .00394 L
Mfstroke
0 0 1 r
.005 w
.02381 .00394 m
.02474 .00394 L
.02575 .00394 L
.0267 .00394 L
.02761 .00394 L
.02859 .00394 L
.02952 .00394 L
.03052 .00394 L
.03148 .00394 L
.0324 .00394 L
.03338 .00394 L
.03433 .00394 L
.03524 .00394 L
.03621 .00394 L
.03714 .00394 L
.03813 .00394 L
.03908 .00394 L
.04 .00394 L
.04098 .00394 L
.04192 .00394 L
.04292 .00394 L
.04388 .00394 L
.0448 .00394 L
.04579 .00394 L
.04674 .00394 L
.04765 .00394 L
.04862 .00394 L
.04956 .00394 L
.05055 .00394 L
.05151 .00394 L
.05243 .00394 L
.05341 .00394 L
.05435 .00394 L
.05526 .00394 L
.05622 .00394 L
.05715 .00394 L
.05814 .00394 L
.05909 .00394 L
.06001 .00394 L
.06098 .00394 L
.06192 .00394 L
.06292 .00394 L
.06388 .00394 L
.0648 .00394 L
.06579 .00394 L
.06673 .00394 L
.06764 .00394 L
.06861 .00394 L
.06954 .00394 L
.07054 .00394 L
Mistroke
.07149 .00394 L
.07241 .00394 L
.07339 .00394 L
.07433 .00394 L
.07533 .00394 L
.07629 .00394 L
.07722 .00394 L
.07821 .00394 L
.07916 .00394 L
.08007 .00394 L
.08104 .00394 L
.08198 .00394 L
.08297 .00394 L
.08393 .00394 L
.08485 .00394 L
.08584 .00394 L
.08678 .00394 L
.08769 .00394 L
.08866 .00394 L
.08959 .00394 L
.09058 .00394 L
.09153 .00394 L
.09245 .00394 L
.09342 .00394 L
.09436 .00394 L
.09536 .00394 L
.09632 .00394 L
.09725 .00394 L
.09823 .00394 L
.09918 .00394 L
.10009 .00394 L
.10106 .00394 L
.10199 .00394 L
.10299 .00394 L
.10394 .00394 L
.10486 .00394 L
.10584 .00394 L
.10678 .00394 L
.10769 .00394 L
.10866 .00394 L
.10958 .00394 L
.11057 .00394 L
.11152 .00394 L
.11244 .00394 L
.11341 .00394 L
.11435 .00394 L
.11535 .00394 L
.1163 .00394 L
.11723 .00394 L
.11821 .00394 L
Mistroke
.11916 .00394 L
.12007 .00394 L
.12103 .00394 L
.12197 .00394 L
.12296 .00394 L
.12391 .00394 L
.12483 .00394 L
.12581 .00394 L
.12675 .00394 L
.12775 .00394 L
.12871 .00394 L
.12964 .00394 L
.13062 .00394 L
.13157 .00394 L
.13248 .00394 L
.13345 .00394 L
.13439 .00394 L
.13538 .00394 L
.13634 .00394 L
.13726 .00394 L
.13824 .00394 L
.13919 .00394 L
.14009 .00394 L
.14106 .00394 L
.14199 .00394 L
.14298 .00394 L
.14393 .00394 L
.14485 .00394 L
.14582 .00394 L
.14676 .00394 L
.14776 .00394 L
.14872 .00394 L
.14964 .00394 L
.15063 .00394 L
.15158 .00394 L
.15249 .00394 L
.15346 .00394 L
.15439 .00394 L
.15538 .00394 L
.15634 .00394 L
.15726 .00394 L
.15823 .00394 L
.15918 .00394 L
.16018 .00394 L
.16114 .00394 L
.16207 .00394 L
.16306 .00394 L
.16401 .00394 L
.16492 .00394 L
.16589 .00394 L
Mistroke
.16683 .00394 L
.16782 .00394 L
.16878 .00394 L
.16971 .00394 L
.17069 .00394 L
.17163 .00394 L
.17254 .00394 L
.17351 .00394 L
.17444 .00394 L
.17543 .00394 L
.17638 .00394 L
.1773 .00394 L
.17828 .00394 L
.17922 .00394 L
.18022 .00394 L
.18118 .00394 L
.1821 .00394 L
.18309 .00394 L
.18404 .00394 L
.18495 .00394 L
.18592 .00394 L
.18685 .00394 L
.18785 .00394 L
.1888 .00394 L
.18972 .00394 L
.1907 .00394 L
.19165 .00394 L
.19255 .00394 L
.19352 .00394 L
.19445 .00394 L
.19544 .00394 L
.19639 .00394 L
.1973 .00394 L
.19828 .00394 L
.19922 .00394 L
.20021 .00394 L
.20117 .00394 L
.2021 .00394 L
.20308 .00394 L
.20403 .00394 L
.20494 .00394 L
.2059 .00394 L
.20684 .00394 L
.20783 .00394 L
.20878 .00394 L
.2097 .00394 L
.21068 .00394 L
.21162 .00394 L
.21262 .00394 L
.21358 .00394 L
Mistroke
.21451 .00394 L
.2155 .00394 L
.21645 .00394 L
.21736 .00394 L
.21833 .00394 L
.21927 .00394 L
.22026 .00394 L
.22122 .00394 L
.22214 .00394 L
.22312 .00394 L
.22407 .00394 L
.22497 .00394 L
.22594 .00394 L
.22687 .00394 L
.22786 .00394 L
.22881 .00394 L
.22973 .00394 L
.23071 .00394 L
.23164 .00394 L
.23264 .00394 L
.2336 .00394 L
.23453 .00394 L
.23551 .00394 L
.23646 .00394 L
.23737 .00394 L
.23834 .00394 L
.23928 .00394 L
.24027 .00394 L
.24122 .00394 L
.24214 .00394 L
.24312 .00394 L
.24406 .00394 L
.24497 .00394 L
.24594 .00394 L
.24686 .00394 L
.24785 .00394 L
.2488 .00394 L
.24972 .00394 L
.25069 .00394 L
.25163 .00394 L
.25262 .00394 L
.25358 .00394 L
.25451 .00394 L
.25549 .00394 L
.25643 .00394 L
.25734 .00394 L
.25831 .00394 L
.25924 .00394 L
.26023 .00394 L
.26119 .00394 L
Mistroke
.2621 .00394 L
.26308 .00394 L
.26402 .00394 L
.26502 .00394 L
.26598 .00394 L
.26691 .00394 L
.26789 .00394 L
.26884 .00394 L
.26976 .00394 L
.27073 .00394 L
.27166 .00394 L
.27266 .00394 L
.27361 .00394 L
.27453 .00394 L
.27551 .00394 L
.27646 .00394 L
.27736 .00394 L
.27833 .00394 L
.27926 .00394 L
.28025 .00394 L
.2812 .00394 L
.28212 .00394 L
.28309 .00394 L
.28403 .00394 L
.28503 .00394 L
.28599 .00394 L
.28691 .00394 L
.28789 .00394 L
.28884 .00394 L
.28975 .00394 L
.29072 .00394 L
.29165 .00394 L
.29265 .00394 L
.2936 .00394 L
.29452 .00394 L
.2955 .00394 L
.29644 .00394 L
.29744 .00394 L
.2984 .00394 L
.29933 .00394 L
.30032 .00394 L
.30127 .00394 L
.30218 .00394 L
.30315 .00394 L
.30409 .00394 L
.30509 .00394 L
.30604 .00394 L
.30697 .00394 L
.30795 .00394 L
.30889 .00394 L
Mistroke
.3098 .00394 L
.31077 .00394 L
.3117 .00394 L
.31269 .00394 L
.31364 .00394 L
.31456 .00394 L
.31554 .00394 L
.31647 .00394 L
.31747 .00394 L
.31844 .00394 L
.31936 .00394 L
.32035 .00394 L
.32129 .00394 L
.3222 .00394 L
.32318 .00394 L
.32411 .00394 L
.3251 .00394 L
.32606 .00394 L
.32698 .00394 L
.32796 .00394 L
.3289 .00394 L
.32981 .00394 L
.33077 .00394 L
.3317 .00394 L
.33269 .00394 L
.33364 .00394 L
.33456 .00394 L
.33553 .00394 L
.33647 .00394 L
.33746 .00394 L
.33842 .00394 L
.33935 .00394 L
.34033 .00394 L
.34128 .00394 L
.34218 .00394 L
.34315 .00394 L
.34409 .00394 L
.34508 .00394 L
.34603 .00394 L
.34695 .00394 L
.34793 .00394 L
.34887 .00394 L
.34987 .00394 L
.35083 .00394 L
.35176 .00394 L
.35274 .00394 L
.35369 .00394 L
.3546 .00394 L
.35558 .00394 L
.35651 .00394 L
Mistroke
.35751 .00394 L
.35846 .00394 L
.35939 .00394 L
.36037 .00394 L
.36131 .00394 L
.36222 .00394 L
.36318 .00394 L
.36411 .00394 L
.3651 .00394 L
.36606 .00394 L
.36697 .00394 L
.36795 .00394 L
.36889 .00394 L
.36988 .00394 L
.37084 .00394 L
.37177 .00394 L
.37275 .00394 L
.3737 .00394 L
.37461 .00394 L
.37558 .00394 L
.37651 .00394 L
.37751 .00394 L
.37846 .00394 L
.37938 .00394 L
.38036 .00394 L
.3813 .00394 L
.3823 .00394 L
.38327 .00394 L
.3842 .00394 L
.38518 .00394 L
.38613 .00394 L
.38705 .00394 L
.38802 .00394 L
.38896 .00394 L
.38943 .00394 L
.38969 .00394 L
.38982 .00394 L
.38995 .00394 L
.39001 .00394 L
.39004 .00394 L
.39007 .00394 L
.3901 .39759 L
.39011 .39759 L
.39013 .39759 L
.39019 .39759 L
.39045 .39759 L
.39091 .39759 L
.39139 .39759 L
.39164 .39759 L
.39191 .39759 L
Mistroke
.39203 .39759 L
.39215 .39759 L
.39219 .39759 L
.3922 .39759 L
.39222 .39759 L
.39225 .00394 L
.39227 .00394 L
.39229 .00394 L
.39241 .00394 L
.39287 .00394 L
.39378 .00394 L
.39475 .00394 L
.39568 .00394 L
.39666 .00394 L
.39762 .00394 L
.39853 .00394 L
.39951 .00394 L
.40044 .00394 L
.40144 .00394 L
.4024 .00394 L
.40332 .00394 L
.40431 .00394 L
.40525 .00394 L
.40616 .00394 L
.40713 .00394 L
.40807 .00394 L
.40906 .00394 L
.41001 .00394 L
.41093 .00394 L
.41191 .00394 L
.41285 .00394 L
.41385 .00394 L
.41481 .00394 L
.41574 .00394 L
.41673 .00394 L
.41768 .00394 L
.41859 .00394 L
.41956 .00394 L
.4205 .00394 L
.42149 .00394 L
.42245 .00394 L
.42337 .00394 L
.42435 .00394 L
.4253 .00394 L
.42621 .00394 L
.42717 .00394 L
.4281 .00394 L
.42909 .00394 L
.43005 .00394 L
.43096 .00394 L
Mistroke
.43194 .00394 L
.43288 .00394 L
.43388 .00394 L
.43484 .00394 L
.43576 .00394 L
.43675 .00394 L
.4377 .00394 L
.43861 .00394 L
.43958 .00394 L
.44051 .00394 L
.4415 .00394 L
.44246 .00394 L
.44338 .00394 L
.44384 .00394 L
.44409 .00394 L
.44422 .00394 L
.44436 .00394 L
.44442 .00394 L
.44445 .00394 L
.44448 .00394 L
.4445 .20076 L
.44452 .20076 L
.44455 .20076 L
.44461 .20076 L
.44484 .20076 L
.4453 .20076 L
.44577 .20076 L
.44602 .20076 L
.44628 .20076 L
.44641 .20076 L
.44654 .20076 L
.44659 .20076 L
.44662 .20076 L
.44665 .20076 L
.44667 .20076 L
.44668 .00394 L
.44671 .00394 L
.44677 .00394 L
.44723 .00394 L
.44821 .00394 L
.44916 .00394 L
.45008 .00394 L
.45105 .00394 L
.45198 .00394 L
.45298 .00394 L
.45393 .00394 L
.45486 .00394 L
.45584 .00394 L
.45678 .00394 L
.45769 .00394 L
Mistroke
.45865 .00394 L
.45958 .00394 L
.46057 .00394 L
.46152 .00394 L
.46244 .00394 L
.46341 .00394 L
.46435 .00394 L
.46535 .00394 L
.46631 .00394 L
.46724 .00394 L
.46822 .00394 L
.46917 .00394 L
.47008 .00394 L
.47105 .00394 L
.47198 .00394 L
.47297 .00394 L
.47393 .00394 L
.47485 .00394 L
.47582 .00394 L
.47677 .00394 L
.47777 .00394 L
.47873 .00394 L
.47966 .00394 L
.48064 .00394 L
.48159 .00394 L
.48251 .00394 L
.48348 .00394 L
.48442 .00394 L
.48541 .00394 L
.48637 .00394 L
.48729 .00394 L
.48828 .00394 L
.48922 .00394 L
.49013 .00394 L
.4911 .00394 L
.49203 .00394 L
.49302 .00394 L
.49397 .00394 L
.49489 .00394 L
.49586 .00394 L
.4968 .00394 L
.4978 .00394 L
.4983 .00394 L
.49852 .00394 L
.49864 .00394 L
.49876 .00394 L
.49883 .00394 L
.49886 .00394 L
.49889 .00394 L
.49891 .20076 L
Mistroke
.49894 .20076 L
.499 .20076 L
.49921 .20076 L
.49969 .20076 L
.5006 .20076 L
.50082 .20076 L
.50095 .20076 L
.50101 .20076 L
.50103 .20076 L
.50106 .20076 L
.50109 .00394 L
.50112 .00394 L
.50119 .00394 L
.50132 .00394 L
.50156 .00394 L
.50255 .00394 L
.50349 .00394 L
.5044 .00394 L
.50537 .00394 L
.5063 .00394 L
.50729 .00394 L
.50825 .00394 L
.50917 .00394 L
.51014 .00394 L
.51108 .00394 L
.51208 .00394 L
.51305 .00394 L
.51397 .00394 L
.51496 .00394 L
.51591 .00394 L
.51682 .00394 L
.5178 .00394 L
.51873 .00394 L
.51973 .00394 L
.52068 .00394 L
.52161 .00394 L
.52259 .00394 L
.52353 .00394 L
.52444 .00394 L
.5254 .00394 L
.52633 .00394 L
.52732 .00394 L
.52828 .00394 L
.52919 .00394 L
.53017 .00394 L
.53111 .00394 L
.53211 .00394 L
.53307 .00394 L
.53399 .00394 L
.53498 .00394 L
Mistroke
.53592 .00394 L
.53683 .00394 L
.5378 .00394 L
.53874 .00394 L
.53973 .00394 L
.54069 .00394 L
.54161 .00394 L
.54258 .00394 L
.54353 .00394 L
.54443 .00394 L
.5454 .00394 L
.54632 .00394 L
.54731 .00394 L
.54826 .00394 L
.54918 .00394 L
.55015 .00394 L
.55109 .00394 L
.55208 .00394 L
.55258 .00394 L
.5528 .00394 L
.55304 .00394 L
.55315 .00394 L
.55322 .00394 L
.55327 .00394 L
.5533 .00394 L
.55333 .00394 L
.55336 .20076 L
.55339 .20076 L
.55349 .20076 L
.55397 .20076 L
.55445 .20076 L
.55496 .20076 L
.55521 .20076 L
.55534 .20076 L
.55541 .20076 L
.55543 .20076 L
.55547 .20076 L
.55549 .20076 L
.55552 .00394 L
.55555 .00394 L
.55557 .00394 L
.55569 .00394 L
.55593 .00394 L
.55683 .00394 L
.5578 .00394 L
.55873 .00394 L
.55972 .00394 L
.56067 .00394 L
.56159 .00394 L
.56256 .00394 L
Mistroke
.5635 .00394 L
.56449 .00394 L
.56546 .00394 L
.56638 .00394 L
.56736 .00394 L
.56831 .00394 L
.56922 .00394 L
.57019 .00394 L
.57112 .00394 L
.57211 .00394 L
.57307 .00394 L
.57399 .00394 L
.57497 .00394 L
.57591 .00394 L
.57691 .00394 L
.57787 .00394 L
.5788 .00394 L
.57978 .00394 L
.58073 .00394 L
.58165 .00394 L
.58262 .00394 L
.58356 .00394 L
.58455 .00394 L
.58551 .00394 L
.58643 .00394 L
.58741 .00394 L
.58836 .00394 L
.58927 .00394 L
.59023 .00394 L
.59116 .00394 L
.59215 .00394 L
.59311 .00394 L
.59402 .00394 L
.595 .00394 L
.59594 .00394 L
.59694 .00394 L
.5979 .00394 L
.59882 .00394 L
.59981 .00394 L
.60076 .00394 L
.60167 .00394 L
.60264 .00394 L
.60357 .00394 L
.60457 .00394 L
.60552 .00394 L
.60644 .00394 L
.60691 .00394 L
.60716 .00394 L
.60742 .00394 L
.60755 .00394 L
Mistroke
.60761 .00394 L
.60768 .00394 L
.6077 .00394 L
.60773 .00394 L
.60776 .39759 L
.60779 .39759 L
.60791 .39759 L
.60836 .39759 L
.60929 .39759 L
.60953 .39759 L
.60976 .39759 L
.60982 .39759 L
.60988 .39759 L
.60991 .39759 L
.60993 .39759 L
.60995 .00394 L
.60997 .00394 L
.61001 .00394 L
.61027 .00394 L
.61127 .00394 L
.61223 .00394 L
.61316 .00394 L
.61415 .00394 L
.61509 .00394 L
.61601 .00394 L
.61698 .00394 L
.61791 .00394 L
.61891 .00394 L
.61987 .00394 L
.62079 .00394 L
.62177 .00394 L
.62271 .00394 L
.62362 .00394 L
.62459 .00394 L
.62552 .00394 L
.6265 .00394 L
.62746 .00394 L
.62837 .00394 L
.62935 .00394 L
.63029 .00394 L
.63128 .00394 L
.63225 .00394 L
.63317 .00394 L
.63415 .00394 L
.6351 .00394 L
.63601 .00394 L
.63698 .00394 L
.63791 .00394 L
.63891 .00394 L
.63986 .00394 L
Mistroke
.64078 .00394 L
.64176 .00394 L
.6427 .00394 L
.6437 .00394 L
.64467 .00394 L
.64559 .00394 L
.64658 .00394 L
.64753 .00394 L
.64845 .00394 L
.64942 .00394 L
.65036 .00394 L
.65135 .00394 L
.65231 .00394 L
.65323 .00394 L
.65421 .00394 L
.65516 .00394 L
.65607 .00394 L
.65704 .00394 L
.65797 .00394 L
.65896 .00394 L
.65991 .00394 L
.66083 .00394 L
.6618 .00394 L
.66274 .00394 L
.66374 .00394 L
.66471 .00394 L
.66563 .00394 L
.66662 .00394 L
.66756 .00394 L
.66848 .00394 L
.66945 .00394 L
.67038 .00394 L
.67138 .00394 L
.67233 .00394 L
.67325 .00394 L
.67423 .00394 L
.67518 .00394 L
.67608 .00394 L
.67705 .00394 L
.67798 .00394 L
.67897 .00394 L
.67992 .00394 L
.68083 .00394 L
.68181 .00394 L
.68274 .00394 L
.68374 .00394 L
.6847 .00394 L
.68563 .00394 L
.68661 .00394 L
.68755 .00394 L
Mistroke
.68846 .00394 L
.68943 .00394 L
.69037 .00394 L
.69136 .00394 L
.69231 .00394 L
.69323 .00394 L
.69421 .00394 L
.69515 .00394 L
.69615 .00394 L
.69711 .00394 L
.69804 .00394 L
.69903 .00394 L
.69998 .00394 L
.70089 .00394 L
.70186 .00394 L
.7028 .00394 L
.70379 .00394 L
.70475 .00394 L
.70567 .00394 L
.70665 .00394 L
.7076 .00394 L
.7085 .00394 L
.70947 .00394 L
.7104 .00394 L
.71139 .00394 L
.71234 .00394 L
.71326 .00394 L
.71424 .00394 L
.71518 .00394 L
.71617 .00394 L
.71714 .00394 L
.71806 .00394 L
.71904 .00394 L
.71999 .00394 L
.7209 .00394 L
.72187 .00394 L
.72281 .00394 L
.7238 .00394 L
.72476 .00394 L
.72568 .00394 L
.72665 .00394 L
.7276 .00394 L
.7285 .00394 L
.72947 .00394 L
.7304 .00394 L
.73138 .00394 L
.73233 .00394 L
.73325 .00394 L
.73422 .00394 L
.73516 .00394 L
Mistroke
.73616 .00394 L
.73711 .00394 L
.73804 .00394 L
.73902 .00394 L
.73997 .00394 L
.74087 .00394 L
.74184 .00394 L
.74277 .00394 L
.74377 .00394 L
.74472 .00394 L
.74564 .00394 L
.74661 .00394 L
.74755 .00394 L
.74855 .00394 L
.74952 .00394 L
.75044 .00394 L
.75143 .00394 L
.75238 .00394 L
.75329 .00394 L
.75426 .00394 L
.7552 .00394 L
.75619 .00394 L
.75715 .00394 L
.75807 .00394 L
.75905 .00394 L
.75999 .00394 L
.7609 .00394 L
.76187 .00394 L
.76279 .00394 L
.76378 .00394 L
.76474 .00394 L
.76565 .00394 L
.76663 .00394 L
.76756 .00394 L
.76856 .00394 L
.76952 .00394 L
.77045 .00394 L
.77143 .00394 L
.77238 .00394 L
.77329 .00394 L
.77426 .00394 L
.77519 .00394 L
.77618 .00394 L
.77714 .00394 L
.77806 .00394 L
.77903 .00394 L
.77998 .00394 L
.78098 .00394 L
.78194 .00394 L
.78287 .00394 L
Mistroke
.78385 .00394 L
.7848 .00394 L
.78572 .00394 L
.78669 .00394 L
.78763 .00394 L
.78862 .00394 L
.78958 .00394 L
.7905 .00394 L
.79148 .00394 L
.79243 .00394 L
.79334 .00394 L
.79431 .00394 L
.79524 .00394 L
.79623 .00394 L
.79718 .00394 L
.7981 .00394 L
.79907 .00394 L
.80001 .00394 L
.80101 .00394 L
.80197 .00394 L
.8029 .00394 L
.80388 .00394 L
.80483 .00394 L
.80574 .00394 L
.80671 .00394 L
.80765 .00394 L
.80864 .00394 L
.8096 .00394 L
.81052 .00394 L
.8115 .00394 L
.81244 .00394 L
.81335 .00394 L
.81431 .00394 L
.81524 .00394 L
.81623 .00394 L
.81718 .00394 L
.81809 .00394 L
.81907 .00394 L
.82001 .00394 L
.821 .00394 L
.82196 .00394 L
.82289 .00394 L
.82387 .00394 L
.82481 .00394 L
.82572 .00394 L
.82669 .00394 L
.82762 .00394 L
.82862 .00394 L
.82957 .00394 L
.83049 .00394 L
Mistroke
.83147 .00394 L
.83241 .00394 L
.83341 .00394 L
.83437 .00394 L
.8353 .00394 L
.83628 .00394 L
.83723 .00394 L
.83815 .00394 L
.83912 .00394 L
.84005 .00394 L
.84105 .00394 L
.842 .00394 L
.84293 .00394 L
.84391 .00394 L
.84485 .00394 L
.84576 .00394 L
.84673 .00394 L
.84766 .00394 L
.84864 .00394 L
.8496 .00394 L
.85051 .00394 L
.85149 .00394 L
.85243 .00394 L
.85342 .00394 L
.85439 .00394 L
.85531 .00394 L
.85629 .00394 L
.85724 .00394 L
.85815 .00394 L
.85912 .00394 L
.86006 .00394 L
.86105 .00394 L
.862 .00394 L
.86292 .00394 L
.8639 .00394 L
.86484 .00394 L
.86585 .00394 L
.86681 .00394 L
.86774 .00394 L
.86873 .00394 L
.86968 .00394 L
.87059 .00394 L
.87156 .00394 L
.8725 .00394 L
.8735 .00394 L
.87445 .00394 L
.87538 .00394 L
.87636 .00394 L
.8773 .00394 L
.87821 .00394 L
Mistroke
.87918 .00394 L
.88011 .00394 L
.8811 .00394 L
.88206 .00394 L
.88297 .00394 L
.88395 .00394 L
.88489 .00394 L
.88589 .00394 L
.88685 .00394 L
.88778 .00394 L
.88876 .00394 L
.88971 .00394 L
.89062 .00394 L
.8916 .00394 L
.89253 .00394 L
.89352 .00394 L
.89448 .00394 L
.8954 .00394 L
.89638 .00394 L
.89732 .00394 L
.89823 .00394 L
.8992 .00394 L
.90013 .00394 L
.90112 .00394 L
.90207 .00394 L
.90298 .00394 L
.90396 .00394 L
.9049 .00394 L
.90589 .00394 L
.90685 .00394 L
.90778 .00394 L
.90876 .00394 L
.90971 .00394 L
.91062 .00394 L
.91159 .00394 L
.91252 .00394 L
.91351 .00394 L
.91446 .00394 L
.91538 .00394 L
.91636 .00394 L
.9173 .00394 L
.9183 .00394 L
.91927 .00394 L
.92019 .00394 L
.92118 .00394 L
.92213 .00394 L
.92304 .00394 L
.92402 .00394 L
.92495 .00394 L
.92595 .00394 L
Mistroke
.9269 .00394 L
.92783 .00394 L
.92881 .00394 L
.92975 .00394 L
.93066 .00394 L
.93163 .00394 L
.93256 .00394 L
.93355 .00394 L
.9345 .00394 L
.93542 .00394 L
.93639 .00394 L
.93733 .00394 L
.93833 .00394 L
.93929 .00394 L
.94022 .00394 L
.9412 .00394 L
.94215 .00394 L
.94306 .00394 L
.94403 .00394 L
.94497 .00394 L
.94596 .00394 L
.94691 .00394 L
.94783 .00394 L
.94881 .00394 L
.94976 .00394 L
.95066 .00394 L
.95163 .00394 L
.95256 .00394 L
.95354 .00394 L
.95449 .00394 L
.95541 .00394 L
.95638 .00394 L
.95732 .00394 L
.95832 .00394 L
.95928 .00394 L
.9602 .00394 L
.96118 .00394 L
.96213 .00394 L
.96304 .00394 L
.96401 .00394 L
.96494 .00394 L
.96593 .00394 L
.96688 .00394 L
.9678 .00394 L
.96878 .00394 L
.96972 .00394 L
.97072 .00394 L
.97168 .00394 L
.97261 .00394 L
.97359 .00394 L
Mistroke
.97454 .00394 L
.97545 .00394 L
.97619 .00394 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.196383 0.0581337 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -12 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .31265 -6 -4.5 ]
[-0.0125 .31265 0 4.5 ]
[-0.0125 .42892 -6 -4.5 ]
[-0.0125 .42892 0 4.5 ]
[-0.0125 .54519 -6 -4.5 ]
[-0.0125 .54519 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(1)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(2)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(3)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(4)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(-2)] -0.0125 .08012 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(0)] -0.0125 .19638 1 0 Mshowa
0 .31265 m
.00625 .31265 L
s
[(2)] -0.0125 .31265 1 0 Mshowa
0 .42892 m
.00625 .42892 L
s
[(4)] -0.0125 .42892 1 0 Mshowa
0 .54519 m
.00625 .54519 L
s
[(6)] -0.0125 .54519 1 0 Mshowa
.125 Mabswid
0 .10918 m
.00375 .10918 L
s
0 .13825 m
.00375 .13825 L
s
0 .16732 m
.00375 .16732 L
s
0 .22545 m
.00375 .22545 L
s
0 .25452 m
.00375 .25452 L
s
0 .28358 m
.00375 .28358 L
s
0 .34172 m
.00375 .34172 L
s
0 .37078 m
.00375 .37078 L
s
0 .39985 m
.00375 .39985 L
s
0 .45798 m
.00375 .45798 L
s
0 .48705 m
.00375 .48705 L
s
0 .51612 m
.00375 .51612 L
s
0 .05105 m
.00375 .05105 L
s
0 .02198 m
.00375 .02198 L
s
0 .57425 m
.00375 .57425 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .31265 m
1 .31265 L
s
.99375 .42892 m
1 .42892 L
s
.99375 .54519 m
1 .54519 L
s
.125 Mabswid
.99625 .10918 m
1 .10918 L
s
.99625 .13825 m
1 .13825 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .22545 m
1 .22545 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .28358 m
1 .28358 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .37078 m
1 .37078 L
s
.99625 .39985 m
1 .39985 L
s
.99625 .45798 m
1 .45798 L
s
.99625 .48705 m
1 .48705 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .02198 m
1 .02198 L
s
.99625 .57425 m
1 .57425 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .19638 m
1 .19638 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.02381 .60332 m
.02409 .60327 L
.02435 .60315 L
.02465 .60291 L
.02494 .6026 L
.02544 .60181 L
.02599 .60063 L
.02659 .59894 L
.02722 .5967 L
.02837 .59157 L
.03066 .57704 L
.03318 .55482 L
.03845 .48973 L
.04339 .4114 L
.05279 .24379 L
.05757 .16395 L
.06278 .0915 L
.0652 .06507 L
.06778 .04268 L
.06903 .0341 L
.07021 .02743 L
.07126 .02263 L
.07241 .01871 L
.07298 .01724 L
.0733 .01658 L
.0736 .01604 L
.07388 .01562 L
.07418 .01526 L
.07446 .01501 L
.07471 .01485 L
.07501 .01474 L
.0753 .01472 L
.07561 .01479 L
.07578 .01487 L
.07594 .01497 L
.07624 .01523 L
.07657 .01561 L
.07724 .01672 L
.07791 .01826 L
.07852 .02003 L
.07989 .02524 L
.08115 .03157 L
.08235 .03879 L
.0872 .07912 L
.09167 .12835 L
.10123 .24727 L
.10603 .30069 L
.11041 .33874 L
.11157 .34657 L
.11283 .35393 L
Mistroke
.11404 .35977 L
.11513 .36402 L
.11574 .36596 L
.1164 .36769 L
.1171 .3691 L
.11741 .3696 L
.11775 .37004 L
.11807 .37036 L
.11837 .37058 L
.11869 .37073 L
.11886 .37077 L
.11902 .37078 L
.11931 .37075 L
.11962 .37064 L
.11992 .37045 L
.12019 .37021 L
.12048 .36988 L
.12078 .36946 L
.12132 .36851 L
.1219 .3672 L
.12253 .36544 L
.12367 .36141 L
.12473 .35669 L
.12714 .34252 L
.12972 .32259 L
.13491 .27024 L
.1398 .21108 L
.14913 .0974 L
.15396 .05168 L
.15639 .03472 L
.15778 .02724 L
.15907 .02176 L
.16028 .01801 L
.16096 .01651 L
.16129 .01595 L
.1616 .01552 L
.16186 .01522 L
.16215 .01497 L
.16247 .0148 L
.16276 .01472 L
.16305 .01473 L
.16336 .01484 L
.16352 .01493 L
.16369 .01505 L
.16399 .01535 L
.1643 .01574 L
.16457 .01618 L
.1652 .01746 L
.16576 .01892 L
.16635 .02081 L
Mistroke
.16737 .02492 L
.16849 .03065 L
.17095 .04758 L
.1732 .06811 L
.17826 .13016 L
.18789 .29 L
.19716 .45192 L
.20233 .52571 L
.20477 .5533 L
.20702 .57375 L
.20936 .58964 L
.2106 .59562 L
.21123 .59802 L
.2119 .60009 L
.2125 .6015 L
.21304 .60243 L
.2133 .60277 L
.21358 .60304 L
.21385 .60321 L
.2141 .6033 L
.21438 .60331 L
.21465 .60324 L
.21495 .60307 L
.21527 .60277 L
.21558 .60236 L
.21591 .60181 L
.21651 .60052 L
.21713 .59872 L
.21772 .59663 L
.21882 .59168 L
.22001 .58487 L
.2213 .5758 L
.22575 .53171 L
.23057 .46515 L
.23567 .38002 L
.24486 .21607 L
.24998 .13491 L
.25465 .0757 L
.25696 .05313 L
.25818 .04321 L
.25948 .03424 L
.26073 .02719 L
.26186 .02216 L
.26241 .02019 L
.263 .0184 L
.26356 .01703 L
.26406 .01606 L
.26434 .01564 L
.26464 .01528 L
.26496 .01499 L
Mistroke
.26526 .01481 L
.26554 .01473 L
.26584 .01472 L
.2661 .01479 L
.26638 .01494 L
.26655 .01507 L
.26671 .01521 L
.26701 .01556 L
.26769 .01665 L
.26827 .01795 L
.26891 .01975 L
.27019 .0245 L
.27156 .03118 L
.27402 .04717 L
.27921 .09495 L
.2841 .15207 L
.29344 .26771 L
.29818 .31668 L
.30087 .33859 L
.30216 .34728 L
.30338 .35432 L
.30454 .35988 L
.30579 .36466 L
.30635 .36634 L
.30694 .36783 L
.30749 .36896 L
.308 .36975 L
.30828 .3701 L
.30858 .37039 L
.30888 .3706 L
.30905 .37069 L
.30921 .37074 L
.3095 .37078 L
.30976 .37076 L
.31006 .37065 L
.31035 .37048 L
.31067 .37021 L
.311 .36982 L
.3116 .36888 L
.31224 .36752 L
.31295 .36561 L
.31421 .36114 L
.31541 .35565 L
.31766 .34223 L
.32008 .32358 L
.32273 .29887 L
.33259 .18173 L
.33715 .12531 L
.34208 .07219 L
.34479 .04892 L
Mistroke
.34598 .04039 L
.34728 .03232 L
.34843 .02639 L
.34966 .02133 L
.35034 .01913 L
.35096 .01751 L
.35159 .01624 L
.35187 .01579 L
.35217 .01539 L
.35247 .01509 L
.35275 .01489 L
.35301 .01477 L
.35329 .01472 L
.35359 .01475 L
.35388 .01486 L
.35419 .01507 L
.35436 .01523 L
.35452 .01541 L
.35513 .01632 L
.35548 .01701 L
.3558 .01775 L
.35701 .02147 L
.35804 .02584 L
.35918 .03188 L
.36148 .04798 L
.36394 .07087 L
.3662 .09647 L
.37127 .16804 L
.38091 .33603 L
.39019 .49078 L
.39498 .55056 L
.3974 .57301 L
.3987 .58265 L
.40007 .59088 L
.40124 .59627 L
.40185 .59851 L
.40251 .60044 L
.40282 .60118 L
.40312 .60178 L
.40341 .60227 L
.40367 .60264 L
.40392 .60292 L
.40419 .60313 L
.40446 .60327 L
.40475 .60332 L
.40491 .60331 L
.40509 .60326 L
.40541 .60308 L
.40572 .6028 L
.40601 .60243 L
Mistroke
.40635 .60188 L
.40666 .60126 L
.40736 .59948 L
.40797 .59749 L
.40862 .59488 L
.40981 .58896 L
.41211 .57312 L
.41464 .54953 L
.41975 .48471 L
.42955 .31903 L
.43898 .15677 L
.44145 .12088 L
.44413 .08679 L
.44645 .06212 L
.44901 .04059 L
.4502 .03272 L
.45149 .02582 L
.4527 .02082 L
.45381 .01754 L
.45442 .01626 L
.45472 .01579 L
.45499 .01542 L
.45515 .01525 L
.45532 .01508 L
.45562 .01487 L
.45579 .01479 L
.45597 .01474 L
.45612 .01472 L
.45629 .01472 L
.45646 .01476 L
.45663 .01482 L
.45694 .015 L
.45711 .01515 L
.45727 .01531 L
.45764 .01577 L
.45825 .01683 L
.4589 .01835 L
.4602 .0226 L
.4614 .02787 L
.4641 .04428 L
.46648 .06342 L
.469 .08767 L
.47822 .19798 L
.48335 .26118 L
.48803 .31092 L
.49036 .33113 L
.49289 .34882 L
.49404 .3553 L
.49527 .36097 L
.49632 .36482 L
Mistroke
.49748 .36797 L
.49808 .36915 L
.4984 .36965 L
.49874 .37008 L
.49906 .37039 L
.49936 .3706 L
.49965 .37073 L
.49993 .37078 L
.5002 .37077 L
.50049 .37068 L
.50074 .37054 L
.50101 .37033 L
.5013 .37003 L
.50161 .36963 L
.50218 .36869 L
.50283 .36725 L
.50354 .36527 L
.50482 .36058 L
.50724 .34807 L
.50951 .33214 L
.51203 .31037 L
.51712 .25564 L
.52686 .13451 L
.53133 .08427 L
.53387 .06032 L
.53623 .04192 L
.53858 .02797 L
.53989 .02224 L
.54109 .01839 L
.54174 .01684 L
.54235 .01579 L
.54266 .01538 L
.54301 .01504 L
.54319 .01491 L
.54337 .01481 L
.54355 .01475 L
.54371 .01472 L
.54403 .01474 L
.54432 .01484 L
.54449 .01494 L
.54465 .01506 L
.54499 .0154 L
.54529 .0158 L
.54561 .01633 L
.5462 .01756 L
.54678 .01911 L
.54739 .02114 L
.54851 .02578 L
.54983 .03293 L
.55104 .04095 L
Mistroke
.55366 .06324 L
.55615 .09009 L
.56544 .22957 L
.57534 .40593 L
.58025 .48472 L
.58266 .51787 L
.58486 .5442 L
.58697 .56528 L
.58927 .5833 L
.59047 .59048 L
.59159 .59576 L
.59219 .59806 L
.59276 .59984 L
.59342 .60145 L
.59371 .60199 L
.59402 .60248 L
.59433 .60284 L
.5946 .60309 L
.59488 .60325 L
.59515 .60331 L
.59545 .60329 L
.59574 .60318 L
.59605 .60294 L
.59622 .60277 L
.59638 .60257 L
.597 .60155 L
.59735 .60079 L
.59767 .59996 L
.59888 .59581 L
.59992 .59094 L
.60106 .58426 L
.60335 .56664 L
.60584 .54171 L
.6081 .51423 L
.61317 .43891 L
.62285 .26805 L
.63216 .11766 L
.63697 .06173 L
.6394 .04126 L
.64077 .0322 L
.64207 .02532 L
.64324 .02058 L
.64391 .01851 L
.64453 .01699 L
.64482 .01641 L
.6451 .01593 L
.64535 .01557 L
.64561 .01526 L
.6459 .015 L
.64617 .01483 L
Mistroke
.64646 .01473 L
.64677 .01472 L
.64694 .01475 L
.64711 .01482 L
.64728 .01491 L
.64743 .01502 L
.64773 .01528 L
.64804 .01566 L
.64868 .01673 L
.64939 .01839 L
.65065 .02249 L
.65183 .02766 L
.65422 .04173 L
.65673 .06136 L
.66121 .10646 L
.67045 .22014 L
.6756 .28122 L
.68028 .32665 L
.68262 .34411 L
.68385 .35167 L
.68515 .35836 L
.68629 .36307 L
.68689 .36512 L
.68754 .36698 L
.68814 .36836 L
.68868 .36936 L
.68894 .36974 L
.68923 .37009 L
.68948 .37034 L
.68975 .37055 L
.6899 .37064 L
.69007 .37071 L
.69037 .37078 L
.69053 .37078 L
.69071 .37076 L
.69088 .37071 L
.69104 .37064 L
.69134 .37046 L
.69151 .37031 L
.69166 .37016 L
.69225 .36939 L
.69278 .36845 L
.69335 .36713 L
.69452 .36358 L
.69579 .35843 L
.69715 .35142 L
.69961 .33506 L
.70448 .29062 L
.7096 .23143 L
.71885 .11665 L
Mistroke
.7215 .08744 L
.72401 .0633 L
.72644 .04377 L
.72751 .03661 L
.72869 .02983 L
.72976 .02471 L
.7309 .02035 L
.73153 .01846 L
.73211 .01707 L
.73269 .01599 L
.73297 .01558 L
.73324 .01527 L
.73352 .01501 L
.73383 .01482 L
.73414 .01473 L
.73431 .01472 L
.73446 .01473 L
.73473 .01481 L
.73502 .01497 L
.73532 .01524 L
.7356 .01556 L
.73625 .01663 L
.73684 .01797 L
.73752 .01995 L
.73817 .02226 L
.74052 .03423 L
.74171 .04236 L
.74301 .05288 L
.74748 .1006 L
.75219 .16762 L
.75725 .25296 L
.76725 .4302 L
.77225 .50611 L
.77468 .53673 L
.77688 .56004 L
.77919 .57943 L
.78025 .58648 L
.78136 .59262 L
.78194 .59523 L
.78256 .59768 L
.78314 .59954 L
.78366 .60092 L
.78428 .60215 L
.78462 .60264 L
.78478 .60282 L
.78495 .60298 L
.78524 .60319 L
.78552 .6033 L
.78582 .60331 L
.78598 .60328 L
Mistroke
.78614 .60321 L
.78643 .60303 L
.78673 .60273 L
.78702 .60235 L
.78728 .60192 L
.78792 .60054 L
.78853 .59882 L
.78973 .59417 L
.79104 .58733 L
.79337 .57056 L
.79553 .55024 L
.80008 .4937 L
.80508 .41503 L
.81486 .24079 L
.81937 .16554 L
.82428 .09644 L
.82695 .06664 L
.82942 .04468 L
.83178 .02917 L
.8331 .02292 L
.83367 .02076 L
.83429 .01877 L
.83486 .0173 L
.83548 .01609 L
.83582 .01558 L
.83613 .01522 L
.83644 .01496 L
.83673 .0148 L
.837 .01472 L
.83729 .01473 L
.83753 .01479 L
.8378 .01494 L
.83809 .01517 L
.8384 .01552 L
.83897 .01638 L
.83961 .01775 L
.84032 .01969 L
.84161 .02443 L
.84286 .03047 L
.84402 .03728 L
.84899 .07799 L
.8535 .12742 L
.86321 .24822 L
.86766 .29799 L
.87019 .32185 L
.87255 .34042 L
.87488 .35471 L
.87619 .36083 L
.87738 .36517 L
.87799 .36692 L
Mistroke
.87864 .36842 L
.87898 .36906 L
.87935 .36964 L
.87969 .37008 L
.88 .37039 L
.8803 .3706 L
.88062 .37074 L
.88094 .37078 L
.88112 .37077 L
.88129 .37073 L
.88159 .3706 L
.88187 .37041 L
.88219 .37011 L
.88249 .36974 L
.88307 .36881 L
.88361 .36767 L
.88484 .36412 L
.88605 .35942 L
.88734 .35303 L
.88967 .33812 L
.89181 .32102 L
.90144 .21431 L
.91071 .10096 L
.91549 .05473 L
.91816 .03559 L
.91931 .02909 L
.92057 .02329 L
.92176 .01917 L
.9224 .01747 L
.92301 .01625 L
.9233 .01579 L
.92357 .01543 L
.92382 .01516 L
.92409 .01495 L
.92438 .01479 L
.92464 .01472 L
.92493 .01473 L
.92525 .01483 L
.92556 .01503 L
.92573 .01517 L
.9259 .01535 L
.9265 .01621 L
.92684 .01686 L
.9272 .01768 L
.92785 .01948 L
.92913 .02429 L
.9303 .03009 L
.93272 .04649 L
.93495 .06658 L
.94 .12776 L
Mistroke
.94956 .28566 L
.95875 .44693 L
.96387 .52113 L
.9661 .54732 L
.96854 .57063 L
.97058 .58557 L
.97147 .59075 L
.97247 .59546 L
.9734 .59888 L
.97427 .60122 L
.97475 .60214 L
.97519 .60275 L
.97543 .60299 L
.97568 .60317 L
.97594 .60328 L
.97619 .60332 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0560224 0.196383 0.0581337 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.16387 -0.0125 -9 -9 ]
[.16387 -0.0125 9 0 ]
[.30392 -0.0125 -3 -9 ]
[.30392 -0.0125 3 0 ]
[.44398 -0.0125 -9 -9 ]
[.44398 -0.0125 9 0 ]
[.58403 -0.0125 -6 -9 ]
[.58403 -0.0125 6 0 ]
[.72409 -0.0125 -12 -9 ]
[.72409 -0.0125 12 0 ]
[.86415 -0.0125 -6 -9 ]
[.86415 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -12 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .31265 -6 -4.5 ]
[-0.0125 .31265 0 4.5 ]
[-0.0125 .42892 -6 -4.5 ]
[-0.0125 .42892 0 4.5 ]
[-0.0125 .54519 -6 -4.5 ]
[-0.0125 .54519 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.16387 0 m
.16387 .00625 L
s
[(2.5)] .16387 -0.0125 0 1 Mshowa
.30392 0 m
.30392 .00625 L
s
[(5)] .30392 -0.0125 0 1 Mshowa
.44398 0 m
.44398 .00625 L
s
[(7.5)] .44398 -0.0125 0 1 Mshowa
.58403 0 m
.58403 .00625 L
s
[(10)] .58403 -0.0125 0 1 Mshowa
.72409 0 m
.72409 .00625 L
s
[(12.5)] .72409 -0.0125 0 1 Mshowa
.86415 0 m
.86415 .00625 L
s
[(15)] .86415 -0.0125 0 1 Mshowa
.125 Mabswid
.05182 0 m
.05182 .00375 L
s
.07983 0 m
.07983 .00375 L
s
.10784 0 m
.10784 .00375 L
s
.13585 0 m
.13585 .00375 L
s
.19188 0 m
.19188 .00375 L
s
.21989 0 m
.21989 .00375 L
s
.2479 0 m
.2479 .00375 L
s
.27591 0 m
.27591 .00375 L
s
.33193 0 m
.33193 .00375 L
s
.35994 0 m
.35994 .00375 L
s
.38796 0 m
.38796 .00375 L
s
.41597 0 m
.41597 .00375 L
s
.47199 0 m
.47199 .00375 L
s
.5 0 m
.5 .00375 L
s
.52801 0 m
.52801 .00375 L
s
.55602 0 m
.55602 .00375 L
s
.61204 0 m
.61204 .00375 L
s
.64006 0 m
.64006 .00375 L
s
.66807 0 m
.66807 .00375 L
s
.69608 0 m
.69608 .00375 L
s
.7521 0 m
.7521 .00375 L
s
.78011 0 m
.78011 .00375 L
s
.80812 0 m
.80812 .00375 L
s
.83613 0 m
.83613 .00375 L
s
.89216 0 m
.89216 .00375 L
s
.92017 0 m
.92017 .00375 L
s
.94818 0 m
.94818 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(-2)] -0.0125 .08012 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(0)] -0.0125 .19638 1 0 Mshowa
0 .31265 m
.00625 .31265 L
s
[(2)] -0.0125 .31265 1 0 Mshowa
0 .42892 m
.00625 .42892 L
s
[(4)] -0.0125 .42892 1 0 Mshowa
0 .54519 m
.00625 .54519 L
s
[(6)] -0.0125 .54519 1 0 Mshowa
.125 Mabswid
0 .10918 m
.00375 .10918 L
s
0 .13825 m
.00375 .13825 L
s
0 .16732 m
.00375 .16732 L
s
0 .22545 m
.00375 .22545 L
s
0 .25452 m
.00375 .25452 L
s
0 .28358 m
.00375 .28358 L
s
0 .34172 m
.00375 .34172 L
s
0 .37078 m
.00375 .37078 L
s
0 .39985 m
.00375 .39985 L
s
0 .45798 m
.00375 .45798 L
s
0 .48705 m
.00375 .48705 L
s
0 .51612 m
.00375 .51612 L
s
0 .05105 m
.00375 .05105 L
s
0 .02198 m
.00375 .02198 L
s
0 .57425 m
.00375 .57425 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.16387 .61178 m
.16387 .61803 L
s
.30392 .61178 m
.30392 .61803 L
s
.44398 .61178 m
.44398 .61803 L
s
.58403 .61178 m
.58403 .61803 L
s
.72409 .61178 m
.72409 .61803 L
s
.86415 .61178 m
.86415 .61803 L
s
.125 Mabswid
.05182 .61428 m
.05182 .61803 L
s
.07983 .61428 m
.07983 .61803 L
s
.10784 .61428 m
.10784 .61803 L
s
.13585 .61428 m
.13585 .61803 L
s
.19188 .61428 m
.19188 .61803 L
s
.21989 .61428 m
.21989 .61803 L
s
.2479 .61428 m
.2479 .61803 L
s
.27591 .61428 m
.27591 .61803 L
s
.33193 .61428 m
.33193 .61803 L
s
.35994 .61428 m
.35994 .61803 L
s
.38796 .61428 m
.38796 .61803 L
s
.41597 .61428 m
.41597 .61803 L
s
.47199 .61428 m
.47199 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52801 .61428 m
.52801 .61803 L
s
.55602 .61428 m
.55602 .61803 L
s
.61204 .61428 m
.61204 .61803 L
s
.64006 .61428 m
.64006 .61803 L
s
.66807 .61428 m
.66807 .61803 L
s
.69608 .61428 m
.69608 .61803 L
s
.7521 .61428 m
.7521 .61803 L
s
.78011 .61428 m
.78011 .61803 L
s
.80812 .61428 m
.80812 .61803 L
s
.83613 .61428 m
.83613 .61803 L
s
.89216 .61428 m
.89216 .61803 L
s
.92017 .61428 m
.92017 .61803 L
s
.94818 .61428 m
.94818 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .31265 m
1 .31265 L
s
.99375 .42892 m
1 .42892 L
s
.99375 .54519 m
1 .54519 L
s
.125 Mabswid
.99625 .10918 m
1 .10918 L
s
.99625 .13825 m
1 .13825 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .22545 m
1 .22545 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .28358 m
1 .28358 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .37078 m
1 .37078 L
s
.99625 .39985 m
1 .39985 L
s
.99625 .45798 m
1 .45798 L
s
.99625 .48705 m
1 .48705 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .02198 m
1 .02198 L
s
.99625 .57425 m
1 .57425 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .19638 m
1 .19638 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .19638 m
.02381 .60332 L
s
.07983 .19638 m
.07983 .01914 L
s
.13585 .19638 m
.13585 .29475 L
s
.19188 .19638 m
.19188 .27526 L
s
.2479 .19638 m
.2479 .27526 L
s
.30392 .19638 m
.30392 .29475 L
s
.35994 .19638 m
.35994 .01914 L
s
.41597 .19638 m
.41597 .60332 L
s
.47199 .19638 m
.47199 .01914 L
s
.52801 .19638 m
.52801 .29475 L
s
.58403 .19638 m
.58403 .27526 L
s
.64006 .19638 m
.64006 .27526 L
s
.69608 .19638 m
.69608 .29475 L
s
.7521 .19638 m
.7521 .01914 L
s
.80812 .19638 m
.80812 .60332 L
s
.86415 .19638 m
.86415 .01914 L
s
.92017 .19638 m
.92017 .29475 L
s
.97619 .19638 m
.97619 .27526 L
s
.015 w
.02381 .60332 Mdot
.07983 .01914 Mdot
.13585 .29475 Mdot
.19188 .27526 Mdot
.2479 .27526 Mdot
.30392 .29475 Mdot
.35994 .01914 Mdot
.41597 .60332 Mdot
.47199 .01914 Mdot
.52801 .29475 Mdot
.58403 .27526 Mdot
.64006 .27526 Mdot
.69608 .29475 Mdot
.7521 .01914 Mdot
.80812 .60332 Mdot
.86415 .01914 Mdot
.92017 .29475 Mdot
.97619 .27526 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00;oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Dooooo`?o00004_ooool5o`0000?ooooo00?o
0000ooooooooool00_ooool3o`00017ooooo0_l0000Booooo`Go00000oooool00ol0003ooooooooo
o`02ooooo`?o00004oooool3o`0001Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`?o0000Aoooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0
000Cooooo`?o00004_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool3o`0001;ooooo0_l0
000Booooo`Go00000oooool00ol0003oooooooooo`02ooooo`?o00004oooool3o`0001Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`?o00006_ooool002oooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000001;ooooo00Go0000oooooooooooooooo
o`00000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000?oooo
o`04o`000?ooooooooooo`0001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo0000017ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00Oo
oooo00Go0000ooooooooooooooooo`000016ooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000004_ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool0000Boooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Aooooo`05o`000?oo
ooooooooooooool000004oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool0
00006Oooool002Oooooo1Ol00004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool5o`0000Gooooo00?o0000ooooooooool02Oooool5o`0000?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0001?ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0looooo`Go00001?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo1Ol00005ooooo`03o`000?oooooooooo00Wooooo1Ol00003ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000Coooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool0033ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool05oooool0037ooooo00?o0000ooooooooool01Oooool4o`0001?ooooo1?l0000Boooo
o`05o`000?ooooooooooooooool000001oooool4o`00013ooooo00Co0000oooooooooooo00004Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo1?l0000Booooo`Co00005_ooool00ol0003ooooo
ooooo`05ooooo`Co0000BOooool00ol0003oooooooooo`05ooooo`Co00004_ooool4o`0001;ooooo
00Go0000ooooooooooooooooo`000007ooooo`Co00004Oooool01?l0003oooooooooool0000Aoooo
o`05o`000?ooooooooooooooool000001oooool4o`0001;ooooo1?l0000Fooooo`03o`000?oooooo
oooo00Gooooo1?l0000Jooooo`00;Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`00017ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool0A_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`00017ooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool06oooool002go
oooo1Ol00007ooooo`Go00004_ooool5o`0001;ooooo0ol00008ooooo`Go00004?ooool2o`0001?o
oooo0ol00008ooooo`Go00004Oooool5o`00017ooooo1Ol00007ooooo`Go0000A?ooool5o`0000Oo
oooo1Ol0000Aooooo`Go00004_ooool3o`0000Sooooo1Ol0000Aooooo`;o00004oooool3o`0000So
oooo1Ol0000Aooooo`Go00004Oooool5o`0000Oooooo1Ol0000Iooooo`00oooooooiooooo`00oooo
oooiooooo`006_ooool2o`000?Sooooo0_l0003Rooooo`006Oooool01?l0003oooooooooool0003f
ooooo`04o`000?ooooooooooo`000>7ooooo000Iooooo`04o`000?ooooooooooo`0000?oooood?l0
000Sooooo`04o`000?ooooooooooo`0000Cooooo1?l000000ooo003o003oo`00o`34o`00o`Go0000
3Oooool001Wooooo00Co0000oooooooooooo00000oooool3o`0000;oooooaol00?l2ooooo`;o0000
8oooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooooooodgoo`0000?o003oool0
0?oo00002?oo00000ol00?ooo`00ool00008ool000;o003o2_oo00000ol00?ooo`00ool00008ool0
0003o`00oooo003oo`0004[oo`001?ooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo04kooooo0_l00?l9ooooo`;o003o2_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo0_l00?m?ooooo`03o`000?oooooooooo
027ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`?oo`000oooool3
ool000Sooooo0ooo0009ooooo`;oo`000oooool3ool000?ooooo0_oo0004ooooo`;oo`002Oooool2
ool000Wooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?oo
o`0000Sooooo00?oo`00o`00ool00?l02Oooool00ooo003o003oooooo`02ooooo`?oo`000oooool0
0ooo003o003oooooo`02ooooo`?oo`002Oooool2ool000Wooooo0ooo0003ooooo`;oo`000oooool3
ool000?ooooo0_oo0009ooooo`?oo`002?ooool3ool000?ooooo0ooo0006ooooo`03o`000?oooooo
oooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0C_ooool2
o`00o`Wooooo0_l00?l:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool2
o`00odoooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00?ooooo0ooo0003ooooo`?oo`002?ooool3ool000Wooooo0_oo0003ooooo`?oo`000ooo
ool2ool000Cooooo0_oo0009ooooo`;oo`002Oooool3ool000?ooooo00?oo`00o`00ooooool00_oo
ool3ool000?ooooo00?oo`00o`00oooo00002?ooool00ooo003o003oo`00o`09ooooo`03ool00?l0
0?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0009ooooo`;oo`002Ooo
ool3ool000?ooooo0_oo0003ooooo`?oo`000oooool2ool000Wooooo0ooo0008ooooo`?oo`000ooo
ool3ool000Kooooo00?o0000ooooooooool02oooool001[ooooo0_l00004ooooo`03o`000?oooooo
oooo04kooooo0_l00?l9ooooo`;o003o2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00Sooooo0_l00?m?ooooo`03o`000?oooooooooo02;ooooo0_l00005ooooo`03o`000?oooooo
oooo00?ooooo0ooo0003ooooo`?oo`002?ooool3ool000Wooooo0_oo0003ooooo`?oo`000oooool2
ool000Cooooo0_oo0009ooooo`;oo`002Oooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3
ool000?ooooo00?oo`00o`00oooo00002?ooool00ooo003o003oo`00o`09ooooo`03ool00?l00?oo
oooo00;ooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0009ooooo`;oo`002Oooool3
ool000?ooooo0_oo0003ooooo`?oo`000oooool2ool000Wooooo0ooo0008ooooo`?oo`000oooool3
ool000Kooooo00?o0000ooooooooool02oooool0023ooooo0_l0001?ooooo`;o003o2Oooool2o`00
o`[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`;o003oCoooool00ol0
003oooooooooo`0Yooooo`;o00001?ooool3ool000?ooooo0ooo0008ooooo`?oo`002Oooool2ool0
00?ooooo0ooo0003ooooo`;oo`001?ooool2ool000Wooooo0_oo0009ooooo`?oo`000oooool00ooo
003o003oooooo`02ooooo`?oo`000oooool00ooo003o003oool00008ooooo`03ool00?l00?oo003o
00Wooooo00?oo`00o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool0
00Wooooo0_oo0009ooooo`?oo`000oooool2ool000?ooooo0ooo0003ooooo`;oo`002Oooool3ool0
00Sooooo0ooo0003ooooo`?oo`001Oooool2o`0000gooooo000Pooooo`03o`000?oooooooooo04ko
oooo0_l00?l9ooooo`;o003o2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00So
oooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool3ool000?o
oooo0ooo0008ooooo`?oo`002Oooool2ool000?ooooo0ooo0003ooooo`;oo`001?ooool2ool000Wo
oooo0_oo0009ooooo`?oo`000oooool00ooo003o003oooooo`02ooooo`?oo`000oooool00ooo003o
003oool00008ooooo`03ool00?l00?oo003o00Wooooo00?oo`00o`00ooooool00_ooool3ool000?o
oooo00?oo`00o`00ooooool00_ooool3ool000Wooooo0_oo0009ooooo`?oo`000oooool2ool000?o
oooo0ooo0003ooooo`;oo`002Oooool3ool000Sooooo0ooo0003ooooo`?oo`001_ooool00ol0003o
ooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1>ooooo`;o003o2Oooool2o`00o`[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`;o003oCoooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00?ooooo0ooo0003ooooo`?oo`002?ooool3ool000Wooooo
0_oo0003ooooo`?oo`000oooool2ool000Cooooo0_oo0009ooooo`;oo`002Oooool3ool000?ooooo
00?oo`00o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00oooo00002?ooool00ooo003o003o
o`00o`09ooooo`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo
0ooo0009ooooo`;oo`002Oooool3ool000?ooooo0_oo0003ooooo`?oo`000oooool2ool000Wooooo
0ooo0008ooooo`?oo`000oooool3ool000Kooooo00?o0000ooooooooool02oooool0023ooooo00?o
0000ooooooooool0C_ooool2o`00o`Wooooo0_l00?l:ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02?ooool2o`00odoooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`03ooooo`?oo`000oooool3ool000Sooooo0ooo0009ooooo`;oo`000oooool3ool000?ooooo0_oo
0004ooooo`;oo`002Oooool2ool000Wooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo
0003ooooo`03ool00?l00?ooo`0000Sooooo00?oo`00o`00ool00?l02Oooool00ooo003o003ooooo
o`02ooooo`?oo`000oooool00ooo003o003oooooo`02ooooo`?oo`002Oooool2ool000Wooooo0ooo
0003ooooo`;oo`000oooool3ool000?ooooo0_oo0009ooooo`?oo`002?ooool3ool000?ooooo0ooo
0006ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000Coooool2o`00o`Wooooo0_l00?l:
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool2o`00odoooooo00?o0000
ooooooooool0:Oooool2o`0000Cooooo0ooo0003ooooo`?oo`002?ooool3ool000Wooooo0_oo0003
ooooo`?oo`000oooool2ool000Cooooo0_oo0009ooooo`;oo`002Oooool3ool000?ooooo00?oo`00
o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00oooo00002?ooool00ooo003o003oo`00o`09
ooooo`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0009
ooooo`;oo`002Oooool3ool000?ooooo0_oo0003ooooo`?oo`000oooool2ool000Wooooo0ooo0008
ooooo`?oo`000oooool3ool000Gooooo0_l0000=ooooo`008?ooool00ol0003oooooooooo`1>oooo
o`;o003o2Oooool2o`00o`[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08oooo
o`;o003oCoooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo0ooo0003oooo
o`?oo`002?ooool3ool000Wooooo0_oo0003ooooo`?oo`000oooool2ool000Cooooo0_oo0009oooo
o`;oo`002Oooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00
oooo00002?ooool00ooo003o003oo`00o`09ooooo`03ool00?l00?oooooo00;ooooo0ooo0003oooo
o`03ool00?l00?oooooo00;ooooo0ooo0009ooooo`;oo`002Oooool3ool000?ooooo0_oo0003oooo
o`?oo`000oooool2ool000Wooooo0ooo0008ooooo`?oo`000oooool3ool000Kooooo00?o0000oooo
ooooool02oooool0023ooooo00?o0000ooooooooool0C_ooool2o`00o`Wooooo0_l00?l:ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool2o`00odoooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`03ooooo`?oo`000oooool3ool000Sooooo0ooo0009ooooo`;o
o`000oooool3ool000?ooooo0_oo0004ooooo`;oo`002Oooool2ool000Wooooo0ooo0003ooooo`03
ool00?l00?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?ooo`0000Sooooo00?oo`00o`00ool0
0?l02Oooool00ooo003o003oooooo`02ooooo`?oo`000oooool00ooo003o003oooooo`02ooooo`?o
o`002Oooool2ool000Wooooo0ooo0003ooooo`;oo`000oooool3ool000?ooooo0_oo0009ooooo`?o
o`002?ooool3ool000?ooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`00
0?oooooooooo04kooooo0_l00?l9ooooo`;o003o2_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00Sooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
0oooool3ool000?ooooo0ooo0008ooooo`?oo`002Oooool2ool000?ooooo0ooo0003ooooo`;oo`00
1?ooool2ool000Wooooo0_oo0009ooooo`?oo`000oooool00ooo003o003oooooo`02ooooo`?oo`00
0oooool00ooo003o003oool00008ooooo`03ool00?l00?oo003o00Wooooo00?oo`00o`00ooooool0
0_ooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool000Wooooo0_oo0009ooooo`?oo`00
0oooool2ool000?ooooo0ooo0003ooooo`;oo`002Oooool3ool000Sooooo0ooo0003ooooo`?oo`00
1_ooool00ol0003oooooooooo`0;ooooo`008?ooool2o`0004oooooo0_l00?l9ooooo`;o003o2_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo0_l00?m?ooooo`03o`000?oo
oooooooo02Wooooo0_l00004ooooo`?oo`000oooool3ool000Sooooo0ooo0009ooooo`;oo`000ooo
ool3ool000?ooooo0_oo0004ooooo`;oo`002Oooool2ool000Wooooo0ooo0003ooooo`03ool00?l0
0?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?ooo`0000Sooooo00?oo`00o`00ool00?l02Ooo
ool00ooo003o003oooooo`02ooooo`?oo`000oooool00ooo003o003oooooo`02ooooo`?oo`002Ooo
ool2ool000Wooooo0ooo0003ooooo`;oo`000oooool3ool000?ooooo0_oo0009ooooo`?oo`002?oo
ool3ool000?ooooo0ooo0005ooooo`;o00003Oooool0023ooooo00?o0000ooooooooool0C_ooool2
o`00o`Wooooo0_l00?l:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool2
o`00odoooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`03ooooo`?oo`000oooool3
ool000Sooooo0ooo0009ooooo`;oo`000oooool3ool000?ooooo0_oo0004ooooo`;oo`002Oooool2
ool000Wooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?oo
o`0000Sooooo00?oo`00o`00ool00?l02Oooool00ooo003o003oooooo`02ooooo`?oo`000oooool0
0ooo003o003oooooo`02ooooo`?oo`002Oooool2ool000Wooooo0ooo0003ooooo`;oo`000oooool3
ool000?ooooo0_oo0009ooooo`?oo`002?ooool3ool000?ooooo0ooo0006ooooo`03o`000?oooooo
oooo00_ooooo000Pooooo`03o`000?oooooooooo04kooooo0_l00?l9ooooo`;o003o2_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo0_l00?m?ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool00oooool3ool000?ooooo0ooo0008ooooo`?oo`002Oooool2ool0
00?ooooo0ooo0003ooooo`;oo`001?ooool2ool000Wooooo0_oo0009ooooo`?oo`000oooool00ooo
003o003oooooo`02ooooo`?oo`000oooool00ooo003o003oool00008ooooo`03ool00?l00?oo003o
00Wooooo00?oo`00o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool0
00Wooooo0_oo0009ooooo`?oo`000oooool2ool000?ooooo0ooo0003ooooo`;oo`002Oooool3ool0
00Sooooo0ooo0003ooooo`?oo`001_ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003o
ooooooooo`1>ooooo`;o003o2Oooool2o`00o`[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`08ooooo`;o003oCoooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?o
oooo0ooo0003ooooo`?oo`002?ooool3ool000Wooooo0_oo0003ooooo`?oo`000oooool2ool000Co
oooo0_oo0009ooooo`;oo`002Oooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool000?o
oooo00?oo`00o`00oooo00002?ooool00ooo003o003oo`00o`09ooooo`03ool00?l00?oooooo00;o
oooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0009ooooo`;oo`002Oooool3ool000?o
oooo0_oo0003ooooo`?oo`000oooool2ool000Wooooo0ooo0008ooooo`?oo`000oooool3ool000Ko
oooo00?o0000ooooooooool02oooool0023ooooo0_l0001?ooooo`;o003o2Oooool2o`00o`[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`;o003oCoooool00ol0003ooooo
ooooo`0Yooooo`;o00001?ooool3ool000?ooooo0ooo0008ooooo`?oo`002Oooool2ool000?ooooo
0ooo0003ooooo`;oo`001?ooool2ool000Wooooo0_oo0009ooooo`?oo`000oooool00ooo003o003o
ooooo`02ooooo`?oo`000oooool00ooo003o003oool00008ooooo`03ool00?l00?oo003o00Wooooo
00?oo`00o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool000Wooooo
0_oo0009ooooo`?oo`000oooool2ool000?ooooo0ooo0003ooooo`;oo`002Oooool3ool000Sooooo
0ooo0003ooooo`?oo`001Oooool2o`0000gooooo000>ooooo`;o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00001?ooool00ol0003oooooooooo`1>ooooo`;o003o2Oooool2o`00o`[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`;o003oCoooool00ol0003ooooooooo
o`0Fooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooooooo
o`03ooooo`?oo`000oooool3ool000Sooooo0ooo0009ooooo`;oo`000oooool3ool000?ooooo0_oo
0004ooooo`;oo`002Oooool2ool000Wooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo
0003ooooo`03ool00?l00?ooo`0000Sooooo00?oo`00o`00ool00?l02Oooool00ooo003o003ooooo
o`02ooooo`?oo`000oooool00ooo003o003oooooo`02ooooo`?oo`002Oooool2ool000Wooooo0ooo
0003ooooo`;oo`000oooool3ool000?ooooo0_oo0009ooooo`?oo`002?ooool3ool000?ooooo0ooo
0006ooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo04kooooo0_l00?l9ooooo`;o003o
2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo0_l00?m?ooooo`03o`00
0?oooooooooo01Gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool00oooool3ool000?ooooo0ooo0008ooooo`?oo`002Oooool2ool0
00?ooooo0ooo0003ooooo`;oo`001?ooool2ool000Wooooo0_oo0009ooooo`?oo`000oooool00ooo
003o003oooooo`02ooooo`?oo`000oooool00ooo003o003oool00008ooooo`03ool00?l00?oo003o
00Wooooo00?oo`00o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool0
00Wooooo0_oo0009ooooo`?oo`000oooool2ool000?ooooo0ooo0003ooooo`;oo`002Oooool3ool0
00Sooooo0ooo0003ooooo`?oo`001_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003o
ooooooooool0000;ooooo`05o`000?ooooooooooooooool00000D?ooool2o`00o`Wooooo0_l00?l:
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool2o`00odoooooo00?o0000
ooooooooool05Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool3ool000?ooooo0ooo0008ooooo`?oo`002Oooool2ool000?ooooo0ooo
0003ooooo`;oo`001?ooool2ool000Wooooo0_oo0009ooooo`?oo`000oooool00ooo003o003ooooo
o`02ooooo`?oo`000oooool00ooo003o003oool00008ooooo`03ool00?l00?oo003o00Wooooo00?o
o`00o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool000Wooooo0_oo
0009ooooo`?oo`000oooool2ool000?ooooo0ooo0003ooooo`;oo`002Oooool3ool000Sooooo0ooo
0003ooooo`?oo`001_ooool00ol0003oooooooooo`0;ooooo`003Oooool01?l0003oooooooooool0
000;ooooo`04o`000?ooooooooooooooo`?o0000C_ooool2o`00o`Wooooo0_l00?l:ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02?ooool2o`00odkooooo0_l0000Gooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0ooo0003ooooo`?o
o`002?ooool3ool000Wooooo0_oo0003ooooo`?oo`000oooool2ool000Cooooo0_oo0009ooooo`;o
o`002Oooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00oooo
00002?ooool00ooo003o003oo`00o`09ooooo`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03
ool00?l00?oooooo00;ooooo0ooo0009ooooo`;oo`002Oooool3ool000?ooooo0_oo0003ooooo`?o
o`000oooool2ool000Wooooo0ooo0008ooooo`?oo`000oooool3ool000Gooooo0_l0000=ooooo`00
3Oooool01?l0003oooooooooool00007ooooo`Co00001?ooool00ol0003oooooooooo`1>ooooo`;o
003o2Oooool2o`00o`[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`;o
003oCoooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000Oooooo1?l00005oooo
o`03o`000?oooooooooo00?ooooo0ooo0003ooooo`?oo`002?ooool3ool000Wooooo0_oo0003oooo
o`?oo`000oooool2ool000Cooooo0_oo0009ooooo`;oo`002Oooool3ool000?ooooo00?oo`00o`00
ooooool00_ooool3ool000?ooooo00?oo`00o`00oooo00002?ooool00ooo003o003oo`00o`09oooo
o`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0009oooo
o`;oo`002Oooool3ool000?ooooo0_oo0003ooooo`?oo`000oooool2ool000Wooooo0ooo0008oooo
o`?oo`000oooool3ool000Kooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04kooooo0_l00?l9oooo
o`;o003o2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo0_l00?m?oooo
o`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo0ooo0003ooooo`?oo`002?ooool3ool000Wooooo0_oo0003
ooooo`?oo`000oooool2ool000Cooooo0_oo0009ooooo`;oo`002Oooool3ool000?ooooo00?oo`00
o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00oooo00002?ooool00ooo003o003oo`00o`09
ooooo`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0009
ooooo`;oo`002Oooool3ool000?ooooo0_oo0003ooooo`?oo`000oooool2ool000Wooooo0ooo0008
ooooo`?oo`000oooool3ool000Kooooo00?o0000ooooooooool02oooool000kooooo0_l00008oooo
o`Go00000oooool00ol0003oooooooooo`1>ooooo`;o003o2Oooool2o`00o`[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`08ooooo`;o003oCoooool00ol0003oooooooooo`0Foooo
o`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool00oooool3ool000?ooooo0ooo0008oooo
o`?oo`002Oooool2ool000?ooooo0ooo0003ooooo`;oo`001?ooool2ool000Wooooo0_oo0009oooo
o`?oo`000oooool00ooo003o003oooooo`02ooooo`?oo`000oooool00ooo003o003oool00008oooo
o`03ool00?l00?oo003o00Wooooo00?oo`00o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00
ooooool00_ooool3ool000Wooooo0_oo0009ooooo`?oo`000oooool2ool000?ooooo0ooo0003oooo
o`;oo`002Oooool3ool000Sooooo0ooo0003ooooo`?oo`001_ooool00ol0003oooooooooo`0;oooo
o`008?ooool2o`0004oooooo0_l00?l9ooooo`;o003o2_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Sooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo0_l00004ooooo`?o
o`000oooool3ool000Sooooo0ooo0009ooooo`;oo`000oooool3ool000?ooooo0_oo0004ooooo`;o
o`002Oooool2ool000Wooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03
ool00?l00?ooo`0000Sooooo00?oo`00o`00ool00?l02Oooool00ooo003o003oooooo`02ooooo`?o
o`000oooool00ooo003o003oooooo`02ooooo`?oo`002Oooool2ool000Wooooo0ooo0003ooooo`;o
o`000oooool3ool000?ooooo0_oo0009ooooo`?oo`002?ooool3ool000?ooooo0ooo0005ooooo`;o
00003Oooool0023ooooo00?o0000ooooooooool0C_ooool2o`00o`Wooooo0_l00?l:ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02?ooool2o`00odoooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`03ooooo`?oo`000oooool3ool000Sooooo0ooo0009ooooo`;oo`00
0oooool3ool000?ooooo0_oo0004ooooo`;oo`002Oooool2ool000Wooooo0ooo0003ooooo`03ool0
0?l00?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?ooo`0000Sooooo00?oo`00o`00ool00?l0
2Oooool00ooo003o003oooooo`02ooooo`?oo`000oooool00ooo003o003oooooo`02ooooo`?oo`00
2Oooool2ool000Wooooo0ooo0003ooooo`;oo`000oooool3ool000?ooooo0_oo0009ooooo`?oo`00
2?ooool3ool000?ooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oo
oooooooo04kooooo0_l00?l9ooooo`;o003o2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00Sooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00ooo
ool3ool000?ooooo0ooo0008ooooo`?oo`002Oooool2ool000?ooooo0ooo0003ooooo`;oo`001?oo
ool2ool000Wooooo0_oo0009ooooo`?oo`000oooool00ooo003o003oooooo`02ooooo`?oo`000ooo
ool00ooo003o003oool00008ooooo`03ool00?l00?oo003o00Wooooo00?oo`00o`00ooooool00_oo
ool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool000Wooooo0_oo0009ooooo`?oo`000ooo
ool2ool000?ooooo0ooo0003ooooo`;oo`002Oooool3ool000Sooooo0ooo0003ooooo`?oo`001_oo
ool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1>ooooo`;o003o2Oooool2
o`00o`[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`;o003oCoooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo0ooo0003ooooo`?oo`002?ooool3
ool000Wooooo0_oo0003ooooo`?oo`000oooool2ool000Cooooo0_oo0009ooooo`;oo`002Oooool3
ool000?ooooo00?oo`00o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00oooo00002?ooool0
0ooo003o003oo`00o`09ooooo`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?oo
oooo00;ooooo0ooo0009ooooo`;oo`002Oooool3ool000?ooooo0_oo0003ooooo`?oo`000oooool2
ool000Wooooo0ooo0008ooooo`?oo`000oooool3ool000Kooooo00?o0000ooooooooool02oooool0
023ooooo0_l0001?ooooo`;o003o2Oooool2o`00o`[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`08ooooo`;o003oCoooool00ol0003oooooooooo`0Yooooo`;o00001?ooool3ool0
00?ooooo0ooo0008ooooo`?oo`002Oooool2ool000?ooooo0ooo0003ooooo`;oo`001?ooool2ool0
00Wooooo0_oo0009ooooo`?oo`000oooool00ooo003o003oooooo`02ooooo`?oo`000oooool00ooo
003o003oool00008ooooo`03ool00?l00?oo003o00Wooooo00?oo`00o`00ooooool00_ooool3ool0
00?ooooo00?oo`00o`00ooooool00_ooool3ool000Wooooo0_oo0009ooooo`?oo`000oooool2ool0
00?ooooo0ooo0003ooooo`;oo`002Oooool3ool000Sooooo0ooo0003ooooo`?oo`001Oooool2o`00
00gooooo000Pooooo`03o`000?oooooooooo04kooooo0_l00?l9ooooo`;o003o2_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00Sooooo0_l00?m?ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool00oooool3ool000?ooooo0ooo0008ooooo`?oo`002Oooool2ool000?o
oooo0ooo0003ooooo`;oo`001?ooool2ool000Wooooo0_oo0009ooooo`?oo`000oooool00ooo003o
003oooooo`02ooooo`?oo`000oooool00ooo003o003oool00008ooooo`03ool00?l00?oo003o00Wo
oooo00?oo`00o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool000Wo
oooo0_oo0009ooooo`?oo`000oooool2ool000?ooooo0ooo0003ooooo`;oo`002Oooool3ool000So
oooo0ooo0003ooooo`?oo`001_ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003ooooo
ooooo`1>ooooo`;o003o2Oooool2o`00o`[ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`08ooooo`;o003oCoooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo
0ooo0003ooooo`?oo`002?ooool3ool000Wooooo0_oo0003ooooo`?oo`000oooool2ool000Cooooo
0_oo0009ooooo`;oo`002Oooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool000?ooooo
00?oo`00o`00oooo00002?ooool00ooo003o003oo`00o`09ooooo`03ool00?l00?oooooo00;ooooo
0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0009ooooo`;oo`002Oooool3ool000?ooooo
0_oo0003ooooo`?oo`000oooool2ool000Wooooo0ooo0008ooooo`?oo`000oooool3ool000Kooooo
00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0C_ooool2o`00o`Wooooo0_l0
0?l:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool2o`00odoooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`03ooooo`?oo`000oooool3ool000Sooooo0ooo
0009ooooo`;oo`000oooool3ool000?ooooo0_oo0004ooooo`;oo`002Oooool2ool000Wooooo0ooo
0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?ooo`0000Sooooo00?o
o`00o`00ool00?l02Oooool00ooo003o003oooooo`02ooooo`?oo`000oooool00ooo003o003ooooo
o`02ooooo`?oo`002Oooool2ool000Wooooo0ooo0003ooooo`;oo`000oooool3ool000?ooooo0_oo
0009ooooo`?oo`002?ooool3ool000?ooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000P
ooooo`;o0000Coooool2o`00o`Wooooo0_l00?l:ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02?ooool2o`00odoooooo00?o0000ooooooooool0:Oooool2o`0000Cooooo0ooo0003
ooooo`?oo`002?ooool3ool000Wooooo0_oo0003ooooo`?oo`000oooool2ool000Cooooo0_oo0009
ooooo`;oo`002Oooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool000?ooooo00?oo`00
o`00oooo00002?ooool00ooo003o003oo`00o`09ooooo`03ool00?l00?oooooo00;ooooo0ooo0003
ooooo`03ool00?l00?oooooo00;ooooo0ooo0009ooooo`;oo`002Oooool3ool000?ooooo0_oo0003
ooooo`?oo`000oooool2ool000Wooooo0ooo0008ooooo`?oo`000oooool3ool000Gooooo0_l0000=
ooooo`008?ooool00ol0003oooooooooo`1>ooooo`;o003o2Oooool2o`00o`[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`08ooooo`;o003oCoooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00?ooooo0ooo0003ooooo`?oo`002?ooool3ool000Wooooo0_oo0003oooo
o`?oo`000oooool2ool000Cooooo0_oo0009ooooo`;oo`002Oooool3ool000?ooooo00?oo`00o`00
ooooool00_ooool3ool000?ooooo00?oo`00o`00oooo00002?ooool00ooo003o003oo`00o`09oooo
o`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0009oooo
o`;oo`002Oooool3ool000?ooooo0_oo0003ooooo`?oo`000oooool2ool000Wooooo0ooo0008oooo
o`?oo`000oooool3ool000Kooooo00?o0000ooooooooool02oooool0023ooooo00?o0000oooooooo
ool0C_ooool2o`00o`Wooooo0_l00?l:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02?ooool2o`00odoooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`03ooooo`?o
o`000oooool3ool000Sooooo0ooo0009ooooo`;oo`000oooool3ool000?ooooo0_oo0004ooooo`;o
o`002Oooool2ool000Wooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03
ool00?l00?ooo`0000Sooooo00?oo`00o`00ool00?l02Oooool00ooo003o003oooooo`02ooooo`?o
o`000oooool00ooo003o003oooooo`02ooooo`?oo`002Oooool2ool000Wooooo0ooo0003ooooo`;o
o`000oooool3ool000?ooooo0_oo0009ooooo`?oo`002?ooool3ool000?ooooo0ooo0006ooooo`03
o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo04kooooo0_l00?l9ooooo`;o003o
2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo0_l00?m?ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool00oooool3ool000?ooooo0ooo0008ooooo`?oo`00
2Oooool2ool000?ooooo0ooo0003ooooo`;oo`001?ooool2ool000Wooooo0_oo0009ooooo`?oo`00
0oooool00ooo003o003oooooo`02ooooo`?oo`000oooool00ooo003o003oool00008ooooo`03ool0
0?l00?oo003o00Wooooo00?oo`00o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00ooooool0
0_ooool3ool000Wooooo0_oo0009ooooo`?oo`000oooool2ool000?ooooo0ooo0003ooooo`;oo`00
2Oooool3ool000Sooooo0ooo0003ooooo`?oo`001_ooool00ol0003oooooooooo`0;ooooo`008?oo
ool2o`0004oooooo0_l00?l9ooooo`;o003o2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00Sooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo0_l00004ooooo`?oo`000ooo
ool3ool000Sooooo0ooo0009ooooo`;oo`000oooool3ool000?ooooo0_oo0004ooooo`;oo`002Ooo
ool2ool000Wooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03ool00?l0
0?ooo`0000Sooooo00?oo`00o`00ool00?l02Oooool00ooo003o003oooooo`02ooooo`?oo`000ooo
ool00ooo003o003oooooo`02ooooo`?oo`002Oooool2ool000Wooooo0ooo0003ooooo`;oo`000ooo
ool3ool000?ooooo0_oo0009ooooo`?oo`002?ooool3ool000?ooooo0ooo0005ooooo`;o00003Ooo
ool0023ooooo00?o0000ooooooooool0C_ooool2o`00o`Wooooo0_l00?l:ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02?ooool2o`00odoooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`03ooooo`?oo`000oooool3ool000Sooooo0ooo0009ooooo`;oo`000oooool3
ool000?ooooo0_oo0004ooooo`;oo`002Oooool2ool000Wooooo0ooo0003ooooo`03ool00?l00?oo
oooo00;ooooo0ooo0003ooooo`03ool00?l00?ooo`0000Sooooo00?oo`00o`00ool00?l02Oooool0
0ooo003o003oooooo`02ooooo`?oo`000oooool00ooo003o003oooooo`02ooooo`?oo`002Oooool2
ool000Wooooo0ooo0003ooooo`;oo`000oooool3ool000?ooooo0_oo0009ooooo`?oo`002?ooool3
ool000?ooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Iooooo`?o00001?ooool00ol0
003oooooooooo`1>ooooo`;o003o2Oooool2o`00o`[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`08ooooo`;o003oCoooool00ol0003oooooooooo`0Qooooo`?o00001Oooool00ol0
003oooooooooo`03ooooo`?oo`000oooool3ool000Sooooo0ooo0009ooooo`;oo`000oooool3ool0
00?ooooo0_oo0004ooooo`;oo`002Oooool2ool000Wooooo0ooo0003ooooo`03ool00?l00?oooooo
00;ooooo0ooo0003ooooo`03ool00?l00?ooo`0000Sooooo00?oo`00o`00ool00?l02Oooool00ooo
003o003oooooo`02ooooo`?oo`000oooool00ooo003o003oooooo`02ooooo`?oo`002Oooool2ool0
00Wooooo0ooo0003ooooo`;oo`000oooool3ool000?ooooo0_oo0009ooooo`?oo`002?ooool3ool0
00?ooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0C_ooool2o`00o`Wooooo0_l00?l:ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02?ooool2o`00odoooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0ooo0003ooooo`?oo`002?ooool3ool000Wo
oooo0_oo0003ooooo`?oo`000oooool2ool000Cooooo0_oo0009ooooo`;oo`002Oooool3ool000?o
oooo00?oo`00o`00ooooool00_ooool3ool000?ooooo00?oo`00o`00oooo00002?ooool00ooo003o
003oo`00o`09ooooo`03ool00?l00?oooooo00;ooooo0ooo0003ooooo`03ool00?l00?oooooo00;o
oooo0ooo0009ooooo`;oo`002Oooool3ool000?ooooo0_oo0003ooooo`?oo`000oooool2ool000Wo
oooo0ooo0008ooooo`?oo`000oooool3ool000Kooooo00?o0000ooooooooool02oooool001[ooooo
00?o0000ooooooooool00oooool3o`0004kooooo0_l00?l9ooooo`;o003o2_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00Sooooo0_l00?m>ooooo`;o00009?ooool00ol0003ooooo
ooooo`04ooooo`;o00001?ooool3ool000?ooooo0ooo0008ooooo`?oo`002Oooool3ool000;ooooo
0ooo0003ooooo`;oo`001?ooool3ool000Sooooo0ooo0008ooooo`?oo`000oooool00ooo003o003o
ooooo`02ooooo`?oo`000oooool00ooo003o003oool00008ooooo`03ool00?l00?oo003o00Wooooo
00?oo`00o`00oooo00000_ooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool000Wooooo
0ooo0008ooooo`?oo`000oooool2ool000?ooooo0ooo0003ooooo`?oo`002?ooool3ool000Sooooo
0ooo0003ooooo`?oo`001Oooool2o`0000gooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0C_ooool2o`00oaGooooo00?o0000ooooooooool04oooool2o`00odoooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0ooo
0003ooooo`?oo`002?ooool3ool000Wooooo0ooo0002ooooo`?oo`000oooool2ool000Cooooo0ooo
0008ooooo`?oo`002?ooool3ool000?ooooo00?oo`00o`00ooooool00_ooool3ool000?ooooo0ooo
0008ooooo`?oo`002Oooool3ool000;ooooo0ooo0003ooooo`03ool00?l00?oooooo00;ooooo0ooo
0009ooooo`?oo`002?ooool3ool000?ooooo0_oo0003ooooo`?oo`000oooool3ool000Sooooo0ooo
0008ooooo`?oo`000oooool3ool000Kooooo00?o0000ooooooooool02oooool001[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1>ooooo`;o003o5Oooool00ol0003oooooooooo`0C
ooooo`;o003oCoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool3ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02
ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0O
ooooo`;oo`000oooool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Ioooo
o`;o00001Oooool00ol0003oooooooooo`1>ooooo`;o003o5Oooool00ol0003oooooooooo`0Coooo
o`;o003oCoooool00ol0003oooooooooo`0Qooooo`;o00001_ooool00ol0003oooooooooo`03oooo
o`?oo`007oooool3ool000?ooooo0_oo000Pooooo`03ool00?l00?oooooo00;ooooo0ooo000@oooo
o`03o`000?oooooooooo00cooooo0ooo0003ooooo`03ool00?l00?oooooo01oooooo0_oo0003oooo
o`?oo`007oooool3ool000Kooooo00?o0000ooooooooool02oooool001[ooooo00?o0000oooooooo
ool00oooool2o`0004oooooo0_l00?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0ooo000Oooooo`?o
o`000oooool2ool0023ooooo00?oo`00o`00ooooool00_ooool3ool0013ooooo00?o0000oooooooo
ool03?ooool3ool000?ooooo00?oo`00o`00ooooool07oooool2ool000?ooooo0ooo000Oooooo`?o
o`001Oooool2o`0000gooooo000Pooooo`03o`000?oooooooooo04kooooo0_l00?lEooooo`03o`00
0?oooooooooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
0oooool3ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02ooooo`?oo`00
4?ooool00ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0Oooooo`;oo`00
0oooool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oo
oooooooo04kooooo0_l00?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool00oooool3ool001oooooo0ooo0003ooooo`;oo`008?oo
ool00ooo003o003oooooo`02ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`000ooo
ool00ooo003o003oooooo`0Oooooo`;oo`000oooool3ool001oooooo0ooo0006ooooo`03o`000?oo
oooooooo00_ooooo000Pooooo`03o`000?oooooooooo04kooooo0_l00?lEooooo`03o`000?oooooo
oooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool3
ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02ooooo`?oo`004?ooool0
0ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0Oooooo`;oo`000oooool3
ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000Coooool2o`00
oaGooooo00?o0000ooooooooool04oooool2o`00odoooooo00?o0000ooooooooool0:Oooool2o`00
00Cooooo0ooo000Oooooo`?oo`000oooool2ool0023ooooo00?oo`00o`00ooooool00_ooool3ool0
013ooooo00?o0000ooooooooool03?ooool3ool000?ooooo00?oo`00o`00ooooool07oooool2ool0
00?ooooo0ooo000Oooooo`?oo`001Oooool2o`0000gooooo000Pooooo`03o`000?oooooooooo04ko
oooo0_l00?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool00oooool3ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o
003oooooo`02ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o
003oooooo`0Oooooo`;oo`000oooool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_o
oooo000Pooooo`03o`000?oooooooooo04kooooo0_l00?lEooooo`03o`000?oooooooooo01?ooooo
0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool3ool001oooooo
0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02ooooo`?oo`004?ooool00ol0003ooooo
ooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0Oooooo`;oo`000oooool3ool001oooooo
0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo04kooooo0_l0
0?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool00oooool3ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o003ooooo
o`02ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o003ooooo
o`0Oooooo`;oo`000oooool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000P
ooooo`;o0000Coooool2o`00oaGooooo00?o0000ooooooooool04oooool2o`00odoooooo00?o0000
ooooooooool0:Oooool2o`0000Cooooo0ooo000Oooooo`?oo`000oooool2ool0023ooooo00?oo`00
o`00ooooool00_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000?ooooo00?oo`00
o`00ooooool07oooool2ool000?ooooo0ooo000Oooooo`?oo`001Oooool2o`0000gooooo000Poooo
o`03o`000?oooooooooo04kooooo0_l00?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool3ool001oooooo0ooo0003oooo
o`;oo`008?ooool00ooo003o003oooooo`02ooooo`?oo`004?ooool00ol0003oooooooooo`0<oooo
o`?oo`000oooool00ooo003o003oooooo`0Oooooo`;oo`000oooool3ool001oooooo0ooo0006oooo
o`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo04kooooo0_l00?lEooooo`03
o`000?oooooooooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool00oooool3ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02ooooo`?o
o`004?ooool00ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0Oooooo`;o
o`000oooool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`00
0?oooooooooo04kooooo0_l00?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?ooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool00oooool3ool001oooooo0ooo0003ooooo`;oo`00
8?ooool00ooo003o003oooooo`02ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`00
0oooool00ooo003o003oooooo`0Oooooo`;oo`000oooool3ool001oooooo0ooo0006ooooo`03o`00
0?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo04kooooo0_l00?lEooooo`03o`000?oo
oooooooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00ooo
ool3ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02ooooo`?oo`004?oo
ool00ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0Oooooo`;oo`000ooo
ool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000Coooool2
o`00oaGooooo00?o0000ooooooooool04oooool2o`00odoooooo00?o0000ooooooooool0:Oooool2
o`0000Cooooo0ooo000Oooooo`?oo`000oooool2ool0023ooooo00?oo`00o`00ooooool00_ooool3
ool0013ooooo00?o0000ooooooooool03?ooool3ool000?ooooo00?oo`00o`00ooooool07oooool2
ool000?ooooo0ooo000Oooooo`?oo`001Oooool2o`0000gooooo000=ooooo`?o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`1>ooooo`;o003o5Oooool00ol0
003oooooooooo`0Cooooo`;o003oCoooool00ol0003oooooooooo`0Eooooo`?o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`?oo`007oooool3ool0
00?ooooo0_oo000Pooooo`03ool00?l00?oooooo00;ooooo0ooo000@ooooo`03o`000?oooooooooo
00cooooo0ooo0003ooooo`03ool00?l00?oooooo01oooooo0_oo0003ooooo`?oo`007oooool3ool0
00Kooooo00?o0000ooooooooool02oooool000kooooo00?o0000ooooooooool01oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool0C_ooool2o`00oaGooooo00?o0000oooo
ooooool04oooool2o`00odoooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`?oo`007oooool3
ool000?ooooo0_oo000Pooooo`03ool00?l00?oooooo00;ooooo0ooo000@ooooo`03o`000?oooooo
oooo00cooooo0ooo0003ooooo`03ool00?l00?oooooo01oooooo0_oo0003ooooo`?oo`007oooool3
ool000Kooooo00?o0000ooooooooool02oooool000kooooo00?o0000ooooooooool02oooool01Ol0
003ooooooooooooooooo0000053ooooo0_l00?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo0ooo000Oooooo`?oo`000oooool2ool0023ooooo00?oo`00
o`00ooooool00_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000?ooooo00?oo`00
o`00ooooool07oooool2ool000?ooooo0ooo000Oooooo`?oo`001_ooool00ol0003oooooooooo`0;
ooooo`003_ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooooooo`?o0000C_ooool2
o`00oaGooooo00?o0000ooooooooool04oooool2o`00odkooooo0_l0000Hooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo0ooo000Oooooo`?oo`000oooool2
ool0023ooooo00?oo`00o`00ooooool00_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3
ool000?ooooo00?oo`00o`00ooooool07oooool2ool000?ooooo0ooo000Oooooo`?oo`001Oooool2
o`0000gooooo000>ooooo`03o`000?oooooooooo00Oooooo1?l00004ooooo`03o`000?oooooooooo
04kooooo0_l00?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01oooool4o`0000Gooooo00?o0000ooooooooool00oooool3ool0
01oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02ooooo`?oo`004?ooool00ol0
003oooooooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0Oooooo`;oo`000oooool3ool0
01oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000=ooooo`;o00002Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04kooooo0_l00?lEooooo`03o`000?oooooooooo01?o
oooo0_l00?m?ooooo`03o`000?oooooooooo01Gooooo0_l00009ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00oooool3ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o
003oooooo`02ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o
003oooooo`0Oooooo`;oo`000oooool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_o
oooo000>ooooo`03o`000?oooooooooo00Oooooo1Ol00003ooooo`03o`000?oooooooooo04kooooo
0_l00?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool01oooool5o`0000Cooooo00?o0000ooooooooool00oooool3ool001oooooo
0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02ooooo`?oo`004?ooool00ol0003ooooo
ooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0Oooooo`;oo`000oooool3ool001oooooo
0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000Coooool2o`00oaGooooo00?o
0000ooooooooool04oooool2o`00odoooooo00?o0000ooooooooool0:Oooool2o`0000Cooooo0ooo
000Oooooo`?oo`000oooool2ool0023ooooo00?oo`00o`00ooooool00_ooool3ool0013ooooo00?o
0000ooooooooool03?ooool3ool000?ooooo00?oo`00o`00ooooool07oooool2ool000?ooooo0ooo
000Oooooo`?oo`001Oooool2o`0000gooooo000Pooooo`03o`000?oooooooooo04kooooo0_l00?lE
ooooo`03o`000?oooooooooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool00oooool3ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02
ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0O
ooooo`;oo`000oooool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Poooo
o`03o`000?oooooooooo04kooooo0_l00?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool3ool001oooooo0ooo0003oooo
o`;oo`008?ooool00ooo003o003oooooo`02ooooo`?oo`004?ooool00ol0003oooooooooo`0<oooo
o`?oo`000oooool00ooo003o003oooooo`0Oooooo`;oo`000oooool3ool001oooooo0ooo0006oooo
o`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo04kooooo0_l00?lEooooo`03
o`000?oooooooooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool00oooool3ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02ooooo`?o
o`004?ooool00ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0Oooooo`;o
o`000oooool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000
Coooool2o`00oaGooooo00?o0000ooooooooool04oooool2o`00odoooooo00?o0000ooooooooool0
:Oooool2o`0000Cooooo0ooo000Oooooo`?oo`000oooool2ool0023ooooo00?oo`00o`00ooooool0
0_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000?ooooo00?oo`00o`00ooooool0
7oooool2ool000?ooooo0ooo000Oooooo`?oo`001Oooool2o`0000gooooo000Pooooo`03o`000?oo
oooooooo04kooooo0_l00?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool00oooool3ool001oooooo0ooo0003ooooo`;oo`008?oo
ool00ooo003o003oooooo`02ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`000ooo
ool00ooo003o003oooooo`0Oooooo`;oo`000oooool3ool001oooooo0ooo0006ooooo`03o`000?oo
oooooooo00_ooooo000Pooooo`03o`000?oooooooooo04kooooo0_l00?lEooooo`03o`000?oooooo
oooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool3
ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02ooooo`?oo`004?ooool0
0ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0Oooooo`;oo`000oooool3
ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo
04kooooo0_l00?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool00oooool3ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo
003o003oooooo`02ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo
003o003oooooo`0Oooooo`;oo`000oooool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo
00_ooooo000Pooooo`;o0000Coooool2o`00oaGooooo00?o0000ooooooooool04oooool2o`00odoo
oooo00?o0000ooooooooool0:Oooool2o`0000Cooooo0ooo000Oooooo`?oo`000oooool2ool0023o
oooo00?oo`00o`00ooooool00_ooool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000?o
oooo00?oo`00o`00ooooool07oooool2ool000?ooooo0ooo000Oooooo`?oo`001Oooool2o`0000go
oooo000Pooooo`03o`000?oooooooooo04kooooo0_l00?lEooooo`03o`000?oooooooooo01?ooooo
0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool3ool001oooooo
0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02ooooo`?oo`004?ooool00ol0003ooooo
ooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0Oooooo`;oo`000oooool3ool001oooooo
0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo04kooooo0_l0
0?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool00oooool3ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o003ooooo
o`02ooooo`?oo`004?ooool00ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o003ooooo
o`0Oooooo`;oo`000oooool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000P
ooooo`03o`000?oooooooooo04kooooo0_l00?lEooooo`03o`000?oooooooooo01?ooooo0_l00?m?
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool3ool001oooooo0ooo0003
ooooo`;oo`008?ooool00ooo003o003oooooo`02ooooo`?oo`004?ooool00ol0003oooooooooo`0<
ooooo`?oo`000oooool00ooo003o003oooooo`0Oooooo`;oo`000oooool3ool001oooooo0ooo0006
ooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o0000Coooool2o`00oaGooooo00?o0000oooo
ooooool04oooool2o`00odoooooo00?o0000ooooooooool0:Oooool2o`0000Cooooo0ooo000Ooooo
o`?oo`000oooool2ool0023ooooo00?oo`00o`00ooooool00_ooool3ool0013ooooo00?o0000oooo
ooooool03?ooool3ool000?ooooo00?oo`00o`00ooooool07oooool2ool000?ooooo0ooo000Ooooo
o`?oo`001Oooool2o`0000gooooo000Pooooo`03o`000?oooooooooo04kooooo0_l00?lEooooo`03
o`000?oooooooooo01?ooooo0_l00?m?ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool00oooool3ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02ooooo`?o
o`004?ooool00ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0Oooooo`;o
o`000oooool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Hooooo`Go0000
0oooool00ol0003oooooooooo`1>ooooo`;o003o5Oooool00ol0003oooooooooo`0Cooooo`;o003o
Coooool00ol0003oooooooooo`0Pooooo`Go00001?ooool00ol0003oooooooooo`03ooooo`?oo`00
7oooool3ool000?ooooo0_oo000Pooooo`03ool00?l00?oooooo00;ooooo0ooo000@ooooo`03o`00
0?oooooooooo00cooooo0ooo0003ooooo`03ool00?l00?oooooo01oooooo0_oo0003ooooo`?oo`00
7oooool3ool000Kooooo00?o0000ooooooooool02oooool001Wooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`1>ooooo`;o003o5Oooool00ol0003oooooooooo`0Cooooo`;o003o
Coooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool00oooool3ool001oooooo0ooo0003ooooo`;oo`008?ooool00ooo003o003oooooo`02ooooo`?o
o`004?ooool00ol0003oooooooooo`0<ooooo`?oo`000oooool00ooo003o003oooooo`0Oooooo`;o
o`000oooool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Jooooo`03o`00
0?oooooooooo00?ooooo0ol0001>ooooo`;o003o5Oooool00ol0003oooooooooo`0Cooooo`;o003o
C_ooool2o`0002Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo0ooo000Oooooo`?oo`00
0oooool3ool001oooooo00?oo`00o`00oooo00000_ooool3ool0013ooooo00?o0000ooooooooool0
3?ooool3ool000?ooooo00?oo`00o`00oooo00007oooool3ool000;ooooo0ooo000Oooooo`?oo`00
1Oooool2o`0000gooooo000Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`?oo`007oooool3ool000?ooooo0ooo000Oooooo`?oo`000_oo
ool3ool0013ooooo00?o0000ooooooooool03?ooool3ool000?ooooo0ooo000Oooooo`?oo`000_oo
ool3ool001oooooo0ooo0006ooooo`03o`000?oooooooooo00_ooooo000Hooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00_ooooo000Hooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00_ooooo000Iooooo`?o0000
1?ooool2o`0006Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Qooooo`?o0000
1Oooool2o`0006Kooooo00?o0000ooooooooool0Hoooool2o`0000gooooo000Pooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0;ooooo`008?ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02oooool0
023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
00_ooooo000Pooooo`;o0000I_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wo
oooo0_l0001Vooooo`03o`000?oooooooooo06?ooooo0_l0000=ooooo`008?ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02oooool0023ooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00_ooooo000P
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0;
ooooo`008?ooool2o`0006Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yoooo
o`;o0000I_ooool00ol0003oooooooooo`1Sooooo`;o00003Oooool0023ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0;ooooo`008?oo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02ooo
ool0023ooooo0_l0001Vooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool2
o`0006Kooooo00?o0000ooooooooool0Hoooool2o`0000gooooo000Pooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0;ooooo`003?ooool5o`0000?o
oooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo01Cooooo1Ol00003ooooo`03o`000?oooooooooo00;o
oooo0ol00005ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`0;ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool05Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02ooo
ool000kooooo00?o0000ooooooooool02oooool01?l0003oooooooooooooool3o`0006Gooooo00?o
0000ooooooooool0Hoooool2o`0001Sooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`02ooooo`;o0000I_ooool00ol0003oooooooooo`1Sooooo`;o00003Oooool000oooooo00?o0000
ooooooooool02_ooool01Ol0003ooooooooooooooooo000006Oooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02ooo
ool000cooooo00Go0000ooooooooooooooooo`000007ooooo`Co00001?ooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooo
oooooooo000000Oooooo1?l00005ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0;ooooo`003?ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool02oooool000gooooo0ol00008ooooo`Go00000oooool2o`0006Kooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Eooooo`?o00002?ooool5o`0000Cooooo0_l0001Vooooo`03o`00
0?oooooooooo06?ooooo0_l0000=ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02oooool0023ooooo
0_l0001Vooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool2o`0006Kooooo
00?o0000ooooooooool0Hoooool2o`0000gooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00_ooooo000Pooooo`;o
0000I_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo0_l0001Vooooo`03
o`000?oooooooooo06?ooooo0_l0000=ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Uooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0;ooooo`008?ooool2o`00
06Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`;o0000I_ooool00ol0
003oooooooooo`1Sooooo`;o00003Oooool001Wooooo0ol00004ooooo`03o`000?oooooooooo06Go
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Qooooo`?o00001Oooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02oooool001Sooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02oooool001co
oooo00Go0000ooooooooooooooooo`00001Wooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`0;ooooo`006_ooool2o`0000Cooooo0ol0001Uooooo`03
o`000?oooooooooo06?ooooo0_l0000Tooooo`;o00001Oooool2o`0006Kooooo00?o0000oooooooo
ool0Hoooool2o`0000gooooo000Looooo`05o`000?ooooooooooooooool00000Ioooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02oooool001Sooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool02oooool001Wo
oooo0ol00004ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Qooooo`?o00001Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool02oooool0023ooooo0_l000000ooooooo0000ooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000[ooooo`?o0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0ol0000=ooooo`008?oo
ooo@o`0002_oooood?l0000=ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`008?ooool2o`0002Gooooo0ol0000Tooooo`Go00009?ooool3o`0002Kooooo0ol0
000Sooooo`?o0000<_ooool2o`0001?ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol0
000Eooooo`?o00005Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0
000Aooooo`?o00001?ooool2o`0000kooooo0ol00002ooooo`Go00000oooool00ol0003ooooooooo
o`02ooooo`?o00003oooool3o`0000?ooooo0ol0000Xooooo`007oooool01?l0003oooooooooool0
000Uooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00008oooool01Ol0003ooooo
oooooooooooo000002Kooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo0000
033ooooo00Co0000oooooooooooo00004oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000004oooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000>ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000oooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo02Gooooo000Oooooo`04o`000?ooooooooooo`0002Gooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo027ooooo1Ol0000Vooooo`03
o`000?oooooooooo02kooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000>
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool001oooooo00Co0000oooo
oooooooo00009Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Cooooo0_l0000T
ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool0;_ooool01?l0003ooooooooo
ool0000Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Uooooo`007oooool01?l0003oooooooooool0000Uooooo`03o`000?oooooooooo02?o
oooo00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ool000008oooool4o`00037ooooo00Co0000oooooooooooo00004_ooool01Ol0003ooooooooooooo
oooo000000Oooooo1?l0000Dooooo`Co00005oooool00ol0003oooooooooo`05ooooo`Co00004_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000kooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Gooooo1?l0000@ooooo`04o`000?oooooooooooooo
o`Co0000:?ooool001oooooo00Co0000oooooooooooo00009?ooool2o`0002Gooooo00Go0000oooo
ooooooooooooo`00000Sooooo`05o`000?ooooooooooooooool000009Oooool2o`0002?ooooo00?o
0000ooooooooool0<_ooool01?l0003oooooooooool0000Booooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo01;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000gooooo0_l00003ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`0@ooooo`;o00000oooool00ol0003oooooooooo`0Yooooo`008?ooool2o`0002Kooooo00?o0000
ooooooooool09?ooool3o`0002Gooooo0ol0000Wooooo`03o`000?oooooooooo027ooooo1Ol0000a
ooooo`;o00005?ooool3o`0000Sooooo1Ol0000Cooooo`Go00004_ooool5o`0000Oooooo1Ol0000A
ooooo`03o`000?oooooooooo00?ooooo0_l0000?ooooo`03o`000?oooooooooo00;ooooo0ol00008
ooooo`Go00003oooool01?l0003oooooooooooooool5o`0002Oooooo003oooooooWooooo003ooooo
ooWooooo003oooooooWooooo003oooooooWooooo000Looooom;o0000:OoooooBo`0000oooooo000L
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000oooo
ooooool0c_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0<kooooo00?o0000oooo
ooooool03Oooool001cooooo00?o0000ooooooooool03Oooool2o`00oa3ooooo0_l00?lDooooo`03
o`00oooooooooooo00oooooo0_l00?lCooooo`;o003o4Oooool00ol00?ooooooooooo`0Booooo`;o
003o4Oooool00ol00?ooooooooooo`0Booooo`;o003o4?ooool2o`00o`kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0=ooooo`?o003o=oooool3o`00oaGooooo0ol00?lgooooo`?o
003o5Oooool3o`00oa[ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool0
3Oooool2o`00oa3ooooo0_l00?lCooooo`?o003o4?ooool2o`00oa?ooooo0_l00?lAooooo`;o003o
4oooool2o`00oa3ooooo0ol00?lCooooo`;o003o4?ooool2o`00o`kooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0=ooooo`?o003o=oooool3o`00oaGooooo0ol00?lgooooo`?o003o
5Oooool3o`00oa[ooooo00?o0000ooooooooool03Oooool001cooooo0_l0000=ooooo`03o`00oooo
oooo003o013ooooo0_l00?lCooooo`03o`00oooooooo003o00oooooo00?o003oooooool00?l04ooo
ool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooo003o01?ooooo0_l00?l@ooooo`03o`00oooo
oooo003o01?ooooo0_l00?l@ooooo`03o`00oooooooo003o00gooooo00?o0000ooooooooool09ooo
ool2o`0000kooooo0ol00?lgooooo`?o003o5Oooool3o`00ocOooooo0ol00?lEooooo`?o003o6Ooo
ool2o`0000oooooo000Looooo`03o`000?oooooooooo00cooooo00?o003oooooool00?l03oooool0
1?l00?ooooooooooool00?lBooooo`03o`00oooooooo003o00oooooo00?o003oooooool00?l04ooo
ool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooo003o01?ooooo00?o003oooooool00?l03ooo
ool00ol00?ooooooo`00o`0Booooo`04o`00ooooooooooooo`00o`oooooo00?o003oooooool00?l0
3Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool0
=oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oo
oooooooo00cooooo00?o003oooooool00?l03oooool01?l00?ooooooooooool00?lBooooo`03o`00
oooooooo003o00oooooo00Co003ooooooooooooo003o4_ooool00ol00?ooooooo`00o`0?ooooo`03
o`00oooooooo003o01;ooooo00Co003ooooooooooooo003o3oooool00ol00?ooooooo`00o`0Boooo
o`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o3Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool0=oooool00ol00?oooooooooo
o`0Eooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool05Oooool00ol00?oooooooooo
o`0Iooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00cooooo00Co003o
oooooooooooo003o3_ooool01?l00?ooooooooooool00?lBooooo`03o`00oooooooo003o00oooooo
00Co003ooooooooooooo003o4Oooool01?l00?ooooooooooool00?l?ooooo`03o`00oooooooo003o
01;ooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?lBooooo`04o`00oooo
ooooooooo`00o`kooooo00Co003ooooooooooooo003o3Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00kooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo03Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Iooooo`03
o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00cooooo00Co003ooooooooooooo
003o3_ooool01?l00?ooooooooooool00?lAooooo`05o`00ooooooooooooooooool00?l03_ooool0
1?l00?ooooooooooool00?lAooooo`04o`00ooooooooooooo`00o`oooooo00Co003ooooooooooooo
003o4Oooool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00oa;ooooo00Co003o
oooooooooooo003o3_ooool01?l00?ooooooooooool00?l=ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool03_ooool00ol00?ooooooooooo`0gooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Wooooo
00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool03?ooool01?l00?oooooooooo
ool00?l>ooooo`04o`00ooooooooooooo`00oa7ooooo00Go003oooooooooooooooooo`00o`0>oooo
o`04o`00ooooooooooooo`00oa7ooooo00Co003ooooooooooooo003o3oooool01?l00?oooooooooo
ool00?lAooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o4_ooool01?l0
0?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`gooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0gooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool06Ooo
ool00ol0003oooooooooo`0=ooooo`007?ooool2o`0000gooooo00Co003ooooooooooooo003o3_oo
ool01?l00?ooooooooooool00?lAooooo`05o`00ooooooooooooooooool00?l03_ooool01?l00?oo
ooooooooool00?lAooooo`04o`00ooooooooooooo`00o`oooooo00Co003ooooooooooooo003o4Ooo
ool01?l00?ooooooooooool00?l>ooooo`05o`00ooooooooooooooooool00?l04Oooool01?l00?oo
ooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`gooooo00?o0000ooooooooool09oooool2
o`0000oooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo03Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Hooooo`;o00003oooool0
01cooooo00?o0000ooooooooool02oooool01Ol00?oooooooooooooooooo003o00kooooo00Co003o
oooooooooooo003o4Oooool01Ol00?oooooooooooooooooo003o00kooooo00Co003ooooooooooooo
003o4Oooool01Ol00?oooooooooooooooooo003o00gooooo00Go003oooooooooooooooooo`00o`0A
ooooo`05o`00ooooooooooooooooool00?l03Oooool01Ol00?oooooooooooooooooo003o013ooooo
00Go003oooooooooooooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`gooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo03Oooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0gooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool06Oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0;ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool02oooool01Ol00?oooooooooooooooooo003o
013ooooo00Go003oooooooooooooooooo`00o`0=ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool03_ooool01Ol00?oooooooooooooooooo003o00gooooo00Go003ooooooooooooooooo
o`00o`0Aooooo`05o`00ooooooooooooooooool00?l03Oooool01Ol00?oooooooooooooooooo003o
013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`05o`00oooooooooooo
ooooool00?l03?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo00?o003o
ooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo03Oooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00gooooo000Doooo
o`Go00000oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool02oooool01Ol00?oooooooooooooooooo003o013ooooo00Go003oooooooooooooooooo`00
o`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool01Ol00?oooooooooo
oooooooo003o00gooooo00Go003oooooooooooooooooo`00o`0Aooooo`05o`00oooooooooooooooo
ool00?l03Oooool01Ol00?oooooooooooooooooo003o013ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0;ooooo`05o`00ooooooooooooooooool00?l03?ooool00ol0003ooooooooo
o`0Nooooo`Go00001?ooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo03Oooooo00?o
003oooooooooool05Oooool00ol00?ooooooooooo`0gooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool06Oooool00ol0003oooooooooo`0=ooooo`005Oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0;ooooo`05o`00ooooooooooooooooool00?l04?ooool01Ol00?oooooooooooooooooo003o00go
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooooooooooo
ool00?l03Oooool01Ol00?oooooooooooooooooo003o017ooooo00Go003oooooooooooooooooo`00
o`0=ooooo`05o`00ooooooooooooooooool00?l04?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00_ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`000?oooooooooo01oo
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo
03Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0gooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool06Oooool00ol0003oooooooooo`0=ooooo`003_ooool5o`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0?ooooo`05o`00oooooooooooooooo
ool00?l03?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0;ooooo`05o`00ooooooooooooooooool00?l03?ooool0
0ol0003oooooooooo`0Hooooo`Go00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00kooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo03Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooo
oooo00gooooo000Gooooo`03o`000?oooooooooo00;ooooo0ol0000;ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0>ooooo`05o`00oooooooooooo
ooooool00?l03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool02Oooool2o`0002?ooooo00?o0000ooooooooool00oooool2o`0000oooooo00?o003o
ooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo03Oooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Hooooo`;o00003oooool001Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool0=oooool00ol00?oooooooooo
o`0Eooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool05Oooool00ol00?oooooooooo
o`0Iooooo`03o`000?oooooooooo00gooooo000Dooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_oo
ool00ol0003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`0>ooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`0gooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool06Oooool00ol0003ooooo
ooooo`0=ooooo`005Oooool3o`0000Cooooo00?o0000ooooooooool02oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool07oooool3o`0000Gooooo00?o
0000ooooooooool03_ooool00ol00?ooooooooooo`0gooooo`03o`00oooooooooooo01Gooooo00?o
003oooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Wooooo00?o
0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0>
ooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0g
ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool06Oooool00ol0003oooooooooo`0=
ooooo`007?ooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool02Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo00?o003ooooo
ooooool0=oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo03Oooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00gooooo000Looooo`;o
00003?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o0000oooooooo
ool09oooool2o`0000oooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo03Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Hooooo`;o
00003oooool001cooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0>ooooo`03o`00
oooooooooooo03Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0gooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool06Oooool00ol0003oooooooooo`0=ooooo`007?oo
ool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool0=ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooo
oooo00[ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`0gooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Wooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0>ooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0gooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool06Oooool00ol0
003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00ko
oooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo03Oo
oooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00go
oooo000Looooo`;o00002oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo
00?o0000ooooooooool09oooool2o`0000oooooo00?o003oooooooooool0=oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`0Hooooo`;o00003oooool001cooooo00?o0000ooooooooool02_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0>ooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool05Oooool00ol00?oooooooooo
o`0gooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool06Oooool00ol0003ooooooooo
o`0=ooooo`007?ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo00?o003o
ooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo03Oooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00gooooo000Loooo
o`03o`000?oooooooooo00Wooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`0goooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo01Wooooo00?o0000ooooooooool03Oooool001cooooo00?o0000oooooooo
ool02Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo03Oooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0gooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool06Oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`09ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00kooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo03Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Iooooo`03o`00
0?oooooooooo00gooooo000Looooo`;o00002_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Wooooo00?o0000ooooooooool09oooool2o`0000oooooo00?o003oooooooooool0=ooo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`0Hooooo`;o00003oooool001cooooo00?o0000ooooooooool02Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0>ooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0gooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool06Oooool0
0ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00kooooo00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
03Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo
00gooooo000Looooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`08ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03_ooool00ol00?oo
ooooooooo`0gooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0=oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool03Oooool001Kooooo
0_l00004ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`08ooooo`03o`000?oooooooooo023ooooo0_l00005ooooo`03o`000?oooooooooo00kooooo
00?o003oooooooooool0=oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo03Oooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00gooooo
000Eooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool07oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool0=oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Iooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?ooooooooooo`0000?o
oooo3?l000000ol00?oo0000o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l0
00001_l000000ol00?oo0000o`00000:o`000003o`00ool0003o000000Ko000000?o003oo`000?l0
00001_l000000ol00?oo0000o`000005o`000003o`00ool0003o000000_o000000?o003oo`000?l0
00001Ol000000ol00?oo0000o`000007o`000003o`00ool0003o000000Go000000?o003oo`000?l0
00002ol000000ol00?oo0000o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l0
00001Ol000000ol00?oo0000o`00000;o`000003o`00ool0003o000000Go000000?o003oo`000?l0
00001_l000000ol00?oo0000o`000006o`000003o`00ool0003o000000Wo00008Oooool01?l0003o
ooooooooool00004ooooo`Go000000?o003oo`000?l000002Ol000000ol00?oo0000o`000008o`00
0003o`00ool0003o000000Wo000000?o003oo`000?l000002Ol000000ol00?oo0000o`000009o`00
0003o`00ool0003o000000So000000?o003oo`000?l000002Ol000000ol00?oo0000o`000009o`00
0003o`00ool0003o000000So000000?o003oo`000?l000002Ol000000ol00?oo0000o`000009o`00
0003o`00ool0003o000000So000000?o003oo`000?l000002Ol000000ol00?oo0000o`000009o`00
0003o`00ool0003o000000Wo000000?o003oo`000?l000002?l000000ol00?oo0000o`000009o`00
0003o`00ool0003o000000?o00003oooool001Gooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol0
003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Eooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Sooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00;ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0=ooooo`005Oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool0
3Oooool001Kooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo023ooooo0_l00005ooooo`03o`000?oo
oooooooo00;ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0=ooooo`007?ooool0
0ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool05?ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool0
0ol0003oooooooooo`0=ooooo`007?ooool2o`0000Wooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`08ooooo`03o`000?oooooooooo02Oooooo0_l00003ooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`09ooooo`04o`00oooooooooooo
ooooo`;o00003oooool001cooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02oooo
o`03o`00oooooooooooo01Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Doooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool05?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool05?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o0000oooooooo
ool03Oooool001cooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00
oooooooooooo01Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Dooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00;ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool05?oo
ool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05?oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03Ooo
ool001cooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00;ooooo00?o0000ooooooooool03Oooool001cooooo0_l00009ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool01oooool00ol0003oooooooooo`0Wooooo`;o00000oooool00ol0
0?ooooooooooo`0Dooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool05?ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool02Oooool01?l0
0?ooooooooooooooool2o`0000oooooo000Looooo`03o`000?oooooooooo00Sooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool05?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Looooo`03
o`000?oooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Dooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo01Cooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo01Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03
o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
0_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0
5?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oo
oooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo00Sooooo0ol00?l9ooooo`?o003o2_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo01Cooooo00?o003oooooooooool02?ooool3o`00o`Wooooo0ol00?l9ooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`08ooooo`?o003o0ooo
ool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`08ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool01oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00;ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`08ooooo`?o003o2Oooool3
o`00o`[ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooo
oooo00Sooooo0ol00?l9ooooo`?o003o2Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo01Cooooo00?o003oooooooooool02?ooool3o`00o`?ooooo00?o0000ooooooooool03Oooool0
01cooooo0_l00009ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01oooool00ol0
003oooooooooo`0Wooooo`;o00000oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
00Sooooo0ol00?l9ooooo`?o003o2_ooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo
01Cooooo00?o003oooooooooool02?ooool3o`00o`Wooooo0ol00?l9ooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`08ooooo`?o003o0_ooool2o`00
00oooooo000Looooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool05?ooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool03Oooool001cooooo
00?o0000ooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo01?ooooo
0ol00?lPooooo`?o003o5_ooool00ol00?ooooooooooo`0Cooooo`?o003o8?ooool3o`00oaKooooo
00?o003oooooooooool04oooool3o`00o`oooooo00?o0000ooooooooool03Oooool001cooooo00?o
0000ooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo01?ooooo0ol0
0?lPooooo`?o003o5_ooool00ol00?ooooooooooo`0Cooooo`?o003o8?ooool3o`00oaKooooo00?o
003oooooooooool04oooool3o`00o`oooooo00?o0000ooooooooool03Oooool001Cooooo1Ol00003
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07
ooooo`03o`000?oooooooooo01kooooo1Ol00004ooooo`03o`000?oooooooooo00;ooooo00?o003o
ooooooooool04oooool3o`00ob3ooooo0ol00?lFooooo`03o`00oooooooooooo01?ooooo0ol00?lP
ooooo`?o003o5_ooool00ol00?ooooooooooo`0Cooooo`?o003o3oooool00ol0003oooooooooo`0=
ooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo01oooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo04oooooo00?o
003oooooooooool0Coooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00gooooo000F
ooooo`03o`000?oooooooooo00?ooooo0ol00008ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool01_ooool2o`0002;ooooo00?o0000ooooooooool01?ooool2o`0000?ooooo00?o003o
ooooooooool0Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo02Cooooo0_l0000?
ooooo`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`09ooooo`05o`00ooooooooooooooooool00?l03?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool0
1Ol00?oooooooooooooooooo003o00cooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`07ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool0Coooool00ol00?oooooooooo
o`0Uooooo`03o`000?oooooooooo00gooooo000Dooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Ooo
ool01Ol00?oooooooooooooooooo003o00cooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol0003oooooooooo`0Nooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo
04oooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo
00gooooo000Dooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`08oooo
o`03o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`0;ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02Oooool01Ol00?oooooooooooooooooo003o00cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l0
3?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00Go003ooooooooooooo
ooooo`00o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol0003o
ooooooooo`0Nooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02oooo
o`03o`00oooooooooooo04oooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`0Uoooo
o`03o`000?oooooooooo00gooooo000Eooooo`?o00001?ooool00ol0003oooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00Go003oooooooooooooooooo`00o`0;ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02Oooool01Ol00?oooooooooooooooooo003o00cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l03?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00Go003ooooooooooooooooo
o`00o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol0003ooooo
ooooo`0Oooooo`?o00001Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo04oooooo
00?o003oooooooooool0Coooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00gooooo
000Looooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool02oooool01?l00?oooooooooo
ool00?l=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool01Ol00?oooooo
oooooooooooo003o00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`05
o`00ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00[ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02_ooool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooooooo00Kooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo04oooooo00?o
003oooooooooool0Coooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00gooooo000L
ooooo`;o00002?ooool00ol00?ooooooooooo`0;ooooo`04o`00ooooooooooooo`00o`gooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l0
3?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00Go003ooooooooooooo
ooooo`00o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool01Ol00?oo
oooooooooooooooo003o00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:oooo
o`04o`00ooooooooooooo`00o`gooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0W
ooooo`;o00000oooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo04oooooo00?o003o
ooooooooool09?ooool2o`0000oooooo000Looooo`03o`000?oooooooooo00Oooooo00?o003ooooo
ooooool02oooool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool02_ooool01Ol00?oooooooooooooooooo003o00cooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0:ooooo`04o`00ooooooooooooo`00o`gooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0:ooooo`04o`00ooooooooooooo`00o`gooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0:ooooo`04o`00ooooooooooooo`00o`gooooo00?o003ooooo
ooooool01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ooooool0Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo02Gooooo00?o0000oooo
ooooool03Oooool001cooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0;ooooo`04
o`00ooooooooooooo`00o`gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooo003o00gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:oooo
o`04o`00ooooooooooooo`00o`gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:
ooooo`04o`00ooooooooooooo`00o`gooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0:ooooo`04o`00ooooooooooooo`00o`gooooo00?o003oooooooooool01_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0Coooool00ol00?oooooo
ooooo`1?ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool03Oooool001cooooo00?o
0000ooooooooool01oooool00ol00?ooooooooooo`0;ooooo`04o`00ooooooooooooo`00o`gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo003o00gooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo003o00gooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`04o`00ooooooooooooo`00o`go
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`04o`00ooooooooooooo`00
o`gooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00;ooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo
02Gooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01oooool00ol00?oo
ooooooooo`0;ooooo`04o`00ooooooooooooo`00o`gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooo003o00gooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooo003o00gooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooo003o00gooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooo003o00gooooo00?o003oooooooooool01_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0Coooool00ol0
0?ooooooooooo`1?ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool03Oooool001co
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`;o003o3_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00_ooooo00?o003oooooool00?l03Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooool00?l03Oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooool00?l03Oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00_ooooo0_l00?l>ooooo`03o`00oooooooooooo00Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo04oo
oooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00go
oooo000Looooo`;o00002?ooool00ol00?ooooooooooo`0<ooooo`;o003o3_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00_ooooo0ol00?l=ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool3o`00o`kooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0;ooooo`;o003o3_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
0_l00?l>ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool09oooool2o`0000?ooooo
00?o003oooooooooool0Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo02Cooooo
0_l0000?ooooo`007?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01_ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00Kooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo04oooooo00?o
003oooooooooool0Coooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00gooooo000L
ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`1?
ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool03Oooool001cooooo00?o0000oooo
ooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo04oooooo00?o003ooooo
ooooool09Oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003oooooooooo`07ooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo01_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03
o`00oooooooooooo04oooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`0Uooooo`03
o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
1_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0
Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool0
3Oooool001cooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`06ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`1?ooooo`03o`00oooo
oooooooo04oooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`0=ooooo`007?ooool2
o`0000Sooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0Wooooo`;o00000oooool0
0ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool09?ooool2
o`0000oooooo000Looooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0Coooool00ol0
0?ooooooooooo`1?ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool03Oooool001co
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo04oo
oooo00?o003oooooooooool09Oooool00ol0003oooooooooo`0=ooooo`005_ooool3o`0000?ooooo
00?o0000ooooooooool01oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo023ooooo
0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0Coooool00ol00?oooooo
ooooo`1?ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool03Oooool001Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
003oooooooooool0Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo02Gooooo00?o
0000ooooooooool03Oooool001Cooooo1Ol00003ooooo`03o`000?oooooooooo00Oooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`Go00001?ooool00ol0003oooooooooo`02
ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`0U
ooooo`03o`000?oooooooooo00gooooo000Dooooo`04o`000?ooooooooooo`0000Cooooo0ol00007
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Cooooo0_l0000Pooooo`04o`000?ooooooooooo`0000Gooooo0_l0
0003ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool0Coooool00ol00?oooooooooo
o`0Tooooo`;o00003oooool001Gooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`06
ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0003oooooo`000005
ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`1?
ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool03Oooool001Kooooo0_l00004oooo
o`03o`000?oooooooooo00Kooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0Poooo
o`;o00001Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo04oooooo00?o003ooooo
ooooool0Coooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00gooooo000Gooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0Nooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo01kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`00oooooooooooo04oooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`0Uooooo`03
o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool0
7_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
1Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0
Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool0
3Oooool001cooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo01oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`1?ooooo`03o`00oooo
oooooooo04oooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`0=ooooo`007?ooool2
o`0000Oooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo01kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo01kooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0Wooooo`;o00000oooool0
0ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool09?ooool2
o`0000oooooo000Looooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool07_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool01Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0Coooool00ol0
0?ooooooooooo`1?ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool03Oooool001co
oooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo04oo
oooo00?o003oooooooooool09Oooool00ol0003oooooooooo`0=ooooo`007?ooool00ol0003ooooo
ooooo`05ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0Nooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0Nooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`02ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool0Coooool00ol00?oooooo
ooooo`0Uooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Gooooo00?o
003oooooooooool07oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01kooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool07oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01kooooo00?o
003oooooooooool01Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o
003oooooooooool0Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo02Gooooo00?o
0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0O
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0O
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`05
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`1?
ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`0=
ooooo`007?ooool2o`0000Kooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo01kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Ooooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo01oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0Woooo
o`;o00000oooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo04oooooo00?o003ooooo
ooooool09?ooool2o`0000oooooo000Looooo`03o`000?oooooooooo00Gooooo00?o003ooooooooo
ool08?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01kooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool07oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003ooooooooo
ool0Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo02Gooooo00?o0000oooooooo
ool03Oooool001cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo01oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`04ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`1?ooooo`03o`00
oooooooooooo04oooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`0=ooooo`007?oo
ool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool0Cooo
ool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooo
oooo00Gooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo01oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00;ooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooo
oooo02Gooooo00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01Oooool00ol0
0?ooooooooooo`0Pooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool00ol0
0?ooooooooooo`04ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol0
0?ooooooooooo`1?ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool09Oooool00ol0
003oooooooooo`0=ooooo`007?ooool2o`0000Kooooo00?o003oooooooooool08?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool01?ooool00ol0003o
ooooooooo`0Wooooo`;o00000oooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo04oo
oooo00?o003oooooooooool09?ooool2o`0000oooooo000Looooo`03o`000?oooooooooo00Gooooo
00?o003oooooooooool08?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01oooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool07oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo
00?o003oooooooooool0Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo02Gooooo
00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01?ooool00ol00?oooooooooo
o`0Qooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool08?ooool01Ol00?oooooooooo
oooooooo003o02;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`04ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`1?ooooo`03o`00
oooooooooooo04oooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`0=ooooo`005Ooo
ool3o`0000Cooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool08?ooool01Ol00?oooooooooooooooooo003o02;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool08?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo01oooooo
0ol00005ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0Coooool00ol00?oooooo
ooooo`1?ooooo`03o`00oooooooooooo02Gooooo00?o0000ooooooooool03Oooool001Cooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool0
8Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo023ooooo00Go003ooooooooooooo
ooooo`00o`0Sooooo`05o`00ooooooooooooooooool00?l08_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo023ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0Noooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooo
oooo04oooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooo
oooo00gooooo000Dooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0P
ooooo`05o`00ooooooooooooooooool00?l08oooool01Ol00?oooooooooooooooooo003o02;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00Cooooo
00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool00_ooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo04oooooo00?o003ooooooooo
ool09Oooool00ol0003oooooooooo`0=ooooo`005?ooool4o`0000Cooooo0ol00004ooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Pooooo`05o`00
ooooooooooooooooool00?l08oooool01Ol00?oooooooooooooooooo003o02;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00?ooooo0_l0000Poooo
o`Co00001Oooool2o`0000?ooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`1?oooo
o`03o`00oooooooooooo02Cooooo0_l0000?ooooo`005?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo023ooooo00Go003oooooooooooooooooo`00o`0Sooooo`05o`00oooooooooooo
ooooool00?l08oooool01Ol00?oooooooooooooooooo003o02;ooooo00?o003oooooooooool01?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool09Ooo
ool00ol0003oooooooooo`0=ooooo`005Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o003oooooooooool08Oooool01Ol00?oooooooooooooooooo003o02?ooooo00Go
003oooooooooooooooooo`00o`0Sooooo`05o`00ooooooooooooooooool00?l08oooool01Ol00?oo
oooooooooooooooo003o02;ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`1?oooo
o`03o`00oooooooooooo04oooooo00?o003oooooooooool09Oooool00ol0003oooooooooo`0=oooo
o`005_ooool2o`0000Cooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Qooooo`05
o`00ooooooooooooooooool00?l08oooool01Ol00?oooooooooooooooooo003o02?ooooo00Go003o
ooooooooooooooooo`00o`0Sooooo`05o`00ooooooooooooooooool00?l08oooool00ol00?oooooo
ooooo`03ooooo`03o`000?oooooooooo023ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo
00?o003oooooooooool0Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo02Gooooo
00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool01?ooool00ol00?oooooooooo
o`0Qooooo`05o`00ooooooooooooooooool00?l08oooool01Ol00?oooooooooooooooooo003o02?o
oooo00Go003oooooooooooooooooo`00o`0Sooooo`04o`00ooooooooooooo`00obCooooo00?o003o
ooooooooool00oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o003o
ooooooooool0Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo02Gooooo00?o0000
ooooooooool03Oooool001cooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Roooo
o`04o`00ooooooooooooo`00ob?ooooo00Go003oooooooooooooooooo`00o`0Sooooo`05o`00oooo
ooooooooooooool00?l08oooool01?l00?ooooooooooool00?lTooooo`03o`00oooooooooooo00?o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo04oo
oooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00go
oooo000Looooo`;o00001Oooool00ol00?ooooooooooo`0Rooooo`04o`00ooooooooooooo`00ob?o
oooo00Go003oooooooooooooooooo`00o`0Sooooo`05o`00ooooooooooooooooool00?l08oooool0
1?l00?ooooooooooool00?lTooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool09ooo
ool2o`0000?ooooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooo
oooooooo02Cooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooo
oooo02;ooooo00Co003ooooooooooooo003o8oooool01Ol00?oooooooooooooooooo003o02Cooooo
00?o003oooooool00?l09?ooool01?l00?ooooooooooool00?lTooooo`03o`00oooooooooooo00?o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo04oo
oooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00go
oooo000Looooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool08_ooool00ol00?oooooo
o`00o`0Uooooo`03o`00oooooooo003o02Gooooo00?o003oooooool00?l09?ooool01?l00?oooooo
ooooool00?lTooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo04oooooo00?o003oooooooooool0Coooool00ol00?oo
ooooooooo`0Uooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool08oooool00ol00?ooooooo`00o`0Uooooo`03o`00oooooooo003o02Gooooo
00?o003oooooool00?l09?ooool01?l00?ooooooooooool00?lTooooo`03o`00oooooooooooo00?o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo04oo
oooo00?o003oooooooooool0Coooool00ol00?ooooooooooo`0Uooooo`03o`000?oooooooooo00go
oooo000Looooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool08oooool00ol00?oooooo
o`00o`0Uooooo`03o`00oooooooo003o02Gooooo00?o003oooooool00?l09Oooool2o`00obKooooo
00?o003oooooooooool00_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo
00?o003oooooooooool0Coooool00ol00?ooooooooooo`1?ooooo`03o`00oooooooooooo02Gooooo
00?o0000ooooooooool03Oooool001cooooo00?o0000ooooooooool00oooool00ol00?oooooooooo
o`0Tooooo`;o003o9Oooool3o`00obGooooo0_l00?lVooooo`;o003o9_ooool00ol00?oooooooooo
o`02ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooooooo0ol00?m?ooooo`?o003o
Coooool3o`00obKooooo00?o0000ooooooooool03Oooool001cooooo0_l00003ooooo`;o003o9_oo
ool2o`00obKooooo00?o003oooooooooool09?ooool2o`00obKooooo0_l00?lVooooo`03o`00oooo
oooooooo00;ooooo00?o0000ooooooooool09oooool2o`0000;ooooo0ol00?m?ooooo`?o003oCooo
ool3o`00obGooooo0_l0000?ooooo`007?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooo
oooo02Oooooo00Co0000oooooooooooooooo0ol00?m?ooooo`?o003oCoooool3o`00obKooooo00?o
0000ooooooooool03Oooool001cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=
ooooo`007?oooooBo`0002Woooood_l0000?ooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-12.1076, \
-0.501709, 0.0887531, 0.02454}, {{262.875, 490.688}, {303, 162.25}} -> \
{-34.3384, -0.501107, 0.0887266, 0.0245326}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-0.852551, -17.6965, 0.0251258, 0.082325}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-24.3063, -17.6965, 0.0854275, 0.082325}}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparison to oversampled case", "Section"],

Cell[CellGroupData[{

Cell["Sampling frequency", "Subsection"],

Cell[BoxData[
    \(\(fs = 10\  (*\ Hz\ *) ;\)\)], "Input",
  Background->RGBColor[1, 1, 0]]
}, Closed]],

Cell[CellGroupData[{

Cell["Continuous-time signal", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x[t_] := 
        1\  + \ 2\ Cos[2  \[Pi]\ t]\  + \ 4\ Cos[4  \[Pi]\ t];\)\), "\n", 
    \(\(gxt = 
        Plot[x[t], {t, 0, 5}, PlotStyle \[Rule] {Blue, Thickness[ .005]}, \ 
          PlotPoints \[Rule] 100];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.196383 0.0581337 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -12 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .31265 -6 -4.5 ]
[-0.0125 .31265 0 4.5 ]
[-0.0125 .42892 -6 -4.5 ]
[-0.0125 .42892 0 4.5 ]
[-0.0125 .54519 -6 -4.5 ]
[-0.0125 .54519 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(1)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(2)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(3)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(4)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(-2)] -0.0125 .08012 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(0)] -0.0125 .19638 1 0 Mshowa
0 .31265 m
.00625 .31265 L
s
[(2)] -0.0125 .31265 1 0 Mshowa
0 .42892 m
.00625 .42892 L
s
[(4)] -0.0125 .42892 1 0 Mshowa
0 .54519 m
.00625 .54519 L
s
[(6)] -0.0125 .54519 1 0 Mshowa
.125 Mabswid
0 .10918 m
.00375 .10918 L
s
0 .13825 m
.00375 .13825 L
s
0 .16732 m
.00375 .16732 L
s
0 .22545 m
.00375 .22545 L
s
0 .25452 m
.00375 .25452 L
s
0 .28358 m
.00375 .28358 L
s
0 .34172 m
.00375 .34172 L
s
0 .37078 m
.00375 .37078 L
s
0 .39985 m
.00375 .39985 L
s
0 .45798 m
.00375 .45798 L
s
0 .48705 m
.00375 .48705 L
s
0 .51612 m
.00375 .51612 L
s
0 .05105 m
.00375 .05105 L
s
0 .02198 m
.00375 .02198 L
s
0 .57425 m
.00375 .57425 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .31265 m
1 .31265 L
s
.99375 .42892 m
1 .42892 L
s
.99375 .54519 m
1 .54519 L
s
.125 Mabswid
.99625 .10918 m
1 .10918 L
s
.99625 .13825 m
1 .13825 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .22545 m
1 .22545 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .28358 m
1 .28358 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .37078 m
1 .37078 L
s
.99625 .39985 m
1 .39985 L
s
.99625 .45798 m
1 .45798 L
s
.99625 .48705 m
1 .48705 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .02198 m
1 .02198 L
s
.99625 .57425 m
1 .57425 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .19638 m
1 .19638 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.02381 .60332 m
.02409 .60327 L
.02435 .60315 L
.02465 .60291 L
.02494 .6026 L
.02544 .60181 L
.02599 .60063 L
.02659 .59894 L
.02722 .5967 L
.02837 .59157 L
.03066 .57704 L
.03318 .55482 L
.03845 .48973 L
.04339 .4114 L
.05279 .24379 L
.05757 .16395 L
.06278 .0915 L
.0652 .06507 L
.06778 .04268 L
.06903 .0341 L
.07021 .02743 L
.07126 .02263 L
.07241 .01871 L
.07298 .01724 L
.0733 .01658 L
.0736 .01604 L
.07388 .01562 L
.07418 .01526 L
.07446 .01501 L
.07471 .01485 L
.07501 .01474 L
.0753 .01472 L
.07561 .01479 L
.07578 .01487 L
.07594 .01497 L
.07624 .01523 L
.07657 .01561 L
.07724 .01672 L
.07791 .01826 L
.07852 .02003 L
.07989 .02524 L
.08115 .03157 L
.08235 .03879 L
.0872 .07912 L
.09167 .12835 L
.10123 .24727 L
.10603 .30069 L
.11041 .33874 L
.11157 .34657 L
.11283 .35393 L
Mistroke
.11404 .35977 L
.11513 .36402 L
.11574 .36596 L
.1164 .36769 L
.1171 .3691 L
.11741 .3696 L
.11775 .37004 L
.11807 .37036 L
.11837 .37058 L
.11869 .37073 L
.11886 .37077 L
.11902 .37078 L
.11931 .37075 L
.11962 .37064 L
.11992 .37045 L
.12019 .37021 L
.12048 .36988 L
.12078 .36946 L
.12132 .36851 L
.1219 .3672 L
.12253 .36544 L
.12367 .36141 L
.12473 .35669 L
.12714 .34252 L
.12972 .32259 L
.13491 .27024 L
.1398 .21108 L
.14913 .0974 L
.15396 .05168 L
.15639 .03472 L
.15778 .02724 L
.15907 .02176 L
.16028 .01801 L
.16096 .01651 L
.16129 .01595 L
.1616 .01552 L
.16186 .01522 L
.16215 .01497 L
.16247 .0148 L
.16276 .01472 L
.16305 .01473 L
.16336 .01484 L
.16352 .01493 L
.16369 .01505 L
.16399 .01535 L
.1643 .01574 L
.16457 .01618 L
.1652 .01746 L
.16576 .01892 L
.16635 .02081 L
Mistroke
.16737 .02492 L
.16849 .03065 L
.17095 .04758 L
.1732 .06811 L
.17826 .13016 L
.18789 .29 L
.19716 .45192 L
.20233 .52571 L
.20477 .5533 L
.20702 .57375 L
.20936 .58964 L
.2106 .59562 L
.21123 .59802 L
.2119 .60009 L
.2125 .6015 L
.21304 .60243 L
.2133 .60277 L
.21358 .60304 L
.21385 .60321 L
.2141 .6033 L
.21438 .60331 L
.21465 .60324 L
.21495 .60307 L
.21527 .60277 L
.21558 .60236 L
.21591 .60181 L
.21651 .60052 L
.21713 .59872 L
.21772 .59663 L
.21882 .59168 L
.22001 .58487 L
.2213 .5758 L
.22575 .53171 L
.23057 .46515 L
.23567 .38002 L
.24486 .21607 L
.24998 .13491 L
.25465 .0757 L
.25696 .05313 L
.25818 .04321 L
.25948 .03424 L
.26073 .02719 L
.26186 .02216 L
.26241 .02019 L
.263 .0184 L
.26356 .01703 L
.26406 .01606 L
.26434 .01564 L
.26464 .01528 L
.26496 .01499 L
Mistroke
.26526 .01481 L
.26554 .01473 L
.26584 .01472 L
.2661 .01479 L
.26638 .01494 L
.26655 .01507 L
.26671 .01521 L
.26701 .01556 L
.26769 .01665 L
.26827 .01795 L
.26891 .01975 L
.27019 .0245 L
.27156 .03118 L
.27402 .04717 L
.27921 .09495 L
.2841 .15207 L
.29344 .26771 L
.29818 .31668 L
.30087 .33859 L
.30216 .34728 L
.30338 .35432 L
.30454 .35988 L
.30579 .36466 L
.30635 .36634 L
.30694 .36783 L
.30749 .36896 L
.308 .36975 L
.30828 .3701 L
.30858 .37039 L
.30888 .3706 L
.30905 .37069 L
.30921 .37074 L
.3095 .37078 L
.30976 .37076 L
.31006 .37065 L
.31035 .37048 L
.31067 .37021 L
.311 .36982 L
.3116 .36888 L
.31224 .36752 L
.31295 .36561 L
.31421 .36114 L
.31541 .35565 L
.31766 .34223 L
.32008 .32358 L
.32273 .29887 L
.33259 .18173 L
.33715 .12531 L
.34208 .07219 L
.34479 .04892 L
Mistroke
.34598 .04039 L
.34728 .03232 L
.34843 .02639 L
.34966 .02133 L
.35034 .01913 L
.35096 .01751 L
.35159 .01624 L
.35187 .01579 L
.35217 .01539 L
.35247 .01509 L
.35275 .01489 L
.35301 .01477 L
.35329 .01472 L
.35359 .01475 L
.35388 .01486 L
.35419 .01507 L
.35436 .01523 L
.35452 .01541 L
.35513 .01632 L
.35548 .01701 L
.3558 .01775 L
.35701 .02147 L
.35804 .02584 L
.35918 .03188 L
.36148 .04798 L
.36394 .07087 L
.3662 .09647 L
.37127 .16804 L
.38091 .33603 L
.39019 .49078 L
.39498 .55056 L
.3974 .57301 L
.3987 .58265 L
.40007 .59088 L
.40124 .59627 L
.40185 .59851 L
.40251 .60044 L
.40282 .60118 L
.40312 .60178 L
.40341 .60227 L
.40367 .60264 L
.40392 .60292 L
.40419 .60313 L
.40446 .60327 L
.40475 .60332 L
.40491 .60331 L
.40509 .60326 L
.40541 .60308 L
.40572 .6028 L
.40601 .60243 L
Mistroke
.40635 .60188 L
.40666 .60126 L
.40736 .59948 L
.40797 .59749 L
.40862 .59488 L
.40981 .58896 L
.41211 .57312 L
.41464 .54953 L
.41975 .48471 L
.42955 .31903 L
.43898 .15677 L
.44145 .12088 L
.44413 .08679 L
.44645 .06212 L
.44901 .04059 L
.4502 .03272 L
.45149 .02582 L
.4527 .02082 L
.45381 .01754 L
.45442 .01626 L
.45472 .01579 L
.45499 .01542 L
.45515 .01525 L
.45532 .01508 L
.45562 .01487 L
.45579 .01479 L
.45597 .01474 L
.45612 .01472 L
.45629 .01472 L
.45646 .01476 L
.45663 .01482 L
.45694 .015 L
.45711 .01515 L
.45727 .01531 L
.45764 .01577 L
.45825 .01683 L
.4589 .01835 L
.4602 .0226 L
.4614 .02787 L
.4641 .04428 L
.46648 .06342 L
.469 .08767 L
.47822 .19798 L
.48335 .26118 L
.48803 .31092 L
.49036 .33113 L
.49289 .34882 L
.49404 .3553 L
.49527 .36097 L
.49632 .36482 L
Mistroke
.49748 .36797 L
.49808 .36915 L
.4984 .36965 L
.49874 .37008 L
.49906 .37039 L
.49936 .3706 L
.49965 .37073 L
.49993 .37078 L
.5002 .37077 L
.50049 .37068 L
.50074 .37054 L
.50101 .37033 L
.5013 .37003 L
.50161 .36963 L
.50218 .36869 L
.50283 .36725 L
.50354 .36527 L
.50482 .36058 L
.50724 .34807 L
.50951 .33214 L
.51203 .31037 L
.51712 .25564 L
.52686 .13451 L
.53133 .08427 L
.53387 .06032 L
.53623 .04192 L
.53858 .02797 L
.53989 .02224 L
.54109 .01839 L
.54174 .01684 L
.54235 .01579 L
.54266 .01538 L
.54301 .01504 L
.54319 .01491 L
.54337 .01481 L
.54355 .01475 L
.54371 .01472 L
.54403 .01474 L
.54432 .01484 L
.54449 .01494 L
.54465 .01506 L
.54499 .0154 L
.54529 .0158 L
.54561 .01633 L
.5462 .01756 L
.54678 .01911 L
.54739 .02114 L
.54851 .02578 L
.54983 .03293 L
.55104 .04095 L
Mistroke
.55366 .06324 L
.55615 .09009 L
.56544 .22957 L
.57534 .40593 L
.58025 .48472 L
.58266 .51787 L
.58486 .5442 L
.58697 .56528 L
.58927 .5833 L
.59047 .59048 L
.59159 .59576 L
.59219 .59806 L
.59276 .59984 L
.59342 .60145 L
.59371 .60199 L
.59402 .60248 L
.59433 .60284 L
.5946 .60309 L
.59488 .60325 L
.59515 .60331 L
.59545 .60329 L
.59574 .60318 L
.59605 .60294 L
.59622 .60277 L
.59638 .60257 L
.597 .60155 L
.59735 .60079 L
.59767 .59996 L
.59888 .59581 L
.59992 .59094 L
.60106 .58426 L
.60335 .56664 L
.60584 .54171 L
.6081 .51423 L
.61317 .43891 L
.62285 .26805 L
.63216 .11766 L
.63697 .06173 L
.6394 .04126 L
.64077 .0322 L
.64207 .02532 L
.64324 .02058 L
.64391 .01851 L
.64453 .01699 L
.64482 .01641 L
.6451 .01593 L
.64535 .01557 L
.64561 .01526 L
.6459 .015 L
.64617 .01483 L
Mistroke
.64646 .01473 L
.64677 .01472 L
.64694 .01475 L
.64711 .01482 L
.64728 .01491 L
.64743 .01502 L
.64773 .01528 L
.64804 .01566 L
.64868 .01673 L
.64939 .01839 L
.65065 .02249 L
.65183 .02766 L
.65422 .04173 L
.65673 .06136 L
.66121 .10646 L
.67045 .22014 L
.6756 .28122 L
.68028 .32665 L
.68262 .34411 L
.68385 .35167 L
.68515 .35836 L
.68629 .36307 L
.68689 .36512 L
.68754 .36698 L
.68814 .36836 L
.68868 .36936 L
.68894 .36974 L
.68923 .37009 L
.68948 .37034 L
.68975 .37055 L
.6899 .37064 L
.69007 .37071 L
.69037 .37078 L
.69053 .37078 L
.69071 .37076 L
.69088 .37071 L
.69104 .37064 L
.69134 .37046 L
.69151 .37031 L
.69166 .37016 L
.69225 .36939 L
.69278 .36845 L
.69335 .36713 L
.69452 .36358 L
.69579 .35843 L
.69715 .35142 L
.69961 .33506 L
.70448 .29062 L
.7096 .23143 L
.71885 .11665 L
Mistroke
.7215 .08744 L
.72401 .0633 L
.72644 .04377 L
.72751 .03661 L
.72869 .02983 L
.72976 .02471 L
.7309 .02035 L
.73153 .01846 L
.73211 .01707 L
.73269 .01599 L
.73297 .01558 L
.73324 .01527 L
.73352 .01501 L
.73383 .01482 L
.73414 .01473 L
.73431 .01472 L
.73446 .01473 L
.73473 .01481 L
.73502 .01497 L
.73532 .01524 L
.7356 .01556 L
.73625 .01663 L
.73684 .01797 L
.73752 .01995 L
.73817 .02226 L
.74052 .03423 L
.74171 .04236 L
.74301 .05288 L
.74748 .1006 L
.75219 .16762 L
.75725 .25296 L
.76725 .4302 L
.77225 .50611 L
.77468 .53673 L
.77688 .56004 L
.77919 .57943 L
.78025 .58648 L
.78136 .59262 L
.78194 .59523 L
.78256 .59768 L
.78314 .59954 L
.78366 .60092 L
.78428 .60215 L
.78462 .60264 L
.78478 .60282 L
.78495 .60298 L
.78524 .60319 L
.78552 .6033 L
.78582 .60331 L
.78598 .60328 L
Mistroke
.78614 .60321 L
.78643 .60303 L
.78673 .60273 L
.78702 .60235 L
.78728 .60192 L
.78792 .60054 L
.78853 .59882 L
.78973 .59417 L
.79104 .58733 L
.79337 .57056 L
.79553 .55024 L
.80008 .4937 L
.80508 .41503 L
.81486 .24079 L
.81937 .16554 L
.82428 .09644 L
.82695 .06664 L
.82942 .04468 L
.83178 .02917 L
.8331 .02292 L
.83367 .02076 L
.83429 .01877 L
.83486 .0173 L
.83548 .01609 L
.83582 .01558 L
.83613 .01522 L
.83644 .01496 L
.83673 .0148 L
.837 .01472 L
.83729 .01473 L
.83753 .01479 L
.8378 .01494 L
.83809 .01517 L
.8384 .01552 L
.83897 .01638 L
.83961 .01775 L
.84032 .01969 L
.84161 .02443 L
.84286 .03047 L
.84402 .03728 L
.84899 .07799 L
.8535 .12742 L
.86321 .24822 L
.86766 .29799 L
.87019 .32185 L
.87255 .34042 L
.87488 .35471 L
.87619 .36083 L
.87738 .36517 L
.87799 .36692 L
Mistroke
.87864 .36842 L
.87898 .36906 L
.87935 .36964 L
.87969 .37008 L
.88 .37039 L
.8803 .3706 L
.88062 .37074 L
.88094 .37078 L
.88112 .37077 L
.88129 .37073 L
.88159 .3706 L
.88187 .37041 L
.88219 .37011 L
.88249 .36974 L
.88307 .36881 L
.88361 .36767 L
.88484 .36412 L
.88605 .35942 L
.88734 .35303 L
.88967 .33812 L
.89181 .32102 L
.90144 .21431 L
.91071 .10096 L
.91549 .05473 L
.91816 .03559 L
.91931 .02909 L
.92057 .02329 L
.92176 .01917 L
.9224 .01747 L
.92301 .01625 L
.9233 .01579 L
.92357 .01543 L
.92382 .01516 L
.92409 .01495 L
.92438 .01479 L
.92464 .01472 L
.92493 .01473 L
.92525 .01483 L
.92556 .01503 L
.92573 .01517 L
.9259 .01535 L
.9265 .01621 L
.92684 .01686 L
.9272 .01768 L
.92785 .01948 L
.92913 .02429 L
.9303 .03009 L
.93272 .04649 L
.93495 .06658 L
.94 .12776 L
Mistroke
.94956 .28566 L
.95875 .44693 L
.96387 .52113 L
.9661 .54732 L
.96854 .57063 L
.97058 .58557 L
.97147 .59075 L
.97247 .59546 L
.9734 .59888 L
.97427 .60122 L
.97475 .60214 L
.97519 .60275 L
.97543 .60299 L
.97568 .60317 L
.97594 .60328 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`00033ooooo0ol0000^ooooo`Go0000;oooool3o`00037ooooo0ol0000^oooo
o`?o00002_ooool001Kooooo00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`0^oooo
o`04o`000?ooooooooooo`0002kooooo00Go0000ooooooooooooooooo`00000aooooo`03o`000?oo
oooooooo02cooooo00Go0000ooooooooooooooooo`000009ooooo`005_ooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0/ooooo`Go0000<Oooool00ol0003oooooooooo`07ooooo`005_ooool01?l0003ooooooooo
ool0000`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool2o`0002oooooo
00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`07ooooo`005_ooool01?l0003ooooo
ooooool0000`ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000boooo
o`03o`000?oooooooooo02gooooo00?o0000ooooool00000;_ooool4o`0000[ooooo000Fooooo`04
o`000?ooooooooooo`0002oooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000;_ooool0
1Ol0003ooooooooooooooooo0000033ooooo0_l0000^ooooo`03o`000?oooooooooo00_ooooo000G
ooooo`;o0000<Oooool00ol0003oooooooooo`0^ooooo`?o0000<?ooool3o`0003;ooooo00?o0000
ooooooooool0;?ooool5o`0000Wooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo000Aoooooooo00003Ol00003ooooo`004Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo0?oooooo2Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`0Aooooo`;o003o5Oooool2o`00oa[ooooo0_l00?lEooooo`;o003o6Oooool2o`00oaKooooo0_l0
0?lIooooo`;o003o5Oooool3o`00oaWooooo0_l00?lEooooo`;o003o4oooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`0Aooooo`;o003o5Oooool3o`00oaSooooo00?o003o
ooooool00?l05Oooool2o`00oaWooooo00?o003oooooool00?l05Oooool2o`00oaWooooo0_l00?lE
ooooo`03o`00oooooooo003o01Sooooo0ol00?lEooooo`?o003o4_ooool00ol0003oooooooooo`01
ooooo`004Oooool2o`00017ooooo00?o003oooooool00?l05Oooool00ol00?ooooooo`00o`0Hoooo
o`03o`00oooooooo003o01Gooooo00?o003oooooool00?l06?ooool00ol00?ooooooo`00o`0Doooo
o`03o`00oooooooo003o01Wooooo00?o003oooooool00?l05?ooool00ol00?ooooooo`00o`0Hoooo
o`04o`00ooooooooooooo`00oaCooooo00?o003oooooool00?l04Oooool2o`0000?ooooo000Aoooo
o`03o`000?oooooooooo013ooooo00Co003ooooooooooooo003o4oooool01?l00?ooooooooooool0
0?lHooooo`03o`00oooooooo003o01Cooooo00Co003ooooooooooooo003o6?ooool00ol00?oooooo
o`00o`0Dooooo`04o`00ooooooooooooo`00oaOooooo00Co003ooooooooooooo003o5?ooool00ol0
0?ooooooo`00o`0Hooooo`04o`00ooooooooooooo`00oaCooooo00?o003oooooool00?l04_ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0@ooooo`04o`00oooooooooooo
o`00oa?ooooo00Co003ooooooooooooo003o6?ooool01?l00?ooooooooooool00?lCooooo`04o`00
ooooooooooooo`00oaSooooo00?o003oooooool00?l05?ooool01?l00?ooooooooooool00?lGoooo
o`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5oooool01?l00?oooooooooo
ool00?lCooooo`04o`00ooooooooooooo`00oa;ooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool04?ooool01?l00?ooooooooooool00?lCooooo`04o`00ooooooooooooo`00
oaSooooo00Co003ooooooooooooo003o4oooool01?l00?ooooooooooool00?lGooooo`04o`00oooo
ooooooooo`00oaCooooo00Co003ooooooooooooo003o5oooool01?l00?ooooooooooool00?lDoooo
o`04o`00ooooooooooooo`00oaOooooo00Co003ooooooooooooo003o4oooool01?l00?oooooooooo
ool00?lBooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo013ooooo00Co
003ooooooooooooo003o4oooool01?l00?ooooooooooool00?lHooooo`04o`00ooooooooooooo`00
oa?ooooo00Co003ooooooooooooo003o5oooool01Ol00?oooooooooooooooooo003o01;ooooo00Go
003oooooooooooooooooo`00o`0Gooooo`05o`00ooooooooooooooooool00?l04_ooool01Ol00?oo
oooooooooooooooo003o01Oooooo00Co003ooooooooooooo003o4oooool01?l00?ooooooooooool0
0?lBooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00oooooo00Go003o
ooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l05_ooool01Ol00?oooooo
oooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Fooooo`05o`00oooooooooooo
ooooool00?l04_ooool01Ol00?oooooooooooooooooo003o01Oooooo00Go003ooooooooooooooooo
o`00o`0Booooo`05o`00ooooooooooooooooool00?l05_ooool01Ol00?oooooooooooooooooo003o
01?ooooo00Go003oooooooooooooooooo`00o`0Aooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00oooooo00Go003oooooooooooooooooo`00o`0Booooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooooooo003o01?ooooo00Go
003oooooooooooooooooo`00o`0Fooooo`05o`00ooooooooooooooooool00?l04_ooool01Ol00?oo
oooooooooooooooo003o01Oooooo00Go003oooooooooooooooooo`00o`0Booooo`05o`00oooooooo
ooooooooool00?l05_ooool01Ol00?oooooooooooooooooo003o01;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0?ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00004?oo
ool01Ol00?oooooooooooooooooo003o01;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Dooooo`05o`00ooooooooooooooooool00?l04_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`0Booooo`05o`00oooooooooooo
ooooool00?l05oooool01Ol00?oooooooooooooooooo003o01;ooooo00Go003ooooooooooooooooo
o`00o`0Fooooo`05o`00ooooooooooooooooool00?l04_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00kooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`0Booooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013o
oooo00Go003oooooooooooooooooo`00o`0Fooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04?ooool01Ol00?oooooooooooooooooo003o01Kooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03oooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01Cooooo00Go003oooooooooooooooooo`00o`0Booooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool03oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0?oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo01Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool03oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol0003oooooooooo`01ooooo`002?oo
ool5o`0000Cooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00oooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03ooo
ool00ol0003oooooooooo`01ooooo`000_ooool5o`0000?ooooo00?o0000ooooooooool01?ooool3
o`0000kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`?o00000oooool0
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
01?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00kooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0>ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003o
ooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool03_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000oooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo017ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0=ooooo`;o00000oooool0017ooooo00?o0000oooooooo
ool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo017ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool03_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00go
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool03Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool00Oooool0017ooooo0_l0
000>ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00003_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo0_l00003ooooo`004Oooool00ol0003o
ooooooooo`0=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`0=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0=oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`01oooo
o`002_ooool2o`0000Gooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool03?ooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`oo
000000?o003oo`000?l000002?l000000ol00?oo0000o`000009o`000003o`00ool0003o000000So
000000?o003oo`000?l000003_l000000ol00?oo0000o`000008o`000003o`00ool0003o000000Wo
000000?o003oo`000?l000001ol000000ol00?oo0000o`00000?o`000003o`00ool0003o000000So
000000?o003oo`000?l000002Ol000000ol00?oo0000o`000007o`000003o`00ool0003o000000ko
000000?o003oo`000?l000002Ol000000ol00?oo0000o`000008o`000003o`00ool0003o000000So
000000?o003oo`000?l000003_l000000ol00?oo0000o`000008o`000003o`00ool0003o000000Wo
000000?o003oo`000?l000002?l000000ol00?oo0000o`00000=o`0000?ooooo0009ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool03?ooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03
o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`0<ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool03?oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool03?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`0<ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool03?ooool00ol0
003oooooooooo`01ooooo`004Oooool2o`0000gooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0;ooooo`;o00000oooool0017ooooo00?o0000ooooooooool02oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool02oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00cooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool02oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00cooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00cooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0
2oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00_ooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00_ooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000<ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo
00_ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00_ooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`0;ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00_ooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0;oooo
o`03o`000?oooooooooo007ooooo000Aooooo`;o00003?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00[ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0;ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02ooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02oooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02oooool00ol0003oooooooooo`01ooooo`002?ooool5o`0000Cooooo
00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo
00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol0003ooooo
ooooo`01ooooo`002_ooool00ol0003oooooooooo`04ooooo`?o00002_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Wooooo0ol00003ooooo`002oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0:
ooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool0
0ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool02_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o0000
ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`000?oooooooooo00[ooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00[ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0:ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0
3_ooool01Ol00?oooooooooooooooooo003o013ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l04?ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0>oooo
o`05o`00ooooooooooooooooool00?l04?ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool03_ooool01Ol0
0?oooooooooooooooooo003o013ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0>
ooooo`05o`00ooooooooooooooooool00?l04?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0>ooooo`05o`00oooo
ooooooooooooool00?l04?ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo007ooooo
000Aooooo`;o00002oooool00ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l0
4?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00kooooo00Go003ooooooooooooo
ooooo`00o`0@ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool03_ooool01Ol00?oo
oooooooooooooooo003o013ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00kooooo00Go003oooooooooooooooooo`00o`0@ooooo`03o`00oooooooo
oooo00Wooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo
00kooooo00Go003oooooooooooooooooo`00o`0@ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool03_ooool01Ol00?oooooooooooooooooo003o013ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l04?ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00kooooo00Go003oooooooooooooooooo`00o`0Aooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool03_ooool01Ol00?oooooooooooooooooo003o
013ooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`0:ooooo`03o`00oooooooooooo00kooooo00Go003oooooooooooooooooo`00o`0@oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool03_ooool01Ol00?oooooooooooooooooo
003o013ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0?ooooo`05o`00oooooooo
ooooooooool00?l04?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00kooooo00Go
003oooooooooooooooooo`00o`0Aooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
3_ooool01Ol00?oooooooooooooooooo003o013ooooo00?o003oooooooooool02_ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00kooooo
00Go003oooooooooooooooooo`00o`0@ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool03_ooool01?l00?ooooooooooool00?lAooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool03oooool01Ol00?oooooooooooooooooo003o013ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0?ooooo`04o`00ooooooooooooo`00oa7ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l04?ooool00ol00?oooooo
ooooo`0:ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o
003oooooooooool03_ooool01Ol00?oooooooooooooooooo003o013ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0?ooooo`04o`00ooooooooooooo`00oa7ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0?ooooo`04o`00ooooooooooooo`00oa7ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0?ooooo`04o`00ooooooooooooo`00oa7ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l04?oo
ool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00[ooooo00?o003oooooooooool03oooool00ol00?ooooooo`00o`0Aooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool04?ooool00ol00?ooooooo`00o`0Aooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool03oooool01?l00?ooooooooooool00?lAooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool03oooool01?l00?ooooooooooool00?lAooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool03oooool00ol00?ooooooo`00o`0Aooooo`03o`00
oooooooooooo00[ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02_oo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo003o017ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo003o017ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo003o017ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo003o01;ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo003o017ooooo00?o003oooooooooool02_oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooo
oooo00oooooo0ol00?lAooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04?ooool3
o`00oa7ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0@ooooo`;o003o4_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo013ooooo0_l00?lBooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool03oooool3o`00oa;ooooo00?o003oooooooooool02Oooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0000[ooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04?ooool2o`00
oa;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0@ooooo`;o003o4_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`08ooooo`;o00000oooool0017ooooo00?o0000ooooooooool02Oooool00ol00?oo
ooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0Tooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`09ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Wooooo
00?o003oooooooooool09Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02Gooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool09?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02Gooooo
00?o003oooooooooool02Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`09ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo02Cooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool02Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00Wooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Uoooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo02Gooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo02Cooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Wooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l0000:ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
9Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo0_l00003ooooo`004Ooo
ool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo02Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool09Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0Vooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool09_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool02Oooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo02Go
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo00Wo
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02Oooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool09Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0Vooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool09Oooool00ol00?oooooo
ooooo`09ooooo`03o`000?oooooooooo007ooooo000:ooooo`?o00001?ooool00ol0003ooooooooo
o`09ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool09_ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool00Oooool000_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool09_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Kooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Sooooo00?o0000
ooooooooool00Oooool000Sooooo1Ol00004ooooo`?o00002Oooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo02Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`06oooo
o`?o00000oooool000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`09oooo
o`03o`00oooooooooooo02Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo02Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo00Sooooo00?o0000ooooooooool00Oooool000Wooooo00?o0000ooooool0
00001Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo02Kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool09_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Kooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Sooooo00?o0000oooooooo
ool00Oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0
9_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
9_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0
2?ooool00ol0003oooooooooo`01ooooo`002oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Wooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo02Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Vooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo02Kooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`09ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool09oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
02Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool09oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0Wooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool09_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool02?ooool00ol0003o
ooooooooo`01ooooo`004Oooool2o`0000Wooooo00?o003oooooooooool09oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Wooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool09_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool01oooool2o`0000?ooooo
000Aooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool09oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0Xooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo02Oooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Oooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00Sooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0Woooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo02Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Xoooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Sooooo00?o003ooooooooo
ool09oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02Oooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Oooooo00?o003ooooooooo
ool02?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`00
oooooooooooo02Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Wooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo02Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Wooooo`03o`00
oooooooooooo00Sooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool09ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09ooo
ool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00Sooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo02Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo02Oooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`00
00Wooooo00?o003oooooooooool09oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
02Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
02Sooooo00?o003oooooooooool01_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Oo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02So
oooo00?o003oooooooooool01oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`08ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Wooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0:?ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Xooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool02?ooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool09oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo02Sooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool0:?ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Y
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool01oooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo02Wooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool0:Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Wooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0Xooooo`03o`00oooooooooooo00Oooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0Yooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo02Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Yooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`07ooooo`03
o`000?oooooooooo007ooooo000Aooooo`;o00002?ooool00ol00?ooooooooooo`0Yooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo02Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Yooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`06ooooo`;o0000
0oooool0017ooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0Yooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo02[ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Yooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?ooooooooooo`07ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0:Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0:Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool01oooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo
02Wooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
02[ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo
00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01oooool00ol00?oo
ooooooooo`0Yooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0:Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0Zooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0:Oooool00ol00?oo
ooooooooo`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Oooooo
00?o003oooooooooool0:Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo02Wooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool0:_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Wooooo
00?o003oooooooooool01oooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o
0000ooooooooool01oooool00ol00?ooooooooooo`0Yooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool0:Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02[ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0:oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo0008
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`06ooooo`03o`00oooo
oooooooo02_ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Zooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo02[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0[ooooo`03o`00oooo
oooooooo00Kooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`00
0004ooooo`?o00001_ooool00ol00?ooooooooooo`0[ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool0:_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02[ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool0:oooool00ol00?ooooooooooo`04ooooo`?o00000oooool000Sooooo1?l00005
ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Z
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo02_ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`01
ooooo`002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o003ooooo
ooooool0:oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02_ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool0:_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02_ooooo00?o003ooooo
ooooool01_ooool00ol0003oooooooooo`01ooooo`002Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo02_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0[ooooo`05
o`00ooooooooooooooooool00?l0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
02_ooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`01ooooo`002_ooool2o`0000Go
oooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0[ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02_o
oooo00Go003oooooooooooooooooo`00o`0]ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0:oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Kooooo00?o003oooooooooool0:oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo02_ooooo00Go003oooooooooooooooooo`00o`0^ooooo`05o`00oooooooooooo
ooooool00?l0;Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02_ooooo00?o003o
ooooooooool01_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06oooo
o`03o`00oooooooooooo02cooooo00Co003ooooooooooooo003o;_ooool01Ol00?oooooooooooooo
oooo003o02kooooo00Go003oooooooooooooooooo`00o`0]ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0:oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool0;?ooool01?l00?oooooooooo
ool00?l^ooooo`05o`00ooooooooooooooooool00?l0;_ooool01Ol00?oooooooooooooooooo003o
02kooooo00Go003oooooooooooooooooo`00o`0]ooooo`03o`00oooooooooooo00Kooooo00?o0000
ooooooooool00Oooool0017ooooo0_l00007ooooo`03o`00oooooooooooo02cooooo00Co003ooooo
oooooooo003o;_ooool01Ol00?oooooooooooooooooo003o02kooooo00Go003ooooooooooooooooo
o`00o`0^ooooo`05o`00ooooooooooooooooool00?l0;Oooool00ol00?ooooooooooo`05ooooo`;o
00000oooool0017ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0/ooooo`04o`00
ooooooooooooo`00obkooooo00Go003oooooooooooooooooo`00o`0^ooooo`05o`00oooooooooooo
ooooool00?l0;_ooool01Ol00?oooooooooooooooooo003o02gooooo00?o003oooooooooool01_oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooo
oooo02cooooo00Co003ooooooooooooo003o;oooool01?l00?ooooooooooool00?l^ooooo`05o`00
ooooooooooooooooool00?l0;_ooool01?l00?ooooooooooool00?l_ooooo`03o`00oooooooooooo
00Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool00ol00?oo
ooooooooo`0]ooooo`04o`00ooooooooooooo`00oboooooo00Co003ooooooooooooo003o;_ooool0
1Ol00?oooooooooooooooooo003o02kooooo00Co003ooooooooooooo003o;oooool00ol00?oooooo
ooooo`05ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Gooooo00?o
003oooooooooool0;Oooool01?l00?ooooooooooool00?l_ooooo`04o`00ooooooooooooo`00oboo
oooo00?o003oooooool00?l0;oooool01?l00?ooooooooooool00?l_ooooo`03o`00oooooooooooo
00Gooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool00ol00?oo
ooooooooo`0]ooooo`04o`00ooooooooooooo`00oboooooo00?o003oooooool00?l0<?ooool00ol0
0?ooooooo`00o`0`ooooo`03o`00oooooooo003o02oooooo00?o003oooooooooool01Oooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo02ko
oooo0_l00?l`ooooo`03o`00oooooooo003o033ooooo00?o003oooooool00?l0<?ooool2o`00oc7o
oooo00?o003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`04ooooo`03o`00oooooooooooo02oooooo0_l00?laooooo`;o003o<?ooool3o`00oc3ooooo
0_l00?laooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00Oooool0017ooooo0_l0
0005ooooo`03o`00oooooooooooo02oooooo0_l00?laooooo`03o`00oooooooooooo033ooooo00?o
003oooooooooool0;oooool2o`00oc7ooooo00?o003oooooooooool00oooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo0?oooooo2Oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`01ooooo`004Oooooooo`0000go00000oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.478464, -4.17447, \
0.0197116, 0.0645854}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CTFT of infinite-length x(t)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X[f_] = 
        FourierTransform[x[t], t, 
            f]\  /. {\[Delta][b_\ a_ + f_\ a_] \[Rule] \[Delta][b + f]/
                a, \[Delta][\ a_ + f_\ a_] \[Rule] \[Delta][1 + f]/
                a};\)\), "\[IndentingNewLine]", 
    \(X[f]\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"2", " ", 
          RowBox[{
            InterpretationBox["\[Delta]",
              DiracDelta,
              Editable->False,
              Selectable->False], "(", \(f - 2\), ")"}]}], "+", 
        RowBox[{
          InterpretationBox["\[Delta]",
            DiracDelta,
            Editable->False,
            Selectable->False], "(", \(f - 1\), ")"}], "+", 
        RowBox[{
          InterpretationBox["\[Delta]",
            DiracDelta,
            Editable->False,
            Selectable->False], "(", "f", ")"}], "+", 
        RowBox[{
          InterpretationBox["\[Delta]",
            DiracDelta,
            Editable->False,
            Selectable->False], "(", \(f + 1\), ")"}], "+", 
        RowBox[{"2", " ", 
          RowBox[{
            InterpretationBox["\[Delta]",
              DiracDelta,
              Editable->False,
              Selectable->False], "(", \(f + 2\), ")"}]}]}], 
      TraditionalForm]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gX = 
        Plot[Evaluate[PlotConvert[X[f],  .04]], {f, \(-2\) fs, 2  fs}, 
          PlotStyle \[Rule] {Blue, Thickness[ .005]}, \ 
          PlotPoints \[Rule] 2000, \ 
          PlotRange \[Rule] {\(- .02\), 3.12}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.00393652 0.196826 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.02381 .00394 m
.02427 .00394 L
.02478 .00394 L
.02525 .00394 L
.02571 .00394 L
.0262 .00394 L
.02667 .00394 L
.02716 .00394 L
.02764 .00394 L
.0281 .00394 L
.02859 .00394 L
.02907 .00394 L
.02952 .00394 L
.03 .00394 L
.03047 .00394 L
.03097 .00394 L
.03144 .00394 L
.0319 .00394 L
.03239 .00394 L
.03286 .00394 L
.03336 .00394 L
.03384 .00394 L
.0343 .00394 L
.03479 .00394 L
.03527 .00394 L
.03572 .00394 L
.03621 .00394 L
.03668 .00394 L
.03717 .00394 L
.03765 .00394 L
.03811 .00394 L
.0386 .00394 L
.03907 .00394 L
.03953 .00394 L
.04001 .00394 L
.04047 .00394 L
.04097 .00394 L
.04144 .00394 L
.0419 .00394 L
.04239 .00394 L
.04286 .00394 L
.04335 .00394 L
.04383 .00394 L
.0443 .00394 L
.04479 .00394 L
.04526 .00394 L
.04572 .00394 L
.0462 .00394 L
.04667 .00394 L
.04716 .00394 L
Mistroke
.04764 .00394 L
.0481 .00394 L
.04859 .00394 L
.04906 .00394 L
.04956 .00394 L
.05004 .00394 L
.0505 .00394 L
.05099 .00394 L
.05147 .00394 L
.05193 .00394 L
.05241 .00394 L
.05288 .00394 L
.05338 .00394 L
.05386 .00394 L
.05432 .00394 L
.05481 .00394 L
.05528 .00394 L
.05573 .00394 L
.05622 .00394 L
.05668 .00394 L
.05718 .00394 L
.05765 .00394 L
.05811 .00394 L
.0586 .00394 L
.05907 .00394 L
.05957 .00394 L
.06005 .00394 L
.06051 .00394 L
.061 .00394 L
.06147 .00394 L
.06193 .00394 L
.06242 .00394 L
.06288 .00394 L
.06338 .00394 L
.06386 .00394 L
.06432 .00394 L
.06481 .00394 L
.06528 .00394 L
.06573 .00394 L
.06621 .00394 L
.06668 .00394 L
.06717 .00394 L
.06764 .00394 L
.0681 .00394 L
.06859 .00394 L
.06906 .00394 L
.06955 .00394 L
.07003 .00394 L
.0705 .00394 L
.07099 .00394 L
Mistroke
.07146 .00394 L
.07191 .00394 L
.0724 .00394 L
.07286 .00394 L
.07336 .00394 L
.07384 .00394 L
.07429 .00394 L
.07478 .00394 L
.07525 .00394 L
.07575 .00394 L
.07623 .00394 L
.0767 .00394 L
.07719 .00394 L
.07766 .00394 L
.07812 .00394 L
.0786 .00394 L
.07907 .00394 L
.07957 .00394 L
.08005 .00394 L
.08051 .00394 L
.081 .00394 L
.08147 .00394 L
.08192 .00394 L
.08241 .00394 L
.08287 .00394 L
.08336 .00394 L
.08384 .00394 L
.0843 .00394 L
.08479 .00394 L
.08525 .00394 L
.08575 .00394 L
.08623 .00394 L
.0867 .00394 L
.08719 .00394 L
.08766 .00394 L
.08812 .00394 L
.0886 .00394 L
.08907 .00394 L
.08956 .00394 L
.09004 .00394 L
.0905 .00394 L
.09099 .00394 L
.09146 .00394 L
.09196 .00394 L
.09244 .00394 L
.0929 .00394 L
.0934 .00394 L
.09387 .00394 L
.09433 .00394 L
.09482 .00394 L
Mistroke
.09528 .00394 L
.09578 .00394 L
.09626 .00394 L
.09672 .00394 L
.09721 .00394 L
.09768 .00394 L
.09814 .00394 L
.09862 .00394 L
.09909 .00394 L
.09958 .00394 L
.10006 .00394 L
.10052 .00394 L
.101 .00394 L
.10147 .00394 L
.10197 .00394 L
.10245 .00394 L
.10292 .00394 L
.10341 .00394 L
.10388 .00394 L
.10434 .00394 L
.10482 .00394 L
.10529 .00394 L
.10579 .00394 L
.10627 .00394 L
.10673 .00394 L
.10722 .00394 L
.10769 .00394 L
.10814 .00394 L
.10862 .00394 L
.10909 .00394 L
.10958 .00394 L
.11006 .00394 L
.11051 .00394 L
.111 .00394 L
.11147 .00394 L
.11197 .00394 L
.11245 .00394 L
.11291 .00394 L
.1134 .00394 L
.11387 .00394 L
.11433 .00394 L
.11481 .00394 L
.11528 .00394 L
.11577 .00394 L
.11625 .00394 L
.11671 .00394 L
.1172 .00394 L
.11767 .00394 L
.11817 .00394 L
.11865 .00394 L
Mistroke
.11911 .00394 L
.1196 .00394 L
.12008 .00394 L
.12054 .00394 L
.12102 .00394 L
.12149 .00394 L
.12199 .00394 L
.12247 .00394 L
.12293 .00394 L
.12342 .00394 L
.12389 .00394 L
.12434 .00394 L
.12482 .00394 L
.12529 .00394 L
.12578 .00394 L
.12626 .00394 L
.12672 .00394 L
.12721 .00394 L
.12768 .00394 L
.12817 .00394 L
.12865 .00394 L
.12912 .00394 L
.12961 .00394 L
.13008 .00394 L
.13054 .00394 L
.13102 .00394 L
.13149 .00394 L
.13198 .00394 L
.13246 .00394 L
.13292 .00394 L
.13341 .00394 L
.13388 .00394 L
.13433 .00394 L
.13482 .00394 L
.13528 .00394 L
.13577 .00394 L
.13625 .00394 L
.13671 .00394 L
.13719 .00394 L
.13766 .00394 L
.13816 .00394 L
.13864 .00394 L
.1391 .00394 L
.13959 .00394 L
.14006 .00394 L
.14052 .00394 L
.141 .00394 L
.14147 .00394 L
.14196 .00394 L
.14244 .00394 L
Mistroke
.1429 .00394 L
.14339 .00394 L
.14386 .00394 L
.14435 .00394 L
.14484 .00394 L
.1453 .00394 L
.14579 .00394 L
.14627 .00394 L
.14672 .00394 L
.14721 .00394 L
.14767 .00394 L
.14817 .00394 L
.14865 .00394 L
.14911 .00394 L
.1496 .00394 L
.15007 .00394 L
.15052 .00394 L
.15101 .00394 L
.15147 .00394 L
.15197 .00394 L
.15244 .00394 L
.1529 .00394 L
.15339 .00394 L
.15385 .00394 L
.15435 .00394 L
.15483 .00394 L
.15529 .00394 L
.15579 .00394 L
.15626 .00394 L
.15671 .00394 L
.1572 .00394 L
.15766 .00394 L
.15816 .00394 L
.15864 .00394 L
.1591 .00394 L
.15959 .00394 L
.16006 .00394 L
.16056 .00394 L
.16104 .00394 L
.1615 .00394 L
.16199 .00394 L
.16247 .00394 L
.16293 .00394 L
.16341 .00394 L
.16388 .00394 L
.16438 .00394 L
.16486 .00394 L
.16532 .00394 L
.16581 .00394 L
.16628 .00394 L
Mistroke
.16673 .00394 L
.16722 .00394 L
.16768 .00394 L
.16818 .00394 L
.16865 .00394 L
.16911 .00394 L
.1696 .00394 L
.17007 .00394 L
.17057 .00394 L
.17105 .00394 L
.17151 .00394 L
.172 .00394 L
.17248 .00394 L
.17293 .00394 L
.17342 .00394 L
.17388 .00394 L
.17438 .00394 L
.17486 .00394 L
.17532 .00394 L
.17581 .00394 L
.17628 .00394 L
.17673 .00394 L
.17721 .00394 L
.17768 .00394 L
.17817 .00394 L
.17865 .00394 L
.1791 .00394 L
.17959 .00394 L
.18006 .00394 L
.18056 .00394 L
.18104 .00394 L
.1815 .00394 L
.18199 .00394 L
.18246 .00394 L
.18292 .00394 L
.1834 .00394 L
.18387 .00394 L
.18436 .00394 L
.18484 .00394 L
.1853 .00394 L
.18579 .00394 L
.18626 .00394 L
.18676 .00394 L
.18724 .00394 L
.1877 .00394 L
.18819 .00394 L
.18867 .00394 L
.18912 .00394 L
.18961 .00394 L
.19008 .00394 L
Mistroke
.19057 .00394 L
.19105 .00394 L
.19151 .00394 L
.192 .00394 L
.19248 .00394 L
.19293 .00394 L
.19341 .00394 L
.19388 .00394 L
.19437 .00394 L
.19485 .00394 L
.19531 .00394 L
.19579 .00394 L
.19626 .00394 L
.19676 .00394 L
.19724 .00394 L
.1977 .00394 L
.19819 .00394 L
.19867 .00394 L
.19912 .00394 L
.19961 .00394 L
.20007 .00394 L
.20057 .00394 L
.20105 .00394 L
.20151 .00394 L
.202 .00394 L
.20247 .00394 L
.20297 .00394 L
.20345 .00394 L
.20391 .00394 L
.20441 .00394 L
.20488 .00394 L
.20534 .00394 L
.20582 .00394 L
.20629 .00394 L
.20679 .00394 L
.20727 .00394 L
.20773 .00394 L
.20822 .00394 L
.20869 .00394 L
.20915 .00394 L
.20963 .00394 L
.2101 .00394 L
.21059 .00394 L
.21107 .00394 L
.21153 .00394 L
.21201 .00394 L
.21248 .00394 L
.21298 .00394 L
.21346 .00394 L
.21393 .00394 L
Mistroke
.21442 .00394 L
.21489 .00394 L
.21535 .00394 L
.21583 .00394 L
.2163 .00394 L
.2168 .00394 L
.21728 .00394 L
.21774 .00394 L
.21823 .00394 L
.2187 .00394 L
.21915 .00394 L
.21963 .00394 L
.2201 .00394 L
.22059 .00394 L
.22107 .00394 L
.22152 .00394 L
.22201 .00394 L
.22248 .00394 L
.22298 .00394 L
.22346 .00394 L
.22392 .00394 L
.22441 .00394 L
.22488 .00394 L
.22534 .00394 L
.22582 .00394 L
.22629 .00394 L
.22679 .00394 L
.22726 .00394 L
.22772 .00394 L
.22821 .00394 L
.22868 .00394 L
.22918 .00394 L
.22966 .00394 L
.23013 .00394 L
.23062 .00394 L
.23109 .00394 L
.23155 .00394 L
.23204 .00394 L
.2325 .00394 L
.233 .00394 L
.23348 .00394 L
.23394 .00394 L
.23443 .00394 L
.2349 .00394 L
.23536 .00394 L
.23584 .00394 L
.2363 .00394 L
.2368 .00394 L
.23727 .00394 L
.23773 .00394 L
Mistroke
.23822 .00394 L
.23869 .00394 L
.23919 .00394 L
.23967 .00394 L
.24013 .00394 L
.24062 .00394 L
.2411 .00394 L
.24155 .00394 L
.24204 .00394 L
.2425 .00394 L
.243 .00394 L
.24348 .00394 L
.24394 .00394 L
.24443 .00394 L
.2449 .00394 L
.24535 .00394 L
.24583 .00394 L
.2463 .00394 L
.24679 .00394 L
.24727 .00394 L
.24772 .00394 L
.24821 .00394 L
.24868 .00394 L
.24918 .00394 L
.24966 .00394 L
.25012 .00394 L
.25061 .00394 L
.25108 .00394 L
.25153 .00394 L
.25202 .00394 L
.25248 .00394 L
.25298 .00394 L
.25346 .00394 L
.25391 .00394 L
.2544 .00394 L
.25487 .00394 L
.25537 .00394 L
.25585 .00394 L
.25632 .00394 L
.25681 .00394 L
.25728 .00394 L
.25774 .00394 L
.25822 .00394 L
.25869 .00394 L
.25919 .00394 L
.25967 .00394 L
.26013 .00394 L
.26062 .00394 L
.26109 .00394 L
.26154 .00394 L
Mistroke
.26203 .00394 L
.26249 .00394 L
.26298 .00394 L
.26346 .00394 L
.26392 .00394 L
.26441 .00394 L
.26487 .00394 L
.26537 .00394 L
.26585 .00394 L
.26631 .00394 L
.26681 .00394 L
.26728 .00394 L
.26773 .00394 L
.26822 .00394 L
.26869 .00394 L
.26918 .00394 L
.26966 .00394 L
.27012 .00394 L
.27061 .00394 L
.27108 .00394 L
.27158 .00394 L
.27206 .00394 L
.27252 .00394 L
.27302 .00394 L
.27349 .00394 L
.27395 .00394 L
.27443 .00394 L
.2749 .00394 L
.2754 .00394 L
.27588 .00394 L
.27634 .00394 L
.27683 .00394 L
.2773 .00394 L
.27776 .00394 L
.27824 .00394 L
.2787 .00394 L
.2792 .00394 L
.27968 .00394 L
.28013 .00394 L
.28062 .00394 L
.28109 .00394 L
.28159 .00394 L
.28207 .00394 L
.28253 .00394 L
.28303 .00394 L
.2835 .00394 L
.28396 .00394 L
.28444 .00394 L
.28491 .00394 L
.2854 .00394 L
Mistroke
.28588 .00394 L
.28634 .00394 L
.28683 .00394 L
.2873 .00394 L
.28776 .00394 L
.28824 .00394 L
.2887 .00394 L
.2892 .00394 L
.28967 .00394 L
.29013 .00394 L
.29062 .00394 L
.29108 .00394 L
.29158 .00394 L
.29206 .00394 L
.29252 .00394 L
.29302 .00394 L
.29349 .00394 L
.29394 .00394 L
.29443 .00394 L
.29489 .00394 L
.29539 .00394 L
.29587 .00394 L
.29632 .00394 L
.29681 .00394 L
.29728 .00394 L
.29778 .00394 L
.29826 .00394 L
.29873 .00394 L
.29922 .00394 L
.29969 .00394 L
.30015 .00394 L
.30064 .00394 L
.3011 .00394 L
.3016 .00394 L
.30208 .00394 L
.30254 .00394 L
.30303 .00394 L
.3035 .00394 L
.30396 .00394 L
.30444 .00394 L
.3049 .00394 L
.3054 .00394 L
.30587 .00394 L
.30633 .00394 L
.30682 .00394 L
.30729 .00394 L
.30779 .00394 L
.30827 .00394 L
.30873 .00394 L
.30922 .00394 L
Mistroke
.3097 .00394 L
.31015 .00394 L
.31064 .00394 L
.3111 .00394 L
.3116 .00394 L
.31208 .00394 L
.31254 .00394 L
.31302 .00394 L
.3135 .00394 L
.31395 .00394 L
.31443 .00394 L
.31489 .00394 L
.31539 .00394 L
.31586 .00394 L
.31632 .00394 L
.31681 .00394 L
.31727 .00394 L
.31777 .00394 L
.31825 .00394 L
.31871 .00394 L
.3192 .00394 L
.31968 .00394 L
.32013 .00394 L
.32061 .00394 L
.32108 .00394 L
.32157 .00394 L
.32205 .00394 L
.32251 .00394 L
.323 .00394 L
.32347 .00394 L
.32397 .00394 L
.32445 .00394 L
.32491 .00394 L
.3254 .00394 L
.32588 .00394 L
.32633 .00394 L
.32682 .00394 L
.32729 .00394 L
.32778 .00394 L
.32826 .00394 L
.32872 .00394 L
.32921 .00394 L
.32968 .00394 L
.33014 .00394 L
.33062 .00394 L
.33108 .00394 L
.33158 .00394 L
.33205 .00394 L
.33251 .00394 L
.333 .00394 L
Mistroke
.33347 .00394 L
.33396 .00394 L
.33444 .00394 L
.33491 .00394 L
.3354 .00394 L
.33587 .00394 L
.33633 .00394 L
.33681 .00394 L
.33728 .00394 L
.33777 .00394 L
.33825 .00394 L
.33871 .00394 L
.3392 .00394 L
.33967 .00394 L
.34017 .00394 L
.34065 .00394 L
.34111 .00394 L
.34161 .00394 L
.34208 .00394 L
.34254 .00394 L
.34302 .00394 L
.34349 .00394 L
.34399 .00394 L
.34447 .00394 L
.34493 .00394 L
.34542 .00394 L
.34589 .00394 L
.34634 .00394 L
.34683 .00394 L
.34729 .00394 L
.34779 .00394 L
.34826 .00394 L
.34872 .00394 L
.34921 .00394 L
.34968 .00394 L
.35018 .00394 L
.35066 .00394 L
.35112 .00394 L
.35161 .00394 L
.35209 .00394 L
.35254 .00394 L
.35303 .00394 L
.35349 .00394 L
.35399 .00394 L
.35447 .00394 L
.35493 .00394 L
.35542 .00394 L
.35589 .00394 L
.35634 .00394 L
.35682 .00394 L
Mistroke
.35729 .00394 L
.35778 .00394 L
.35826 .00394 L
.35871 .00394 L
.3592 .00394 L
.35967 .00394 L
.36017 .00394 L
.36065 .00394 L
.36111 .00394 L
.3616 .00394 L
.36207 .00394 L
.36253 .00394 L
.36301 .00394 L
.36348 .00394 L
.36397 .00394 L
.36445 .00394 L
.36491 .00394 L
.36539 .00394 L
.36586 .00394 L
.36636 .00394 L
.36685 .00394 L
.36731 .00394 L
.3678 .00394 L
.36828 .00394 L
.36873 .00394 L
.36922 .00394 L
.36968 .00394 L
.37018 .00394 L
.37066 .00394 L
.37112 .00394 L
.37161 .00394 L
.37208 .00394 L
.37254 .00394 L
.37302 .00394 L
.37348 .00394 L
.37398 .00394 L
.37445 .00394 L
.37491 .00394 L
.3754 .00394 L
.37587 .00394 L
.37637 .00394 L
.37685 .00394 L
.37731 .00394 L
.3778 .00394 L
.37827 .00394 L
.37873 .00394 L
.37921 .00394 L
.37968 .00394 L
.38018 .00394 L
.38065 .00394 L
Mistroke
.38111 .00394 L
.3816 .00394 L
.38207 .00394 L
.38257 .00394 L
.38305 .00394 L
.38352 .00394 L
.38401 .00394 L
.38449 .00394 L
.38494 .00394 L
.38543 .00394 L
.3859 .00394 L
.38639 .00394 L
.38687 .00394 L
.38734 .00394 L
.38783 .00394 L
.3883 .00394 L
.38875 .00394 L
.38924 .00394 L
.3897 .00394 L
.3902 .00394 L
.39067 .00394 L
.39113 .00394 L
.39162 .00394 L
.39209 .00394 L
.39259 .00394 L
.39307 .00394 L
.39353 .00394 L
.39402 .00394 L
.3945 .00394 L
.39495 .00394 L
.39544 .00394 L
.39591 .00394 L
.3964 .00394 L
.39688 .00394 L
.39734 .00394 L
.39783 .00394 L
.3983 .00394 L
.39875 .00394 L
.39924 .00394 L
.3997 .00394 L
.40019 .00394 L
.40067 .00394 L
.40113 .00394 L
.40161 .00394 L
.40208 .00394 L
.40258 .00394 L
.40306 .00394 L
.40352 .00394 L
.40401 .00394 L
.40449 .00394 L
Mistroke
.40494 .00394 L
.40543 .00394 L
.40589 .00394 L
.40639 .00394 L
.40686 .00394 L
.40732 .00394 L
.40781 .00394 L
.40828 .00394 L
.40878 .00394 L
.40926 .00394 L
.40973 .00394 L
.41022 .00394 L
.41069 .00394 L
.41115 .00394 L
.41164 .00394 L
.4121 .00394 L
.4126 .00394 L
.41308 .00394 L
.41354 .00394 L
.41403 .00394 L
.4145 .00394 L
.41496 .00394 L
.41544 .00394 L
.41591 .00394 L
.4164 .00394 L
.41688 .00394 L
.41733 .00394 L
.41782 .00394 L
.41829 .00394 L
.41879 .00394 L
.41927 .00394 L
.41973 .00394 L
.42022 .00394 L
.4207 .00394 L
.42115 .00394 L
.42164 .00394 L
.4221 .00394 L
.4226 .00394 L
.42308 .00394 L
.42354 .00394 L
.42403 .00394 L
.4245 .00394 L
.42495 .00394 L
.42543 .00394 L
.4259 .00394 L
.42639 .00394 L
.42687 .00394 L
.42732 .00394 L
.42781 .00394 L
.42828 .00394 L
Mistroke
.42878 .00394 L
.42926 .00394 L
.42972 .00394 L
.43021 .00394 L
.43068 .00394 L
.43113 .00394 L
.43162 .00394 L
.43208 .00394 L
.43258 .00394 L
.43306 .00394 L
.43351 .00394 L
.434 .00394 L
.43447 .00394 L
.43497 .00394 L
.43545 .00394 L
.43592 .00394 L
.43641 .00394 L
.43688 .00394 L
.43734 .00394 L
.43782 .00394 L
.43829 .00394 L
.43879 .00394 L
.43927 .00394 L
.43973 .00394 L
.44022 .00394 L
.44069 .00394 L
.44114 .00394 L
.44162 .00394 L
.44209 .00394 L
.44258 .00394 L
.44306 .00394 L
.44352 .00394 L
.444 .00394 L
.44447 .00394 L
.44497 .00394 L
.44545 .00394 L
.44591 .00394 L
.4464 .00394 L
.44688 .00394 L
.44733 .00394 L
.44782 .00394 L
.44828 .00394 L
.44878 .00394 L
.44926 .00394 L
.44972 .00394 L
.4502 .00394 L
.45067 .00394 L
.45117 .00394 L
.45143 .00394 L
.45166 .00394 L
Mistroke
.45177 .00394 L
.45183 .00394 L
.45186 .00394 L
.45188 .00394 L
.4519 .00394 L
.45191 .39759 L
.45192 .39759 L
.45194 .39759 L
.452 .39759 L
.45212 .39759 L
.45257 .39759 L
.45269 .39759 L
.45275 .39759 L
.45281 .39759 L
.45284 .39759 L
.45285 .39759 L
.45285 .39759 L
.45287 .00394 L
.45288 .00394 L
.45289 .00394 L
.4529 .00394 L
.45294 .00394 L
.45306 .00394 L
.45351 .00394 L
.454 .00394 L
.45447 .00394 L
.45496 .00394 L
.45544 .00394 L
.4559 .00394 L
.45639 .00394 L
.45686 .00394 L
.45731 .00394 L
.4578 .00394 L
.45826 .00394 L
.45875 .00394 L
.45923 .00394 L
.45969 .00394 L
.46017 .00394 L
.46064 .00394 L
.46114 .00394 L
.46162 .00394 L
.46208 .00394 L
.46257 .00394 L
.46304 .00394 L
.4635 .00394 L
.46398 .00394 L
.46445 .00394 L
.46494 .00394 L
.46542 .00394 L
.46588 .00394 L
Mistroke
.46637 .00394 L
.46684 .00394 L
.46734 .00394 L
.46782 .00394 L
.46828 .00394 L
.46878 .00394 L
.46925 .00394 L
.46971 .00394 L
.47019 .00394 L
.47066 .00394 L
.47116 .00394 L
.47164 .00394 L
.4721 .00394 L
.47259 .00394 L
.47306 .00394 L
.47351 .00394 L
.47399 .00394 L
.47446 .00394 L
.47495 .00394 L
.4752 .00394 L
.47543 .00394 L
.47554 .00394 L
.47565 .00394 L
.47568 .00394 L
.4757 .00394 L
.47571 .00394 L
.47572 .20076 L
.47573 .20076 L
.47574 .20076 L
.47577 .20076 L
.47589 .20076 L
.47612 .20076 L
.47638 .20076 L
.4765 .20076 L
.47657 .20076 L
.4766 .20076 L
.47663 .20076 L
.47665 .20076 L
.47666 .20076 L
.47667 .00394 L
.47669 .00394 L
.47675 .00394 L
.47686 .00394 L
.47733 .00394 L
.47783 .00394 L
.47831 .00394 L
.47877 .00394 L
.47926 .00394 L
.47973 .00394 L
.48018 .00394 L
Mistroke
.48067 .00394 L
.48113 .00394 L
.48163 .00394 L
.48211 .00394 L
.48256 .00394 L
.48305 .00394 L
.48352 .00394 L
.48402 .00394 L
.4845 .00394 L
.48496 .00394 L
.48546 .00394 L
.48593 .00394 L
.48639 .00394 L
.48687 .00394 L
.48734 .00394 L
.48784 .00394 L
.48831 .00394 L
.48877 .00394 L
.48926 .00394 L
.48974 .00394 L
.49019 .00394 L
.49067 .00394 L
.49114 .00394 L
.49163 .00394 L
.49211 .00394 L
.49256 .00394 L
.49305 .00394 L
.49352 .00394 L
.49402 .00394 L
.4945 .00394 L
.49496 .00394 L
.49545 .00394 L
.49592 .00394 L
.49638 .00394 L
.49686 .00394 L
.49733 .00394 L
.49782 .00394 L
.4983 .00394 L
.49876 .00394 L
.49902 .00394 L
.49925 .00394 L
.49937 .00394 L
.49943 .00394 L
.49946 .00394 L
.49949 .00394 L
.49951 .00394 L
.49952 .00394 L
.49953 .20076 L
.49955 .20076 L
.49961 .20076 L
Mistroke
.49972 .20076 L
.50018 .20076 L
.5003 .20076 L
.50042 .20076 L
.50045 .20076 L
.50046 .20076 L
.50048 .20076 L
.50049 .00394 L
.5005 .00394 L
.50051 .00394 L
.50054 .00394 L
.50067 .00394 L
.50117 .00394 L
.50165 .00394 L
.50211 .00394 L
.5026 .00394 L
.50308 .00394 L
.50353 .00394 L
.50402 .00394 L
.50448 .00394 L
.50498 .00394 L
.50546 .00394 L
.50592 .00394 L
.50641 .00394 L
.50688 .00394 L
.50733 .00394 L
.50781 .00394 L
.50828 .00394 L
.50877 .00394 L
.50925 .00394 L
.5097 .00394 L
.51019 .00394 L
.51066 .00394 L
.51116 .00394 L
.51164 .00394 L
.5121 .00394 L
.51259 .00394 L
.51306 .00394 L
.51352 .00394 L
.514 .00394 L
.51447 .00394 L
.51496 .00394 L
.51544 .00394 L
.5159 .00394 L
.51638 .00394 L
.51685 .00394 L
.51735 .00394 L
.51784 .00394 L
.5183 .00394 L
.51879 .00394 L
Mistroke
.51927 .00394 L
.51972 .00394 L
.52021 .00394 L
.52067 .00394 L
.52117 .00394 L
.52165 .00394 L
.52211 .00394 L
.5226 .00394 L
.52284 .00394 L
.52307 .00394 L
.52318 .00394 L
.52324 .00394 L
.52329 .00394 L
.5233 .00394 L
.52332 .00394 L
.52333 .20076 L
.52335 .20076 L
.52341 .20076 L
.52352 .20076 L
.52399 .20076 L
.52411 .20076 L
.52423 .20076 L
.52426 .20076 L
.52427 .20076 L
.52428 .20076 L
.5243 .00394 L
.52431 .00394 L
.52432 .00394 L
.52435 .00394 L
.52448 .00394 L
.52498 .00394 L
.52546 .00394 L
.52592 .00394 L
.52642 .00394 L
.52689 .00394 L
.52735 .00394 L
.52784 .00394 L
.5283 .00394 L
.5288 .00394 L
.52928 .00394 L
.52974 .00394 L
.53023 .00394 L
.5307 .00394 L
.53116 .00394 L
.53164 .00394 L
.53211 .00394 L
.5326 .00394 L
.53308 .00394 L
.53354 .00394 L
.53402 .00394 L
Mistroke
.53449 .00394 L
.53499 .00394 L
.53547 .00394 L
.53594 .00394 L
.53643 .00394 L
.5369 .00394 L
.53736 .00394 L
.53784 .00394 L
.53831 .00394 L
.53881 .00394 L
.53928 .00394 L
.53974 .00394 L
.54023 .00394 L
.54071 .00394 L
.54116 .00394 L
.54164 .00394 L
.54211 .00394 L
.5426 .00394 L
.54307 .00394 L
.54353 .00394 L
.54402 .00394 L
.54449 .00394 L
.54499 .00394 L
.54547 .00394 L
.54593 .00394 L
.54642 .00394 L
.54666 .00394 L
.54689 .00394 L
.547 .00394 L
.54706 .00394 L
.54711 .00394 L
.54712 .00394 L
.54714 .00394 L
.54715 .39759 L
.54715 .39759 L
.54717 .39759 L
.54723 .39759 L
.54735 .39759 L
.54758 .39759 L
.54784 .39759 L
.54796 .39759 L
.54802 .39759 L
.54805 .39759 L
.54807 .39759 L
.54808 .39759 L
.5481 .00394 L
.54811 .00394 L
.54814 .00394 L
.5482 .00394 L
.54831 .00394 L
Mistroke
.54878 .00394 L
.54927 .00394 L
.54975 .00394 L
.55021 .00394 L
.55069 .00394 L
.55116 .00394 L
.55166 .00394 L
.55214 .00394 L
.5526 .00394 L
.5531 .00394 L
.55357 .00394 L
.55403 .00394 L
.55451 .00394 L
.55498 .00394 L
.55547 .00394 L
.55595 .00394 L
.55641 .00394 L
.5569 .00394 L
.55737 .00394 L
.55782 .00394 L
.5583 .00394 L
.55877 .00394 L
.55926 .00394 L
.55974 .00394 L
.56019 .00394 L
.56068 .00394 L
.56115 .00394 L
.56165 .00394 L
.56213 .00394 L
.56259 .00394 L
.56308 .00394 L
.56355 .00394 L
.564 .00394 L
.56449 .00394 L
.56495 .00394 L
.56545 .00394 L
.56593 .00394 L
.56638 .00394 L
.56687 .00394 L
.56734 .00394 L
.56784 .00394 L
.56832 .00394 L
.56879 .00394 L
.56928 .00394 L
.56975 .00394 L
.57021 .00394 L
.57069 .00394 L
.57116 .00394 L
.57166 .00394 L
.57214 .00394 L
Mistroke
.5726 .00394 L
.57309 .00394 L
.57356 .00394 L
.57401 .00394 L
.57449 .00394 L
.57496 .00394 L
.57545 .00394 L
.57593 .00394 L
.57639 .00394 L
.57687 .00394 L
.57734 .00394 L
.57784 .00394 L
.57832 .00394 L
.57878 .00394 L
.57927 .00394 L
.57975 .00394 L
.5802 .00394 L
.58069 .00394 L
.58115 .00394 L
.58165 .00394 L
.58212 .00394 L
.58258 .00394 L
.58307 .00394 L
.58354 .00394 L
.58404 .00394 L
.58452 .00394 L
.58499 .00394 L
.58548 .00394 L
.58596 .00394 L
.58641 .00394 L
.5869 .00394 L
.58737 .00394 L
.58786 .00394 L
.58834 .00394 L
.5888 .00394 L
.58929 .00394 L
.58977 .00394 L
.59022 .00394 L
.5907 .00394 L
.59117 .00394 L
.59166 .00394 L
.59214 .00394 L
.5926 .00394 L
.59309 .00394 L
.59356 .00394 L
.59405 .00394 L
.59453 .00394 L
.595 .00394 L
.59549 .00394 L
.59596 .00394 L
Mistroke
.59642 .00394 L
.5969 .00394 L
.59737 .00394 L
.59787 .00394 L
.59834 .00394 L
.5988 .00394 L
.59929 .00394 L
.59976 .00394 L
.60022 .00394 L
.6007 .00394 L
.60116 .00394 L
.60166 .00394 L
.60213 .00394 L
.60259 .00394 L
.60308 .00394 L
.60355 .00394 L
.60404 .00394 L
.60452 .00394 L
.60498 .00394 L
.60548 .00394 L
.60595 .00394 L
.6064 .00394 L
.60689 .00394 L
.60735 .00394 L
.60785 .00394 L
.60833 .00394 L
.60878 .00394 L
.60927 .00394 L
.60974 .00394 L
.61024 .00394 L
.61072 .00394 L
.61119 .00394 L
.61168 .00394 L
.61215 .00394 L
.61261 .00394 L
.6131 .00394 L
.61356 .00394 L
.61406 .00394 L
.61454 .00394 L
.615 .00394 L
.61549 .00394 L
.61596 .00394 L
.61641 .00394 L
.6169 .00394 L
.61736 .00394 L
.61786 .00394 L
.61833 .00394 L
.61879 .00394 L
.61928 .00394 L
.61975 .00394 L
Mistroke
.62024 .00394 L
.62073 .00394 L
.62119 .00394 L
.62168 .00394 L
.62215 .00394 L
.62261 .00394 L
.62309 .00394 L
.62356 .00394 L
.62405 .00394 L
.62453 .00394 L
.62499 .00394 L
.62548 .00394 L
.62595 .00394 L
.62645 .00394 L
.62693 .00394 L
.6274 .00394 L
.62789 .00394 L
.62837 .00394 L
.62882 .00394 L
.62931 .00394 L
.62978 .00394 L
.63027 .00394 L
.63075 .00394 L
.63121 .00394 L
.63171 .00394 L
.63218 .00394 L
.63263 .00394 L
.63312 .00394 L
.63358 .00394 L
.63408 .00394 L
.63455 .00394 L
.63501 .00394 L
.6355 .00394 L
.63597 .00394 L
.63647 .00394 L
.63695 .00394 L
.63741 .00394 L
.6379 .00394 L
.63838 .00394 L
.63883 .00394 L
.63932 .00394 L
.63979 .00394 L
.64028 .00394 L
.64076 .00394 L
.64122 .00394 L
.64171 .00394 L
.64218 .00394 L
.64263 .00394 L
.64312 .00394 L
.64358 .00394 L
Mistroke
.64408 .00394 L
.64455 .00394 L
.64501 .00394 L
.6455 .00394 L
.64596 .00394 L
.64646 .00394 L
.64694 .00394 L
.6474 .00394 L
.6479 .00394 L
.64837 .00394 L
.64882 .00394 L
.64931 .00394 L
.64977 .00394 L
.65027 .00394 L
.65075 .00394 L
.65121 .00394 L
.65169 .00394 L
.65216 .00394 L
.65266 .00394 L
.65315 .00394 L
.65361 .00394 L
.6541 .00394 L
.65458 .00394 L
.65503 .00394 L
.65552 .00394 L
.65599 .00394 L
.65648 .00394 L
.65696 .00394 L
.65742 .00394 L
.65791 .00394 L
.65839 .00394 L
.65884 .00394 L
.65932 .00394 L
.65979 .00394 L
.66028 .00394 L
.66076 .00394 L
.66122 .00394 L
.6617 .00394 L
.66217 .00394 L
.66267 .00394 L
.66315 .00394 L
.66361 .00394 L
.66411 .00394 L
.66458 .00394 L
.66504 .00394 L
.66552 .00394 L
.66599 .00394 L
.66648 .00394 L
.66696 .00394 L
.66742 .00394 L
Mistroke
.66791 .00394 L
.66838 .00394 L
.66883 .00394 L
.66932 .00394 L
.66978 .00394 L
.67027 .00394 L
.67075 .00394 L
.67121 .00394 L
.67169 .00394 L
.67216 .00394 L
.67266 .00394 L
.67314 .00394 L
.6736 .00394 L
.67409 .00394 L
.67456 .00394 L
.67502 .00394 L
.6755 .00394 L
.67597 .00394 L
.67646 .00394 L
.67694 .00394 L
.6774 .00394 L
.67789 .00394 L
.67836 .00394 L
.67885 .00394 L
.67934 .00394 L
.6798 .00394 L
.68029 .00394 L
.68077 .00394 L
.68122 .00394 L
.68171 .00394 L
.68217 .00394 L
.68267 .00394 L
.68315 .00394 L
.68361 .00394 L
.6841 .00394 L
.68457 .00394 L
.68502 .00394 L
.68551 .00394 L
.68597 .00394 L
.68647 .00394 L
.68694 .00394 L
.6874 .00394 L
.68789 .00394 L
.68836 .00394 L
.68885 .00394 L
.68933 .00394 L
.6898 .00394 L
.69029 .00394 L
.69076 .00394 L
.69122 .00394 L
Mistroke
.6917 .00394 L
.69217 .00394 L
.69266 .00394 L
.69314 .00394 L
.6936 .00394 L
.69409 .00394 L
.69456 .00394 L
.69506 .00394 L
.69554 .00394 L
.696 .00394 L
.6965 .00394 L
.69697 .00394 L
.69743 .00394 L
.69792 .00394 L
.69838 .00394 L
.69888 .00394 L
.69936 .00394 L
.69982 .00394 L
.70031 .00394 L
.70078 .00394 L
.70124 .00394 L
.70172 .00394 L
.70219 .00394 L
.70268 .00394 L
.70316 .00394 L
.70362 .00394 L
.7041 .00394 L
.70457 .00394 L
.70507 .00394 L
.70555 .00394 L
.70602 .00394 L
.70651 .00394 L
.70698 .00394 L
.70744 .00394 L
.70792 .00394 L
.70839 .00394 L
.70889 .00394 L
.70936 .00394 L
.70982 .00394 L
.71031 .00394 L
.71078 .00394 L
.71124 .00394 L
.71172 .00394 L
.71218 .00394 L
.71268 .00394 L
.71315 .00394 L
.71361 .00394 L
.7141 .00394 L
.71457 .00394 L
.71506 .00394 L
Mistroke
.71554 .00394 L
.716 .00394 L
.7165 .00394 L
.71697 .00394 L
.71742 .00394 L
.71791 .00394 L
.71837 .00394 L
.71887 .00394 L
.71935 .00394 L
.7198 .00394 L
.72029 .00394 L
.72076 .00394 L
.72126 .00394 L
.72174 .00394 L
.72221 .00394 L
.7227 .00394 L
.72318 .00394 L
.72363 .00394 L
.72412 .00394 L
.72458 .00394 L
.72508 .00394 L
.72556 .00394 L
.72602 .00394 L
.72651 .00394 L
.72698 .00394 L
.72744 .00394 L
.72792 .00394 L
.72838 .00394 L
.72888 .00394 L
.72935 .00394 L
.72981 .00394 L
.7303 .00394 L
.73077 .00394 L
.73127 .00394 L
.73175 .00394 L
.73221 .00394 L
.7327 .00394 L
.73318 .00394 L
.73363 .00394 L
.73412 .00394 L
.73458 .00394 L
.73508 .00394 L
.73556 .00394 L
.73602 .00394 L
.7365 .00394 L
.73698 .00394 L
.73743 .00394 L
.73791 .00394 L
.73837 .00394 L
.73887 .00394 L
Mistroke
.73934 .00394 L
.7398 .00394 L
.74029 .00394 L
.74075 .00394 L
.74125 .00394 L
.74173 .00394 L
.74219 .00394 L
.74268 .00394 L
.74316 .00394 L
.74361 .00394 L
.74409 .00394 L
.74456 .00394 L
.74505 .00394 L
.74553 .00394 L
.74599 .00394 L
.74648 .00394 L
.74695 .00394 L
.74745 .00394 L
.74793 .00394 L
.74839 .00394 L
.74888 .00394 L
.74936 .00394 L
.74981 .00394 L
.7503 .00394 L
.75076 .00394 L
.75126 .00394 L
.75174 .00394 L
.7522 .00394 L
.75269 .00394 L
.75316 .00394 L
.75361 .00394 L
.7541 .00394 L
.75456 .00394 L
.75506 .00394 L
.75553 .00394 L
.75599 .00394 L
.75648 .00394 L
.75694 .00394 L
.75744 .00394 L
.75792 .00394 L
.75838 .00394 L
.75888 .00394 L
.75935 .00394 L
.7598 .00394 L
.76029 .00394 L
.76075 .00394 L
.76125 .00394 L
.76173 .00394 L
.76219 .00394 L
.76267 .00394 L
Mistroke
.76315 .00394 L
.76365 .00394 L
.76413 .00394 L
.76459 .00394 L
.76508 .00394 L
.76556 .00394 L
.76601 .00394 L
.7665 .00394 L
.76697 .00394 L
.76747 .00394 L
.76794 .00394 L
.76841 .00394 L
.7689 .00394 L
.76937 .00394 L
.76982 .00394 L
.7703 .00394 L
.77077 .00394 L
.77126 .00394 L
.77174 .00394 L
.7722 .00394 L
.77269 .00394 L
.77316 .00394 L
.77366 .00394 L
.77414 .00394 L
.7746 .00394 L
.77509 .00394 L
.77556 .00394 L
.77602 .00394 L
.7765 .00394 L
.77697 .00394 L
.77747 .00394 L
.77795 .00394 L
.77841 .00394 L
.77889 .00394 L
.77937 .00394 L
.77982 .00394 L
.7803 .00394 L
.78076 .00394 L
.78126 .00394 L
.78173 .00394 L
.78219 .00394 L
.78268 .00394 L
.78315 .00394 L
.78364 .00394 L
.78412 .00394 L
.78458 .00394 L
.78508 .00394 L
.78555 .00394 L
.786 .00394 L
.78649 .00394 L
Mistroke
.78695 .00394 L
.78745 .00394 L
.78792 .00394 L
.78838 .00394 L
.78887 .00394 L
.78934 .00394 L
.78984 .00394 L
.79032 .00394 L
.79079 .00394 L
.79128 .00394 L
.79175 .00394 L
.79221 .00394 L
.79269 .00394 L
.79316 .00394 L
.79366 .00394 L
.79414 .00394 L
.7946 .00394 L
.79509 .00394 L
.79556 .00394 L
.79601 .00394 L
.7965 .00394 L
.79696 .00394 L
.79745 .00394 L
.79793 .00394 L
.79839 .00394 L
.79888 .00394 L
.79934 .00394 L
.79984 .00394 L
.80032 .00394 L
.80079 .00394 L
.80128 .00394 L
.80175 .00394 L
.80221 .00394 L
.80269 .00394 L
.80316 .00394 L
.80365 .00394 L
.80413 .00394 L
.80459 .00394 L
.80508 .00394 L
.80555 .00394 L
.80605 .00394 L
.80653 .00394 L
.80699 .00394 L
.80749 .00394 L
.80796 .00394 L
.80842 .00394 L
.80891 .00394 L
.80937 .00394 L
.80987 .00394 L
.81035 .00394 L
Mistroke
.81081 .00394 L
.8113 .00394 L
.81177 .00394 L
.81223 .00394 L
.81271 .00394 L
.81318 .00394 L
.81367 .00394 L
.81415 .00394 L
.81461 .00394 L
.81509 .00394 L
.81556 .00394 L
.81606 .00394 L
.81654 .00394 L
.81701 .00394 L
.8175 .00394 L
.81797 .00394 L
.81843 .00394 L
.81891 .00394 L
.81938 .00394 L
.81988 .00394 L
.82036 .00394 L
.82082 .00394 L
.82131 .00394 L
.82178 .00394 L
.82223 .00394 L
.82271 .00394 L
.82318 .00394 L
.82367 .00394 L
.82415 .00394 L
.8246 .00394 L
.82509 .00394 L
.82556 .00394 L
.82606 .00394 L
.82654 .00394 L
.827 .00394 L
.82749 .00394 L
.82796 .00394 L
.82842 .00394 L
.8289 .00394 L
.82937 .00394 L
.82986 .00394 L
.83034 .00394 L
.8308 .00394 L
.83129 .00394 L
.83176 .00394 L
.83226 .00394 L
.83274 .00394 L
.8332 .00394 L
.8337 .00394 L
.83417 .00394 L
Mistroke
.83463 .00394 L
.83511 .00394 L
.83558 .00394 L
.83608 .00394 L
.83656 .00394 L
.83702 .00394 L
.83751 .00394 L
.83798 .00394 L
.83843 .00394 L
.83892 .00394 L
.83938 .00394 L
.83987 .00394 L
.84035 .00394 L
.84081 .00394 L
.8413 .00394 L
.84177 .00394 L
.84226 .00394 L
.84275 .00394 L
.84321 .00394 L
.8437 .00394 L
.84417 .00394 L
.84463 .00394 L
.84511 .00394 L
.84558 .00394 L
.84608 .00394 L
.84655 .00394 L
.84701 .00394 L
.8475 .00394 L
.84797 .00394 L
.84843 .00394 L
.84891 .00394 L
.84937 .00394 L
.84987 .00394 L
.85034 .00394 L
.8508 .00394 L
.85128 .00394 L
.85175 .00394 L
.85225 .00394 L
.85273 .00394 L
.85319 .00394 L
.85368 .00394 L
.85415 .00394 L
.85461 .00394 L
.85509 .00394 L
.85556 .00394 L
.85605 .00394 L
.85653 .00394 L
.85699 .00394 L
.85748 .00394 L
.85795 .00394 L
Mistroke
.85845 .00394 L
.85893 .00394 L
.85939 .00394 L
.85988 .00394 L
.86036 .00394 L
.86081 .00394 L
.8613 .00394 L
.86177 .00394 L
.86226 .00394 L
.86274 .00394 L
.8632 .00394 L
.86369 .00394 L
.86416 .00394 L
.86462 .00394 L
.8651 .00394 L
.86556 .00394 L
.86606 .00394 L
.86653 .00394 L
.86699 .00394 L
.86748 .00394 L
.86795 .00394 L
.86844 .00394 L
.86892 .00394 L
.86939 .00394 L
.86988 .00394 L
.87035 .00394 L
.87081 .00394 L
.87129 .00394 L
.87176 .00394 L
.87225 .00394 L
.87273 .00394 L
.87319 .00394 L
.87368 .00394 L
.87415 .00394 L
.87465 .00394 L
.87513 .00394 L
.87559 .00394 L
.87609 .00394 L
.87656 .00394 L
.87702 .00394 L
.8775 .00394 L
.87797 .00394 L
.87847 .00394 L
.87895 .00394 L
.87941 .00394 L
.8799 .00394 L
.88037 .00394 L
.88083 .00394 L
.88131 .00394 L
.88177 .00394 L
Mistroke
.88227 .00394 L
.88275 .00394 L
.8832 .00394 L
.88369 .00394 L
.88416 .00394 L
.88466 .00394 L
.88514 .00394 L
.8856 .00394 L
.8861 .00394 L
.88657 .00394 L
.88702 .00394 L
.88751 .00394 L
.88798 .00394 L
.88847 .00394 L
.88895 .00394 L
.88941 .00394 L
.8899 .00394 L
.89037 .00394 L
.89082 .00394 L
.89131 .00394 L
.89177 .00394 L
.89226 .00394 L
.89274 .00394 L
.8932 .00394 L
.89368 .00394 L
.89415 .00394 L
.89465 .00394 L
.89513 .00394 L
.89559 .00394 L
.89608 .00394 L
.89656 .00394 L
.89701 .00394 L
.89749 .00394 L
.89796 .00394 L
.89846 .00394 L
.89893 .00394 L
.89939 .00394 L
.89988 .00394 L
.90035 .00394 L
.90085 .00394 L
.90133 .00394 L
.90179 .00394 L
.90229 .00394 L
.90276 .00394 L
.90322 .00394 L
.9037 .00394 L
.90417 .00394 L
.90467 .00394 L
.90515 .00394 L
.90561 .00394 L
Mistroke
.9061 .00394 L
.90657 .00394 L
.90702 .00394 L
.9075 .00394 L
.90797 .00394 L
.90846 .00394 L
.90894 .00394 L
.9094 .00394 L
.90989 .00394 L
.91035 .00394 L
.91085 .00394 L
.91133 .00394 L
.9118 .00394 L
.91229 .00394 L
.91276 .00394 L
.91322 .00394 L
.9137 .00394 L
.91417 .00394 L
.91466 .00394 L
.91514 .00394 L
.9156 .00394 L
.91609 .00394 L
.91656 .00394 L
.91706 .00394 L
.91754 .00394 L
.91801 .00394 L
.9185 .00394 L
.91897 .00394 L
.91943 .00394 L
.91992 .00394 L
.92039 .00394 L
.92088 .00394 L
.92136 .00394 L
.92182 .00394 L
.92231 .00394 L
.92279 .00394 L
.92324 .00394 L
.92372 .00394 L
.92419 .00394 L
.92468 .00394 L
.92516 .00394 L
.92562 .00394 L
.92611 .00394 L
.92658 .00394 L
.92708 .00394 L
.92756 .00394 L
.92802 .00394 L
.92851 .00394 L
.92899 .00394 L
.92944 .00394 L
Mistroke
.92993 .00394 L
.93039 .00394 L
.93089 .00394 L
.93137 .00394 L
.93183 .00394 L
.93232 .00394 L
.93279 .00394 L
.93324 .00394 L
.93373 .00394 L
.93419 .00394 L
.93469 .00394 L
.93516 .00394 L
.93562 .00394 L
.93611 .00394 L
.93657 .00394 L
.93707 .00394 L
.93755 .00394 L
.93801 .00394 L
.93851 .00394 L
.93898 .00394 L
.93943 .00394 L
.93992 .00394 L
.94038 .00394 L
.94088 .00394 L
.94136 .00394 L
.94182 .00394 L
.9423 .00394 L
.94277 .00394 L
.94327 .00394 L
.94376 .00394 L
.94422 .00394 L
.94471 .00394 L
.94519 .00394 L
.94564 .00394 L
.94613 .00394 L
.9466 .00394 L
.94709 .00394 L
.94757 .00394 L
.94803 .00394 L
.94852 .00394 L
.949 .00394 L
.94945 .00394 L
.94993 .00394 L
.9504 .00394 L
.95089 .00394 L
.95137 .00394 L
.95183 .00394 L
.95231 .00394 L
.95278 .00394 L
.95328 .00394 L
Mistroke
.95376 .00394 L
.95423 .00394 L
.95472 .00394 L
.95519 .00394 L
.95565 .00394 L
.95613 .00394 L
.9566 .00394 L
.95709 .00394 L
.95757 .00394 L
.95803 .00394 L
.95852 .00394 L
.95899 .00394 L
.95945 .00394 L
.95993 .00394 L
.96039 .00394 L
.96088 .00394 L
.96136 .00394 L
.96182 .00394 L
.9623 .00394 L
.96277 .00394 L
.96327 .00394 L
.96375 .00394 L
.96421 .00394 L
.9647 .00394 L
.96517 .00394 L
.96563 .00394 L
.96611 .00394 L
.96658 .00394 L
.96707 .00394 L
.96755 .00394 L
.96801 .00394 L
.9685 .00394 L
.96897 .00394 L
.96947 .00394 L
.96995 .00394 L
.97041 .00394 L
.9709 .00394 L
.97138 .00394 L
.97183 .00394 L
.97232 .00394 L
.97279 .00394 L
.97328 .00394 L
.97376 .00394 L
.97422 .00394 L
.97471 .00394 L
.97518 .00394 L
.97564 .00394 L
.97612 .00394 L
.97619 .00394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006?ooool5o`0000?ooooo0_l0000fooooo`?o00001?ooool2o`0003Sooooo0_l0000ioooo
o`?o00001?ooool2o`0003Gooooo1Ol00003ooooo`;o00001?ooool001Wooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000fooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000=_ooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000=Oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000?ooooo000Booooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002kooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=_oo
ool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000=_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo000Kooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0000iooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00Oooool001Sooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000f
ooooo`04o`000?ooooooooooo`0003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000dooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`006?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000=Oooool2
o`0000Cooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0000hooooo`;o0000
1?ooool01?l0003oooooooooool0000dooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00003ooooo`006Oooool3o`0000Cooooo0_l0000gooooo`03o`000?oooooooooo
00?ooooo0_l0000hooooo`;o0000>_ooool00ol0003oooooooooo`03ooooo`;o0000=_ooool3o`00
00Cooooo0_l00004ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`003_ooool2
o`000?oooooo4Oooool000gooooo00Co0000oooooooooooo00001?ooooooo`0000_o00000Oooool0
00gooooo00Co0000oooooooooooo00001?ooool2o`0000Coooooo_l00?l4ooooo`;o00000Oooool0
00gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool0<?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0<?ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`003Oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo07Gooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo07Gooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo07Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`003_ooool2o`00
00Gooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0MOooool1o`00
007ooooo000Eooooo`;o0000M_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?o
oooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0M?ooool2o`00007o
oooo000Eooooo`03o`000?oooooooooo07Gooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Gooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`1eooooo`7o00000Oooool001Gooooo0_l0001fooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`1dooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0MOoo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo07Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`1eooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool2o`00
o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1eooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?o
oooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0MOooool1o`00007o
oooo000Eooooo`;o0000M_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo
0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0M?ooool2o`00007ooooo
000Eooooo`03o`000?oooooooooo07Gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Gooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1e
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo07Gooooo0Ol00001ooooo`005Oooool2o`0007Kooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo07Cooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool0MOooool1o`00007ooooo0002ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`1eooooo`7o00000Oooool00005ooooool0003oooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0MOooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000_ooooo00?o0000
ooooooooool00_ooool2o`0007Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03
ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Cooooo0_l00001
ooooo`0000Goooooo`000?ooooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0MOooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l5
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0MOooool1o`00007ooooo00001Ooo
oooo0000oooooooooooo000000Oooooo1?l00005ooooo`03o`000?oooooooooo07Gooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0MOooool1o`00007ooooo0002ooooo`;o00002?ooool5o`0000Cooooo00?o0000oooo
ooooool0MOooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l5oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool0MOooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo07Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o
003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`00
5Oooool2o`0007Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o
1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Cooooo0_l00001ooooo`005Ooo
ool00ol0003oooooooooo`1eooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00ooo
ool2o`00o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1eooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0MOooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`1eooooo`7o00000Oooool001Gooooo0_l0001fooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`1dooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eoooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0MOooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool0MOooool1o`00007ooooo000Eooooo`;o0000
M_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool0M?ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo07Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1eooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool2
o`00o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1eooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0MOooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Go
oooo0Ol00001ooooo`005Oooool2o`0007Kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Cooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool00oooool2o`00o`Gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0MOooool1o`00007ooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`1eoooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`1eooooo`7o00000Oooool000kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1eooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool00oooool2o`00o`Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1eooooo`7o
00000Oooool000kooooo00?o0000ooooooooool01?ooool2o`0007Kooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo07Cooooo0_l00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo07Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`;o003o1Ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`003_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Gooooo00?o003oooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`003Oooool2o`00
00Kooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o003oooooooooool0MOooool1o`00007ooooo000>ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o003oooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo
00?o003oooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Gooooo
0Ol00001ooooo`005Oooool2o`0007Kooooo00?o003oooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`00oooooooooooo07Cooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`1e
ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`1e
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o003oooooooooool0MOooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo07Gooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`00oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03o`00
oooooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`1eooooo`7o0000
0Oooool001Gooooo0_l0001fooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol00?ooooooooooo`1dooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0MOooool0
0ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0MOooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?o003oooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`1eooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol00?oo
ooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00ol00?oooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0MOooool1o`00007ooooo
000Eooooo`;o0000M_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
003oooooooooool0M?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?o003o
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Gooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol00?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0MOooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o003ooooooooo
ool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?o003oooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`005Ooo
ool2o`0007Kooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooo
oooooooo07Cooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`1eooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o003oooooooooool0MOooool1o`00007ooooo00001?oooooo0000o`000?l00004oooo
o`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo07Gooooo00?o003ooooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Gooooo0Ol00001oooo
o`000_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`1eooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
0?ooooooooooo`1eooooo`7o00000Oooool000;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07Gooooo00?o003oooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`000_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l0001fooooo`03o`00oooooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol00?ooooooooooo`1dooooo`;o00000Oooool000;ooooo00?o
0000ooooooooool01oooool4o`0000Gooooo00?o0000ooooooooool0MOooool00ol00?oooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0MOooool1o`00007ooooo0000
0ooooooo0000o`000009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0MOooool0
0ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0MOooool1
o`00007ooooo0002ooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo
07Gooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo
07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`1eooooo`7o00000Oooool001Gooooo
0_l0001fooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol00?oooooo
ooooo`1dooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00ol00?oooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0MOooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo07Gooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eoooo
o`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`1eoooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o003oooooooooool0MOooool1o`00007ooooo000Eooooo`;o0000
M_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0
M?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?o003oooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1eooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol00?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00ol0
0?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0MOooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?o003oooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`00oooooooooooo07Gooooo0Ol00001ooooo`005Oooool2o`0007Kooooo
00?o003oooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Cooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol00?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0MOooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o003o
ooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00?o003ooooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Gooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol00?ooooooooooo`1eooooo`7o00000Oooool001Gooooo0_l0001fooooo`03o`00
oooooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`1dooooo`;o0000
0Oooool001Gooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o003oooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo07Gooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooo
oooo07Gooooo0Ol00001ooooo`003?ooool5o`0000Cooooo00?o0000ooooooooool0MOooool00ol0
0?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0MOooool1o`00
007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0MOooool00ol0
0?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0MOooool1o`00
007ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0MOooool00ol00?oo
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool0MOooool1o`00007o
oooo000?ooooo`03o`000?oooooooooo00?ooooo0_l0001fooooo`03o`00oooooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol00?ooooooooooo`1dooooo`;o00000Oooool000cooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
POooool1o`00007ooooo000<ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`003Oooool3o`0000Gooooo00?o
0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023oooo
o`03o`000?oooooooooo083ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooo
oooo087ooooo0Ol00001ooooo`005Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00
007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo
000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eoooo
o`;o0000Poooool00ol0003oooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083o
oooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo
0Ol00001ooooo`001Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo00001Ooooooo0000oooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool0POooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`000oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0_l00023
ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`0000Go0000ooooooooooooooooo`000007
ooooo`Co00001Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`0000Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool00004ooooool0003o0000
o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00
007ooooo000Eooooo`;o0000Poooool00ol0003oooooooooo`20ooooo`;o00000Oooool001Gooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03
o`000?oooooooooo083ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooo
oooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087o
oooo0Ol00001ooooo`005Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo
000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000
Poooool00ol0003oooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`21ooooo`7o00000Oooool000gooooo0ol00005ooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000<ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0POooool1o`00007ooooo000>ooooo`;o00001Oooool2o`0008?ooooo00?o0000oooooooo
ool0P?ooool2o`00007ooooo000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool000cooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo
000=ooooo`?o00001Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`005Oooool2o`0000Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00;ooooo0_l00001ooooo`005Oooooooo`0000_o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-24.3721, -0.260466, \
0.158161, 0.0191323}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CTFT of finite-length x(t)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xf\  = \ 
        Integrate[x[t]\ Exp[\(-I\)\ 2  \[Pi]\ f\ t], {t, 0, \ 5}]\  // \ 
          FullSimplify;\)\), "\[IndentingNewLine]", 
    \(xf\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(\[ExponentialE]\^\(\(-5\)\ \[ImaginaryI]\ f\ \[Pi]\)\
\ \((7\ f\^4 - 17\ f\^2 + 4)\)\ \(sin(5\ f\ \[Pi])\)\)\/\(\((f - 2)\)\ \((f - \
1)\)\ f\ \((f + 1)\)\ \((f + 2)\)\ \[Pi]\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gX2 = 
        Plot[Abs[xf], {f, \(-2\) fs, 2  fs}, \ PlotStyle \[Rule] {Blue}, \ 
          PlotRange \[Rule] All, PlotPoints \[Rule] 200];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.0147151 0.0583947 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1315 -6 -4.5 ]
[-0.0125 .1315 0 4.5 ]
[-0.0125 .24829 -6 -4.5 ]
[-0.0125 .24829 0 4.5 ]
[-0.0125 .36508 -6 -4.5 ]
[-0.0125 .36508 0 4.5 ]
[-0.0125 .48187 -6 -4.5 ]
[-0.0125 .48187 0 4.5 ]
[-0.0125 .59866 -12 -4.5 ]
[-0.0125 .59866 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1315 m
.00625 .1315 L
s
[(2)] -0.0125 .1315 1 0 Mshowa
0 .24829 m
.00625 .24829 L
s
[(4)] -0.0125 .24829 1 0 Mshowa
0 .36508 m
.00625 .36508 L
s
[(6)] -0.0125 .36508 1 0 Mshowa
0 .48187 m
.00625 .48187 L
s
[(8)] -0.0125 .48187 1 0 Mshowa
0 .59866 m
.00625 .59866 L
s
[(10)] -0.0125 .59866 1 0 Mshowa
.125 Mabswid
0 .04391 m
.00375 .04391 L
s
0 .07311 m
.00375 .07311 L
s
0 .10231 m
.00375 .10231 L
s
0 .1607 m
.00375 .1607 L
s
0 .1899 m
.00375 .1899 L
s
0 .2191 m
.00375 .2191 L
s
0 .27749 m
.00375 .27749 L
s
0 .30669 m
.00375 .30669 L
s
0 .33589 m
.00375 .33589 L
s
0 .39428 m
.00375 .39428 L
s
0 .42348 m
.00375 .42348 L
s
0 .45268 m
.00375 .45268 L
s
0 .51107 m
.00375 .51107 L
s
0 .54027 m
.00375 .54027 L
s
0 .56946 m
.00375 .56946 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1315 m
1 .1315 L
s
.99375 .24829 m
1 .24829 L
s
.99375 .36508 m
1 .36508 L
s
.99375 .48187 m
1 .48187 L
s
.99375 .59866 m
1 .59866 L
s
.125 Mabswid
.99625 .04391 m
1 .04391 L
s
.99625 .07311 m
1 .07311 L
s
.99625 .10231 m
1 .10231 L
s
.99625 .1607 m
1 .1607 L
s
.99625 .1899 m
1 .1899 L
s
.99625 .2191 m
1 .2191 L
s
.99625 .27749 m
1 .27749 L
s
.99625 .30669 m
1 .30669 L
s
.99625 .33589 m
1 .33589 L
s
.99625 .39428 m
1 .39428 L
s
.99625 .42348 m
1 .42348 L
s
.99625 .45268 m
1 .45268 L
s
.99625 .51107 m
1 .51107 L
s
.99625 .54027 m
1 .54027 L
s
.99625 .56946 m
1 .56946 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
.02381 .01472 m
.02847 .01516 L
.02964 .01901 L
.02998 .02003 L
.03014 .02043 L
.0303 .02074 L
.03043 .02097 L
.03058 .02116 L
.03073 .02129 L
.03082 .02134 L
.03089 .02136 L
.03098 .02136 L
.03107 .02135 L
.03116 .02131 L
.03124 .02125 L
.03139 .02109 L
.03148 .02097 L
.03156 .02085 L
.03192 .02006 L
.03227 .01902 L
.03289 .01663 L
.03304 .01598 L
.03321 .01527 L
.0333 .01486 L
.03338 .01494 L
.03347 .01532 L
.03355 .01567 L
.03412 .01805 L
.03442 .01913 L
.03474 .02009 L
.03502 .02072 L
.03517 .021 L
.03532 .0212 L
.03545 .02133 L
.03557 .0214 L
.0357 .02143 L
.03584 .02141 L
.036 .02132 L
.03614 .02118 L
.03622 .02107 L
.0363 .02094 L
.03646 .02065 L
.03675 .01993 L
.03703 .01908 L
.03765 .01666 L
.03783 .01588 L
.03792 .01549 L
.038 .01513 L
.03816 .01499 L
.03824 .01535 L
Mistroke
.03832 .01573 L
.03894 .01828 L
.03949 .02011 L
.03976 .02076 L
.03992 .02104 L
.04006 .02124 L
.04018 .02137 L
.04031 .02146 L
.04045 .0215 L
.04059 .02149 L
.04074 .0214 L
.04083 .02133 L
.04091 .02123 L
.04106 .02102 L
.04122 .02072 L
.04149 .02006 L
.04179 .01913 L
.04242 .01667 L
.04257 .01601 L
.04273 .01528 L
.04282 .01486 L
.04291 .01495 L
.04299 .01533 L
.04308 .01569 L
.04366 .01817 L
.04397 .0193 L
.0443 .02028 L
.04457 .02092 L
.04473 .02119 L
.04488 .02138 L
.04501 .0215 L
.04514 .02156 L
.04528 .02157 L
.04541 .02153 L
.04556 .02143 L
.04572 .02124 L
.04588 .02097 L
.04604 .02065 L
.04632 .01992 L
.04662 .01894 L
.04695 .01765 L
.0473 .01614 L
.04745 .01549 L
.0476 .01479 L
.04769 .01504 L
.04777 .01541 L
.04793 .01612 L
.04851 .01856 L
.04883 .01968 L
.04913 .02053 L
Mistroke
.04939 .02108 L
.04953 .02131 L
.04966 .02147 L
.0498 .02159 L
.04996 .02165 L
.0501 .02163 L
.05024 .02157 L
.0504 .02142 L
.05049 .0213 L
.05057 .02117 L
.05088 .02053 L
.05116 .01973 L
.05145 .01871 L
.05207 .01613 L
.05224 .01536 L
.05234 .01492 L
.05242 .0149 L
.0525 .01527 L
.05259 .01567 L
.05275 .01639 L
.05329 .01868 L
.05358 .01969 L
.05388 .02057 L
.05404 .02094 L
.05422 .02127 L
.0543 .02139 L
.05438 .0215 L
.05453 .02164 L
.05461 .02169 L
.05469 .02172 L
.05485 .02172 L
.055 .02164 L
.05513 .02152 L
.05528 .02133 L
.05544 .02105 L
.05572 .02038 L
.05606 .01933 L
.05637 .01816 L
.05669 .0168 L
.05686 .01604 L
.05695 .01562 L
.05703 .01522 L
.05712 .01483 L
.05721 .01502 L
.05736 .01574 L
.05767 .01712 L
.05822 .01934 L
.05853 .02032 L
.05882 .02104 L
.05898 .02135 L
Mistroke
.05907 .02148 L
.05916 .02159 L
.05924 .02167 L
.05932 .02174 L
.05947 .0218 L
.05962 .02179 L
.05971 .02175 L
.05979 .0217 L
.05994 .02155 L
.06008 .02134 L
.06131 .01743 L
.06148 .01668 L
.06167 .01584 L
.06175 .01544 L
.06184 .01502 L
.06192 .01476 L
.062 .01516 L
.06262 .01797 L
.06322 .02016 L
.06339 .02065 L
.06355 .02105 L
.0637 .02134 L
.06386 .02159 L
.06399 .02174 L
.06414 .02185 L
.06428 .02188 L
.06441 .02186 L
.06456 .02177 L
.0647 .02162 L
.06485 .0214 L
.06501 .02109 L
.06561 .01934 L
.06617 .01702 L
.06642 .01589 L
.06655 .01526 L
.06668 .01477 L
.06681 .01542 L
.06696 .01612 L
.06723 .01732 L
.06754 .01863 L
.06783 .01973 L
.06811 .02062 L
.06838 .02125 L
.06852 .02151 L
.06866 .02172 L
.06875 .02181 L
.06882 .02188 L
.06897 .02195 L
.06913 .02195 L
.06928 .02188 L
Mistroke
.06935 .02182 L
.06944 .02173 L
.06961 .02148 L
.06976 .02119 L
.0699 .02086 L
.07016 .02011 L
.07075 .01785 L
.071 .01674 L
.07127 .0155 L
.0714 .01484 L
.07155 .01532 L
.07169 .01598 L
.07182 .01659 L
.07244 .01923 L
.07274 .02027 L
.07301 .02104 L
.07315 .02135 L
.0733 .02162 L
.07346 .02184 L
.07361 .02197 L
.07369 .02202 L
.07377 .02204 L
.07386 .02204 L
.07395 .02202 L
.0741 .02192 L
.07418 .02183 L
.07426 .02173 L
.0744 .02151 L
.07454 .02121 L
.07481 .02052 L
.07541 .01835 L
.07592 .01601 L
.07606 .01533 L
.07622 .01484 L
.07636 .01554 L
.07649 .01618 L
.07706 .01873 L
.07738 .01992 L
.07767 .02085 L
.07795 .0215 L
.0781 .02177 L
.07825 .02195 L
.07837 .02206 L
.0785 .02212 L
.07864 .02212 L
.07877 .02207 L
.07893 .02193 L
.07901 .02182 L
.07909 .0217 L
.0794 .02106 L
Mistroke
.07968 .02026 L
.07997 .01919 L
.08032 .01772 L
.08065 .01618 L
.0808 .01549 L
.08095 .01474 L
.08103 .01508 L
.08111 .0155 L
.08127 .01625 L
.0819 .01908 L
.08221 .02023 L
.0825 .02109 L
.08276 .02167 L
.08289 .02189 L
.08304 .02206 L
.08318 .02217 L
.08334 .02221 L
.08348 .02218 L
.08362 .02208 L
.08377 .02192 L
.08392 .02166 L
.08421 .02102 L
.08454 .01996 L
.08485 .01878 L
.08517 .01737 L
.08534 .01657 L
.08551 .01571 L
.08567 .01494 L
.08576 .01493 L
.08584 .01535 L
.08614 .01682 L
.08674 .01946 L
.08706 .02059 L
.08723 .0211 L
.0874 .0215 L
.08755 .02181 L
.08764 .02195 L
.08772 .02207 L
.08788 .02222 L
.08802 .02229 L
.08816 .0223 L
.08829 .02224 L
.08843 .02212 L
.08859 .02191 L
.08874 .02164 L
.08888 .02132 L
.08919 .02042 L
.08976 .01818 L
.09003 .01694 L
.09028 .01571 L
Mistroke
.0904 .01508 L
.09054 .01503 L
.09069 .01578 L
.09083 .01646 L
.0914 .01909 L
.09171 .0203 L
.09201 .02121 L
.09229 .02185 L
.09245 .0221 L
.09259 .02227 L
.09271 .02235 L
.09284 .02239 L
.09298 .02237 L
.09311 .02229 L
.09327 .02212 L
.09336 .02199 L
.09344 .02185 L
.09374 .02113 L
.09402 .02025 L
.09432 .01911 L
.09493 .01626 L
.0951 .01541 L
.0952 .01493 L
.09528 .01494 L
.09536 .01533 L
.09544 .01576 L
.09561 .0166 L
.09625 .0195 L
.09656 .02065 L
.09685 .02149 L
.09711 .02204 L
.09724 .02224 L
.09739 .02239 L
.09753 .02247 L
.09769 .02248 L
.09784 .02241 L
.09797 .02228 L
.09813 .02206 L
.0983 .02173 L
.09859 .02095 L
.09895 .0197 L
.09927 .01833 L
.09957 .01688 L
.09973 .01608 L
.09982 .01563 L
.0999 .01521 L
.10005 .01498 L
.10013 .01539 L
.10021 .01582 L
.1005 .01725 L
Mistroke
.1011 .0199 L
.1014 .02096 L
.10173 .02185 L
.1019 .02218 L
.102 .02232 L
.10209 .02243 L
.10217 .0225 L
.10225 .02255 L
.10234 .02258 L
.10242 .02258 L
.10251 .02255 L
.10259 .02251 L
.10273 .02237 L
.10289 .02215 L
.10306 .02181 L
.10422 .01748 L
.10454 .01588 L
.10463 .01541 L
.10472 .01496 L
.10479 .01488 L
.10488 .01532 L
.10549 .01839 L
.1061 .02083 L
.10627 .02137 L
.10643 .0218 L
.10658 .02212 L
.10674 .02239 L
.10688 .02255 L
.10703 .02265 L
.10716 .02268 L
.10729 .02264 L
.10744 .02253 L
.10758 .02235 L
.10774 .02208 L
.10789 .02174 L
.1082 .02084 L
.10852 .01961 L
.10911 .01688 L
.10927 .01607 L
.10935 .01562 L
.10943 .01519 L
.10959 .01508 L
.10974 .01584 L
.11043 .01924 L
.11074 .0205 L
.11104 .02147 L
.1113 .02213 L
.11145 .02241 L
.11159 .02259 L
.11173 .02272 L
Mistroke
.11187 .02277 L
.11202 .02275 L
.11211 .02271 L
.11219 .02264 L
.11234 .02245 L
.11243 .02231 L
.11251 .02215 L
.11282 .02137 L
.11308 .02048 L
.11333 .01949 L
.11362 .01814 L
.11389 .01679 L
.11416 .01538 L
.1143 .01477 L
.11444 .01556 L
.11504 .01858 L
.11534 .01993 L
.11567 .02117 L
.11583 .02164 L
.11599 .02206 L
.11613 .02235 L
.11627 .0226 L
.11642 .02276 L
.11655 .02285 L
.11668 .02288 L
.11681 .02284 L
.11696 .02273 L
.11709 .02257 L
.11724 .02231 L
.1174 .02195 L
.11773 .02097 L
.11808 .01958 L
.1184 .01813 L
.11873 .01644 L
.11887 .01567 L
.11902 .01484 L
.11911 .01507 L
.11919 .01551 L
.11935 .01636 L
.11993 .01923 L
.12023 .0205 L
.12051 .02149 L
.1208 .02227 L
.12096 .02258 L
.12104 .02271 L
.12113 .02281 L
.12126 .02293 L
.12141 .02298 L
.12155 .02296 L
.1217 .02285 L
Mistroke
.12185 .02268 L
.12198 .02245 L
.12223 .02186 L
.12254 .02089 L
.12286 .01958 L
.12344 .01674 L
.12359 .01591 L
.12368 .01545 L
.12376 .01501 L
.12391 .01528 L
.12406 .01607 L
.12474 .01951 L
.125 .02063 L
.12529 .02164 L
.12545 .02211 L
.1256 .02246 L
.12575 .02273 L
.1259 .02293 L
.12605 .02305 L
.12621 .02309 L
.12635 .02304 L
.12649 .02293 L
.12665 .02272 L
.12674 .02256 L
.12682 .02239 L
.12714 .02153 L
.1274 .02058 L
.12765 .01952 L
.12794 .0181 L
.12821 .01668 L
.12835 .01595 L
.1285 .01513 L
.12864 .01507 L
.12876 .01579 L
.12936 .0189 L
.12965 .02026 L
.12997 .02146 L
.13013 .02198 L
.13031 .02245 L
.13048 .02278 L
.13063 .023 L
.13079 .02315 L
.13094 .0232 L
.13107 .02318 L
.13121 .02308 L
.13137 .02289 L
.13145 .02276 L
.13153 .0226 L
.13183 .02183 L
.13212 .02081 L
Mistroke
.13239 .01968 L
.13268 .01829 L
.13299 .01663 L
.13312 .01589 L
.13327 .0151 L
.1334 .01508 L
.13352 .01577 L
.13408 .01875 L
.13466 .02131 L
.13496 .02225 L
.13513 .02266 L
.13528 .02296 L
.13543 .02315 L
.13556 .02327 L
.13568 .02331 L
.13582 .0233 L
.13596 .02321 L
.13612 .02302 L
.13626 .02277 L
.13639 .02248 L
.13672 .02152 L
.13701 .02036 L
.13733 .01887 L
.13769 .01702 L
.13783 .0162 L
.13799 .01531 L
.13814 .01498 L
.13828 .01575 L
.1389 .01911 L
.13948 .02161 L
.13978 .0225 L
.13994 .02289 L
.1401 .02316 L
.14024 .02332 L
.14038 .02341 L
.1405 .02343 L
.14063 .02339 L
.14078 .02327 L
.14093 .02305 L
.14108 .02277 L
.14121 .02245 L
.14153 .02142 L
.14183 .02021 L
.14215 .01866 L
.1425 .01677 L
.14265 .01593 L
.1428 .01502 L
.14295 .01528 L
.14309 .01606 L
.14371 .01943 L
Mistroke
.14401 .0208 L
.14429 .02187 L
.14459 .02273 L
.14474 .02307 L
.14483 .02322 L
.14491 .02334 L
.14504 .02347 L
.14519 .02354 L
.14533 .02354 L
.14549 .02344 L
.14563 .02327 L
.14576 .02304 L
.14602 .02243 L
.14632 .02142 L
.14664 .02006 L
.14722 .01705 L
.14737 .01617 L
.14746 .01567 L
.14754 .0152 L
.14769 .01515 L
.14784 .01598 L
.14852 .0197 L
.14883 .02112 L
.14913 .02221 L
.14939 .02294 L
.14954 .02325 L
.14968 .02346 L
.14982 .02361 L
.14996 .02367 L
.15011 .02365 L
.1502 .0236 L
.15028 .02353 L
.15043 .02332 L
.15052 .02316 L
.1506 .02299 L
.15091 .02213 L
.15117 .02114 L
.15142 .02003 L
.15172 .01854 L
.15199 .01703 L
.15225 .01547 L
.15239 .01476 L
.15254 .01564 L
.15313 .019 L
.15344 .02051 L
.15377 .02189 L
.15392 .02241 L
.15408 .02288 L
.15422 .02321 L
.15437 .02349 L
Mistroke
.15452 .02367 L
.15465 .02377 L
.15478 .0238 L
.15491 .02376 L
.15505 .02364 L
.15519 .02345 L
.15534 .02317 L
.1555 .02277 L
.15579 .02179 L
.15612 .02043 L
.1567 .01736 L
.15687 .01634 L
.15703 .01537 L
.15712 .01488 L
.1572 .01508 L
.1573 .01567 L
.15739 .0162 L
.15802 .01976 L
.15833 .02117 L
.15861 .02228 L
.1589 .02315 L
.15906 .02349 L
.15914 .02363 L
.15923 .02374 L
.15937 .02388 L
.15952 .02393 L
.15966 .0239 L
.1598 .02378 L
.15995 .02358 L
.16008 .02333 L
.16033 .02266 L
.16064 .02157 L
.16096 .02011 L
.16154 .01694 L
.16169 .01601 L
.16178 .01549 L
.16186 .01499 L
.16202 .0154 L
.16216 .01627 L
.16284 .0201 L
.16311 .02135 L
.16339 .02247 L
.16356 .02299 L
.16371 .02338 L
.16385 .02368 L
.16401 .0239 L
.16415 .02403 L
.16431 .02406 L
.16446 .02401 L
.1646 .02388 L
Mistroke
.16476 .02363 L
.16493 .02325 L
.16524 .02229 L
.16551 .0212 L
.1658 .01978 L
.16609 .01821 L
.1664 .01637 L
.16655 .01547 L
.16669 .01483 L
.16681 .01561 L
.16695 .01646 L
.16746 .01945 L
.16777 .02102 L
.16811 .02241 L
.16826 .02293 L
.16842 .02339 L
.16856 .0237 L
.16871 .02396 L
.16886 .02412 L
.16899 .0242 L
.16915 .02418 L
.1693 .02408 L
.16943 .02391 L
.16956 .02369 L
.1697 .02337 L
.16984 .02295 L
.17014 .02187 L
.17046 .02039 L
.17105 .0171 L
.17122 .01602 L
.17131 .01549 L
.17138 .015 L
.17147 .01495 L
.17155 .0155 L
.17174 .01665 L
.17237 .02031 L
.17268 .02175 L
.17296 .02285 L
.17311 .02333 L
.17325 .02369 L
.17341 .024 L
.1735 .02413 L
.17358 .02423 L
.17371 .02432 L
.17386 .02434 L
.17398 .02429 L
.17411 .02416 L
.17426 .02394 L
.17441 .02362 L
.17469 .02278 L
Mistroke
.175 .02157 L
.17533 .01993 L
.17565 .01808 L
.17583 .01699 L
.176 .01593 L
.17616 .01493 L
.17624 .01506 L
.17633 .01558 L
.17662 .01744 L
.1772 .02073 L
.17749 .02208 L
.17776 .02311 L
.17791 .02357 L
.17808 .02397 L
.17823 .02423 L
.17837 .0244 L
.17851 .02448 L
.17865 .02448 L
.17877 .02442 L
.1789 .02428 L
.17904 .02404 L
.17919 .0237 L
.17946 .02288 L
.17976 .02167 L
.18008 .02009 L
.18065 .01668 L
.18082 .0156 L
.18091 .01499 L
.181 .01501 L
.18107 .01551 L
.18116 .01605 L
.18133 .01714 L
.18195 .02076 L
.18226 .02222 L
.18254 .0233 L
.1827 .02377 L
.18284 .02411 L
.183 .02439 L
.18309 .0245 L
.18317 .02458 L
.1833 .02464 L
.18345 .02462 L
.18357 .02453 L
.1837 .02436 L
.18385 .02409 L
.184 .02371 L
.18428 .02278 L
.18461 .02136 L
.18496 .01948 L
.18527 .0176 L
Mistroke
.18544 .01651 L
.18552 .01597 L
.1856 .01547 L
.18576 .015 L
.18584 .01554 L
.18593 .01612 L
.18622 .01802 L
.1868 .02131 L
.18711 .02272 L
.18726 .02329 L
.1874 .02374 L
.18753 .02408 L
.18766 .02438 L
.1878 .0246 L
.18795 .02475 L
.18811 .0248 L
.18825 .02475 L
.18833 .02468 L
.18842 .02458 L
.18851 .02445 L
.18858 .0243 L
.18887 .02353 L
.18903 .02297 L
.18918 .02237 L
.18972 .01955 L
.19001 .01778 L
.19017 .01676 L
.19032 .01579 L
.19044 .01493 L
.19058 .01543 L
.19074 .01645 L
.19087 .01736 L
.19139 .02049 L
.19169 .02203 L
.19197 .02323 L
.19226 .02416 L
.19242 .02452 L
.1925 .02467 L
.19258 .02479 L
.19272 .02491 L
.19284 .02496 L
.19298 .02493 L
.19312 .02481 L
.19328 .02459 L
.19342 .02428 L
.19369 .02348 L
.19399 .02224 L
.19432 .0206 L
.19489 .01705 L
.19505 .01602 L
Mistroke
.19513 .01544 L
.19521 .01489 L
.19537 .0156 L
.19551 .01657 L
.19619 .02082 L
.19651 .02242 L
.1968 .02363 L
.19707 .02442 L
.19722 .02475 L
.19735 .02496 L
.1975 .02509 L
.19764 .02513 L
.19779 .02507 L
.19788 .02499 L
.19795 .02489 L
.19811 .02461 L
.19828 .02418 L
.19859 .02311 L
.19885 .0219 L
.19915 .02031 L
.19943 .01855 L
.19974 .01651 L
.19988 .01555 L
.20003 .0149 L
.20015 .01577 L
.20029 .01671 L
.20081 .02005 L
.20111 .02177 L
.20144 .02331 L
.2016 .02389 L
.20176 .0244 L
.2019 .02474 L
.20205 .02503 L
.20219 .02521 L
.20233 .02529 L
.20248 .02528 L
.20263 .02517 L
.20276 .02498 L
.20289 .02473 L
.20303 .02437 L
.20317 .02391 L
.20347 .02271 L
.20379 .02106 L
.20437 .01741 L
.20455 .01621 L
.20463 .01561 L
.20471 .01507 L
.20479 .01494 L
.20488 .01556 L
.20507 .01685 L
Mistroke
.2057 .02094 L
.206 .02254 L
.20629 .02377 L
.20644 .02431 L
.20658 .02472 L
.20674 .02508 L
.20682 .02522 L
.2069 .02533 L
.20704 .02545 L
.20718 .02548 L
.20731 .02542 L
.20743 .02529 L
.20758 .02506 L
.20773 .0247 L
.20801 .02378 L
.20831 .02245 L
.20865 .02063 L
.20897 .01858 L
.20915 .01737 L
.20932 .01618 L
.20947 .01507 L
.20956 .01499 L
.20964 .01557 L
.20994 .01766 L
.21052 .02136 L
.21079 .02281 L
.21108 .02405 L
.21123 .02457 L
.21139 .02502 L
.21154 .02534 L
.21168 .02553 L
.21182 .02564 L
.21196 .02566 L
.21208 .0256 L
.21221 .02546 L
.21235 .02521 L
.2125 .02485 L
.21277 .02395 L
.21307 .02264 L
.21338 .02089 L
.21395 .01711 L
.21412 .01591 L
.21421 .01527 L
.2143 .01484 L
.21439 .0155 L
.21448 .01609 L
.21463 .01724 L
.21526 .02133 L
.21556 .02299 L
.21585 .02423 L
Mistroke
.216 .02477 L
.21614 .02517 L
.2163 .02551 L
.21639 .02565 L
.21647 .02575 L
.2166 .02584 L
.21675 .02584 L
.21687 .02576 L
.217 .02559 L
.21715 .02532 L
.2173 .02491 L
.21758 .02391 L
.2179 .02238 L
.21826 .02031 L
.21856 .01823 L
.21873 .01702 L
.21889 .01585 L
.21905 .01474 L
.21914 .0154 L
.21922 .016 L
.21952 .01815 L
.2201 .02191 L
.22039 .02344 L
.22066 .0246 L
.22081 .02511 L
.22098 .02554 L
.22113 .02582 L
.22127 .02598 L
.2214 .02605 L
.22152 .02603 L
.22165 .02593 L
.2218 .02573 L
.22194 .02542 L
.22209 .025 L
.22236 .02399 L
.22266 .02254 L
.22298 .02065 L
.22326 .0188 L
.22355 .01664 L
.22364 .01598 L
.22374 .01527 L
.22382 .01476 L
.2239 .01543 L
.22424 .01789 L
.22486 .02202 L
.22516 .02363 L
.22531 .02435 L
.22548 .02499 L
.22565 .0255 L
.22579 .02584 L
Mistroke
.22594 .02609 L
.22608 .02622 L
.22622 .02626 L
.22636 .02619 L
.22648 .02605 L
.22662 .02582 L
.22676 .02547 L
.22692 .02498 L
.2272 .02383 L
.22752 .02211 L
.22788 .01986 L
.22819 .01763 L
.22836 .01636 L
.22844 .01572 L
.22852 .01513 L
.22866 .01539 L
.22881 .01657 L
.22914 .019 L
.22944 .02107 L
.22972 .02274 L
.22999 .02415 L
.23029 .02534 L
.23045 .02582 L
.23061 .02615 L
.23075 .02635 L
.2309 .02646 L
.23103 .02646 L
.23117 .02635 L
.23131 .02617 L
.23143 .02592 L
.23157 .02554 L
.23172 .02502 L
.232 .02379 L
.23263 .02 L
.23298 .01749 L
.23314 .01619 L
.2333 .01498 L
.23345 .0156 L
.2336 .01681 L
.23393 .01927 L
.2345 .02301 L
.23481 .02458 L
.23496 .02521 L
.2351 .0257 L
.23523 .02605 L
.23536 .02635 L
.2355 .02656 L
.23565 .02667 L
.23581 .02667 L
.23595 .02655 L
Mistroke
.23603 .02644 L
.23612 .02628 L
.23628 .02588 L
.23643 .0254 L
.23659 .02478 L
.23688 .02338 L
.23747 .01952 L
.23777 .01731 L
.2379 .0163 L
.23804 .01518 L
.23816 .01527 L
.23828 .01621 L
.23854 .01824 L
.23909 .02212 L
.23938 .02384 L
.23969 .02529 L
.23986 .02588 L
.23994 .02614 L
.24003 .02638 L
.24012 .02657 L
.2402 .0267 L
.24035 .02687 L
.24049 .02692 L
.24063 .02687 L
.24077 .0267 L
.24093 .02639 L
.24101 .02619 L
.2411 .02594 L
.24125 .02539 L
.24154 .02405 L
.24211 .02053 L
.24242 .01822 L
.24257 .01703 L
.24271 .01592 L
.24283 .0149 L
.24295 .01551 L
.24308 .01653 L
.24322 .01764 L
.24378 .0218 L
.24409 .02372 L
.24425 .02458 L
.24442 .02537 L
.24458 .02596 L
.24474 .02647 L
.24489 .02681 L
.24503 .02703 L
.24518 .02714 L
.24531 .02715 L
.24544 .02706 L
.24557 .02687 L
Mistroke
.24572 .02655 L
.24588 .02609 L
.24616 .02497 L
.24646 .02338 L
.24678 .0213 L
.24706 .01924 L
.24736 .01683 L
.24745 .01613 L
.24754 .01539 L
.24762 .01475 L
.2477 .01539 L
.24806 .01829 L
.24869 .02291 L
.24899 .02467 L
.24928 .02595 L
.24942 .02646 L
.24957 .02688 L
.24966 .02707 L
.24974 .02721 L
.2499 .02737 L
.25003 .0274 L
.25017 .02733 L
.25029 .02718 L
.25043 .02692 L
.25057 .02654 L
.25073 .02601 L
.25101 .02474 L
.25165 .02068 L
.25199 .01795 L
.25216 .01655 L
.25232 .01526 L
.25246 .01538 L
.25259 .01651 L
.25289 .01895 L
.25321 .02144 L
.25352 .0235 L
.25381 .02515 L
.25408 .02632 L
.25423 .02684 L
.25437 .02721 L
.25452 .02749 L
.25461 .02759 L
.25469 .02765 L
.25477 .02766 L
.25485 .02765 L
.255 .02751 L
.25515 .02726 L
.25529 .02692 L
.25544 .02643 L
.2556 .02577 L
Mistroke
.25593 .02406 L
.25648 .02021 L
.25679 .01773 L
.25694 .01646 L
.25708 .01526 L
.25721 .01529 L
.25735 .01649 L
.25764 .01895 L
.25815 .02284 L
.25844 .02465 L
.25874 .02618 L
.259 .02713 L
.25915 .02751 L
.25928 .02776 L
.25944 .02791 L
.25959 .02792 L
.25973 .02783 L
.25987 .0276 L
.26003 .02722 L
.2602 .02667 L
.2605 .02532 L
.26105 .02186 L
.26155 .01778 L
.2617 .01649 L
.26184 .01525 L
.26197 .0153 L
.26211 .01652 L
.26271 .02149 L
.26302 .02371 L
.26335 .02569 L
.26351 .02642 L
.26367 .02707 L
.26381 .02752 L
.26396 .02788 L
.2641 .02811 L
.26424 .02821 L
.26439 .02819 L
.26454 .02804 L
.26468 .02779 L
.2648 .02747 L
.26494 .02701 L
.26509 .02642 L
.26539 .02486 L
.26571 .02274 L
.26629 .01805 L
.26646 .01656 L
.26655 .01576 L
.26665 .0149 L
.26674 .01536 L
.26682 .01611 L
Mistroke
.26698 .01756 L
.26762 .02277 L
.26792 .02483 L
.26821 .02639 L
.26836 .02708 L
.2685 .02759 L
.26866 .02803 L
.26874 .02822 L
.26883 .02835 L
.26896 .02848 L
.2691 .0285 L
.26922 .02843 L
.26936 .02824 L
.2695 .02792 L
.26966 .02744 L
.26994 .02624 L
.27024 .02449 L
.27058 .02212 L
.2709 .01946 L
.27108 .01789 L
.27125 .01637 L
.2714 .01494 L
.27149 .0153 L
.27157 .01605 L
.27187 .01873 L
.27245 .02345 L
.27274 .02538 L
.27301 .02687 L
.27316 .02752 L
.27333 .02808 L
.27348 .02846 L
.27362 .02869 L
.27376 .02881 L
.2739 .0288 L
.27402 .0287 L
.27415 .02849 L
.27429 .02815 L
.27444 .02765 L
.27471 .02645 L
.27501 .0247 L
.27532 .02239 L
.2759 .01745 L
.27607 .01589 L
.27616 .015 L
.27625 .01525 L
.27632 .01597 L
.27641 .01676 L
.27658 .01834 L
.2772 .02356 L
.27751 .02567 L
Mistroke
.27779 .02724 L
.27795 .02791 L
.27809 .02839 L
.27825 .0288 L
.27834 .02895 L
.27842 .02906 L
.27855 .02914 L
.2787 .0291 L
.27882 .02896 L
.27896 .02871 L
.2791 .02831 L
.27926 .02774 L
.27954 .02637 L
.27986 .0243 L
.28021 .02154 L
.28052 .0188 L
.28069 .01721 L
.28078 .01642 L
.28085 .01568 L
.28099 .01512 L
.28115 .01659 L
.28148 .01966 L
.28205 .02445 L
.28235 .0264 L
.28262 .02784 L
.28278 .02845 L
.28286 .02872 L
.28294 .02896 L
.28309 .02928 L
.28323 .02944 L
.28336 .02948 L
.2835 .0294 L
.28363 .02921 L
.28375 .02894 L
.2839 .02851 L
.28405 .0279 L
.28433 .02645 L
.28466 .02424 L
.28496 .02184 L
.28528 .01895 L
.28545 .01734 L
.28554 .01644 L
.28562 .0156 L
.28578 .01535 L
.28586 .01615 L
.28595 .017 L
.28624 .01984 L
.28683 .02477 L
.28713 .02684 L
.2873 .02777 L
Mistroke
.28746 .02849 L
.28761 .02903 L
.28774 .0294 L
.28789 .02968 L
.28797 .02977 L
.28805 .02982 L
.28814 .02983 L
.28821 .0298 L
.2883 .02971 L
.28838 .02958 L
.28853 .02924 L
.28861 .02899 L
.28869 .02872 L
.28903 .02711 L
.28939 .02473 L
.28995 .01995 L
.29009 .01854 L
.29025 .01697 L
.2904 .01545 L
.29054 .0154 L
.29063 .01628 L
.29071 .01707 L
.29089 .01882 L
.2912 .02178 L
.29149 .02428 L
.29181 .02662 L
.29196 .02752 L
.29212 .02836 L
.29226 .02896 L
.2924 .02949 L
.29249 .02973 L
.29257 .02991 L
.29273 .03014 L
.29287 .03021 L
.29303 .03012 L
.29316 .02992 L
.2933 .02958 L
.29343 .02914 L
.29356 .02863 L
.29384 .02711 L
.29414 .02504 L
.29472 .01994 L
.29488 .01842 L
.29504 .01674 L
.2952 .01513 L
.29534 .01579 L
.29542 .01664 L
.29552 .01757 L
.2957 .01942 L
.29602 .0225 L
Mistroke
.29632 .02508 L
.29665 .02742 L
.29681 .02834 L
.29698 .02916 L
.29713 .02972 L
.29728 .03018 L
.29743 .03046 L
.29752 .03055 L
.29759 .03059 L
.29773 .03056 L
.29788 .03038 L
.29802 .03008 L
.29816 .02964 L
.29842 .0285 L
.29873 .02662 L
.299 .02448 L
.29963 .01863 L
.2998 .01686 L
.29989 .01588 L
.29998 .01496 L
.30013 .01611 L
.3003 .01789 L
.30094 .02408 L
.30125 .02658 L
.30153 .02842 L
.30182 .02985 L
.30198 .0304 L
.30213 .03076 L
.30221 .03088 L
.30229 .03097 L
.30244 .031 L
.30252 .03095 L
.3026 .03086 L
.30269 .0307 L
.30278 .03048 L
.30293 .02999 L
.3031 .02927 L
.3034 .02752 L
.30397 .02291 L
.30426 .02006 L
.30453 .01719 L
.30467 .01571 L
.30482 .01532 L
.3049 .01619 L
.30498 .0171 L
.30513 .01871 L
.30568 .0242 L
.30621 .02827 L
.3065 .02989 L
.30666 .03056 L
Mistroke
.30681 .03101 L
.30694 .03127 L
.30708 .03142 L
.30722 .03143 L
.30736 .0313 L
.30752 .03097 L
.30767 .0305 L
.3078 .02994 L
.30795 .02919 L
.30828 .02702 L
.30859 .02448 L
.30885 .02194 L
.30914 .01894 L
.30927 .0175 L
.30941 .01595 L
.30953 .0148 L
.30966 .01626 L
.31026 .02268 L
.3108 .02749 L
.31111 .02952 L
.31128 .03041 L
.31144 .03106 L
.31158 .03148 L
.31173 .03178 L
.31181 .03186 L
.31189 .0319 L
.31204 .03185 L
.31218 .03164 L
.31234 .03124 L
.31249 .0307 L
.31263 .03006 L
.31289 .0285 L
.31316 .02639 L
.31349 .0234 L
.31385 .01969 L
.31401 .01788 L
.3141 .01687 L
.31418 .01593 L
.31433 .01519 L
.3144 .01608 L
.31449 .01704 L
.31507 .02338 L
.31539 .02639 L
.31569 .02876 L
.31599 .03061 L
.31615 .03134 L
.31624 .03164 L
.31633 .03191 L
.31648 .03223 L
.31663 .03239 L
Mistroke
.31678 .03236 L
.31692 .03218 L
.317 .03201 L
.31709 .03175 L
.31725 .03114 L
.31741 .03036 L
.31756 .02949 L
.31825 .02368 L
.31852 .02081 L
.31881 .0175 L
.3189 .0165 L
.31898 .01554 L
.31913 .01569 L
.31927 .01737 L
.31943 .01918 L
.32007 .026 L
.32039 .02869 L
.32068 .03064 L
.32083 .03144 L
.32097 .03203 L
.32111 .03249 L
.32119 .03267 L
.32128 .0328 L
.32136 .03289 L
.32145 .03291 L
.32154 .03288 L
.32161 .0328 L
.32176 .0325 L
.32192 .032 L
.32206 .03143 L
.3222 .03068 L
.32246 .02894 L
.32305 .02351 L
.32339 .01979 L
.32355 .01786 L
.3237 .01608 L
.32385 .01525 L
.32394 .0163 L
.32402 .01728 L
.32437 .02146 L
.32495 .02743 L
.32528 .03008 L
.32543 .0311 L
.32558 .03191 L
.32573 .03254 L
.32588 .03304 L
.32602 .03333 L
.32615 .03345 L
.32629 .03343 L
.32645 .03323 L
Mistroke
.32652 .03305 L
.32661 .03281 L
.32676 .03222 L
.32691 .03147 L
.32707 .03045 L
.32741 .02784 L
.328 .02168 L
.32829 .01824 L
.32843 .0165 L
.32856 .01487 L
.32871 .01644 L
.32887 .01846 L
.32915 .02189 L
.32972 .02786 L
.32996 .02996 L
.33023 .0318 L
.33038 .03261 L
.33052 .0332 L
.33065 .03363 L
.33079 .03392 L
.33087 .03401 L
.33095 .03405 L
.33111 .03397 L
.33126 .0337 L
.3314 .03328 L
.33153 .03275 L
.33165 .03212 L
.33193 .03029 L
.33249 .02505 L
.33281 .02133 L
.33297 .01937 L
.33312 .01751 L
.33325 .0158 L
.33339 .01546 L
.33353 .01729 L
.33369 .01929 L
.33432 .02665 L
.33466 .02991 L
.33482 .03123 L
.33498 .03227 L
.33511 .03304 L
.33526 .03372 L
.33541 .03424 L
.33556 .03455 L
.33563 .03464 L
.33572 .03468 L
.33581 .03465 L
.33589 .03457 L
.33604 .03427 L
.33619 .03375 L
Mistroke
.33634 .03309 L
.33649 .03219 L
.33678 .03007 L
.33731 .0247 L
.33764 .02074 L
.33794 .01675 L
.33803 .01565 L
.33811 .01495 L
.33821 .01623 L
.3383 .0174 L
.33862 .02158 L
.33894 .02553 L
.33925 .02883 L
.33955 .0315 L
.33968 .03247 L
.33983 .03339 L
.33995 .03407 L
.34009 .03464 L
.34024 .03506 L
.34038 .03529 L
.34045 .03534 L
.34054 .03534 L
.34069 .03518 L
.34084 .03482 L
.34097 .03432 L
.34113 .03352 L
.34128 .03258 L
.34157 .03035 L
.3422 .02348 L
.34247 .02001 L
.34262 .01802 L
.34275 .01614 L
.34287 .01491 L
.343 .01665 L
.34326 .02029 L
.34382 .02727 L
.34413 .03045 L
.34441 .03288 L
.34457 .03394 L
.34472 .03474 L
.34488 .03541 L
.34496 .03567 L
.34505 .03587 L
.3452 .03605 L
.34533 .03604 L
.34548 .03583 L
.34564 .03538 L
.34573 .03503 L
.34581 .03464 L
.346 .03354 L
Mistroke
.34634 .03082 L
.34697 .02365 L
.34724 .02003 L
.34739 .01794 L
.34753 .01593 L
.34761 .01479 L
.3477 .01589 L
.34785 .01807 L
.34815 .02223 L
.34846 .02624 L
.34879 .03006 L
.34908 .03279 L
.34925 .03406 L
.3494 .03504 L
.34955 .03581 L
.34963 .03613 L
.34972 .03641 L
.34981 .03663 L
.34989 .03677 L
.35005 .03684 L
.3502 .03669 L
.35028 .03652 L
.35036 .03628 L
.35051 .0357 L
.35065 .03496 L
.35093 .03294 L
.35119 .03051 L
.35178 .02344 L
.35206 .01944 L
.35222 .01715 L
.35236 .01496 L
.35245 .01572 L
.35254 .01707 L
.3527 .01941 L
.35301 .02383 L
.35334 .0281 L
.35368 .03196 L
.35398 .03457 L
.35415 .03572 L
.35431 .03657 L
.35446 .03716 L
.35453 .03738 L
.35462 .03755 L
.35477 .03768 L
.35491 .0376 L
.35499 .03747 L
.35507 .03726 L
.35522 .03671 L
.35538 .03587 L
.35556 .03468 L
Mistroke
.35586 .03205 L
.35618 .0285 L
.35676 .02062 L
.3569 .01851 L
.35704 .01624 L
.35712 .01504 L
.35721 .01571 L
.35736 .01802 L
.35793 .02636 L
.35819 .02978 L
.35848 .03296 L
.35875 .03539 L
.35899 .03704 L
.35915 .03779 L
.3593 .03828 L
.35945 .03855 L
.35954 .03859 L
.35962 .03856 L
.35976 .03835 L
.35991 .0379 L
.36007 .03719 L
.36021 .0363 L
.36055 .03352 L
.36085 .03016 L
.36121 .02543 L
.36154 .02049 L
.36169 .01815 L
.36183 .01592 L
.36198 .01586 L
.36205 .0171 L
.36214 .01844 L
.36279 .02818 L
.36308 .03199 L
.3634 .0353 L
.36367 .03743 L
.36382 .03833 L
.36396 .03895 L
.36412 .03939 L
.3642 .03952 L
.36428 .03958 L
.36443 .0395 L
.36457 .0392 L
.36466 .03891 L
.36474 .03857 L
.36489 .03775 L
.36505 .0366 L
.36523 .03505 L
.36585 .02758 L
.36615 .02314 L
.36643 .01864 L
Mistroke
.36656 .01642 L
.36671 .01536 L
.36686 .01794 L
.367 .02029 L
.36752 .02833 L
.36807 .03525 L
.36822 .03672 L
.36838 .03805 L
.36853 .03906 L
.36867 .03979 L
.36882 .04032 L
.3689 .0405 L
.36898 .04062 L
.36907 .04067 L
.36916 .04062 L
.36931 .04033 L
.36946 .03981 L
.36959 .03911 L
.36974 .03812 L
.3699 .03681 L
.37026 .03295 L
.3706 .02834 L
.37091 .02353 L
.37108 .02071 L
.37124 .01801 L
.37138 .01558 L
.37153 .01647 L
.37161 .01796 L
.37169 .01936 L
.37185 .02197 L
.37241 .0308 L
.3727 .03467 L
.37301 .03798 L
.37317 .03934 L
.37335 .04051 L
.37343 .04091 L
.37351 .04126 L
.37367 .0417 L
.37382 .04185 L
.37396 .04176 L
.37411 .04138 L
.37426 .04075 L
.3744 .03994 L
.37453 .03901 L
.37482 .03625 L
.37511 .03267 L
.37543 .02793 L
.37577 .02226 L
.37593 .01941 L
.37608 .0167 L
Mistroke
.37624 .01557 L
.37632 .01707 L
.37641 .01867 L
.37671 .02418 L
.37707 .03001 L
.3774 .03479 L
.37771 .03844 L
.37787 .03998 L
.37804 .0413 L
.37819 .04215 L
.37835 .04279 L
.37849 .0431 L
.37863 .04317 L
.37878 .04296 L
.37885 .04275 L
.37894 .04244 L
.37909 .04167 L
.37923 .0407 L
.37955 .03771 L
.37989 .03335 L
.38047 .02381 L
.38076 .01836 L
.38084 .01683 L
.38093 .01519 L
.38108 .01721 L
.38169 .02853 L
.38196 .03291 L
.38225 .03705 L
.38254 .04037 L
.38266 .04155 L
.3828 .04264 L
.38293 .04346 L
.38305 .04403 L
.38318 .04443 L
.38332 .04463 L
.3834 .04462 L
.38348 .04454 L
.38363 .04416 L
.38379 .04345 L
.38387 .04291 L
.38396 .04233 L
.38424 .03967 L
.38454 .03587 L
.38488 .03068 L
.38523 .02424 L
.38541 .02089 L
.38557 .01763 L
.38572 .01477 L
.38588 .018 L
.38644 .02894 L
Mistroke
.38703 .03855 L
.38735 .04227 L
.38753 .04387 L
.38761 .04451 L
.38769 .04502 L
.38785 .04575 L
.38799 .04615 L
.38814 .04628 L
.38822 .04621 L
.3883 .04606 L
.38846 .04551 L
.38853 .04511 L
.38862 .04458 L
.38891 .04205 L
.38908 .04016 L
.38926 .03778 L
.38957 .0327 L
.3899 .02673 L
.3902 .02052 L
.39034 .01772 L
.39048 .01473 L
.39063 .01805 L
.39078 .0211 L
.39129 .03144 L
.39184 .04058 L
.392 .04258 L
.39216 .04438 L
.39231 .04575 L
.39245 .04676 L
.39258 .04746 L
.39272 .04793 L
.39288 .04813 L
.39302 .048 L
.39316 .04757 L
.3933 .0469 L
.39344 .04587 L
.3936 .04443 L
.39393 .04049 L
.39422 .03583 L
.3948 .02452 L
.39494 .02137 L
.39508 .01834 L
.3952 .01558 L
.39533 .01684 L
.39549 .02036 L
.39563 .02356 L
.39595 .03038 L
.39627 .03663 L
.39662 .0424 L
.39677 .04443 L
Mistroke
.39693 .04629 L
.39706 .04763 L
.39721 .04878 L
.3973 .04931 L
.39738 .04969 L
.39746 .04997 L
.39754 .05016 L
.39768 .05024 L
.39784 .04997 L
.39799 .04937 L
.39812 .04852 L
.39827 .04726 L
.39843 .04557 L
.39876 .04102 L
.39906 .03578 L
.39934 .03001 L
.39964 .02329 L
.39976 .02039 L
.3999 .01723 L
.40004 .01571 L
.40018 .01899 L
.4008 .03337 L
.40114 .04027 L
.40147 .04565 L
.40178 .04941 L
.40195 .05094 L
.40203 .0515 L
.40211 .05194 L
.40224 .05246 L
.40239 .05269 L
.40254 .05257 L
.40269 .05205 L
.40284 .05117 L
.40298 .05006 L
.40329 .04649 L
.40357 .04198 L
.40384 .03678 L
.40445 .02272 L
.40462 .0185 L
.4047 .01635 L
.40479 .01547 L
.40487 .01751 L
.40495 .0197 L
.40511 .02362 L
.40579 .03974 L
.40612 .04614 L
.40629 .04874 L
.40643 .05076 L
.40657 .05232 L
.40672 .05367 L
Mistroke
.40687 .05472 L
.40702 .05532 L
.40709 .05549 L
.40718 .05556 L
.40726 .0555 L
.40735 .05532 L
.40749 .05469 L
.40765 .05361 L
.40888 .0321 L
.40921 .02331 L
.4093 .02089 L
.4094 .01824 L
.40949 .01573 L
.40957 .01602 L
.40972 .02019 L
.40988 .02453 L
.41021 .03356 L
.41077 .04654 L
.41109 .05212 L
.41137 .05586 L
.41153 .05736 L
.41162 .058 L
.41171 .05845 L
.41186 .05892 L
.41194 .05898 L
.41203 .05892 L
.41218 .05845 L
.41227 .058 L
.41234 .05746 L
.41249 .05609 L
.41264 .0544 L
.41295 .04946 L
.41325 .0434 L
.4138 .02919 L
.41409 .02073 L
.41423 .01633 L
.41439 .01796 L
.41448 .02051 L
.41456 .02323 L
.41473 .02807 L
.41503 .03691 L
.41532 .04443 L
.41563 .05148 L
.41592 .0568 L
.41606 .05882 L
.41619 .06037 L
.41631 .06148 L
.41644 .06237 L
.41658 .06297 L
.41671 .06316 L
Mistroke
.41684 .06298 L
.41699 .06236 L
.41712 .06137 L
.41725 .0601 L
.41755 .05588 L
.41786 .04965 L
.41821 .041 L
.41853 .03171 L
.4188 .02291 L
.41896 .01779 L
.4191 .01638 L
.41918 .01906 L
.41926 .02198 L
.41942 .02725 L
.41973 .03703 L
.42029 .05292 L
.42058 .05921 L
.42074 .06216 L
.42089 .0644 L
.42102 .06595 L
.42116 .06718 L
.4213 .06799 L
.42145 .06838 L
.42158 .06829 L
.42172 .06775 L
.42185 .06682 L
.42197 .06563 L
.42211 .06378 L
.42225 .06163 L
.42255 .05534 L
.42317 .03758 L
.42345 .02812 L
.42358 .02323 L
.42371 .0186 L
.42385 .0162 L
.42401 .02209 L
.42428 .03229 L
.42491 .05338 L
.42521 .06177 L
.42549 .06791 L
.42565 .0706 L
.42582 .0728 L
.42591 .07367 L
.42599 .07432 L
.42608 .07483 L
.42617 .07515 L
.42625 .07523 L
.42634 .07514 L
.42649 .07447 L
.42665 .07319 L
Mistroke
.42679 .07148 L
.42706 .06671 L
.42732 .06068 L
.42758 .0529 L
.42787 .04293 L
.42817 .03156 L
.42833 .02493 L
.42848 .0185 L
.42862 .01692 L
.42878 .02345 L
.42904 .03475 L
.42971 .06045 L
.43 .06953 L
.43016 .0736 L
.43032 .07732 L
.43048 .08019 L
.43063 .08221 L
.43077 .08364 L
.43091 .08443 L
.43106 .08464 L
.4312 .08419 L
.43136 .08299 L
.43145 .08199 L
.43153 .0809 L
.43181 .07544 L
.43197 .07139 L
.43211 .06712 L
.43266 .04658 L
.43293 .03424 L
.43308 .02736 L
.43323 .01985 L
.43331 .01589 L
.4334 .01794 L
.43355 .02572 L
.43386 .04091 L
.43418 .05644 L
.43453 .07141 L
.43486 .08295 L
.43502 .08763 L
.43517 .0913 L
.43532 .09443 L
.43547 .09656 L
.43562 .0981 L
.43571 .09856 L
.43579 .09875 L
.43594 .09849 L
.43607 .09758 L
.43622 .09583 L
.43637 .09315 L
.43751 .04898 L
Mistroke
.43767 .04022 L
.43784 .03022 L
.43792 .02551 L
.438 .02043 L
.43815 .01827 L
.4383 .02724 L
.43843 .03568 L
.43874 .05466 L
.43926 .08405 L
.43954 .09758 L
.4398 .10797 L
.43995 .11279 L
.44009 .11641 L
.44024 .11955 L
.44032 .12085 L
.4404 .1218 L
.44054 .12279 L
.44066 .12294 L
.4408 .12223 L
.44095 .12049 L
.44109 .11773 L
.44125 .11357 L
.44154 .10298 L
.44182 .0891 L
.44209 .07338 L
.44239 .05204 L
.44268 .0296 L
.44284 .01643 L
.44293 .02058 L
.44301 .02763 L
.44331 .05365 L
.44386 .10077 L
.44438 .13866 L
.44467 .15504 L
.44492 .1665 L
.44507 .17137 L
.44521 .17476 L
.44536 .17698 L
.44544 .17759 L
.44552 .17774 L
.44566 .17691 L
.44581 .17445 L
.44594 .17104 L
.44608 .1659 L
.44623 .15867 L
.44639 .14905 L
.44668 .12677 L
.4472 .07122 L
.44735 .0528 L
.4475 .03197 L
Mistroke
.44763 .01627 L
.44777 .03795 L
.44844 .15127 L
.44908 .26689 L
.45026 .46612 L
.45056 .50659 L
.45089 .54356 L
.4512 .57084 L
.45135 .58106 L
.45149 .58894 L
.45161 .59454 L
.45174 .59905 L
.45189 .60218 L
.45203 .60332 L
.45216 .60282 L
.45231 .60044 L
.45246 .59595 L
.45261 .58997 L
.45277 .58143 L
.45294 .56993 L
.45325 .54349 L
.45383 .4773 L
.45513 .28186 L
.45627 .11239 L
.45658 .07331 L
.45675 .05368 L
.45692 .03638 L
.45707 .02159 L
.45715 .01568 L
.45723 .0226 L
.45752 .04487 L
.45785 .06473 L
.45802 .07229 L
.45817 .07802 L
.4583 .08217 L
.45845 .08571 L
.4586 .08824 L
.45875 .08985 L
.45884 .0903 L
.45892 .09044 L
.45908 .08999 L
.45917 .08936 L
.45925 .08855 L
.45943 .08595 L
.45957 .08321 L
.45973 .07959 L
.46006 .07072 L
.4612 .03369 L
.46147 .02549 L
.46163 .02138 L
Mistroke
.46177 .0178 L
.46185 .01591 L
.46194 .01545 L
.46209 .0185 L
.46239 .02327 L
.46255 .02513 L
.46273 .02665 L
.46281 .02722 L
.46291 .02769 L
.463 .028 L
.46308 .02817 L
.46323 .02822 L
.46332 .0281 L
.4634 .02789 L
.46355 .0273 L
.46371 .0264 L
.46403 .02385 L
.46434 .02091 L
.46463 .01791 L
.46478 .01648 L
.46491 .01525 L
.46505 .0154 L
.46518 .01643 L
.46532 .01737 L
.46547 .01817 L
.46563 .01874 L
.46577 .01903 L
.46592 .01905 L
.46601 .01893 L
.46609 .01873 L
.46617 .01845 L
.46625 .01806 L
.46641 .0171 L
.46656 .01584 L
.46669 .015 L
.46678 .01598 L
.46685 .01698 L
.46703 .01944 L
.46734 .02467 L
.4684 .04633 L
.46869 .05181 L
.46885 .05446 L
.469 .05665 L
.46915 .05836 L
.4693 .05982 L
.46944 .06074 L
.46957 .0612 L
.46971 .06126 L
.46984 .06085 L
.46998 .05988 L
Mistroke
.47014 .05816 L
.47029 .05575 L
.47045 .05243 L
.47074 .04439 L
.47105 .0329 L
.4712 .02632 L
.47134 .01948 L
.47142 .01533 L
.4715 .01881 L
.47165 .02756 L
.47199 .04942 L
.47314 .14073 L
.47422 .22849 L
.47477 .26485 L
.47505 .27978 L
.47536 .29258 L
.47553 .29809 L
.47569 .30202 L
.47585 .30468 L
.47593 .3057 L
.47601 .30632 L
.47616 .30673 L
.47624 .30652 L
.47632 .30604 L
.47646 .30445 L
.47661 .3018 L
.47677 .29791 L
.47691 .29343 L
.47724 .28027 L
.47782 .24697 L
.47915 .14342 L
.47973 .09596 L
.48035 .05065 L
.4806 .03443 L
.48073 .02659 L
.48087 .01886 L
.48103 .01852 L
.48117 .02518 L
.48145 .03641 L
.48175 .04571 L
.48192 .04971 L
.48207 .05262 L
.48222 .05474 L
.48237 .05639 L
.48252 .05737 L
.48265 .0578 L
.48281 .05777 L
.48295 .05725 L
.48304 .05676 L
.48311 .0562 L
Mistroke
.48329 .05455 L
.48363 .04995 L
.48396 .04441 L
.48512 .02284 L
.4854 .01856 L
.48555 .01661 L
.48571 .0148 L
.48579 .01548 L
.48588 .01633 L
.48604 .01758 L
.48612 .01809 L
.4862 .01856 L
.48635 .01918 L
.4865 .01955 L
.48664 .01967 L
.48679 .01958 L
.48687 .01945 L
.48695 .01924 L
.48709 .01876 L
.48724 .01807 L
.48752 .01647 L
.48765 .01554 L
.4878 .01497 L
.48794 .01602 L
.48807 .017 L
.48858 .02051 L
.48872 .02129 L
.48885 .02191 L
.489 .02244 L
.48915 .02275 L
.48928 .02286 L
.4894 .0228 L
.48953 .02254 L
.48968 .02204 L
.48981 .02134 L
.48994 .02047 L
.49023 .01775 L
.49038 .01605 L
.49053 .01542 L
.4906 .01659 L
.49069 .01794 L
.49084 .02049 L
.4915 .03356 L
.49212 .04655 L
.49241 .0521 L
.49269 .05652 L
.49284 .05852 L
.49301 .06024 L
.49316 .06135 L
.49329 .06197 L
Mistroke
.49344 .06214 L
.49353 .062 L
.4936 .06172 L
.49375 .06074 L
.49389 .05925 L
.49406 .05681 L
.49421 .05384 L
.49455 .04452 L
.49489 .03174 L
.49505 .02448 L
.49519 .01713 L
.49528 .01672 L
.49536 .0216 L
.49555 .03256 L
.49588 .05461 L
.49705 .14798 L
.4977 .20134 L
.49831 .24629 L
.49891 .28028 L
.49907 .28741 L
.49924 .29381 L
.49939 .29835 L
.49955 .30216 L
.4997 .30461 L
.49983 .30603 L
.49996 .30665 L
.50009 .3065 L
.50024 .30541 L
.50037 .30352 L
.50052 .3005 L
.50068 .29619 L
.50097 .28579 L
.50128 .27091 L
.50184 .23576 L
.5029 .15229 L
.50404 .06042 L
.50435 .03891 L
.50453 .02809 L
.50461 .02306 L
.50469 .01859 L
.50484 .01899 L
.50492 .02301 L
.50501 .02707 L
.5053 .0392 L
.5056 .04897 L
.50577 .05323 L
.50592 .05638 L
.50606 .05856 L
.50621 .06034 L
.50636 .06153 L
Mistroke
.50651 .06207 L
.50659 .06214 L
.50668 .06203 L
.50676 .06176 L
.50684 .06136 L
.50699 .06026 L
.50715 .05864 L
.50748 .05399 L
.50784 .0474 L
.50847 .0342 L
.50878 .02775 L
.50906 .0222 L
.50932 .01775 L
.50947 .01554 L
.5096 .0157 L
.50974 .01747 L
.5099 .0191 L
.51003 .02029 L
.51018 .02131 L
.51034 .02211 L
.51049 .02259 L
.51058 .02277 L
.51066 .02285 L
.51082 .02279 L
.5109 .02267 L
.51099 .02246 L
.51114 .02194 L
.51131 .02116 L
.51149 .02009 L
.51179 .01803 L
.51195 .01685 L
.51204 .0162 L
.51212 .01559 L
.51226 .01492 L
.51242 .01605 L
.5127 .01778 L
.51741 .05766 L
.51756 .05692 L
.51765 .05625 L
.51772 .05548 L
.51787 .05351 L
.51801 .05106 L
.51832 .04382 L
.51865 .03262 L
.51881 .02595 L
.5189 .02196 L
.51898 .01798 L
.51908 .01644 L
.51917 .0212 L
.51935 .03115 L
Mistroke
.51999 .07433 L
.52117 .17008 L
.52182 .22146 L
.52242 .26202 L
.52271 .27759 L
.52298 .28953 L
.52313 .29485 L
.52329 .29956 L
.52344 .30284 L
.52358 .30499 L
.52373 .30638 L
.52387 .30673 L
.52403 .30605 L
.52411 .30518 L
.52419 .30408 L
.52435 .30101 L
.52453 .29635 L
.52485 .28454 L
.52514 .27011 L
.52541 .25439 L
.526 .21185 L
.52708 .12241 L
.52767 .0748 L
.52799 .0512 L
.52829 .03134 L
.52842 .02339 L
.52854 .01632 L
.52869 .02069 L
.52882 .02705 L
.52909 .0387 L
.52925 .04423 L
.5294 .04869 L
.52956 .05267 L
.5297 .05563 L
.52986 .05809 L
.52994 .05908 L
.53002 .05993 L
.53017 .06088 L
.5303 .06127 L
.53044 .06118 L
.5306 .06052 L
.53069 .05992 L
.53077 .05922 L
.53095 .0572 L
.53129 .05218 L
.53191 .03994 L
.53247 .02827 L
.53278 .02253 L
.53294 .02001 L
.53308 .01791 L
Mistroke
.53322 .01602 L
.53335 .0149 L
.5335 .0163 L
.53365 .01748 L
.53378 .01822 L
.53392 .01876 L
.53405 .01903 L
.53417 .01907 L
.53432 .01888 L
.53447 .01841 L
.53462 .01772 L
.53475 .0169 L
.5349 .01576 L
.53499 .01503 L
.53507 .01511 L
.53522 .01651 L
.53538 .01807 L
.53571 .02137 L
.53605 .02457 L
.53619 .02569 L
.53634 .0267 L
.53643 .02718 L
.53651 .02755 L
.53666 .02805 L
.53681 .02824 L
.53694 .02814 L
.53709 .02771 L
.53724 .02687 L
.53738 .0258 L
.5375 .0245 L
.53779 .0205 L
.53795 .01768 L
.5381 .01482 L
.53823 .0179 L
.53838 .02156 L
.53901 .04038 L
.53956 .05864 L
.53985 .06788 L
.54015 .07664 L
.54042 .08299 L
.54056 .08569 L
.54071 .08797 L
.54085 .08945 L
.54097 .09023 L
.5411 .09043 L
.54122 .09004 L
.54136 .08887 L
.5415 .08671 L
.54162 .0841 L
.54176 .08036 L
Mistroke
.54206 .06864 L
.54235 .05321 L
.5425 .04347 L
.54266 .03147 L
.54281 .01884 L
.54295 .02344 L
.54304 .03177 L
.54312 .03965 L
.54329 .05844 L
.5436 .09535 L
.54492 .28943 L
.5455 .3804 L
.54613 .47181 L
.54641 .50703 L
.54672 .53978 L
.54698 .56323 L
.54726 .58301 L
.54743 .59162 L
.54758 .59753 L
.54773 .60128 L
.54789 .60319 L
.54802 .60306 L
.54816 .60136 L
.5483 .59774 L
.54845 .59178 L
.54861 .58353 L
.54876 .57391 L
.54909 .54544 L
.54942 .50939 L
.54976 .46289 L
.55097 .25944 L
.55157 .14974 L
.55189 .09239 L
.5522 .04214 L
.55228 .0294 L
.55236 .01763 L
.55245 .02499 L
.55253 .03664 L
.5529 .08361 L
.55321 .11672 L
.55354 .14431 L
.5537 .15489 L
.55386 .163 L
.554 .16875 L
.55414 .17336 L
.55429 .17621 L
.55444 .17763 L
.55456 .17758 L
.5547 .17623 L
.55479 .17477 L
Mistroke
.55487 .17296 L
.55502 .16849 L
.55518 .16218 L
.55536 .1537 L
.55597 .11366 L
.55652 .06863 L
.55682 .04236 L
.55697 .02945 L
.55711 .0176 L
.55719 .01841 L
.55727 .02533 L
.55745 .03955 L
.55776 .06264 L
.55807 .08314 L
.55836 .09865 L
.55869 .11181 L
.55886 .11673 L
.55895 .11868 L
.55905 .1204 L
.55913 .12155 L
.55921 .1223 L
.5593 .12282 L
.55938 .12297 L
.55953 .12243 L
.55961 .12167 L
.55969 .12068 L
.55983 .11817 L
.55997 .11502 L
.56028 .10518 L
.56058 .09244 L
.5609 .07591 L
.56145 .04286 L
.56162 .03282 L
.56177 .0233 L
.5619 .01482 L
.56205 .02368 L
.5627 .06014 L
.56302 .07431 L
.56331 .08492 L
.56347 .08949 L
.56362 .09289 L
.56378 .09578 L
.56387 .09696 L
.56396 .0978 L
.56404 .09837 L
.56412 .0987 L
.56428 .09859 L
.56438 .09809 L
.56447 .09731 L
.56455 .09638 L
Mistroke
.56464 .09511 L
.56478 .0924 L
.56495 .08862 L
.56527 .07869 L
.56586 .0547 L
.56616 .04016 L
.56632 .03219 L
.56649 .02362 L
.56664 .01615 L
.56672 .01751 L
.5668 .02144 L
.56709 .03533 L
.56764 .05853 L
.56794 .06862 L
.56821 .07596 L
.56836 .07898 L
.56852 .08151 L
.5686 .08262 L
.56869 .08345 L
.56885 .08443 L
.56899 .08465 L
.56913 .08429 L
.56927 .08328 L
.56943 .08153 L
.56958 .0791 L
.56975 .07577 L
.57005 .06803 L
.57074 .0439 L
.57104 .03117 L
.57121 .02398 L
.57137 .01718 L
.57152 .01859 L
.5716 .02212 L
.57168 .02533 L
.57196 .03659 L
.57261 .05862 L
.57293 .06664 L
.57312 .07008 L
.57329 .07252 L
.57344 .07402 L
.57353 .07461 L
.57361 .07498 L
.57375 .07523 L
.57391 .0749 L
.57404 .07408 L
.57417 .07289 L
.57431 .07111 L
.57446 .06866 L
.5748 .06147 L
.57512 .05264 L
Mistroke
.57572 .03236 L
.57587 .02682 L
.57603 .02075 L
.57618 .01499 L
.57632 .0197 L
.57687 .03905 L
.57747 .05594 L
.57777 .062 L
.57795 .06459 L
.57803 .06561 L
.57811 .06641 L
.57824 .06752 L
.57839 .06821 L
.57853 .06839 L
.57867 .06814 L
.57879 .06753 L
.57891 .06664 L
.57904 .0653 L
.57918 .06346 L
.57947 .05835 L
.57978 .05131 L
.58032 .03549 L
.58063 .0254 L
.58079 .02029 L
.58093 .01557 L
.58105 .01814 L
.58119 .02261 L
.58147 .03172 L
.58178 .04071 L
.58211 .04905 L
.58242 .05537 L
.58257 .05776 L
.5827 .0596 L
.58284 .06106 L
.58296 .06205 L
.5831 .06279 L
.58325 .06314 L
.58337 .06308 L
.58351 .06263 L
.58364 .06186 L
.58376 .06084 L
.5839 .0593 L
.58403 .05753 L
.58432 .05241 L
.58492 .03821 L
.58521 .02985 L
.58553 .02048 L
.5856 .01809 L
.58569 .01551 L
.58578 .01674 L
Mistroke
.58587 .01936 L
.58618 .02867 L
.58677 .04371 L
.58706 .04967 L
.58723 .05249 L
.58738 .05463 L
.58752 .05624 L
.58767 .05758 L
.58776 .05813 L
.58783 .05851 L
.58798 .05894 L
.58812 .05895 L
.58826 .05858 L
.58841 .05779 L
.58855 .05667 L
.58869 .05522 L
.58882 .05353 L
.58906 .04963 L
.58962 .03782 L
.59017 .02326 L
.59032 .01904 L
.5904 .01681 L
.59049 .01497 L
.59064 .01926 L
.59078 .02315 L
.59142 .03911 L
.59173 .04537 L
.59202 .04991 L
.59214 .05152 L
.59228 .05298 L
.59241 .05406 L
.59253 .05481 L
.59266 .05532 L
.59279 .05556 L
.59294 .05544 L
.59308 .05498 L
.59323 .05411 L
.59337 .05293 L
.59364 .04984 L
.59392 .04534 L
.59424 .03922 L
.59455 .03226 L
.59488 .02401 L
.59503 .02007 L
.59512 .01791 L
.59519 .01588 L
.59533 .01713 L
.59548 .02101 L
.59606 .03482 L
.59635 .04058 L
Mistroke
.59661 .04505 L
.59692 .04904 L
.59708 .05058 L
.59716 .05121 L
.59725 .05177 L
.59739 .05239 L
.59753 .05267 L
.59769 .05261 L
.59783 .05219 L
.59799 .05135 L
.59814 .05022 L
.5983 .0486 L
.59847 .04646 L
.59914 .03465 L
.59945 .02775 L
.59962 .02375 L
.59978 .01992 L
.59992 .01663 L
.60007 .01634 L
.60015 .01835 L
.60023 .02024 L
.60038 .02372 L
.60071 .03122 L
.60107 .03823 L
.60141 .04351 L
.60157 .04559 L
.60172 .04718 L
.60186 .0484 L
.60201 .04936 L
.60216 .04998 L
.60225 .05017 L
.60233 .05025 L
.60247 .05014 L
.6026 .04979 L
.60274 .04907 L
.60288 .0481 L
.60303 .04671 L
.6032 .04489 L
.60349 .04078 L
.60415 .02838 L
.60445 .02173 L
.6046 .01836 L
.60474 .0152 L
.60487 .01708 L
.605 .02008 L
.60528 .02624 L
.60558 .03231 L
.60591 .03804 L
.60619 .0421 L
.60635 .04398 L
Mistroke
.6065 .04544 L
.60664 .04653 L
.6068 .0474 L
.60688 .04773 L
.60696 .04795 L
.60711 .04813 L
.60724 .04801 L
.60737 .04765 L
.60751 .04699 L
.60766 .046 L
.60792 .04358 L
.60816 .04057 L
.60871 .03148 L
.60898 .02612 L
.60928 .02002 L
.60936 .01818 L
.60944 .01643 L
.6096 .01627 L
.60974 .01931 L
.60989 .02255 L
.6105 .03399 L
.61083 .039 L
.61099 .04103 L
.61114 .04261 L
.61127 .04376 L
.61141 .04477 L
.61156 .04556 L
.6117 .04605 L
.61185 .04627 L
.61193 .04626 L
.61201 .04616 L
.61216 .04573 L
.6123 .04505 L
.61243 .04419 L
.61257 .04305 L
.61282 .04044 L
.61337 .03227 L
.61366 .0272 L
.61396 .02124 L
.6141 .01842 L
.61425 .0154 L
.61438 .01661 L
.61452 .01942 L
.61516 .03133 L
.61547 .03601 L
.61575 .03953 L
.61601 .0421 L
.61615 .04306 L
.6163 .04386 L
.61644 .04438 L
Mistroke
.6166 .04463 L
.61675 .04456 L
.61689 .04424 L
.61703 .04368 L
.61715 .04296 L
.61729 .04194 L
.61744 .04062 L
.61796 .03414 L
.61854 .02428 L
.61868 .02168 L
.61883 .01886 L
.61896 .01643 L
.6191 .0157 L
.61926 .01872 L
.61941 .0215 L
.61974 .02746 L
.62002 .03204 L
.62032 .03617 L
.62059 .03911 L
.62073 .04036 L
.62088 .04145 L
.62101 .04223 L
.62114 .04274 L
.62127 .04305 L
.62139 .04317 L
.62152 .04308 L
.62167 .04273 L
.6218 .04223 L
.62194 .04145 L
.62208 .04038 L
.62224 .03895 L
.62253 .03571 L
.62316 .02625 L
.62347 .02096 L
.62362 .01827 L
.62375 .01578 L
.62383 .0151 L
.62391 .01662 L
.62409 .0198 L
.6244 .02513 L
.62473 .03038 L
.62508 .03513 L
.62524 .03692 L
.62539 .03838 L
.62554 .03957 L
.62568 .04045 L
.62581 .0411 L
.62595 .04157 L
.62608 .04181 L
.62624 .04183 L
Mistroke
.62632 .04173 L
.6264 .04154 L
.62655 .04099 L
.62664 .04058 L
.62671 .04012 L
.62689 .03884 L
.62719 .03598 L
.62751 .03205 L
.62811 .02278 L
.62841 .01757 L
.62849 .01613 L
.62858 .01486 L
.62866 .01633 L
.62874 .01767 L
.62944 .02895 L
.62977 .03338 L
.63008 .03666 L
.63023 .03792 L
.63037 .03889 L
.63045 .03935 L
.63053 .03976 L
.63068 .0403 L
.63076 .04049 L
.63084 .04062 L
.63093 .04067 L
.63102 .04063 L
.63117 .04036 L
.63125 .04009 L
.63133 .03979 L
.63148 .039 L
.63162 .03805 L
.63194 .03521 L
.63251 .02793 L
.6328 .02354 L
.63307 .01909 L
.63322 .01658 L
.63331 .01515 L
.63339 .01561 L
.63353 .01793 L
.63368 .02038 L
.6342 .02834 L
.63448 .03191 L
.63477 .03505 L
.63493 .0365 L
.63512 .03779 L
.6352 .03825 L
.63528 .03867 L
.63544 .03923 L
.63552 .03942 L
.63561 .03954 L
Mistroke
.63569 .03958 L
.63577 .03955 L
.63592 .03932 L
.63607 .03882 L
.63621 .03816 L
.63636 .03723 L
.63663 .03499 L
.63696 .03151 L
.63725 .02765 L
.63782 .01906 L
.6379 .0178 L
.63799 .01643 L
.63814 .01549 L
.63829 .01791 L
.63843 .0201 L
.639 .02833 L
.63928 .0317 L
.63953 .03427 L
.63981 .03645 L
.63996 .03734 L
.64011 .03797 L
.64027 .03841 L
.64041 .03858 L
.6405 .03858 L
.64057 .03852 L
.64066 .03837 L
.64075 .03816 L
.6409 .03758 L
.64098 .03719 L
.64107 .03669 L
.64136 .03448 L
.64171 .03097 L
.64203 .02696 L
.64232 .02284 L
.64263 .01816 L
.64271 .01695 L
.6428 .01565 L
.64289 .0152 L
.64298 .01654 L
.64329 .02131 L
.64387 .02914 L
.64419 .03257 L
.64435 .03395 L
.64449 .03504 L
.64462 .03588 L
.64476 .03661 L
.6449 .03719 L
.64504 .03753 L
.6452 .03768 L
.64528 .03767 L
Mistroke
.64536 .03758 L
.64551 .03726 L
.64565 .03675 L
.64579 .03607 L
.64592 .03526 L
.64617 .03333 L
.64672 .02734 L
.64704 .02317 L
.64733 .01893 L
.64746 .01703 L
.6476 .01501 L
.64775 .01664 L
.64789 .01865 L
.64853 .02731 L
.64884 .03079 L
.64912 .03335 L
.64925 .03428 L
.64938 .03514 L
.6495 .03574 L
.64963 .03626 L
.64977 .03663 L
.64992 .03682 L
.65005 .03682 L
.65018 .03666 L
.65033 .03627 L
.65047 .0357 L
.6506 .03504 L
.65074 .03415 L
.65105 .0316 L
.65134 .0286 L
.65195 .02079 L
.65212 .01844 L
.65221 .01714 L
.6523 .01591 L
.65245 .01569 L
.65253 .01683 L
.65261 .01805 L
.65323 .0262 L
.65353 .02957 L
.65382 .03216 L
.65409 .03409 L
.65423 .03482 L
.65438 .03544 L
.65453 .03585 L
.65461 .03599 L
.65469 .03606 L
.65484 .03603 L
.65499 .03579 L
.65512 .03543 L
.65525 .03488 L
Mistroke
.6555 .03348 L
.65579 .03119 L
.65606 .02858 L
.65664 .02153 L
.65694 .01754 L
.65702 .01643 L
.65711 .01523 L
.65726 .01637 L
.6574 .01832 L
.65756 .0204 L
.65784 .02401 L
.65837 .0298 L
.65854 .03129 L
.6587 .0325 L
.65885 .03342 L
.659 .03421 L
.65908 .03454 L
.65917 .03484 L
.65933 .0352 L
.65941 .03531 L
.65951 .03535 L
.65959 .03531 L
.65967 .03522 L
.65983 .03489 L
.65997 .03439 L
.66013 .03365 L
.66029 .03264 L
.66057 .03048 L
.66088 .0275 L
.66148 .02041 L
.66162 .01852 L
.66177 .01647 L
.66186 .01528 L
.66194 .01523 L
.6621 .01732 L
.66268 .02462 L
.66322 .03004 L
.66352 .03228 L
.66367 .03314 L
.66384 .03388 L
.66393 .03417 L
.66401 .03438 L
.6641 .03455 L
.66419 .03465 L
.66434 .03465 L
.66443 .03456 L
.66451 .03442 L
.66466 .03403 L
.66479 .0335 L
.66494 .03274 L
Mistroke
.66511 .03173 L
.66543 .02911 L
.66573 .02612 L
.6663 .01937 L
.66647 .01727 L
.66662 .01526 L
.66676 .01597 L
.66691 .01791 L
.66744 .02423 L
.66801 .02983 L
.66817 .031 L
.66834 .03206 L
.66848 .0328 L
.66864 .03342 L
.66874 .03368 L
.66882 .03386 L
.6689 .03398 L
.66899 .03404 L
.66908 .03404 L
.66916 .03398 L
.66931 .03372 L
.66946 .0333 L
.66961 .03266 L
.66989 .03107 L
.67018 .02877 L
.67051 .02563 L
.67081 .02228 L
.67114 .01831 L
.67129 .01642 L
.67137 .01547 L
.67145 .01502 L
.6716 .01688 L
.67174 .0186 L
.67229 .02488 L
.67259 .02778 L
.67286 .03002 L
.67317 .03187 L
.67333 .03257 L
.67341 .03285 L
.6735 .0331 L
.67365 .03338 L
.6738 .03346 L
.67394 .03337 L
.67408 .03314 L
.67423 .03268 L
.67438 .03209 L
.67454 .03125 L
.67471 .03014 L
.67539 .02411 L
.67569 .02068 L
Mistroke
.67586 .01869 L
.67602 .01678 L
.67617 .01498 L
.67625 .01547 L
.67633 .0164 L
.67661 .01973 L
.67724 .02647 L
.6776 .02942 L
.67778 .03055 L
.67794 .03143 L
.67808 .03203 L
.67824 .03251 L
.67838 .03279 L
.67851 .0329 L
.67865 .03288 L
.67881 .03267 L
.67889 .03249 L
.67897 .03225 L
.67912 .03167 L
.67928 .03089 L
.67945 .02983 L
.67977 .02741 L
.68037 .02151 L
.68067 .01801 L
.68076 .01702 L
.68085 .01597 L
.68101 .01535 L
.68115 .0171 L
.68129 .01871 L
.68161 .02221 L
.68189 .02502 L
.68219 .02767 L
.68245 .02958 L
.68274 .0311 L
.68289 .0317 L
.68298 .03196 L
.68307 .03215 L
.68322 .03235 L
.68337 .03238 L
.68352 .03224 L
.68368 .0319 L
.68381 .03147 L
.68396 .03086 L
.68428 .02894 L
.68463 .02618 L
.68527 .01981 L
.68558 .01629 L
.68573 .01495 L
.68582 .01597 L
.68591 .01693 L
Mistroke
.6865 .02331 L
.68683 .02635 L
.68714 .02871 L
.68732 .02976 L
.68751 .03068 L
.68759 .03101 L
.68768 .0313 L
.68784 .03169 L
.68792 .03181 L
.688 .03188 L
.68815 .03189 L
.68824 .03182 L
.68832 .0317 L
.6884 .03152 L
.6885 .03127 L
.68866 .03067 L
.68882 .02992 L
.68911 .02809 L
.68967 .02339 L
.68996 .02043 L
.69011 .0188 L
.69027 .01704 L
.69041 .01541 L
.6905 .01495 L
.69057 .01581 L
.69085 .01889 L
.6914 .02441 L
.69172 .027 L
.69201 .02897 L
.69217 .02982 L
.69235 .03056 L
.69243 .03081 L
.69251 .03104 L
.69266 .03132 L
.69281 .03144 L
.69296 .0314 L
.69304 .03131 L
.69312 .03116 L
.69328 .03076 L
.69343 .03023 L
.69358 .0295 L
.69386 .02782 L
.69449 .02253 L
.69483 .01915 L
.695 .01727 L
.6951 .01622 L
.69519 .01523 L
.69527 .01504 L
.69535 .01594 L
.6955 .01752 L
Mistroke
.69578 .02049 L
.69608 .02342 L
.69641 .02613 L
.69668 .02806 L
.69683 .0289 L
.69698 .02965 L
.69713 .03021 L
.69726 .03059 L
.69739 .03085 L
.69752 .03098 L
.69768 .03099 L
.69782 .03085 L
.6979 .0307 L
.69799 .0305 L
.69814 .03 L
.69829 .02939 L
.69844 .02859 L
.69872 .02681 L
.69941 .02086 L
.69971 .0178 L
.69987 .01614 L
.69995 .0153 L
.70003 .01507 L
.70019 .01673 L
.70034 .01827 L
.70062 .0211 L
.70118 .02591 L
.70148 .02796 L
.70177 .02936 L
.70191 .02989 L
.702 .03013 L
.70208 .0303 L
.70216 .03044 L
.70224 .03054 L
.7024 .03059 L
.70254 .0305 L
.70269 .03025 L
.70281 .02993 L
.70295 .02945 L
.70325 .02798 L
.70354 .02611 L
.7041 .0214 L
.70437 .01876 L
.70461 .01625 L
.70476 .01473 L
.7049 .01618 L
.70521 .01931 L
.70556 .02252 L
.70587 .02511 L
.70614 .02701 L
Mistroke
.70644 .02863 L
.7066 .02925 L
.70674 .0297 L
.7069 .03002 L
.70698 .03013 L
.70706 .03019 L
.7072 .03019 L
.70735 .03005 L
.70747 .02981 L
.70761 .02944 L
.70776 .0289 L
.70792 .02816 L
.70821 .02646 L
.70878 .02199 L
.70904 .01949 L
.7093 .01701 L
.70944 .01556 L
.7096 .01545 L
.70974 .01687 L
.70987 .01817 L
.71048 .02371 L
.71076 .02577 L
.71102 .02737 L
.71129 .02864 L
.71143 .02913 L
.71158 .02952 L
.71166 .02966 L
.71175 .02976 L
.7119 .02983 L
.71199 .0298 L
.71207 .02973 L
.71216 .0296 L
.71225 .02941 L
.71241 .02895 L
.71258 .02829 L
.71289 .0267 L
.71346 .0225 L
.71378 .0196 L
.71408 .01673 L
.71423 .01527 L
.71439 .01571 L
.71454 .01724 L
.71472 .0189 L
.71532 .02408 L
.7156 .02602 L
.71575 .02693 L
.7159 .02768 L
.71604 .02826 L
.71618 .02877 L
.71632 .02911 L
Mistroke
.71644 .02933 L
.7166 .02947 L
.71669 .02947 L
.71677 .02943 L
.71693 .02924 L
.717 .0291 L
.71709 .02889 L
.71723 .02843 L
.71739 .0278 L
.71767 .02632 L
.71835 .02123 L
.71864 .01857 L
.7188 .01709 L
.71888 .0163 L
.71897 .01547 L
.71913 .01546 L
.71927 .01683 L
.71955 .01945 L
.72017 .02448 L
.72042 .02613 L
.72069 .02753 L
.72085 .02815 L
.72099 .02858 L
.72114 .0289 L
.72127 .02907 L
.72142 .02914 L
.72158 .02906 L
.72166 .02896 L
.72174 .02881 L
.7219 .02842 L
.72205 .02789 L
.7222 .02727 L
.72248 .02578 L
.7231 .02119 L
.72342 .0183 L
.7236 .01672 L
.72369 .01584 L
.72378 .01502 L
.72385 .01514 L
.72394 .01592 L
.72411 .01755 L
.72442 .0203 L
.72473 .02284 L
.72503 .02492 L
.72531 .02655 L
.72546 .02725 L
.72562 .02786 L
.72575 .02826 L
.7259 .02858 L
.72603 .02875 L
Mistroke
.72616 .02882 L
.72631 .02876 L
.7264 .02867 L
.72648 .02854 L
.72663 .02819 L
.72679 .02768 L
.7271 .02631 L
.72738 .02466 L
.72801 .01974 L
.72818 .01826 L
.72836 .01663 L
.72845 .01583 L
.72853 .01507 L
.72869 .01579 L
.72883 .01709 L
.72896 .01828 L
.72926 .02085 L
.72956 .02318 L
.7299 .02535 L
.73017 .02678 L
.7303 .0273 L
.73044 .02775 L
.73058 .02812 L
.73071 .02835 L
.73085 .02849 L
.73101 .0285 L
.73109 .02844 L
.73118 .02834 L
.73126 .02821 L
.73134 .02804 L
.73148 .02764 L
.73164 .02709 L
.73196 .02554 L
.73231 .02329 L
.73289 .01867 L
.73305 .01728 L
.73313 .01651 L
.73322 .01578 L
.73337 .01509 L
.73352 .01638 L
.73415 .02167 L
.73446 .02389 L
.73474 .02559 L
.73501 .02681 L
.73514 .02728 L
.73528 .0277 L
.73543 .02799 L
.73558 .02817 L
.73573 .02821 L
.73586 .02814 L
Mistroke
.73602 .02792 L
.7361 .02776 L
.73619 .02754 L
.73648 .02647 L
.73665 .02567 L
.73683 .02466 L
.73716 .02249 L
.73747 .02009 L
.7378 .01732 L
.73793 .01614 L
.73808 .01487 L
.73824 .01595 L
.73838 .01723 L
.73898 .02208 L
.73931 .02428 L
.73962 .02593 L
.73979 .02666 L
.73995 .02718 L
.74004 .02741 L
.74013 .02761 L
.74023 .02777 L
.74032 .02787 L
.7404 .02792 L
.74048 .02793 L
.74057 .0279 L
.74065 .02784 L
.7408 .02761 L
.74088 .02743 L
.74096 .02724 L
.74127 .0261 L
.74157 .02459 L
.74191 .0224 L
.74222 .02007 L
.74249 .01783 L
.74264 .01656 L
.74278 .01536 L
.74293 .01538 L
.74301 .01606 L
.7431 .0168 L
.74339 .01923 L
.74368 .02148 L
.744 .02365 L
.74428 .02523 L
.74444 .02594 L
.74458 .02651 L
.74473 .02696 L
.74488 .02732 L
.74502 .02754 L
.74515 .02765 L
.74527 .02766 L
Mistroke
.7454 .02758 L
.74554 .02739 L
.74567 .02712 L
.74583 .02667 L
.746 .02605 L
.7463 .02456 L
.74688 .02077 L
.7472 .01821 L
.74738 .01674 L
.74747 .016 L
.74755 .01533 L
.74769 .0153 L
.74784 .01659 L
.74817 .01924 L
.74874 .02331 L
.74906 .02508 L
.74921 .02576 L
.74935 .02629 L
.74948 .02669 L
.74962 .02703 L
.74976 .02726 L
.74992 .02739 L
.75005 .0274 L
.75019 .02729 L
.75033 .0271 L
.75045 .02683 L
.75061 .02638 L
.75077 .02575 L
.75108 .02429 L
.75143 .02213 L
.75175 .01984 L
.75205 .01744 L
.75222 .01608 L
.75237 .01479 L
.7525 .01573 L
.75265 .0169 L
.75295 .01929 L
.75324 .02146 L
.75356 .02351 L
.75385 .025 L
.754 .02566 L
.75415 .02618 L
.75428 .02655 L
.75442 .02686 L
.75457 .02707 L
.75472 .02715 L
.75485 .02713 L
.75499 .02701 L
.75512 .0268 L
.75524 .02652 L
Mistroke
.75554 .02551 L
.75569 .02484 L
.75586 .02399 L
.75621 .02186 L
.75653 .01958 L
.75683 .01723 L
.757 .01588 L
.75716 .01483 L
.7573 .01602 L
.75746 .0173 L
.75774 .01946 L
.75837 .02357 L
.75868 .02511 L
.75886 .02579 L
.75903 .02629 L
.75917 .02661 L
.75933 .02682 L
.75946 .02691 L
.7596 .0269 L
.75975 .02677 L
.75984 .02664 L
.75992 .02649 L
.76007 .02611 L
.76022 .02564 L
.76128 .01954 L
.76158 .01731 L
.76174 .01604 L
.76189 .01482 L
.76203 .01574 L
.76219 .01696 L
.76246 .01903 L
.76303 .02283 L
.76334 .02449 L
.76363 .02562 L
.76379 .02608 L
.76387 .02627 L
.76396 .02643 L
.76404 .02654 L
.76412 .02663 L
.76427 .02669 L
.76442 .02663 L
.76451 .02655 L
.76458 .02645 L
.76473 .02616 L
.76487 .02578 L
.76538 .02366 L
.76567 .02201 L
.76593 .02028 L
.76622 .01815 L
.76638 .01693 L
Mistroke
.76653 .01577 L
.76666 .01475 L
.7668 .01576 L
.7671 .01802 L
.7677 .02214 L
.76799 .02376 L
.76826 .02496 L
.76841 .02548 L
.76857 .02592 L
.76865 .02609 L
.76873 .02623 L
.76883 .02635 L
.76891 .02643 L
.76907 .02647 L
.76922 .02639 L
.76935 .02622 L
.7695 .02593 L
.76965 .02552 L
.76979 .02504 L
.77006 .02391 L
.77065 .02043 L
.77117 .01671 L
.77131 .01564 L
.77146 .01493 L
.77158 .0159 L
.77172 .01696 L
.77236 .02139 L
.77267 .02318 L
.77296 .02451 L
.77322 .02542 L
.77335 .02575 L
.7735 .02602 L
.77364 .02619 L
.7738 .02626 L
.77395 .0262 L
.77408 .02606 L
.77424 .02578 L
.77432 .02557 L
.7744 .02536 L
.7747 .02428 L
.77505 .02257 L
.77538 .02058 L
.77566 .01861 L
.77597 .01639 L
.77613 .0152 L
.77622 .01491 L
.7763 .01555 L
.77661 .01782 L
.77721 .02182 L
.77755 .02362 L
Mistroke
.77771 .02432 L
.77787 .02488 L
.77801 .02531 L
.77814 .02562 L
.77829 .02587 L
.77845 .02602 L
.77859 .02605 L
.77875 .02597 L
.77883 .02588 L
.77891 .02576 L
.77906 .02544 L
.77921 .02503 L
.77935 .02456 L
.77966 .02319 L
.78023 .01986 L
.7805 .01801 L
.78075 .0162 L
.78088 .01527 L
.78101 .01516 L
.78116 .01627 L
.7813 .01726 L
.78188 .02112 L
.78219 .02288 L
.78249 .0242 L
.78263 .02469 L
.78277 .02511 L
.78293 .02547 L
.78307 .02569 L
.7832 .02581 L
.78332 .02585 L
.78345 .02581 L
.78359 .02568 L
.78367 .02556 L
.78376 .0254 L
.78392 .02502 L
.78408 .02449 L
.78427 .02378 L
.7849 .02037 L
.7852 .0184 L
.78535 .01732 L
.78552 .01614 L
.78566 .0151 L
.78582 .01548 L
.78596 .01651 L
.78609 .01745 L
.78671 .02141 L
.78703 .02309 L
.7872 .02385 L
.78737 .02445 L
.78752 .02491 L
Mistroke
.78766 .02524 L
.78782 .0255 L
.78791 .02559 L
.78799 .02564 L
.78813 .02566 L
.78827 .02559 L
.78841 .02541 L
.78857 .02512 L
.7887 .02477 L
.78883 .02437 L
.78912 .02324 L
.78963 .02047 L
.79021 .01665 L
.79034 .01565 L
.79049 .01484 L
.79058 .01545 L
.79066 .01601 L
.79081 .01708 L
.79139 .02087 L
.79171 .02258 L
.79201 .02387 L
.79227 .02469 L
.79241 .02503 L
.79254 .02525 L
.79268 .02541 L
.79284 .02548 L
.79298 .02544 L
.79312 .02531 L
.79328 .02505 L
.79337 .02486 L
.79345 .02465 L
.79376 .02361 L
.79404 .02234 L
.79433 .02073 L
.79463 .01888 L
.79495 .01673 L
.79504 .01607 L
.79513 .01545 L
.79521 .01489 L
.7953 .01516 L
.79538 .01573 L
.79547 .01634 L
.79563 .01742 L
.79618 .0209 L
.79648 .02247 L
.79676 .02367 L
.79692 .02421 L
.79706 .02461 L
.79722 .02495 L
.79731 .02509 L
Mistroke
.79739 .02519 L
.79754 .02529 L
.79767 .02529 L
.79782 .0252 L
.79798 .02499 L
.79811 .02472 L
.79824 .02441 L
.79852 .02346 L
.79878 .02231 L
.79903 .02102 L
.79931 .01932 L
.79962 .01731 L
.79976 .01634 L
.79991 .01531 L
.80004 .01501 L
.80018 .01597 L
.80079 .01994 L
.80134 .02281 L
.80165 .02397 L
.80182 .02445 L
.80198 .02478 L
.80213 .02499 L
.80229 .02511 L
.80244 .02512 L
.80258 .02503 L
.8027 .02488 L
.80284 .02463 L
.80297 .02433 L
.80309 .02399 L
.80338 .02292 L
.80365 .02163 L
.80424 .01819 L
.80453 .01628 L
.80466 .01542 L
.8048 .01495 L
.80494 .01591 L
.80509 .01692 L
.8054 .01894 L
.80595 .02199 L
.80626 .0233 L
.80643 .02387 L
.80659 .0243 L
.80674 .02461 L
.80682 .02474 L
.8069 .02484 L
.80704 .02494 L
.80718 .02496 L
.80732 .02488 L
.80745 .02475 L
.80758 .02452 L
Mistroke
.80773 .02419 L
.80797 .02344 L
.80824 .02237 L
.80884 .01915 L
.80911 .01744 L
.80926 .01646 L
.8094 .01554 L
.80955 .0149 L
.80963 .01544 L
.80972 .01601 L
.81001 .01791 L
.81035 .01996 L
.81067 .02166 L
.81097 .02296 L
.81113 .02352 L
.8113 .02401 L
.81145 .02437 L
.81159 .0246 L
.81173 .02474 L
.81187 .0248 L
.812 .02478 L
.81214 .02467 L
.81229 .02446 L
.81243 .02419 L
.81268 .02349 L
.81294 .02249 L
.81355 .01937 L
.81384 .01762 L
.81411 .01588 L
.81424 .01501 L
.81438 .01537 L
.81454 .01641 L
.81469 .01735 L
.81531 .02093 L
.81559 .02225 L
.81585 .02325 L
.81612 .02401 L
.81626 .0243 L
.81641 .02451 L
.8165 .02459 L
.81658 .02463 L
.81674 .02463 L
.81682 .02458 L
.81691 .02451 L
.81699 .0244 L
.81709 .02425 L
.81726 .02387 L
.81742 .02341 L
.81773 .02229 L
.8183 .01941 L
Mistroke
.8186 .01761 L
.81875 .01662 L
.81892 .01555 L
.81906 .01482 L
.81922 .01585 L
.8195 .01762 L
.82005 .02074 L
.82036 .0222 L
.82053 .02286 L
.8207 .02339 L
.82085 .0238 L
.82093 .02398 L
.82101 .02414 L
.82116 .02435 L
.8213 .02446 L
.82146 .02449 L
.8216 .02442 L
.82168 .02435 L
.82176 .02424 L
.82192 .02397 L
.82207 .02362 L
.82222 .02316 L
.8225 .02211 L
.8232 .01852 L
.8235 .01668 L
.82366 .01567 L
.82375 .01511 L
.82383 .01485 L
.82399 .01587 L
.82414 .01678 L
.82442 .01851 L
.82474 .0203 L
.82504 .02173 L
.82529 .02273 L
.82557 .02358 L
.82572 .0239 L
.82585 .02412 L
.826 .02427 L
.82615 .02434 L
.82631 .02431 L
.82646 .02419 L
.82654 .02408 L
.82662 .02395 L
.82679 .02358 L
.82696 .02312 L
.82714 .02251 L
.82746 .02112 L
.82808 .01774 L
.82824 .0168 L
.82839 .01588 L
Mistroke
.82852 .01504 L
.82866 .0153 L
.8288 .01616 L
.82895 .01707 L
.82921 .01864 L
.82981 .02164 L
.82997 .0223 L
.83015 .02291 L
.8303 .02336 L
.83046 .02373 L
.83061 .02398 L
.8307 .02408 L
.83078 .02414 L
.83091 .0242 L
.83106 .02417 L
.83114 .02412 L
.83123 .02403 L
.83139 .0238 L
.83148 .02363 L
.83156 .02344 L
.83174 .02292 L
.83206 .02178 L
.83239 .02022 L
.8327 .01856 L
.83302 .01664 L
.83316 .01582 L
.8333 .01494 L
.83345 .01546 L
.8336 .01636 L
.8342 .01981 L
.83453 .02138 L
.83484 .02257 L
.83501 .0231 L
.83517 .02348 L
.83526 .02365 L
.83535 .0238 L
.83544 .02392 L
.83554 .02401 L
.83561 .02405 L
.8357 .02406 L
.83579 .02405 L
.83587 .02401 L
.83602 .02387 L
.8361 .02375 L
.83618 .02362 L
.83633 .02329 L
.83649 .02284 L
.83679 .02179 L
.83713 .02026 L
.83744 .01862 L
Mistroke
.83773 .0169 L
.8379 .01593 L
.83805 .015 L
.83818 .01522 L
.83832 .01606 L
.83861 .01781 L
.8389 .01942 L
.83922 .02097 L
.8395 .02212 L
.83966 .02264 L
.8398 .02305 L
.83994 .02338 L
.8401 .02366 L
.84024 .02382 L
.84037 .02391 L
.84049 .02393 L
.84062 .02388 L
.84076 .02376 L
.84089 .02358 L
.84105 .02327 L
.84121 .02284 L
.84152 .0218 L
.8421 .01913 L
.84242 .01731 L
.8426 .01626 L
.84269 .01574 L
.84277 .01526 L
.84291 .01502 L
.84306 .01594 L
.84339 .01784 L
.84396 .02078 L
.84428 .02206 L
.84443 .02256 L
.84457 .02295 L
.8447 .02325 L
.84484 .0235 L
.84499 .02368 L
.84514 .02378 L
.84527 .0238 L
.84541 .02374 L
.84555 .0236 L
.84567 .02342 L
.84583 .02311 L
.84599 .02269 L
.84628 .0217 L
.84695 .01856 L
.84728 .01671 L
.84744 .01576 L
.84759 .01488 L
.84773 .01535 L
Mistroke
.84787 .01619 L
.84817 .01791 L
.84845 .01941 L
.84876 .02085 L
.84903 .02192 L
.84932 .02279 L
.84948 .02315 L
.84956 .02331 L
.84965 .02345 L
.84981 .02361 L
.84996 .02367 L
.85012 .02364 L
.85026 .02353 L
.8504 .02336 L
.85054 .02309 L
.85069 .02273 L
.85084 .02233 L
.8511 .0214 L
.85169 .01863 L
.85194 .01727 L
.8522 .01575 L
.85234 .01495 L
.85249 .01537 L
.85263 .01616 L
.85276 .0169 L
.85336 .02006 L
.85368 .02141 L
.85385 .02203 L
.85402 .02252 L
.85417 .0229 L
.85431 .02318 L
.85447 .02339 L
.85455 .02347 L
.85464 .02352 L
.85478 .02355 L
.85491 .0235 L
.85506 .02338 L
.85521 .02315 L
.85536 .02285 L
.8555 .02251 L
.85581 .02148 L
.85638 .01894 L
.8569 .01611 L
.85703 .01539 L
.85716 .01483 L
.85731 .01568 L
.85745 .01647 L
.85804 .0196 L
.85836 .02103 L
.85867 .0221 L
Mistroke
.85884 .02259 L
.85894 .0228 L
.85903 .02299 L
.85911 .02312 L
.8592 .02325 L
.85936 .02338 L
.85945 .02342 L
.85952 .02343 L
.85961 .02341 L
.85969 .02337 L
.85984 .02323 L
.85992 .02312 L
.86 .02299 L
.8603 .02231 L
.86044 .02186 L
.8606 .02129 L
.86094 .01986 L
.86125 .01833 L
.86155 .01674 L
.86171 .01583 L
.86186 .01496 L
.862 .01528 L
.86216 .01615 L
.86243 .01763 L
.863 .02041 L
.86328 .02152 L
.86345 .02205 L
.8636 .02246 L
.86373 .02275 L
.86387 .023 L
.86402 .02319 L
.86416 .02329 L
.86429 .02331 L
.86443 .02327 L
.86455 .02318 L
.86468 .02301 L
.86484 .02274 L
.865 .02236 L
.8653 .02145 L
.86596 .01855 L
.86624 .01709 L
.86639 .01625 L
.86654 .01544 L
.86662 .01498 L
.86671 .01495 L
.86686 .01582 L
.86717 .01748 L
.86772 .02015 L
.86802 .02134 L
.86831 .02222 L
Mistroke
.86847 .0226 L
.86855 .02277 L
.86864 .02291 L
.86873 .02302 L
.86881 .0231 L
.86895 .02319 L
.8691 .02319 L
.86919 .02316 L
.86927 .02311 L
.86941 .02295 L
.86956 .02271 L
.87079 .01819 L
.87114 .01632 L
.87122 .01586 L
.87131 .01537 L
.87139 .01494 L
.87147 .01495 L
.87163 .01581 L
.87177 .0166 L
.8721 .01831 L
.87265 .02079 L
.87293 .02174 L
.87309 .02219 L
.87324 .02251 L
.8734 .02279 L
.87349 .02291 L
.87357 .02299 L
.87372 .02308 L
.8738 .02309 L
.87388 .02308 L
.87402 .02301 L
.87416 .02285 L
.87432 .02261 L
.87447 .0223 L
.87553 .01826 L
.87582 .01676 L
.87597 .0159 L
.87612 .01508 L
.87626 .01512 L
.87641 .01594 L
.87668 .01734 L
.877 .01893 L
.87733 .02039 L
.87764 .0215 L
.8778 .02194 L
.87793 .02228 L
.87807 .02254 L
.87821 .02276 L
.87836 .02291 L
.8785 .02298 L
Mistroke
.87866 .02297 L
.87874 .02293 L
.87883 .02286 L
.87898 .02267 L
.87913 .02242 L
.87941 .02172 L
.87969 .02082 L
.8802 .01862 L
.88047 .01728 L
.88076 .01577 L
.88084 .01531 L
.88092 .01488 L
.88107 .01536 L
.88121 .01611 L
.88136 .01691 L
.88191 .01958 L
.88222 .02079 L
.88251 .02171 L
.88267 .02212 L
.88285 .02247 L
.88293 .02259 L
.88301 .0227 L
.88316 .02283 L
.88331 .02288 L
.88345 .02285 L
.8836 .02275 L
.88369 .02265 L
.88377 .02254 L
.88392 .02226 L
.88409 .02186 L
.8844 .02092 L
.88476 .01952 L
.88508 .01801 L
.88539 .01644 L
.88556 .01554 L
.88572 .01473 L
.88585 .01545 L
.886 .01622 L
.88631 .01779 L
.8866 .01917 L
.88692 .02048 L
.8872 .02142 L
.88735 .02184 L
.8875 .02217 L
.88764 .02242 L
.88779 .02262 L
.88793 .02273 L
.88806 .02277 L
.88818 .02276 L
.88832 .02269 L
Mistroke
.88846 .02254 L
.88859 .02235 L
.88888 .0217 L
.88903 .02126 L
.8892 .02071 L
.88955 .01934 L
.88987 .01785 L
.89017 .01633 L
.89033 .0155 L
.89041 .01504 L
.89049 .01481 L
.89064 .01558 L
.8908 .01642 L
.89108 .01782 L
.89138 .01918 L
.89169 .02046 L
.89197 .02138 L
.89213 .02178 L
.89227 .0221 L
.89244 .02238 L
.89252 .02249 L
.89262 .02258 L
.8927 .02264 L
.89278 .02267 L
.89294 .02266 L
.89309 .02258 L
.89322 .02244 L
.89338 .0222 L
.89354 .02187 L
.89411 .0201 L
.89439 .01891 L
.89471 .01744 L
.89497 .01609 L
.89512 .01532 L
.89526 .01483 L
.89539 .01551 L
.89553 .01624 L
.89578 .01747 L
.89632 .0199 L
.89662 .02096 L
.8969 .02174 L
.89705 .02204 L
.89721 .0223 L
.89729 .02241 L
.89738 .02249 L
.89754 .02257 L
.89768 .02257 L
.89782 .02251 L
.89796 .02237 L
.89812 .02214 L
Mistroke
.89827 .02185 L
.89841 .02153 L
.89872 .02059 L
.89928 .01831 L
.89954 .01705 L
.89979 .01581 L
.89991 .01518 L
.90004 .01494 L
.90019 .01569 L
.90032 .01637 L
.9009 .0191 L
.90122 .02034 L
.90152 .02128 L
.90177 .02188 L
.90192 .02213 L
.90205 .0223 L
.90218 .02242 L
.90233 .02248 L
.90248 .02246 L
.90263 .02238 L
.90278 .02221 L
.90287 .02207 L
.90295 .02193 L
.90326 .0212 L
.90354 .0203 L
.90384 .01915 L
.90445 .01628 L
.90462 .01543 L
.90472 .01495 L
.9048 .01492 L
.90488 .01533 L
.90497 .01577 L
.90513 .01657 L
.90577 .01948 L
.90609 .02062 L
.90638 .02145 L
.90651 .02175 L
.90664 .02199 L
.90677 .02217 L
.90692 .02231 L
.90707 .02238 L
.9072 .02238 L
.90736 .02231 L
.90751 .02216 L
.90765 .02195 L
.90781 .02164 L
.90814 .02078 L
.90844 .01974 L
.90872 .01858 L
.90903 .01716 L
Mistroke
.90936 .01556 L
.90944 .01515 L
.90953 .01472 L
.90962 .01521 L
.90971 .01566 L
.91004 .01725 L
.91064 .01983 L
.91094 .02084 L
.91112 .02131 L
.91128 .02167 L
.91145 .02197 L
.91155 .0221 L
.91164 .02219 L
.91172 .02225 L
.9118 .02229 L
.91188 .0223 L
.91197 .02229 L
.91213 .02221 L
.91228 .02206 L
.91236 .02195 L
.91244 .02182 L
.91262 .02147 L
.91291 .02068 L
.91318 .01974 L
.91351 .01843 L
.9138 .01709 L
.91395 .01637 L
.91411 .01558 L
.91426 .01482 L
.9144 .01531 L
.91505 .01835 L
.91561 .02048 L
.91577 .02096 L
.91593 .02135 L
.91607 .02165 L
.91622 .02189 L
.91636 .02206 L
.91649 .02216 L
.91662 .02221 L
.91674 .0222 L
.91688 .02213 L
.91701 .02201 L
.91716 .02182 L
.91731 .02154 L
.91851 .0173 L
.91868 .01652 L
.91886 .01565 L
.91894 .01525 L
.91903 .01482 L
.91918 .01539 L
Mistroke
.9198 .01825 L
.92008 .01939 L
.92038 .02043 L
.92066 .02122 L
.92079 .02149 L
.92092 .02173 L
.92107 .02193 L
.92121 .02206 L
.9213 .0221 L
.92138 .02212 L
.92153 .02211 L
.92169 .02201 L
.92184 .02185 L
.92191 .02174 L
.922 .0216 L
.92217 .02125 L
.92271 .01961 L
.9233 .01714 L
.92357 .01586 L
.92372 .01513 L
.92386 .01497 L
.92399 .01559 L
.92413 .01625 L
.92438 .01742 L
.92469 .01875 L
.92502 .01998 L
.9253 .02083 L
.92546 .02122 L
.92561 .02152 L
.92575 .02174 L
.92589 .0219 L
.92603 .022 L
.92619 .02204 L
.92632 .02201 L
.92647 .02192 L
.92659 .02178 L
.92673 .02158 L
.92705 .02089 L
.9274 .01981 L
.92804 .01721 L
.92835 .0158 L
.92843 .01538 L
.92851 .01499 L
.92867 .01518 L
.92881 .01587 L
.92895 .0165 L
.92925 .01785 L
.92953 .01902 L
.92984 .0201 L
.93012 .0209 L
Mistroke
.93038 .02147 L
.93053 .02169 L
.93068 .02185 L
.93083 .02194 L
.93096 .02196 L
.9311 .02192 L
.93119 .02187 L
.93126 .0218 L
.93142 .02161 L
.93159 .02133 L
.93279 .01725 L
.93312 .01573 L
.93321 .01528 L
.9333 .01486 L
.93338 .01495 L
.93347 .01537 L
.9341 .01822 L
.93442 .01944 L
.93471 .02039 L
.93502 .02116 L
.93519 .02146 L
.93528 .02159 L
.93536 .02169 L
.93551 .02182 L
.93559 .02186 L
.93567 .02188 L
.93583 .02186 L
.93597 .02178 L
.9361 .02164 L
.93625 .02143 L
.93652 .02088 L
.93683 .02002 L
.93717 .01883 L
.93749 .01747 L
.93768 .01667 L
.93785 .01588 L
.938 .01514 L
.93809 .01472 L
.93818 .0151 L
.93848 .01649 L
.93906 .01896 L
.93934 .01991 L
.93962 .02072 L
.93978 .02107 L
.93994 .02137 L
.94009 .02158 L
.94023 .02171 L
.94037 .02179 L
.9405 .0218 L
.94063 .02176 L
Mistroke
.94076 .02168 L
.9409 .02152 L
.94105 .02129 L
.94132 .02072 L
.94161 .01988 L
.94193 .01877 L
.9425 .01634 L
.94267 .01558 L
.94276 .01517 L
.94285 .01473 L
.94293 .01508 L
.94302 .01549 L
.94318 .01622 L
.94381 .01883 L
.94411 .01989 L
.9444 .02068 L
.94455 .02103 L
.94469 .02129 L
.94485 .0215 L
.94494 .02159 L
.94502 .02166 L
.94515 .02172 L
.9453 .02172 L
.94542 .02167 L
.94555 .02157 L
.9457 .0214 L
.94585 .02114 L
.94613 .02052 L
.94646 .01957 L
.94681 .01828 L
.94712 .01698 L
.94729 .01623 L
.94745 .0155 L
.9476 .01478 L
.94769 .01505 L
.94777 .01543 L
.94807 .01676 L
.94865 .01908 L
.94894 .02003 L
.94922 .02075 L
.94937 .02106 L
.94953 .02133 L
.94968 .0215 L
.94982 .02161 L
.94995 .02165 L
.95008 .02164 L
.95021 .02158 L
.95035 .02145 L
.9505 .02127 L
.95065 .02101 L
Mistroke
.95092 .0204 L
.95122 .01952 L
.95154 .01837 L
.95181 .01725 L
.95211 .01594 L
.9522 .01554 L
.95229 .01512 L
.95237 .01475 L
.95246 .01508 L
.95279 .01656 L
.95341 .01904 L
.95371 .02001 L
.95387 .02044 L
.95404 .02082 L
.9542 .02112 L
.95435 .02133 L
.9545 .02148 L
.95464 .02155 L
.95477 .02158 L
.95492 .02154 L
.95504 .02146 L
.95518 .02131 L
.95532 .02111 L
.95548 .02082 L
.95576 .02013 L
.95608 .01912 L
.95644 .01779 L
.95675 .01648 L
.95692 .01573 L
.957 .01535 L
.95708 .01501 L
.95722 .01506 L
.95737 .01575 L
.9577 .01717 L
.958 .01838 L
.95828 .01935 L
.95855 .02017 L
.95885 .02086 L
.95902 .02113 L
.95917 .02132 L
.95931 .02144 L
.95946 .0215 L
.95959 .0215 L
.95974 .02143 L
.95987 .02132 L
.95999 .02118 L
.96013 .02096 L
.96028 .02066 L
.96057 .01995 L
.96119 .01777 L
Mistroke
.96154 .01633 L
.96171 .01559 L
.96186 .0149 L
.962 .01512 L
.96214 .01575 L
.96243 .01702 L
.96276 .01831 L
.96306 .01938 L
.96335 .02021 L
.9635 .02057 L
.96367 .02089 L
.9638 .0211 L
.96395 .02127 L
.96409 .02138 L
.96421 .02143 L
.96437 .02142 L
.96452 .02135 L
.96466 .02123 L
.96481 .02103 L
.96497 .02076 L
.96514 .02039 L
.96544 .01956 L
.96604 .0174 L
.96633 .01617 L
.96646 .01561 L
.9666 .01499 L
.96673 .015 L
.96685 .01552 L
.96711 .01664 L
.96766 .01877 L
.96795 .01971 L
.96826 .0205 L
.96842 .02082 L
.96851 .02096 L
.9686 .02109 L
.96869 .02118 L
.96877 .02125 L
.96892 .02134 L
.96906 .02136 L
.9692 .02133 L
.96934 .02123 L
.9695 .02106 L
.96967 .02081 L
.96982 .0205 L
.97011 .01977 L
.97067 .01788 L
.97119 .01576 L
.97132 .01519 L
.97146 .01484 L
.97161 .01551 L
Mistroke
.97175 .01613 L
.97235 .0185 L
.97259 .01929 L
.97284 .02001 L
.97306 .02052 L
.9733 .02093 L
.97344 .02111 L
.97357 .02122 L
.9737 .02128 L
.97383 .0213 L
.97395 .02126 L
.97407 .0212 L
.97419 .02108 L
.97432 .02092 L
.97456 .02049 L
.97483 .01986 L
.9753 .01835 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005Oooool5o`0000?ooooo0_l0000fooooo`?o00001?ooool2o`0003Sooooo0_l0000ioooo
o`?o00001?ooool2o`0003Gooooo1Ol00003ooooo`;o00001oooool001Kooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000fooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000=_ooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000=Oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Kooooo000?ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002kooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=_oo
ool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000=_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo000Hooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0000iooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool01?ooool001Gooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000f
ooooo`04o`000?ooooooooooo`0003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000dooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006oooo
o`005Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000=Oooool2
o`0000Cooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0000hooooo`;o0000
1?ooool01?l0003oooooooooool0000dooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00006ooooo`005_ooool3o`0000Cooooo0_l0000gooooo`03o`000?oooooooooo
00?ooooo0_l0000hooooo`;o0000>_ooool00ol0003oooooooooo`03ooooo`;o0000=_ooool3o`00
00Cooooo0_l00007ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`004Oooooooo`0000go00000oooool000[ooooo0_l00005ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003ooooo
ooooool00004ooooo`?o00001?ooool8o`00o`03ooooool00?oo003o013o003o00?oooooo`00ool0
0?l02ol00?l00ooooooo003oo`00o`0;o`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool0
0?l00_l00?l00ooooooo003oo`00o`06o`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool0
0?l01_l00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool0
0?l01_l00?l02?oooooo003oo`00oooooooo003oooooool00?oooooo1Ol00?l3ooooo`?o003o00?o
ooooo`000?ooool00_l00?l00ooooooo003oooooo`04o`00o`Gooooo0_l00?l00ooooooo003oo`00
o`02o`00o`05ooooool00?oo003oo`00ooooool01?l00?l00ooooooo003oo`00o`02o`00o`03oooo
ool00?oo003o00;o003o00?oooooo`00ool00?l01_l00?l00ooooooo003oo`00o`0@o`00o`03oooo
ool00?oo003o00_o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`0;o`00o`03oooo
ool00?oo003o01Go003o1?ooool3o`0000?ooooo0009ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool01OoooomLo`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool00?l0
1_l00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oooooo00Go003o0_ooool4o`00o`03oooo
ool0003o003o00;o003o00?oooooo`00ooooool01Ol00?l2ooooo`Co003o00?oooooo`00ool00?l0
0_l00?l00ooooooo003oo`00o`0;o`00o`03ooooool00?oo003o05Oo003o1_ooool00ol0003ooooo
ooooo`01ooooo`002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Kooooo
Fol00?l00ooooooo003oo`00o`0;o`00o`03ooooool00?oo003o00;o003o00?oooooo`00ooooool0
1Ol00?l2ooooo`Co003o00?oooooo`000?l00?l00_l00?l00ooooooo003oooooo`05o`00o`;ooooo
1?l00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00_o003o00?oooooo`00ool00?l0
Eol00?l6ooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003ooooooooo
o`0aooooocko003o00?oooooo`00ool00?l00_l00?l00ooooooo003oooooo`05o`00o`03ooooool0
0?oo003o00?o003o00?oooooo`000?l00?l00_l00?l00ooooooo003oooooo`05o`00o`;ooooo1?l0
0?l00ooooooo003oo`00o`0mo`00oc?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0A_ooool00ol00?ooooooo`00o`0[o`00o`03ooooool00?oooooo00;o003o00Cooooo
o`00ool00?oooooo1Ol00?l00ooooooo0000o`00o`02o`00o`03ooooool00?oooooo00;o003o00?o
ooooo`00ool00?l00_ooool4o`00o`03ooooool00?oo003o02So003oB?ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1Booooob;o003o00?oooooo`00ooooool00_l00?l0
1?oooooo003oo`00ooooool5o`00o`03ooooool0003o003o00;o003o00?oooooo`00ooooool00_l0
0?l00ooooooo003oo`00o`02ooooo`Co003o00?oooooo`00ool00?l07?l00?mDooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo05_ooooo6Ol00?l00ooooooo003oooooo`02
o`00o`04ooooool00?oo003oooooo`;o003o00Goooooo`00ool00?ooooooo`000003o`00o`03oooo
ool00?oooooo00;o003o00?oooooo`00ool00?l00_ooool4o`00o`03ooooool00?oo003o01Co003o
G?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1PoooooaKo003o00Co
ooooo`00ool00?oooooo0_l00?l00ooooooo003oo`00o`02ooooo`03o`00oooooooo000000;o003o
00Coooooo`00ool00?oooooo0_l00?l00ooooooo003oo`00o`02oooooaKo003oHOooool00ol0003o
ooooooooo`01ooooo`004Oooool2o`0006Cooooo4ol00?l01?oooooo003oo`00ooooool2o`00o`03
ooooool00?oo003o00;ooooo0_l00?l01?l0003o003oo`00ooooool2o`00o`04ooooool00?oo003o
ooooo`;o003o0_oooolBo`00ofCooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1Voooo
oa3o003o00Coooooo`00ool00?oooooo0_l00?l00ooooooo003oo`00o`02ooooo`;o003o00Co0000
o`00ool00?oooooo0_l00?l01?oooooo003oo`00ooooool2o`00o`;ooooo3ol00?mXooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo06Wooooo3Ol00?l01?oooooo003oo`00
ooooool2o`00o`03ooooool00?oo003o00;ooooo0_l00?l01?l0003o003oo`00ooooool2o`00o`04
ooooool00?oo003oooooo`;o003o0_ooool=o`00of[ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0J_ooool<o`00o`04ooooool00?oo003oooooo`;o003o00?oooooo`00
ool00?l00_ooool2o`00o`04o`000?l00?oo003oooooo`;o003o00Coooooo`00ool00?oooooo0_l0
0?l2ooooo`_o003oK?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1[
ooooo`_o003o00Coooooo`00ool00?oooooo0_l00?l00ooooooo003oooooo`02ooooo`;o003o00?o
0000o`00ool00?l00_ooool01Ol00?ooooooo`00ool00?oooooo00;o003o0_ooool:o`00ofgooooo
00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0K?ooool00ol00?ooooooo`00
o`07o`00o`03ooooool00?oo003o00;ooooo00?o003oooooool00?l01?ooool00ol00?oo0000o`00
o`03ooooo`03o`00oooooooo003o00;ooooo0_l00?l2ooooo`Wo003oK_ooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1^ooooo`So003o00?oooooo`00ool00?l00_ooool0
0ol00?ooooooo`00o`04ooooo`03o`00ool0003o003o00?ooooo00?o003oooooool00?l00_ooool2
o`00o`03ooooool00?oo003o00Oo003oKoooool00ol0003oooooooooo`01ooooo`004Oooool2o`00
073ooooo1ol00?l00ooooooo003oo`00o`02ooooo`03o`00oooooooo003o00Cooooo00?o003oo`00
0?l00?l00oooool00ol00?ooooooo`00o`02ooooo`;o003o00?oooooo`00ool00?l01Ol00?m`oooo
o`;o00000oooool0017ooooo00?o0000ooooooooool0Koooool7o`00o`03ooooool00?oo003o00;o
oooo00?o003oooooool00?l01?ooool00ol00?oo0000o`00o`03ooooo`03o`00oooooooo003o00;o
oooo0_l00?l00ooooooo003oo`00o`05o`00og7ooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0L?ooool6o`00o`03ooooool00?oo003o00;ooooo00?o003oooooool00?l0
1?ooool00ol00?oo0000o`00o`03ooooo`03o`00oooooooo003o00;ooooo0_l00?l00ooooooo003o
o`00o`04o`00og;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0L?oo
ool6o`00o`03ooooool00?oo003o00;ooooo00?o003oooooool00?l01?ooool00ol00?oo0000o`00
o`03ooooo`03o`00oooooooo003o00;ooooo0_l00?l00ooooooo003oo`00o`04o`00og;ooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0LOooool5o`00o`03ooooool00?oo
003o00;ooooo00?o003oooooool00?l01?ooool00ol00?oo0000o`00o`03ooooo`03o`00oooooooo
003o00;ooooo0_l00?l00ooooooo003oo`00o`03o`00og?ooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0LOooool5o`00o`03ooooool00?oo003o00;ooooo00?o003ooooo
ool00?l01?ooool00ol00?oo0000o`00o`03ooooo`03o`00oooooooo003o00;ooooo0_l00?l00ooo
oooo003oo`00o`03o`00og?ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0LOooool5o`00o`03ooooool00?oooooo00;ooooo00?o003oooooool00?l01?ooool00ol00?oo
0000o`00o`03ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l01?l00?mcooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo077ooooo1Ol00?l00ooooooo003o
ooooo`02ooooo`03o`00oooooooo003o00Cooooo00?o003oo`000?l00?l00oooool00ol00?oooooo
o`00o`03ooooo`03o`00oooooooo003o00Co003oLoooool00ol0003oooooooooo`01ooooo`004Ooo
ool2o`0007Cooooo0ol00?l00ooooooo003oooooo`02ooooo`03o`00oooooooo003o00Cooooo00?o
003oo`000?l00?l00oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00?o003oLooo
ool2o`0000?ooooo000Aooooo`03o`000?oooooooooo07?ooooo0ol00?l00ooooooo003oooooo`02
ooooo`03o`00oooooooo003o00Cooooo00?o003oo`000?l00?l00oooool00ol00?ooooooo`00o`03
ooooo`03o`00oooooooo003o00?o003oM?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`1cooooo`?o003o00?oooooo`00ooooool00_ooool00ol00?ooooooo`00o`04oooo
o`;o003o1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00?o003oM?ooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1cooooo`?o003o00?oooooo`00oooo
ool00_ooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool00ol00?ooooooo`00o`03ooooo`03
o`00oooooooo003o00?o003oM?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`1cooooo`?o003o00?oooooo`00ooooool00_ooool00ol00?ooooooo`00o`04ooooo`;o003o
1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o00?o003oM?ooool00ol0003ooooo
ooooo`01ooooo`002?ooool5o`0000Cooooo00?o0000ooooooooool0Loooool3o`00o`03ooooool0
0?oooooo00;ooooo00?o003oooooool00?l01?ooool2o`00o`Cooooo00?o003oooooool00?l00ooo
ool00ol00?ooooooo`00o`03o`00ogCooooo00?o0000ooooooooool00Oooool000Wooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`1cooooo`?o003o00?oooooo`00ooooool00_oo
ool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooo
oooo003o00;o003oMOooool00ol0003oooooooooo`01ooooo`002_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo07Cooooo0_l00?l00ooooooo003oooooo`02ooooo`03o`00oooooooo
003o00Cooooo0_l00?l4ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l00_l00?me
ooooo`03o`000?oooooooooo007ooooo000;ooooo`03o`000?oooooooooo00?ooooo0ol0001doooo
o`;o003o00?oooooo`00ooooool00_ooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool00ol0
0?ooooooo`00o`03ooooo`03o`00oooooooo003o00;o003oLoooool3o`0000?ooooo0008ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1dooooo`;o003o00?oooooo`00
ooooool00_ooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool00ol00?ooooooo`00o`03oooo
o`04o`00oooooooo003oo`00ogKooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo07Cooooo0_l00?l00ooooooo003oooooo`02
ooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`03o`00oooooooo003o00?ooooo00Co003o
ooooool00?oo003oM_ooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000
ooooooooool0M?ooool2o`00o`03ooooool00?oooooo00;ooooo00?o003oooooool00?l01?ooool2
o`00o`Cooooo00?o003oooooool00?l00oooool01?l00?ooooooo`00ool00?mfooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo07Cooooo0_l00?l00ooooooo003oooooo`02
ooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`03o`00oooooooo003o00?ooooo00Co003o
ooooool00?oo003oM_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1d
ooooo`;o003o00?oooooo`00ooooool00_ooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool0
0ol00?ooooooo`00o`03ooooo`04o`00oooooooo003oo`00ogKooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0M?ooool2o`00o`03ooooool00?oooooo00;ooooo00?o003o
ooooool00?l01?ooool2o`00o`Cooooo00?o003oooooool00?l00oooool01?l00?ooooooo`00ool0
0?mfooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Cooooo0_l00?l0
0ooooooo003oooooo`02ooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`03o`00oooooooo
003o00?ooooo00Co003oooooool00?oo003oM_ooool00ol0003oooooooooo`01ooooo`004Oooool2
o`0007Gooooo0_l00?l00ooooooo003oooooo`02ooooo`03o`00oooooooo003o00Cooooo0_l00?l4
ooooo`03o`00oooooooo003o00?ooooo00Co003oooooool00?oo003oMOooool2o`0000?ooooo000A
ooooo`03o`000?oooooooooo07Cooooo0_l00?l00ooooooo003oooooo`02ooooo`03o`00oooooooo
003o00Cooooo0_l00?l4ooooo`03o`00oooooooo003o00?ooooo00Co003oooooool00?oo003oM_oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1dooooo`;o003o00?ooooo
o`00ooooool00_ooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool00ol00?ooooooo`00o`03
ooooo`04o`00oooooooo003oo`00ogKooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000
ooooooooool0M?ooool2o`00o`03ooooool00?oooooo00;ooooo00?o003oooooool00?l01?ooool2
o`00o`Cooooo00?o003oooooool00?l00oooool01?l00?ooooooo`00ool00?mfooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo07Cooooo0_l00?l00ooooooo003oooooo`02
ooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`03o`00oooooooo003o00?ooooo00Co003o
ooooool00?oo003oM_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1e
ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l01?ooool2o`00o`Cooooo00?o003o
ooooool00?l00oooool00ol00?ooooooo`00o`1gooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo07Gooooo00?o003oooooool00?l00oooool00ol00?ooooooo`00o`04oooo
o`;o003o1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o07Oooooo00?o0000oooo
ooooool00Oooool0017ooooo0_l0001fooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`;o
003o1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o07Kooooo0_l00003ooooo`00
4Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`;o003o
1?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooo003o07Oooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0MOooool00ol00?ooooooo`00o`04ooooo`;o003o1?oo
ool2o`00o`Cooooo00?o003oooooool00?l01?ooool2o`00ogOooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0MOooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool2
o`00o`Cooooo00?o003oooooool00?l01?ooool2o`00ogOooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool0MOooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool2o`00
o`Cooooo00?o003oooooool00?l01?ooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0MOooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool2o`00o`Co
oooo00?o003oooooool00?l01?ooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool0MOooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool2o`00o`Cooooo
00?o003oooooool00?l01?ooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0MOooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool2o`00o`Cooooo00?o
003oooooool00?l01?ooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001f
ooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`;o003o1?ooool00ol00?ooooooo`00o`04
ooooo`;o003oM_ooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo07Gooooo00?o003ooooo
ool00?l01?ooool2o`00o`Cooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo0_l00?mgoooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Gooooo00?o003oooooool0
0?l01?ooool2o`00o`Cooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo0_l00?mgooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Gooooo00?o003oooooool00?l0
1?ooool2o`00o`Cooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo0_l00?mgooooo`03o`00
0?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Gooooo00?o003oooooool00?l01?oo
ool2o`00o`Cooooo0_l00?l4ooooo`03o`00oooooooo003o00Cooooo0_l00?mgooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo07Gooooo00?o003oooooool00?l01?ooool2
o`00o`Cooooo0_l00?l4ooooo`;o003o1Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool0
00[ooooo0ol00004ooooo`03o`000?oooooooooo07Gooooo00?o003oooooool00?l01?ooool2o`00
o`Cooooo0_l00?l4ooooo`;o003o1Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool000_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1eooooo`03o`00oooooooo003o00Co
oooo0_l00?l4ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`;o003oMoooool00ol0003o
ooooooooo`01ooooo`002?ooool5o`0000Cooooo0ol0001eooooo`03o`00oooooooo003o00Cooooo
0_l00?l4ooooo`;o003o1Oooool00ol00?ooooooooooo`03ooooo`;o003oMOooool3o`0000?ooooo
0008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0MOooool00ol00?oooooo
o`00o`04ooooo`;o003o1?ooool2o`00o`Gooooo00?o003oooooooooool00oooool2o`00ogOooooo
00?o0000ooooooooool00Oooool000Wooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`1eooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`;o003o1Oooool00ol00?oooooooooo
o`03ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000
ooooooooool0MOooool00ol00?ooooooo`00o`04ooooo`;o003o1?ooool2o`00o`Gooooo00?o003o
ooooooooool00oooool2o`00ogOooooo00?o0000ooooooooool00Oooool000_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1eooooo`03o`00oooooooo003o00Cooooo0_l00?l4oooo
o`;o003o1Oooool00ol00?ooooooooooo`03ooooo`;o003oMoooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`;o
003o1Oooool00ol00?ooooooooooo`03ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`;o003o
1Oooool00ol00?ooooooooooo`03ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`1eooooo`03o`00oooooooo003o00Cooooo0_l00?l4ooooo`;o003o1Ooo
ool00ol00?ooooooooooo`03ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`004Oooool2
o`0007Kooooo00?o003oooooool00?l01?ooool2o`00o`Cooooo0_l00?l5ooooo`03o`00oooooooo
oooo00?ooooo0_l00?mfooooo`;o00000oooool0017ooooo00?o0000ooooooooool0MOooool00ol0
0?ooooooo`00o`04ooooo`;o003o1?ooool2o`00o`Gooooo00?o003oooooooooool00oooool2o`00
ogOooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0MOooool00ol00?oo
ooooo`00o`04ooooo`;o003o1?ooool2o`00o`Gooooo00?o003oooooooooool00oooool2o`00ogOo
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0MOooool00ol00?oooooo
o`00o`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00oooooooooooo00?ooooo
0_l00?mgooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Gooooo00?o
003oooooool00?l01?ooool00ol00?ooooooooooo`03ooooo`;o003o1Oooool00ol00?oooooooooo
o`03ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1e
ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00oooool2o`00o`Gooooo00?o003o
ooooooooool00oooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool0MOooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00?ooooo0_l00?l5oooo
o`03o`00oooooooooooo00?ooooo0_l00?mgooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo07Gooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool2o`00ogOooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l0001fooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo0_l00?mfooooo`;o0000
0oooool0017ooooo00?o0000ooooooooool0MOooool00ol00?ooooooo`00o`0;ooooo`03o`000?oo
oooooooo00Wooooo0_l00?mgooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo07Gooooo00?o003oooooool00?l02oooool00ol0003oooooooooo`09ooooo`;o003oMoooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooo003o
00_ooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool0MOooool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo00Wo
oooo0_l00?mgooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Gooooo
00?o003oooooool00?l02oooool00ol0003oooooooooo`09ooooo`;o003oMoooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooo003o00_ooooo00?o
0000ooooooooool02Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001f
ooooo`03o`00oooooooo003o00_ooooo00?o0000ooooooooool02Oooool2o`00ogKooooo0_l00003
ooooo`004Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooo003o00_ooooo00?o0000oooo
ooooool02Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0MOooool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo00Wooooo0_l00?mgooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Gooooo00?o003oooooool00?l0
2oooool00ol0003oooooooooo`09ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`1eooooo`03o`00oooooooo003o00_ooooo00?o0000ooooooooool02Ooo
ool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0MOooool0
0ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo00Wooooo0_l00?mgooooo`03o`000?oooooo
oooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`1eooooo`03o`00oooooooo003o
00_ooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool000So
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo07Gooooo00?o003ooooo
ool00?l02oooool00ol0003oooooooooo`09ooooo`;o003oMoooool00ol0003oooooooooo`01oooo
o`002?ooool01Ol0003ooooooooooooooooo000000Cooooo0ol0001eooooo`03o`00oooooooo003o
00_ooooo00?o0000ooooooooool02Oooool2o`00ogGooooo0ol00003ooooo`002?ooool4o`0000Go
oooo00?o0000ooooooooool0MOooool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo00Wo
oooo0_l00?mgooooo`03o`000?oooooooooo007ooooo0008ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0MOooool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo00Wooooo
0_l00?mgooooo`03o`000?oooooooooo007ooooo0009ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0MOooool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo00Wooooo0_l0
0?mgooooo`03o`000?oooooooooo007ooooo000:ooooo`;o00001Oooool00ol0003oooooooooo`1e
ooooo`03o`00oooooooo003o00_ooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0MOooool2o`00o`cooooo00?o0000oooo
ooooool02Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0MOooool2o`00o`cooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0MOooool2o`00o`cooooo00?o0000ooooooooool0
2Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo0_l0001fooooo`;o003o3?oo
ool00ol0003oooooooooo`09ooooo`;o003oM_ooool2o`0000?ooooo000Aooooo`03o`000?oooooo
oooo07Gooooo0_l00?l<ooooo`03o`000?oooooooooo00Wooooo0_l00?mgooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo07Gooooo0_l00?l<ooooo`03o`000?oooooooooo
00Wooooo0_l00?mgooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Go
oooo0_l00?l<ooooo`03o`000?oooooooooo00Wooooo0_l00?mgooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo07Gooooo0_l00?l<ooooo`03o`000?oooooooooo00Wooooo
0_l00?mgooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Gooooo0_l0
0?l<ooooo`03o`000?oooooooooo00Wooooo0_l00?mgooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo07Gooooo0_l00?l<ooooo`03o`000?oooooooooo00Wooooo0_l00?mg
ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Gooooo0_l00?l<oooo
o`03o`000?oooooooooo00Wooooo0_l00?mgooooo`03o`000?oooooooooo007ooooo000Aooooo`;o
0000M_ooool2o`00o`cooooo00?o0000ooooooooool02Oooool2o`00ogKooooo0_l00003ooooo`00
4Oooool00ol0003oooooooooo`1eooooo`;o003o3?ooool00ol0003oooooooooo`09ooooo`;o003o
Moooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1eooooo`;o003o3?oo
ool00ol0003oooooooooo`09ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`1eooooo`;o003o3?ooool00ol0003oooooooooo`09ooooo`;o003oMoooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1eooooo`;o003o3?ooool00ol0
003oooooooooo`09ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`1eooooo`;o003o3?ooool00ol0003oooooooooo`09ooooo`;o003oMoooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1eooooo`;o003o3?ooool00ol0003ooooo
ooooo`09ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`004Oooool2o`0007Kooooo0_l0
0?l<ooooo`03o`000?oooooooooo00Wooooo0_l00?mfooooo`;o00000oooool0017ooooo00?o0000
ooooooooool0MOooool2o`00o`cooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0MOooool2o`00o`cooooo00?o0000oooo
ooooool02Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool0MOooool2o`00o`cooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0MOooool2o`00o`cooooo00?o0000ooooooooool0
2Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0MOoo
ool2o`00o`cooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000ooooooooool00Ooo
ool000Wooooo0ol00005ooooo`03o`000?oooooooooo07Gooooo0_l00?l<ooooo`03o`000?oooooo
oooo00Wooooo0_l00?mgooooo`03o`000?oooooooooo007ooooo0008ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`1eooooo`;o003o3?ooool00ol0003oooooooooo`09
ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003ooooooooooooooooo
000000Cooooo0ol0001eooooo`;o003o3?ooool00ol0003oooooooooo`09ooooo`;o003oMOooool3
o`0000?ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`1eooooo`;o003o3?ooool00ol0
003oooooooooo`09ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0MOooool2o`00o`cooooo00?o0000oooo
ooooool02Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool000Sooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo07Gooooo0_l00?l<ooooo`03o`000?oooooooooo
00Wooooo0_l00?mgooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003o
ooooooooo`1eooooo`;o003o3?ooool00ol0003oooooooooo`09ooooo`;o003oMoooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1eooooo`;o003o3?ooool00ol0003ooooo
ooooo`09ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`1eooooo`;o003o3?ooool00ol0003oooooooooo`09ooooo`;o003oMoooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`1eooooo`;o003o3?ooool00ol0003oooooooooo`09
ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`004Oooool2o`0007Kooooo0_l00?l<oooo
o`03o`000?oooooooooo00Wooooo0_l00?mfooooo`;o00000oooool0017ooooo00?o0000oooooooo
ool0MOooool2o`00o`cooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool0MOooool2o`00o`cooooo00?o0000ooooooooool0
2Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0MOoo
ool2o`00o`cooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool0MOooool2o`00o`cooooo00?o0000ooooooooool02Oooool2
o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0M_ooool00ol0
0?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0_l00?mgooooo`03o`000?oooooooooo
007ooooo000Aooooo`03o`000?oooooooooo07Kooooo00?o003oooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`1fooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool2o`00ogOooooo
00?o0000ooooooooool00Oooool0017ooooo0_l0001gooooo`03o`00oooooooooooo00[ooooo00?o
0000ooooooooool02Oooool2o`00ogKooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1f
ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000
ooooooooool00Oooool0017ooooo00?o0000ooooooooool0M_ooool00ol00?ooooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo0_l00?mgooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo07Kooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`09ooooo`;o
003oMoooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1fooooo`03o`00
oooooooooooo00[ooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool0M_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo0_l00?mgooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo07Kooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`09ooooo`;o003oMoooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`1fooooo`03o`00oooooooooooo
00[ooooo00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017o
oooo0_l0001gooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool2o`00ogKo
oooo0_l00003ooooo`004Oooool00ol0003oooooooooo`1fooooo`03o`00oooooooooooo00[ooooo
00?o0000ooooooooool02Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool0M_ooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0_l0
0?mgooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo07Kooooo00?o003o
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`;o003oMoooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`1fooooo`03o`00oooooooooooo00[ooooo00?o0000oooo
ooooool02Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool000?ooooo0ol00004ooooo`;o
00001Oooool00ol0003oooooooooo`1fooooo`03o`00oooooooooooo00[ooooo00?o0000oooooooo
ool02Oooool2o`00ogOooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Kooooo00?o003ooooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`;o003oMoooool00ol0003oooooooooo`01ooooo`00
1?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo0ol0001fooooo`03
o`00oooooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`1dooooo`?o
00000oooool000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo07Kooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`00oooooooooooo07Kooooo00?o0000ooooooooool00Oooool000Cooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07Kooooo00?o003ooooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo07Kooooo00?o0000oooooooo
ool00Oooool000?ooooo0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0Poooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo007ooooo0004ooooo`03o`00
0?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0Oooool0017oooooool0000=o`0000?ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-23.8277, -1.04478, \
0.157693, 0.0642967}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampled waveform (finite-length)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(xd = \ sampler[x, fs]; \ 
    If[OddQ[Length[xd]], \ xd\  = \ Drop[xd, \(-1\)]];\), "\n", 
    \(\(gxn\  = \ 
        DiscreteListPlot[xd, \ Blue, \ Frame \[Rule] True, 
          Axes \[Rule] {True, False}, 
          PlotRange -> {All, 
              Evaluate[\(AbsoluteOptions[gxt, PlotRange]\)[\([1, 2, 
                    2]\)]]}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0194363 0.196383 0.0581337 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21817 -0.0125 -6 -9 ]
[.21817 -0.0125 6 0 ]
[.41254 -0.0125 -6 -9 ]
[.41254 -0.0125 6 0 ]
[.6069 -0.0125 -6 -9 ]
[.6069 -0.0125 6 0 ]
[.80126 -0.0125 -6 -9 ]
[.80126 -0.0125 6 0 ]
[.99563 -0.0125 -6 -9 ]
[.99563 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -12 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .31265 -6 -4.5 ]
[-0.0125 .31265 0 4.5 ]
[-0.0125 .42892 -6 -4.5 ]
[-0.0125 .42892 0 4.5 ]
[-0.0125 .54519 -6 -4.5 ]
[-0.0125 .54519 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21817 0 m
.21817 .00625 L
s
[(10)] .21817 -0.0125 0 1 Mshowa
.41254 0 m
.41254 .00625 L
s
[(20)] .41254 -0.0125 0 1 Mshowa
.6069 0 m
.6069 .00625 L
s
[(30)] .6069 -0.0125 0 1 Mshowa
.80126 0 m
.80126 .00625 L
s
[(40)] .80126 -0.0125 0 1 Mshowa
.99563 0 m
.99563 .00625 L
s
[(50)] .99563 -0.0125 0 1 Mshowa
.125 Mabswid
.06268 0 m
.06268 .00375 L
s
.10155 0 m
.10155 .00375 L
s
.14043 0 m
.14043 .00375 L
s
.1793 0 m
.1793 .00375 L
s
.25705 0 m
.25705 .00375 L
s
.29592 0 m
.29592 .00375 L
s
.33479 0 m
.33479 .00375 L
s
.37366 0 m
.37366 .00375 L
s
.45141 0 m
.45141 .00375 L
s
.49028 0 m
.49028 .00375 L
s
.52915 0 m
.52915 .00375 L
s
.56803 0 m
.56803 .00375 L
s
.64577 0 m
.64577 .00375 L
s
.68465 0 m
.68465 .00375 L
s
.72352 0 m
.72352 .00375 L
s
.76239 0 m
.76239 .00375 L
s
.84014 0 m
.84014 .00375 L
s
.87901 0 m
.87901 .00375 L
s
.91788 0 m
.91788 .00375 L
s
.95675 0 m
.95675 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(-2)] -0.0125 .08012 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(0)] -0.0125 .19638 1 0 Mshowa
0 .31265 m
.00625 .31265 L
s
[(2)] -0.0125 .31265 1 0 Mshowa
0 .42892 m
.00625 .42892 L
s
[(4)] -0.0125 .42892 1 0 Mshowa
0 .54519 m
.00625 .54519 L
s
[(6)] -0.0125 .54519 1 0 Mshowa
.125 Mabswid
0 .10918 m
.00375 .10918 L
s
0 .13825 m
.00375 .13825 L
s
0 .16732 m
.00375 .16732 L
s
0 .22545 m
.00375 .22545 L
s
0 .25452 m
.00375 .25452 L
s
0 .28358 m
.00375 .28358 L
s
0 .34172 m
.00375 .34172 L
s
0 .37078 m
.00375 .37078 L
s
0 .39985 m
.00375 .39985 L
s
0 .45798 m
.00375 .45798 L
s
0 .48705 m
.00375 .48705 L
s
0 .51612 m
.00375 .51612 L
s
0 .05105 m
.00375 .05105 L
s
0 .02198 m
.00375 .02198 L
s
0 .57425 m
.00375 .57425 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21817 .61178 m
.21817 .61803 L
s
.41254 .61178 m
.41254 .61803 L
s
.6069 .61178 m
.6069 .61803 L
s
.80126 .61178 m
.80126 .61803 L
s
.99563 .61178 m
.99563 .61803 L
s
.125 Mabswid
.06268 .61428 m
.06268 .61803 L
s
.10155 .61428 m
.10155 .61803 L
s
.14043 .61428 m
.14043 .61803 L
s
.1793 .61428 m
.1793 .61803 L
s
.25705 .61428 m
.25705 .61803 L
s
.29592 .61428 m
.29592 .61803 L
s
.33479 .61428 m
.33479 .61803 L
s
.37366 .61428 m
.37366 .61803 L
s
.45141 .61428 m
.45141 .61803 L
s
.49028 .61428 m
.49028 .61803 L
s
.52915 .61428 m
.52915 .61803 L
s
.56803 .61428 m
.56803 .61803 L
s
.64577 .61428 m
.64577 .61803 L
s
.68465 .61428 m
.68465 .61803 L
s
.72352 .61428 m
.72352 .61803 L
s
.76239 .61428 m
.76239 .61803 L
s
.84014 .61428 m
.84014 .61803 L
s
.87901 .61428 m
.87901 .61803 L
s
.91788 .61428 m
.91788 .61803 L
s
.95675 .61428 m
.95675 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .31265 m
1 .31265 L
s
.99375 .42892 m
1 .42892 L
s
.99375 .54519 m
1 .54519 L
s
.125 Mabswid
.99625 .10918 m
1 .10918 L
s
.99625 .13825 m
1 .13825 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .22545 m
1 .22545 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .28358 m
1 .28358 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .37078 m
1 .37078 L
s
.99625 .39985 m
1 .39985 L
s
.99625 .45798 m
1 .45798 L
s
.99625 .48705 m
1 .48705 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .02198 m
1 .02198 L
s
.99625 .57425 m
1 .57425 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .19638 m
1 .19638 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .19638 m
.02381 .60332 L
s
.04325 .19638 m
.04325 .42044 L
s
.06268 .19638 m
.06268 .10232 L
s
.08212 .19638 m
.08212 .03046 L
s
.10155 .19638 m
.10155 .23231 L
s
.12099 .19638 m
.12099 .37078 L
s
.14043 .19638 m
.14043 .23231 L
s
.15986 .19638 m
.15986 .03046 L
s
.1793 .19638 m
.1793 .10232 L
s
.19874 .19638 m
.19874 .42044 L
s
.21817 .19638 m
.21817 .60332 L
s
.23761 .19638 m
.23761 .42044 L
s
.25705 .19638 m
.25705 .10232 L
s
.27648 .19638 m
.27648 .03046 L
s
.29592 .19638 m
.29592 .23231 L
s
.31535 .19638 m
.31535 .37078 L
s
.33479 .19638 m
.33479 .23231 L
s
.35423 .19638 m
.35423 .03046 L
s
.37366 .19638 m
.37366 .10232 L
s
.3931 .19638 m
.3931 .42044 L
s
.41254 .19638 m
.41254 .60332 L
s
.43197 .19638 m
.43197 .42044 L
s
.45141 .19638 m
.45141 .10232 L
s
.47085 .19638 m
.47085 .03046 L
s
.49028 .19638 m
.49028 .23231 L
s
.50972 .19638 m
.50972 .37078 L
s
.52915 .19638 m
.52915 .23231 L
s
.54859 .19638 m
.54859 .03046 L
s
.56803 .19638 m
.56803 .10232 L
s
.58746 .19638 m
.58746 .42044 L
s
.6069 .19638 m
.6069 .60332 L
s
.62634 .19638 m
.62634 .42044 L
s
.64577 .19638 m
.64577 .10232 L
s
.66521 .19638 m
.66521 .03046 L
s
.68465 .19638 m
.68465 .23231 L
s
.70408 .19638 m
.70408 .37078 L
s
.72352 .19638 m
.72352 .23231 L
s
.74295 .19638 m
.74295 .03046 L
s
.76239 .19638 m
.76239 .10232 L
s
.78183 .19638 m
.78183 .42044 L
s
.80126 .19638 m
.80126 .60332 L
s
.8207 .19638 m
.8207 .42044 L
s
.84014 .19638 m
.84014 .10232 L
s
.85957 .19638 m
.85957 .03046 L
s
.87901 .19638 m
.87901 .23231 L
s
.89845 .19638 m
.89845 .37078 L
s
.91788 .19638 m
.91788 .23231 L
s
.93732 .19638 m
.93732 .03046 L
s
.95675 .19638 m
.95675 .10232 L
s
.97619 .19638 m
.97619 .42044 L
s
.015 w
.02381 .60332 Mdot
.04325 .42044 Mdot
.06268 .10232 Mdot
.08212 .03046 Mdot
.10155 .23231 Mdot
.12099 .37078 Mdot
.14043 .23231 Mdot
.15986 .03046 Mdot
.1793 .10232 Mdot
.19874 .42044 Mdot
.21817 .60332 Mdot
.23761 .42044 Mdot
.25705 .10232 Mdot
.27648 .03046 Mdot
.29592 .23231 Mdot
.31535 .37078 Mdot
.33479 .23231 Mdot
.35423 .03046 Mdot
.37366 .10232 Mdot
.3931 .42044 Mdot
.41254 .60332 Mdot
.43197 .42044 Mdot
.45141 .10232 Mdot
.47085 .03046 Mdot
.49028 .23231 Mdot
.50972 .37078 Mdot
.52915 .23231 Mdot
.54859 .03046 Mdot
.56803 .10232 Mdot
.58746 .42044 Mdot
.6069 .60332 Mdot
.62634 .42044 Mdot
.64577 .10232 Mdot
.66521 .03046 Mdot
.68465 .23231 Mdot
.70408 .37078 Mdot
.72352 .23231 Mdot
.74295 .03046 Mdot
.76239 .10232 Mdot
.78183 .42044 Mdot
.80126 .60332 Mdot
.8207 .42044 Mdot
.84014 .10232 Mdot
.85957 .03046 Mdot
.87901 .23231 Mdot
.89845 .37078 Mdot
.91788 .23231 Mdot
.93732 .03046 Mdot
.95675 .10232 Mdot
.97619 .42044 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005?ooool2o`0002kooooo0ol00004ooooo`;o0000:_ooool5o`0000?ooooo0_l0000[oooo
o`?o00001?ooool2o`0002_ooooo0ol00003ooooo`;o0000:oooool3o`0000Cooooo0_l00004oooo
o`004oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo0000:_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Wooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002_ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000?ooooo000Cooooo`04o`000?ooooooooooo`0002kooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo0000;Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo02Kooooo1Ol00002ooooo`04o`000?ooooooooooo`0002gooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`01ooooo`004oooool01?l0003oooooooooool0000^ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool0:Oooool2o`0000?ooooo00Co0000oooooooooooo0000:?ooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0002gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`01ooooo`004oooool01?l0003oooooooooool0000^ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo0000;Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooool000000oooool01?l0003oooooooooool0000Yooooo`Co
00000oooool01?l0003oooooooooool00003ooooo`004oooool01?l0003oooooooooool0000]oooo
o`;o00001?ooool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool0000Yooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Zooooo`;o00000oooool01?l0003oooooooooool0000Yooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00000oooool001Cooooo0_l0000_ooooo`03o`000?oooooo
oooo00?ooooo0_l0000[ooooo`?o00001?ooool2o`0002_ooooo0ol00004ooooo`;o0000;?ooool0
0ol0003oooooooooo`02ooooo`;o0000:_ooool5o`0000?ooooo0_l00004ooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`003oooooooo`0000co00001_ooool0
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`;o00001_ooool000oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo037o
oooo0_l00006ooooo`003oooool00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool0
1?ooool000oooooo00?o0000ooooooooool0ooooool8ooooo`03o`000?oooooooooo00Cooooo000?
ooooo`03o`000?oooooooooo0?oooooo2?ooool00ol0003oooooooooo`04ooooo`003oooool2o`00
0?oooooo2?ooool2o`0000Kooooo000?ooooo`03o`000?oooooooooo01;ooooo0ol00?lAooooo`?o
003o7?ooool3o`00oa;ooooo0ol00?lLooooo`?o003o4_ooool3o`00oacooooo0ol00?lBooooo`?o
003o7?ooool3o`00oa7ooooo0ol00?l?ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`00
0?oooooooooo01;ooooo0ol00?lAooooo`?o003o7?ooool3o`00oa;ooooo0ol00?lLooooo`?o003o
4_ooool3o`00oacooooo0ol00?lBooooo`?o003o7?ooool3o`00oa7ooooo0ol00?l?ooooo`03o`00
0?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo01;ooooo0ol00?lAooooo`?o003o7?oo
ool3o`00oa;ooooo0ol00?lLooooo`?o003o4_ooool3o`00oacooooo0ol00?lBooooo`?o003o7?oo
ool3o`00oa7ooooo0ol00?l?ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooo
oooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`04ooooo`003oooool00ol0
003oooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0Looooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool01?ooool000oo
oooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo000?ooooo`;o00005?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`0<ooooo`;o00001_ooool000oooooo00?o
0000ooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo000?
ooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`04
ooooo`003oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00gooooo00?o0000oooo
ooooool01?ooool000oooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0=ooooo`03
o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
3Oooool00ol0003oooooooooo`04ooooo`001_ooool5o`0000Cooooo00?o0000ooooooooool04ooo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo00?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0007ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo0005o`0000?ooooo00?o0000ooooooooool01?ooool3o`0001?ooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool03?ooool2o`0000Kooooo0009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0006ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo
00gooooo00?o0000ooooooooool01?ooool000Kooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`04oooo
o`001oooool3o`0000Gooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0=ooooo`03
o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
3Oooool00ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`0<ooooo`?o003o1?oo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00?o003o4_ooool3o`00o`Cooooo00?o
003oooooooooool04Oooool01?l00?ooooooooooooooool3o`00oa;ooooo0ol00?l3ooooo`03o`00
oooooooooooo01;ooooo00Co003ooooooooooooooooo0ol00?lBooooo`?o003o0oooool00ol00?oo
ooooooooo`0Booooo`04o`00ooooooooooooooooo`?o003o4Oooool3o`00o`Cooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`03o`00o`[ooooo00?o0000ooooooooool01?ooool000oo
oooo00?o0000ooooooooool03?ooool3o`00o`Cooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`03o`00oa;ooooo0ol00?l4ooooo`03o`00oooooooooooo017ooooo00Co003ooooooooo
oooooooo0ol00?lBooooo`?o003o0oooool00ol00?ooooooooooo`0Booooo`04o`00oooooooooooo
ooooo`?o003o4_ooool3o`00o`?ooooo00?o003oooooooooool04_ooool01?l00?oooooooooooooo
ool3o`00oa7ooooo0ol00?l4ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00ol0
0?l:ooooo`03o`000?oooooooooo00Cooooo000?ooooo`;o00003Oooool3o`00o`Cooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`03o`00oa;ooooo0ol00?l4ooooo`03o`00oooooooo
oooo017ooooo00Co003ooooooooooooooooo0ol00?lBooooo`?o003o0oooool00ol00?oooooooooo
o`0Booooo`04o`00ooooooooooooooooo`?o003o4_ooool3o`00o`?ooooo00?o003oooooooooool0
4_ooool01?l00?ooooooooooooooool3o`00oa7ooooo0ol00?l4ooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool00ol00?l9ooooo`;o00001_ooool000oooooo00?o0000ooooooooool0
3_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0
1?ooool000oooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Sooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool03_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool01?ooool0
00oooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00Sooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool03_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool01?ooool000oooooo
00?o0000ooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Sooooo
00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool03_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool01?ooool000oooooo0_l0000?
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01oooool2o`0000Kooooo000?oooo
o`03o`000?oooooooooo00kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aoooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`08oooo
o`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00kooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`00
0?oooooooooo00kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo017ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`00
0?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooo
oooo00kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooo
oooo00Cooooo000?ooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`08ooooo`03o`000?oooooooooo00Cooooo000?ooooo`;o00003oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Oooooo0_l00006ooooo`003oooool00ol0003ooooo
ooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`04ooooo`003oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool02?ooool00ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`0>
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`04
ooooo`003oooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool02?ooool00ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`0>ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`04ooooo`00
2?ooool2o`0000Gooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00Sooooo00?o0000ooooooooool01?ooool000Oooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
4Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
2?ooool00ol0003oooooooooo`04ooooo`001oooool01?l0003oooooooooool00004ooooo`Ko0000
00?o003oo`000?l000000ol000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o0000
00?o003oo`000?l000000ol000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000?o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000?o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000?o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000003o`000003o`00ool0003o000000;o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000003o`000003o`00ool0003o000000;o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000003o`000003o`00ool0003o000000;o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o0000
00?o003oo`000?l000000ol000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o0000
00?o003oo`000?l000000_l000000ol00?oo0000o`000004o`0000Kooooo0007ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool00oooool00ol0003oooooooooo`04ooooo`001ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool0
1?ooool000Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo0008ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo000?ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool01?ooool0
00oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool00oooool00ol0003oooooooooo`04ooooo`003oooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo000?ooooo`;o00001?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool00_ooool2o`0000Kooooo
000?ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0;ooooo`?o003o0oooool01?l00?ooooooooooooooool3o`00o`kooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00_ooooo0ol00?l4ooooo`04o`00
ooooooooooooooooo`?o003o3_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool02oooool3o`00o`Cooooo00Co003ooooooooooooooooo0ol00?l>oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;oooo
o`?o003o1?ooool00ol00?ooooooooooo`03o`00o`kooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00_ooooo0ol00?l3ooooo`04o`00oooooooooooo
ooooo`?o003o3_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00Cooooo000?oooo
o`03o`000?oooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0;oooo
o`?o003o0oooool01?l00?ooooooooooooooool3o`00o`kooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00_ooooo0ol00?l4ooooo`04o`00oooooooo
ooooooooo`?o003o3_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool02oooool3o`00o`Cooooo00Co003ooooooooooooooooo0ol00?l>ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`?o003o
1?ooool00ol00?ooooooooooo`03o`00o`kooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00_ooooo0ol00?l3ooooo`04o`00ooooooooooooooooo`?o
003o3_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`00
0?oooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0;ooooo`?o003o
0oooool01?l00?ooooooooooooooool3o`00o`kooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00_ooooo0ol00?l4ooooo`04o`00oooooooooooooooo
o`?o003o3_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool02oooool3o`00o`Cooooo00Co003ooooooooooooooooo0ol00?l>ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`?o003o1?ooool0
0ol00?ooooooooooo`03o`00o`kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00_ooooo0ol00?l3ooooo`04o`00ooooooooooooooooo`?o003o3_oo
ool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooo
oooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo000?ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`03ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00?o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo000?ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo000?ooooo`;o00001?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00;ooooo0_l00006ooooo`003oooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`04
ooooo`003oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool00oooool00ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`03ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`04ooooo`00
3oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
4Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
0oooool00ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`03ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`04ooooo`003oooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00oooool0
0ol0003oooooooooo`04ooooo`003oooool2o`0000Cooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`02ooooo`;o00001_ooool000oooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`0Booooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool01?ooool000oooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00?ooooo
00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool00oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000
ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00?ooooo00?o0000
ooooooooool01?ooool000oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Boooo
o`03o`00oooooooooooo00?ooooo00?o0000ooooooooool01?ooool000Kooooo1Ol00004ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo0007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool04Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00?ooooo00?o0000oooooooo
ool01?ooool000Sooooo00?o0000ooooooooool01?ooool3o`0000?ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`02ooooo`;o00001_ooool000Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_oo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`001_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00?ooooo00?o
0000ooooooooool01?ooool000Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo0007ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo01;ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`04ooooo`003oooool00ol0
003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Booooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00oooool00ol0
003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool00oooool00ol0003oooooooooo`04ooooo`003oooool00ol0003ooooo
ooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`003oooool2o`0000Cooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`02ooooo`;o00001_ooool000oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0B
ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000oooo
ooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool04Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00?ooooo00?o0000oooo
ooooool01?ooool000oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Booooo`03
o`00oooooooooooo00?ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool0
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0
4Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
4Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool0
1?ooool000oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo00?ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool00oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool01?ooool0
00oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
013ooooo0ol00?lCooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Aooooo`?o003o4oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04?ooool3o`00oaCooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo0ol00?lCooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`?o003o4oooool00ol0
0?ooooooooooo`03ooooo`03o`000?oooooooooo00Cooooo000?ooooo`;o00001?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo013ooooo0ol00?lCooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`?o003o4oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool3o`00oaCo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013o
oooo0ol00?lCooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0@ooooo`?o003o4oooool00ol00?ooooooooooo`02ooooo`;o00001_ooool000oooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo
0ol00?lCooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Aooooo`?o003o4oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04?ooool3o`00oaCooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo013ooooo0ol00?lCooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`?o003o4oooool00ol00?oooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00?ooooo00?o
0000ooooooooool01?ooool000oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00oooool00ol0003oooooooooo`04
ooooo`003oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool09_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool09oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool09oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool09_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool09_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Vooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Wooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Wooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Vooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Vooooo`03
o`00oooooooooooo00?ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool0
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0
0oooool00ol0003oooooooooo`04ooooo`003oooool2o`0000Cooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00;ooooo0_l00006ooooo`003oooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool09oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool09oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool09_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool09_ooool0
0ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo
00?ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool00oooool00ol0003o
ooooooooo`04ooooo`003oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool09_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool09oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool09oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool09_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool09_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
000?ooooo`03o`000?oooooooooo00?ooooo00Co003ooooooooooooooooo0ol00?lWooooo`?o003o
0oooool01?l00?ooooooooooooooool3o`00obKooooo0ol00?l4ooooo`04o`00oooooooooooooooo
o`?o003o9_ooool3o`00o`Cooooo00?o003oooooooooool00ol00?lWooooo`?o003o0oooool01?l0
0?ooooooooooooooool3o`00obOooooo0ol00?l4ooooo`03o`000?oooooooooo00Cooooo0008oooo
o`?o00001?ooool00ol0003oooooooooo`03ooooo`04o`00ooooooooooooooooo`?o003o9oooool3
o`00o`?ooooo00Co003ooooooooooooooooo0ol00?lVooooo`?o003o1?ooool01?l00?oooooooooo
ooooool3o`00obKooooo0ol00?l4ooooo`03o`00oooooooooooo00?o003o9oooool3o`00o`?ooooo
00Co003ooooooooooooooooo0ol00?lWooooo`?o003o1?ooool00ol0003oooooooooo`04ooooo`00
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co003ooooooooooooo
oooo0ol00?lWooooo`?o003o0oooool01?l00?ooooooooooooooool3o`00obKooooo0ol00?l4oooo
o`04o`00ooooooooooooooooo`?o003o9_ooool3o`00o`Cooooo00?o003oooooooooool00ol00?lW
ooooo`?o003o0oooool01?l00?ooooooooooooooool3o`00obOooooo0ol00?l4ooooo`03o`000?oo
oooooooo00Cooooo0006ooooo`Go00001?ooool3o`0000?ooooo00?o003oooooooooool0<Oooool0
0ol00?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<?ooool0
0ol00?ooooooooooo`0aooooo`;o00001_ooool000Kooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Oooool0
0ol00?ooooooooooo`0aooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<_ooool0
0ol0003oooooooooo`04ooooo`001oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo
037ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0booooo`03o`000?oooooooooo
00Cooooo0008ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo037o
oooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo033o
oooo00?o003oooooooooool0<_ooool00ol0003oooooooooo`04ooooo`002Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0<Oooool00ol00?oooooo
ooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<?ooool00ol00?oooooo
ooooo`0booooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o
003oooooooooool0<?ooool00ol00?ooooooooooo`0booooo`03o`000?oooooooooo00Cooooo000?
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0a
ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0b
ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00?ooooo00?o003ooooo
ooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003ooooo
ooooool0<?ooool00ol00?ooooooooooo`0booooo`03o`000?oooooooooo00Cooooo000?ooooo`;o
00001?ooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool0<Oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo037ooooo0_l00006ooooo`00
3oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0
<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0
<_ooool00ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`03ooooo`03o`00oooo
oooooooo037ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooo
oooooooo033ooooo00?o003oooooooooool0<_ooool00ol0003oooooooooo`04ooooo`003oooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Oooool0
0ol00?ooooooooooo`0aooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<_ooool0
0ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo
037ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo
033ooooo00?o003oooooooooool0<_ooool00ol0003oooooooooo`04ooooo`003oooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Oooool00ol00?oo
ooooooooo`0aooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<_ooool00ol0003o
ooooooooo`04ooooo`003oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo037ooooo
00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo033ooooo
00?o003oooooooooool0<_ooool00ol0003oooooooooo`04ooooo`003oooool00ol0003ooooooooo
o`03ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Oooool00ol00?oooooooooo
o`0aooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<_ooool00ol0003ooooooooo
o`04ooooo`003oooool2o`0000Cooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0a
ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0a
ooooo`;o00001_ooool000oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0aoooo
o`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0`oooo
o`03o`00oooooooooooo03;ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000oooooooo
ool00oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool0<Oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo03;ooooo00?o0000oooooooo
ool01?ooool000oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0aooooo`03o`00
oooooooooooo037ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0`ooooo`03o`00
oooooooooooo03;ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool00ooo
ool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Ooo
ool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool01?oo
ool000oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooo
oooo037ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooo
oooo03;ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool00oooool00ol0
0?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Oooool00ol0
0?ooooooooooo`0`ooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool01?ooool000oo
oooo0_l00004ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Oooool00ol00?oo
ooooooooo`0aooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<Oooool2o`0000Ko
oooo000?ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0<Oooool00ol00?oooooo
ooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<?ooool00ol00?oooooo
ooooo`0booooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o
003oooooooooool0<?ooool00ol00?ooooooooooo`0booooo`03o`000?oooooooooo00Cooooo000?
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0a
ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0b
ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00?ooooo00?o003ooooo
ooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003ooooo
ooooool0<?ooool00ol00?ooooooooooo`0booooo`03o`000?oooooooooo00Cooooo000?ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0aooooo`03
o`00oooooooooooo037ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0booooo`03
o`000?oooooooooo00Cooooo0007ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`00
oooooooooooo037ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00
oooooooooooo033ooooo00?o003oooooooooool0<_ooool00ol0003oooooooooo`04ooooo`001_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Oooool00ol00?oooooo
ooooo`0`ooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool01?ooool000Kooooo00Go
0000ooooooooooooooooo`000004ooooo`?o00000oooool00ol00?ooooooooooo`0aooooo`03o`00
oooooooooooo037ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0`ooooo`03o`00
oooooooooooo037ooooo0_l00006ooooo`001_ooool4o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Ooo
ool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool01?oo
ool000Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`00oooooooo
oooo037ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooo
oooo033ooooo00?o003oooooooooool0<_ooool00ol0003oooooooooo`04ooooo`001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0<Oooool00ol0
0?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<?ooool00ol0
0?ooooooooooo`0booooo`03o`000?oooooooooo00Cooooo0008ooooo`;o00001Oooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Oooool00ol00?oo
ooooooooo`0aooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<_ooool00ol0003o
ooooooooo`04ooooo`003oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo037ooooo
00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo033ooooo
00?o003oooooooooool0<_ooool00ol0003oooooooooo`04ooooo`003oooool00ol0003ooooooooo
o`03ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Oooool00ol00?oooooooooo
o`0aooooo`03o`00oooooooooooo033ooooo00?o003oooooooooool0<_ooool00ol0003ooooooooo
o`04ooooo`003oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo037ooooo00?o003o
ooooooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo033ooooo00?o003o
ooooooooool0<_ooool00ol0003oooooooooo`04ooooo`003oooool2o`0000Cooooo00?o003ooooo
ooooool0<Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003ooooo
ooooool0<?ooool00ol00?ooooooooooo`0aooooo`;o00001_ooool000oooooo00?o0000oooooooo
ool00oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003ooooooooo
ool0<Oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo03;ooooo00?o0000oooooooo
ool01?ooool000oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0aooooo`03o`00
oooooooooooo037ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0`ooooo`03o`00
oooooooooooo03;ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool00ooo
ool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Ooo
ool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool01?oo
ool000oooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooo
oooo037ooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooo
oooo03;ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool00oooool00ol0
0?ooooooooooo`0aooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0<Oooool00ol0
0?ooooooooooo`0`ooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool01?ooool000oo
oooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo037o
oooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`0`ooooo`03o`00oooooooooooo03;o
oooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool00_ooool3o`00oc7ooooo
0ol00?laooooo`?o003o<?ooool3o`00oc7ooooo0ol00?lcooooo`03o`000?oooooooooo00Cooooo
000?ooooo`;o00000oooool3o`00oc7ooooo0ol00?laooooo`?o003o<?ooool3o`00oc7ooooo0ol0
0?lbooooo`;o00001_ooool000oooooo00?o0000ooooooooool00_ooool3o`00oc7ooooo0ol00?la
ooooo`?o003o<?ooool3o`00oc7ooooo0ol00?lcooooo`03o`000?oooooooooo00Cooooo000?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2o`0000Kooooo000?oooooooo
00003?l00006ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.23392, -4.17447, \
0.193174, 0.0645854}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CTFT of infinite-length sampled signal", "Subsection"],

Cell[BoxData[
    \(\(Xs[f_, fs_, n_:  5] := SampledSpectrum[X, f, fs, n];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gXs = 
        Plot[Evaluate[PlotConvert[Xs[f, fs, 10],  .05]], {f, \(-2\) fs, 
            2  fs}, PlotStyle \[Rule] {Red, Thickness[ .01]}, \ 
          PlotPoints \[Rule] 1000, \ 
          PlotRange \[Rule] {\(- .02\), 3.12}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.00393652 0.196826 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .20076 m
.02403 .20076 L
.02426 .20076 L
.02432 .20076 L
.02435 .20076 L
.02438 .20076 L
.0244 .20076 L
.02441 .00394 L
.02443 .00394 L
.02445 .00394 L
.02451 .00394 L
.02474 .00394 L
.02575 .00394 L
.02672 .00394 L
.02765 .00394 L
.02864 .00394 L
.02959 .00394 L
.03051 .00394 L
.03149 .00394 L
.03243 .00394 L
.03343 .00394 L
.03439 .00394 L
.03532 .00394 L
.0363 .00394 L
.03725 .00394 L
.03816 .00394 L
.03913 .00394 L
.04007 .00394 L
.04106 .00394 L
.04202 .00394 L
.04294 .00394 L
.04392 .00394 L
.04486 .00394 L
.04577 .00394 L
.04627 .00394 L
.04649 .00394 L
.04673 .00394 L
.04685 .00394 L
.04691 .00394 L
.04694 .00394 L
.04697 .00394 L
.047 .00394 L
.04702 .20076 L
.04705 .20076 L
.04708 .20076 L
.04719 .20076 L
.04766 .20076 L
.0479 .20076 L
.04802 .20076 L
.04813 .20076 L
Mistroke
.04816 .20076 L
.04819 .20076 L
.04821 .20076 L
.04823 .00394 L
.04826 .00394 L
.04839 .00394 L
.04863 .00394 L
.04962 .00394 L
.05057 .00394 L
.05148 .00394 L
.05246 .00394 L
.05339 .00394 L
.05439 .00394 L
.05534 .00394 L
.05627 .00394 L
.05725 .00394 L
.05819 .00394 L
.0591 .00394 L
.06007 .00394 L
.061 .00394 L
.06199 .00394 L
.06294 .00394 L
.06386 .00394 L
.06483 .00394 L
.06577 .00394 L
.06677 .00394 L
.06773 .00394 L
.06866 .00394 L
.06964 .00394 L
.07013 .00394 L
.07037 .00394 L
.07059 .00394 L
.0707 .00394 L
.07076 .00394 L
.07079 .00394 L
.07082 .00394 L
.07084 .39759 L
.07087 .39759 L
.07093 .39759 L
.07103 .39759 L
.0715 .39759 L
.07175 .39759 L
.07187 .39759 L
.07193 .39759 L
.07198 .39759 L
.07201 .39759 L
.07204 .00394 L
.07207 .00394 L
.0721 .00394 L
.07222 .00394 L
Mistroke
.07249 .00394 L
.0734 .00394 L
.07437 .00394 L
.0753 .00394 L
.07629 .00394 L
.07724 .00394 L
.07816 .00394 L
.07914 .00394 L
.08008 .00394 L
.08108 .00394 L
.08204 .00394 L
.08297 .00394 L
.08395 .00394 L
.0849 .00394 L
.08582 .00394 L
.08679 .00394 L
.08772 .00394 L
.08872 .00394 L
.08968 .00394 L
.0906 .00394 L
.09158 .00394 L
.09252 .00394 L
.09343 .00394 L
.09439 .00394 L
.09532 .00394 L
.09631 .00394 L
.09727 .00394 L
.09818 .00394 L
.09916 .00394 L
.10009 .00394 L
.10109 .00394 L
.10205 .00394 L
.10298 .00394 L
.10396 .00394 L
.10491 .00394 L
.10582 .00394 L
.10679 .00394 L
.10772 .00394 L
.10871 .00394 L
.10967 .00394 L
.11059 .00394 L
.11157 .00394 L
.11251 .00394 L
.11351 .00394 L
.11447 .00394 L
.1154 .00394 L
.11639 .00394 L
.11734 .00394 L
.11825 .00394 L
.11923 .00394 L
Mistroke
.12016 .00394 L
.12116 .00394 L
.12212 .00394 L
.12304 .00394 L
.12402 .00394 L
.12497 .00394 L
.12587 .00394 L
.12684 .00394 L
.12777 .00394 L
.12876 .00394 L
.12972 .00394 L
.13063 .00394 L
.13161 .00394 L
.13255 .00394 L
.13355 .00394 L
.13451 .00394 L
.13544 .00394 L
.13642 .00394 L
.13737 .00394 L
.13828 .00394 L
.13925 .00394 L
.14019 .00394 L
.14118 .00394 L
.14214 .00394 L
.14306 .00394 L
.14404 .00394 L
.14498 .00394 L
.14589 .00394 L
.14685 .00394 L
.14778 .00394 L
.14877 .00394 L
.14972 .00394 L
.15064 .00394 L
.15161 .00394 L
.15255 .00394 L
.15355 .00394 L
.15451 .00394 L
.15543 .00394 L
.15641 .00394 L
.15736 .00394 L
.15827 .00394 L
.15924 .00394 L
.16017 .00394 L
.16116 .00394 L
.16212 .00394 L
.16303 .00394 L
.16401 .00394 L
.16495 .00394 L
.16595 .00394 L
.16692 .00394 L
Mistroke
.16784 .00394 L
.16883 .00394 L
.16978 .00394 L
.17069 .00394 L
.17166 .00394 L
.1726 .00394 L
.17359 .00394 L
.17455 .00394 L
.17547 .00394 L
.17646 .00394 L
.1774 .00394 L
.17831 .00394 L
.17927 .00394 L
.1802 .00394 L
.18119 .00394 L
.18215 .00394 L
.18306 .00394 L
.18404 .00394 L
.18498 .00394 L
.18598 .00394 L
.18694 .00394 L
.18786 .00394 L
.18885 .00394 L
.18979 .00394 L
.19071 .00394 L
.19168 .00394 L
.19261 .00394 L
.1936 .00394 L
.19456 .00394 L
.19548 .00394 L
.19646 .00394 L
.1974 .00394 L
.1983 .00394 L
.19927 .00394 L
.2002 .00394 L
.20118 .00394 L
.20214 .00394 L
.20305 .00394 L
.20402 .00394 L
.20496 .00394 L
.20596 .00394 L
.20692 .00394 L
.20784 .00394 L
.20882 .00394 L
.20977 .00394 L
.21068 .00394 L
.21164 .00394 L
.21257 .00394 L
.21305 .00394 L
.2133 .00394 L
Mistroke
.21344 .00394 L
.21357 .00394 L
.21363 .00394 L
.21366 .00394 L
.21369 .00394 L
.21371 .39759 L
.21372 .39759 L
.21376 .39759 L
.21382 .39759 L
.21406 .39759 L
.21452 .39759 L
.21464 .39759 L
.21476 .39759 L
.21483 .39759 L
.21485 .39759 L
.21487 .39759 L
.21489 .00394 L
.2149 .00394 L
.21503 .00394 L
.21551 .00394 L
.21647 .00394 L
.21738 .00394 L
.21836 .00394 L
.21929 .00394 L
.22029 .00394 L
.22125 .00394 L
.22218 .00394 L
.22316 .00394 L
.22411 .00394 L
.22502 .00394 L
.22599 .00394 L
.22692 .00394 L
.22791 .00394 L
.22887 .00394 L
.22978 .00394 L
.23076 .00394 L
.2317 .00394 L
.2327 .00394 L
.23367 .00394 L
.2346 .00394 L
.23558 .00394 L
.23653 .00394 L
.23701 .00394 L
.23722 .00394 L
.23733 .00394 L
.23739 .00394 L
.23745 .00394 L
.23748 .00394 L
.23751 .20076 L
.23752 .20076 L
Mistroke
.23754 .20076 L
.23757 .20076 L
.23769 .20076 L
.23792 .20076 L
.23816 .20076 L
.23842 .20076 L
.23855 .20076 L
.23861 .20076 L
.23864 .20076 L
.23867 .20076 L
.2387 .00394 L
.23872 .00394 L
.23878 .00394 L
.23889 .00394 L
.23934 .00394 L
.24027 .00394 L
.24126 .00394 L
.24222 .00394 L
.24314 .00394 L
.24412 .00394 L
.24506 .00394 L
.24597 .00394 L
.24693 .00394 L
.24786 .00394 L
.24885 .00394 L
.2498 .00394 L
.25072 .00394 L
.25169 .00394 L
.25263 .00394 L
.25362 .00394 L
.25458 .00394 L
.25551 .00394 L
.25649 .00394 L
.25744 .00394 L
.25835 .00394 L
.25931 .00394 L
.26025 .00394 L
.26072 .00394 L
.26097 .00394 L
.26111 .00394 L
.26118 .00394 L
.26124 .00394 L
.26127 .00394 L
.2613 .00394 L
.26133 .20076 L
.26134 .20076 L
.26136 .20076 L
.2615 .20076 L
.26173 .20076 L
.26219 .20076 L
Mistroke
.26231 .20076 L
.26238 .20076 L
.26244 .20076 L
.26247 .20076 L
.26249 .20076 L
.2625 .00394 L
.26252 .00394 L
.26254 .00394 L
.26258 .00394 L
.2627 .00394 L
.26319 .00394 L
.26416 .00394 L
.2651 .00394 L
.2661 .00394 L
.26706 .00394 L
.26798 .00394 L
.26897 .00394 L
.26991 .00394 L
.27083 .00394 L
.2718 .00394 L
.27273 .00394 L
.27372 .00394 L
.27468 .00394 L
.2756 .00394 L
.27657 .00394 L
.27752 .00394 L
.27852 .00394 L
.27948 .00394 L
.28041 .00394 L
.2814 .00394 L
.28235 .00394 L
.28326 .00394 L
.28377 .00394 L
.28423 .00394 L
.28447 .00394 L
.28472 .00394 L
.28483 .00394 L
.28495 .00394 L
.28506 .00394 L
.28509 .00394 L
.28512 .00394 L
.28515 .20076 L
.28517 .20076 L
.28567 .20076 L
.28591 .20076 L
.28613 .20076 L
.28624 .20076 L
.28627 .20076 L
.28628 .20076 L
.2863 .20076 L
Mistroke
.28632 .00394 L
.28635 .00394 L
.28657 .00394 L
.28704 .00394 L
.28798 .00394 L
.28897 .00394 L
.28993 .00394 L
.29085 .00394 L
.29183 .00394 L
.29277 .00394 L
.29368 .00394 L
.29464 .00394 L
.29557 .00394 L
.29656 .00394 L
.29751 .00394 L
.29843 .00394 L
.2994 .00394 L
.30034 .00394 L
.30134 .00394 L
.3023 .00394 L
.30322 .00394 L
.30421 .00394 L
.30515 .00394 L
.30606 .00394 L
.30703 .00394 L
.30796 .00394 L
.30821 .00394 L
.30847 .00394 L
.30859 .00394 L
.30872 .00394 L
.30879 .00394 L
.30884 .00394 L
.3089 .00394 L
.30893 .00394 L
.30896 .39759 L
.30899 .39759 L
.30901 .39759 L
.30907 .39759 L
.30919 .39759 L
.30941 .39759 L
.30965 .39759 L
.30978 .39759 L
.3099 .39759 L
.31001 .39759 L
.31004 .39759 L
.31008 .39759 L
.3101 .39759 L
.31013 .00394 L
.31015 .00394 L
.31017 .00394 L
Mistroke
.3102 .00394 L
.31026 .00394 L
.31038 .00394 L
.31083 .00394 L
.31175 .00394 L
.31274 .00394 L
.31368 .00394 L
.3146 .00394 L
.31557 .00394 L
.3165 .00394 L
.31749 .00394 L
.31845 .00394 L
.31937 .00394 L
.32035 .00394 L
.32129 .00394 L
.3222 .00394 L
.32316 .00394 L
.32409 .00394 L
.32508 .00394 L
.32603 .00394 L
.32694 .00394 L
.32792 .00394 L
.32885 .00394 L
.32985 .00394 L
.33081 .00394 L
.33173 .00394 L
.33271 .00394 L
.33366 .00394 L
.33457 .00394 L
.33554 .00394 L
.33647 .00394 L
.33746 .00394 L
.33841 .00394 L
.33933 .00394 L
.34031 .00394 L
.34125 .00394 L
.34225 .00394 L
.34321 .00394 L
.34414 .00394 L
.34512 .00394 L
.34607 .00394 L
.34699 .00394 L
.34796 .00394 L
.34889 .00394 L
.34989 .00394 L
.35084 .00394 L
.35176 .00394 L
.35275 .00394 L
.35369 .00394 L
.3546 .00394 L
Mistroke
.35556 .00394 L
.35649 .00394 L
.35748 .00394 L
.35843 .00394 L
.35935 .00394 L
.36032 .00394 L
.36126 .00394 L
.36226 .00394 L
.36322 .00394 L
.36414 .00394 L
.36513 .00394 L
.36608 .00394 L
.36699 .00394 L
.36796 .00394 L
.36889 .00394 L
.36988 .00394 L
.37084 .00394 L
.37176 .00394 L
.37273 .00394 L
.37367 .00394 L
.37468 .00394 L
.37564 .00394 L
.37657 .00394 L
.37755 .00394 L
.3785 .00394 L
.37942 .00394 L
.38039 .00394 L
.38133 .00394 L
.38232 .00394 L
.38328 .00394 L
.3842 .00394 L
.38519 .00394 L
.38613 .00394 L
.38704 .00394 L
.38801 .00394 L
.38894 .00394 L
.38993 .00394 L
.39088 .00394 L
.3918 .00394 L
.39277 .00394 L
.39371 .00394 L
.39471 .00394 L
.39567 .00394 L
.3966 .00394 L
.39758 .00394 L
.39853 .00394 L
.39944 .00394 L
.40042 .00394 L
.40135 .00394 L
.40234 .00394 L
Mistroke
.4033 .00394 L
.40422 .00394 L
.4052 .00394 L
.40614 .00394 L
.40705 .00394 L
.40801 .00394 L
.40894 .00394 L
.40993 .00394 L
.41088 .00394 L
.4118 .00394 L
.41277 .00394 L
.41371 .00394 L
.41471 .00394 L
.41567 .00394 L
.41659 .00394 L
.41757 .00394 L
.41852 .00394 L
.41943 .00394 L
.4204 .00394 L
.42133 .00394 L
.42232 .00394 L
.42328 .00394 L
.42419 .00394 L
.42517 .00394 L
.42611 .00394 L
.42711 .00394 L
.42808 .00394 L
.429 .00394 L
.42999 .00394 L
.43094 .00394 L
.43185 .00394 L
.43282 .00394 L
.43376 .00394 L
.43475 .00394 L
.43571 .00394 L
.43663 .00394 L
.43761 .00394 L
.43856 .00394 L
.43947 .00394 L
.44043 .00394 L
.44136 .00394 L
.44235 .00394 L
.4433 .00394 L
.44422 .00394 L
.4452 .00394 L
.44613 .00394 L
.44713 .00394 L
.44809 .00394 L
.44902 .00394 L
.45 .00394 L
Mistroke
.45049 .00394 L
.45095 .00394 L
.45139 .00394 L
.45152 .00394 L
.45164 .00394 L
.45169 .00394 L
.45174 .00394 L
.45177 .00394 L
.45179 .39759 L
.45181 .39759 L
.45186 .39759 L
.4523 .39759 L
.45256 .39759 L
.45268 .39759 L
.45279 .39759 L
.45285 .39759 L
.45291 .39759 L
.45294 .39759 L
.45297 .39759 L
.45299 .00394 L
.45302 .00394 L
.45327 .00394 L
.45378 .00394 L
.45474 .00394 L
.45568 .00394 L
.45667 .00394 L
.45762 .00394 L
.45854 .00394 L
.45952 .00394 L
.46046 .00394 L
.46145 .00394 L
.46242 .00394 L
.46334 .00394 L
.46433 .00394 L
.46528 .00394 L
.46619 .00394 L
.46716 .00394 L
.4681 .00394 L
.46909 .00394 L
.47005 .00394 L
.47097 .00394 L
.47195 .00394 L
.47289 .00394 L
.4738 .00394 L
.4743 .00394 L
.47476 .00394 L
.47522 .00394 L
.47544 .00394 L
.47551 .00394 L
.47554 .00394 L
Mistroke
.47556 .00394 L
.47557 .00394 L
.4756 .20076 L
.47562 .20076 L
.47564 .20076 L
.47569 .20076 L
.47617 .20076 L
.47638 .20076 L
.4766 .20076 L
.47666 .20076 L
.4767 .20076 L
.47673 .20076 L
.47676 .20076 L
.47679 .00394 L
.47682 .00394 L
.47684 .00394 L
.47707 .00394 L
.47757 .00394 L
.47852 .00394 L
.47944 .00394 L
.48041 .00394 L
.48134 .00394 L
.48234 .00394 L
.4833 .00394 L
.48422 .00394 L
.4852 .00394 L
.48615 .00394 L
.48705 .00394 L
.48802 .00394 L
.48895 .00394 L
.48994 .00394 L
.49089 .00394 L
.49181 .00394 L
.49279 .00394 L
.49373 .00394 L
.49473 .00394 L
.49569 .00394 L
.49661 .00394 L
.4976 .00394 L
.49809 .00394 L
.49854 .00394 L
.49898 .00394 L
.49911 .00394 L
.49923 .00394 L
.49934 .00394 L
.49937 .00394 L
.4994 .00394 L
.49943 .20076 L
.49946 .20076 L
.49996 .20076 L
Mistroke
.50018 .20076 L
.5003 .20076 L
.50042 .20076 L
.50048 .20076 L
.50052 .20076 L
.50054 .20076 L
.50057 .20076 L
.5006 .00394 L
.50063 .00394 L
.50066 .00394 L
.50087 .00394 L
.50135 .00394 L
.50232 .00394 L
.50325 .00394 L
.50424 .00394 L
.5052 .00394 L
.50611 .00394 L
.50709 .00394 L
.50803 .00394 L
.50903 .00394 L
.50999 .00394 L
.51092 .00394 L
.51191 .00394 L
.51286 .00394 L
.51377 .00394 L
.51474 .00394 L
.51568 .00394 L
.51667 .00394 L
.51763 .00394 L
.51855 .00394 L
.51953 .00394 L
.52047 .00394 L
.52138 .00394 L
.52188 .00394 L
.52235 .00394 L
.5228 .00394 L
.52303 .00394 L
.52309 .00394 L
.52312 .00394 L
.52316 .00394 L
.52319 .00394 L
.5232 .00394 L
.52322 .20076 L
.52325 .20076 L
.52328 .20076 L
.52375 .20076 L
.52396 .20076 L
.52419 .20076 L
.52425 .20076 L
.52431 .20076 L
Mistroke
.52434 .20076 L
.52437 .20076 L
.5244 .20076 L
.52443 .00394 L
.52446 .00394 L
.52449 .00394 L
.52455 .00394 L
.52466 .00394 L
.52516 .00394 L
.52613 .00394 L
.52707 .00394 L
.52806 .00394 L
.52902 .00394 L
.52994 .00394 L
.53093 .00394 L
.53187 .00394 L
.53278 .00394 L
.53375 .00394 L
.53468 .00394 L
.53567 .00394 L
.53662 .00394 L
.53754 .00394 L
.53852 .00394 L
.53946 .00394 L
.54045 .00394 L
.54142 .00394 L
.54234 .00394 L
.54333 .00394 L
.54428 .00394 L
.54519 .00394 L
.5457 .00394 L
.54616 .00394 L
.54639 .00394 L
.54664 .00394 L
.54675 .00394 L
.54687 .00394 L
.54692 .00394 L
.54698 .00394 L
.54701 .00394 L
.54704 .39759 L
.54706 .39759 L
.54709 .39759 L
.54757 .39759 L
.54778 .39759 L
.54801 .39759 L
.54807 .39759 L
.54813 .39759 L
.54816 .39759 L
.54819 .39759 L
.54822 .00394 L
Mistroke
.54825 .00394 L
.54848 .00394 L
.54898 .00394 L
.54997 .00394 L
.55093 .00394 L
.55185 .00394 L
.55283 .00394 L
.55377 .00394 L
.55477 .00394 L
.55573 .00394 L
.55666 .00394 L
.55764 .00394 L
.55859 .00394 L
.55951 .00394 L
.56048 .00394 L
.56141 .00394 L
.56241 .00394 L
.56337 .00394 L
.56429 .00394 L
.56527 .00394 L
.56621 .00394 L
.56712 .00394 L
.56809 .00394 L
.56902 .00394 L
.57001 .00394 L
.57096 .00394 L
.57188 .00394 L
.57285 .00394 L
.57379 .00394 L
.57479 .00394 L
.57575 .00394 L
.57668 .00394 L
.57766 .00394 L
.57861 .00394 L
.57952 .00394 L
.58049 .00394 L
.58142 .00394 L
.58242 .00394 L
.58337 .00394 L
.58429 .00394 L
.58527 .00394 L
.58621 .00394 L
.58712 .00394 L
.58808 .00394 L
.58901 .00394 L
.59 .00394 L
.59095 .00394 L
.59187 .00394 L
.59284 .00394 L
.59378 .00394 L
Mistroke
.59477 .00394 L
.59573 .00394 L
.59665 .00394 L
.59764 .00394 L
.59858 .00394 L
.59949 .00394 L
.60046 .00394 L
.60139 .00394 L
.60238 .00394 L
.60334 .00394 L
.60425 .00394 L
.60523 .00394 L
.60617 .00394 L
.60717 .00394 L
.60813 .00394 L
.60906 .00394 L
.61005 .00394 L
.61099 .00394 L
.61191 .00394 L
.61288 .00394 L
.61381 .00394 L
.61481 .00394 L
.61576 .00394 L
.61669 .00394 L
.61767 .00394 L
.61861 .00394 L
.61952 .00394 L
.62048 .00394 L
.62141 .00394 L
.6224 .00394 L
.62335 .00394 L
.62427 .00394 L
.62524 .00394 L
.62618 .00394 L
.62718 .00394 L
.62814 .00394 L
.62906 .00394 L
.63005 .00394 L
.63099 .00394 L
.6319 .00394 L
.63287 .00394 L
.63381 .00394 L
.6348 .00394 L
.63575 .00394 L
.63667 .00394 L
.63765 .00394 L
.63859 .00394 L
.63959 .00394 L
.64056 .00394 L
.64148 .00394 L
Mistroke
.64247 .00394 L
.64342 .00394 L
.64434 .00394 L
.64531 .00394 L
.64624 .00394 L
.64724 .00394 L
.6482 .00394 L
.64912 .00394 L
.6501 .00394 L
.65105 .00394 L
.65196 .00394 L
.65292 .00394 L
.65385 .00394 L
.65484 .00394 L
.6558 .00394 L
.65671 .00394 L
.65769 .00394 L
.65863 .00394 L
.65963 .00394 L
.66059 .00394 L
.66152 .00394 L
.6625 .00394 L
.66345 .00394 L
.66436 .00394 L
.66533 .00394 L
.66626 .00394 L
.66726 .00394 L
.66821 .00394 L
.66913 .00394 L
.67011 .00394 L
.67106 .00394 L
.67196 .00394 L
.67293 .00394 L
.67386 .00394 L
.67485 .00394 L
.6758 .00394 L
.67671 .00394 L
.67769 .00394 L
.67862 .00394 L
.67962 .00394 L
.68058 .00394 L
.6815 .00394 L
.68249 .00394 L
.68343 .00394 L
.68434 .00394 L
.68531 .00394 L
.68624 .00394 L
.68723 .00394 L
.68819 .00394 L
.68911 .00394 L
Mistroke
.68958 .00394 L
.68972 .00394 L
.68978 .00394 L
.68981 .00394 L
.68984 .00394 L
.68987 .00394 L
.6899 .39759 L
.68993 .39759 L
.68996 .39759 L
.69008 .39759 L
.69033 .39759 L
.69059 .39759 L
.69072 .39759 L
.69085 .39759 L
.69096 .39759 L
.69099 .39759 L
.69102 .39759 L
.69105 .39759 L
.69108 .00394 L
.69111 .00394 L
.69114 .00394 L
.69119 .00394 L
.69131 .00394 L
.69153 .00394 L
.69203 .00394 L
.69296 .00394 L
.69394 .00394 L
.69489 .00394 L
.6958 .00394 L
.69677 .00394 L
.6977 .00394 L
.69869 .00394 L
.69965 .00394 L
.70057 .00394 L
.70155 .00394 L
.70249 .00394 L
.70349 .00394 L
.70445 .00394 L
.70538 .00394 L
.70637 .00394 L
.70732 .00394 L
.70823 .00394 L
.70921 .00394 L
.71014 .00394 L
.71114 .00394 L
.7121 .00394 L
.71302 .00394 L
.71327 .00394 L
.7135 .00394 L
.71361 .00394 L
Mistroke
.71365 .00394 L
.71368 .00394 L
.71371 .20076 L
.71374 .20076 L
.714 .20076 L
.71448 .20076 L
.71461 .20076 L
.71474 .20076 L
.7148 .20076 L
.71483 .20076 L
.71486 .20076 L
.71489 .00394 L
.7149 .00394 L
.71492 .00394 L
.71498 .00394 L
.71597 .00394 L
.71693 .00394 L
.71785 .00394 L
.71883 .00394 L
.71977 .00394 L
.72068 .00394 L
.72165 .00394 L
.72258 .00394 L
.72357 .00394 L
.72452 .00394 L
.72543 .00394 L
.72641 .00394 L
.72734 .00394 L
.72834 .00394 L
.7293 .00394 L
.73023 .00394 L
.73121 .00394 L
.73216 .00394 L
.73307 .00394 L
.73404 .00394 L
.73497 .00394 L
.73596 .00394 L
.73645 .00394 L
.73691 .00394 L
.73714 .00394 L
.73736 .00394 L
.73742 .00394 L
.73745 .00394 L
.73748 .00394 L
.73749 .00394 L
.73751 .20076 L
.73753 .20076 L
.73755 .20076 L
.73761 .20076 L
.73783 .20076 L
Mistroke
.73829 .20076 L
.73842 .20076 L
.73855 .20076 L
.73861 .20076 L
.73864 .20076 L
.73867 .20076 L
.73868 .20076 L
.7387 .00394 L
.73873 .00394 L
.73879 .00394 L
.73977 .00394 L
.74071 .00394 L
.7417 .00394 L
.74267 .00394 L
.74359 .00394 L
.74458 .00394 L
.74552 .00394 L
.74644 .00394 L
.74741 .00394 L
.74834 .00394 L
.74933 .00394 L
.75029 .00394 L
.75121 .00394 L
.75219 .00394 L
.75313 .00394 L
.75404 .00394 L
.755 .00394 L
.75593 .00394 L
.75692 .00394 L
.75787 .00394 L
.75878 .00394 L
.75976 .00394 L
.76069 .00394 L
.76094 .00394 L
.76107 .00394 L
.76114 .00394 L
.76121 .00394 L
.76126 .00394 L
.76128 .00394 L
.7613 .00394 L
.76133 .20076 L
.76134 .20076 L
.76136 .20076 L
.76139 .20076 L
.76146 .20076 L
.76169 .20076 L
.76194 .20076 L
.76221 .20076 L
.76233 .20076 L
.76239 .20076 L
Mistroke
.76243 .20076 L
.76246 .20076 L
.76249 .20076 L
.76251 .00394 L
.76254 .00394 L
.76257 .00394 L
.76269 .00394 L
.76367 .00394 L
.76461 .00394 L
.76552 .00394 L
.76649 .00394 L
.76742 .00394 L
.76841 .00394 L
.76936 .00394 L
.77027 .00394 L
.77125 .00394 L
.77219 .00394 L
.77319 .00394 L
.77415 .00394 L
.77507 .00394 L
.77605 .00394 L
.777 .00394 L
.77791 .00394 L
.77888 .00394 L
.77981 .00394 L
.78081 .00394 L
.78176 .00394 L
.78268 .00394 L
.78366 .00394 L
.7846 .00394 L
.78485 .00394 L
.78498 .00394 L
.78505 .00394 L
.78509 .00394 L
.78512 .00394 L
.78515 .39759 L
.78518 .39759 L
.78524 .39759 L
.78537 .39759 L
.7856 .39759 L
.78583 .39759 L
.78608 .39759 L
.78618 .39759 L
.78624 .39759 L
.78627 .39759 L
.78629 .39759 L
.78632 .00394 L
.78634 .00394 L
.78635 .00394 L
.78641 .00394 L
Mistroke
.78652 .00394 L
.78752 .00394 L
.78849 .00394 L
.78941 .00394 L
.7904 .00394 L
.79134 .00394 L
.79226 .00394 L
.79323 .00394 L
.79416 .00394 L
.79515 .00394 L
.79611 .00394 L
.79703 .00394 L
.79801 .00394 L
.79895 .00394 L
.79986 .00394 L
.80083 .00394 L
.80176 .00394 L
.80274 .00394 L
.8037 .00394 L
.80461 .00394 L
.80558 .00394 L
.80652 .00394 L
.80752 .00394 L
.80848 .00394 L
.8094 .00394 L
.81039 .00394 L
.81133 .00394 L
.81224 .00394 L
.81321 .00394 L
.81414 .00394 L
.81513 .00394 L
.81609 .00394 L
.81701 .00394 L
.81798 .00394 L
.81893 .00394 L
.81993 .00394 L
.82089 .00394 L
.82182 .00394 L
.8228 .00394 L
.82375 .00394 L
.82466 .00394 L
.82564 .00394 L
.82657 .00394 L
.82757 .00394 L
.82853 .00394 L
.82945 .00394 L
.83043 .00394 L
.83137 .00394 L
.83228 .00394 L
.83325 .00394 L
Mistroke
.83418 .00394 L
.83517 .00394 L
.83612 .00394 L
.83704 .00394 L
.83801 .00394 L
.83895 .00394 L
.83995 .00394 L
.84091 .00394 L
.84183 .00394 L
.84282 .00394 L
.84377 .00394 L
.84468 .00394 L
.84565 .00394 L
.84658 .00394 L
.84757 .00394 L
.84853 .00394 L
.84945 .00394 L
.85043 .00394 L
.85137 .00394 L
.85228 .00394 L
.85324 .00394 L
.85417 .00394 L
.85516 .00394 L
.85611 .00394 L
.85702 .00394 L
.85799 .00394 L
.85893 .00394 L
.85993 .00394 L
.86089 .00394 L
.86181 .00394 L
.86279 .00394 L
.86374 .00394 L
.86465 .00394 L
.86561 .00394 L
.86655 .00394 L
.86754 .00394 L
.86849 .00394 L
.86941 .00394 L
.87038 .00394 L
.87132 .00394 L
.87232 .00394 L
.87329 .00394 L
.87421 .00394 L
.8752 .00394 L
.87615 .00394 L
.87706 .00394 L
.87803 .00394 L
.87897 .00394 L
.87996 .00394 L
.88092 .00394 L
Mistroke
.88184 .00394 L
.88282 .00394 L
.88376 .00394 L
.88467 .00394 L
.88563 .00394 L
.88656 .00394 L
.88755 .00394 L
.8885 .00394 L
.88942 .00394 L
.89039 .00394 L
.89133 .00394 L
.89233 .00394 L
.89329 .00394 L
.89421 .00394 L
.8952 .00394 L
.89614 .00394 L
.89705 .00394 L
.89802 .00394 L
.89896 .00394 L
.89995 .00394 L
.9009 .00394 L
.90182 .00394 L
.9028 .00394 L
.90374 .00394 L
.90474 .00394 L
.90571 .00394 L
.90663 .00394 L
.90762 .00394 L
.90857 .00394 L
.90948 .00394 L
.91046 .00394 L
.91139 .00394 L
.91239 .00394 L
.91335 .00394 L
.91427 .00394 L
.91525 .00394 L
.91619 .00394 L
.9171 .00394 L
.91807 .00394 L
.919 .00394 L
.91999 .00394 L
.92094 .00394 L
.92186 .00394 L
.92284 .00394 L
.92378 .00394 L
.92477 .00394 L
.92574 .00394 L
.92666 .00394 L
.92713 .00394 L
.92738 .00394 L
Mistroke
.92765 .00394 L
.92778 .00394 L
.92784 .00394 L
.9279 .00394 L
.92793 .00394 L
.92796 .00394 L
.92798 .39759 L
.92801 .39759 L
.92814 .39759 L
.92859 .39759 L
.92883 .39759 L
.92896 .39759 L
.92902 .39759 L
.92908 .39759 L
.9291 .39759 L
.92913 .39759 L
.92916 .39759 L
.92918 .00394 L
.92921 .00394 L
.92923 .00394 L
.92929 .00394 L
.92952 .00394 L
.93049 .00394 L
.93142 .00394 L
.93241 .00394 L
.93337 .00394 L
.93429 .00394 L
.93526 .00394 L
.93621 .00394 L
.9372 .00394 L
.93817 .00394 L
.93909 .00394 L
.94008 .00394 L
.94103 .00394 L
.94194 .00394 L
.94291 .00394 L
.94385 .00394 L
.94484 .00394 L
.9458 .00394 L
.94672 .00394 L
.9477 .00394 L
.94865 .00394 L
.94955 .00394 L
.95052 .00394 L
.95097 .00394 L
.95122 .00394 L
.95145 .00394 L
.95157 .00394 L
.95168 .00394 L
.95175 .00394 L
Mistroke
.95176 .00394 L
.95178 .00394 L
.9518 .20076 L
.95181 .20076 L
.95193 .20076 L
.95244 .20076 L
.95268 .20076 L
.9528 .20076 L
.95291 .20076 L
.95294 .20076 L
.95297 .20076 L
.95299 .00394 L
.953 .00394 L
.95303 .00394 L
.95317 .00394 L
.95341 .00394 L
.9544 .00394 L
.95535 .00394 L
.95626 .00394 L
.95723 .00394 L
.95817 .00394 L
.95917 .00394 L
.96013 .00394 L
.96105 .00394 L
.96203 .00394 L
.96298 .00394 L
.96388 .00394 L
.96485 .00394 L
.96578 .00394 L
.96677 .00394 L
.96773 .00394 L
.96864 .00394 L
.96962 .00394 L
.97056 .00394 L
.97156 .00394 L
.97252 .00394 L
.97345 .00394 L
.97443 .00394 L
.97492 .00394 L
.97516 .00394 L
.97538 .00394 L
.97548 .00394 L
.97553 .00394 L
.97556 .00394 L
.97558 .00394 L
.9756 .20076 L
.97563 .20076 L
.97568 .20076 L
.97577 .20076 L
.97619 .20076 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006?ooool5o`0000?ooooo0_l0000fooooo`?o00001?ooool2o`0003Sooooo0_l0000ioooo
o`?o00001?ooool2o`0003Gooooo1Ol00003ooooo`;o00001?ooool001Wooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000fooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000=_ooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000=Oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000?ooooo000Booooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002kooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=_oo
ool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000=_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo000Kooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0000iooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00Oooool001Sooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000f
ooooo`04o`000?ooooooooooo`0003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000dooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`006?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000=Oooool2
o`0000Cooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0000hooooo`;o0000
1?ooool01?l0003oooooooooool0000dooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00003ooooo`006Oooool3o`0000Cooooo0_l0000gooooo`03o`000?oooooooooo
00?ooooo0_l0000hooooo`;o0000>_ooool00ol0003oooooooooo`03ooooo`;o0000=_ooool3o`00
00Cooooo0_l00004ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`003_ooool2
o`000?oooooo4Oooool000gooooo00Co0000oooooooooooo00001?ooooooo`0000_o00000Oooool0
00gooooo00Co0000oooooooooooo00001?ooool2o`0000?ooooooooo0004ooooo`;o00000Oooool0
00gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooooooo`001Oooool1
o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool2
ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2
ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2
ool002Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?oo`008oooool3
ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000=ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2
ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool2
ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`?oo`001?ooool2
ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1
o`00007ooooo000>ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3ool0
00Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool0
02Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool0
00Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool0
00Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo0_l00003ooooo`;oo`001?ooool3ool000Co
oooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Co
oooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Co
oooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool000Co
oooo0_oo0004ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool00_ooool2ool000Cooooo
0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo
0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo
0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool000Cooooo
0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo0_oo
0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo
0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo
000Tooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo
0004ooooo`;oo`001?ooool2ool000Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02
ooooo`;oo`001?ooool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004
ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004
ooooo`;oo`009?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000S
ooooo`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004oooo
o`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004oooo
o`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004oooo
o`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004ooooo`;o
o`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?o
o`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;o
o`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool000Gooooo0Ol00001ooooo`00
5Oooool2o`0000?ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`00
1?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`00
1?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`00
1?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0_l00001ooooo`005Ooo
ool00ol0003oooooooooo`02ooooo`;oo`001?ooool3ool000Cooooo0_oo000Tooooo`;oo`001?oo
ool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?oo
ool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?oo
ool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2
ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool2
ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`?oo`001?ooool2
ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool0
02Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool0
00Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool3ool0
00Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool0
00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3ool000Co
oooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Co
oooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Co
oooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool000Co
oooo0_oo0005ooooo`7o00000Oooool001Gooooo0_l00003ooooo`;oo`001?ooool3ool000Cooooo
0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo
0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo
0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool000Cooooo
0_oo0004ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool00_ooool2ool000Cooooo0ooo
0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo
000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo
0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo
0004ooooo`;oo`001Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo0_oo0004
ooooo`?oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004
ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000T
ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004
ooooo`;oo`001?ooool2ool000Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02oooo
o`;oo`001?ooool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004oooo
o`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004oooo
o`;oo`009?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Soooo
o`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?o
o`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;o
o`001?ooool2ool002Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?o
o`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000Eooooo`;o0000
0oooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`00
1?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`00
1?ooool2ool002Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?oo`00
8oooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?oo
ool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?oo
ool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`001?oo
ool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool000Gooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`02ooooo`;oo`001?ooool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2
ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3
ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2
ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool0
00;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo
00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool0
00Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool0
00Cooooo0_oo000Tooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool0
02?ooooo0ooo0004ooooo`;oo`001?ooool2ool000Gooooo0Ol00001ooooo`0000Goooooo`000?oo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02
ooooo`;oo`001?ooool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004
ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004
ooooo`;oo`009?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000S
ooooo`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool00005ooooool0003ooooo
ooooool000002oooool00ol0003oooooooooo`02ooooo`;o00000oooool2ool000Cooooo0ooo0004
ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000T
ooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004
ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004
ooooo`;oo`001?ooool2o`00007ooooo00001Ooooooo0000oooooooooooo000000_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3ool000Cooooo0_oo000T
ooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004
ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0ooo0004
ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool000Cooooo0_oo0005
ooooo`7o00000Oooool00005ooooool0003oooooooooool000001oooool4o`0000Gooooo00?o0000
ooooooooool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004
ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004
ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004
ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo00001Ooo
oooo0000oooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`;oo`001?ooool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004
ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004
ooooo`;oo`009?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000S
ooooo`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool000;ooooo0_l00008oooo
o`Go00001?ooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3ool000Cooooo0_oo000Toooo
o`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004oooo
o`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0ooo0004oooo
o`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool000Cooooo0_oo0005oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool00_ooool2ool000Cooooo0ooo0004ooooo`;o
o`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;o
o`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`?o
o`001?ooool2ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;o
o`001Oooool1o`00007ooooo000Eooooo`;o00000oooool2ool000Cooooo0ooo0004ooooo`;oo`00
9?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`00
1?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`?oo`00
1?ooool2ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`00
1?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?oo
ool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?oo
ool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?oo
ool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?oo
ool2ool000Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3
ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2
ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2
ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2
ool000Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_ooool2ool0
00Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool0
00Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool0
02Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool0
00Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;o
oooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Co
oooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Co
oooo0_oo000Tooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?o
oooo0ooo0004ooooo`;oo`001?ooool2ool000Gooooo0Ol00001ooooo`005Oooool2o`0000?ooooo
0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo
0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo
0_oo000Tooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo
0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0_l00001ooooo`005Oooool00ol0003ooooooooo
o`02ooooo`;oo`001?ooool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo
0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo
0004ooooo`;oo`009?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo
000Sooooo`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004
ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004
ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004
ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004oooo
o`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004oooo
o`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool3ool000Cooooo0_oo0004oooo
o`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool000Gooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3ool000Cooooo0_oo000Tooooo`;o
o`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`;o
o`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0ooo0004ooooo`;o
o`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o
00000Oooool001Gooooo0_l00003ooooo`;oo`001?ooool3ool000Cooooo0_oo000Tooooo`;oo`00
1?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`00
1?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0ooo0004ooooo`;oo`00
1?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`;o0000
0Oooool001Gooooo00?o0000ooooooooool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?oo
ool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?oo
ool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`?oo`001?oo
ool2ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Ooo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2
ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2
ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool3
ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2
ool000Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3ool0
00Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool0
02Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool0
00Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool0
00Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_ooool2ool000Co
oooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Co
oooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Co
oooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool000Co
oooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000Eooooo`;o00000oooool2ool000Cooooo
0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo
0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo
0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool000Cooooo
0_oo0004ooooo`;oo`001?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00;ooooo0_oo
0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo
0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo
000Tooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo
0004ooooo`;oo`001?ooool2ool000Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02
ooooo`;oo`001?ooool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004
ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004
ooooo`;oo`009?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000S
ooooo`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool000gooooo0ol00005oooo
o`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004oooo
o`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004oooo
o`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool3ool000Cooooo0_oo0004oooo
o`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool000Gooooo0Ol00001oooo
o`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?o
o`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;o
o`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;o
o`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;o
o`001?ooool2ool000Gooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`;o0000
0oooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`00
1?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?ooool3ool000?ooooo0ooo0004ooooo`;oo`00
1?ooool2ool002Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?oo`00
8oooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool2o`00007ooooo000>ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?oo
ool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`;oo`001?oo
ool3ool000?ooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo0_oo0004ooooo`?oo`001?oo
ool2ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Ooo
ool1o`00007ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool2
ool002Cooooo0_oo000Gooooo`;oo`009?ooool2ool000cooooo00?o0000ooooooooool02?ooool2
ool002Cooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`003Oooool2o`00
00Kooooo00?o0000ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool2ool0
00cooooo00?o0000ooooooooool02?ooool2ool002Cooooo0_oo000Gooooo`?oo`008oooool3ool0
017ooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oo
oooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo0_oo000<ooooo`03o`000?oooooooooo00So
oooo0_oo000Tooooo`;oo`005oooool3ool002?ooooo0ooo000Aooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool2ool000cooooo
00?o0000ooooooooool02?ooool2ool002Cooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo
0Ol00001ooooo`005Oooool2o`00013ooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo0_oo
000<ooooo`03o`000?oooooooooo00Sooooo0_oo000Tooooo`;oo`005oooool3ool002?ooooo0ooo
000@ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool03oooool2ool002Cooooo0_oo000G
ooooo`;oo`009?ooool2ool000cooooo00?o0000ooooooooool02?ooool2ool002Cooooo0_oo000G
ooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0?oooo
o`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`;oo`003?ooool00ol0003oooooooooo`08oooo
o`;oo`009?ooool2ool001Oooooo0ooo000Sooooo`?oo`004Oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo0_oo000<ooooo`03
o`000?oooooooooo00Sooooo0_oo000Tooooo`;oo`005oooool3ool002?ooooo0ooo000Aooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;oo`00
9?ooool2ool000cooooo00?o0000ooooooooool02?ooool2ool002Cooooo0_oo000Gooooo`?oo`00
8oooool3ool0017ooooo0Ol00001ooooo`005Oooool2o`00013ooooo0_oo000Tooooo`;oo`005ooo
ool2ool002Cooooo0_oo000<ooooo`03o`000?oooooooooo00Sooooo0_oo000Tooooo`;oo`005ooo
ool3ool002?ooooo0ooo000@ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool03oooool2
ool002Cooooo0_oo000Gooooo`;oo`009?ooool2ool000cooooo00?o0000ooooooooool02?ooool2
ool002Cooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`;oo`003?ooool00ol0
003oooooooooo`08ooooo`;oo`009?ooool2ool001Oooooo0ooo000Sooooo`?oo`004Oooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Co
oooo0_oo000<ooooo`03o`000?oooooooooo00Sooooo0_oo000Tooooo`;oo`005oooool3ool002?o
oooo0ooo000Aooooo`7o00000Oooool001Gooooo00?o0000ooooooooool03oooool2ool002Cooooo
0_oo000Gooooo`;oo`009?ooool2ool000cooooo00?o0000ooooooooool02?ooool2ool002Cooooo
0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`005Oooool2o`00013ooooo0_oo
000Tooooo`;oo`005oooool2ool002Cooooo0_oo000<ooooo`03o`000?oooooooooo00Sooooo0_oo
000Tooooo`;oo`005oooool3ool002?ooooo0ooo000@ooooo`;o00000Oooool001Gooooo00?o0000
ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool2ool000cooooo00?o0000
ooooooooool02?ooool2ool002Cooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000Toooo
o`;oo`003?ooool00ol0003oooooooooo`08ooooo`;oo`009?ooool2ool001Oooooo0ooo000Soooo
o`?oo`004Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00oooooo0_oo000Tooooo`;o
o`005oooool2ool002Cooooo0_oo000<ooooo`03o`000?oooooooooo00Sooooo0_oo000Tooooo`;o
o`005oooool3ool002?ooooo0ooo000Aooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
3oooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool2ool000cooooo00?o0000ooooooooool0
2?ooool2ool002Cooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`005Ooo
ool2o`00013ooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo0_oo000<ooooo`03o`000?oo
oooooooo00Sooooo0_oo000Tooooo`;oo`005oooool3ool002?ooooo0ooo000@ooooo`;o00000Ooo
ool001Gooooo00?o0000ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool2
ool000cooooo00?o0000ooooooooool02?ooool2ool002Cooooo0_oo000Gooooo`?oo`008oooool3
ool0017ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0?ooooo`;oo`009?ooool2ool0
01Oooooo0_oo000Tooooo`;oo`003?ooool00ol0003oooooooooo`08ooooo`;oo`009?ooool2ool0
01Oooooo0ooo000Sooooo`?oo`004Oooool1o`00007ooooo00001?oooooo0000o`000?l00004oooo
o`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo00oooooo0_oo000Toooo
o`;oo`005oooool2ool002Cooooo0_oo000<ooooo`03o`000?oooooooooo00Sooooo0_oo000Toooo
o`;oo`005oooool3ool002?ooooo0ooo000Aooooo`7o00000Oooool000;ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool03oooool2ool0
02Cooooo0_oo000Gooooo`;oo`009?ooool2ool000cooooo00?o0000ooooooooool02?ooool2ool0
02Cooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`000_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool2ool002Co
oooo0_oo000Gooooo`;oo`009?ooool2ool000cooooo00?o0000ooooooooool02?ooool2ool002Co
oooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`000_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l0000@ooooo`;oo`009?ooool2ool001Oooooo
0_oo000Tooooo`;oo`003?ooool00ol0003oooooooooo`08ooooo`;oo`009?ooool2ool001Oooooo
0ooo000Sooooo`?oo`004?ooool2o`00007ooooo0002ooooo`03o`000?oooooooooo00Oooooo1?l0
0005ooooo`03o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo0_oo
000<ooooo`03o`000?oooooooooo00Sooooo0_oo000Tooooo`;oo`005oooool3ool002?ooooo0ooo
000Aooooo`7o00000Oooool00003ooooool0003o000000Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`;oo`003?ooool0
0ol0003oooooooooo`08ooooo`;oo`009?ooool2ool001Oooooo0ooo000Sooooo`?oo`004Oooool1
o`00007ooooo0002ooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo
00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo0_oo000<ooooo`03o`000?oooooooooo
00Sooooo0_oo000Tooooo`;oo`005oooool3ool002?ooooo0ooo000Aooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool2ool000co
oooo00?o0000ooooooooool02?ooool2ool002Cooooo0_oo000Gooooo`?oo`008oooool3ool0017o
oooo0Ol00001ooooo`005Oooool2o`00013ooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo
0_oo000<ooooo`03o`000?oooooooooo00Sooooo0_oo000Tooooo`;oo`005oooool3ool002?ooooo
0ooo000@ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool03oooool2ool002Cooooo0_oo
000Gooooo`;oo`009?ooool2ool000cooooo00?o0000ooooooooool02?ooool2ool002Cooooo0_oo
000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0?
ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`;oo`003?ooool00ol0003oooooooooo`08
ooooo`;oo`009?ooool2ool001Oooooo0ooo000Sooooo`?oo`004Oooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo0_oo000<oooo
o`03o`000?oooooooooo00Sooooo0_oo000Tooooo`;oo`005oooool3ool002?ooooo0ooo000Aoooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;o
o`009?ooool2ool000cooooo00?o0000ooooooooool02?ooool2ool002Cooooo0_oo000Gooooo`?o
o`008oooool3ool0017ooooo0Ol00001ooooo`005Oooool2o`00013ooooo0_oo000Tooooo`;oo`00
5oooool2ool002Cooooo0_oo000<ooooo`03o`000?oooooooooo00Sooooo0_oo000Tooooo`;oo`00
5oooool3ool002?ooooo0ooo000@ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool03ooo
ool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool2ool000cooooo00?o0000ooooooooool02?oo
ool2ool002Cooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`;oo`003?ooool0
0ol0003oooooooooo`08ooooo`;oo`009?ooool2ool001Oooooo0ooo000Sooooo`?oo`004Oooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool0
02Cooooo0_oo000<ooooo`03o`000?oooooooooo00Sooooo0_oo000Tooooo`;oo`005oooool3ool0
02?ooooo0ooo000Aooooo`7o00000Oooool001Gooooo00?o0000ooooooooool03oooool2ool002Co
oooo0_oo000Gooooo`;oo`009?ooool2ool000cooooo00?o0000ooooooooool02?ooool2ool002Co
oooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`005Oooool2o`00013ooooo
0_oo000Tooooo`;oo`005oooool2ool002Cooooo0_oo000<ooooo`03o`000?oooooooooo00Sooooo
0_oo000Tooooo`;oo`005oooool3ool002?ooooo0ooo000@ooooo`;o00000Oooool001Gooooo00?o
0000ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool2ool000cooooo00?o
0000ooooooooool02?ooool2ool002Cooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000T
ooooo`;oo`003?ooool00ol0003oooooooooo`08ooooo`;oo`009?ooool2ool001Oooooo0ooo000S
ooooo`?oo`004Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00oooooo0_oo000Toooo
o`;oo`005oooool2ool002Cooooo0_oo000<ooooo`03o`000?oooooooooo00Sooooo0_oo000Toooo
o`;oo`005oooool3ool002?ooooo0ooo000Aooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool03oooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool2ool000cooooo00?o0000oooooooo
ool02?ooool2ool002Cooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`00
5Oooool2o`00013ooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo0_oo000<ooooo`03o`00
0?oooooooooo00Sooooo0_oo000Tooooo`;oo`005oooool3ool002?ooooo0ooo000@ooooo`;o0000
0Oooool001Gooooo00?o0000ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;oo`009?oo
ool2ool000cooooo00?o0000ooooooooool02?ooool2ool002Cooooo0_oo000Gooooo`?oo`008ooo
ool3ool0017ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0?ooooo`;oo`009?ooool2
ool001Oooooo0_oo000Tooooo`;oo`003?ooool00ol0003oooooooooo`08ooooo`;oo`009?ooool2
ool001Oooooo0ooo000Sooooo`?oo`004Oooool1o`00007ooooo000<ooooo`Go00001?ooool00ol0
003oooooooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`;oo`003?ooool00ol0
003oooooooooo`08ooooo`;oo`009?ooool2ool001Oooooo0ooo000Sooooo`?oo`004Oooool1o`00
007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03oooool2ool0
02Cooooo0_oo000Gooooo`;oo`009?ooool2ool000cooooo00?o0000ooooooooool02?ooool2ool0
02Cooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`003_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Co
oooo0_oo000<ooooo`03o`000?oooooooooo00Sooooo0_oo000Tooooo`;oo`005oooool3ool002?o
oooo0ooo000Aooooo`7o00000Oooool000oooooo00?o0000ooooooooool00oooool2o`00013ooooo
0_oo000Tooooo`;oo`005oooool2ool002Cooooo0_oo000<ooooo`03o`000?oooooooooo00Sooooo
0ooo000Sooooo`?oo`005_ooool3ool002?ooooo0ooo000@ooooo`;o00000Oooool000cooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`00
5oooool2ool002Cooooo0_oo000<ooooo`03o`000?oooooooooo00Sooooo0ooo000Sooooo`?oo`00
5_ooool3ool002?ooooo0ooo000Aooooo`7o00000Oooool000cooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo
000=ooooo`?o00001Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`005Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0
003oooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001oooo
o`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?o
oooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool0POooool1o`00007ooooo0005o`0000?ooooo00?o0000ooooooooool00_oo
ool3o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Ooo
ool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool000;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0POooool1o`00007ooooo0003ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00_ooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo00001Ol0
003ooooooooooooooooo000000Oooooo1?l00005ooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0POooool1o`00007ooooo00001Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`0000Coooooo`000?l0003o00002?ooool5o`0000Cooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083o
oooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001oooo
o`005Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003ooooo
ooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o
00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`005Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`003Oooool3
o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool0
00cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0POooool1o`00007ooooo000@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool000kooooo0_l00005ooooo`;o
0000Poooool00ol0003oooooooooo`20ooooo`;o00000Oooool0013ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`003?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`21ooooo`7o00000Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0POooool1o`00007ooooo000Eooooo`;o00001?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool2o`00007ooooo000Eoooooooo
00002ol00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-24.3721, -0.260466, \
0.158161, 0.0191323}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gXXs = Show[gXs, gX];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.00393652 0.196826 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .20076 m
.02403 .20076 L
.02426 .20076 L
.02432 .20076 L
.02435 .20076 L
.02438 .20076 L
.0244 .20076 L
.02441 .00394 L
.02443 .00394 L
.02445 .00394 L
.02451 .00394 L
.02474 .00394 L
.02575 .00394 L
.02672 .00394 L
.02765 .00394 L
.02864 .00394 L
.02959 .00394 L
.03051 .00394 L
.03149 .00394 L
.03243 .00394 L
.03343 .00394 L
.03439 .00394 L
.03532 .00394 L
.0363 .00394 L
.03725 .00394 L
.03816 .00394 L
.03913 .00394 L
.04007 .00394 L
.04106 .00394 L
.04202 .00394 L
.04294 .00394 L
.04392 .00394 L
.04486 .00394 L
.04577 .00394 L
.04627 .00394 L
.04649 .00394 L
.04673 .00394 L
.04685 .00394 L
.04691 .00394 L
.04694 .00394 L
.04697 .00394 L
.047 .00394 L
.04702 .20076 L
.04705 .20076 L
.04708 .20076 L
.04719 .20076 L
.04766 .20076 L
.0479 .20076 L
.04802 .20076 L
.04813 .20076 L
Mistroke
.04816 .20076 L
.04819 .20076 L
.04821 .20076 L
.04823 .00394 L
.04826 .00394 L
.04839 .00394 L
.04863 .00394 L
.04962 .00394 L
.05057 .00394 L
.05148 .00394 L
.05246 .00394 L
.05339 .00394 L
.05439 .00394 L
.05534 .00394 L
.05627 .00394 L
.05725 .00394 L
.05819 .00394 L
.0591 .00394 L
.06007 .00394 L
.061 .00394 L
.06199 .00394 L
.06294 .00394 L
.06386 .00394 L
.06483 .00394 L
.06577 .00394 L
.06677 .00394 L
.06773 .00394 L
.06866 .00394 L
.06964 .00394 L
.07013 .00394 L
.07037 .00394 L
.07059 .00394 L
.0707 .00394 L
.07076 .00394 L
.07079 .00394 L
.07082 .00394 L
.07084 .39759 L
.07087 .39759 L
.07093 .39759 L
.07103 .39759 L
.0715 .39759 L
.07175 .39759 L
.07187 .39759 L
.07193 .39759 L
.07198 .39759 L
.07201 .39759 L
.07204 .00394 L
.07207 .00394 L
.0721 .00394 L
.07222 .00394 L
Mistroke
.07249 .00394 L
.0734 .00394 L
.07437 .00394 L
.0753 .00394 L
.07629 .00394 L
.07724 .00394 L
.07816 .00394 L
.07914 .00394 L
.08008 .00394 L
.08108 .00394 L
.08204 .00394 L
.08297 .00394 L
.08395 .00394 L
.0849 .00394 L
.08582 .00394 L
.08679 .00394 L
.08772 .00394 L
.08872 .00394 L
.08968 .00394 L
.0906 .00394 L
.09158 .00394 L
.09252 .00394 L
.09343 .00394 L
.09439 .00394 L
.09532 .00394 L
.09631 .00394 L
.09727 .00394 L
.09818 .00394 L
.09916 .00394 L
.10009 .00394 L
.10109 .00394 L
.10205 .00394 L
.10298 .00394 L
.10396 .00394 L
.10491 .00394 L
.10582 .00394 L
.10679 .00394 L
.10772 .00394 L
.10871 .00394 L
.10967 .00394 L
.11059 .00394 L
.11157 .00394 L
.11251 .00394 L
.11351 .00394 L
.11447 .00394 L
.1154 .00394 L
.11639 .00394 L
.11734 .00394 L
.11825 .00394 L
.11923 .00394 L
Mistroke
.12016 .00394 L
.12116 .00394 L
.12212 .00394 L
.12304 .00394 L
.12402 .00394 L
.12497 .00394 L
.12587 .00394 L
.12684 .00394 L
.12777 .00394 L
.12876 .00394 L
.12972 .00394 L
.13063 .00394 L
.13161 .00394 L
.13255 .00394 L
.13355 .00394 L
.13451 .00394 L
.13544 .00394 L
.13642 .00394 L
.13737 .00394 L
.13828 .00394 L
.13925 .00394 L
.14019 .00394 L
.14118 .00394 L
.14214 .00394 L
.14306 .00394 L
.14404 .00394 L
.14498 .00394 L
.14589 .00394 L
.14685 .00394 L
.14778 .00394 L
.14877 .00394 L
.14972 .00394 L
.15064 .00394 L
.15161 .00394 L
.15255 .00394 L
.15355 .00394 L
.15451 .00394 L
.15543 .00394 L
.15641 .00394 L
.15736 .00394 L
.15827 .00394 L
.15924 .00394 L
.16017 .00394 L
.16116 .00394 L
.16212 .00394 L
.16303 .00394 L
.16401 .00394 L
.16495 .00394 L
.16595 .00394 L
.16692 .00394 L
Mistroke
.16784 .00394 L
.16883 .00394 L
.16978 .00394 L
.17069 .00394 L
.17166 .00394 L
.1726 .00394 L
.17359 .00394 L
.17455 .00394 L
.17547 .00394 L
.17646 .00394 L
.1774 .00394 L
.17831 .00394 L
.17927 .00394 L
.1802 .00394 L
.18119 .00394 L
.18215 .00394 L
.18306 .00394 L
.18404 .00394 L
.18498 .00394 L
.18598 .00394 L
.18694 .00394 L
.18786 .00394 L
.18885 .00394 L
.18979 .00394 L
.19071 .00394 L
.19168 .00394 L
.19261 .00394 L
.1936 .00394 L
.19456 .00394 L
.19548 .00394 L
.19646 .00394 L
.1974 .00394 L
.1983 .00394 L
.19927 .00394 L
.2002 .00394 L
.20118 .00394 L
.20214 .00394 L
.20305 .00394 L
.20402 .00394 L
.20496 .00394 L
.20596 .00394 L
.20692 .00394 L
.20784 .00394 L
.20882 .00394 L
.20977 .00394 L
.21068 .00394 L
.21164 .00394 L
.21257 .00394 L
.21305 .00394 L
.2133 .00394 L
Mistroke
.21344 .00394 L
.21357 .00394 L
.21363 .00394 L
.21366 .00394 L
.21369 .00394 L
.21371 .39759 L
.21372 .39759 L
.21376 .39759 L
.21382 .39759 L
.21406 .39759 L
.21452 .39759 L
.21464 .39759 L
.21476 .39759 L
.21483 .39759 L
.21485 .39759 L
.21487 .39759 L
.21489 .00394 L
.2149 .00394 L
.21503 .00394 L
.21551 .00394 L
.21647 .00394 L
.21738 .00394 L
.21836 .00394 L
.21929 .00394 L
.22029 .00394 L
.22125 .00394 L
.22218 .00394 L
.22316 .00394 L
.22411 .00394 L
.22502 .00394 L
.22599 .00394 L
.22692 .00394 L
.22791 .00394 L
.22887 .00394 L
.22978 .00394 L
.23076 .00394 L
.2317 .00394 L
.2327 .00394 L
.23367 .00394 L
.2346 .00394 L
.23558 .00394 L
.23653 .00394 L
.23701 .00394 L
.23722 .00394 L
.23733 .00394 L
.23739 .00394 L
.23745 .00394 L
.23748 .00394 L
.23751 .20076 L
.23752 .20076 L
Mistroke
.23754 .20076 L
.23757 .20076 L
.23769 .20076 L
.23792 .20076 L
.23816 .20076 L
.23842 .20076 L
.23855 .20076 L
.23861 .20076 L
.23864 .20076 L
.23867 .20076 L
.2387 .00394 L
.23872 .00394 L
.23878 .00394 L
.23889 .00394 L
.23934 .00394 L
.24027 .00394 L
.24126 .00394 L
.24222 .00394 L
.24314 .00394 L
.24412 .00394 L
.24506 .00394 L
.24597 .00394 L
.24693 .00394 L
.24786 .00394 L
.24885 .00394 L
.2498 .00394 L
.25072 .00394 L
.25169 .00394 L
.25263 .00394 L
.25362 .00394 L
.25458 .00394 L
.25551 .00394 L
.25649 .00394 L
.25744 .00394 L
.25835 .00394 L
.25931 .00394 L
.26025 .00394 L
.26072 .00394 L
.26097 .00394 L
.26111 .00394 L
.26118 .00394 L
.26124 .00394 L
.26127 .00394 L
.2613 .00394 L
.26133 .20076 L
.26134 .20076 L
.26136 .20076 L
.2615 .20076 L
.26173 .20076 L
.26219 .20076 L
Mistroke
.26231 .20076 L
.26238 .20076 L
.26244 .20076 L
.26247 .20076 L
.26249 .20076 L
.2625 .00394 L
.26252 .00394 L
.26254 .00394 L
.26258 .00394 L
.2627 .00394 L
.26319 .00394 L
.26416 .00394 L
.2651 .00394 L
.2661 .00394 L
.26706 .00394 L
.26798 .00394 L
.26897 .00394 L
.26991 .00394 L
.27083 .00394 L
.2718 .00394 L
.27273 .00394 L
.27372 .00394 L
.27468 .00394 L
.2756 .00394 L
.27657 .00394 L
.27752 .00394 L
.27852 .00394 L
.27948 .00394 L
.28041 .00394 L
.2814 .00394 L
.28235 .00394 L
.28326 .00394 L
.28377 .00394 L
.28423 .00394 L
.28447 .00394 L
.28472 .00394 L
.28483 .00394 L
.28495 .00394 L
.28506 .00394 L
.28509 .00394 L
.28512 .00394 L
.28515 .20076 L
.28517 .20076 L
.28567 .20076 L
.28591 .20076 L
.28613 .20076 L
.28624 .20076 L
.28627 .20076 L
.28628 .20076 L
.2863 .20076 L
Mistroke
.28632 .00394 L
.28635 .00394 L
.28657 .00394 L
.28704 .00394 L
.28798 .00394 L
.28897 .00394 L
.28993 .00394 L
.29085 .00394 L
.29183 .00394 L
.29277 .00394 L
.29368 .00394 L
.29464 .00394 L
.29557 .00394 L
.29656 .00394 L
.29751 .00394 L
.29843 .00394 L
.2994 .00394 L
.30034 .00394 L
.30134 .00394 L
.3023 .00394 L
.30322 .00394 L
.30421 .00394 L
.30515 .00394 L
.30606 .00394 L
.30703 .00394 L
.30796 .00394 L
.30821 .00394 L
.30847 .00394 L
.30859 .00394 L
.30872 .00394 L
.30879 .00394 L
.30884 .00394 L
.3089 .00394 L
.30893 .00394 L
.30896 .39759 L
.30899 .39759 L
.30901 .39759 L
.30907 .39759 L
.30919 .39759 L
.30941 .39759 L
.30965 .39759 L
.30978 .39759 L
.3099 .39759 L
.31001 .39759 L
.31004 .39759 L
.31008 .39759 L
.3101 .39759 L
.31013 .00394 L
.31015 .00394 L
.31017 .00394 L
Mistroke
.3102 .00394 L
.31026 .00394 L
.31038 .00394 L
.31083 .00394 L
.31175 .00394 L
.31274 .00394 L
.31368 .00394 L
.3146 .00394 L
.31557 .00394 L
.3165 .00394 L
.31749 .00394 L
.31845 .00394 L
.31937 .00394 L
.32035 .00394 L
.32129 .00394 L
.3222 .00394 L
.32316 .00394 L
.32409 .00394 L
.32508 .00394 L
.32603 .00394 L
.32694 .00394 L
.32792 .00394 L
.32885 .00394 L
.32985 .00394 L
.33081 .00394 L
.33173 .00394 L
.33271 .00394 L
.33366 .00394 L
.33457 .00394 L
.33554 .00394 L
.33647 .00394 L
.33746 .00394 L
.33841 .00394 L
.33933 .00394 L
.34031 .00394 L
.34125 .00394 L
.34225 .00394 L
.34321 .00394 L
.34414 .00394 L
.34512 .00394 L
.34607 .00394 L
.34699 .00394 L
.34796 .00394 L
.34889 .00394 L
.34989 .00394 L
.35084 .00394 L
.35176 .00394 L
.35275 .00394 L
.35369 .00394 L
.3546 .00394 L
Mistroke
.35556 .00394 L
.35649 .00394 L
.35748 .00394 L
.35843 .00394 L
.35935 .00394 L
.36032 .00394 L
.36126 .00394 L
.36226 .00394 L
.36322 .00394 L
.36414 .00394 L
.36513 .00394 L
.36608 .00394 L
.36699 .00394 L
.36796 .00394 L
.36889 .00394 L
.36988 .00394 L
.37084 .00394 L
.37176 .00394 L
.37273 .00394 L
.37367 .00394 L
.37468 .00394 L
.37564 .00394 L
.37657 .00394 L
.37755 .00394 L
.3785 .00394 L
.37942 .00394 L
.38039 .00394 L
.38133 .00394 L
.38232 .00394 L
.38328 .00394 L
.3842 .00394 L
.38519 .00394 L
.38613 .00394 L
.38704 .00394 L
.38801 .00394 L
.38894 .00394 L
.38993 .00394 L
.39088 .00394 L
.3918 .00394 L
.39277 .00394 L
.39371 .00394 L
.39471 .00394 L
.39567 .00394 L
.3966 .00394 L
.39758 .00394 L
.39853 .00394 L
.39944 .00394 L
.40042 .00394 L
.40135 .00394 L
.40234 .00394 L
Mistroke
.4033 .00394 L
.40422 .00394 L
.4052 .00394 L
.40614 .00394 L
.40705 .00394 L
.40801 .00394 L
.40894 .00394 L
.40993 .00394 L
.41088 .00394 L
.4118 .00394 L
.41277 .00394 L
.41371 .00394 L
.41471 .00394 L
.41567 .00394 L
.41659 .00394 L
.41757 .00394 L
.41852 .00394 L
.41943 .00394 L
.4204 .00394 L
.42133 .00394 L
.42232 .00394 L
.42328 .00394 L
.42419 .00394 L
.42517 .00394 L
.42611 .00394 L
.42711 .00394 L
.42808 .00394 L
.429 .00394 L
.42999 .00394 L
.43094 .00394 L
.43185 .00394 L
.43282 .00394 L
.43376 .00394 L
.43475 .00394 L
.43571 .00394 L
.43663 .00394 L
.43761 .00394 L
.43856 .00394 L
.43947 .00394 L
.44043 .00394 L
.44136 .00394 L
.44235 .00394 L
.4433 .00394 L
.44422 .00394 L
.4452 .00394 L
.44613 .00394 L
.44713 .00394 L
.44809 .00394 L
.44902 .00394 L
.45 .00394 L
Mistroke
.45049 .00394 L
.45095 .00394 L
.45139 .00394 L
.45152 .00394 L
.45164 .00394 L
.45169 .00394 L
.45174 .00394 L
.45177 .00394 L
.45179 .39759 L
.45181 .39759 L
.45186 .39759 L
.4523 .39759 L
.45256 .39759 L
.45268 .39759 L
.45279 .39759 L
.45285 .39759 L
.45291 .39759 L
.45294 .39759 L
.45297 .39759 L
.45299 .00394 L
.45302 .00394 L
.45327 .00394 L
.45378 .00394 L
.45474 .00394 L
.45568 .00394 L
.45667 .00394 L
.45762 .00394 L
.45854 .00394 L
.45952 .00394 L
.46046 .00394 L
.46145 .00394 L
.46242 .00394 L
.46334 .00394 L
.46433 .00394 L
.46528 .00394 L
.46619 .00394 L
.46716 .00394 L
.4681 .00394 L
.46909 .00394 L
.47005 .00394 L
.47097 .00394 L
.47195 .00394 L
.47289 .00394 L
.4738 .00394 L
.4743 .00394 L
.47476 .00394 L
.47522 .00394 L
.47544 .00394 L
.47551 .00394 L
.47554 .00394 L
Mistroke
.47556 .00394 L
.47557 .00394 L
.4756 .20076 L
.47562 .20076 L
.47564 .20076 L
.47569 .20076 L
.47617 .20076 L
.47638 .20076 L
.4766 .20076 L
.47666 .20076 L
.4767 .20076 L
.47673 .20076 L
.47676 .20076 L
.47679 .00394 L
.47682 .00394 L
.47684 .00394 L
.47707 .00394 L
.47757 .00394 L
.47852 .00394 L
.47944 .00394 L
.48041 .00394 L
.48134 .00394 L
.48234 .00394 L
.4833 .00394 L
.48422 .00394 L
.4852 .00394 L
.48615 .00394 L
.48705 .00394 L
.48802 .00394 L
.48895 .00394 L
.48994 .00394 L
.49089 .00394 L
.49181 .00394 L
.49279 .00394 L
.49373 .00394 L
.49473 .00394 L
.49569 .00394 L
.49661 .00394 L
.4976 .00394 L
.49809 .00394 L
.49854 .00394 L
.49898 .00394 L
.49911 .00394 L
.49923 .00394 L
.49934 .00394 L
.49937 .00394 L
.4994 .00394 L
.49943 .20076 L
.49946 .20076 L
.49996 .20076 L
Mistroke
.50018 .20076 L
.5003 .20076 L
.50042 .20076 L
.50048 .20076 L
.50052 .20076 L
.50054 .20076 L
.50057 .20076 L
.5006 .00394 L
.50063 .00394 L
.50066 .00394 L
.50087 .00394 L
.50135 .00394 L
.50232 .00394 L
.50325 .00394 L
.50424 .00394 L
.5052 .00394 L
.50611 .00394 L
.50709 .00394 L
.50803 .00394 L
.50903 .00394 L
.50999 .00394 L
.51092 .00394 L
.51191 .00394 L
.51286 .00394 L
.51377 .00394 L
.51474 .00394 L
.51568 .00394 L
.51667 .00394 L
.51763 .00394 L
.51855 .00394 L
.51953 .00394 L
.52047 .00394 L
.52138 .00394 L
.52188 .00394 L
.52235 .00394 L
.5228 .00394 L
.52303 .00394 L
.52309 .00394 L
.52312 .00394 L
.52316 .00394 L
.52319 .00394 L
.5232 .00394 L
.52322 .20076 L
.52325 .20076 L
.52328 .20076 L
.52375 .20076 L
.52396 .20076 L
.52419 .20076 L
.52425 .20076 L
.52431 .20076 L
Mistroke
.52434 .20076 L
.52437 .20076 L
.5244 .20076 L
.52443 .00394 L
.52446 .00394 L
.52449 .00394 L
.52455 .00394 L
.52466 .00394 L
.52516 .00394 L
.52613 .00394 L
.52707 .00394 L
.52806 .00394 L
.52902 .00394 L
.52994 .00394 L
.53093 .00394 L
.53187 .00394 L
.53278 .00394 L
.53375 .00394 L
.53468 .00394 L
.53567 .00394 L
.53662 .00394 L
.53754 .00394 L
.53852 .00394 L
.53946 .00394 L
.54045 .00394 L
.54142 .00394 L
.54234 .00394 L
.54333 .00394 L
.54428 .00394 L
.54519 .00394 L
.5457 .00394 L
.54616 .00394 L
.54639 .00394 L
.54664 .00394 L
.54675 .00394 L
.54687 .00394 L
.54692 .00394 L
.54698 .00394 L
.54701 .00394 L
.54704 .39759 L
.54706 .39759 L
.54709 .39759 L
.54757 .39759 L
.54778 .39759 L
.54801 .39759 L
.54807 .39759 L
.54813 .39759 L
.54816 .39759 L
.54819 .39759 L
.54822 .00394 L
Mistroke
.54825 .00394 L
.54848 .00394 L
.54898 .00394 L
.54997 .00394 L
.55093 .00394 L
.55185 .00394 L
.55283 .00394 L
.55377 .00394 L
.55477 .00394 L
.55573 .00394 L
.55666 .00394 L
.55764 .00394 L
.55859 .00394 L
.55951 .00394 L
.56048 .00394 L
.56141 .00394 L
.56241 .00394 L
.56337 .00394 L
.56429 .00394 L
.56527 .00394 L
.56621 .00394 L
.56712 .00394 L
.56809 .00394 L
.56902 .00394 L
.57001 .00394 L
.57096 .00394 L
.57188 .00394 L
.57285 .00394 L
.57379 .00394 L
.57479 .00394 L
.57575 .00394 L
.57668 .00394 L
.57766 .00394 L
.57861 .00394 L
.57952 .00394 L
.58049 .00394 L
.58142 .00394 L
.58242 .00394 L
.58337 .00394 L
.58429 .00394 L
.58527 .00394 L
.58621 .00394 L
.58712 .00394 L
.58808 .00394 L
.58901 .00394 L
.59 .00394 L
.59095 .00394 L
.59187 .00394 L
.59284 .00394 L
.59378 .00394 L
Mistroke
.59477 .00394 L
.59573 .00394 L
.59665 .00394 L
.59764 .00394 L
.59858 .00394 L
.59949 .00394 L
.60046 .00394 L
.60139 .00394 L
.60238 .00394 L
.60334 .00394 L
.60425 .00394 L
.60523 .00394 L
.60617 .00394 L
.60717 .00394 L
.60813 .00394 L
.60906 .00394 L
.61005 .00394 L
.61099 .00394 L
.61191 .00394 L
.61288 .00394 L
.61381 .00394 L
.61481 .00394 L
.61576 .00394 L
.61669 .00394 L
.61767 .00394 L
.61861 .00394 L
.61952 .00394 L
.62048 .00394 L
.62141 .00394 L
.6224 .00394 L
.62335 .00394 L
.62427 .00394 L
.62524 .00394 L
.62618 .00394 L
.62718 .00394 L
.62814 .00394 L
.62906 .00394 L
.63005 .00394 L
.63099 .00394 L
.6319 .00394 L
.63287 .00394 L
.63381 .00394 L
.6348 .00394 L
.63575 .00394 L
.63667 .00394 L
.63765 .00394 L
.63859 .00394 L
.63959 .00394 L
.64056 .00394 L
.64148 .00394 L
Mistroke
.64247 .00394 L
.64342 .00394 L
.64434 .00394 L
.64531 .00394 L
.64624 .00394 L
.64724 .00394 L
.6482 .00394 L
.64912 .00394 L
.6501 .00394 L
.65105 .00394 L
.65196 .00394 L
.65292 .00394 L
.65385 .00394 L
.65484 .00394 L
.6558 .00394 L
.65671 .00394 L
.65769 .00394 L
.65863 .00394 L
.65963 .00394 L
.66059 .00394 L
.66152 .00394 L
.6625 .00394 L
.66345 .00394 L
.66436 .00394 L
.66533 .00394 L
.66626 .00394 L
.66726 .00394 L
.66821 .00394 L
.66913 .00394 L
.67011 .00394 L
.67106 .00394 L
.67196 .00394 L
.67293 .00394 L
.67386 .00394 L
.67485 .00394 L
.6758 .00394 L
.67671 .00394 L
.67769 .00394 L
.67862 .00394 L
.67962 .00394 L
.68058 .00394 L
.6815 .00394 L
.68249 .00394 L
.68343 .00394 L
.68434 .00394 L
.68531 .00394 L
.68624 .00394 L
.68723 .00394 L
.68819 .00394 L
.68911 .00394 L
Mistroke
.68958 .00394 L
.68972 .00394 L
.68978 .00394 L
.68981 .00394 L
.68984 .00394 L
.68987 .00394 L
.6899 .39759 L
.68993 .39759 L
.68996 .39759 L
.69008 .39759 L
.69033 .39759 L
.69059 .39759 L
.69072 .39759 L
.69085 .39759 L
.69096 .39759 L
.69099 .39759 L
.69102 .39759 L
.69105 .39759 L
.69108 .00394 L
.69111 .00394 L
.69114 .00394 L
.69119 .00394 L
.69131 .00394 L
.69153 .00394 L
.69203 .00394 L
.69296 .00394 L
.69394 .00394 L
.69489 .00394 L
.6958 .00394 L
.69677 .00394 L
.6977 .00394 L
.69869 .00394 L
.69965 .00394 L
.70057 .00394 L
.70155 .00394 L
.70249 .00394 L
.70349 .00394 L
.70445 .00394 L
.70538 .00394 L
.70637 .00394 L
.70732 .00394 L
.70823 .00394 L
.70921 .00394 L
.71014 .00394 L
.71114 .00394 L
.7121 .00394 L
.71302 .00394 L
.71327 .00394 L
.7135 .00394 L
.71361 .00394 L
Mistroke
.71365 .00394 L
.71368 .00394 L
.71371 .20076 L
.71374 .20076 L
.714 .20076 L
.71448 .20076 L
.71461 .20076 L
.71474 .20076 L
.7148 .20076 L
.71483 .20076 L
.71486 .20076 L
.71489 .00394 L
.7149 .00394 L
.71492 .00394 L
.71498 .00394 L
.71597 .00394 L
.71693 .00394 L
.71785 .00394 L
.71883 .00394 L
.71977 .00394 L
.72068 .00394 L
.72165 .00394 L
.72258 .00394 L
.72357 .00394 L
.72452 .00394 L
.72543 .00394 L
.72641 .00394 L
.72734 .00394 L
.72834 .00394 L
.7293 .00394 L
.73023 .00394 L
.73121 .00394 L
.73216 .00394 L
.73307 .00394 L
.73404 .00394 L
.73497 .00394 L
.73596 .00394 L
.73645 .00394 L
.73691 .00394 L
.73714 .00394 L
.73736 .00394 L
.73742 .00394 L
.73745 .00394 L
.73748 .00394 L
.73749 .00394 L
.73751 .20076 L
.73753 .20076 L
.73755 .20076 L
.73761 .20076 L
.73783 .20076 L
Mistroke
.73829 .20076 L
.73842 .20076 L
.73855 .20076 L
.73861 .20076 L
.73864 .20076 L
.73867 .20076 L
.73868 .20076 L
.7387 .00394 L
.73873 .00394 L
.73879 .00394 L
.73977 .00394 L
.74071 .00394 L
.7417 .00394 L
.74267 .00394 L
.74359 .00394 L
.74458 .00394 L
.74552 .00394 L
.74644 .00394 L
.74741 .00394 L
.74834 .00394 L
.74933 .00394 L
.75029 .00394 L
.75121 .00394 L
.75219 .00394 L
.75313 .00394 L
.75404 .00394 L
.755 .00394 L
.75593 .00394 L
.75692 .00394 L
.75787 .00394 L
.75878 .00394 L
.75976 .00394 L
.76069 .00394 L
.76094 .00394 L
.76107 .00394 L
.76114 .00394 L
.76121 .00394 L
.76126 .00394 L
.76128 .00394 L
.7613 .00394 L
.76133 .20076 L
.76134 .20076 L
.76136 .20076 L
.76139 .20076 L
.76146 .20076 L
.76169 .20076 L
.76194 .20076 L
.76221 .20076 L
.76233 .20076 L
.76239 .20076 L
Mistroke
.76243 .20076 L
.76246 .20076 L
.76249 .20076 L
.76251 .00394 L
.76254 .00394 L
.76257 .00394 L
.76269 .00394 L
.76367 .00394 L
.76461 .00394 L
.76552 .00394 L
.76649 .00394 L
.76742 .00394 L
.76841 .00394 L
.76936 .00394 L
.77027 .00394 L
.77125 .00394 L
.77219 .00394 L
.77319 .00394 L
.77415 .00394 L
.77507 .00394 L
.77605 .00394 L
.777 .00394 L
.77791 .00394 L
.77888 .00394 L
.77981 .00394 L
.78081 .00394 L
.78176 .00394 L
.78268 .00394 L
.78366 .00394 L
.7846 .00394 L
.78485 .00394 L
.78498 .00394 L
.78505 .00394 L
.78509 .00394 L
.78512 .00394 L
.78515 .39759 L
.78518 .39759 L
.78524 .39759 L
.78537 .39759 L
.7856 .39759 L
.78583 .39759 L
.78608 .39759 L
.78618 .39759 L
.78624 .39759 L
.78627 .39759 L
.78629 .39759 L
.78632 .00394 L
.78634 .00394 L
.78635 .00394 L
.78641 .00394 L
Mistroke
.78652 .00394 L
.78752 .00394 L
.78849 .00394 L
.78941 .00394 L
.7904 .00394 L
.79134 .00394 L
.79226 .00394 L
.79323 .00394 L
.79416 .00394 L
.79515 .00394 L
.79611 .00394 L
.79703 .00394 L
.79801 .00394 L
.79895 .00394 L
.79986 .00394 L
.80083 .00394 L
.80176 .00394 L
.80274 .00394 L
.8037 .00394 L
.80461 .00394 L
.80558 .00394 L
.80652 .00394 L
.80752 .00394 L
.80848 .00394 L
.8094 .00394 L
.81039 .00394 L
.81133 .00394 L
.81224 .00394 L
.81321 .00394 L
.81414 .00394 L
.81513 .00394 L
.81609 .00394 L
.81701 .00394 L
.81798 .00394 L
.81893 .00394 L
.81993 .00394 L
.82089 .00394 L
.82182 .00394 L
.8228 .00394 L
.82375 .00394 L
.82466 .00394 L
.82564 .00394 L
.82657 .00394 L
.82757 .00394 L
.82853 .00394 L
.82945 .00394 L
.83043 .00394 L
.83137 .00394 L
.83228 .00394 L
.83325 .00394 L
Mistroke
.83418 .00394 L
.83517 .00394 L
.83612 .00394 L
.83704 .00394 L
.83801 .00394 L
.83895 .00394 L
.83995 .00394 L
.84091 .00394 L
.84183 .00394 L
.84282 .00394 L
.84377 .00394 L
.84468 .00394 L
.84565 .00394 L
.84658 .00394 L
.84757 .00394 L
.84853 .00394 L
.84945 .00394 L
.85043 .00394 L
.85137 .00394 L
.85228 .00394 L
.85324 .00394 L
.85417 .00394 L
.85516 .00394 L
.85611 .00394 L
.85702 .00394 L
.85799 .00394 L
.85893 .00394 L
.85993 .00394 L
.86089 .00394 L
.86181 .00394 L
.86279 .00394 L
.86374 .00394 L
.86465 .00394 L
.86561 .00394 L
.86655 .00394 L
.86754 .00394 L
.86849 .00394 L
.86941 .00394 L
.87038 .00394 L
.87132 .00394 L
.87232 .00394 L
.87329 .00394 L
.87421 .00394 L
.8752 .00394 L
.87615 .00394 L
.87706 .00394 L
.87803 .00394 L
.87897 .00394 L
.87996 .00394 L
.88092 .00394 L
Mistroke
.88184 .00394 L
.88282 .00394 L
.88376 .00394 L
.88467 .00394 L
.88563 .00394 L
.88656 .00394 L
.88755 .00394 L
.8885 .00394 L
.88942 .00394 L
.89039 .00394 L
.89133 .00394 L
.89233 .00394 L
.89329 .00394 L
.89421 .00394 L
.8952 .00394 L
.89614 .00394 L
.89705 .00394 L
.89802 .00394 L
.89896 .00394 L
.89995 .00394 L
.9009 .00394 L
.90182 .00394 L
.9028 .00394 L
.90374 .00394 L
.90474 .00394 L
.90571 .00394 L
.90663 .00394 L
.90762 .00394 L
.90857 .00394 L
.90948 .00394 L
.91046 .00394 L
.91139 .00394 L
.91239 .00394 L
.91335 .00394 L
.91427 .00394 L
.91525 .00394 L
.91619 .00394 L
.9171 .00394 L
.91807 .00394 L
.919 .00394 L
.91999 .00394 L
.92094 .00394 L
.92186 .00394 L
.92284 .00394 L
.92378 .00394 L
.92477 .00394 L
.92574 .00394 L
.92666 .00394 L
.92713 .00394 L
.92738 .00394 L
Mistroke
.92765 .00394 L
.92778 .00394 L
.92784 .00394 L
.9279 .00394 L
.92793 .00394 L
.92796 .00394 L
.92798 .39759 L
.92801 .39759 L
.92814 .39759 L
.92859 .39759 L
.92883 .39759 L
.92896 .39759 L
.92902 .39759 L
.92908 .39759 L
.9291 .39759 L
.92913 .39759 L
.92916 .39759 L
.92918 .00394 L
.92921 .00394 L
.92923 .00394 L
.92929 .00394 L
.92952 .00394 L
.93049 .00394 L
.93142 .00394 L
.93241 .00394 L
.93337 .00394 L
.93429 .00394 L
.93526 .00394 L
.93621 .00394 L
.9372 .00394 L
.93817 .00394 L
.93909 .00394 L
.94008 .00394 L
.94103 .00394 L
.94194 .00394 L
.94291 .00394 L
.94385 .00394 L
.94484 .00394 L
.9458 .00394 L
.94672 .00394 L
.9477 .00394 L
.94865 .00394 L
.94955 .00394 L
.95052 .00394 L
.95097 .00394 L
.95122 .00394 L
.95145 .00394 L
.95157 .00394 L
.95168 .00394 L
.95175 .00394 L
Mistroke
.95176 .00394 L
.95178 .00394 L
.9518 .20076 L
.95181 .20076 L
.95193 .20076 L
.95244 .20076 L
.95268 .20076 L
.9528 .20076 L
.95291 .20076 L
.95294 .20076 L
.95297 .20076 L
.95299 .00394 L
.953 .00394 L
.95303 .00394 L
.95317 .00394 L
.95341 .00394 L
.9544 .00394 L
.95535 .00394 L
.95626 .00394 L
.95723 .00394 L
.95817 .00394 L
.95917 .00394 L
.96013 .00394 L
.96105 .00394 L
.96203 .00394 L
.96298 .00394 L
.96388 .00394 L
.96485 .00394 L
.96578 .00394 L
.96677 .00394 L
.96773 .00394 L
.96864 .00394 L
.96962 .00394 L
.97056 .00394 L
.97156 .00394 L
.97252 .00394 L
.97345 .00394 L
.97443 .00394 L
.97492 .00394 L
.97516 .00394 L
.97538 .00394 L
.97548 .00394 L
.97553 .00394 L
.97556 .00394 L
.97558 .00394 L
.9756 .20076 L
.97563 .20076 L
.97568 .20076 L
.97577 .20076 L
.97619 .20076 L
Mistroke
Mfstroke
0 0 1 r
.005 w
.02381 .00394 m
.02427 .00394 L
.02478 .00394 L
.02525 .00394 L
.02571 .00394 L
.0262 .00394 L
.02667 .00394 L
.02716 .00394 L
.02764 .00394 L
.0281 .00394 L
.02859 .00394 L
.02907 .00394 L
.02952 .00394 L
.03 .00394 L
.03047 .00394 L
.03097 .00394 L
.03144 .00394 L
.0319 .00394 L
.03239 .00394 L
.03286 .00394 L
.03336 .00394 L
.03384 .00394 L
.0343 .00394 L
.03479 .00394 L
.03527 .00394 L
.03572 .00394 L
.03621 .00394 L
.03668 .00394 L
.03717 .00394 L
.03765 .00394 L
.03811 .00394 L
.0386 .00394 L
.03907 .00394 L
.03953 .00394 L
.04001 .00394 L
.04047 .00394 L
.04097 .00394 L
.04144 .00394 L
.0419 .00394 L
.04239 .00394 L
.04286 .00394 L
.04335 .00394 L
.04383 .00394 L
.0443 .00394 L
.04479 .00394 L
.04526 .00394 L
.04572 .00394 L
.0462 .00394 L
.04667 .00394 L
.04716 .00394 L
Mistroke
.04764 .00394 L
.0481 .00394 L
.04859 .00394 L
.04906 .00394 L
.04956 .00394 L
.05004 .00394 L
.0505 .00394 L
.05099 .00394 L
.05147 .00394 L
.05193 .00394 L
.05241 .00394 L
.05288 .00394 L
.05338 .00394 L
.05386 .00394 L
.05432 .00394 L
.05481 .00394 L
.05528 .00394 L
.05573 .00394 L
.05622 .00394 L
.05668 .00394 L
.05718 .00394 L
.05765 .00394 L
.05811 .00394 L
.0586 .00394 L
.05907 .00394 L
.05957 .00394 L
.06005 .00394 L
.06051 .00394 L
.061 .00394 L
.06147 .00394 L
.06193 .00394 L
.06242 .00394 L
.06288 .00394 L
.06338 .00394 L
.06386 .00394 L
.06432 .00394 L
.06481 .00394 L
.06528 .00394 L
.06573 .00394 L
.06621 .00394 L
.06668 .00394 L
.06717 .00394 L
.06764 .00394 L
.0681 .00394 L
.06859 .00394 L
.06906 .00394 L
.06955 .00394 L
.07003 .00394 L
.0705 .00394 L
.07099 .00394 L
Mistroke
.07146 .00394 L
.07191 .00394 L
.0724 .00394 L
.07286 .00394 L
.07336 .00394 L
.07384 .00394 L
.07429 .00394 L
.07478 .00394 L
.07525 .00394 L
.07575 .00394 L
.07623 .00394 L
.0767 .00394 L
.07719 .00394 L
.07766 .00394 L
.07812 .00394 L
.0786 .00394 L
.07907 .00394 L
.07957 .00394 L
.08005 .00394 L
.08051 .00394 L
.081 .00394 L
.08147 .00394 L
.08192 .00394 L
.08241 .00394 L
.08287 .00394 L
.08336 .00394 L
.08384 .00394 L
.0843 .00394 L
.08479 .00394 L
.08525 .00394 L
.08575 .00394 L
.08623 .00394 L
.0867 .00394 L
.08719 .00394 L
.08766 .00394 L
.08812 .00394 L
.0886 .00394 L
.08907 .00394 L
.08956 .00394 L
.09004 .00394 L
.0905 .00394 L
.09099 .00394 L
.09146 .00394 L
.09196 .00394 L
.09244 .00394 L
.0929 .00394 L
.0934 .00394 L
.09387 .00394 L
.09433 .00394 L
.09482 .00394 L
Mistroke
.09528 .00394 L
.09578 .00394 L
.09626 .00394 L
.09672 .00394 L
.09721 .00394 L
.09768 .00394 L
.09814 .00394 L
.09862 .00394 L
.09909 .00394 L
.09958 .00394 L
.10006 .00394 L
.10052 .00394 L
.101 .00394 L
.10147 .00394 L
.10197 .00394 L
.10245 .00394 L
.10292 .00394 L
.10341 .00394 L
.10388 .00394 L
.10434 .00394 L
.10482 .00394 L
.10529 .00394 L
.10579 .00394 L
.10627 .00394 L
.10673 .00394 L
.10722 .00394 L
.10769 .00394 L
.10814 .00394 L
.10862 .00394 L
.10909 .00394 L
.10958 .00394 L
.11006 .00394 L
.11051 .00394 L
.111 .00394 L
.11147 .00394 L
.11197 .00394 L
.11245 .00394 L
.11291 .00394 L
.1134 .00394 L
.11387 .00394 L
.11433 .00394 L
.11481 .00394 L
.11528 .00394 L
.11577 .00394 L
.11625 .00394 L
.11671 .00394 L
.1172 .00394 L
.11767 .00394 L
.11817 .00394 L
.11865 .00394 L
Mistroke
.11911 .00394 L
.1196 .00394 L
.12008 .00394 L
.12054 .00394 L
.12102 .00394 L
.12149 .00394 L
.12199 .00394 L
.12247 .00394 L
.12293 .00394 L
.12342 .00394 L
.12389 .00394 L
.12434 .00394 L
.12482 .00394 L
.12529 .00394 L
.12578 .00394 L
.12626 .00394 L
.12672 .00394 L
.12721 .00394 L
.12768 .00394 L
.12817 .00394 L
.12865 .00394 L
.12912 .00394 L
.12961 .00394 L
.13008 .00394 L
.13054 .00394 L
.13102 .00394 L
.13149 .00394 L
.13198 .00394 L
.13246 .00394 L
.13292 .00394 L
.13341 .00394 L
.13388 .00394 L
.13433 .00394 L
.13482 .00394 L
.13528 .00394 L
.13577 .00394 L
.13625 .00394 L
.13671 .00394 L
.13719 .00394 L
.13766 .00394 L
.13816 .00394 L
.13864 .00394 L
.1391 .00394 L
.13959 .00394 L
.14006 .00394 L
.14052 .00394 L
.141 .00394 L
.14147 .00394 L
.14196 .00394 L
.14244 .00394 L
Mistroke
.1429 .00394 L
.14339 .00394 L
.14386 .00394 L
.14435 .00394 L
.14484 .00394 L
.1453 .00394 L
.14579 .00394 L
.14627 .00394 L
.14672 .00394 L
.14721 .00394 L
.14767 .00394 L
.14817 .00394 L
.14865 .00394 L
.14911 .00394 L
.1496 .00394 L
.15007 .00394 L
.15052 .00394 L
.15101 .00394 L
.15147 .00394 L
.15197 .00394 L
.15244 .00394 L
.1529 .00394 L
.15339 .00394 L
.15385 .00394 L
.15435 .00394 L
.15483 .00394 L
.15529 .00394 L
.15579 .00394 L
.15626 .00394 L
.15671 .00394 L
.1572 .00394 L
.15766 .00394 L
.15816 .00394 L
.15864 .00394 L
.1591 .00394 L
.15959 .00394 L
.16006 .00394 L
.16056 .00394 L
.16104 .00394 L
.1615 .00394 L
.16199 .00394 L
.16247 .00394 L
.16293 .00394 L
.16341 .00394 L
.16388 .00394 L
.16438 .00394 L
.16486 .00394 L
.16532 .00394 L
.16581 .00394 L
.16628 .00394 L
Mistroke
.16673 .00394 L
.16722 .00394 L
.16768 .00394 L
.16818 .00394 L
.16865 .00394 L
.16911 .00394 L
.1696 .00394 L
.17007 .00394 L
.17057 .00394 L
.17105 .00394 L
.17151 .00394 L
.172 .00394 L
.17248 .00394 L
.17293 .00394 L
.17342 .00394 L
.17388 .00394 L
.17438 .00394 L
.17486 .00394 L
.17532 .00394 L
.17581 .00394 L
.17628 .00394 L
.17673 .00394 L
.17721 .00394 L
.17768 .00394 L
.17817 .00394 L
.17865 .00394 L
.1791 .00394 L
.17959 .00394 L
.18006 .00394 L
.18056 .00394 L
.18104 .00394 L
.1815 .00394 L
.18199 .00394 L
.18246 .00394 L
.18292 .00394 L
.1834 .00394 L
.18387 .00394 L
.18436 .00394 L
.18484 .00394 L
.1853 .00394 L
.18579 .00394 L
.18626 .00394 L
.18676 .00394 L
.18724 .00394 L
.1877 .00394 L
.18819 .00394 L
.18867 .00394 L
.18912 .00394 L
.18961 .00394 L
.19008 .00394 L
Mistroke
.19057 .00394 L
.19105 .00394 L
.19151 .00394 L
.192 .00394 L
.19248 .00394 L
.19293 .00394 L
.19341 .00394 L
.19388 .00394 L
.19437 .00394 L
.19485 .00394 L
.19531 .00394 L
.19579 .00394 L
.19626 .00394 L
.19676 .00394 L
.19724 .00394 L
.1977 .00394 L
.19819 .00394 L
.19867 .00394 L
.19912 .00394 L
.19961 .00394 L
.20007 .00394 L
.20057 .00394 L
.20105 .00394 L
.20151 .00394 L
.202 .00394 L
.20247 .00394 L
.20297 .00394 L
.20345 .00394 L
.20391 .00394 L
.20441 .00394 L
.20488 .00394 L
.20534 .00394 L
.20582 .00394 L
.20629 .00394 L
.20679 .00394 L
.20727 .00394 L
.20773 .00394 L
.20822 .00394 L
.20869 .00394 L
.20915 .00394 L
.20963 .00394 L
.2101 .00394 L
.21059 .00394 L
.21107 .00394 L
.21153 .00394 L
.21201 .00394 L
.21248 .00394 L
.21298 .00394 L
.21346 .00394 L
.21393 .00394 L
Mistroke
.21442 .00394 L
.21489 .00394 L
.21535 .00394 L
.21583 .00394 L
.2163 .00394 L
.2168 .00394 L
.21728 .00394 L
.21774 .00394 L
.21823 .00394 L
.2187 .00394 L
.21915 .00394 L
.21963 .00394 L
.2201 .00394 L
.22059 .00394 L
.22107 .00394 L
.22152 .00394 L
.22201 .00394 L
.22248 .00394 L
.22298 .00394 L
.22346 .00394 L
.22392 .00394 L
.22441 .00394 L
.22488 .00394 L
.22534 .00394 L
.22582 .00394 L
.22629 .00394 L
.22679 .00394 L
.22726 .00394 L
.22772 .00394 L
.22821 .00394 L
.22868 .00394 L
.22918 .00394 L
.22966 .00394 L
.23013 .00394 L
.23062 .00394 L
.23109 .00394 L
.23155 .00394 L
.23204 .00394 L
.2325 .00394 L
.233 .00394 L
.23348 .00394 L
.23394 .00394 L
.23443 .00394 L
.2349 .00394 L
.23536 .00394 L
.23584 .00394 L
.2363 .00394 L
.2368 .00394 L
.23727 .00394 L
.23773 .00394 L
Mistroke
.23822 .00394 L
.23869 .00394 L
.23919 .00394 L
.23967 .00394 L
.24013 .00394 L
.24062 .00394 L
.2411 .00394 L
.24155 .00394 L
.24204 .00394 L
.2425 .00394 L
.243 .00394 L
.24348 .00394 L
.24394 .00394 L
.24443 .00394 L
.2449 .00394 L
.24535 .00394 L
.24583 .00394 L
.2463 .00394 L
.24679 .00394 L
.24727 .00394 L
.24772 .00394 L
.24821 .00394 L
.24868 .00394 L
.24918 .00394 L
.24966 .00394 L
.25012 .00394 L
.25061 .00394 L
.25108 .00394 L
.25153 .00394 L
.25202 .00394 L
.25248 .00394 L
.25298 .00394 L
.25346 .00394 L
.25391 .00394 L
.2544 .00394 L
.25487 .00394 L
.25537 .00394 L
.25585 .00394 L
.25632 .00394 L
.25681 .00394 L
.25728 .00394 L
.25774 .00394 L
.25822 .00394 L
.25869 .00394 L
.25919 .00394 L
.25967 .00394 L
.26013 .00394 L
.26062 .00394 L
.26109 .00394 L
.26154 .00394 L
Mistroke
.26203 .00394 L
.26249 .00394 L
.26298 .00394 L
.26346 .00394 L
.26392 .00394 L
.26441 .00394 L
.26487 .00394 L
.26537 .00394 L
.26585 .00394 L
.26631 .00394 L
.26681 .00394 L
.26728 .00394 L
.26773 .00394 L
.26822 .00394 L
.26869 .00394 L
.26918 .00394 L
.26966 .00394 L
.27012 .00394 L
.27061 .00394 L
.27108 .00394 L
.27158 .00394 L
.27206 .00394 L
.27252 .00394 L
.27302 .00394 L
.27349 .00394 L
.27395 .00394 L
.27443 .00394 L
.2749 .00394 L
.2754 .00394 L
.27588 .00394 L
.27634 .00394 L
.27683 .00394 L
.2773 .00394 L
.27776 .00394 L
.27824 .00394 L
.2787 .00394 L
.2792 .00394 L
.27968 .00394 L
.28013 .00394 L
.28062 .00394 L
.28109 .00394 L
.28159 .00394 L
.28207 .00394 L
.28253 .00394 L
.28303 .00394 L
.2835 .00394 L
.28396 .00394 L
.28444 .00394 L
.28491 .00394 L
.2854 .00394 L
Mistroke
.28588 .00394 L
.28634 .00394 L
.28683 .00394 L
.2873 .00394 L
.28776 .00394 L
.28824 .00394 L
.2887 .00394 L
.2892 .00394 L
.28967 .00394 L
.29013 .00394 L
.29062 .00394 L
.29108 .00394 L
.29158 .00394 L
.29206 .00394 L
.29252 .00394 L
.29302 .00394 L
.29349 .00394 L
.29394 .00394 L
.29443 .00394 L
.29489 .00394 L
.29539 .00394 L
.29587 .00394 L
.29632 .00394 L
.29681 .00394 L
.29728 .00394 L
.29778 .00394 L
.29826 .00394 L
.29873 .00394 L
.29922 .00394 L
.29969 .00394 L
.30015 .00394 L
.30064 .00394 L
.3011 .00394 L
.3016 .00394 L
.30208 .00394 L
.30254 .00394 L
.30303 .00394 L
.3035 .00394 L
.30396 .00394 L
.30444 .00394 L
.3049 .00394 L
.3054 .00394 L
.30587 .00394 L
.30633 .00394 L
.30682 .00394 L
.30729 .00394 L
.30779 .00394 L
.30827 .00394 L
.30873 .00394 L
.30922 .00394 L
Mistroke
.3097 .00394 L
.31015 .00394 L
.31064 .00394 L
.3111 .00394 L
.3116 .00394 L
.31208 .00394 L
.31254 .00394 L
.31302 .00394 L
.3135 .00394 L
.31395 .00394 L
.31443 .00394 L
.31489 .00394 L
.31539 .00394 L
.31586 .00394 L
.31632 .00394 L
.31681 .00394 L
.31727 .00394 L
.31777 .00394 L
.31825 .00394 L
.31871 .00394 L
.3192 .00394 L
.31968 .00394 L
.32013 .00394 L
.32061 .00394 L
.32108 .00394 L
.32157 .00394 L
.32205 .00394 L
.32251 .00394 L
.323 .00394 L
.32347 .00394 L
.32397 .00394 L
.32445 .00394 L
.32491 .00394 L
.3254 .00394 L
.32588 .00394 L
.32633 .00394 L
.32682 .00394 L
.32729 .00394 L
.32778 .00394 L
.32826 .00394 L
.32872 .00394 L
.32921 .00394 L
.32968 .00394 L
.33014 .00394 L
.33062 .00394 L
.33108 .00394 L
.33158 .00394 L
.33205 .00394 L
.33251 .00394 L
.333 .00394 L
Mistroke
.33347 .00394 L
.33396 .00394 L
.33444 .00394 L
.33491 .00394 L
.3354 .00394 L
.33587 .00394 L
.33633 .00394 L
.33681 .00394 L
.33728 .00394 L
.33777 .00394 L
.33825 .00394 L
.33871 .00394 L
.3392 .00394 L
.33967 .00394 L
.34017 .00394 L
.34065 .00394 L
.34111 .00394 L
.34161 .00394 L
.34208 .00394 L
.34254 .00394 L
.34302 .00394 L
.34349 .00394 L
.34399 .00394 L
.34447 .00394 L
.34493 .00394 L
.34542 .00394 L
.34589 .00394 L
.34634 .00394 L
.34683 .00394 L
.34729 .00394 L
.34779 .00394 L
.34826 .00394 L
.34872 .00394 L
.34921 .00394 L
.34968 .00394 L
.35018 .00394 L
.35066 .00394 L
.35112 .00394 L
.35161 .00394 L
.35209 .00394 L
.35254 .00394 L
.35303 .00394 L
.35349 .00394 L
.35399 .00394 L
.35447 .00394 L
.35493 .00394 L
.35542 .00394 L
.35589 .00394 L
.35634 .00394 L
.35682 .00394 L
Mistroke
.35729 .00394 L
.35778 .00394 L
.35826 .00394 L
.35871 .00394 L
.3592 .00394 L
.35967 .00394 L
.36017 .00394 L
.36065 .00394 L
.36111 .00394 L
.3616 .00394 L
.36207 .00394 L
.36253 .00394 L
.36301 .00394 L
.36348 .00394 L
.36397 .00394 L
.36445 .00394 L
.36491 .00394 L
.36539 .00394 L
.36586 .00394 L
.36636 .00394 L
.36685 .00394 L
.36731 .00394 L
.3678 .00394 L
.36828 .00394 L
.36873 .00394 L
.36922 .00394 L
.36968 .00394 L
.37018 .00394 L
.37066 .00394 L
.37112 .00394 L
.37161 .00394 L
.37208 .00394 L
.37254 .00394 L
.37302 .00394 L
.37348 .00394 L
.37398 .00394 L
.37445 .00394 L
.37491 .00394 L
.3754 .00394 L
.37587 .00394 L
.37637 .00394 L
.37685 .00394 L
.37731 .00394 L
.3778 .00394 L
.37827 .00394 L
.37873 .00394 L
.37921 .00394 L
.37968 .00394 L
.38018 .00394 L
.38065 .00394 L
Mistroke
.38111 .00394 L
.3816 .00394 L
.38207 .00394 L
.38257 .00394 L
.38305 .00394 L
.38352 .00394 L
.38401 .00394 L
.38449 .00394 L
.38494 .00394 L
.38543 .00394 L
.3859 .00394 L
.38639 .00394 L
.38687 .00394 L
.38734 .00394 L
.38783 .00394 L
.3883 .00394 L
.38875 .00394 L
.38924 .00394 L
.3897 .00394 L
.3902 .00394 L
.39067 .00394 L
.39113 .00394 L
.39162 .00394 L
.39209 .00394 L
.39259 .00394 L
.39307 .00394 L
.39353 .00394 L
.39402 .00394 L
.3945 .00394 L
.39495 .00394 L
.39544 .00394 L
.39591 .00394 L
.3964 .00394 L
.39688 .00394 L
.39734 .00394 L
.39783 .00394 L
.3983 .00394 L
.39875 .00394 L
.39924 .00394 L
.3997 .00394 L
.40019 .00394 L
.40067 .00394 L
.40113 .00394 L
.40161 .00394 L
.40208 .00394 L
.40258 .00394 L
.40306 .00394 L
.40352 .00394 L
.40401 .00394 L
.40449 .00394 L
Mistroke
.40494 .00394 L
.40543 .00394 L
.40589 .00394 L
.40639 .00394 L
.40686 .00394 L
.40732 .00394 L
.40781 .00394 L
.40828 .00394 L
.40878 .00394 L
.40926 .00394 L
.40973 .00394 L
.41022 .00394 L
.41069 .00394 L
.41115 .00394 L
.41164 .00394 L
.4121 .00394 L
.4126 .00394 L
.41308 .00394 L
.41354 .00394 L
.41403 .00394 L
.4145 .00394 L
.41496 .00394 L
.41544 .00394 L
.41591 .00394 L
.4164 .00394 L
.41688 .00394 L
.41733 .00394 L
.41782 .00394 L
.41829 .00394 L
.41879 .00394 L
.41927 .00394 L
.41973 .00394 L
.42022 .00394 L
.4207 .00394 L
.42115 .00394 L
.42164 .00394 L
.4221 .00394 L
.4226 .00394 L
.42308 .00394 L
.42354 .00394 L
.42403 .00394 L
.4245 .00394 L
.42495 .00394 L
.42543 .00394 L
.4259 .00394 L
.42639 .00394 L
.42687 .00394 L
.42732 .00394 L
.42781 .00394 L
.42828 .00394 L
Mistroke
.42878 .00394 L
.42926 .00394 L
.42972 .00394 L
.43021 .00394 L
.43068 .00394 L
.43113 .00394 L
.43162 .00394 L
.43208 .00394 L
.43258 .00394 L
.43306 .00394 L
.43351 .00394 L
.434 .00394 L
.43447 .00394 L
.43497 .00394 L
.43545 .00394 L
.43592 .00394 L
.43641 .00394 L
.43688 .00394 L
.43734 .00394 L
.43782 .00394 L
.43829 .00394 L
.43879 .00394 L
.43927 .00394 L
.43973 .00394 L
.44022 .00394 L
.44069 .00394 L
.44114 .00394 L
.44162 .00394 L
.44209 .00394 L
.44258 .00394 L
.44306 .00394 L
.44352 .00394 L
.444 .00394 L
.44447 .00394 L
.44497 .00394 L
.44545 .00394 L
.44591 .00394 L
.4464 .00394 L
.44688 .00394 L
.44733 .00394 L
.44782 .00394 L
.44828 .00394 L
.44878 .00394 L
.44926 .00394 L
.44972 .00394 L
.4502 .00394 L
.45067 .00394 L
.45117 .00394 L
.45143 .00394 L
.45166 .00394 L
Mistroke
.45177 .00394 L
.45183 .00394 L
.45186 .00394 L
.45188 .00394 L
.4519 .00394 L
.45191 .39759 L
.45192 .39759 L
.45194 .39759 L
.452 .39759 L
.45212 .39759 L
.45257 .39759 L
.45269 .39759 L
.45275 .39759 L
.45281 .39759 L
.45284 .39759 L
.45285 .39759 L
.45285 .39759 L
.45287 .00394 L
.45288 .00394 L
.45289 .00394 L
.4529 .00394 L
.45294 .00394 L
.45306 .00394 L
.45351 .00394 L
.454 .00394 L
.45447 .00394 L
.45496 .00394 L
.45544 .00394 L
.4559 .00394 L
.45639 .00394 L
.45686 .00394 L
.45731 .00394 L
.4578 .00394 L
.45826 .00394 L
.45875 .00394 L
.45923 .00394 L
.45969 .00394 L
.46017 .00394 L
.46064 .00394 L
.46114 .00394 L
.46162 .00394 L
.46208 .00394 L
.46257 .00394 L
.46304 .00394 L
.4635 .00394 L
.46398 .00394 L
.46445 .00394 L
.46494 .00394 L
.46542 .00394 L
.46588 .00394 L
Mistroke
.46637 .00394 L
.46684 .00394 L
.46734 .00394 L
.46782 .00394 L
.46828 .00394 L
.46878 .00394 L
.46925 .00394 L
.46971 .00394 L
.47019 .00394 L
.47066 .00394 L
.47116 .00394 L
.47164 .00394 L
.4721 .00394 L
.47259 .00394 L
.47306 .00394 L
.47351 .00394 L
.47399 .00394 L
.47446 .00394 L
.47495 .00394 L
.4752 .00394 L
.47543 .00394 L
.47554 .00394 L
.47565 .00394 L
.47568 .00394 L
.4757 .00394 L
.47571 .00394 L
.47572 .20076 L
.47573 .20076 L
.47574 .20076 L
.47577 .20076 L
.47589 .20076 L
.47612 .20076 L
.47638 .20076 L
.4765 .20076 L
.47657 .20076 L
.4766 .20076 L
.47663 .20076 L
.47665 .20076 L
.47666 .20076 L
.47667 .00394 L
.47669 .00394 L
.47675 .00394 L
.47686 .00394 L
.47733 .00394 L
.47783 .00394 L
.47831 .00394 L
.47877 .00394 L
.47926 .00394 L
.47973 .00394 L
.48018 .00394 L
Mistroke
.48067 .00394 L
.48113 .00394 L
.48163 .00394 L
.48211 .00394 L
.48256 .00394 L
.48305 .00394 L
.48352 .00394 L
.48402 .00394 L
.4845 .00394 L
.48496 .00394 L
.48546 .00394 L
.48593 .00394 L
.48639 .00394 L
.48687 .00394 L
.48734 .00394 L
.48784 .00394 L
.48831 .00394 L
.48877 .00394 L
.48926 .00394 L
.48974 .00394 L
.49019 .00394 L
.49067 .00394 L
.49114 .00394 L
.49163 .00394 L
.49211 .00394 L
.49256 .00394 L
.49305 .00394 L
.49352 .00394 L
.49402 .00394 L
.4945 .00394 L
.49496 .00394 L
.49545 .00394 L
.49592 .00394 L
.49638 .00394 L
.49686 .00394 L
.49733 .00394 L
.49782 .00394 L
.4983 .00394 L
.49876 .00394 L
.49902 .00394 L
.49925 .00394 L
.49937 .00394 L
.49943 .00394 L
.49946 .00394 L
.49949 .00394 L
.49951 .00394 L
.49952 .00394 L
.49953 .20076 L
.49955 .20076 L
.49961 .20076 L
Mistroke
.49972 .20076 L
.50018 .20076 L
.5003 .20076 L
.50042 .20076 L
.50045 .20076 L
.50046 .20076 L
.50048 .20076 L
.50049 .00394 L
.5005 .00394 L
.50051 .00394 L
.50054 .00394 L
.50067 .00394 L
.50117 .00394 L
.50165 .00394 L
.50211 .00394 L
.5026 .00394 L
.50308 .00394 L
.50353 .00394 L
.50402 .00394 L
.50448 .00394 L
.50498 .00394 L
.50546 .00394 L
.50592 .00394 L
.50641 .00394 L
.50688 .00394 L
.50733 .00394 L
.50781 .00394 L
.50828 .00394 L
.50877 .00394 L
.50925 .00394 L
.5097 .00394 L
.51019 .00394 L
.51066 .00394 L
.51116 .00394 L
.51164 .00394 L
.5121 .00394 L
.51259 .00394 L
.51306 .00394 L
.51352 .00394 L
.514 .00394 L
.51447 .00394 L
.51496 .00394 L
.51544 .00394 L
.5159 .00394 L
.51638 .00394 L
.51685 .00394 L
.51735 .00394 L
.51784 .00394 L
.5183 .00394 L
.51879 .00394 L
Mistroke
.51927 .00394 L
.51972 .00394 L
.52021 .00394 L
.52067 .00394 L
.52117 .00394 L
.52165 .00394 L
.52211 .00394 L
.5226 .00394 L
.52284 .00394 L
.52307 .00394 L
.52318 .00394 L
.52324 .00394 L
.52329 .00394 L
.5233 .00394 L
.52332 .00394 L
.52333 .20076 L
.52335 .20076 L
.52341 .20076 L
.52352 .20076 L
.52399 .20076 L
.52411 .20076 L
.52423 .20076 L
.52426 .20076 L
.52427 .20076 L
.52428 .20076 L
.5243 .00394 L
.52431 .00394 L
.52432 .00394 L
.52435 .00394 L
.52448 .00394 L
.52498 .00394 L
.52546 .00394 L
.52592 .00394 L
.52642 .00394 L
.52689 .00394 L
.52735 .00394 L
.52784 .00394 L
.5283 .00394 L
.5288 .00394 L
.52928 .00394 L
.52974 .00394 L
.53023 .00394 L
.5307 .00394 L
.53116 .00394 L
.53164 .00394 L
.53211 .00394 L
.5326 .00394 L
.53308 .00394 L
.53354 .00394 L
.53402 .00394 L
Mistroke
.53449 .00394 L
.53499 .00394 L
.53547 .00394 L
.53594 .00394 L
.53643 .00394 L
.5369 .00394 L
.53736 .00394 L
.53784 .00394 L
.53831 .00394 L
.53881 .00394 L
.53928 .00394 L
.53974 .00394 L
.54023 .00394 L
.54071 .00394 L
.54116 .00394 L
.54164 .00394 L
.54211 .00394 L
.5426 .00394 L
.54307 .00394 L
.54353 .00394 L
.54402 .00394 L
.54449 .00394 L
.54499 .00394 L
.54547 .00394 L
.54593 .00394 L
.54642 .00394 L
.54666 .00394 L
.54689 .00394 L
.547 .00394 L
.54706 .00394 L
.54711 .00394 L
.54712 .00394 L
.54714 .00394 L
.54715 .39759 L
.54715 .39759 L
.54717 .39759 L
.54723 .39759 L
.54735 .39759 L
.54758 .39759 L
.54784 .39759 L
.54796 .39759 L
.54802 .39759 L
.54805 .39759 L
.54807 .39759 L
.54808 .39759 L
.5481 .00394 L
.54811 .00394 L
.54814 .00394 L
.5482 .00394 L
.54831 .00394 L
Mistroke
.54878 .00394 L
.54927 .00394 L
.54975 .00394 L
.55021 .00394 L
.55069 .00394 L
.55116 .00394 L
.55166 .00394 L
.55214 .00394 L
.5526 .00394 L
.5531 .00394 L
.55357 .00394 L
.55403 .00394 L
.55451 .00394 L
.55498 .00394 L
.55547 .00394 L
.55595 .00394 L
.55641 .00394 L
.5569 .00394 L
.55737 .00394 L
.55782 .00394 L
.5583 .00394 L
.55877 .00394 L
.55926 .00394 L
.55974 .00394 L
.56019 .00394 L
.56068 .00394 L
.56115 .00394 L
.56165 .00394 L
.56213 .00394 L
.56259 .00394 L
.56308 .00394 L
.56355 .00394 L
.564 .00394 L
.56449 .00394 L
.56495 .00394 L
.56545 .00394 L
.56593 .00394 L
.56638 .00394 L
.56687 .00394 L
.56734 .00394 L
.56784 .00394 L
.56832 .00394 L
.56879 .00394 L
.56928 .00394 L
.56975 .00394 L
.57021 .00394 L
.57069 .00394 L
.57116 .00394 L
.57166 .00394 L
.57214 .00394 L
Mistroke
.5726 .00394 L
.57309 .00394 L
.57356 .00394 L
.57401 .00394 L
.57449 .00394 L
.57496 .00394 L
.57545 .00394 L
.57593 .00394 L
.57639 .00394 L
.57687 .00394 L
.57734 .00394 L
.57784 .00394 L
.57832 .00394 L
.57878 .00394 L
.57927 .00394 L
.57975 .00394 L
.5802 .00394 L
.58069 .00394 L
.58115 .00394 L
.58165 .00394 L
.58212 .00394 L
.58258 .00394 L
.58307 .00394 L
.58354 .00394 L
.58404 .00394 L
.58452 .00394 L
.58499 .00394 L
.58548 .00394 L
.58596 .00394 L
.58641 .00394 L
.5869 .00394 L
.58737 .00394 L
.58786 .00394 L
.58834 .00394 L
.5888 .00394 L
.58929 .00394 L
.58977 .00394 L
.59022 .00394 L
.5907 .00394 L
.59117 .00394 L
.59166 .00394 L
.59214 .00394 L
.5926 .00394 L
.59309 .00394 L
.59356 .00394 L
.59405 .00394 L
.59453 .00394 L
.595 .00394 L
.59549 .00394 L
.59596 .00394 L
Mistroke
.59642 .00394 L
.5969 .00394 L
.59737 .00394 L
.59787 .00394 L
.59834 .00394 L
.5988 .00394 L
.59929 .00394 L
.59976 .00394 L
.60022 .00394 L
.6007 .00394 L
.60116 .00394 L
.60166 .00394 L
.60213 .00394 L
.60259 .00394 L
.60308 .00394 L
.60355 .00394 L
.60404 .00394 L
.60452 .00394 L
.60498 .00394 L
.60548 .00394 L
.60595 .00394 L
.6064 .00394 L
.60689 .00394 L
.60735 .00394 L
.60785 .00394 L
.60833 .00394 L
.60878 .00394 L
.60927 .00394 L
.60974 .00394 L
.61024 .00394 L
.61072 .00394 L
.61119 .00394 L
.61168 .00394 L
.61215 .00394 L
.61261 .00394 L
.6131 .00394 L
.61356 .00394 L
.61406 .00394 L
.61454 .00394 L
.615 .00394 L
.61549 .00394 L
.61596 .00394 L
.61641 .00394 L
.6169 .00394 L
.61736 .00394 L
.61786 .00394 L
.61833 .00394 L
.61879 .00394 L
.61928 .00394 L
.61975 .00394 L
Mistroke
.62024 .00394 L
.62073 .00394 L
.62119 .00394 L
.62168 .00394 L
.62215 .00394 L
.62261 .00394 L
.62309 .00394 L
.62356 .00394 L
.62405 .00394 L
.62453 .00394 L
.62499 .00394 L
.62548 .00394 L
.62595 .00394 L
.62645 .00394 L
.62693 .00394 L
.6274 .00394 L
.62789 .00394 L
.62837 .00394 L
.62882 .00394 L
.62931 .00394 L
.62978 .00394 L
.63027 .00394 L
.63075 .00394 L
.63121 .00394 L
.63171 .00394 L
.63218 .00394 L
.63263 .00394 L
.63312 .00394 L
.63358 .00394 L
.63408 .00394 L
.63455 .00394 L
.63501 .00394 L
.6355 .00394 L
.63597 .00394 L
.63647 .00394 L
.63695 .00394 L
.63741 .00394 L
.6379 .00394 L
.63838 .00394 L
.63883 .00394 L
.63932 .00394 L
.63979 .00394 L
.64028 .00394 L
.64076 .00394 L
.64122 .00394 L
.64171 .00394 L
.64218 .00394 L
.64263 .00394 L
.64312 .00394 L
.64358 .00394 L
Mistroke
.64408 .00394 L
.64455 .00394 L
.64501 .00394 L
.6455 .00394 L
.64596 .00394 L
.64646 .00394 L
.64694 .00394 L
.6474 .00394 L
.6479 .00394 L
.64837 .00394 L
.64882 .00394 L
.64931 .00394 L
.64977 .00394 L
.65027 .00394 L
.65075 .00394 L
.65121 .00394 L
.65169 .00394 L
.65216 .00394 L
.65266 .00394 L
.65315 .00394 L
.65361 .00394 L
.6541 .00394 L
.65458 .00394 L
.65503 .00394 L
.65552 .00394 L
.65599 .00394 L
.65648 .00394 L
.65696 .00394 L
.65742 .00394 L
.65791 .00394 L
.65839 .00394 L
.65884 .00394 L
.65932 .00394 L
.65979 .00394 L
.66028 .00394 L
.66076 .00394 L
.66122 .00394 L
.6617 .00394 L
.66217 .00394 L
.66267 .00394 L
.66315 .00394 L
.66361 .00394 L
.66411 .00394 L
.66458 .00394 L
.66504 .00394 L
.66552 .00394 L
.66599 .00394 L
.66648 .00394 L
.66696 .00394 L
.66742 .00394 L
Mistroke
.66791 .00394 L
.66838 .00394 L
.66883 .00394 L
.66932 .00394 L
.66978 .00394 L
.67027 .00394 L
.67075 .00394 L
.67121 .00394 L
.67169 .00394 L
.67216 .00394 L
.67266 .00394 L
.67314 .00394 L
.6736 .00394 L
.67409 .00394 L
.67456 .00394 L
.67502 .00394 L
.6755 .00394 L
.67597 .00394 L
.67646 .00394 L
.67694 .00394 L
.6774 .00394 L
.67789 .00394 L
.67836 .00394 L
.67885 .00394 L
.67934 .00394 L
.6798 .00394 L
.68029 .00394 L
.68077 .00394 L
.68122 .00394 L
.68171 .00394 L
.68217 .00394 L
.68267 .00394 L
.68315 .00394 L
.68361 .00394 L
.6841 .00394 L
.68457 .00394 L
.68502 .00394 L
.68551 .00394 L
.68597 .00394 L
.68647 .00394 L
.68694 .00394 L
.6874 .00394 L
.68789 .00394 L
.68836 .00394 L
.68885 .00394 L
.68933 .00394 L
.6898 .00394 L
.69029 .00394 L
.69076 .00394 L
.69122 .00394 L
Mistroke
.6917 .00394 L
.69217 .00394 L
.69266 .00394 L
.69314 .00394 L
.6936 .00394 L
.69409 .00394 L
.69456 .00394 L
.69506 .00394 L
.69554 .00394 L
.696 .00394 L
.6965 .00394 L
.69697 .00394 L
.69743 .00394 L
.69792 .00394 L
.69838 .00394 L
.69888 .00394 L
.69936 .00394 L
.69982 .00394 L
.70031 .00394 L
.70078 .00394 L
.70124 .00394 L
.70172 .00394 L
.70219 .00394 L
.70268 .00394 L
.70316 .00394 L
.70362 .00394 L
.7041 .00394 L
.70457 .00394 L
.70507 .00394 L
.70555 .00394 L
.70602 .00394 L
.70651 .00394 L
.70698 .00394 L
.70744 .00394 L
.70792 .00394 L
.70839 .00394 L
.70889 .00394 L
.70936 .00394 L
.70982 .00394 L
.71031 .00394 L
.71078 .00394 L
.71124 .00394 L
.71172 .00394 L
.71218 .00394 L
.71268 .00394 L
.71315 .00394 L
.71361 .00394 L
.7141 .00394 L
.71457 .00394 L
.71506 .00394 L
Mistroke
.71554 .00394 L
.716 .00394 L
.7165 .00394 L
.71697 .00394 L
.71742 .00394 L
.71791 .00394 L
.71837 .00394 L
.71887 .00394 L
.71935 .00394 L
.7198 .00394 L
.72029 .00394 L
.72076 .00394 L
.72126 .00394 L
.72174 .00394 L
.72221 .00394 L
.7227 .00394 L
.72318 .00394 L
.72363 .00394 L
.72412 .00394 L
.72458 .00394 L
.72508 .00394 L
.72556 .00394 L
.72602 .00394 L
.72651 .00394 L
.72698 .00394 L
.72744 .00394 L
.72792 .00394 L
.72838 .00394 L
.72888 .00394 L
.72935 .00394 L
.72981 .00394 L
.7303 .00394 L
.73077 .00394 L
.73127 .00394 L
.73175 .00394 L
.73221 .00394 L
.7327 .00394 L
.73318 .00394 L
.73363 .00394 L
.73412 .00394 L
.73458 .00394 L
.73508 .00394 L
.73556 .00394 L
.73602 .00394 L
.7365 .00394 L
.73698 .00394 L
.73743 .00394 L
.73791 .00394 L
.73837 .00394 L
.73887 .00394 L
Mistroke
.73934 .00394 L
.7398 .00394 L
.74029 .00394 L
.74075 .00394 L
.74125 .00394 L
.74173 .00394 L
.74219 .00394 L
.74268 .00394 L
.74316 .00394 L
.74361 .00394 L
.74409 .00394 L
.74456 .00394 L
.74505 .00394 L
.74553 .00394 L
.74599 .00394 L
.74648 .00394 L
.74695 .00394 L
.74745 .00394 L
.74793 .00394 L
.74839 .00394 L
.74888 .00394 L
.74936 .00394 L
.74981 .00394 L
.7503 .00394 L
.75076 .00394 L
.75126 .00394 L
.75174 .00394 L
.7522 .00394 L
.75269 .00394 L
.75316 .00394 L
.75361 .00394 L
.7541 .00394 L
.75456 .00394 L
.75506 .00394 L
.75553 .00394 L
.75599 .00394 L
.75648 .00394 L
.75694 .00394 L
.75744 .00394 L
.75792 .00394 L
.75838 .00394 L
.75888 .00394 L
.75935 .00394 L
.7598 .00394 L
.76029 .00394 L
.76075 .00394 L
.76125 .00394 L
.76173 .00394 L
.76219 .00394 L
.76267 .00394 L
Mistroke
.76315 .00394 L
.76365 .00394 L
.76413 .00394 L
.76459 .00394 L
.76508 .00394 L
.76556 .00394 L
.76601 .00394 L
.7665 .00394 L
.76697 .00394 L
.76747 .00394 L
.76794 .00394 L
.76841 .00394 L
.7689 .00394 L
.76937 .00394 L
.76982 .00394 L
.7703 .00394 L
.77077 .00394 L
.77126 .00394 L
.77174 .00394 L
.7722 .00394 L
.77269 .00394 L
.77316 .00394 L
.77366 .00394 L
.77414 .00394 L
.7746 .00394 L
.77509 .00394 L
.77556 .00394 L
.77602 .00394 L
.7765 .00394 L
.77697 .00394 L
.77747 .00394 L
.77795 .00394 L
.77841 .00394 L
.77889 .00394 L
.77937 .00394 L
.77982 .00394 L
.7803 .00394 L
.78076 .00394 L
.78126 .00394 L
.78173 .00394 L
.78219 .00394 L
.78268 .00394 L
.78315 .00394 L
.78364 .00394 L
.78412 .00394 L
.78458 .00394 L
.78508 .00394 L
.78555 .00394 L
.786 .00394 L
.78649 .00394 L
Mistroke
.78695 .00394 L
.78745 .00394 L
.78792 .00394 L
.78838 .00394 L
.78887 .00394 L
.78934 .00394 L
.78984 .00394 L
.79032 .00394 L
.79079 .00394 L
.79128 .00394 L
.79175 .00394 L
.79221 .00394 L
.79269 .00394 L
.79316 .00394 L
.79366 .00394 L
.79414 .00394 L
.7946 .00394 L
.79509 .00394 L
.79556 .00394 L
.79601 .00394 L
.7965 .00394 L
.79696 .00394 L
.79745 .00394 L
.79793 .00394 L
.79839 .00394 L
.79888 .00394 L
.79934 .00394 L
.79984 .00394 L
.80032 .00394 L
.80079 .00394 L
.80128 .00394 L
.80175 .00394 L
.80221 .00394 L
.80269 .00394 L
.80316 .00394 L
.80365 .00394 L
.80413 .00394 L
.80459 .00394 L
.80508 .00394 L
.80555 .00394 L
.80605 .00394 L
.80653 .00394 L
.80699 .00394 L
.80749 .00394 L
.80796 .00394 L
.80842 .00394 L
.80891 .00394 L
.80937 .00394 L
.80987 .00394 L
.81035 .00394 L
Mistroke
.81081 .00394 L
.8113 .00394 L
.81177 .00394 L
.81223 .00394 L
.81271 .00394 L
.81318 .00394 L
.81367 .00394 L
.81415 .00394 L
.81461 .00394 L
.81509 .00394 L
.81556 .00394 L
.81606 .00394 L
.81654 .00394 L
.81701 .00394 L
.8175 .00394 L
.81797 .00394 L
.81843 .00394 L
.81891 .00394 L
.81938 .00394 L
.81988 .00394 L
.82036 .00394 L
.82082 .00394 L
.82131 .00394 L
.82178 .00394 L
.82223 .00394 L
.82271 .00394 L
.82318 .00394 L
.82367 .00394 L
.82415 .00394 L
.8246 .00394 L
.82509 .00394 L
.82556 .00394 L
.82606 .00394 L
.82654 .00394 L
.827 .00394 L
.82749 .00394 L
.82796 .00394 L
.82842 .00394 L
.8289 .00394 L
.82937 .00394 L
.82986 .00394 L
.83034 .00394 L
.8308 .00394 L
.83129 .00394 L
.83176 .00394 L
.83226 .00394 L
.83274 .00394 L
.8332 .00394 L
.8337 .00394 L
.83417 .00394 L
Mistroke
.83463 .00394 L
.83511 .00394 L
.83558 .00394 L
.83608 .00394 L
.83656 .00394 L
.83702 .00394 L
.83751 .00394 L
.83798 .00394 L
.83843 .00394 L
.83892 .00394 L
.83938 .00394 L
.83987 .00394 L
.84035 .00394 L
.84081 .00394 L
.8413 .00394 L
.84177 .00394 L
.84226 .00394 L
.84275 .00394 L
.84321 .00394 L
.8437 .00394 L
.84417 .00394 L
.84463 .00394 L
.84511 .00394 L
.84558 .00394 L
.84608 .00394 L
.84655 .00394 L
.84701 .00394 L
.8475 .00394 L
.84797 .00394 L
.84843 .00394 L
.84891 .00394 L
.84937 .00394 L
.84987 .00394 L
.85034 .00394 L
.8508 .00394 L
.85128 .00394 L
.85175 .00394 L
.85225 .00394 L
.85273 .00394 L
.85319 .00394 L
.85368 .00394 L
.85415 .00394 L
.85461 .00394 L
.85509 .00394 L
.85556 .00394 L
.85605 .00394 L
.85653 .00394 L
.85699 .00394 L
.85748 .00394 L
.85795 .00394 L
Mistroke
.85845 .00394 L
.85893 .00394 L
.85939 .00394 L
.85988 .00394 L
.86036 .00394 L
.86081 .00394 L
.8613 .00394 L
.86177 .00394 L
.86226 .00394 L
.86274 .00394 L
.8632 .00394 L
.86369 .00394 L
.86416 .00394 L
.86462 .00394 L
.8651 .00394 L
.86556 .00394 L
.86606 .00394 L
.86653 .00394 L
.86699 .00394 L
.86748 .00394 L
.86795 .00394 L
.86844 .00394 L
.86892 .00394 L
.86939 .00394 L
.86988 .00394 L
.87035 .00394 L
.87081 .00394 L
.87129 .00394 L
.87176 .00394 L
.87225 .00394 L
.87273 .00394 L
.87319 .00394 L
.87368 .00394 L
.87415 .00394 L
.87465 .00394 L
.87513 .00394 L
.87559 .00394 L
.87609 .00394 L
.87656 .00394 L
.87702 .00394 L
.8775 .00394 L
.87797 .00394 L
.87847 .00394 L
.87895 .00394 L
.87941 .00394 L
.8799 .00394 L
.88037 .00394 L
.88083 .00394 L
.88131 .00394 L
.88177 .00394 L
Mistroke
.88227 .00394 L
.88275 .00394 L
.8832 .00394 L
.88369 .00394 L
.88416 .00394 L
.88466 .00394 L
.88514 .00394 L
.8856 .00394 L
.8861 .00394 L
.88657 .00394 L
.88702 .00394 L
.88751 .00394 L
.88798 .00394 L
.88847 .00394 L
.88895 .00394 L
.88941 .00394 L
.8899 .00394 L
.89037 .00394 L
.89082 .00394 L
.89131 .00394 L
.89177 .00394 L
.89226 .00394 L
.89274 .00394 L
.8932 .00394 L
.89368 .00394 L
.89415 .00394 L
.89465 .00394 L
.89513 .00394 L
.89559 .00394 L
.89608 .00394 L
.89656 .00394 L
.89701 .00394 L
.89749 .00394 L
.89796 .00394 L
.89846 .00394 L
.89893 .00394 L
.89939 .00394 L
.89988 .00394 L
.90035 .00394 L
.90085 .00394 L
.90133 .00394 L
.90179 .00394 L
.90229 .00394 L
.90276 .00394 L
.90322 .00394 L
.9037 .00394 L
.90417 .00394 L
.90467 .00394 L
.90515 .00394 L
.90561 .00394 L
Mistroke
.9061 .00394 L
.90657 .00394 L
.90702 .00394 L
.9075 .00394 L
.90797 .00394 L
.90846 .00394 L
.90894 .00394 L
.9094 .00394 L
.90989 .00394 L
.91035 .00394 L
.91085 .00394 L
.91133 .00394 L
.9118 .00394 L
.91229 .00394 L
.91276 .00394 L
.91322 .00394 L
.9137 .00394 L
.91417 .00394 L
.91466 .00394 L
.91514 .00394 L
.9156 .00394 L
.91609 .00394 L
.91656 .00394 L
.91706 .00394 L
.91754 .00394 L
.91801 .00394 L
.9185 .00394 L
.91897 .00394 L
.91943 .00394 L
.91992 .00394 L
.92039 .00394 L
.92088 .00394 L
.92136 .00394 L
.92182 .00394 L
.92231 .00394 L
.92279 .00394 L
.92324 .00394 L
.92372 .00394 L
.92419 .00394 L
.92468 .00394 L
.92516 .00394 L
.92562 .00394 L
.92611 .00394 L
.92658 .00394 L
.92708 .00394 L
.92756 .00394 L
.92802 .00394 L
.92851 .00394 L
.92899 .00394 L
.92944 .00394 L
Mistroke
.92993 .00394 L
.93039 .00394 L
.93089 .00394 L
.93137 .00394 L
.93183 .00394 L
.93232 .00394 L
.93279 .00394 L
.93324 .00394 L
.93373 .00394 L
.93419 .00394 L
.93469 .00394 L
.93516 .00394 L
.93562 .00394 L
.93611 .00394 L
.93657 .00394 L
.93707 .00394 L
.93755 .00394 L
.93801 .00394 L
.93851 .00394 L
.93898 .00394 L
.93943 .00394 L
.93992 .00394 L
.94038 .00394 L
.94088 .00394 L
.94136 .00394 L
.94182 .00394 L
.9423 .00394 L
.94277 .00394 L
.94327 .00394 L
.94376 .00394 L
.94422 .00394 L
.94471 .00394 L
.94519 .00394 L
.94564 .00394 L
.94613 .00394 L
.9466 .00394 L
.94709 .00394 L
.94757 .00394 L
.94803 .00394 L
.94852 .00394 L
.949 .00394 L
.94945 .00394 L
.94993 .00394 L
.9504 .00394 L
.95089 .00394 L
.95137 .00394 L
.95183 .00394 L
.95231 .00394 L
.95278 .00394 L
.95328 .00394 L
Mistroke
.95376 .00394 L
.95423 .00394 L
.95472 .00394 L
.95519 .00394 L
.95565 .00394 L
.95613 .00394 L
.9566 .00394 L
.95709 .00394 L
.95757 .00394 L
.95803 .00394 L
.95852 .00394 L
.95899 .00394 L
.95945 .00394 L
.95993 .00394 L
.96039 .00394 L
.96088 .00394 L
.96136 .00394 L
.96182 .00394 L
.9623 .00394 L
.96277 .00394 L
.96327 .00394 L
.96375 .00394 L
.96421 .00394 L
.9647 .00394 L
.96517 .00394 L
.96563 .00394 L
.96611 .00394 L
.96658 .00394 L
.96707 .00394 L
.96755 .00394 L
.96801 .00394 L
.9685 .00394 L
.96897 .00394 L
.96947 .00394 L
.96995 .00394 L
.97041 .00394 L
.9709 .00394 L
.97138 .00394 L
.97183 .00394 L
.97232 .00394 L
.97279 .00394 L
.97328 .00394 L
.97376 .00394 L
.97422 .00394 L
.97471 .00394 L
.97518 .00394 L
.97564 .00394 L
.97612 .00394 L
.97619 .00394 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006?ooool5o`0000?ooooo0_l0000fooooo`?o00001?ooool2o`0003Sooooo0_l0000ioooo
o`?o00001?ooool2o`0003Gooooo1Ol00003ooooo`;o00001?ooool001Wooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000fooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000=_ooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000=Oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000?ooooo000Booooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0002kooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=_oo
ool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000=_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo000Kooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0000iooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00Oooool001Sooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000f
ooooo`04o`000?ooooooooooo`0003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000dooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`006?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000=Oooool2
o`0000Cooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0000hooooo`;o0000
1?ooool01?l0003oooooooooool0000dooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00003ooooo`006Oooool3o`0000Cooooo0_l0000gooooo`03o`000?oooooooooo
00?ooooo0_l0000hooooo`;o0000>_ooool00ol0003oooooooooo`03ooooo`;o0000=_ooool3o`00
00Cooooo0_l00004ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`003_ooool2
o`000?oooooo4Oooool000gooooo00Co0000oooooooooooo00001?ooooooo`0000_o00000Oooool0
00gooooo00Co0000oooooooooooo00001?ooool2o`0000?ooooo00?oo`00o`00ool00?l0o?l00?l4
ooooo`;o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02
ooooog?oo`0000?o003oool00?oo00000ooo00000ol00?ooo`00ool00003ool000;o003o1Ooo0000
0ol00?ooo`00ool00003ool00003o`00oooo003oo`00073oo`001Oooool1o`00007ooooo000=oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool2ool000Cooooo0ooo0004
ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000T
ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool00oooool00ooo003o003oo`00o`04
ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool08oooool2ool000Cooooo0ooo0004
ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool000Cooooo0_oo0005
ooooo`7o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02
ooooo`;oo`001?ooool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004
ooooo`;oo`001?ooool2ool002Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`03
ooooo`03ool00?l00?oo003o00Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0S
ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004
ooooo`;oo`001?ooool2ool000Gooooo0Ol00001ooooo`003_ooool2o`0000Gooooo00?o0000oooo
ooooool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004oooo
o`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00
ooooool00oooool00ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00
ooooool08oooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Soooo
o`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo0_l00003ooooo`;o
o`001?ooool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;o
o`001?ooool2ool002Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03
ool00?l00?oo003o00Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;o
o`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;o
o`001?ooool2ool000Cooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`00
1?ooool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`00
1?ooool2ool002Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03ool0
0?l00?oo003o00Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;oo`00
1?ooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`00
1?ooool2ool000Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?oo
ool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?oo
ool2ool002Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03ool00?l0
0?oo003o00Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;oo`001?oo
ool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?oo
ool2ool000Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3
ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2
ool002Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03ool00?l00?oo
003o00Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;oo`001?ooool3
ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2
ool000Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3ool0
00Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool0
02Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03ool00?l00?oo003o
00Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;oo`001?ooool3ool0
00Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool0
00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3ool000Co
oooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Co
oooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03ool00?l00?oo003o00Co
oooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;oo`001?ooool3ool000Co
oooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool000Go
oooo0Ol00001ooooo`005Oooool2o`0000?ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo
0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o003o
ooooo`03ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o003o
ooooo`03ooooo`03ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo
0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool2o`00007ooooo
000Eooooo`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo
0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o003ooooo
o`03ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o003ooooo
o`03ooooo`03ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo
0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004
ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o003oooooo`03
ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o003oooooo`03
ooooo`03ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004
ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004oooo
o`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o003oooooo`03oooo
o`03ool00?l00?oooooo00?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o003oooooo`03oooo
o`03ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004oooo
o`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004ooooo`;o
o`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o003oooooo`03ooooo`03
ool00?l00?oooooo00?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o003oooooo`03ooooo`03
ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?o
o`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000Eooooo`;o0000
0oooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`00
1?ooool2ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool0
0oooool00ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool0
8oooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`00
1?ooool2ool000Cooooo0_oo0004ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool00_oo
ool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?oo
ool2ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool00ooo
ool00ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool08ooo
ool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?oo
ool2ool000Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_ooool2
ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2
ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool00oooool0
0ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool08oooool2
ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2
ool000Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_ooool2ool0
00Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool0
00Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool00oooool00ooo
003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool08oooool2ool0
00Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool0
00Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_ooool2ool000Co
oooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Co
oooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool00oooool00ooo003o
003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool08oooool2ool000Co
oooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool000Co
oooo0_oo0005ooooo`7o00000Oooool001Gooooo0_l00003ooooo`;oo`001?ooool3ool000Cooooo
0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo
00?oo`00o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03ool00?l00?oo003o00Cooooo
00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;oo`001?ooool3ool000Cooooo
0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3ool000Cooooo0_oo
000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo00?o
o`00o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03ool00?l00?oo003o00Cooooo00?o
o`00o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;oo`001?ooool3ool000Cooooo0_oo
0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool000Gooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3ool000Cooooo0_oo000T
ooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo00?oo`00
o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03ool00?l00?oo003o00Cooooo00?oo`00
o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;oo`001?ooool3ool000Cooooo0_oo0004
ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool000Gooooo0Ol00001
ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooo
ooooool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004oooo
o`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00
ooooool00oooool00ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00
ooooool08oooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Soooo
o`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool00005ooooool0003ooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool2
ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2
ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool00oooool0
0ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool08oooool2
ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2
ool000Cooooo0_oo0005ooooo`7o00000Oooool00005ooooool0003oooooooooool000002oooool0
0ol0003oooooooooo`02ooooo`;o00000oooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2
ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`03ool00?l00?oo
oooo00?ooooo00?oo`00o`00ooooool00oooool00ooo003o003oo`00o`04ooooo`03ool00?l00?oo
oooo00?ooooo00?oo`00o`00ooooool08oooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2
ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`;o00000Oooool0
0005ooooool0003oooooooooool000002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3
ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o003oooooo`03ooooo`03ool00?l00?oo
oooo00?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o003oooooo`03ooooo`03ool00?l00?oo
oooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?oo`008oooool3
ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo00001Ooooooo0000oooooooooooo
000000Oooooo1?l00005ooooo`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2
ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool0
0ooo003o003oooooo`03ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ool00?l01?ooool0
0ooo003o003oooooo`03ooooo`03ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2
ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1
o`00007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`;oo`001?ooool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2
ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Cooooo00?oo`00o`00ooooool00oooool0
0ooo003o003oooooo`03ooooo`03ool00?l00?oo003o00Cooooo00?oo`00o`00ooooool00oooool0
0ooo003o003oooooo`0Sooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3
ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool000Gooooo0Ol00001ooooo`000_ooool2o`00
00Sooooo1Ol00004ooooo`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool0
02Cooooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo
003o003oooooo`03ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ool00?l01?ooool00ooo
003o003oooooo`03ooooo`03ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool0
00Cooooo0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Co
oooo0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o
003oooooo`03ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o
003oooooo`03ooooo`03ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Co
oooo0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007o
oooo000Eooooo`;o00000oooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo
0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo
00?oo`00o`00ooooool00oooool00ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo
00?oo`00o`00ooooool08oooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo
0ooo000Sooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`;o00000Oooool001Gooooo00?o
0000ooooooooool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo
0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?o
o`00o`00ooooool00oooool00ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?o
o`00o`00ooooool08oooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo
000Sooooo`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004
ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00
o`00ooooool00oooool00ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00
o`00ooooool08oooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000S
ooooo`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004oooo
o`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00
ooooool00oooool00ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00
ooooool08oooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Soooo
o`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?o
o`001?ooool2ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00oooo
ool00oooool00ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00oooo
ool08oooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?o
o`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo0_l00003ooooo`;oo`00
1?ooool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`00
1?ooool2ool002Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03ool0
0?l00?oo003o00Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;oo`00
1?ooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`00
1?ooool2ool000Cooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?oo
ool3ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?oo
ool2ool002Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03ool00?l0
0?oo003o00Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;oo`001?oo
ool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?oo
ool2ool000Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3
ool000Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2
ool002Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03ool00?l00?oo
003o00Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;oo`001?ooool3
ool000Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2
ool000Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3ool0
00Cooooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool0
02Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03ool00?l00?oo003o
00Cooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;oo`001?ooool3ool0
00Cooooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool0
00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`02ooooo`;oo`001?ooool3ool000Co
oooo0_oo000Tooooo`;oo`001?ooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool002Co
oooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`03ooooo`03ool00?l00?oo003o00Co
oooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`0Sooooo`;oo`001?ooool3ool000Co
oooo0_oo0004ooooo`;oo`001?ooool3ool002?ooooo0ooo0004ooooo`;oo`001?ooool2ool000Go
oooo0Ol00001ooooo`005Oooool2o`0000?ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo
0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o003o
ooooo`03ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o003o
ooooo`03ooooo`03ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo
0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool2o`00007ooooo
000Eooooo`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo
0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o003ooooo
o`03ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o003ooooo
o`03ooooo`03ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo
0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004
ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o003oooooo`03
ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o003oooooo`03
ooooo`03ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004
ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004oooo
o`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o003oooooo`03oooo
o`03ool00?l00?oooooo00?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o003oooooo`03oooo
o`03ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004oooo
o`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004ooooo`;o
o`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o003oooooo`03ooooo`03
ool00?l00?oooooo00?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o003oooooo`03ooooo`03
ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?o
o`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000Eooooo`;o0000
0oooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`00
1?ooool2ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool0
0oooool00ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool0
8oooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`00
1?ooool2ool000Cooooo0_oo0004ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool00_oo
ool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?oo
ool2ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool00ooo
ool00ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool08ooo
ool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?oo
ool2ool000Cooooo0_oo0005ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool00_ooool2
ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2
ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool00oooool0
0ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool08oooool2
ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2
ool000Cooooo0_oo0005ooooo`7o00000Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo
00;ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo0_oo0004ooooo`;oo`001?ooool3ool0
00Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o003oooooo`03ooooo`03ool00?l00?oooooo
00?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o003oooooo`03ooooo`03ool00?l00?oooooo
02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo0004ooooo`?oo`008oooool3ool0
00Cooooo0_oo0004ooooo`;oo`001Oooool1o`00007ooooo000>ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool2ool000Cooooo0ooo0004ooooo`;oo`009?ooool2ool000Co
oooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo000Tooooo`03ool00?l00?oooooo00?o
oooo00?oo`00o`00ooooool00oooool00ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?o
oooo00?oo`00o`00ooooool08oooool2ool000Cooooo0ooo0004ooooo`;oo`001?ooool2ool000Co
oooo0ooo000Sooooo`?oo`001?ooool2ool000Cooooo0_oo0005ooooo`7o00000Oooool000kooooo
00?o0000ooooooooool01?ooool2o`0000?ooooo0_oo0004ooooo`?oo`001?ooool2ool002Cooooo
0_oo0004ooooo`;oo`001?ooool3ool000Cooooo0_oo0004ooooo`;oo`009?ooool00ooo003o003o
ooooo`03ooooo`03ool00?l00?ooo`0000?ooooo00?oo`00o`00ool00?l01?ooool00ooo003o003o
ooooo`03ooooo`03ool00?l00?oooooo02?ooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo
0_oo0004ooooo`?oo`008oooool3ool000Cooooo0_oo0004ooooo`;oo`001?ooool2o`00007ooooo
000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2ool000Cooooo0ooo
0004ooooo`;oo`009?ooool2ool000Cooooo0_oo0004ooooo`?oo`001?ooool2ool000Cooooo0_oo
000Tooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00oooo00000oooool00ooo003o003oo`00
o`04ooooo`03ool00?l00?oooooo00?ooooo00?oo`00o`00ooooool08oooool2ool000Cooooo0ooo
0004ooooo`;oo`001?ooool2ool000Cooooo0ooo000Sooooo`?oo`001?ooool2ool000Cooooo0_oo
0005ooooo`7o00000Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?
ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`03ool00?l00?oooooo00_ooooo00?o0000
ooooooooool02?ooool00ooo003o003oooooo`0Sooooo`;oo`005oooool3ool002?ooooo0ooo000A
ooooo`7o00000Oooool000gooooo0_l00006ooooo`03o`000?oooooooooo00oooooo0_oo000Toooo
o`;oo`005oooool2ool002Cooooo00?oo`00o`00ooooool02oooool00ol0003oooooooooo`08oooo
o`03ool00?l00?oooooo02?ooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001oooo
o`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo0_oo000Tooooo`;o
o`005oooool2ool002Cooooo00?oo`00o`00ooooool02oooool00ol0003oooooooooo`08ooooo`03
ool00?l00?oooooo02?ooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`03ool0
0?l00?oooooo00_ooooo00?o0000ooooooooool02?ooool00ooo003o003oooooo`0Sooooo`;oo`00
5oooool3ool002?ooooo0ooo000Aooooo`7o00000Oooool001Gooooo0_l0000@ooooo`;oo`009?oo
ool2ool001Oooooo0_oo000Tooooo`03ool00?l00?oooooo00_ooooo00?o0000ooooooooool02?oo
ool00ooo003o003oooooo`0Sooooo`;oo`005oooool3ool002?ooooo0ooo000@ooooo`;o00000Ooo
ool001Gooooo00?o0000ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool0
0ooo003o003oooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?oo`00o`00ooooool08oooool2
ool001Oooooo0ooo000Sooooo`?oo`004Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo00?oo`00o`00ooooool02oooool00ol0
003oooooooooo`08ooooo`03ool00?l00?oooooo02?ooooo0_oo000Gooooo`?oo`008oooool3ool0
017ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0?ooooo`;oo`009?ooool2ool001Oo
oooo0_oo000Tooooo`03ool00?l00?oooooo00_ooooo00?o0000ooooooooool02?ooool00ooo003o
003oooooo`0Sooooo`;oo`005oooool3ool002?ooooo0ooo000Aooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool00ooo003o003o
ooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?oo`00o`00ooooool08oooool2ool001Oooooo
0ooo000Sooooo`?oo`004Oooool1o`00007ooooo000Eooooo`;o00004?ooool2ool002Cooooo0_oo
000Gooooo`;oo`009?ooool00ooo003o003oooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o
o`00o`00ooooool08oooool2ool001Oooooo0ooo000Sooooo`?oo`004?ooool2o`00007ooooo000E
ooooo`03o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo00?oo`00
o`00ooooool02oooool00ol0003oooooooooo`08ooooo`03ool00?l00?oooooo02?ooooo0_oo000G
ooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0?oooo
o`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`03ool00?l00?oooooo00_ooooo00?o0000oooo
ooooool02?ooool00ooo003o003oooooo`0Sooooo`;oo`005oooool3ool002?ooooo0ooo000Aoooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;o
o`009?ooool00ooo003o003oooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?oo`00o`00oooo
ool08oooool2ool001Oooooo0ooo000Sooooo`?oo`004Oooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo00?oo`00o`00ooooool0
2oooool00ol0003oooooooooo`08ooooo`03ool00?l00?oooooo02?ooooo0_oo000Gooooo`?oo`00
8oooool3ool0017ooooo0Ol00001ooooo`005Oooool2o`00013ooooo0_oo000Tooooo`;oo`005ooo
ool2ool002Cooooo00?oo`00o`00ooooool02oooool00ol0003oooooooooo`08ooooo`03ool00?l0
0?oooooo02?ooooo0_oo000Gooooo`?oo`008oooool3ool0013ooooo0_l00001ooooo`005Oooool0
0ol0003oooooooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`03ool00?l00?oo
oooo00_ooooo00?o0000ooooooooool02?ooool00ooo003o003oooooo`0Sooooo`;oo`005oooool3
ool002?ooooo0ooo000Aooooo`7o00000Oooool001Gooooo00?o0000ooooooooool03oooool2ool0
02Cooooo0_oo000Gooooo`;oo`009?ooool00ooo003o003oooooo`0;ooooo`03o`000?oooooooooo
00Sooooo00?oo`00o`00ooooool08oooool2ool001Oooooo0ooo000Sooooo`?oo`004Oooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Co
oooo00?oo`00o`00ooooool02oooool00ol0003oooooooooo`08ooooo`03ool00?l00?oooooo02?o
oooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`03ool00?l00?oooooo00_ooooo
00?o0000ooooooooool02?ooool00ooo003o003oooooo`0Sooooo`;oo`005oooool3ool002?ooooo
0ooo000Aooooo`7o00000Oooool001Gooooo0_l0000@ooooo`;oo`009?ooool2ool001Oooooo0_oo
000Tooooo`03ool00?l00?oooooo00_ooooo00?o0000ooooooooool02?ooool00ooo003o003ooooo
o`0Sooooo`;oo`005oooool3ool002?ooooo0ooo000@ooooo`;o00000Oooool001Gooooo00?o0000
ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool00ooo003o003oooooo`0;
ooooo`03o`000?oooooooooo00Sooooo00?oo`00o`00ooooool08oooool2ool001Oooooo0ooo000S
ooooo`?oo`004Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00oooooo0_oo000Toooo
o`;oo`005oooool2ool002Cooooo00?oo`00o`00ooooool02oooool00ol0003oooooooooo`08oooo
o`03ool00?l00?oooooo02?ooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001oooo
o`0000Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0
003oooooooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`03ool00?l00?oooooo
00_ooooo00?o0000ooooooooool02?ooool00ooo003o003oooooo`0Sooooo`;oo`005oooool3ool0
02?ooooo0ooo000Aooooo`7o00000Oooool000;ooooo00?o0000ooooooooool01oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool03oooool2ool002Cooooo0_oo000Goooo
o`;oo`009?ooool00ooo003o003oooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?oo`00o`00
ooooool08oooool2ool001Oooooo0ooo000Sooooo`?oo`004Oooool1o`00007ooooo0002ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`;o
o`009?ooool2ool001Oooooo0_oo000Tooooo`03ool00?l00?oooooo00_ooooo00?o0000oooooooo
ool02?ooool00ooo003o003oooooo`0Sooooo`;oo`005oooool3ool002?ooooo0ooo000Aooooo`7o
00000Oooool000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`;o0000
4?ooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool00ooo003o003oooooo`0;ooooo`03o`00
0?oooooooooo00Sooooo00?oo`00o`00ooooool08oooool2ool001Oooooo0ooo000Sooooo`?oo`00
4?ooool2o`00007ooooo0002ooooo`03o`000?oooooooooo00Oooooo1?l00005ooooo`03o`000?oo
oooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo00?oo`00o`00ooooool02ooo
ool00ol0003oooooooooo`08ooooo`03ool00?l00?oooooo02?ooooo0_oo000Gooooo`?oo`008ooo
ool3ool0017ooooo0Ol00001ooooo`0000?oooooo`000?l000002Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo00?oo`00
o`00ooooool02oooool00ol0003oooooooooo`08ooooo`03ool00?l00?oooooo02?ooooo0_oo000G
ooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`000_ooool00ol0003oooooooooo`07oooo
o`Go00001?ooool00ol0003oooooooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000Toooo
o`03ool00?l00?oooooo00_ooooo00?o0000ooooooooool02?ooool00ooo003o003oooooo`0Soooo
o`;oo`005oooool3ool002?ooooo0ooo000Aooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool03oooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool00ooo003o003oooooo`0;ooooo`03
o`000?oooooooooo00Sooooo00?oo`00o`00ooooool08oooool2ool001Oooooo0ooo000Sooooo`?o
o`004Oooool1o`00007ooooo000Eooooo`;o00004?ooool2ool002Cooooo0_oo000Gooooo`;oo`00
9?ooool00ooo003o003oooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?oo`00o`00ooooool0
8oooool2ool001Oooooo0ooo000Sooooo`?oo`004?ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo00?oo`00o`00ooooool02ooo
ool00ol0003oooooooooo`08ooooo`03ool00?l00?oooooo02?ooooo0_oo000Gooooo`?oo`008ooo
ool3ool0017ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0?ooooo`;oo`009?ooool2
ool001Oooooo0_oo000Tooooo`03ool00?l00?oooooo00_ooooo00?o0000ooooooooool02?ooool0
0ooo003o003oooooo`0Sooooo`;oo`005oooool3ool002?ooooo0ooo000Aooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool03oooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool00ooo
003o003oooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?oo`00o`00ooooool08oooool2ool0
01Oooooo0ooo000Sooooo`?oo`004Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00oo
oooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo00?oo`00o`00ooooool02oooool00ol0003o
ooooooooo`08ooooo`03ool00?l00?oooooo02?ooooo0_oo000Gooooo`?oo`008oooool3ool0017o
oooo0Ol00001ooooo`005Oooool2o`00013ooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo
00?oo`00o`00ooooool02oooool00ol0003oooooooooo`08ooooo`03ool00?l00?oooooo02?ooooo
0_oo000Gooooo`?oo`008oooool3ool0013ooooo0_l00001ooooo`005Oooool00ol0003ooooooooo
o`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`03ool00?l00?oooooo00_ooooo00?o
0000ooooooooool02?ooool00ooo003o003oooooo`0Sooooo`;oo`005oooool3ool002?ooooo0ooo
000Aooooo`7o00000Oooool001Gooooo00?o0000ooooooooool03oooool2ool002Cooooo0_oo000G
ooooo`;oo`009?ooool00ooo003o003oooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?oo`00
o`00ooooool08oooool2ool001Oooooo0ooo000Sooooo`?oo`004Oooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo00?oo`00o`00
ooooool02oooool00ol0003oooooooooo`08ooooo`03ool00?l00?oooooo02?ooooo0_oo000Goooo
o`?oo`008oooool3ool0017ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0?ooooo`;o
o`009?ooool2ool001Oooooo0_oo000Tooooo`03ool00?l00?oooooo00_ooooo00?o0000oooooooo
ool02?ooool00ooo003o003oooooo`0Sooooo`;oo`005oooool3ool002?ooooo0ooo000Aooooo`7o
00000Oooool001Gooooo0_l0000@ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`03ool0
0?l00?oooooo00_ooooo00?o0000ooooooooool02?ooool00ooo003o003oooooo`0Sooooo`;oo`00
5oooool3ool002?ooooo0ooo000@ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool03ooo
ool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool00ooo003o003oooooo`0;ooooo`03o`000?oo
oooooooo00Sooooo00?oo`00o`00ooooool08oooool2ool001Oooooo0ooo000Sooooo`?oo`004Ooo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2
ool002Cooooo00?oo`00o`00ooooool02oooool00ol0003oooooooooo`08ooooo`03ool00?l00?oo
oooo02?ooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`03ool00?l00?oooooo
00_ooooo00?o0000ooooooooool02?ooool00ooo003o003oooooo`0Sooooo`;oo`005oooool3ool0
02?ooooo0ooo000Aooooo`7o00000Oooool001Gooooo00?o0000ooooooooool03oooool2ool002Co
oooo0_oo000Gooooo`;oo`009?ooool00ooo003o003oooooo`0;ooooo`03o`000?oooooooooo00So
oooo00?oo`00o`00ooooool08oooool2ool001Oooooo0ooo000Sooooo`?oo`004Oooool1o`00007o
oooo000Eooooo`;o00004?ooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool00ooo003o003o
ooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?oo`00o`00ooooool08oooool2ool001Oooooo
0ooo000Sooooo`?oo`004?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00oooooo0_oo
000Tooooo`;oo`005oooool2ool002Cooooo00?oo`00o`00ooooool02oooool00ol0003ooooooooo
o`08ooooo`03ool00?l00?oooooo02?ooooo0_oo000Gooooo`?oo`008oooool3ool0017ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000T
ooooo`03ool00?l00?oooooo00_ooooo00?o0000ooooooooool02?ooool00ooo003o003oooooo`0S
ooooo`;oo`005oooool3ool002?ooooo0ooo000Aooooo`7o00000Oooool000cooooo1Ol00004oooo
o`03o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo00?oo`00o`00
ooooool02oooool00ol0003oooooooooo`08ooooo`03ool00?l00?oooooo02?ooooo0_oo000Goooo
o`?oo`008oooool3ool0017ooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo00?oo`00o`00
ooooool02oooool00ol0003oooooooooo`08ooooo`03ool00?l00?oooooo02?ooooo0_oo000Goooo
o`?oo`008oooool3ool0017ooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00oooooo0_oo000Tooooo`;oo`005oooool2ool002Cooooo00?oo`00o`00oooo
ool02oooool00ol0003oooooooooo`08ooooo`03ool00?l00?oooooo02?ooooo0_oo000Gooooo`?o
o`008oooool3ool0017ooooo0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooo`;o0000
4?ooool2ool002Cooooo0_oo000Gooooo`;oo`009?ooool00ooo003o003oooooo`0;ooooo`03o`00
0?oooooooooo00Sooooo00?oo`00o`00oooo00008oooool3ool001Kooooo0ooo000Sooooo`?oo`00
4?ooool2o`00007ooooo000<ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`0?ooooo`;oo`009?ooool2ool001Oooooo0_oo000Tooooo`;oo`003?ooool00ol0003ooooo
ooooo`08ooooo`?oo`008oooool3ool001Kooooo0ooo000Sooooo`?oo`004Oooool1o`00007ooooo
000<ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo087ooooo0Ol00001ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo
083ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087o
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`005Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0
003oooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`00
5Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`001Ol0
0003ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0POooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
POooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`000oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo0_l00023ooooo`03o`000?oooooo
oooo083ooooo0_l00001ooooo`0000Go0000ooooooooooooooooo`000007ooooo`Co00001Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`0000Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`21ooooo`7o00000Oooool00004ooooool0003o0000o`0000Sooooo1Ol00004
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o
0000Poooool00ol0003oooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083o
oooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`00
5Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003ooooo
ooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`21ooooo`7o00000Oooool000gooooo0ol00005ooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0POooool1o`00007ooooo000<ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`004?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00
007ooooo000>ooooo`;o00001Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007o
oooo000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`21ooooo`7o00000Oooool000cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000=ooooo`?o00001Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`00
00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00;ooooo0_l00001ooooo`005Oooooooo`0000_o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-24.3721, -0.260466, \
0.158161, 0.0191323}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DTFT of finite-length sampled signal", "Subsection"],

Cell[BoxData[
    \(\(X\[Theta]\  = DTFT[xd, \[Theta]]\  // \ Simplify;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gX\[Theta] = 
        Plot[Abs[
            X\[Theta]\  /. \ \[Theta] \[Rule] \ 2  \[Pi]\ f/fs], {f, \(-2\) 
              fs, 2  fs}, \ PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ AspectRatio \[Rule] 1/3, \ 
          ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
%%ImageSize: 504 168 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.00793138 0.00315879 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00793 -6 -4.5 ]
[-0.0125 .00793 0 4.5 ]
[-0.0125 .07111 -12 -4.5 ]
[-0.0125 .07111 0 4.5 ]
[-0.0125 .13428 -12 -4.5 ]
[-0.0125 .13428 0 4.5 ]
[-0.0125 .19746 -12 -4.5 ]
[-0.0125 .19746 0 4.5 ]
[-0.0125 .26063 -12 -4.5 ]
[-0.0125 .26063 0 4.5 ]
[-0.0125 .32381 -18 -4.5 ]
[-0.0125 .32381 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .33333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00793 m
.00625 .00793 L
s
[(0)] -0.0125 .00793 1 0 Mshowa
0 .07111 m
.00625 .07111 L
s
[(20)] -0.0125 .07111 1 0 Mshowa
0 .13428 m
.00625 .13428 L
s
[(40)] -0.0125 .13428 1 0 Mshowa
0 .19746 m
.00625 .19746 L
s
[(60)] -0.0125 .19746 1 0 Mshowa
0 .26063 m
.00625 .26063 L
s
[(80)] -0.0125 .26063 1 0 Mshowa
0 .32381 m
.00625 .32381 L
s
[(100)] -0.0125 .32381 1 0 Mshowa
.125 Mabswid
0 .02373 m
.00375 .02373 L
s
0 .03952 m
.00375 .03952 L
s
0 .05531 m
.00375 .05531 L
s
0 .0869 m
.00375 .0869 L
s
0 .1027 m
.00375 .1027 L
s
0 .11849 m
.00375 .11849 L
s
0 .15008 m
.00375 .15008 L
s
0 .16587 m
.00375 .16587 L
s
0 .18166 m
.00375 .18166 L
s
0 .21325 m
.00375 .21325 L
s
0 .22905 m
.00375 .22905 L
s
0 .24484 m
.00375 .24484 L
s
0 .27643 m
.00375 .27643 L
s
0 .29222 m
.00375 .29222 L
s
0 .30802 m
.00375 .30802 L
s
.25 Mabswid
0 0 m
0 .33333 L
s
.02381 .32708 m
.02381 .33333 L
s
.2619 .32708 m
.2619 .33333 L
s
.5 .32708 m
.5 .33333 L
s
.7381 .32708 m
.7381 .33333 L
s
.97619 .32708 m
.97619 .33333 L
s
.125 Mabswid
.07143 .32958 m
.07143 .33333 L
s
.11905 .32958 m
.11905 .33333 L
s
.16667 .32958 m
.16667 .33333 L
s
.21429 .32958 m
.21429 .33333 L
s
.30952 .32958 m
.30952 .33333 L
s
.35714 .32958 m
.35714 .33333 L
s
.40476 .32958 m
.40476 .33333 L
s
.45238 .32958 m
.45238 .33333 L
s
.54762 .32958 m
.54762 .33333 L
s
.59524 .32958 m
.59524 .33333 L
s
.64286 .32958 m
.64286 .33333 L
s
.69048 .32958 m
.69048 .33333 L
s
.78571 .32958 m
.78571 .33333 L
s
.83333 .32958 m
.83333 .33333 L
s
.88095 .32958 m
.88095 .33333 L
s
.92857 .32958 m
.92857 .33333 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.99375 .00793 m
1 .00793 L
s
.99375 .07111 m
1 .07111 L
s
.99375 .13428 m
1 .13428 L
s
.99375 .19746 m
1 .19746 L
s
.99375 .26063 m
1 .26063 L
s
.99375 .32381 m
1 .32381 L
s
.125 Mabswid
.99625 .02373 m
1 .02373 L
s
.99625 .03952 m
1 .03952 L
s
.99625 .05531 m
1 .05531 L
s
.99625 .0869 m
1 .0869 L
s
.99625 .1027 m
1 .1027 L
s
.99625 .11849 m
1 .11849 L
s
.99625 .15008 m
1 .15008 L
s
.99625 .16587 m
1 .16587 L
s
.99625 .18166 m
1 .18166 L
s
.99625 .21325 m
1 .21325 L
s
.99625 .22905 m
1 .22905 L
s
.99625 .24484 m
1 .24484 L
s
.99625 .27643 m
1 .27643 L
s
.99625 .29222 m
1 .29222 L
s
.99625 .30802 m
1 .30802 L
s
.25 Mabswid
1 0 m
1 .33333 L
s
.5 0 m
.5 .33333 L
s
1 0 0 r
.5 Mabswid
.02381 .16587 m
.02395 .16564 L
.02408 .16502 L
.02423 .16382 L
.02437 .16223 L
.02462 .1583 L
.02489 .15254 L
.02551 .13429 L
.02608 .11242 L
.02731 .05756 L
.02792 .03181 L
.02818 .02155 L
.02832 .01646 L
.02847 .0113 L
.02862 .00946 L
.02876 .01372 L
.02903 .02126 L
.02933 .02794 L
.02964 .03357 L
.02982 .03605 L
.02999 .03786 L
.03015 .03916 L
.03023 .03966 L
.03032 .0401 L
.03047 .04057 L
.03056 .04068 L
.03064 .04069 L
.03079 .04046 L
.03094 .03996 L
.03109 .03917 L
.03125 .03798 L
.03159 .03473 L
.03219 .02664 L
.03285 .01589 L
.03301 .01319 L
.03319 .01034 L
.03328 .00872 L
.03337 .0086 L
.03347 .01003 L
.03355 .01136 L
.03413 .0196 L
.03444 .02315 L
.03477 .02618 L
.03504 .02809 L
.0352 .0289 L
.03535 .02946 L
.03548 .02981 L
.03561 .02999 L
.03575 .03004 L
.03588 .02991 L
Mistroke
.03604 .02956 L
.03619 .02905 L
.03635 .02825 L
.03651 .02728 L
.03679 .02506 L
.03709 .02202 L
.03742 .01794 L
.03777 .01297 L
.03792 .01077 L
.03807 .00832 L
.03816 .00897 L
.03824 .01029 L
.0384 .01291 L
.03952 .03059 L
.03979 .03405 L
.04008 .0371 L
.04025 .03847 L
.0404 .03945 L
.04055 .04013 L
.04071 .04054 L
.04086 .04063 L
.04095 .04053 L
.04103 .04034 L
.04118 .0397 L
.04133 .03876 L
.0415 .03723 L
.04165 .03541 L
.04201 .02979 L
.04229 .02389 L
.04259 .01596 L
.04275 .0114 L
.04283 .00869 L
.04291 .00974 L
.04307 .01497 L
.04321 .02021 L
.04541 .11507 L
.04601 .13767 L
.04632 .14738 L
.04666 .1556 L
.04695 .16094 L
.04711 .16313 L
.04727 .1646 L
.04741 .16546 L
.04754 .16584 L
.04769 .16578 L
.04783 .16524 L
.04797 .16426 L
.04812 .16269 L
.04828 .16049 L
.04842 .15793 L
Mistroke
.04897 .14451 L
.04957 .12395 L
.05021 .09715 L
.05085 .06859 L
.05153 .03914 L
.05185 .02611 L
.05202 .02015 L
.05216 .01495 L
.0523 .01048 L
.05244 .00983 L
.05259 .014 L
.05274 .0182 L
.05305 .02521 L
.05338 .03105 L
.05353 .03326 L
.05368 .03498 L
.05382 .03621 L
.05396 .03726 L
.05405 .0377 L
.05412 .03802 L
.05421 .03827 L
.0543 .03843 L
.05437 .03849 L
.05446 .03845 L
.0546 .03819 L
.05468 .03792 L
.05477 .03754 L
.05493 .03664 L
.05512 .03524 L
.0553 .03368 L
.05591 .02639 L
.05656 .0169 L
.05682 .0128 L
.05697 .01055 L
.05711 .00843 L
.05719 .00862 L
.05727 .00989 L
.05742 .01208 L
.05772 .01617 L
.0583 .02324 L
.05862 .02634 L
.05892 .02866 L
.05906 .0295 L
.0592 .03023 L
.05936 .03083 L
.0595 .0312 L
.05964 .03138 L
.05976 .0314 L
.05989 .03126 L
.06003 .03092 L
Mistroke
.06012 .03064 L
.0602 .03026 L
.06036 .0294 L
.06052 .02821 L
.06071 .02655 L
.06104 .02274 L
.06135 .0182 L
.06164 .01306 L
.06179 .01027 L
.06192 .00831 L
.06208 .01157 L
.06225 .01526 L
.06254 .02199 L
.06315 .03601 L
.06348 .04283 L
.06382 .04908 L
.06411 .0534 L
.06428 .05524 L
.06444 .0565 L
.06459 .05722 L
.06472 .0575 L
.06487 .05733 L
.06502 .05666 L
.06515 .05561 L
.06527 .05424 L
.06539 .0524 L
.06553 .04988 L
.06582 .04284 L
.06608 .03423 L
.06638 .02224 L
.06654 .01458 L
.06669 .00921 L
.06683 .01725 L
.06699 .0266 L
.06726 .04441 L
.06842 .13649 L
.06966 .2396 L
.07022 .27812 L
.07053 .29516 L
.07082 .30799 L
.07106 .31627 L
.0712 .31979 L
.07132 .32228 L
.07146 .32417 L
.07161 .32525 L
.07175 .32531 L
.07188 .32452 L
.07204 .32253 L
.07212 .3211 L
.0722 .3192 L
Mistroke
.0725 .31013 L
.07266 .3033 L
.07284 .29469 L
.07316 .27594 L
.07436 .17717 L
.07493 .12236 L
.07553 .06485 L
.07577 .04254 L
.07604 .01993 L
.07619 .00809 L
.07633 .01865 L
.07661 .03763 L
.07692 .05607 L
.0772 .07002 L
.07751 .08111 L
.07767 .08552 L
.07784 .08911 L
.07793 .09055 L
.07801 .0916 L
.0781 .09245 L
.0782 .093 L
.07828 .09319 L
.07836 .09314 L
.07844 .09283 L
.07854 .09221 L
.07862 .09142 L
.07871 .0903 L
.07887 .08762 L
.07917 .08052 L
.08032 .03629 L
.08064 .02194 L
.08081 .01443 L
.08089 .0107 L
.08098 .0092 L
.08106 .01271 L
.08115 .01639 L
.0813 .02283 L
.0816 .0342 L
.08191 .04446 L
.08224 .05344 L
.08239 .05671 L
.08255 .05958 L
.08269 .06152 L
.08285 .06311 L
.08299 .06409 L
.08313 .06452 L
.08328 .06445 L
.08343 .06385 L
.08357 .06284 L
.08369 .06152 L
Mistroke
.08383 .05968 L
.08398 .05729 L
.08431 .05049 L
.08466 .04125 L
.08498 .0319 L
.08531 .02128 L
.08545 .01654 L
.08561 .01145 L
.0857 .00854 L
.08578 .00995 L
.08593 .01501 L
.08651 .03177 L
.08681 .03893 L
.08709 .0444 L
.08738 .04864 L
.08754 .05025 L
.08763 .05095 L
.08771 .05147 L
.08784 .05205 L
.08797 .05228 L
.0881 .05219 L
.08825 .05171 L
.0884 .05077 L
.08854 .04951 L
.08881 .04619 L
.08912 .04112 L
.08944 .03446 L
.09002 .02022 L
.09017 .01612 L
.09034 .01167 L
.09049 .00838 L
.09064 .01217 L
.09132 .02865 L
.09162 .03449 L
.0919 .03897 L
.09205 .04098 L
.09222 .04274 L
.09237 .04396 L
.09251 .04475 L
.09264 .04521 L
.09277 .04538 L
.0929 .04528 L
.09305 .04484 L
.0932 .04403 L
.09334 .04293 L
.09361 .04006 L
.09392 .03571 L
.09424 .02999 L
.09481 .01774 L
.09497 .01422 L
Mistroke
.09505 .01226 L
.09513 .01039 L
.09529 .00909 L
.09543 .01236 L
.09611 .02663 L
.09643 .03189 L
.09672 .03587 L
.09698 .03852 L
.09713 .0396 L
.09727 .04031 L
.09742 .04078 L
.09755 .04094 L
.09771 .0408 L
.09779 .04058 L
.09787 .04029 L
.09802 .03946 L
.09819 .03819 L
.0985 .03495 L
.09877 .03131 L
.09906 .02652 L
.09934 .02125 L
.09965 .01511 L
.09979 .01225 L
.09994 .0092 L
.10006 .00925 L
.1002 .01207 L
.10072 .02201 L
.10102 .02711 L
.10135 .0317 L
.10151 .03342 L
.10167 .03495 L
.10181 .03602 L
.10196 .03691 L
.1021 .03749 L
.10223 .03779 L
.10236 .03786 L
.10249 .03771 L
.10264 .03729 L
.10277 .03665 L
.10292 .0357 L
.10308 .03439 L
.10341 .03081 L
.10376 .02581 L
.10408 .02064 L
.10441 .01466 L
.10455 .01195 L
.1047 .00903 L
.10479 .00851 L
.10487 .01004 L
.10503 .01299 L
Mistroke
.10561 .02292 L
.10591 .02726 L
.10619 .03062 L
.10648 .03326 L
.10664 .03428 L
.10672 .03473 L
.1068 .03506 L
.10694 .03545 L
.10709 .03562 L
.10723 .03554 L
.10738 .03518 L
.10752 .0346 L
.10766 .03384 L
.10791 .03188 L
.10821 .02867 L
.10854 .0244 L
.10911 .01515 L
.10927 .01246 L
.10935 .01096 L
.10943 .00953 L
.10959 .0091 L
.10973 .01161 L
.11042 .02263 L
.11073 .02678 L
.11102 .02992 L
.11129 .03202 L
.11144 .03287 L
.11158 .03344 L
.11172 .03382 L
.11186 .03396 L
.11201 .03385 L
.1121 .03368 L
.11218 .03345 L
.11233 .0328 L
.1125 .03179 L
.11281 .02922 L
.11308 .0263 L
.11337 .02245 L
.11366 .01821 L
.11397 .01327 L
.11411 .01082 L
.11425 .00848 L
.11438 .00948 L
.11452 .01175 L
.11503 .01981 L
.11534 .02399 L
.11567 .02773 L
.11582 .02914 L
.11599 .03038 L
.11613 .03125 L
Mistroke
.11628 .03196 L
.11642 .03242 L
.11655 .03265 L
.11669 .03269 L
.11681 .03255 L
.11696 .03217 L
.1171 .03162 L
.11724 .03079 L
.1174 .02968 L
.1177 .02696 L
.11802 .02323 L
.11861 .01493 L
.11878 .0122 L
.11894 .00961 L
.11902 .0083 L
.11911 .00896 L
.11921 .01051 L
.1193 .01191 L
.11993 .0212 L
.12023 .02488 L
.12052 .0277 L
.12081 .0299 L
.12097 .03073 L
.12106 .03109 L
.12114 .03135 L
.12128 .03165 L
.12141 .03174 L
.12155 .03164 L
.12171 .0313 L
.12185 .03075 L
.12199 .03005 L
.12225 .02825 L
.12255 .02536 L
.12287 .02157 L
.12345 .01343 L
.12361 .01106 L
.12369 .00975 L
.12377 .0085 L
.12393 .00979 L
.12407 .01197 L
.12475 .02152 L
.12502 .02461 L
.12531 .02733 L
.12547 .02858 L
.12562 .02951 L
.12577 .0302 L
.12592 .03071 L
.12607 .03098 L
.12623 .03103 L
.12638 .03084 L
Mistroke
.12651 .03048 L
.1266 .03017 L
.12667 .02982 L
.12685 .02884 L
.12716 .02638 L
.12767 .02073 L
.12824 .0129 L
.12839 .01072 L
.12852 .00864 L
.1286 .00838 L
.12868 .00963 L
.12883 .01181 L
.12938 .01953 L
.12966 .02292 L
.12997 .02598 L
.1301 .02716 L
.13025 .02822 L
.13039 .02904 L
.13051 .02963 L
.13066 .03015 L
.13075 .03035 L
.13082 .03047 L
.13096 .03054 L
.13111 .0304 L
.13119 .03024 L
.13128 .03 L
.13137 .02967 L
.13145 .02929 L
.13176 .02732 L
.13192 .02602 L
.13209 .02439 L
.1324 .02091 L
.13298 .01306 L
.13315 .01058 L
.13324 .00936 L
.13331 .00822 L
.1334 .00895 L
.1335 .01036 L
.13366 .01279 L
.1343 .0212 L
.13459 .02438 L
.13486 .02684 L
.13502 .02793 L
.13518 .02888 L
.13533 .02953 L
.13547 .02994 L
.1356 .03016 L
.13572 .03022 L
.13586 .03011 L
.136 .0298 L
Mistroke
.13615 .0293 L
.1363 .02856 L
.13657 .02674 L
.13687 .02405 L
.13718 .02049 L
.13776 .01282 L
.13793 .01039 L
.13802 .0091 L
.13811 .00814 L
.13819 .00934 L
.13828 .01066 L
.13844 .01294 L
.13906 .02111 L
.13936 .02436 L
.13952 .02582 L
.13969 .02716 L
.13985 .02822 L
.14 .02899 L
.14015 .02955 L
.14029 .02989 L
.14042 .03005 L
.14057 .03002 L
.14069 .02984 L
.14083 .02947 L
.14097 .02889 L
.14113 .02805 L
.14141 .02601 L
.14173 .02288 L
.14209 .01871 L
.1424 .01455 L
.14257 .01214 L
.14273 .00984 L
.14287 .00811 L
.14302 .01035 L
.14335 .015 L
.14393 .02228 L
.14423 .02536 L
.1444 .02676 L
.14456 .02787 L
.14471 .02871 L
.14478 .02907 L
.14487 .02939 L
.14501 .02981 L
.14514 .03002 L
.1453 .03004 L
.14539 .02995 L
.14547 .0298 L
.14563 .02933 L
.14578 .02868 L
.14595 .02767 L
Mistroke
.14611 .0265 L
.14647 .02312 L
.14708 .01565 L
.14738 .01146 L
.14751 .00957 L
.14765 .00837 L
.14779 .0104 L
.14793 .01251 L
.14824 .01681 L
.14856 .02081 L
.1489 .02454 L
.14906 .02601 L
.14923 .02736 L
.14939 .02839 L
.14953 .02915 L
.14967 .02968 L
.14982 .03005 L
.1499 .03017 L
.14998 .03022 L
.15014 .03014 L
.15027 .02988 L
.15041 .02941 L
.15055 .02879 L
.15067 .02809 L
.15098 .0258 L
.15126 .02299 L
.15185 .0156 L
.15201 .0134 L
.15217 .01099 L
.15233 .00867 L
.15247 .00932 L
.15255 .0105 L
.15264 .01178 L
.1528 .01407 L
.15316 .01896 L
.15346 .02264 L
.15379 .02596 L
.15394 .02721 L
.15409 .02832 L
.15424 .02916 L
.15437 .02977 L
.1545 .03018 L
.15464 .03045 L
.15479 .03054 L
.15492 .03043 L
.155 .03028 L
.15508 .03006 L
.15523 .0295 L
.15539 .02867 L
.15557 .02749 L
Mistroke
.15588 .02473 L
.15617 .02149 L
.15648 .01764 L
.1568 .01301 L
.15695 .0108 L
.15711 .00841 L
.15725 .0095 L
.1574 .01175 L
.15808 .02126 L
.15838 .02469 L
.15871 .0277 L
.15886 .02877 L
.15902 .02969 L
.15916 .03035 L
.1593 .03076 L
.15945 .031 L
.15954 .03104 L
.15962 .031 L
.15977 .03077 L
.15992 .03029 L
.16006 .02969 L
.1602 .02887 L
.16045 .02692 L
.16076 .02389 L
.16104 .02054 L
.16134 .01648 L
.16165 .01178 L
.16175 .01034 L
.16184 .00897 L
.16192 .00812 L
.162 .00945 L
.16233 .01439 L
.16296 .02307 L
.16327 .02646 L
.16355 .0289 L
.16369 .02982 L
.16384 .03063 L
.16398 .0312 L
.16411 .03154 L
.16424 .03173 L
.16439 .0317 L
.16455 .03143 L
.1647 .03093 L
.16485 .03019 L
.16501 .02916 L
.1653 .02671 L
.16562 .0233 L
.16596 .01881 L
.16628 .01396 L
.16645 .01146 L
Mistroke
.16659 .0091 L
.16668 .00809 L
.16676 .00949 L
.16695 .01244 L
.16727 .01743 L
.1676 .02207 L
.16791 .02589 L
.16822 .0289 L
.16836 .03008 L
.1685 .03097 L
.16863 .03168 L
.16876 .03219 L
.1689 .03254 L
.16904 .03269 L
.16919 .03261 L
.16935 .03227 L
.16949 .03176 L
.16964 .03098 L
.1698 .02989 L
.16994 .02869 L
.17027 .02529 L
.17086 .01719 L
.17112 .013 L
.17127 .01062 L
.1714 .00837 L
.17155 .00994 L
.17163 .01123 L
.17171 .01262 L
.17199 .01722 L
.17251 .02475 L
.1728 .02814 L
.17307 .0307 L
.17322 .03184 L
.17338 .0328 L
.17353 .03343 L
.17367 .0338 L
.1738 .03395 L
.17394 .0339 L
.17409 .0336 L
.17422 .03311 L
.1743 .03273 L
.17439 .03224 L
.17454 .03116 L
.17483 .02847 L
.17517 .02436 L
.17549 .01979 L
.17577 .01521 L
.17592 .01268 L
.17608 .00996 L
.17616 .00849 L
Mistroke
.17625 .00898 L
.17633 .01044 L
.17641 .0118 L
.17672 .01722 L
.17735 .02681 L
.17771 .03096 L
.17788 .03252 L
.17804 .03371 L
.17818 .03454 L
.17833 .03517 L
.17841 .03541 L
.1785 .03556 L
.17865 .03561 L
.17873 .03553 L
.17881 .03537 L
.17896 .03486 L
.17905 .03441 L
.17914 .03391 L
.1793 .03273 L
.1796 .02979 L
.17988 .02631 L
.1805 .01632 L
.18075 .01173 L
.18089 .00908 L
.18102 .00921 L
.18117 .01208 L
.18131 .01477 L
.18159 .01978 L
.18188 .02462 L
.18218 .02922 L
.18247 .03279 L
.18274 .0353 L
.18287 .03623 L
.18301 .03701 L
.18316 .03756 L
.1833 .03782 L
.18345 .03783 L
.18359 .03756 L
.18367 .0373 L
.18375 .03694 L
.18391 .03603 L
.18406 .03488 L
.18422 .0333 L
.18455 .02919 L
.18514 .01931 L
.18543 .01377 L
.18557 .01094 L
.1857 .00827 L
.18585 .01067 L
.18601 .01402 L
Mistroke
.18629 .01974 L
.18685 .02982 L
.1871 .03345 L
.18737 .0367 L
.18751 .0381 L
.18767 .0393 L
.18775 .03983 L
.18783 .04022 L
.18798 .04074 L
.18807 .0409 L
.18815 .04094 L
.18823 .04089 L
.18832 .04073 L
.18848 .04017 L
.18856 .03971 L
.18865 .03917 L
.18895 .03641 L
.18922 .03284 L
.18985 .02179 L
.19011 .01612 L
.19026 .01285 L
.1904 .00971 L
.19048 .00796 L
.19056 .00992 L
.19071 .01335 L
.191 .01994 L
.19153 .03095 L
.19182 .03604 L
.19209 .03998 L
.19224 .04169 L
.1924 .04321 L
.19255 .04425 L
.19269 .04492 L
.19281 .04528 L
.19296 .04538 L
.1931 .04513 L
.19324 .04458 L
.19339 .0436 L
.19356 .04217 L
.19385 .0386 L
.19416 .03342 L
.1945 .02641 L
.19483 .01865 L
.19499 .01456 L
.19513 .01068 L
.19522 .00848 L
.19531 .00973 L
.19539 .01209 L
.19549 .01469 L
.19581 .02324 L
Mistroke
.1964 .03719 L
.19673 .04353 L
.19689 .04608 L
.19704 .04804 L
.19718 .04965 L
.19734 .05098 L
.19743 .05152 L
.19751 .05189 L
.19767 .05227 L
.19781 .05221 L
.19796 .05172 L
.19812 .05074 L
.19826 .04938 L
.19841 .04765 L
.19855 .04564 L
.1988 .041 L
.19938 .02688 L
.19969 .01788 L
.19985 .01264 L
.20001 .00828 L
.20014 .01263 L
.20029 .01734 L
.20059 .02725 L
.20092 .03745 L
.20127 .04717 L
.2016 .05465 L
.20176 .05765 L
.2019 .05998 L
.20204 .06176 L
.20219 .06323 L
.20235 .06417 L
.20243 .06445 L
.20251 .06456 L
.20265 .06438 L
.20277 .0638 L
.20292 .06263 L
.20306 .06103 L
.20321 .05873 L
.20337 .05566 L
.20366 .04862 L
.20398 .03889 L
.20432 .02634 L
.20448 .01994 L
.20457 .01632 L
.20465 .01288 L
.20479 .00921 L
.20495 .01618 L
.20553 .04267 L
.20617 .06874 L
.20654 .0803 L
Mistroke
.20671 .08469 L
.20687 .08805 L
.20701 .09033 L
.20716 .09207 L
.20725 .09271 L
.20733 .09308 L
.20748 .09311 L
.20756 .09279 L
.20765 .0922 L
.2078 .09046 L
.20789 .08896 L
.20797 .08725 L
.20814 .08324 L
.20844 .07308 L
.20871 .06063 L
.20903 .04247 L
.20919 .03228 L
.20933 .02228 L
.20946 .01273 L
.20958 .01261 L
.20971 .02306 L
.20985 .03489 L
.21042 .08698 L
.21157 .19762 L
.21212 .24446 L
.21271 .28533 L
.21304 .30291 L
.21319 .30909 L
.21335 .31476 L
.21351 .31904 L
.21365 .32204 L
.2138 .32418 L
.21388 .32492 L
.21396 .32529 L
.21412 .3252 L
.2142 .32471 L
.21428 .32383 L
.21444 .3214 L
.21458 .31815 L
.21476 .31313 L
.21491 .30747 L
.21526 .2912 L
.21589 .2514 L
.21649 .20463 L
.21765 .10583 L
.21829 .05606 L
.2186 .03454 L
.21874 .02584 L
.21889 .01687 L
.21903 .00897 L
Mistroke
.21916 .01375 L
.21945 .02702 L
.21976 .03881 L
.22005 .04695 L
.22018 .04974 L
.22031 .05227 L
.22043 .05403 L
.22056 .05555 L
.2207 .05667 L
.22084 .05734 L
.22098 .05751 L
.22111 .05729 L
.22126 .0566 L
.22134 .05601 L
.22142 .05537 L
.2217 .05203 L
.22204 .04661 L
.22236 .04038 L
.22298 .0265 L
.22325 .02022 L
.22355 .01352 L
.22368 .01071 L
.22382 .00807 L
.22395 .0107 L
.22407 .01299 L
.22462 .02197 L
.2249 .0255 L
.22506 .02703 L
.22522 .02841 L
.22535 .02939 L
.22551 .03025 L
.22565 .03082 L
.22578 .03118 L
.22592 .03138 L
.22607 .03138 L
.22622 .03119 L
.22635 .03086 L
.2265 .03029 L
.22666 .02946 L
.22696 .02742 L
.22728 .02461 L
.22761 .021 L
.2279 .01742 L
.22821 .01319 L
.22836 .01108 L
.2285 .00902 L
.22862 .00872 L
.22876 .0108 L
.22927 .01867 L
.23044 .03391 L
Mistroke
.23075 .03646 L
.23091 .03738 L
.231 .03779 L
.23108 .03809 L
.23117 .03832 L
.23125 .03845 L
.23135 .03848 L
.23144 .0384 L
.2316 .03799 L
.23169 .03761 L
.23177 .03714 L
.23192 .03605 L
.23206 .03471 L
.23237 .0305 L
.23268 .02483 L
.23302 .01698 L
.23315 .01325 L
.2333 .00895 L
.23338 .00953 L
.23346 .012 L
.23361 .01704 L
.23423 .04101 L
.23535 .09032 L
.23592 .11481 L
.23652 .13735 L
.23683 .14702 L
.23717 .15557 L
.23732 .15856 L
.23749 .16122 L
.23764 .16319 L
.23778 .16453 L
.23792 .16542 L
.23807 .16585 L
.23821 .16577 L
.23834 .16528 L
.23849 .1642 L
.23858 .16336 L
.23866 .16244 L
.23896 .1577 L
.23921 .15202 L
.2395 .14428 L
.24007 .12453 L
.24128 .07187 L
.24188 .04527 L
.24243 .02288 L
.24259 .01702 L
.24274 .01182 L
.24289 .00914 L
.24298 .01171 L
.24307 .01435 L
Mistroke
.24342 .02368 L
.24375 .03067 L
.24405 .03534 L
.24422 .03732 L
.24438 .03873 L
.24453 .03968 L
.24466 .04026 L
.24481 .0406 L
.24496 .04061 L
.2451 .04034 L
.24525 .03977 L
.24539 .03898 L
.24552 .03806 L
.24583 .03506 L
.24613 .03142 L
.24678 .02175 L
.24706 .01708 L
.24738 .01186 L
.24751 .00975 L
.24765 .00835 L
.24778 .01041 L
.2479 .01226 L
.24845 .01988 L
.24874 .02322 L
.24901 .02579 L
.2493 .02786 L
.24945 .02868 L
.24953 .02906 L
.24961 .02935 L
.24975 .02977 L
.24983 .02992 L
.24992 .03001 L
.25001 .03004 L
.25009 .03001 L
.25025 .02978 L
.2504 .02936 L
.25053 .02881 L
.25068 .02802 L
.25084 .02698 L
.2512 .02385 L
.25154 .02004 L
.25185 .01595 L
.25202 .0135 L
.25218 .01111 L
.25232 .0089 L
.25247 .00939 L
.25256 .01079 L
.25264 .01213 L
.25279 .01466 L
.25335 .02388 L
Mistroke
.25461 .03905 L
.25474 .03978 L
.25488 .04033 L
.25501 .04063 L
.25513 .04069 L
.25526 .04052 L
.25539 .04012 L
.25552 .03942 L
.25567 .03832 L
.25582 .03684 L
.25598 .03487 L
.25627 .03029 L
.25653 .02493 L
.25681 .01778 L
.25697 .01321 L
.25712 .00852 L
.25721 .01008 L
.2573 .01316 L
.25746 .01883 L
.25806 .04286 L
.25924 .0953 L
.25984 .1207 L
.26048 .14322 L
.26074 .15056 L
.26103 .157 L
.26119 .15993 L
.26134 .16213 L
.26148 .16376 L
.26163 .16498 L
.26179 .16571 L
.26193 .16586 L
.26201 .16574 L
.2621 .16543 L
.26226 .16444 L
.2624 .16299 L
.26256 .16092 L
.26284 .15587 L
.26316 .14798 L
.26347 .13881 L
.26416 .1128 L
.26542 .05715 L
.26603 .0309 L
.26633 .01937 L
.26647 .01468 L
.26661 .00987 L
.26675 .01045 L
.26687 .0143 L
.26712 .02114 L
.26741 .02769 L
.26768 .03259 L
Mistroke
.26795 .03637 L
.26809 .03788 L
.26824 .03913 L
.26832 .03962 L
.2684 .04004 L
.26856 .04054 L
.2687 .04069 L
.26884 .04056 L
.26898 .04015 L
.26913 .03944 L
.26926 .03863 L
.2694 .03753 L
.26971 .03436 L
.27 .03068 L
.27057 .0222 L
.27109 .01342 L
.27124 .01099 L
.2714 .00844 L
.27148 .00873 L
.27157 .01014 L
.27172 .01257 L
.2723 .02042 L
.27262 .02395 L
.27279 .02559 L
.27296 .02692 L
.27311 .02795 L
.27328 .02884 L
.27344 .02944 L
.27358 .02982 L
.27374 .03002 L
.27381 .03004 L
.2739 .03 L
.27405 .02978 L
.27419 .02938 L
.27428 .02906 L
.27436 .02869 L
.27452 .02785 L
.27486 .02527 L
.27516 .02229 L
.27544 .01898 L
.27576 .01456 L
.27592 .01222 L
.27606 .00998 L
.27619 .00795 L
.27631 .00989 L
.27658 .01433 L
.27715 .02372 L
.27831 .03818 L
.27846 .03921 L
.2786 .03993 L
Mistroke
.27874 .04043 L
.27882 .04057 L
.2789 .04064 L
.27899 .0406 L
.27908 .04045 L
.27916 .04023 L
.27924 .03989 L
.27932 .03947 L
.2794 .03892 L
.27955 .03766 L
.27984 .03421 L
.28011 .02971 L
.2804 .02339 L
.28072 .01498 L
.28085 .01115 L
.28099 .00908 L
.28114 .01417 L
.28128 .01918 L
.28186 .04253 L
.28291 .08948 L
.28355 .11712 L
.28415 .13939 L
.28442 .14736 L
.2847 .1544 L
.28484 .15746 L
.285 .16029 L
.28514 .16225 L
.28528 .16391 L
.28537 .16466 L
.28545 .16519 L
.28553 .16556 L
.28561 .1658 L
.28577 .16581 L
.28591 .1653 L
.286 .16476 L
.28608 .1641 L
.28626 .16208 L
.28642 .15968 L
.28659 .15654 L
.28717 .14129 L
.28781 .11813 L
.28902 .065 L
.28962 .03924 L
.29017 .01812 L
.29033 .01271 L
.29048 .00795 L
.29063 .01254 L
.2908 .01721 L
.29116 .02554 L
.29149 .03133 L
Mistroke
.29177 .03491 L
.29191 .03622 L
.29207 .03731 L
.29222 .03804 L
.29231 .03829 L
.29239 .03843 L
.29255 .03846 L
.29269 .0382 L
.29282 .03776 L
.29295 .03709 L
.2931 .03614 L
.29324 .03506 L
.29376 .02956 L
.29436 .02133 L
.2949 .01301 L
.29505 .01074 L
.29513 .00956 L
.29521 .00832 L
.29536 .00979 L
.2955 .01182 L
.29616 .02058 L
.29672 .0264 L
.29688 .02766 L
.29704 .02882 L
.29718 .02967 L
.29734 .0304 L
.29741 .03069 L
.2975 .03096 L
.29765 .03128 L
.29773 .03137 L
.29782 .0314 L
.2979 .03136 L
.29798 .03127 L
.29813 .03091 L
.29822 .03062 L
.2983 .03028 L
.29844 .02949 L
.29859 .02842 L
.2989 .02554 L
.29919 .02194 L
.29974 .01309 L
.29981 .01163 L
.2999 .01002 L
.30005 .00887 L
.3002 .01216 L
.30037 .01592 L
.30096 .02935 L
.30164 .04421 L
.30194 .04959 L
.3021 .05199 L
Mistroke
.30228 .05417 L
.30244 .05574 L
.30258 .05677 L
.30272 .05735 L
.30287 .0575 L
.30303 .05712 L
.30317 .05622 L
.30326 .05546 L
.30333 .05462 L
.3035 .05215 L
.30367 .04886 L
.30383 .04507 L
.30419 .03382 L
.30435 .0275 L
.30452 .01984 L
.30461 .01582 L
.30469 .01181 L
.30484 .01206 L
.30498 .02007 L
.30511 .02797 L
.3054 .0474 L
.30602 .09431 L
.30726 .20028 L
.30788 .24873 L
.3082 .27092 L
.30854 .29096 L
.30884 .30517 L
.309 .31127 L
.30917 .31665 L
.30933 .32049 L
.30947 .32305 L
.30961 .32468 L
.30974 .32536 L
.30987 .32521 L
.31002 .32412 L
.31016 .32197 L
.3103 .31902 L
.31043 .31545 L
.31055 .3115 L
.31082 .30031 L
.31139 .26672 L
.31199 .21956 L
.31315 .11034 L
.31345 .08105 L
.31378 .05058 L
.31393 .03723 L
.31409 .02366 L
.31423 .01257 L
.31438 .01489 L
.31453 .02594 L
Mistroke
.31467 .03538 L
.31498 .05423 L
.31525 .06766 L
.31554 .07911 L
.31568 .08328 L
.31582 .08691 L
.31594 .08935 L
.31608 .09134 L
.31621 .09254 L
.31634 .09315 L
.31647 .09309 L
.31659 .0925 L
.31674 .09114 L
.31689 .08896 L
.31705 .08575 L
.31721 .08207 L
.31779 .06305 L
.31846 .03455 L
.31875 .02123 L
.31891 .01392 L
.31907 .00877 L
.31921 .0149 L
.31936 .02136 L
.31963 .03195 L
.32016 .0491 L
.32047 .05627 L
.32064 .05934 L
.32079 .06152 L
.32093 .06303 L
.32109 .06409 L
.32123 .06453 L
.32137 .06447 L
.32151 .06395 L
.32164 .06307 L
.32178 .06161 L
.32192 .05979 L
.32217 .05558 L
.32243 .04976 L
.32299 .03443 L
.32331 .02443 L
.32346 .01937 L
.3236 .0147 L
.32374 .01012 L
.32389 .01052 L
.32404 .01522 L
.3242 .02019 L
.3245 .029 L
.32483 .0372 L
.32514 .04351 L
.32542 .04785 L
Mistroke
.32555 .04943 L
.3257 .05076 L
.32583 .05164 L
.32596 .05212 L
.32611 .05229 L
.32626 .05204 L
.32639 .05148 L
.32653 .05053 L
.32668 .0491 L
.32684 .04714 L
.32713 .04259 L
.32771 .03045 L
.32823 .01715 L
.32838 .01296 L
.32847 .01067 L
.32855 .00854 L
.32869 .01107 L
.32884 .0151 L
.32951 .03067 L
.32981 .03621 L
.33009 .04035 L
.33025 .04213 L
.33042 .04364 L
.33057 .04461 L
.33072 .04516 L
.33087 .04538 L
.33101 .04525 L
.33114 .04486 L
.33128 .04413 L
.33143 .043 L
.33159 .04142 L
.33188 .03769 L
.33246 .02754 L
.33297 .01621 L
.33313 .01262 L
.33322 .01065 L
.3333 .00881 L
.33344 .01029 L
.33359 .01379 L
.33426 .02746 L
.33455 .0324 L
.33484 .03614 L
.33499 .03777 L
.33516 .03918 L
.33532 .0401 L
.33546 .04066 L
.3356 .04092 L
.33575 .04088 L
.33588 .0406 L
.33602 .04003 L
Mistroke
.33617 .03911 L
.33633 .03779 L
.33662 .03462 L
.33719 .02582 L
.33771 .01582 L
.33787 .01264 L
.33795 .01089 L
.33803 .00925 L
.33817 .00951 L
.33833 .01265 L
.33899 .02507 L
.33929 .02961 L
.33957 .03311 L
.33973 .03465 L
.3399 .036 L
.34005 .03692 L
.3402 .0375 L
.34035 .03782 L
.34043 .03786 L
.34052 .03782 L
.34067 .03751 L
.34081 .03695 L
.3409 .03649 L
.34098 .03597 L
.34113 .03478 L
.34147 .03118 L
.34205 .0227 L
.34235 .01748 L
.34251 .01456 L
.34268 .01136 L
.34283 .00847 L
.34297 .01004 L
.3431 .01253 L
.34324 .01511 L
.34384 .02506 L
.34409 .02843 L
.34436 .03139 L
.34451 .03277 L
.34465 .03379 L
.34479 .03459 L
.34492 .03515 L
.34506 .0355 L
.34521 .03563 L
.34535 .0355 L
.34548 .03517 L
.34563 .03454 L
.34572 .03406 L
.3458 .03355 L
.3461 .03101 L
.34638 .02777 L
Mistroke
.3467 .0234 L
.34703 .01811 L
.34734 .01286 L
.34748 .01041 L
.34761 .00812 L
.34774 .01013 L
.34789 .01271 L
.34849 .0223 L
.34901 .02883 L
.34916 .03027 L
.3493 .03143 L
.34944 .03236 L
.34957 .03302 L
.3497 .03355 L
.34985 .03388 L
.34999 .03396 L
.35012 .03383 L
.35028 .03344 L
.35042 .03286 L
.35057 .03197 L
.35074 .03075 L
.35107 .02748 L
.35139 .02355 L
.35167 .01942 L
.35198 .01464 L
.35224 .01026 L
.35239 .00813 L
.35253 .01047 L
.35305 .01861 L
.3536 .026 L
.35392 .0291 L
.35406 .03025 L
.3542 .03114 L
.35433 .03181 L
.35448 .03232 L
.35464 .03264 L
.35478 .03269 L
.35492 .03251 L
.35508 .03208 L
.35516 .03176 L
.35524 .03134 L
.3554 .03042 L
.3557 .02797 L
.35598 .02497 L
.3565 .01791 L
.35681 .01327 L
.35697 .01064 L
.35713 .00815 L
.35726 .00983 L
.3574 .01207 L
Mistroke
.35771 .01669 L
.35805 .02156 L
.35839 .02549 L
.35868 .0283 L
.35885 .02955 L
.35901 .03046 L
.35916 .03112 L
.35932 .03156 L
.35948 .03174 L
.35957 .03173 L
.35965 .03164 L
.3598 .03129 L
.35994 .03077 L
.3601 .02993 L
.36026 .02891 L
.36054 .02648 L
.3608 .02367 L
.36139 .01581 L
.36167 .01158 L
.36183 .00915 L
.36197 .00895 L
.36205 .01021 L
.36214 .01157 L
.3623 .01401 L
.36261 .01847 L
.36294 .02265 L
.36329 .02633 L
.36346 .02778 L
.36362 .02892 L
.36376 .02974 L
.36392 .03041 L
.36407 .03083 L
.3642 .03101 L
.36436 .031 L
.36451 .03076 L
.36465 .03034 L
.36477 .02979 L
.36491 .02901 L
.36506 .02798 L
.36537 .02526 L
.36566 .02206 L
.36598 .01793 L
.36632 .0131 L
.36647 .01092 L
.36663 .00856 L
.36672 .00867 L
.3668 .0099 L
.36696 .01229 L
.36754 .02036 L
.36787 .02411 L
Mistroke
.36804 .02579 L
.36822 .02732 L
.36838 .02843 L
.36855 .02939 L
.36871 .03002 L
.36886 .03038 L
.36901 .03054 L
.3691 .03052 L
.36917 .03045 L
.36932 .03015 L
.36946 .02967 L
.36962 .02888 L
.36977 .02793 L
.37011 .0251 L
.37069 .0184 L
.37099 .01435 L
.37115 .01201 L
.37131 .00975 L
.37144 .00816 L
.37159 .01038 L
.37186 .01418 L
.37237 .02097 L
.37267 .02422 L
.37298 .02699 L
.37325 .02872 L
.3734 .02942 L
.37354 .02988 L
.37368 .03015 L
.37383 .03021 L
.37398 .03007 L
.37411 .02977 L
.37426 .02921 L
.37443 .02837 L
.37473 .02621 L
.37504 .02318 L
.37538 .01927 L
.37567 .01544 L
.37583 .01321 L
.37598 .01104 L
.37612 .00903 L
.37627 .00902 L
.3764 .01101 L
.37653 .01282 L
.37704 .01973 L
.37761 .02576 L
.37789 .0279 L
.37806 .02881 L
.37821 .02944 L
.37835 .02983 L
.3785 .03004 L
Mistroke
.37865 .03003 L
.37877 .02986 L
.37893 .02945 L
.37901 .02912 L
.37909 .02876 L
.37939 .02688 L
.37968 .02438 L
.38 .02095 L
.38033 .01671 L
.38064 .01246 L
.38078 .0105 L
.38092 .00834 L
.38106 .00957 L
.38119 .01145 L
.38179 .01956 L
.38231 .02523 L
.38246 .02651 L
.38261 .02755 L
.38274 .0284 L
.38287 .02903 L
.38301 .02956 L
.38316 .02992 L
.3833 .03006 L
.38343 .03002 L
.38358 .02976 L
.38373 .02933 L
.38388 .02864 L
.38405 .02766 L
.38435 .02526 L
.38464 .02236 L
.38496 .01855 L
.38529 .01403 L
.38556 .0102 L
.38571 .00799 L
.38585 .00993 L
.38636 .01716 L
.38692 .02384 L
.38724 .02669 L
.38738 .02777 L
.38752 .02861 L
.38765 .02926 L
.3878 .02978 L
.38788 .02998 L
.38796 .03012 L
.3881 .03022 L
.38826 .0301 L
.3884 .02978 L
.38856 .02921 L
.38872 .02836 L
.38902 .02621 L
Mistroke
.38931 .02352 L
.38983 .01714 L
.39014 .01287 L
.39031 .01044 L
.39046 .00814 L
.39059 .00969 L
.39074 .01178 L
.39104 .01609 L
.39137 .02041 L
.39172 .02436 L
.39201 .02707 L
.39218 .0283 L
.39234 .0292 L
.39249 .02985 L
.39265 .03031 L
.3928 .03052 L
.39289 .03054 L
.39298 .03048 L
.39313 .0302 L
.39326 .02976 L
.39342 .02903 L
.39357 .02813 L
.39391 .02541 L
.39421 .02215 L
.39457 .01761 L
.39491 .01285 L
.39505 .01079 L
.39518 .00881 L
.39533 .00934 L
.39547 .01143 L
.39609 .02013 L
.39638 .02362 L
.39669 .0267 L
.39685 .02802 L
.39702 .02921 L
.39718 .03005 L
.39734 .0306 L
.39748 .03092 L
.39763 .03104 L
.39777 .03094 L
.3979 .03067 L
.39805 .03015 L
.39814 .02975 L
.39822 .02932 L
.39852 .02717 L
.39881 .02439 L
.39913 .02064 L
.39946 .01606 L
.39961 .01391 L
.39977 .0115 L
Mistroke
.39992 .00924 L
.40005 .00874 L
.40018 .01076 L
.40032 .01289 L
.40092 .02137 L
.40121 .02486 L
.40149 .02758 L
.40173 .02949 L
.40187 .03033 L
.402 .03093 L
.40215 .03143 L
.4023 .03169 L
.40242 .03174 L
.40257 .0316 L
.40272 .03121 L
.4028 .03092 L
.40288 .03054 L
.40317 .02868 L
.40345 .02624 L
.40374 .02295 L
.40427 .01562 L
.40457 .01094 L
.40466 .00962 L
.40474 .0082 L
.4049 .01021 L
.40557 .02036 L
.40589 .02455 L
.4062 .02785 L
.40647 .03015 L
.40662 .03113 L
.40676 .03184 L
.40691 .03236 L
.40706 .03264 L
.40719 .03269 L
.40733 .03255 L
.40748 .03216 L
.40757 .03183 L
.40764 .03147 L
.40793 .02956 L
.4082 .02705 L
.4085 .02365 L
.40903 .01603 L
.40933 .01116 L
.40941 .0098 L
.4095 .00832 L
.40966 .01021 L
.41033 .02084 L
.41065 .02525 L
.41095 .02873 L
.41122 .03118 L
Mistroke
.41138 .03224 L
.41152 .033 L
.41167 .03357 L
.41181 .03388 L
.41194 .03396 L
.41208 .03383 L
.41223 .03345 L
.41232 .03313 L
.41239 .03276 L
.41254 .03185 L
.41268 .03081 L
.41295 .02822 L
.41325 .02469 L
.41378 .01673 L
.41405 .01201 L
.41421 .00928 L
.41435 .0091 L
.41443 .01052 L
.41452 .01207 L
.41468 .01484 L
.41498 .01996 L
.41531 .02487 L
.41565 .02929 L
.41594 .03225 L
.41611 .03354 L
.41626 .03449 L
.4164 .0351 L
.41656 .0355 L
.4167 .03563 L
.41683 .03553 L
.41698 .03515 L
.41707 .03482 L
.41715 .03443 L
.41729 .03353 L
.41745 .03231 L
.41775 .02913 L
.41804 .02534 L
.41838 .0201 L
.4187 .01451 L
.41883 .01211 L
.41896 .00951 L
.41912 .00924 L
.41926 .01191 L
.41977 .02128 L
.42008 .02638 L
.42038 .03052 L
.42064 .03356 L
.42079 .03492 L
.42093 .03598 L
.42108 .03688 L
Mistroke
.42122 .03745 L
.42135 .03777 L
.42149 .03786 L
.42165 .03767 L
.42172 .03745 L
.42181 .03711 L
.42196 .03629 L
.42211 .03525 L
.42242 .03212 L
.42271 .02832 L
.42335 .01716 L
.4236 .01216 L
.42374 .00929 L
.42387 .00921 L
.42402 .01234 L
.42417 .01527 L
.42444 .02073 L
.42472 .02604 L
.42503 .03109 L
.42531 .035 L
.42558 .03788 L
.42572 .03902 L
.42587 .03997 L
.42601 .04056 L
.42614 .04087 L
.42628 .04093 L
.42644 .04067 L
.42652 .0404 L
.4266 .04002 L
.42676 .03906 L
.42691 .03781 L
.42707 .03609 L
.4274 .03158 L
.428 .02065 L
.42829 .01445 L
.42843 .01127 L
.42856 .00829 L
.42871 .01103 L
.42887 .01478 L
.42915 .0212 L
.42971 .0326 L
.42996 .03672 L
.43023 .04042 L
.43037 .04207 L
.43051 .04332 L
.43065 .04425 L
.43079 .04494 L
.43087 .04519 L
.43095 .04534 L
.4311 .04533 L
Mistroke
.43125 .04494 L
.43139 .04427 L
.43152 .04334 L
.43165 .04223 L
.43192 .03885 L
.43219 .03449 L
.43248 .02879 L
.4328 .0215 L
.43297 .01732 L
.43315 .0127 L
.43331 .00858 L
.4334 .00966 L
.43348 .0119 L
.43379 .02002 L
.43435 .03406 L
.43465 .04037 L
.43497 .04585 L
.43514 .04809 L
.43529 .04979 L
.43543 .05095 L
.43559 .05181 L
.43573 .05223 L
.43588 .05224 L
.43601 .05189 L
.43616 .05112 L
.43624 .05049 L
.43632 .04977 L
.43647 .04809 L
.4368 .04286 L
.43709 .03682 L
.43741 .02886 L
.4377 .02052 L
.43797 .01204 L
.43812 .0087 L
.4382 .01148 L
.43828 .01404 L
.43857 .02336 L
.43913 .04072 L
.43964 .05357 L
.43978 .05637 L
.43993 .05898 L
.44006 .06087 L
.44021 .06251 L
.44036 .06374 L
.44045 .06419 L
.44052 .06445 L
.44067 .06454 L
.44082 .06409 L
.44096 .06317 L
.44111 .06159 L
Mistroke
.44126 .05957 L
.44139 .05723 L
.44164 .05165 L
.44191 .04411 L
.44224 .03321 L
.44241 .02675 L
.44259 .01948 L
.44275 .01281 L
.44283 .00892 L
.44292 .01063 L
.44306 .01722 L
.44322 .02436 L
.4438 .05005 L
.44441 .07355 L
.44471 .08245 L
.44487 .08621 L
.44505 .08943 L
.4452 .09154 L
.44535 .09274 L
.44549 .09319 L
.44563 .09291 L
.44579 .09169 L
.44588 .09057 L
.44596 .08929 L
.44612 .08606 L
.44627 .08209 L
.44661 .06998 L
.44697 .05195 L
.44728 .03228 L
.44744 .02144 L
.44758 .01088 L
.44773 .01672 L
.44781 .02344 L
.44789 .02998 L
.44823 .06004 L
.44939 .17195 L
.44999 .22611 L
.45055 .26937 L
.45086 .28881 L
.4512 .30552 L
.45135 .31136 L
.4515 .31646 L
.45164 .31991 L
.45179 .32274 L
.45193 .32458 L
.45208 .32535 L
.4522 .32524 L
.45234 .32427 L
.45249 .32223 L
.45265 .31894 L
Mistroke
.45278 .31525 L
.45293 .31027 L
.45349 .28415 L
.454 .25034 L
.45519 .15322 L
.45584 .09836 L
.45644 .05201 L
.45671 .03389 L
.45696 .01839 L
.45709 .01053 L
.45725 .01325 L
.45738 .01988 L
.45751 .02552 L
.4578 .03683 L
.45807 .0451 L
.45836 .0514 L
.45851 .05381 L
.45859 .05488 L
.45867 .0557 L
.45875 .05636 L
.45883 .05691 L
.45898 .05743 L
.45906 .05751 L
.45915 .05742 L
.45931 .05685 L
.45945 .05587 L
.45959 .05461 L
.4599 .05061 L
.46023 .04478 L
.46054 .03851 L
.46123 .02285 L
.46152 .01622 L
.46168 .01272 L
.46183 .00954 L
.4619 .00794 L
.46199 .00961 L
.46216 .01302 L
.46248 .01842 L
.46279 .02301 L
.46309 .02646 L
.46336 .02879 L
.46351 .02977 L
.46365 .03048 L
.46381 .03102 L
.46389 .0312 L
.46397 .03134 L
.46413 .0314 L
.46427 .03127 L
.46435 .0311 L
.46443 .03088 L
Mistroke
.46459 .03032 L
.46475 .02951 L
.46493 .02839 L
.46523 .02597 L
.46555 .02277 L
.46613 .01566 L
.46639 .01195 L
.46653 .00992 L
.46668 .00812 L
.46681 .01007 L
.46695 .01222 L
.4672 .01602 L
.46837 .03222 L
.47326 .08226 L
.47436 .12856 L
.47492 .14677 L
.47523 .15472 L
.47552 .16034 L
.47569 .16265 L
.47584 .16429 L
.47599 .16527 L
.47614 .16581 L
.47623 .16587 L
.4763 .16578 L
.4764 .16548 L
.47648 .16503 L
.47663 .16379 L
.47672 .16286 L
.4768 .16185 L
.47707 .15731 L
.47737 .15052 L
.47797 .13176 L
.47931 .07529 L
.47996 .04619 L
.48055 .02212 L
.48069 .01697 L
.48084 .01178 L
.48091 .00918 L
.481 .00944 L
.48115 .01403 L
.48172 .02821 L
.48203 .03371 L
.48221 .03608 L
.48237 .03781 L
.48251 .03898 L
.48267 .0399 L
.48274 .04022 L
.48283 .04046 L
.48298 .04064 L
.48313 .0405 L
Mistroke
.48321 .04029 L
.48329 .04 L
.48345 .03919 L
.48362 .03799 L
.48393 .03504 L
.48422 .0316 L
.48486 .02204 L
.4852 .01647 L
.48538 .01338 L
.48556 .0105 L
.4857 .00809 L
.48579 .00911 L
.48586 .01031 L
.4862 .0154 L
.48649 .01926 L
.4868 .02292 L
.48708 .0256 L
.48738 .0278 L
.48755 .02871 L
.4877 .02933 L
.48785 .02976 L
.48799 .02999 L
.48811 .03004 L
.48825 .02994 L
.4884 .02965 L
.48853 .02921 L
.48867 .02859 L
.4888 .02786 L
.48905 .0261 L
.48934 .02345 L
.48965 .01993 L
.49019 .01236 L
.49027 .01114 L
.49036 .00981 L
.49051 .00851 L
.4906 .00987 L
.49067 .01113 L
.49085 .01405 L
.49145 .02395 L
.49174 .02847 L
.49206 .03276 L
.49235 .03608 L
.49262 .03848 L
.49276 .03937 L
.4929 .04008 L
.49298 .04036 L
.49306 .04056 L
.49321 .04069 L
.49337 .04049 L
.49352 .03996 L
Mistroke
.4936 .03951 L
.49368 .039 L
.49385 .03752 L
.494 .03584 L
.49414 .03397 L
.49445 .02857 L
.49472 .02253 L
.49502 .01471 L
.49518 .00993 L
.49532 .01062 L
.49547 .01562 L
.4956 .02062 L
.49625 .04668 L
.49755 .10487 L
.49815 .12894 L
.49871 .14725 L
.49903 .15501 L
.49919 .1583 L
.49936 .16116 L
.49951 .16305 L
.49958 .16387 L
.49967 .16458 L
.49981 .16546 L
.49995 .16584 L
.5001 .16576 L
.50023 .16523 L
.50039 .16414 L
.50046 .16339 L
.50055 .16242 L
.50084 .15781 L
.50111 .15186 L
.50162 .13699 L
.50217 .11654 L
.50339 .0628 L
.50403 .03496 L
.50438 .02113 L
.50456 .01487 L
.50463 .01224 L
.50472 .00945 L
.50487 .01131 L
.50495 .01383 L
.50503 .01609 L
.50537 .02484 L
.50566 .03073 L
.50597 .0355 L
.50612 .03725 L
.50628 .03874 L
.50644 .03975 L
.50658 .04035 L
.50671 .04064 L
Mistroke
.50685 .04067 L
.507 .04041 L
.50714 .03991 L
.50728 .03914 L
.50743 .03807 L
.5077 .03553 L
.50832 .02748 L
.50896 .01719 L
.50912 .01463 L
.50928 .01193 L
.50942 .00965 L
.50957 .00868 L
.50971 .01088 L
.50986 .01317 L
.51013 .01706 L
.51044 .02104 L
.51074 .02423 L
.511 .02654 L
.51115 .02754 L
.51129 .02842 L
.51143 .02907 L
.51156 .02952 L
.51168 .02983 L
.5118 .03 L
.51193 .03004 L
.51207 .02993 L
.51221 .02961 L
.51235 .02915 L
.51248 .02858 L
.5126 .02791 L
.51287 .02596 L
.51316 .02326 L
.51347 .0197 L
.51402 .01207 L
.5141 .01084 L
.51419 .0095 L
.51434 .00883 L
.51443 .01021 L
.5145 .01147 L
.51468 .01439 L
.51528 .02425 L
.51558 .02875 L
.51589 .03298 L
.51618 .03625 L
.51646 .03857 L
.51659 .03944 L
.51674 .04012 L
.51682 .04038 L
.5169 .04055 L
.51705 .04063 L
Mistroke
.51713 .04055 L
.51721 .04036 L
.51736 .03978 L
.51744 .0393 L
.51752 .03876 L
.51769 .03717 L
.51784 .03551 L
.51799 .03339 L
.51826 .02866 L
.51857 .02153 L
.51886 .01363 L
.51902 .00884 L
.51917 .01188 L
.51932 .01733 L
.51949 .02359 L
.52008 .04756 L
.5214 .10703 L
.52195 .12909 L
.52254 .14822 L
.52288 .15636 L
.52319 .1617 L
.52334 .16352 L
.52342 .16427 L
.5235 .16491 L
.52366 .16567 L
.5238 .16588 L
.52388 .16577 L
.52397 .16549 L
.52413 .16452 L
.52421 .16373 L
.5243 .16284 L
.52448 .16023 L
.52479 .15419 L
.52513 .14553 L
.52576 .12399 L
.52633 .10014 L
.52745 .05036 L
.52774 .03796 L
.52806 .02548 L
.52821 .02011 L
.52836 .01474 L
.52849 .01042 L
.52864 .0099 L
.52879 .01437 L
.52896 .01874 L
.52925 .02551 L
.52944 .02898 L
.52961 .03174 L
.52977 .03382 L
.52994 .0356 L
Mistroke
.53008 .03677 L
.53024 .0377 L
.53038 .03823 L
.53051 .03846 L
.53067 .03843 L
.53082 .03812 L
.5309 .03784 L
.53098 .03745 L
.53114 .03654 L
.53145 .03403 L
.53178 .03043 L
.53239 .02229 L
.53293 .01413 L
.53307 .01186 L
.53323 .00945 L
.53338 .00866 L
.53352 .01067 L
.53416 .01941 L
.53448 .02316 L
.53484 .02657 L
.53499 .02783 L
.53516 .02898 L
.53531 .02986 L
.53546 .03051 L
.53559 .03097 L
.53574 .03128 L
.53582 .03137 L
.5359 .0314 L
.53605 .03131 L
.5362 .031 L
.53628 .03073 L
.53636 .03041 L
.5365 .02968 L
.53665 .02868 L
.53692 .02639 L
.5372 .02308 L
.53751 .01864 L
.53784 .01293 L
.53792 .01149 L
.538 .00986 L
.53815 .00908 L
.5383 .01221 L
.53843 .0152 L
.5395 .0394 L
.53979 .04529 L
.5401 .05058 L
.54036 .05409 L
.54051 .05559 L
.54065 .05662 L
.5408 .05731 L
Mistroke
.54094 .05751 L
.54107 .0573 L
.54121 .05663 L
.54136 .05534 L
.54144 .05447 L
.54152 .05333 L
.54167 .0508 L
.54181 .04793 L
.54208 .04067 L
.54237 .03044 L
.54263 .01942 L
.54277 .01257 L
.5429 .01025 L
.54298 .0147 L
.54307 .0197 L
.54322 .02889 L
.54351 .04845 L
.54417 .09937 L
.54538 .2023 L
.54594 .24608 L
.54653 .28512 L
.54687 .3024 L
.54718 .31421 L
.54733 .31846 L
.54741 .3203 L
.5475 .32195 L
.54765 .32415 L
.54779 .32521 L
.54795 .32529 L
.54809 .32434 L
.54825 .32219 L
.54833 .32066 L
.54841 .31866 L
.54872 .30894 L
.549 .29625 L
.54964 .25539 L
.55033 .19761 L
.55157 .07881 L
.55191 .04763 L
.55209 .03147 L
.55218 .02385 L
.55227 .01707 L
.55241 .01044 L
.55257 .02226 L
.55291 .04469 L
.5532 .06081 L
.55351 .07448 L
.55368 .08068 L
.55384 .0852 L
.554 .08872 L
Mistroke
.55416 .0911 L
.5543 .09253 L
.55445 .09318 L
.55458 .09305 L
.55472 .09222 L
.55488 .09055 L
.55496 .08927 L
.55504 .08791 L
.55534 .08112 L
.55646 .03876 L
.55673 .02644 L
.55688 .01961 L
.55703 .01317 L
.55711 .00959 L
.55719 .01013 L
.55735 .01674 L
.55765 .02892 L
.55797 .0406 L
.55832 .05083 L
.55849 .05484 L
.55865 .05802 L
.55879 .06033 L
.55895 .06229 L
.5591 .06358 L
.55925 .06436 L
.5594 .06456 L
.55953 .06429 L
.55969 .06342 L
.55983 .06212 L
.56 .06006 L
.56015 .05757 L
.56132 .02714 L
.5616 .01792 L
.56175 .01303 L
.56191 .00796 L
.56199 .01066 L
.56208 .01358 L
.56224 .01858 L
.56255 .0278 L
.56311 .04121 L
.56327 .0442 L
.56342 .04661 L
.56356 .04845 L
.56371 .05002 L
.56383 .05105 L
.56397 .05183 L
.5641 .05221 L
.56422 .05228 L
.56436 .05202 L
.56449 .05145 L
Mistroke
.56464 .05042 L
.56478 .04908 L
.56593 .02721 L
.56627 .01859 L
.56643 .01423 L
.56658 .0102 L
.56672 .00933 L
.56686 .01314 L
.56717 .02084 L
.56768 .03213 L
.56796 .0371 L
.56823 .04082 L
.56838 .04245 L
.56846 .04317 L
.56854 .04383 L
.56869 .04471 L
.56883 .0452 L
.56896 .04538 L
.56909 .04528 L
.56923 .04485 L
.56939 .04404 L
.56954 .04288 L
.56968 .04153 L
.56999 .03756 L
.57054 .02767 L
.57086 .02103 L
.57102 .01733 L
.57119 .01334 L
.57135 .00982 L
.57143 .00804 L
.57151 .0099 L
.57181 .01652 L
.57211 .02287 L
.57244 .029 L
.57273 .03353 L
.57304 .03725 L
.57321 .03878 L
.5733 .03943 L
.57339 .04 L
.57348 .04041 L
.57356 .04068 L
.57364 .04085 L
.57373 .04094 L
.57388 .04083 L
.57403 .04043 L
.57418 .03965 L
.57427 .03906 L
.57435 .03844 L
.57548 .02238 L
.57575 .01703 L
Mistroke
.57604 .01102 L
.57613 .00923 L
.57621 .00832 L
.57636 .01148 L
.57666 .01747 L
.57729 .02823 L
.57764 .03281 L
.57781 .03452 L
.57797 .03582 L
.57811 .03675 L
.57827 .03744 L
.57842 .03778 L
.57855 .03786 L
.57869 .03769 L
.57885 .03719 L
.57893 .03682 L
.57902 .03634 L
.57917 .03525 L
.5804 .01828 L
.58074 .01205 L
.58082 .0105 L
.5809 .00883 L
.581 .00886 L
.58109 .01057 L
.58173 .02192 L
.58205 .02668 L
.58235 .03033 L
.58266 .03319 L
.58282 .03427 L
.58292 .03475 L
.583 .03509 L
.58315 .03549 L
.58329 .03563 L
.58344 .03551 L
.58351 .03535 L
.5836 .0351 L
.58374 .03449 L
.58389 .03358 L
.58416 .03132 L
.58447 .02789 L
.5848 .02339 L
.58538 .01376 L
.58556 .01072 L
.58565 .009 L
.58574 .00845 L
.58582 .00984 L
.58591 .01135 L
.58608 .01435 L
.58672 .02417 L
.58703 .02801 L
Mistroke
.58732 .03085 L
.58748 .03204 L
.58757 .03256 L
.58766 .03302 L
.58774 .03334 L
.58782 .03361 L
.58797 .0339 L
.58812 .03394 L
.58826 .03375 L
.58834 .03355 L
.58842 .03326 L
.58857 .03253 L
.58872 .03163 L
.58887 .03045 L
.58914 .02777 L
.58979 .01917 L
.59009 .0143 L
.59024 .01183 L
.59038 .00955 L
.59053 .00882 L
.59061 .0102 L
.59069 .01149 L
.59103 .01696 L
.59137 .02184 L
.59172 .02625 L
.59201 .02908 L
.59216 .03027 L
.59233 .0313 L
.59248 .032 L
.59261 .03243 L
.59275 .03265 L
.59289 .03268 L
.59304 .03248 L
.59312 .03226 L
.5932 .03199 L
.59335 .0313 L
.59349 .03043 L
.59381 .02781 L
.59415 .024 L
.5947 .01636 L
.59485 .01414 L
.59501 .01165 L
.59515 .00927 L
.59529 .00881 L
.59538 .01018 L
.59546 .01142 L
.59563 .01414 L
.59594 .01872 L
.59655 .02619 L
.59671 .0277 L
Mistroke
.59688 .02905 L
.59702 .03001 L
.59718 .03081 L
.59726 .03115 L
.59734 .0314 L
.5975 .03169 L
.59759 .03174 L
.59768 .03171 L
.59777 .0316 L
.59785 .03142 L
.598 .03093 L
.59814 .03027 L
.59829 .02935 L
.59845 .02812 L
.59909 .02131 L
.59964 .01339 L
.59981 .01094 L
.59996 .00859 L
.60009 .00938 L
.60024 .01164 L
.6009 .02092 L
.60121 .0246 L
.6015 .02738 L
.60167 .02859 L
.60181 .0295 L
.60197 .03026 L
.60206 .03057 L
.60215 .0308 L
.60223 .03094 L
.60232 .03103 L
.60247 .03098 L
.60257 .03083 L
.60266 .03061 L
.60274 .03034 L
.60283 .02998 L
.60298 .0292 L
.60314 .02812 L
.60347 .02526 L
.60405 .01829 L
.60436 .014 L
.60452 .01163 L
.6046 .01031 L
.60469 .00908 L
.60483 .00902 L
.60491 .01021 L
.605 .01147 L
.60529 .01566 L
.60582 .02259 L
.60611 .02554 L
.60641 .02801 L
Mistroke
.60659 .02912 L
.60676 .02986 L
.60684 .03012 L
.60693 .03033 L
.60709 .03053 L
.60716 .03053 L
.60725 .03047 L
.60734 .03033 L
.60742 .03013 L
.60757 .02961 L
.60773 .02882 L
.60788 .02783 L
.60805 .02652 L
.60836 .02356 L
.60894 .01643 L
.60922 .01244 L
.60937 .01028 L
.60952 .00798 L
.60966 .0099 L
.60981 .01209 L
.61007 .01582 L
.61041 .02024 L
.61073 .02385 L
.61104 .02669 L
.61132 .02861 L
.61147 .02932 L
.61163 .02985 L
.61178 .03015 L
.61187 .03021 L
.61196 .0302 L
.61204 .03012 L
.61213 .02997 L
.61228 .02951 L
.61237 .02916 L
.61245 .02877 L
.61263 .02766 L
.61294 .02515 L
.61322 .02225 L
.61353 .01862 L
.61385 .01417 L
.614 .01207 L
.61416 .00978 L
.61431 .00826 L
.61444 .01025 L
.61507 .01885 L
.61534 .02214 L
.61564 .02518 L
.61592 .02744 L
.61606 .0283 L
.61618 .02894 L
Mistroke
.61632 .02951 L
.61648 .0299 L
.61662 .03005 L
.61676 .03002 L
.61692 .02975 L
.61707 .02929 L
.61715 .02894 L
.61723 .02856 L
.6174 .02752 L
.61772 .02493 L
.61806 .02128 L
.61837 .01752 L
.61869 .01306 L
.61885 .01078 L
.619 .0086 L
.61914 .00924 L
.61928 .01137 L
.61984 .01894 L
.62015 .02267 L
.62049 .02594 L
.62078 .02804 L
.62094 .02892 L
.62109 .02952 L
.62124 .02989 L
.62133 .03001 L
.6214 .03006 L
.62156 .02998 L
.62165 .02983 L
.62173 .02963 L
.62188 .02911 L
.62203 .02834 L
.62232 .02639 L
.62265 .02329 L
.623 .0192 L
.62333 .01489 L
.62349 .01264 L
.62363 .0105 L
.62377 .00849 L
.62392 .00951 L
.624 .01073 L
.62408 .01187 L
.62423 .01397 L
.62477 .02109 L
.62506 .02422 L
.62536 .0269 L
.62551 .02801 L
.62569 .02898 L
.62584 .02963 L
.62599 .03002 L
.62613 .0302 L
Mistroke
.62628 .03019 L
.62642 .02998 L
.62655 .02962 L
.62667 .02915 L
.6268 .0285 L
.62706 .02671 L
.62734 .02415 L
.62765 .02075 L
.6282 .01338 L
.62835 .01122 L
.62849 .00915 L
.62857 .008 L
.62865 .0091 L
.6288 .01127 L
.62935 .01904 L
.62967 .0229 L
.63001 .02626 L
.6303 .02843 L
.63046 .02934 L
.63062 .02996 L
.63078 .03037 L
.63086 .03049 L
.63095 .03054 L
.6311 .03045 L
.63118 .0303 L
.63126 .0301 L
.6314 .02958 L
.63156 .02879 L
.63185 .02679 L
.63218 .0236 L
.63253 .0194 L
.63286 .01498 L
.63302 .01267 L
.63316 .01049 L
.6333 .00839 L
.63345 .0097 L
.6336 .01193 L
.63376 .01434 L
.63431 .02171 L
.63462 .02513 L
.63478 .02673 L
.63494 .02804 L
.63509 .02905 L
.63525 .02993 L
.6354 .03051 L
.63554 .03086 L
.63568 .03103 L
.63583 .03099 L
.63597 .03074 L
.6361 .03034 L
Mistroke
.63622 .02984 L
.63635 .02913 L
.63661 .02722 L
.63689 .02449 L
.6372 .02091 L
.63775 .01319 L
.63791 .01078 L
.63806 .00848 L
.63822 .0098 L
.6383 .01107 L
.63839 .01244 L
.63898 .02088 L
.63932 .02497 L
.6395 .02685 L
.63967 .02836 L
.63983 .02953 L
.63998 .03039 L
.64014 .0311 L
.64023 .03138 L
.64031 .03157 L
.64045 .03174 L
.64061 .03168 L
.64068 .03156 L
.64077 .03136 L
.64092 .03082 L
.64107 .03005 L
.64121 .02913 L
.64148 .02689 L
.64208 .01976 L
.6424 .01517 L
.64256 .01261 L
.64265 .01118 L
.64274 .00984 L
.64282 .00861 L
.6429 .00858 L
.64299 .01004 L
.64307 .01137 L
.64338 .01617 L
.64398 .02451 L
.64426 .02757 L
.64441 .02893 L
.64456 .03016 L
.6447 .03104 L
.64485 .0318 L
.64499 .0323 L
.64511 .03258 L
.64526 .0327 L
.64535 .03266 L
.64542 .03255 L
.64558 .03214 L
Mistroke
.64567 .03179 L
.64575 .03141 L
.64605 .02939 L
.64633 .02671 L
.64696 .0185 L
.64729 .01335 L
.64747 .01037 L
.64756 .00889 L
.64764 .00836 L
.64779 .01083 L
.64795 .0135 L
.64824 .01803 L
.64879 .02583 L
.64908 .02906 L
.6494 .03176 L
.64956 .03273 L
.64964 .03313 L
.64973 .03347 L
.64981 .03369 L
.6499 .03386 L
.65005 .03396 L
.65013 .0339 L
.65022 .03375 L
.6503 .03354 L
.65038 .03326 L
.65052 .03256 L
.65068 .03157 L
.651 .0287 L
.65136 .02443 L
.65166 .02009 L
.65199 .01477 L
.65214 .01221 L
.65222 .01077 L
.6523 .00941 L
.65245 .00911 L
.65258 .01152 L
.65317 .02143 L
.65348 .02598 L
.65381 .03 L
.65408 .03266 L
.65424 .03382 L
.65439 .03465 L
.65453 .03519 L
.65465 .0355 L
.65479 .03563 L
.65493 .03553 L
.65507 .03517 L
.65523 .0345 L
.65531 .03404 L
.6554 .03347 L
Mistroke
.65555 .03222 L
.65585 .02907 L
.65613 .02542 L
.65677 .01486 L
.65693 .012 L
.65701 .01041 L
.65709 .00889 L
.65719 .00878 L
.65727 .01043 L
.65744 .01363 L
.65805 .02436 L
.65862 .03226 L
.6589 .03506 L
.65906 .03624 L
.65921 .03704 L
.65929 .03738 L
.65937 .03761 L
.65945 .03778 L
.65954 .03786 L
.65963 .03784 L
.65971 .03773 L
.65986 .03731 L
.65999 .03671 L
.66013 .0358 L
.66042 .03323 L
.66068 .03002 L
.66093 .02638 L
.66122 .02143 L
.66153 .01556 L
.66166 .01302 L
.66179 .01024 L
.66194 .00872 L
.66208 .01164 L
.66269 .0237 L
.66303 .02957 L
.66335 .03425 L
.66365 .0376 L
.66382 .03901 L
.66397 .03999 L
.66412 .04059 L
.66425 .04089 L
.6644 .04092 L
.66454 .04064 L
.66467 .04014 L
.66482 .03931 L
.66496 .03815 L
.6651 .03679 L
.66562 .02964 L
.66591 .02431 L
.66622 .01789 L
Mistroke
.66649 .01199 L
.66664 .00852 L
.66678 .01063 L
.66693 .01413 L
.66707 .01731 L
.66739 .02424 L
.6677 .03059 L
.66804 .03656 L
.66834 .04069 L
.66849 .04224 L
.66862 .04344 L
.66878 .04446 L
.66892 .04507 L
.66907 .04537 L
.66916 .04537 L
.66924 .04527 L
.66936 .04489 L
.6695 .04417 L
.66963 .04321 L
.66975 .0421 L
.67004 .03847 L
.67032 .0339 L
.67091 .02114 L
.67106 .01763 L
.67121 .01381 L
.67133 .01047 L
.67147 .00912 L
.67162 .01316 L
.67176 .01693 L
.67208 .02518 L
.67263 .03803 L
.67294 .04378 L
.67323 .048 L
.67339 .04976 L
.67347 .0505 L
.67356 .05116 L
.67372 .05195 L
.67386 .05227 L
.674 .0522 L
.67413 .05182 L
.67426 .05105 L
.67441 .04984 L
.67453 .04847 L
.67465 .04692 L
.67492 .04249 L
.67548 .02942 L
.67577 .02124 L
.67593 .01625 L
.67608 .01143 L
.67623 .00933 L
Mistroke
.67632 .0121 L
.6764 .01464 L
.67673 .02548 L
.67732 .04343 L
.67765 .05169 L
.67782 .05537 L
.67801 .05867 L
.67818 .0612 L
.67835 .06291 L
.67842 .06352 L
.67851 .06403 L
.67866 .06452 L
.67881 .06445 L
.67895 .06387 L
.67911 .06265 L
.6792 .0617 L
.67928 .06068 L
.67961 .05467 L
.67993 .0466 L
.68022 .03738 L
.68053 .0258 L
.68068 .01969 L
.68082 .01364 L
.68095 .00804 L
.68109 .01407 L
.68165 .03926 L
.68226 .06489 L
.68257 .07569 L
.68274 .08072 L
.6829 .08478 L
.68305 .08791 L
.68313 .08928 L
.68321 .09052 L
.68336 .09216 L
.6835 .093 L
.68364 .09318 L
.68376 .09273 L
.68391 .09146 L
.68405 .0895 L
.68417 .08703 L
.68429 .08417 L
.68456 .07566 L
.68483 .06427 L
.68512 .04851 L
.68541 .03028 L
.68556 .01953 L
.68564 .01333 L
.68572 .00858 L
.6858 .01468 L
.68588 .02148 L
Mistroke
.68603 .03377 L
.68632 .05913 L
.68694 .11858 L
.68806 .22351 L
.68869 .27232 L
.68901 .29177 L
.6892 .30111 L
.68936 .30838 L
.68951 .3136 L
.68966 .31823 L
.68975 .32028 L
.68983 .32188 L
.68999 .32416 L
.69014 .32524 L
.69027 .32533 L
.69042 .32437 L
.69057 .32246 L
.69071 .31969 L
.69086 .31575 L
.69113 .3062 L
.69146 .29101 L
.69175 .27393 L
.693 .17821 L
.69408 .08672 L
.69467 .04263 L
.69496 .02387 L
.69509 .01634 L
.69523 .00861 L
.69536 .01421 L
.6955 .02096 L
.6958 .03326 L
.69612 .04382 L
.69628 .04776 L
.69642 .05084 L
.69656 .05313 L
.6967 .05505 L
.69684 .0563 L
.69696 .05706 L
.69709 .05746 L
.69724 .05744 L
.69739 .05692 L
.69753 .05601 L
.69769 .05458 L
.69786 .05256 L
.69816 .04781 L
.69874 .03624 L
.69941 .02092 L
.69974 .01354 L
.69988 .01044 L
.70004 .00868 L
Mistroke
.70017 .01139 L
.7003 .01379 L
.70058 .01857 L
.70088 .02295 L
.70117 .02627 L
.70132 .0277 L
.70148 .02899 L
.70162 .02985 L
.70177 .03057 L
.70186 .03088 L
.70194 .0311 L
.70202 .03127 L
.70211 .03137 L
.70219 .03141 L
.70227 .03138 L
.70242 .03117 L
.70258 .03073 L
.70272 .03014 L
.70289 .02926 L
.70305 .02823 L
.70363 .02297 L
.70426 .01519 L
.70443 .01277 L
.70453 .01141 L
.70462 .01009 L
.7047 .00885 L
.70479 .00837 L
.70495 .01079 L
.70613 .02815 L
.70644 .03193 L
.70678 .03518 L
.70691 .03624 L
.70706 .03717 L
.70714 .0376 L
.70722 .03792 L
.70737 .03835 L
.7075 .03848 L
.70764 .03839 L
.70777 .03805 L
.70789 .03753 L
.70803 .03665 L
.70818 .03536 L
.70846 .03208 L
.70875 .02733 L
.70905 .02083 L
.70932 .01405 L
.70946 .00975 L
.7096 .01038 L
.70975 .01528 L
.70991 .02082 L
Mistroke
.7102 .03178 L
.71074 .05452 L
.71196 .10886 L
.71256 .13234 L
.71285 .14213 L
.71312 .14984 L
.71336 .15557 L
.71363 .16047 L
.71377 .16242 L
.71389 .16385 L
.71403 .16495 L
.71417 .16566 L
.71432 .16587 L
.7144 .16577 L
.71448 .16551 L
.71464 .16456 L
.71473 .16377 L
.71481 .16288 L
.71512 .15827 L
.7154 .15206 L
.71604 .13268 L
.71674 .10487 L
.7174 .07549 L
.71801 .04778 L
.71857 .02493 L
.71872 .01922 L
.71888 .0135 L
.71902 .00888 L
.71917 .01174 L
.71976 .02707 L
.72009 .03316 L
.72025 .0354 L
.72039 .03711 L
.72053 .03838 L
.72068 .03944 L
.72083 .04017 L
.72098 .04057 L
.72112 .04063 L
.72127 .04039 L
.72141 .0399 L
.72154 .03923 L
.72169 .03822 L
.72184 .03689 L
.72213 .03389 L
.72277 .02493 L
.7231 .01965 L
.72345 .01389 L
.72359 .01152 L
.72374 .00901 L
.72383 .00827 L
Mistroke
.72391 .00955 L
.72407 .012 L
.72466 .02017 L
.72497 .02366 L
.7253 .0266 L
.72549 .02788 L
.72566 .02879 L
.72574 .02914 L
.72583 .02946 L
.72591 .0297 L
.72599 .02986 L
.72614 .03003 L
.72623 .03004 L
.72631 .02999 L
.72639 .02987 L
.72647 .02971 L
.72656 .02946 L
.72664 .02916 L
.72678 .02853 L
.72694 .02764 L
.72725 .02525 L
.72781 .01915 L
.72812 .01486 L
.72829 .01242 L
.72838 .01104 L
.72846 .00973 L
.72861 .00858 L
.72869 .0099 L
.72878 .01132 L
.72907 .0162 L
.72967 .02597 L
.73031 .03462 L
.73064 .03788 L
.73073 .03858 L
.73083 .03923 L
.73091 .0397 L
.73101 .04011 L
.7311 .04041 L
.73118 .0406 L
.73126 .04068 L
.73134 .04068 L
.73149 .04043 L
.73157 .04015 L
.73165 .03979 L
.73179 .03889 L
.73195 .03754 L
.73211 .03571 L
.73226 .03362 L
.73253 .02892 L
.73282 .02255 L
Mistroke
.73298 .01837 L
.73316 .01336 L
.73324 .01091 L
.73332 .0082 L
.73348 .01278 L
.73408 .03555 L
.7353 .0896 L
.7359 .11561 L
.73646 .13659 L
.73697 .15145 L
.73725 .15766 L
.73751 .16184 L
.73765 .16359 L
.73779 .16477 L
.73794 .16557 L
.73809 .16587 L
.73823 .16567 L
.73835 .16508 L
.73849 .16402 L
.73864 .16238 L
.7388 .16013 L
.73894 .15757 L
.73927 .15018 L
.73987 .13168 L
.74098 .08527 L
.74221 .03167 L
.7425 .02022 L
.74266 .01462 L
.74274 .0117 L
.74282 .00907 L
.74291 .0096 L
.74301 .01255 L
.74317 .01739 L
.7435 .02559 L
.74382 .03181 L
.74411 .03607 L
.74426 .03773 L
.74443 .03912 L
.74452 .03965 L
.74461 .0401 L
.74469 .04041 L
.74477 .04059 L
.74492 .04069 L
.74507 .04049 L
.74522 .03996 L
.74531 .03953 L
.74539 .03907 L
.74569 .03666 L
.74597 .03358 L
.74705 .01739 L
Mistroke
.74734 .01246 L
.74742 .01117 L
.7475 .0098 L
.74765 .0085 L
.74779 .0107 L
.74792 .01265 L
.74821 .01686 L
.74879 .02382 L
.74909 .02644 L
.74926 .02764 L
.74941 .02853 L
.74955 .02914 L
.74969 .02962 L
.74983 .02992 L
.74998 .03004 L
.75012 .02998 L
.75026 .02974 L
.7504 .02935 L
.75052 .02885 L
.75068 .02803 L
.75085 .02691 L
.75115 .02432 L
.75147 .02088 L
.75182 .01635 L
.75198 .01415 L
.75215 .01163 L
.7523 .00916 L
.75245 .00906 L
.75258 .01122 L
.75273 .01363 L
.75302 .01855 L
.7536 .02767 L
.7539 .03189 L
.75422 .03564 L
.7545 .03819 L
.75466 .03927 L
.75481 .04001 L
.75494 .04044 L
.75506 .04063 L
.75521 .04057 L
.75534 .04025 L
.7555 .03954 L
.75565 .03851 L
.75582 .03689 L
.75597 .03499 L
.75625 .03053 L
.75656 .02415 L
.75686 .01651 L
.75694 .01426 L
.75702 .01172 L
Mistroke
.75718 .00901 L
.75727 .01221 L
.75736 .01527 L
.75753 .02133 L
.75785 .03409 L
.75903 .08599 L
.75967 .11402 L
.76026 .13669 L
.76078 .15178 L
.76106 .15804 L
.76132 .16221 L
.76147 .1639 L
.76161 .165 L
.76176 .1657 L
.76184 .16585 L
.76192 .16586 L
.76206 .1655 L
.76221 .16458 L
.76236 .16323 L
.76249 .16159 L
.76279 .15638 L
.76306 .15002 L
.76367 .13082 L
.76477 .08489 L
.76539 .0572 L
.76606 .0293 L
.76636 .01796 L
.76644 .01516 L
.76653 .01225 L
.76669 .00859 L
.76683 .01287 L
.76697 .01651 L
.76727 .02383 L
.76757 .02964 L
.76785 .0336 L
.768 .03528 L
.76816 .03669 L
.76832 .03763 L
.76846 .03819 L
.76859 .03845 L
.76872 .03847 L
.76885 .03827 L
.769 .03781 L
.76915 .03705 L
.7693 .03612 L
.76957 .03382 L
.77078 .01784 L
.77108 .01332 L
.77124 .01082 L
.77139 .00847 L
Mistroke
.77148 .00869 L
.77157 .0101 L
.77174 .01252 L
.77207 .01701 L
.77267 .02412 L
.77301 .02721 L
.77317 .02841 L
.77332 .02935 L
.77345 .03007 L
.7736 .03069 L
.77375 .03113 L
.77391 .03137 L
.77405 .03139 L
.7742 .03121 L
.77435 .03084 L
.77448 .03032 L
.77474 .02873 L
.77489 .02751 L
.77503 .02618 L
.77555 .01945 L
.77581 .01515 L
.77595 .01264 L
.7761 .0098 L
.77625 .00915 L
.77639 .01215 L
.7767 .01902 L
.77733 .03343 L
.77789 .04539 L
.77817 .05012 L
.77831 .05223 L
.77846 .05413 L
.7786 .05548 L
.77874 .05659 L
.77888 .05723 L
.779 .0575 L
.77915 .05734 L
.77924 .057 L
.77932 .05652 L
.77947 .0552 L
.77963 .05315 L
.77979 .05047 L
.77993 .04731 L
.78021 .03975 L
.78053 .02791 L
.78069 .02118 L
.78083 .01427 L
.78099 .00975 L
.78107 .01435 L
.78116 .01949 L
.7815 .04147 L
Mistroke
.7839 .23579 L
.78455 .28078 L
.78488 .2985 L
.78507 .30686 L
.78525 .31323 L
.7854 .31764 L
.78556 .32135 L
.78564 .32282 L
.78572 .32389 L
.7858 .32471 L
.78589 .32524 L
.78597 .3254 L
.78606 .32524 L
.78621 .3241 L
.78636 .32191 L
.7865 .31897 L
.78664 .31492 L
.78677 .31038 L
.78707 .29735 L
.78761 .2647 L
.78883 .15914 L
.78944 .10001 L
.78976 .06952 L
.7901 .03872 L
.79025 .02651 L
.7904 .0139 L
.79049 .0089 L
.79057 .01507 L
.79073 .02662 L
.79103 .04638 L
.79131 .06152 L
.79158 .07371 L
.79188 .0836 L
.79204 .08755 L
.79219 .09026 L
.79233 .09202 L
.79249 .09302 L
.79262 .09319 L
.79276 .09268 L
.79289 .09157 L
.79301 .09004 L
.79315 .08767 L
.79331 .08439 L
.79359 .07676 L
.79421 .05367 L
.79456 .03872 L
.79488 .02405 L
.79503 .01737 L
.79518 .01039 L
.79526 .00906 L
Mistroke
.79535 .01294 L
.79551 .01958 L
.79608 .04096 L
.79638 .04992 L
.79654 .05385 L
.79671 .05738 L
.79686 .0599 L
.79702 .06206 L
.79717 .06344 L
.79731 .06424 L
.79745 .06455 L
.79759 .06439 L
.79772 .06384 L
.79785 .06284 L
.798 .06129 L
.79815 .05913 L
.79843 .05402 L
.79911 .03643 L
.79945 .02599 L
.79976 .01592 L
.7999 .01116 L
.80004 .00912 L
.80018 .01365 L
.80033 .0185 L
.80066 .028 L
.80096 .03575 L
.80127 .04251 L
.80156 .0472 L
.80172 .04922 L
.80188 .05067 L
.80196 .05127 L
.80204 .0517 L
.80212 .05204 L
.80221 .05224 L
.80236 .05224 L
.80251 .05182 L
.80265 .05102 L
.80278 .04997 L
.80294 .04835 L
.8031 .04616 L
.8034 .04109 L
.80397 .02871 L
.80428 .02085 L
.80443 .01685 L
.80457 .01315 L
.80469 .00977 L
.80481 .0093 L
.80494 .01263 L
.80508 .01621 L
.80564 .02943 L
Mistroke
.80595 .03532 L
.80611 .03794 L
.80628 .04031 L
.80643 .04203 L
.80659 .04352 L
.80674 .0445 L
.80688 .04509 L
.80703 .04537 L
.80717 .04531 L
.80729 .04499 L
.80743 .04437 L
.80757 .04338 L
.80773 .04196 L
.80801 .03857 L
.80831 .0339 L
.80863 .02784 L
.80921 .01511 L
.8093 .01317 L
.80939 .01108 L
.80947 .00911 L
.80955 .00854 L
.80964 .01054 L
.80972 .01242 L
.80991 .01656 L
.81054 .02911 L
.81081 .03332 L
.8111 .0369 L
.81126 .03847 L
.81141 .03957 L
.81157 .04036 L
.81171 .0408 L
.81186 .04094 L
.81202 .04074 L
.81217 .04023 L
.8123 .03949 L
.81246 .03831 L
.81264 .03666 L
.81295 .03277 L
.81352 .02342 L
.81382 .01743 L
.81397 .01437 L
.81411 .01155 L
.81424 .00894 L
.81436 .00939 L
.81448 .01196 L
.81462 .01472 L
.81518 .02499 L
.81546 .02932 L
.81576 .0331 L
.8159 .0345 L
Mistroke
.81605 .03572 L
.81617 .03655 L
.81631 .03723 L
.8164 .03753 L
.81648 .03772 L
.81663 .03786 L
.81671 .03782 L
.81679 .03769 L
.81687 .03747 L
.81696 .03714 L
.81711 .03636 L
.81725 .03539 L
.81756 .03237 L
.81789 .02816 L
.8182 .02333 L
.81849 .01843 L
.81879 .01288 L
.81887 .01121 L
.81896 .00964 L
.81911 .00916 L
.81926 .01189 L
.81941 .01477 L
.81974 .02054 L
.8201 .02598 L
.82041 .02994 L
.82069 .0327 L
.82083 .03373 L
.82098 .03459 L
.82112 .03517 L
.82125 .0355 L
.8214 .03563 L
.82154 .0355 L
.8217 .03509 L
.82178 .03473 L
.82186 .03433 L
.82202 .03332 L
.82219 .0319 L
.82251 .02854 L
.82315 .01934 L
.8235 .0134 L
.82367 .01038 L
.82383 .00828 L
.82398 .01092 L
.82414 .01366 L
.82447 .01917 L
.82505 .02723 L
.82536 .03037 L
.82551 .03158 L
.82565 .03248 L
.82578 .03312 L
Mistroke
.82591 .0336 L
.82605 .03388 L
.8262 .03395 L
.82636 .03375 L
.8265 .03332 L
.82658 .033 L
.82666 .03258 L
.82683 .03151 L
.82714 .02883 L
.82742 .02558 L
.82797 .01776 L
.82824 .01342 L
.82836 .01146 L
.82849 .00928 L
.82863 .00891 L
.82878 .01137 L
.82909 .01638 L
.82963 .02409 L
.82993 .0275 L
.83009 .02898 L
.83026 .03031 L
.83042 .03132 L
.83057 .032 L
.83072 .03245 L
.83086 .03267 L
.83099 .03267 L
.83114 .03246 L
.83126 .03211 L
.8314 .03154 L
.83154 .03072 L
.8317 .02961 L
.83198 .02706 L
.83266 .01848 L
.83299 .01341 L
.83314 .0111 L
.83321 .00986 L
.8333 .00852 L
.83344 .00965 L
.83358 .01179 L
.83387 .01634 L
.83417 .02063 L
.8345 .02463 L
.83481 .02778 L
.8351 .0299 L
.83524 .03064 L
.83538 .03124 L
.83553 .03159 L
.83565 .03173 L
.83581 .03168 L
.83595 .03142 L
Mistroke
.8361 .0309 L
.83619 .0305 L
.83627 .03008 L
.8366 .02764 L
.83692 .02447 L
.83751 .01679 L
.83783 .01196 L
.83799 .00952 L
.83814 .00859 L
.8383 .01101 L
.83847 .01358 L
.83883 .01876 L
.83916 .02299 L
.83947 .02619 L
.83961 .02743 L
.83976 .02858 L
.83989 .0294 L
.84004 .03012 L
.84019 .03066 L
.84027 .03086 L
.84035 .03098 L
.84049 .03103 L
.84065 .03087 L
.84079 .03052 L
.84094 .02991 L
.84108 .02913 L
.84122 .02824 L
.84174 .02331 L
.84237 .01521 L
.84252 .01305 L
.84267 .01072 L
.84281 .00871 L
.84295 .00937 L
.84303 .01058 L
.84312 .01187 L
.84328 .01416 L
.84363 .01901 L
.84392 .02258 L
.84424 .02588 L
.84455 .0283 L
.84472 .02927 L
.84488 .02993 L
.84503 .03034 L
.84516 .03052 L
.84531 .03051 L
.84547 .03026 L
.84555 .03003 L
.84563 .02976 L
.8458 .02897 L
.84596 .02799 L
Mistroke
.84611 .02688 L
.8468 .01946 L
.8471 .01551 L
.84726 .01322 L
.84741 .01103 L
.84754 .00914 L
.84768 .00876 L
.84783 .01101 L
.84797 .01304 L
.84858 .02117 L
.84891 .02479 L
.84908 .02627 L
.84923 .02744 L
.84937 .02837 L
.84953 .02918 L
.84969 .02977 L
.84978 .02999 L
.84986 .03012 L
.85 .03022 L
.85013 .03013 L
.85028 .02983 L
.85042 .02934 L
.85056 .02872 L
.8507 .02787 L
.85095 .02594 L
.85153 .01981 L
.85182 .01594 L
.85199 .01366 L
.85214 .01144 L
.85228 .00935 L
.85244 .00881 L
.85258 .01089 L
.85272 .0128 L
.85335 .02111 L
.85368 .02465 L
.85386 .02626 L
.85403 .02753 L
.85419 .02853 L
.85434 .02923 L
.85443 .02954 L
.85451 .02976 L
.8546 .02993 L
.85469 .03004 L
.85484 .03003 L
.85492 .02994 L
.85501 .02977 L
.85516 .0293 L
.8553 .02867 L
.85545 .02783 L
.8556 .02674 L
Mistroke
.85588 .02431 L
.8565 .01701 L
.85677 .01332 L
.85692 .01122 L
.85706 .0092 L
.85719 .00856 L
.85733 .01061 L
.85757 .01412 L
.85818 .02189 L
.85847 .02496 L
.85874 .02719 L
.85888 .02809 L
.85903 .02888 L
.85917 .02944 L
.85929 .02981 L
.85944 .03003 L
.85958 .03005 L
.85974 .02985 L
.85989 .02944 L
.86004 .02881 L
.8602 .02791 L
.86049 .02574 L
.8608 .02269 L
.86114 .01864 L
.86147 .01426 L
.86163 .01198 L
.86177 .00983 L
.86186 .00863 L
.86194 .00852 L
.86203 .0098 L
.86213 .01122 L
.86245 .0158 L
.86305 .02318 L
.86335 .02607 L
.86352 .02742 L
.86368 .02843 L
.86384 .02922 L
.86398 .02976 L
.86414 .03011 L
.86423 .0302 L
.86431 .03022 L
.86445 .0301 L
.8646 .02977 L
.86475 .0292 L
.8649 .02846 L
.86518 .0265 L
.86544 .02414 L
.86601 .01727 L
.86631 .01309 L
.86648 .01071 L
Mistroke
.86663 .00843 L
.86671 .00861 L
.8668 .00989 L
.86698 .01257 L
.86731 .01713 L
.86762 .02113 L
.86794 .02475 L
.86822 .02723 L
.86838 .02836 L
.86853 .0292 L
.86868 .02984 L
.86884 .0303 L
.86899 .03052 L
.86908 .03054 L
.86917 .03048 L
.86932 .0302 L
.86946 .02976 L
.86953 .02943 L
.86962 .02902 L
.86977 .02809 L
.87005 .02585 L
.87035 .02276 L
.87089 .01583 L
.87122 .01106 L
.87131 .00972 L
.8714 .0083 L
.87149 .00879 L
.87157 .01012 L
.87222 .01932 L
.87252 .02302 L
.87284 .02635 L
.87299 .02768 L
.87314 .02875 L
.87329 .02961 L
.87342 .03022 L
.87355 .03068 L
.8737 .03097 L
.87383 .03104 L
.87397 .03093 L
.87412 .03059 L
.87426 .03007 L
.87442 .02928 L
.87458 .02819 L
.87492 .02526 L
.87523 .02172 L
.87552 .01797 L
.87582 .0136 L
.87595 .01168 L
.87608 .00959 L
.87623 .00859 L
Mistroke
.87637 .01076 L
.87689 .01834 L
.87719 .02244 L
.87749 .02579 L
.87775 .02825 L
.87789 .0293 L
.87804 .03021 L
.87812 .03061 L
.8782 .03099 L
.87835 .03146 L
.87851 .03171 L
.87865 .03172 L
.87879 .03154 L
.87892 .03119 L
.87906 .03059 L
.8792 .02982 L
.87951 .02748 L
.87979 .02458 L
.88043 .01602 L
.88068 .01224 L
.88081 .01019 L
.88095 .00802 L
.8811 .01027 L
.88124 .01249 L
.88151 .01671 L
.8821 .02474 L
.88239 .02786 L
.88265 .03011 L
.88279 .03103 L
.88294 .0318 L
.88309 .03233 L
.88318 .03253 L
.88326 .03265 L
.8834 .03269 L
.88352 .03254 L
.88367 .03216 L
.88381 .03159 L
.88396 .03076 L
.88411 .02964 L
.8844 .02703 L
.88504 .01877 L
.8853 .01473 L
.88544 .01251 L
.88558 .01012 L
.88571 .008 L
.88585 .01018 L
.88609 .01423 L
.88665 .02277 L
.88695 .02657 L
.88726 .02986 L
Mistroke
.88741 .03119 L
.88759 .03236 L
.88775 .03316 L
.88789 .03366 L
.88804 .03392 L
.88818 .03394 L
.88826 .03385 L
.88834 .03368 L
.88849 .03318 L
.88864 .03244 L
.88878 .03156 L
.88908 .02892 L
.88936 .02572 L
.88962 .02213 L
.88993 .01737 L
.89009 .01457 L
.89025 .01188 L
.89039 .00953 L
.89053 .00886 L
.89069 .01167 L
.89083 .01421 L
.89147 .02448 L
.89182 .02905 L
.89199 .03091 L
.89215 .03237 L
.89228 .0334 L
.89242 .03431 L
.89256 .03499 L
.89271 .03544 L
.89287 .03563 L
.89296 .0356 L
.89304 .03549 L
.8932 .03507 L
.89334 .0344 L
.89348 .03357 L
.89362 .03247 L
.89387 .02996 L
.89445 .02204 L
.89475 .01702 L
.89491 .01406 L
.89507 .01118 L
.89521 .00847 L
.89537 .01037 L
.89551 .01307 L
.89564 .01555 L
.89627 .02636 L
.8966 .03097 L
.89679 .03306 L
.89695 .03469 L
.89712 .03599 L
Mistroke
.89727 .03689 L
.89736 .03727 L
.89744 .03755 L
.89753 .03775 L
.89762 .03785 L
.89778 .03778 L
.89785 .03762 L
.89794 .03736 L
.89809 .03666 L
.89823 .03575 L
.89854 .03297 L
.89881 .02953 L
.89944 .0192 L
.8997 .01401 L
.89985 .01105 L
.89999 .00821 L
.90006 .00927 L
.90015 .01103 L
.9003 .01409 L
.90059 .01991 L
.90112 .02946 L
.90141 .03376 L
.90168 .03701 L
.90183 .03839 L
.90199 .03956 L
.90214 .04032 L
.90227 .04076 L
.9024 .04094 L
.90254 .04086 L
.90269 .04047 L
.90283 .03983 L
.90298 .0388 L
.90314 .03736 L
.90343 .03393 L
.90375 .02912 L
.90409 .02276 L
.90441 .01584 L
.90457 .01224 L
.90472 .00885 L
.90481 .00893 L
.90489 .01096 L
.90508 .01524 L
.9054 .02252 L
.90573 .02934 L
.90604 .03501 L
.90634 .03953 L
.90649 .0413 L
.90663 .04266 L
.90675 .04369 L
.90689 .04455 L
Mistroke
.90703 .04513 L
.90717 .04537 L
.90732 .04529 L
.90748 .0448 L
.90762 .04406 L
.90776 .04291 L
.90792 .04128 L
.90807 .03946 L
.9084 .03428 L
.90899 .02171 L
.90925 .01512 L
.90939 .01136 L
.90953 .0081 L
.90968 .01201 L
.90984 .01632 L
.91012 .02379 L
.91068 .03702 L
.91095 .04234 L
.91119 .04632 L
.91133 .04807 L
.91147 .04964 L
.91162 .05092 L
.91176 .05175 L
.91192 .05223 L
.912 .05229 L
.91209 .05222 L
.91224 .05174 L
.91238 .05087 L
.91246 .05024 L
.91254 .04943 L
.9127 .0476 L
.91299 .04301 L
.91332 .03591 L
.91363 .02789 L
.91388 .02072 L
.91415 .01241 L
.9143 .00839 L
.91444 .01298 L
.91472 .02203 L
.91532 .04072 L
.91587 .05433 L
.91601 .05704 L
.91616 .05955 L
.91629 .06134 L
.91644 .06287 L
.91659 .06397 L
.91667 .06433 L
.91675 .06452 L
.91689 .06448 L
.91705 .06389 L
Mistroke
.91719 .06282 L
.91734 .0611 L
.91749 .05893 L
.91762 .05647 L
.91814 .04288 L
.91847 .03163 L
.91878 .01948 L
.91891 .01381 L
.91905 .00823 L
.91921 .01516 L
.91935 .02163 L
.92003 .05168 L
.92032 .06358 L
.92064 .07488 L
.92095 .08354 L
.92108 .08657 L
.92123 .0893 L
.92137 .09123 L
.9215 .09247 L
.92164 .09313 L
.92178 .09307 L
.92193 .09219 L
.92202 .09131 L
.9221 .09025 L
.92225 .08737 L
.92242 .08319 L
.92273 .07269 L
.92301 .05996 L
.92356 .02674 L
.92371 .01589 L
.92386 .01217 L
.924 .02313 L
.92415 .03571 L
.92522 .13678 L
.9258 .19194 L
.92643 .24605 L
.92671 .2673 L
.92702 .28679 L
.92728 .3007 L
.92757 .31241 L
.92775 .31806 L
.92783 .32004 L
.92792 .32186 L
.928 .32315 L
.92809 .32421 L
.92818 .32497 L
.92826 .32533 L
.92834 .32538 L
.92843 .32508 L
.92859 .32362 L
Mistroke
.92874 .32108 L
.92888 .31777 L
.92916 .30882 L
.92947 .2953 L
.93009 .25791 L
.93129 .16143 L
.93243 .067 L
.93273 .04501 L
.93305 .02389 L
.93315 .01815 L
.93324 .01296 L
.93332 .0085 L
.93341 .01199 L
.93374 .02736 L
.93405 .03868 L
.93421 .0437 L
.93437 .04765 L
.93451 .05069 L
.93464 .05295 L
.93479 .05491 L
.93494 .05639 L
.93509 .05719 L
.93522 .0575 L
.93537 .05737 L
.93552 .05671 L
.93568 .05557 L
.93584 .05389 L
.93614 .04981 L
.93667 .03989 L
.93724 .02692 L
.93757 .01948 L
.93787 .01267 L
.93795 .01091 L
.93804 .00909 L
.93813 .00872 L
.93822 .01047 L
.93854 .01634 L
.93882 .02073 L
.93912 .02465 L
.93929 .0265 L
.93944 .02793 L
.9396 .02912 L
.93975 .03001 L
.93989 .03067 L
.94005 .03114 L
.94019 .03136 L
.94032 .0314 L
.94047 .03126 L
.94062 .03089 L
.9407 .03063 L
Mistroke
.94078 .03029 L
.94094 .02953 L
.94123 .02755 L
.94151 .02511 L
.94204 .0193 L
.94234 .01536 L
.94251 .01305 L
.94266 .01082 L
.94279 .00887 L
.94294 .00912 L
.94309 .01152 L
.94324 .01374 L
.94387 .02324 L
.94421 .02801 L
.94454 .03196 L
.94484 .03491 L
.945 .03615 L
.94516 .0372 L
.9453 .03786 L
.94545 .03832 L
.94559 .03848 L
.94572 .03841 L
.94587 .03805 L
.946 .03745 L
.94612 .03668 L
.94626 .03558 L
.94655 .03213 L
.94683 .02767 L
.94712 .02147 L
.9474 .01436 L
.94756 .00975 L
.94771 .01067 L
.94778 .01318 L
.94787 .01602 L
.94804 .02203 L
.94932 .07629 L
.9499 .10225 L
.95054 .12797 L
.95083 .13817 L
.95113 .14753 L
.9514 .15423 L
.95168 .15983 L
.95185 .16233 L
.95201 .16404 L
.95216 .1652 L
.95231 .16578 L
.9524 .16588 L
.95248 .1658 L
.95264 .16519 L
.95274 .16452 L
Mistroke
.95283 .16369 L
.95301 .16162 L
.95315 .15933 L
.95331 .1564 L
.95358 .14992 L
.95421 .13013 L
.95535 .08186 L
.95598 .05341 L
.95658 .02832 L
.95685 .01814 L
.95699 .01294 L
.95713 .00832 L
.95728 .01221 L
.95744 .01698 L
.95773 .02436 L
.95798 .02957 L
.95824 .03396 L
.95838 .03581 L
.95853 .03748 L
.95866 .03868 L
.95879 .03954 L
.95894 .04025 L
.95902 .04047 L
.9591 .0406 L
.95926 .04059 L
.9594 .0403 L
.95948 .04 L
.95956 .03962 L
.95972 .03871 L
.95988 .03744 L
.96006 .03574 L
.96068 .02778 L
.96126 .01865 L
.96155 .01377 L
.96169 .01138 L
.96183 .00922 L
.96195 .00859 L
.96207 .0106 L
.96234 .01463 L
.96265 .01888 L
.96295 .02239 L
.96323 .02524 L
.9635 .02732 L
.96363 .02817 L
.96376 .02883 L
.9639 .02937 L
.96405 .02979 L
.9642 .03001 L
.96433 .03003 L
.96448 .02987 L
Mistroke
.96464 .02949 L
.96479 .02894 L
.96495 .02814 L
.96523 .0262 L
.96557 .02307 L
.96587 .01954 L
.96614 .016 L
.96642 .01186 L
.96656 .00957 L
.96665 .00824 L
.96673 .00888 L
.96686 .01113 L
.96701 .01357 L
.96808 .03057 L
.96839 .03447 L
.96856 .03628 L
.96872 .03774 L
.96886 .03884 L
.969 .03965 L
.96915 .04028 L
.96923 .0405 L
.96931 .04064 L
.96947 .04065 L
.96956 .0405 L
.96964 .04026 L
.9698 .0395 L
.96994 .03842 L
.97012 .03672 L
.97028 .0347 L
.97064 .02858 L
.97093 .02212 L
.9712 .01486 L
.97136 .01019 L
.9715 .01026 L
.97158 .0129 L
.97166 .01588 L
.97182 .02155 L
.97307 .07467 L
.97385 .10923 L
.97458 .13728 L
.97499 .14946 L
.9752 .15464 L
.97542 .15911 L
.97561 .16203 L
.97572 .16325 L
.97582 .1643 L
.97592 .16504 L
.97601 .1655 L
.9761 .16578 L
.97619 .16587 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 168},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000Z2000`400?l00000o`00003ooooooooi
ooooo`00:_ooool5o`0000?ooooo0_l0001Tooooo`?o00001?ooool2o`0006Gooooo0_l0001Voooo
o`?o00001?ooool2o`0006?ooooo1Ol00003ooooo`;o00005?ooool002_ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0001Tooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000Hoooool01?l0003oooooooooool0001Vooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000Hoooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001?ooooo000Tooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0005cooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000Hooo
ool01?l0003oooooooooool0001Vooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000I?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001?ooooo000]ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000Hoooool01?l0003oooooooooool0001Vooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000IOooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool04Oooool002[ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0006Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0001S
ooooo`04o`000?ooooooooooo`0006Kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0001Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Coooo
o`00:_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000Hoooool2
o`0000Cooooo00Co0000oooooooooooo0000Hoooool01?l0003oooooooooool0001Uooooo`;o0000
1?ooool01?l0003oooooooooool0001Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`00:oooool3o`0000Cooooo0_l0001Uooooo`03o`000?oooooooooo
00?ooooo0_l0001Uooooo`;o0000Ioooool00ol0003oooooooooo`03ooooo`;o0000I?ooool3o`00
00Cooooo0_l0000Dooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`008oooooooo`000<[o00003?oo
ool001Wooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0
01Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo000Hooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0JOooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0
01Sooooo00Co0000oooooooooooo00001oooool3o`0000cooooo00Goo`00oooooooo003oooooool0
0006ooooo`05ool00?ooooooo`00oooooooo00000oooool03_oo003ooooooooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool02ooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`0000;ooooo00_oo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00002ooooo`09ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
00;ooooo00Ooo`00oooooooo003oooooool00?ooooooo`0000Kooooo00Ooo`00oooooooo003ooooo
ool00?ooooooo`0000?ooooo00Soo`00ooooooooooooo`00oooooooo003oooooool000Gooooo00Ko
o`00ooooooooooooo`00oooooooo0003ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`02ooooo`0;ool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo00000_ooool02ooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`0000;ooooo00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00002
ooooo`09ool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000;ooooo00?oo`00oooooooo
00001oooool01?oo003ooooooooooooo0005ooooo`05ool00?ooooooo`00oooooooo00001?ooool0
2Ol0003oooooooooooooooooo`00oooooooo003oooooool00006ooooo`03ool00?ooooooo`0000[o
oooo00Goo`00oooooooo003oooooool00002ooooo`0;ool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo00000_ooool02_oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooool2ool0000;oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo
00002_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`09ool00?oooooo
oooooooooooo003oooooool00?ooooooo`0000Kooooo00Ooo`00oooooooo003oooooool00?oooooo
o`0000Cooooo00Ooo`00oooooooo003oooooool00?ooooooo`0000Cooooo00Goo`00oooooooo003o
ooooool00005ooooo`0>ool00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo0002ooooo`0;ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
00000_ooool02Ooo003oooooool00?ooooooo`00oooooooo003oooooool00002ooooo`0;ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00000_ooool01ooo003oooooool00?oo
ooooo`00oooooooo00001_ooool01Ooo003oooooool00?ooooooo`0000Gooooo00Koo`00oooooooo
ooooo`00oooooooo000;ooooo`Co00003?ooool001Sooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0:ooooo`07ool00?ooooooo`00oooooooo003oooooool00003ooooo`;oo`00
00Koooooool00?ooooooo`00oooooooo0003ooooo`0?ool00?ooooooooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003ooooo00;oo`0000Woooooool00?ooooooo`00oooo
oooo003oooooool00?ooool00_oo00002oooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003ooooo00;oo`0000_oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
o`02ool00006oooooooo003oooooool00?ooooooo`001_ooool01ooo003oooooool00?ooooooo`00
oooooooo00000oooool02?oo003ooooooooooooo003oooooool00?ooooooo`000oooool02?oo003o
ooooool00?oo003oooooool00?ooooooo`000oooool01?oo003oooooool00?ooool2ool000Oooooo
00?oo`00oooooooo00000_ooool02ooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`0000;ooooo00[oo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0000
2oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00;oo`0000[oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`000_ooool01Ooo003oooooool00?ooooooo`00
00?ooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`03ooooo`04ool00?ooooooo`00
ooooo`;oo`0000coooooool00?oooooo0000oooooooo003oooooool00?ooooooo`00oooooooo0004
ooooo`07ool00?ooooooo`00oooooooo003oooooool00004ooooo`0:ool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ooooo`;oo`0000[oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`000_ooool02_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool0
000;oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo00002_oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`0;ool00?oooooooooooooooooo
003oooooool00?ooooooo`00oooooooo00001?ooool01ooo003oooooool00?ooooooo`00oooooooo
00001?ooool01ooo003oooooool00?ooooooo`00oooooooo00001?ooool01ooo003oooooool00?oo
ooooo`00oooooooo00000oooool03_oo003ooooooooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`000_ooool02_oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooool2ool0000;oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo
00002_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0002ooooo`07ool00?oooooo
o`00oooooooo003oooooool00006ooooo`07ool00?ooooooo`00oooooooo003oooooool00003oooo
o`08ool00?ooooooooooool00?ooooooo`00oooooooo000<ooooo`03o`000?oooooooooo00[ooooo
000Hooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02_ooool01ooo003ooooo
ool00?ooooooo`00oooooooo00000oooool2ool00006oooooooo003oooooool00?ooooooo`000ooo
ool03Ooo003ooooooooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo
00002Oooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`04ool00009oooooooo003ooooo
ool00?ooooooo`00oooooooo003ooooo00;oo`0000_oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00ooooo`02ool00008oooooooo003oooooool00?ooooooo`00oooooooo0004oooo
o`07ool00?ooooooo`00oooooooo003oooooool00003ooooo`08ool00?ooooooo`00ool00?oooooo
o`00oooooooo0003ooooo`08ool00?ooooooo`00ool00?ooooooo`00oooooooo0003ooooo`04ool0
0?ooooooo`00ooooo`;oo`0000?oooooool00?ooool00_ooool01_oo003oooooool00?ooooooo`00
ooooo`;oo`0000_oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool0
0009oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00;oo`0000_oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`02ool0000;oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooool00_oo00001?ooooooo`00oooooooo0003ooooo`03ool00?oo
ooooo`0000?oo`001Oooool01?oo003oooooool00?ooool2ool0000;oooooooo003oooooo`000?oo
ooooo`00oooooooo003oooooool00?ooool00_oo0003ooooo`07ool00?ooooooo`00oooooooo003o
ooooool00004ooooo`0:ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`00
00Woooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo00002Oooooooo`00oooooooo
003oooooool00?ooooooo`00ooooo`02ool0000;oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooool00_oo00002_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
0002ooooo`0;ool00?oooooooooooooooooo003oooooool00?ooooooo`00oooooooo00001?ooool0
1ooo003oooooool00?ooooooo`00oooooooo00001?ooool01ooo003oooooool00?ooooooo`00oooo
oooo00000oooool2ool00006oooooooo003oooooool00?ooooooo`000oooool03Ooo003ooooooooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo00002Oooooooo`00oooo
oooo003oooooool00?ooooooo`00ooooo`04ool00009oooooooo003oooooool00?ooooooo`00oooo
oooo003ooooo00;oo`0000_oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
o`02ool00008oooooooo003oooooool00?ooooooo`00oooooooo0004ooooo`07ool00?ooooooo`00
oooooooo003oooooool00003ooooo`Coo`0000Coooooool00?ooooooo`003?ooool00ol0003ooooo
ooooo`0:ooooo`006Oooool2o`0000Sooooo00?o0000ooooooooool02_ooool01ooo003oooooool0
0?ooooooo`00oooooooo00000oooool2ool00006oooooooo003oooooool00?ooooooo`000oooool0
3Ooo003oooooool00?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo0000
2Oooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`04ool00009oooooooo003oooooool0
0?ooooooo`00oooooooo003ooooo00Coo`0000Woooooool00?ooooooo`00oooooooo003oooooool0
0?ooool00_oo00002?ooooooo`00oooooooo003oooooool00?ooooooo`000oooool2ool00006oooo
oooo003oooooool00?ooooooo`000oooool4ool00004oooooooo003oooooool000?ooooo00?oo`00
oooooooo00000ooo00000oooooooo`00ooooo`02ooooo`04ool00?ooooooo`00ooooo`;oo`0000?o
ooooool00?ooool00_ooool01_oo003oooooool00?ooooooo`00ooooo`;oo`0000_oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool00009oooooooo003oooooool00?oo
ooooo`00oooooooo003ooooo00Coo`0000Woooooool00?ooooooo`00oooooooo003oooooool00?oo
ool00_oo00002oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00;oo`00
00Coooooool00?ooooooo`000oooool00ooo003oooooool00003ool000Gooooo00Coo`00oooooooo
003ooooo0_oo00002oooooooo`00ooooool0003oooooool00?ooooooo`00oooooooo003ooooo00;o
o`000oooool01ooo003oooooool00?ooooooo`00oooooooo00001?ooool02?oo003oooooool00?oo
ooooo`00oooooooo003ooooo1?oo00002Oooooooo`00oooooooo003oooooool00?ooooooo`00oooo
o`04ool00009oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00Coo`0000Woooooool0
0?ooooooo`00oooooooo003oooooool00?ooool00_oo00002_ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo0002ooooo`0:ool00?oooooooooooooooooo003oooooool00?ooooooo`00
ooooo`;oo`000oooool01ooo003oooooool00?ooooooo`00oooooooo00001?ooool01ooo003ooooo
ool00?ooooooo`00oooooooo00000oooool2ool00006oooooooo003oooooool00?ooooooo`000ooo
ool03Ooo003oooooool00?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo
00002Oooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`04ool00009oooooooo003ooooo
ool00?ooooooo`00oooooooo003ooooo00;oo`0000_oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00ooooo`02ool00008oooooooo003oooooool00?ooooooo`00oooooooo0004oooo
o`07ool00?ooooooo`00oooooooo003oooooool00003ooooo`Coo`0000Coooooool00?ooooooo`00
3?ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0:ooooo`07ool00?oo
ooooo`00oooooooo003oooooool00003ooooo`Coo`0000Coooooool00?ooooooo`000oooool03Ooo
003oooooool00?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool01_oo00001Ooo
ooooo`00oooooooo003ooooo00Koo`0000Woooooool00?ooooooo`00oooooooo003oooooool00?oo
ool01?oo00002Oooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool00008oooooooo
003oooooool00?ooooooo`00oooooooo0003ooooo`Coo`0000Coooooool00?ooooooo`000oooool4
ool00004oooooooo003oooooool000?ooooo00?oo`00oooooooo00000ooo00000oooooooo`00oooo
o`02ooooo`04ool00?ooooooo`00ooooo`;oo`0000?oooooool00?ooool00_ooool01_oo003ooooo
ool00?ooooooo`00ooooo`;oo`0000Woooooool00?ooooooo`00oooooooo003oooooool00?ooool0
1?oo00001oooooooo`00oooooooo003oooooool00?ooool01_oo00001oooooooo`00oooooooo003o
ooooool00?ooool01_oo00001oooooooo`00oooooooo003oooooool00?ooool01?oo00001?oooooo
o`00oooooooo0003ooooo`03ool00?ooooooo`0000?oo`001Oooool01?oo003oooooool00?ooool2
ool0000;oooooooo003oooooo`000?ooooooo`00oooooooo003oooooool00?ooool00_oo0003oooo
o`07ool00?ooooooo`00oooooooo003oooooool00004ooooo`08ool00?ooooooo`00oooooooo003o
ooooool00?ooool6ool00007oooooooo003oooooool00?ooooooo`00ooooo`04ool00009oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo00Coo`0000Ooooooool00?ooooooo`00oooooooo
003ooooo00Coo`0000_oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02
ool000?ooooo00Koo`00oooooooo003oooooool00?ooool2ool000?ooooo00Ooo`00oooooooo003o
ooooool00?ooooooo`0000Cooooo00Ooo`00oooooooo003oooooool00?ooooooo`0000?ooooo1?oo
00001?ooooooo`00oooooooo0003ooooo`0=ool00?ooooooo`00ool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00ooooo`06ool00007oooooooo003oooooool00?ooooooo`00ooooo`04ool0
0007oooooooo003oooooool00?ooooooo`00ooooo`06ool00009oooooooo003oooooool00?oooooo
o`00oooooooo003ooooo00;oo`0000Soooooool00?ooooooo`00oooooooo003oooooool000?ooooo
0_oo00001_ooooooo`00oooooooo003oooooool000?ooooo1?oo00001?ooooooo`00oooooooo000<
ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo00[ooooo00Ooo`00oooo
oooo003oooooool00?ooooooo`0000?ooooo1?oo00001?ooooooo`00oooooooo0003ooooo`0;ool0
0?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?ooool02?oo00000oooooooo`00oooo
o`0:ool00005oooooooo003oooooool00?ooool01_oo00001oooooooo`00oooooooo003oooooool0
0?ooool01?oo00002?ooooooo`00oooooooo003oooooool00?ooooooo`000oooool4ool00004oooo
oooo003oooooool000?ooooo1_oo00000oooooooo`00ooooo`02ooooo`Koo`0000?oooooool00?oo
ool00_ooool00ooo003oooooool00003ool00003oooooooo003ooooo00;ooooo00Coo`00oooooooo
003ooooo1?oo00001oooooooo`00oooooooo003oooooool00?ooool01_oo00001Oooooooo`00oooo
oooo003ooooo00Soo`0000Goooooool00?ooooooo`00ooooo`08ool00007oooooooo003oooooool0
0?ooooooo`00ooooo`04ool00004oooooooo003oooooool000?ooooo00?oo`00oooooooo00000ooo
0005ooooo`03ool00?ooooooo`0000Goo`0000Woooooo`000?ooooooo`00oooooooo003oooooool0
0?ooool00_oo0003ooooo`07ool00?ooooooo`00oooooooo003oooooool00004ooooo`08ool00?oo
ooooo`00oooooooo003oooooool00?ooool8ool00003oooooooo003ooooo00Koo`0000Ooooooool0
0?ooooooo`00oooooooo003ooooo00Soo`0000Goooooool00?ooooooo`00ooooo`06ool00009oooo
oooo003oooooool00?ooooooo`00oooooooo003ooooo00;oo`000oooool01_oo003oooooool00?oo
ooooo`00ooooo`;oo`000oooool01ooo003oooooool00?ooooooo`00oooooooo00000oooool2ool0
0006oooooooo003oooooool00?ooooooo`000oooool4ool00004oooooooo003oooooool000?ooooo
00goo`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00Koo`00
00Goooooool00?ooooooo`00ooooo`06ool00007oooooooo003oooooool00?ooooooo`00ooooo`06
ool00007oooooooo003oooooool00?ooooooo`00ooooo`06ool00006oooooooo003oooooool00?oo
ooooo`000oooool2ool00006oooooooo003oooooool00?ooooooo`000oooool6ool00003oooooooo
003ooooo00_ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool02Oooool4
ool00004oooooooo003oooooool000?ooooo1?oo00001?ooooooo`00oooooooo0003ooooo`0;ool0
0?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?ooool02_oo00000oooooooo`00ool0
000:ool00003oooooooo003ooooo00Koo`0000Ooooooool00?ooooooo`00oooooooo003ooooo00Co
o`0000Soooooool00?ooooooo`00oooooooo003oooooool000?ooooo1_oo00000oooooooo`00oooo
o`02ooooo`Koo`0000?oooooool00?ooool00_ooool6ool00003oooooooo003ooooo00;ooooo00?o
o`00oooooooo00000ooo00000oooooooo`00ooooo`02ooooo`04ool00?ooooooo`00ooooo`Coo`00
00Goooooool00?oo003oo`00ooooo`0<ool00003oooooooo003oo`0000Soo`0000?oooooool00?oo
ool02?oo00001oooooooo`00oooooooo003oooooool00?ooool01?oo00001?ooooooo`00oooooooo
0003ooooo`03ool00?ooooooo`0000?oo`001Oooool00ooo003oooooool00005ool00005ooooool0
003oooooool00?ooool01_oo0003ooooo`07ool00?ooooooo`00oooooooo003oooooool00004oooo
o`08ool00?ooooooo`00oooooooo003oooooool00?ooool8ool00003oooooooo003ooooo00[oo`00
00?oooooool00?ooool02?oo00001Oooooooo`00ool00?oo003ooooo00Koo`0000Woooooool00?oo
ooooo`00oooooooo003oooooool00?ooool00_oo0003ooooo`04ool00?ooooooo`00ooooo`Coo`00
0oooool01ooo003oooooool00?ooooooo`00oooooooo00000oooool2ool00006oooooooo003ooooo
ool00?ooooooo`000oooool4ool00004oooooooo003oooooool000?ooooo00?oo`00oooooooo0000
0ooo00001Oooooooo`00oooooooo003ooooo00Soo`0000Goooooool00?ooooooo`00ooooo`08ool0
0003oooooooo003ooooo00Soo`0000Goooooool00?ooooooo`00ooooo`08ool00006oooooooo003o
ooooool00?ooooooo`000oooool2ool00006oooooooo003oooooool00?ooooooo`000oooool6ool0
0003oooooooo003ooooo00_ooooo00?o0000ooooooooool02_ooool002?ooooo0_l0000:ooooo`Co
o`0000Coooooool00?oo003oo`000oooool6ool00003oooooooo003ooooo00;ooooo00_oo`00oooo
oooo003oo`00oooooooo003oooooool00?ooooooo`00ooooo`0:ool00003oooooooo003oo`0000Wo
o`0000?oooooool00?oo00002Ooo00000oooooooo`00ool00008ool00006oooooooo003oooooool0
0?ooooooo`000oooool6ool00003oooooooo003ooooo00;ooooo1_oo00000oooooooo`00ooooo`02
ooooo`Koo`0000?oooooool00?ooool00_ooool00ooo003oooooool00003ool00003oooooooo003o
oooo00;ooooo00Coo`00oooooooo003ooooo2?oo00000oooooooo`00ool0000:ool00003oooooooo
003oo`0000Soo`0000?oooooool00?ooool02_oo00001Oooooooo`00oooooooo003ooooo00Coo`00
00Coooooool00?ooooooo`000oooool00ooo003oooooool00003ool000Gooooo00?oo`00oooooooo
00001Ooo00001Ooooooo0000oooooooo003ooooo00Koo`000oooool00ooo003oooooool00002ool0
0003oooooooo003ooooo00?ooooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`Soo`00
00?oooooool00?ooool02_oo00000oooooooo`00ool00009ool00003oooooooo003oo`0000Ooo`00
00Woooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo0003ooooo`04ool00?oooooo
o`00ooooo`Coo`000oooool3ool00004oooooooo003oo`00ool000?ooooo0_oo00001_ooooooo`00
ool00?oo003oooooool000?ooooo1_oo00000oooooooo`00ooooo`02ooooo`03ool00?ooooooo`00
00?oo`0000?oooooool00?ooool02_oo00000oooooooo`00ooooo`0<ool00003oooooooo003oo`00
00Koo`0000Goooooool00?ooooooo`00ooooo`08ool00006oooooooo003oooooool00?ooooooo`00
0oooool6ool00003oooooooo003ooooo00;ooooo1_oo00000oooooooo`00ooooo`09ooooo`?o0000
3?ooool002?ooooo00?o0000ooooooooool02Oooool5ool00003oooooooo003oo`0000?ooooo1_oo
00000oooooooo`00ooooo`02ooooo`0;ool00?ooooooo`00ool00?ooooooo`00oooooooo003ooooo
ool00?ooool02_oo00000oooooooo`00ool00009ool00003oooooooo003ooooo00Woo`0000?ooooo
ool00?oo00002?oo00001_ooooooo`00oooooooo003oooooool000?ooooo1_oo00000oooooooo`00
ooooo`02ooooo`Koo`0000?oooooool00?ooool00_ooool6ool00003oooooooo003ooooo00;ooooo
00?oo`00oooooooo00001Ooo0003ooooo`04ool00?ooooooo`00ooooo`Soo`0000?oooooool00?oo
00002Ooo00000oooooooo`00ool0000:ool00003oooooooo003oo`0000Woo`0000Goooooool00?oo
ooooo`00ooooo`04ool00004oooooooo003oooooool000?ooooo00?oo`00oooooooo00000ooo0005
ooooo`03ool00?ooooooo`0000Goo`0000Goooooo`000?ooooooo`00ooooo`06ool000?ooooo00?o
o`00oooooooo00000_oo00000oooooooo`00ool00003ooooo`08ool00?ooooooo`00oooooooo003o
ooooool00?ooool9ool00003oooooooo003oo`0000Soo`0000?oooooool00?oo00002_oo00000ooo
ooooo`00ool00007ool00009oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00;oo`00
0oooool00ooo003oooooool00005ool000?ooooo0_oo00000oooooooo`00ool00003ool000;ooooo
0_oo00001?ooooooo`00ool00?ooool2ool000?ooooo1_oo00000oooooooo`00ooooo`02ooooo`03
ool00?ooooooo`0000?oo`0000?oooooool00?ooool03?oo00000oooooooo`00ool00009ool00003
oooooooo003ooooo00Woo`0000?oooooool00?ooool02?oo00001_ooooooo`00oooooooo003ooooo
ool000?ooooo1_oo00000oooooooo`00ooooo`02ooooo`Koo`0000?oooooool00?ooool02oooool0
0ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`09ooooo`?oo`0000?oooooool0
0?ooool00_oo0003ooooo`Koo`0000?oooooool00?ooool00_ooool00ooo003oooooool00005ool0
0003oooooooo003ooooo00Woo`0000Goooooool00?ooooooo`00ooooo`06ool00005oooooooo003o
ooooool00?ooool02_oo00000oooooooo`00ool00007ool00006oooooooo003oooooool00?oooooo
o`000oooool5ool00003oooooooo003oo`0000?ooooo1_oo00000oooooooo`00ooooo`02ooooo`So
o`000oooool00ooo003oooooool00005ool000?ooooo00Coo`00oooooooo003ooooo2Ooo00000ooo
ooooo`00ool00008ool00005oooooooo003oooooool00?ooool01_oo00001Oooooooo`00oooooooo
003ooooo00Woo`0000?oooooool00?ooool01_oo00001?ooooooo`00oooooooo0003ooooo`03ool0
0?ooooooo`0000?oo`001Oooool00ooo003oooooool00005ool00005ooooool0003oooooool00?oo
ool01_oo0003ooooo`;oo`0000?oooooool00?oo00000ooo0003ooooo`06ool00?ooooooo`00oooo
oooo003ooooo2Ooo00000oooooooo`00ooooo`08ool00007oooooooo003oooooool00?ooooooo`00
ooooo`06ool00003oooooooo003ooooo00_oo`0000Goooooool00?ooooooo`00ooooo`04ool000?o
oooo00Goo`00oooooooo003oo`00ooooo`03ool000?ooooo0_oo00000oooooooo`00ooooo`03ool0
00;ooooo0ooo00000oooooooo`00ooooo`02ool000?ooooo1_oo00000oooooooo`00ooooo`02oooo
o`03ool00?ooooooo`0000?oo`0000?oooooool00?ooool02ooo00000oooooooo`00ooooo`08ool0
0005oooooooo003oooooool00?ooool02_oo00000oooooooo`00ool00007ool00006oooooooo003o
ooooool00?ooooooo`000oooool5ool00003oooooooo003oo`0000?ooooo1_oo00000oooooooo`00
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo00Wooooo0ooo
00000oooooooo`00ooooo`02ool000?ooooo0ooo00001Oooooooo`00ool00?ooooooo`0000?ooooo
2?oo00000oooooooo`00ool00009ool00005oooooooo003oooooool00?ooool01?oo00002Ooooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`06ool00003oooooooo003ooooo00Woo`0000Ko
ooooool00?ooooooo`00oooooooo0003ooooo`Goo`0000?oooooool00?oo00000oooool3ool00005
oooooooo003oo`00oooooooo00000oooool8ool000?ooooo2?oo0003ooooo`04ool00?ooooooo`00
ooooo`Woo`0000?oooooool00?oo00001_oo00001oooooooo`00oooooooo003oooooool00?ooool0
1?oo00002Oooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`07ool00003oooooooo003o
o`0000Soo`0000?oooooool00?ooool00_ooool00ooo003oooooool00003ool000Gooooo00?oo`00
oooooooo00001Ooo00001Ooooooo0000oooooooo003ooooo00;oo`0000Coooooool00?oo003oo`00
0oooool2ool00003oooooooo003ooooo00?oo`000oooool01_oo003oooooool00?ooooooo`00oooo
o`Woo`0000Goooooool00?ooooooo`00ooooo`04ool00009oooooooo003oooooool00?ooooooo`00
oooooooo003ooooo00Coo`0000Ooooooool00?ooooooo`00oooooooo003ooooo00Woo`0000Gooooo
ool00?ooooooo`00ooooo`04ool000?ooooo00Goo`00oooooooo003oo`00ooooo`03ool000?ooooo
0_oo00000oooooooo`00ooooo`03ool000;ooooo0ooo00000oooooooo`00ooooo`02ool000?ooooo
0ooo00001Oooooooo`00ool00?ooooooo`0000?ooooo00?oo`00oooooooo00000ooo00000ooooooo
o`00ooooo`09ool00007oooooooo003oooooool00?ooooooo`00ooooo`04ool00009oooooooo003o
ooooool00?ooooooo`00oooooooo003ooooo00Koo`0000?oooooool00?ooool02Ooo00001_oooooo
o`00oooooooo003oooooool000?ooooo0ooo00000oooooooo`00ooooo`02ool000?ooooo0ooo0000
1Oooooooo`00ool00?ooooooo`0000cooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000
ooooooooool02Oooool3ool000?ooooo0_oo0003ooooo`?oo`0000Goooooool00?oo003oooooool0
0003ooooo`Soo`0000?oooooool00?oo00001ooo00001?ooooooo`00oooooooo000Booooo`;oo`00
00Ooooooool00?ooooooo`00oooooooo003ooooo00Ooo`0000Koooooool00?ooooooo`00oooooooo
0003ooooo`?oo`0000?oooooool00?ooool00_oo0003ooooo`?oo`000oooool2ool000?ooooo0ooo
0003ooooo`;oo`000oooool8ool000?ooooo00Coo`00oooooooo003ooooo1ooo00000oooooooo`00
ooooo`06ool00003oooooooo003ooooo017ooooo00?oo`00oooooooo00001ooo00000oooooooo`00
ool00007ool00003oooooooo003ooooo00;ooooo1?oo00000oooooooo`00ooooo`04ooooo`?oo`00
0_ooool3ool00003ooooool0003ooooo00;oo`000oooool3ool000?ooooo0_oo00000oooooooo`00
ooooo`03ool000?ooooo00Koo`00oooooooo003oooooool00?ooool7ool00008oooooooo003ooooo
ool00?ooooooo`00oooooooo000Cooooo`04ool00?ooooooo`00ooooo`Woo`0000Goooooool00?oo
ooooo`00ooooo`04ool000?ooooo00Goo`00oooooooo003oo`00ooooo`03ool000?ooooo0_oo0003
ooooo`?oo`000_ooool3ool000?ooooo0_oo0003ooooo`?oo`0000Goooooool00?oo003oooooool0
0003ooooo`03ool00?ooooooo`0000?oo`0000?oooooool00?ooool02Ooo00001?ooooooo`00oooo
oooo000Booooo`;oo`0000Ooooooool00?ooooooo`00oooooooo003ooooo00Ooo`0000Koooooool0
0?ooooooo`00oooooooo0003ooooo`?oo`0000?oooooool00?ooool00_oo0003ooooo`?oo`000_oo
ool3ool000cooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool02Oooool3
ool000?ooooo0_oo0003ooooo`?oo`000_ooool00ooo003oooooool00003ooooo`Woo`0000?ooooo
ool00?oo00001?oo00000oooooooo`00ooooo`0Jooooo`04ool00?ooooooo`00ooooo`Woo`0000Co
ooooool00?ooooooo`000oooool3ool000?ooooo0_oo0003ooooo`?oo`000oooool2ool000?ooooo
0ooo0003ooooo`;oo`000oooool2ool000?ooooo0ooo0003ooooo`04ool00?ooooooo`00ooooo`Oo
o`0000Koooooool00?ooooooo`00oooooooo000Kooooo`;oo`0000Goooooool00?ooooooo`00oooo
o`09ool00003oooooooo003ooooo00;ooooo0ooo0002ooooo`03ool00?oooooooooo00?ooooo0_oo
0003ooooo`?oo`0000?oooooo`000?ooool00_oo0003ooooo`?oo`000_ooool3ool000?ooooo0ooo
0003ooooo`06ool00?ooooooo`00oooooooo003ooooo1ooo00001?ooooooo`00oooooooo000Koooo
o`03ool00?ooooooo`0000Koo`0000Goooooool00?oo003oo`00ooooo`04ool000?ooooo00?oo`00
oooooooo00000_ooool3ool000?ooooo0_oo0003ooooo`?oo`000_ooool3ool000?ooooo0_oo0003
ooooo`?oo`000_ooool00ooo003oooooool00003ooooo`03ool00?ooooooo`0000?oo`0000?ooooo
ool00?ooool01ooo00000oooooooo`00ooooo`0Jooooo`04ool00?ooooooo`00ooooo`Woo`0000Co
ooooool00?ooooooo`000oooool3ool000?ooooo0_oo0003ooooo`?oo`000oooool2ool000cooooo
00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool02Oooool3ool000?ooooo0_oo
0003ooooo`?oo`000_ooool00ooo003oooooool00003ooooo`Woo`0000Coooooool00?oo003oo`00
9?ooool9ool00004oooooooo003oooooool000?ooooo0ooo0003ooooo`;oo`000oooool3ool000?o
oooo0_oo0003ooooo`?oo`000oooool2ool000?ooooo0_oo0003ooooo`?oo`000oooool01?oo003o
ooooool00?ooool7ool00003oooooooo003ooooo02?ooooo00?oo`00oooooooo00002?oo00000ooo
ooooo`00ooooo`02ooooo`?oo`000_ooool00ooo003oooooooooo`03ooooo`;oo`000oooool3ool0
0003ooooool0003ooooo00;oo`000oooool3ool000;ooooo00?oo`00oooooooo00000oooool3ool0
00?ooooo00Coo`00oooooooo003ooooo2Ooo000Sooooo`Goo`0000?oooooool00?oo00001_oo0003
ooooo`03ool00?ooooooo`0000;ooooo0ooo0003ooooo`;oo`000oooool3ool000;ooooo0ooo0003
ooooo`;oo`000oooool3ool000;ooooo00?oo`00oooooooo00000oooool8ool00004oooooooo003o
o`00ooooo`;oo`008oooool9ool00004oooooooo003oooooool000?ooooo0ooo0003ooooo`;oo`00
0oooool3ool000?ooooo0_oo000<ooooo`03o`000?oooooooooo00[ooooo000Sooooo`;o00002_oo
ool3ool000?ooooo0_oo0003ooooo`?oo`000_ooool00ooo003oooooool00003ooooo`Ooo`0000Co
ooooool00?ooooooo`00:?ooool7ool00004oooooooo003oooooool000?ooooo0ooo0003ooooo`;o
o`000oooool3ool000?ooooo0_oo0003ooooo`;oo`001?ooool2ool000?ooooo0_oo0003ooooo`?o
o`000oooool01?oo003oooooool00?ooool5ool00003oooooooo003ooooo02Oooooo00?oo`00oooo
oooo00001_oo00000oooooooo`00ooooo`02ooooo`?oo`000_ooool00ooo003oooooooooo`03oooo
o`;oo`000oooool3ool00003ooooool0003ooooo00;oo`000oooool3ool000;ooooo00?oo`00oooo
oooo00000oooool3ool000?ooooo00Coo`00oooooooo003ooooo1ooo000Xooooo`?oo`0000?ooooo
ool00?oo00001Ooo0003ooooo`03ool00?ooooooo`0000;ooooo0ooo0002ooooo`?oo`000oooool3
ool000;ooooo0ooo0003ooooo`;oo`000oooool3ool000;ooooo00?oo`00oooooooo00000oooool7
ool00004oooooooo003oooooool002Sooooo1ooo00001?ooooooo`00ool00?oo0003ooooo`?oo`00
0oooool2ool000?ooooo0ooo0003ooooo`;oo`002_ooool3o`0000cooooo000Sooooo`03o`000?oo
oooooooo00Wooooo0ooo0003ooooo`;oo`000oooool00ooo003oooooooooo`03ooooo`;oo`000ooo
ool7ool00004oooooooo003oooooool002Sooooo1ooo00001?ooooooo`00oooooooo0003ooooo`?o
o`001?ooool01?oo003oooooooooooooool2ool000Cooooo0_oo0003ooooo`;oo`001?ooool2ool0
00?ooooo00?oo`00ooooooooool00_ooool3ool000?ooooo00Coo`00oooooooo003ooooo1Ooo0000
0oooooooo`00ooooo`0Wooooo`03ool00?ooooooo`0000Koo`0000?oooooool00?ooool00_ooool3
ool000;ooooo00?oo`00ooooooooool00oooool2ool000Cooooo0_oo00000ooooooo0000ooooo`02
ool000?ooooo0ooo0002ooooo`03ool00?oooooooooo00?ooooo0ooo0002ooooo`;oo`0000?ooooo
ool00?ooool00_oo00000oooooooo`00ool00002ool002Sooooo00Coo`00oooooooo003ooooo1ooo
0003ooooo`03ool00?ooooooo`0000Cooooo00Koo`00ooooooooooooo`00oooooooo0003ooooo`03
ool00?ooooooo`0000;ooooo0ooo0003ooooo`;oo`000oooool00ooo003oooooooooo`03ooooo`;o
o`000oooool7ool00004oooooooo003oooooool002Sooooo1ooo00001?ooooooo`00ool00?oo0003
ooooo`?oo`001?ooool01?oo003oooooooooooooool2ool000Cooooo0_oo000<ooooo`03o`000?oo
oooooooo00[ooooo000Sooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool01?ooool0
1Ooo003oooooooooooooooooo`0000Gooooo0_oo0003ooooo`Ooo`0000?oooooool00?ooool0:ooo
ool5ool00004oooooooo003oooooool000?ooooo0ooo0004ooooo`05ool00?oooooooooooooooooo
00001_ooool01Ooo003oooooooooooooooooo`0000Kooooo00Goo`00ooooooooooooooooool00004
ooooo`?oo`000oooool00ooo003oooooool00006ool002cooooo1ooo00000oooooooo`00ooooo`02
ooooo`?oo`000oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00Goo`00
ooooool0003oooooool00006ooooo`04ool00?ooooooooooool000Gooooo0ooo0002ooooo`;oo`00
00Koooooool00?oo003oooooool00?ooool2ool002cooooo00?oo`00oooooooo00001_oo0003oooo
o`;oo`001Oooool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Kooooo00Go
o`00ooooooooooooooooool00005ooooo`;oo`000oooool7ool00003oooooooo003ooooo02_ooooo
1Ooo00001?ooooooo`00ool00?oo0003ooooo`?oo`001?ooool01Ooo003oooooooooooooooooo`00
00Kooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003o
ooooooooo`09ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool00005oooo
o`;oo`000oooool7ool00003oooooooo003ooooo02cooooo1?oo00001?ooooooo`00oooooooo0003
ooooo`?oo`001?ooool01Ooo003oooooooooooooooooo`0000Kooooo00Goo`00oooooooooooooooo
ool00006ooooo`05ool00?oooooooooooooooooo00001?ooool3ool000?ooooo00?oo`00oooooooo
00001_oo000/ooooo`03ool00?ooooooo`0000Coo`0000?oooooool00?ooool00_ooool3ool000?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`05ool00?oooooo0000oooo
oooo00001_ooool01?oo003ooooooooooooo0005ooooo`?oo`000_ooool2ool00007oooooooo003o
o`00oooooooo003oooooool0000]ooooo`03ool00?ooooooo`0000Koo`000oooool2ool000Gooooo
00Coo`00ooooooooooooo`001oooool01?oo003ooooooooooooo0006ooooo`05ool00?oooooooooo
oooooooo00001Oooool2ool000?ooooo1ooo00000oooooooo`00ooooo`0/ooooo`Coo`0000Cooooo
ool00?oo003oo`000oooool3ool000Cooooo00Goo`00ooooooooooooooooool00006ooooo`03ool0
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool02Ooo
ool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00001Oooool2ool000?ooooo
1ooo000aooooo`;oo`0000Coooooool00?ooooooo`000oooool3ool000Cooooo00Goo`00oooooooo
ooooooooool00006ooooo`05ool00?oooooooooooooooooo00001_ooool01Ooo003ooooooooooooo
ooooo`0000Cooooo0ooo0003ooooo`03ool00?ooooooo`0000Coo`00<?ooool5ool00003oooooooo
003ooooo00;ooooo0ooo0003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool01?oo
ool01Ooo003oooooo`000?ooooooo`0000Kooooo00Coo`00ooooooooooooo`001Oooool3ool000;o
oooo0_oo00001Oooooooo`00ool00?ooooooo`00037ooooo1ooo0003ooooo`;oo`001Oooool01?oo
003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Kooooo00Goo`00oooooooooooooooo
ool00005ooooo`;oo`000oooool7ool0037ooooo0_oo00001?ooooooo`00ool00?oo0003ooooo`?o
o`001?ooool01Ooo003oooooooooooooooooo`0000Kooooo00?oo`00ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00Co
oooo00Goo`00ooooooooooooooooool00005ooooo`;oo`000oooool5ool00003oooooooo003ooooo
033ooooo0_oo00001?ooooooo`00oooooooo0003ooooo`?oo`001?ooool01Ooo003ooooooooooooo
ooooo`0000Kooooo00Goo`00ooooooooooooooooool00006ooooo`05ool00?oooooooooooooooooo
00001?ooool3ool000?ooooo00?oo`00oooooooo00001?oo000`ooooo`Goo`0000?oooooool00?oo
ool00_ooool2ool000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`04ooooo`04
ool00?oooooo0000ool000Oooooo00Coo`00ooooooooooooo`001Oooool3ool000;ooooo0_oo0000
1Oooooooo`00ool00?ooooooo`00037ooooo00?oo`00oooooooo00001?oo0003ooooo`;oo`001Ooo
ool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Kooooo00Goo`00oooooooo
ooooooooool00005ooooo`;oo`000oooool5ool00003oooooooo003ooooo033ooooo00?oo`00oooo
oooo00000ooo0003ooooo`?oo`001Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool02Oooool00ooo
003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00001Oooool2ool000?ooooo1Ooo0000
0oooooooo`00ooooo`0`ooooo`06ool00?ooooooo`00ool00?ooooooo`000oooool3ool000Cooooo
00Goo`00ooooooooooooooooool00006ooooo`05ool00?oooooooooooooooooo00001_ooool01Ooo
003oooooooooooooooooo`0000Cooooo0ooo0003ooooo`03ool00?ooooooo`0000Coo`00<?ooool5
ool00003oooooooo003ooooo00;ooooo0_oo0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool01?ooool01?oo003oooooo`000?oo0007ooooo`04ool00?ooooooooooool000Gooooo
0ooo0002ooooo`;oo`0000Goooooool00?oo003oooooool0000aooooo`03ool00?ooooooo`0000Co
o`000oooool2ool000Gooooo00Coo`00ooooooooooooo`001oooool01?oo003ooooooooooooo0006
ooooo`05ool00?oooooooooooooooooo00001Oooool2ool000?ooooo1Ooo00000oooooooo`00oooo
o`0`ooooo`04ool00?ooooooo`00ooooo`;oo`000oooool3ool000Gooooo00Coo`00oooooooooooo
o`001oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000Sooooo`;o0000
2_ooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00001Oooool2ool000?o
oooo1Ooo000eooooo`;oo`0000?oooooool00?ooool00_ooool3ool000Cooooo00Goo`00oooooooo
ooooooooool00006ooooo`05ool00?oooooooooooooooooo00001_ooool01?oo003ooooooooooooo
0006ooooo`;oo`000oooool00ooo003oooooool00002ool003Cooooo0ooo00000oooooooo`00oooo
o`02ooooo`;oo`001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00Co
o`00ooooool0003oo`001oooool01?oo003ooooooooooooo0005ooooo`?oo`000_ooool2ool00003
oooooooo003oo`0003Gooooo1Ooo0003ooooo`;oo`001Oooool01?oo003ooooooooooooo0007oooo
o`04ool00?ooooooooooool000Kooooo00Goo`00ooooooooooooooooool00005ooooo`;oo`000ooo
ool5ool003Gooooo00Coo`00oooooooo003oo`000oooool3ool000Gooooo00Coo`00oooooooooooo
o`001oooool00ooo003oooooooooo`07ooooo`?o00003?ooool002?ooooo00?o0000ooooooooool0
2Oooool00ooo003oooooooooo`04ooooo`05ool00?oooooooooooooooooo00001Oooool2ool000?o
oooo1Ooo000eooooo`;oo`0000?oooooool00?ooool00_ooool3ool000Cooooo00Goo`00oooooooo
ooooooooool00006ooooo`05ool00?oooooooooooooooooo00001_ooool01?oo003ooooooooooooo
0006ooooo`;oo`000oooool00ooo003oooooool00002ool003Cooooo0ooo00000oooooooo`00oooo
o`02ooooo`;oo`001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00Co
o`00ooooool0003oo`001oooool01?oo003ooooooooooooo0005ooooo`?oo`000_ooool2ool00003
oooooooo003oo`0003Gooooo1Ooo0003ooooo`;oo`001Oooool01?oo003ooooooooooooo0007oooo
o`04ool00?ooooooooooool000Kooooo00Goo`00ooooooooooooooooool00005ooooo`;oo`000ooo
ool5ool003Gooooo00Coo`00oooooooo003oo`000oooool3ool000Gooooo00Coo`00oooooooooooo
o`001oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`00
0?oooooooooo00Wooooo00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0000Ko
oooo00Coo`00oooooooooooooooo1Ooo000eooooo`04ool00?ooooooo`00ool000?ooooo00?oo`00
ooooooooool01?ooool01Ooo003oooooooooooooooooo`0000Kooooo00Goo`00oooooooooooooooo
ool00006ooooo`04ool00?ooooooooooool000Oooooo00Koo`00ooooooooooooooooool00?ooool3
ool003Cooooo0ooo00000oooooooo`00ooooo`02ooooo`03ool00?oooooooooo00Cooooo00Goo`00
ooooooooooooooooool00006ooooo`04ool00?oooooo0000ool000Oooooo00Coo`00oooooooooooo
o`001oooool00ooo003oooooooooo`02ool00003oooooooo003oo`0003Gooooo1Ooo0003ooooo`03
ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`001oooool01?oo003ooooooooooooo0006
ooooo`05ool00?oooooooooooooooooo00001_ooool01?oo003oooooooooooooool5ool003Gooooo
00Coo`00oooooooo003oo`000oooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooool0
00Oooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003o
ooooooooo`09ooooo`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool00006oooo
o`04ool00?ooooooooooooooo`Goo`00=Oooool01?oo003oooooool00?oo0003ooooo`03ool00?oo
oooooooo00Cooooo00Goo`00ooooooooooooooooool00006ooooo`05ool00?oooooooooooooooooo
00001_ooool01?oo003ooooooooooooo0007ooooo`06ool00?oooooooooooooooooo003ooooo0_oo
000eooooo`?oo`0000?oooooool00?ooool00_ooool00ooo003oooooooooo`04ooooo`05ool00?oo
oooooooooooooooo00001_ooool01?oo003oooooo`000?oo0007ooooo`04ool00?ooooooooooool0
00Oooooo00?oo`00ooooooooool00ooo00000oooooooo`00ooooo`0dooooo`Goo`000oooool00ooo
003oooooooooo`04ooooo`04ool00?ooooooooooool000Oooooo00Coo`00ooooooooooooo`001ooo
ool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooooooo`Goo`00=Oooool01?oo003o
ooooool00?oo0003ooooo`03ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`001oooool0
0ooo003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo
00Wooooo00?oo`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0000Kooooo00Coo`00
oooooooooooooooo1Ooo000eooooo`03ool00?ooooooo`0000;oo`000_ooool00ooo003ooooooooo
o`04ooooo`05ool00?oooooooooooooooooo00001_ooool01Ooo003oooooooooooooooooo`0000Ko
oooo00Coo`00ooooooooooooo`001oooool01_oo003oooooooooooooooooo`00ooooo`;oo`00=_oo
ool4ool000?ooooo00?oo`00ooooooooool01?ooool01?oo003ooooooooooooo0007ooooo`04ool0
0?oooooo0000ool000Oooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`03ool0
0003oooooooo003ooooo03Cooooo1Ooo0003ooooo`03ool00?oooooooooo00Cooooo00Coo`00oooo
ooooooooo`001oooool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Kooooo
00Coo`00oooooooooooooooo1Ooo000eooooo`04ool00?ooooooo`00ool000?ooooo00?oo`00oooo
ooooool01Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool0017ooooo1Ol00003ooooo`;o00002?ooool00ol0003oooooooooo`09oooo
o`03ool00?oooooooooo00Cooooo00Goo`00ooooooooooooooooool00006ooooo`04ool00?oooooo
ooooooooo`?oo`0000?oooooool00?ooool0=?ooool00ooo003oooooool00002ool000;ooooo00?o
o`00ooooooooool01?ooool01Ooo003oooooooooooooooooo`0000Kooooo00Goo`00oooooooooooo
ooooool00006ooooo`04ool00?ooooooooooool000Oooooo00Koo`00ooooooooooooooooool00?oo
ool2ool003Kooooo1?oo0003ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`00
1oooool01?oo003oooooo`000?oo0007ooooo`04ool00?ooooooooooool000Oooooo00?oo`00oooo
ooooool00ooo00000oooooooo`00ooooo`0dooooo`03ool00?ooooooo`0000;oo`000oooool00ooo
003oooooooooo`04ooooo`04ool00?ooooooooooool000Oooooo00Coo`00ooooooooooooo`001ooo
ool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooooooo`Goo`00=Oooool01?oo003o
ooooool00?oo0003ooooo`03ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`001oooool0
0ooo003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000Booooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`09ooooo`03ool00?oo
oooooooo00Cooooo00Goo`00ooooooooooooooooool00006ooooo`04ool00?ooooooooooooooo`?o
o`00>Oooool3ool000;ooooo00?oo`00ooooooooool01Oooool01?oo003ooooooooooooo0006oooo
o`05ool00?oooooooooooooooooo00001oooool00ooo003oooooool00007ooooo`07ool00?oooooo
oooooooooooo003oooooool0000hooooo`?oo`000oooool00ooo003oooooooooo`04ooooo`04ool0
0?ooooooooooool000Oooooo00Coo`00ooooool0003oo`001oooool01?oo003ooooooooooooo0007
ooooo`03ool00?oooooooooo00?oo`00>Oooool3ool000;ooooo00?oo`00ooooooooool01Oooool0
1?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Oooooo00Coo`00oooooooooooo
o`001_ooool01?oo003oooooooooooooool3ool003Wooooo0_oo0003ooooo`03ool00?oooooooooo
00Gooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`09ooooo`03ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`001_oo
ool01?oo003oooooooooooooool3ool003Wooooo0ooo0002ooooo`03ool00?oooooooooo00Gooooo
00Coo`00ooooooooooooo`001_ooool01Ooo003oooooooooooooooooo`0000Oooooo00?oo`00oooo
oooo00001oooool01ooo003oooooooooooooooooo`00oooooooo0000>?ooool3ool000?ooooo00?o
o`00ooooooooool01?ooool01?oo003ooooooooooooo0007ooooo`04ool00?oooooo0000ool000Oo
oooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`03ool003Wooooo0ooo0002oooo
o`03ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`001oooool01?oo003ooooooooooooo
0007ooooo`04ool00?ooooooooooool000Kooooo00Coo`00oooooooooooooooo0ooo000iooooo`;o
o`000oooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooool000Oooooo00?oo`00oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`005?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool01Oooool3o`0000Wooooo00?oo`00ooooooooool01Oooool01?oo
003ooooooooooooo0006ooooo`04ool00?ooooooooooooooo`?oo`00>Oooool3ool000;ooooo00?o
o`00ooooooooool01Oooool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Oo
oooo00?oo`00oooooooo00001oooool01ooo003oooooooooooooooooo`00oooooooo0000>?ooool3
ool000?ooooo00?oo`00ooooooooool01?ooool01?oo003ooooooooooooo0007ooooo`04ool00?oo
oooo0000ool000Oooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`03ool003Wo
oooo0ooo0002ooooo`03ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`001oooool01?oo
003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Kooooo00Coo`00oooooooooooooooo
0ooo000iooooo`;oo`000oooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooool000Oo
oooo00?oo`00ooooooooool01_ooool4o`0000cooooo000Aooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Wooooo00?oo`00oooo
ooooool01Oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooooooo`?oo`00>Ooo
ool3ool000;ooooo00?oo`00ooooooooool01Oooool01?oo003ooooooooooooo0007ooooo`04ool0
0?ooooooooooool000Oooooo00?oo`00oooooooo00001oooool01?oo003oooooooooooooool2ool0
03Wooooo0ooo0003ooooo`03ool00?oooooooooo00Cooooo00Coo`00ooooooooooooo`001oooool0
1?oo003oooooo`000?oo0007ooooo`04ool00?ooooooooooool000Oooooo00?oo`00ooooooooool0
0ooo000iooooo`?oo`000_ooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooool000Oo
oooo00Coo`00ooooooooooooo`001oooool01?oo003ooooooooooooo0006ooooo`04ool00?oooooo
ooooooooo`?oo`00>Oooool2ool000?ooooo00?oo`00ooooooooool01Oooool01?oo003ooooooooo
oooo0007ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0017ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool02Oooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooool000Kooooo00Coo`00oooo
oooooooooooo0ooo000iooooo`?oo`000_ooool00ooo003oooooooooo`05ooooo`04ool00?oooooo
ooooool000Oooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooool00007ooooo`04ool0
0?ooooooooooooooo`;oo`00>Oooool3ool000?ooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooool00007ooooo`04ool00?oooooo0000ool000Oooooo00Coo`00ooooooooooooo`001oooool0
0ooo003oooooooooo`03ool003Wooooo0ooo0002ooooo`03ool00?oooooooooo00Gooooo00Coo`00
ooooooooooooo`001oooool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Ko
oooo00Coo`00oooooooooooooooo0ooo000iooooo`;oo`000oooool00ooo003oooooooooo`05oooo
o`04ool00?ooooooooooool000Oooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`004_ooool3o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo00Wooooo00?oo`00oooo
ooooool01Oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooooooo`?oo`00>Ooo
ool3ool000;ooooo00?oo`00ooooooooool01Oooool01?oo003ooooooooooooo0007ooooo`04ool0
0?ooooooooooool000Oooooo00?oo`00oooooooo00001oooool01?oo003oooooooooooooool2ool0
03Wooooo0ooo0003ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo00002?ooool00ooo
003o0000ool00008ooooo`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool00ooo000ioooo
o`?oo`000_ooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooool000Oooooo00Coo`00
ooooooooooooo`001oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooooooo`?o
o`00>Oooool2ool000?ooooo00?oo`00ooooooooool01Oooool01?oo003ooooooooooooo0007oooo
o`03ool00?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooool000Kooooo00Coo`00oooo
oooooooooooo0ooo000iooooo`?oo`000_ooool00ooo003oooooooooo`05ooooo`04ool00?oooooo
ooooool000Oooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooool00007ooooo`04ool0
0?ooooooooooooooo`;oo`00>_ooool2ool000?ooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooool00008ooooo`03ool00?l0003oo`0000Sooooo00?oo`00oooooooo00001oooool00ooo003o
ooooooooo`03ool003Wooooo0ooo0002ooooo`03ool00?oooooooooo00Gooooo00Coo`00oooooooo
ooooo`001oooool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Kooooo00Co
o`00oooooooooooooooo0ooo000iooooo`;oo`000oooool00ooo003oooooooooo`05ooooo`04ool0
0?ooooooooooool000Oooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`00
8oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00Gooooo00Coo`00oooooooooooo
o`001_ooool01?oo003oooooooooooooool3ool003Wooooo0ooo0002ooooo`03ool00?oooooooooo
00Gooooo00Coo`00ooooooooooooo`001oooool01?oo003ooooooooooooo0007ooooo`03ool00?oo
ooooo`0000Oooooo00Coo`00oooooooooooooooo0_oo000jooooo`;oo`000oooool00ooo003ooooo
ooooo`05ooooo`03ool00?ooooooo`0000Sooooo00?oo`00o`000?oo00002?ooool00ooo003ooooo
ool00007ooooo`03ool00?oooooooooo00?oo`00>Oooool3ool000;ooooo00?oo`00ooooooooool0
1_ooool00ooo003oooooool00007ooooo`04ool00?ooooooooooool000Oooooo00Coo`00oooooooo
ooooo`001_ooool01?oo003oooooooooooooool3ool003Wooooo0_oo0003ooooo`03ool00?oooooo
oooo00Gooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo000Sooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooool00007ooooo`04ool00?ooooooooooooooo`?oo`00>Oooool3ool000;ooooo00?o
o`00ooooooooool01Oooool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Oo
oooo00?oo`00oooooooo00001oooool01?oo003oooooooooooooool2ool003[ooooo0_oo0003oooo
o`03ool00?oooooooooo00Gooooo00?oo`00oooooooo00002?ooool00ooo003o0000ool00008oooo
o`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool00ooo000iooooo`?oo`000_ooool00ooo
003oooooooooo`06ooooo`03ool00?ooooooo`0000Oooooo00Coo`00ooooooooooooo`001oooool0
1?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooooooo`?oo`00>Oooool2ool000?ooooo
00?oo`00ooooooooool01Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool002?ooooo0_l00009ooooo`03ool00?oooooooooo00Kooooo
00?oo`00oooooooo00001oooool01?oo003oooooooooooooool3ool003Wooooo0ooo0002ooooo`03
ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooool00008oooo
o`03ool00?ooooooo`0000Oooooo00Coo`00oooooooooooooooo0_oo000jooooo`;oo`000oooool0
0ooo003oooooooooo`05ooooo`03ool00?ooooooo`0000Sooooo00?oo`00o`000?oo00002?ooool0
0ooo003oooooool00007ooooo`03ool00?oooooooooo00?oo`00>Oooool3ool000;ooooo00?oo`00
ooooooooool01_ooool00ooo003oooooool00007ooooo`04ool00?ooooooooooool000Oooooo00Co
o`00ooooooooooooo`001_ooool01?oo003oooooooooooooool3ool003Wooooo0_oo0003ooooo`03
ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooooooo`07oooo
o`?o00003?ooool002?ooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`06ooooo`03
ool00?ooooooo`0000Oooooo00Coo`00oooooooooooooooo0ooo000iooooo`03ool00?ooooooo`00
00;ooooo00?oo`00ooooooooool01Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooo
o`0000Sooooo00?oo`00oooooooo00001oooool01?oo003oooooooooooooool2ool003[ooooo0_oo
0003ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo00002?ooool00ooo003o0000ool0
0008ooooo`03ool00?ooooooo`0000Oooooo00?oo`00ooooooooool00ooo000iooooo`?oo`000_oo
ool00ooo003oooooooooo`06ooooo`03ool00?ooooooo`0000Oooooo00Coo`00ooooooooooooo`00
1oooool01?oo003ooooooooooooo0006ooooo`04ool00?ooooooooooooooo`?oo`00>Oooool00ooo
003oooooool00002ooooo`03ool00?oooooooooo00Gooooo00Coo`00ooooooooooooo`001oooool0
0ooo003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo
00Sooooo00?oo`00ooooooooool01_ooool00ooo003oooooool00008ooooo`03ool00?oooooooooo
00;oo`00>_ooool00ooo003oooooool00002ooooo`03ool00?oooooooooo00Gooooo00Coo`00oooo
ooooooooo`001oooool00ooo003oooooool00008ooooo`03ool00?ooooooo`0000Oooooo00Coo`00
oooooooooooooooo0_oo000jooooo`;oo`000oooool00ooo003oooooooooo`05ooooo`03ool00?oo
ooooo`0000Sooooo00?oo`00o`000?oo00002?ooool00ooo003oooooool00007ooooo`06ool00?oo
ooooooooool00?ooooooo`00>Oooool3ool000;ooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooool00007ooooo`04ool00?ooooooooooool000Oooooo00Coo`00ooooooooooooo`001_ooool0
1?oo003oooooooooooooool2ool003[ooooo00?oo`00oooooooo00000_ooool00ooo003ooooooooo
o`05ooooo`04ool00?ooooooooooool000Oooooo00?oo`00ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`008oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00Kooooo00?o
o`00oooooooo00002?ooool00ooo003oooooooooo`02ool003[ooooo00?oo`00oooooooo00000_oo
ool00ooo003oooooooooo`05ooooo`04ool00?ooooooooooool000Oooooo00?oo`00oooooooo0000
2?ooool00ooo003oooooool00007ooooo`04ool00?ooooooooooooooo`;oo`00>_ooool2ool000?o
oooo00?oo`00ooooooooool01Oooool00ooo003oooooool00008ooooo`03ool00?l0003oo`0000So
oooo00?oo`00oooooooo00001oooool01_oo003ooooooooooooo003oooooool003[ooooo0_oo0002
ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo00001oooool01?oo003ooooooooooooo
0007ooooo`04ool00?ooooooooooool000Kooooo00Coo`00oooooooooooooooo0_oo000jooooo`03
ool00?ooooooo`0000;ooooo00?oo`00ooooooooool01Oooool01?oo003ooooooooooooo0007oooo
o`03ool00?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000oooooooo
ool02?ooool00ooo003oooooooooo`06ooooo`03ool00?ooooooo`0000Sooooo00Coo`00oooooooo
ooooo`00?Oooool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Oooooo00?o
o`00oooooooo00002?ooool00ooo003oooooool00007ooooo`05ool00?oooooooooooooooooo0000
??ooool01Ooo003oooooooooooooooooo`0000Oooooo00?oo`00oooooooo00002?ooool00ooo003o
0000ool00008ooooo`03ool00?ooooooo`0000Oooooo00Coo`00ooooooooooooo`00?Oooool01?oo
003ooooooooooooo0008ooooo`03ool00?ooooooo`0000Oooooo00Coo`00ooooooooooooo`001ooo
ool01?oo003ooooooooooooo0006ooooo`05ool00?oooooooooooooooooo0000?Oooool01?oo003o
oooooooooooo0007ooooo`04ool00?ooooooooooool000Oooooo00?oo`00ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo
00Kooooo00?oo`00oooooooo00002?ooool01?oo003ooooooooooooo000mooooo`04ool00?oooooo
ooooool000Oooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooool00008ooooo`03ool0
0?ooooooo`0000Oooooo00Goo`00ooooooooooooooooool0000looooo`05ool00?oooooooooooooo
oooo00001oooool00ooo003oooooool00008ooooo`03ool00?l0003oo`0000Sooooo00?oo`00oooo
oooo00001oooool01?oo003ooooooooooooo000mooooo`04ool00?ooooooooooool000Sooooo00?o
o`00oooooooo00001oooool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Ko
oooo00Goo`00ooooooooooooooooool0000mooooo`04ool00?ooooooooooool000Oooooo00Coo`00
ooooooooooooo`001oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000S
ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool01_ooool00ooo003oooooool00008
ooooo`04ool00?ooooooooooool003gooooo00Coo`00ooooooooooooo`001oooool00ooo003ooooo
ool00008ooooo`03ool00?ooooooo`0000Sooooo00?oo`00oooooooo00001oooool01Ooo003ooooo
ooooooooooooo`0003cooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?ooooooo`00
00Sooooo00?oo`00o`000?oo00002?ooool00ooo003oooooool00007ooooo`04ool00?oooooooooo
ool003gooooo00Coo`00ooooooooooooo`002?ooool00ooo003oooooool00007ooooo`04ool00?oo
ooooooooool000Oooooo00Coo`00ooooooooooooo`001_ooool01Ooo003oooooooooooooooooo`00
03gooooo00Coo`00ooooooooooooo`001oooool01?oo003ooooooooooooo0007ooooo`03ool00?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool002?ooooo0_l00009ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00oooooooo00002?ooool01?oo003ooooooooooooo000mooooo`04ool00?oo
ooooooooool000Oooooo00?oo`00oooooooo00002?ooool00ooo003oooooool00008ooooo`03ool0
0?ooooooo`0000Oooooo00Goo`00ooooooooooooooooool0000looooo`05ool00?oooooooooooooo
oooo00001oooool00ooo003oooooool00008ooooo`03ool00?l0003oo`0000Sooooo00?oo`00oooo
oooo00001oooool01?oo003ooooooooooooo000mooooo`04ool00?ooooooooooool000Sooooo00?o
o`00oooooooo00001oooool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Ko
oooo00Goo`00ooooooooooooooooool0000mooooo`04ool00?ooooooooooool000Oooooo00Coo`00
ooooooooooooo`001oooool00ooo003oooooooooo`07ooooo`?o00003?ooool002?ooooo00?o0000
ooooooooool02?ooool00ooo003oooooooooo`06ooooo`03ool00?ooooooo`0000Sooooo00Coo`00
ooooooooooooo`00?Oooool01?oo003ooooooooooooo0007ooooo`03ool00?ooooooo`0000Sooooo
00?oo`00oooooooo00002?ooool00ooo003oooooool00007ooooo`05ool00?oooooooooooooooooo
0000??ooool01Ooo003oooooooooooooooooo`0000Oooooo00?oo`00oooooooo00002?ooool00ooo
003o0000ool00008ooooo`03ool00?ooooooo`0000Oooooo00Coo`00ooooooooooooo`00?Oooool0
1?oo003ooooooooooooo0008ooooo`03ool00?ooooooo`0000Oooooo00Coo`00ooooooooooooo`00
1oooool01?oo003ooooooooooooo0006ooooo`05ool00?oooooooooooooooooo0000?Oooool01?oo
003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Oooooo00?oo`00ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`08ooooo`03ool00?oooooo
oooo00Kooooo00?oo`00oooooooo00002?ooool01?oo003ooooooooooooo000mooooo`04ool00?oo
ooooooooool000Oooooo00?oo`00oooooooo00002?ooool00ooo003oooooool00008ooooo`03ool0
0?ooooooo`0000Oooooo00Goo`00ooooooooooooooooool0000looooo`05ool00?oooooooooooooo
oooo00001oooool00ooo003oooooool00008ooooo`03ool00?l0003oo`0000Sooooo00?oo`00oooo
oooo00001oooool01?oo003ooooooooooooo000mooooo`04ool00?ooooooooooool000Sooooo00?o
o`00oooooooo00001oooool01?oo003ooooooooooooo0007ooooo`04ool00?ooooooooooool000Ko
oooo00Goo`00ooooooooooooooooool0000mooooo`04ool00?ooooooooooool000Oooooo00Coo`00
ooooooooooooo`001oooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo000S
ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool01_ooool00ooo003oooooool00008
ooooo`04ool00?ooooooooooool003gooooo00Coo`00ooooooooooooo`001oooool00ooo003ooooo
ool00008ooooo`03ool00?ooooooo`0000Sooooo00?oo`00oooooooo00001oooool01Ooo003ooooo
ooooooooooooo`0003cooooo00Goo`00ooooooooooooooooool00007ooooo`03ool00?ooooooo`00
00Sooooo00?oo`00o`000?oo00002?ooool00ooo003oooooool00007ooooo`04ool00?oooooooooo
ool003gooooo00Coo`00ooooooooooooo`002?ooool00ooo003oooooool00007ooooo`03ool00?oo
ooooo`0000Sooooo00?oo`00oooooooo00001oooool01Ooo003oooooooooooooooooo`0003gooooo
00Coo`00ooooooooooooo`001oooool00ooo003oooooool00008ooooo`03ool00?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`06ooooo`03ool00?ooooooo`0000Sooooo00Coo`00ooooooooooooo`00?Oooool01?oo003o
oooooooooooo0007ooooo`03ool00?ooooooo`0000Sooooo00?oo`00oooooooo00002?ooool00ooo
003oooooool00007ooooo`05ool00?oooooooooooooooooo0000??ooool01Ooo003ooooooooooooo
ooooo`0000Oooooo00?oo`00oooooooo00002?ooool00ooo003o0000ool00008ooooo`03ool00?oo
ooooo`0000Oooooo00Coo`00ooooooooooooo`00?Oooool01?oo003ooooooooooooo0008ooooo`03
ool00?ooooooo`0000Oooooo00?oo`00oooooooo00002?ooool00ooo003oooooool00007ooooo`05
ool00?oooooooooooooooooo0000?Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oooooo
o`0000Sooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0
003oooooooooo`08ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooooooo00002?ooool01?oo
003ooooooooooooo000mooooo`04ool00?ooooooooooool000Oooooo00?oo`00oooooooo00002?oo
ool00ooo003oooooool00008ooooo`03ool00?ooooooo`0000Oooooo00Goo`00oooooooooooooooo
ool0000looooo`05ool00?oooooooooooooooooo00001oooool00ooo003oooooool00008ooooo`03
ool00?l0003oo`0000Sooooo00?oo`00oooooooo00001oooool01?oo003ooooooooooooo000moooo
o`04ool00?ooooooooooool000Sooooo00?oo`00oooooooo00001oooool00ooo003oooooool00008
ooooo`03ool00?ooooooo`0000Oooooo00Goo`00ooooooooooooooooool0000mooooo`04ool00?oo
ooooooooool000Oooooo00?oo`00oooooooo00002?ooool00ooo003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooool00008ooooo`04ool00?ooooooooooool003gooooo00Coo`00oooooooooooo
o`001oooool00ooo003oooooool00008ooooo`03ool00?ooooooo`0000Sooooo00?oo`00oooooooo
00001oooool01Ooo003oooooooooooooooooo`0003cooooo00Goo`00ooooooooooooooooool00007
ooooo`03ool00?ooooooo`0000Sooooo00?oo`00o`000?oo00002?ooool00ooo003oooooool00007
ooooo`04ool00?ooooooooooool003gooooo00Coo`00ooooooooooooo`002?ooool00ooo003ooooo
ool00007ooooo`03ool00?ooooooo`0000Sooooo00?oo`00oooooooo00001oooool01Ooo003ooooo
ooooooooooooo`0003gooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooool00008oooo
o`03ool00?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002?ooooo0_l00009ooooo`03
ool00?oooooooooo00Kooooo00?oo`00oooooooo00002?ooool01?oo003ooooooooooooo000moooo
o`04ool00?ooooooooooool000Oooooo00?oo`00oooooooo00002?ooool00ooo003oooooool00008
ooooo`03ool00?ooooooo`0000Oooooo00Goo`00ooooooooooooooooool0000mooooo`04ool00?oo
ooooooooool000Oooooo00?oo`00oooooooo00002?ooool00ooo003o0000ool00008ooooo`03ool0
0?ooooooo`0000Oooooo00Coo`00ooooooooooooo`00?Oooool01?oo003ooooooooooooo0008oooo
o`03ool00?ooooooo`0000Oooooo00?oo`00oooooooo00002?ooool00ooo003oooooool00007oooo
o`05ool00?oooooooooooooooooo0000?Oooool01?oo003ooooooooooooo0007ooooo`03ool00?oo
ooooo`0000Sooooo00?oo`00ooooooooool01oooool3o`0000cooooo000Sooooo`03o`000?oooooo
oooo00Sooooo00?oo`00ooooooooool01_ooool00ooo003oooooool00008ooooo`04ool00?oooooo
ooooool003gooooo00Coo`00ooooooooooooo`001oooool00ooo003oooooool00008ooooo`03ool0
0?ooooooo`0000Sooooo00?oo`00oooooooo00001oooool01Ooo003oooooooooooooooooo`0003go
oooo00Coo`00ooooooooooooo`001oooool00ooo003oooooool00008ooooo`03ool00?l0003oo`00
00Sooooo00?oo`00oooooooo00001oooool01?oo003ooooooooooooo000mooooo`04ool00?oooooo
ooooool000Sooooo0_oo0008ooooo`03ool00?ooooooo`0000Sooooo00?oo`00oooooooo00001ooo
ool01Ooo003oooooooooooooooooo`0003gooooo00Coo`00ooooooooooooo`001oooool00ooo003o
ooooool00008ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool02_ooool002?ooooo
00?o0000ooooooooool02?ooool00ooo003oooooooooo`06ooooo`03ool00?ooooooo`0000Sooooo
00Coo`00ooooooooooooo`00?Oooool01?oo003ooooooooooooo0007ooooo`03ool00?ooooooo`00
00Sooooo00?oo`00oooooooo00002?ooool00ooo003oooooool00007ooooo`05ool00?oooooooooo
oooooooo0000?Oooool01?oo003ooooooooooooo0007ooooo`03ool00?ooooooo`0000Sooooo00?o
o`00o`000?oo00002?ooool00ooo003oooooool00007ooooo`04ool00?ooooooooooool003gooooo
00Coo`00ooooooooooooo`002?ooool2ool000Sooooo00?oo`00oooooooo00002?ooool00ooo003o
ooooool00007ooooo`05ool00?oooooooooooooooooo0000?Oooool01?oo003ooooooooooooo0007
ooooo`03ool00?ooooooo`0000Sooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`008oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
oooo00002?ooool01?oo003ooooooooooooo000mooooo`04ool00?ooooooooooool000Oooooo00?o
o`00oooooooo00002?ooool00ooo003oooooool00008ooooo`03ool00?ooooooo`0000Oooooo00Go
o`00ooooooooooooooooool0000mooooo`04ool00?ooooooooooool000Oooooo00?oo`00oooooooo
00002?ooool00ooo003o0000ool00008ooooo`03ool00?ooooooo`0000Oooooo00Coo`00oooooooo
ooooo`00?Oooool01?oo003ooooooooooooo0008ooooo`;oo`002?ooool00ooo003oooooool00008
ooooo`03ool00?ooooooo`0000Oooooo00Goo`00ooooooooooooooooool0000mooooo`04ool00?oo
ooooooooool000Oooooo00?oo`00oooooooo00002?ooool00ooo003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool01_oo
ool00ooo003oooooool00008ooooo`04ool00?ooooooooooool003gooooo00Coo`00oooooooooooo
o`001oooool00ooo003oooooool00008ooooo`03ool00?ooooooo`0000Sooooo00?oo`00oooooooo
00001oooool01Ooo003oooooooooooooooooo`0003gooooo00?oo`00oooooooo00002?ooool00ooo
003oooooool00008ooooo`03ool00?l0003oo`0000Sooooo00?oo`00oooooooo00001oooool01?oo
003ooooooooooooo000mooooo`04ool00?ooooooooooool000Sooooo0_oo0008ooooo`03ool00?oo
ooooo`0000Wooooo0_oo0007ooooo`05ool00?oooooooooooooooooo0000?Oooool01?oo003ooooo
oooooooo0007ooooo`03ool00?ooooooo`0000Sooooo00?oo`00ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`004oooool3o`0000?ooooo0_l00008ooooo`03o`000?oooooooooo00Sooooo
00?oo`00ooooooooool01oooool2ool000Sooooo00Coo`00ooooooooooooo`00?Oooool01?oo003o
oooooooooooo0008ooooo`;oo`002?ooool00ooo003oooooool00008ooooo`03ool00?ooooooo`00
00Oooooo00Goo`00ooooooooooooooooool0000mooooo`03ool00?ooooooo`0000Sooooo00?oo`00
oooooooo00002?ooool00ooo003o0000ool00008ooooo`03ool00?ooooooo`0000Oooooo00Coo`00
ooooooooooooo`00?Oooool01?oo003ooooooooooooo0008ooooo`;oo`002Oooool2ool000Wooooo
0_oo0007ooooo`05ool00?oooooooooooooooooo0000?Oooool01?oo003ooooooooooooo0007oooo
o`03ool00?ooooooo`0000Sooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`005?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`03ool00?oooooooooo00Oooooo0_oo0008ooooo`04ool00?oooooooooo
ool003gooooo00Coo`00ooooooooooooo`002?ooool2ool000Sooooo00?oo`00oooooooo00002?oo
ool00ooo003oooooool00007ooooo`05ool00?oooooooooooooooooo0000?Oooool00ooo003ooooo
ool00008ooooo`03ool00?ooooooo`0000Sooooo00?oo`00o`000?oo00002?ooool00ooo003ooooo
ool00007ooooo`04ool00?ooooooooooool003gooooo00Coo`00ooooooooooooo`002?ooool2ool0
00Wooooo0_oo0009ooooo`;oo`001oooool01Ooo003oooooooooooooooooo`0003gooooo00Coo`00
ooooooooooooo`001oooool00ooo003oooooool00008ooooo`03ool00?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool0017ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Oooooo0ol0
0008ooooo`03ool00?oooooooooo00Oooooo0_oo0008ooooo`04ool00?ooooooooooool003gooooo
00Coo`00ooooooooooooo`002?ooool2ool000Sooooo00?oo`00oooooooo00002?ooool00ooo003o
ooooool00007ooooo`05ool00?oooooooooooooooooo0000?Oooool00ooo003oooooool00008oooo
o`03ool00?ooooooo`0000Sooooo00?oo`00o`000?oo00002?ooool00ooo003oooooool00007oooo
o`04ool00?ooooooooooool003gooooo00Coo`00ooooooooooooo`002?ooool2ool000Wooooo0_oo
0009ooooo`;oo`001oooool01Ooo003oooooooooooooooooo`0003gooooo00Coo`00oooooooooooo
o`001oooool00ooo003oooooool00008ooooo`03ool00?oooooooooo00Kooooo1?l0000<ooooo`00
4Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ooooool02?ooool00ooo003oooooooooo`07ooooo`;oo`002?ooool01?oo003ooooooooooooo000m
ooooo`04ool00?ooooooooooool000Sooooo0_oo0008ooooo`03ool00?ooooooo`0000Sooooo00?o
o`00oooooooo00001oooool01Ooo003oooooooooooooooooo`0003gooooo00?oo`00oooooooo0000
2?ooool00ooo003oooooool00008ooooo`03ool00?l0003oo`0000Sooooo00?oo`00oooooooo0000
1oooool01?oo003ooooooooooooo000mooooo`04ool00?ooooooooooool000Sooooo0_oo0009oooo
o`;oo`002Oooool2ool000Oooooo00Goo`00ooooooooooooooooool0000mooooo`04ool00?oooooo
ooooool000Sooooo0_oo0008ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool001;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooooooo00Sooooo00?oo`00ooooooooool01oooool2ool000Sooooo00Coo`00ooooooooooooo`00
?Oooool01?oo003ooooooooooooo0008ooooo`;oo`002?ooool00ooo003oooooool00008ooooo`03
ool00?ooooooo`0000Oooooo00Goo`00ooooooooooooooooool0000mooooo`03ool00?ooooooo`00
00Sooooo00?oo`00oooooooo00002?ooool00ooo003o0000ool00008ooooo`;oo`002?ooool01?oo
003ooooooooooooo000mooooo`04ool00?ooooooooooool000Sooooo0_oo0009ooooo`;oo`002Ooo
ool2ool000Oooooo00Goo`00ooooooooooooooooool0000mooooo`04ool00?ooooooooooool000So
oooo0_oo0008ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool02_ooool001?ooooo
0_l00003ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02?ooool00ooo003o
ooooooooo`07ooooo`;oo`002?ooool01?oo003ooooooooooooo000mooooo`04ool00?oooooooooo
ool000Sooooo0_oo0008ooooo`03ool00?ooooooo`0000Sooooo00?oo`00oooooooo00001oooool0
1Ooo003oooooooooooooooooo`0003gooooo00?oo`00oooooooo00002?ooool00ooo003oooooool0
0008ooooo`03ool00?l0003oo`0000Sooooo0_oo0008ooooo`04ool00?ooooooooooool003gooooo
00Coo`00ooooooooooooo`002?ooool2ool000Wooooo0_oo0009ooooo`;oo`002?ooool01?oo003o
oooooooooooo000mooooo`04ool00?ooooooooooool000Sooooo0_oo0008ooooo`03ool00?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool001Cooooo00?o0000ooooooooool00_ooool2o`00
00Sooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`07ooooo`;oo`002?ooool01?oo
003ooooooooooooo000mooooo`04ool00?ooooooooooool000Sooooo0_oo0008ooooo`03ool00?oo
ooooo`0000Sooooo00?oo`00oooooooo00001oooool01Ooo003oooooooooooooooooo`0003gooooo
00?oo`00oooooooo00002?ooool2ool000Wooooo00?oo`00o`000?oo00002?ooool2ool000Sooooo
00Coo`00ooooooooooooo`00?Oooool01?oo003ooooooooooooo0008ooooo`;oo`002Oooool2ool0
00Wooooo0_oo0008ooooo`04ool00?ooooooooooool003gooooo00Coo`00ooooooooooooo`002?oo
ool2ool000Sooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`008oooool0
0ol0003oooooooooo`08ooooo`03ool00?oooooooooo00Oooooo0_oo0008ooooo`04ool00?oooooo
ooooool003gooooo00Coo`00ooooooooooooo`002?ooool2ool000Sooooo00?oo`00oooooooo0000
2?ooool00ooo003oooooool00007ooooo`05ool00?oooooooooooooooooo0000?Oooool00ooo003o
ooooool00008ooooo`;oo`002Oooool00ooo003o0000ool00008ooooo`;oo`002?ooool01?oo003o
oooooooooooo000mooooo`04ool00?ooooooooooool000Sooooo0_oo0009ooooo`;oo`002Oooool2
ool000Sooooo00Coo`00ooooooooooooo`00?Oooool01?oo003ooooooooooooo0008ooooo`;oo`00
2Oooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oo
oooooooo00Sooooo00?oo`00ooooooooool01oooool2ool000Sooooo00Coo`00ooooooooooooo`00
?Oooool01?oo003ooooooooooooo0008ooooo`;oo`002?ooool00ooo003oooooool00008ooooo`03
ool00?ooooooo`0000Oooooo00Goo`00ooooooooooooooooool0000mooooo`03ool00?ooooooo`00
00Sooooo0_oo0009ooooo`;oo`002Oooool2ool000Sooooo00Coo`00ooooooooooooo`00?Oooool0
1?oo003ooooooooooooo0008ooooo`;oo`002Oooool2ool000Wooooo0_oo0008ooooo`04ool00?oo
ooooooooool003gooooo00Coo`00ooooooooooooo`002?ooool2ool000Wooooo00?oo`00oooooooo
ool02?ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`08ooooo`03ool0
0?oooooooooo00Oooooo0_oo0008ooooo`04ool00?ooooooooooool003gooooo00Coo`00oooooooo
ooooo`002?ooool2ool000Wooooo0_oo0008ooooo`03ool00?ooooooo`0000Sooooo00Coo`00oooo
ooooooooo`00?Oooool00ooo003oooooool00008ooooo`;oo`002Oooool2ool000Wooooo0_oo0008
ooooo`04ool00?ooooooooooool003gooooo00Coo`00ooooooooooooo`002?ooool2ool000Wooooo
0_oo0009ooooo`;oo`002?ooool01?oo003ooooooooooooo000mooooo`04ool00?ooooooooooool0
00Sooooo0_oo0009ooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002?o
oooo0_l00009ooooo`03ool00?oooooooooo00Oooooo0_oo0008ooooo`04ool00?ooooooooooool0
03gooooo00Coo`00ooooooooooooo`002?ooool2ool000Wooooo0_oo0008ooooo`;oo`002Oooool0
1?oo003ooooooooooooo000mooooo`03ool00?ooooooo`0000Sooooo0_oo0009ooooo`;oo`002Ooo
ool2ool000Sooooo00Coo`00ooooooooooooo`00?Oooool01?oo003ooooooooooooo0008ooooo`;o
o`002Oooool2ool000Wooooo0_oo0008ooooo`04ool00?ooooooooooool003gooooo00Coo`00oooo
ooooooooo`002?ooool2ool000Wooooo00?oo`00ooooooooool01_ooool3o`0000cooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool01oooool2ool000Sooooo00Coo`00oooo
ooooooooo`00?Oooool01?oo003ooooooooooooo0008ooooo`;oo`002Oooool2ool000Wooooo00?o
o`00ooooooooool01oooool01?oo003ooooooooooooo000mooooo`03ool00?ooooooo`0000Sooooo
0_oo0009ooooo`;oo`002Oooool2ool000Wooooo00?oo`00oooooooo0000?Oooool01?oo003ooooo
oooooooo0008ooooo`;oo`002Oooool2ool000Wooooo0_oo0008ooooo`04ool00?ooooooooooool0
03gooooo00Coo`00ooooooooooooo`002?ooool2ool000Wooooo00?oo`00ooooooooool02?ooool0
0ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo
00Oooooo0_oo0008ooooo`04ool00?ooooooooooool003gooooo00Coo`00ooooooooooooo`002?oo
ool2ool000Wooooo0_oo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`00
?Oooool00ooo003oooooool00008ooooo`;oo`002Oooool2ool000Wooooo0_oo0009ooooo`03ool0
0?ooooooo`0003gooooo00Coo`00ooooooooooooo`002?ooool2ool000Wooooo0_oo0009ooooo`;o
o`002?ooool01?oo003ooooooooooooo000mooooo`04ool00?ooooooooooool000Sooooo0_oo0009
ooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000oooo
ooooool02?ooool00ooo003oooooooooo`07ooooo`;oo`002?ooool01?oo003ooooooooooooo000m
ooooo`03ool00?ooooooo`0000Wooooo0_oo0009ooooo`;oo`002Oooool00ooo003oooooooooo`07
ooooo`04ool00?ooooooooooool003gooooo00?oo`00oooooooo00002?ooool2ool000Wooooo0_oo
0009ooooo`;oo`002Oooool00ooo003oooooool0000mooooo`04ool00?ooooooooooool000Sooooo
0_oo0009ooooo`;oo`002Oooool2ool000Sooooo00Coo`00ooooooooooooo`00?Oooool01?oo003o
oooooooooooo0008ooooo`;oo`002Oooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo
00[ooooo000Sooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool01oooool2ool000So
oooo00Coo`00ooooooooooooo`00?Oooool00ooo003oooooool00009ooooo`;oo`002Oooool00ooo
003oooooooooo`08ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`00?Oooool0
0ooo003oooooool00009ooooo`03ool00?oooooooooo00Oooooo0_oo0009ooooo`;oo`002Oooool0
0ooo003oooooool0000mooooo`04ool00?ooooooooooool000Sooooo0_oo0009ooooo`;oo`002Ooo
ool2ool000Sooooo00Coo`00ooooooooooooo`00?Oooool01?oo003ooooooooooooo0008ooooo`;o
o`002Oooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`00
0?oooooooooo00Sooooo00?oo`00ooooooooool01oooool2ool000Sooooo00Coo`00oooooooooooo
o`00?Oooool00ooo003oooooool00009ooooo`;oo`002Oooool00ooo003oooooooooo`08ooooo`03
ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`00?Oooool00ooo003oooooool00009oooo
o`03ool00?oooooooooo00Oooooo0_oo0009ooooo`;oo`002Oooool00ooo003oooooool0000moooo
o`04ool00?ooooooooooool000Sooooo0_oo0009ooooo`;oo`002Oooool2ool000Sooooo00Coo`00
ooooooooooooo`00?Oooool01?oo003ooooooooooooo0008ooooo`;oo`002Oooool00ooo003ooooo
ooooo`08ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo00Sooooo00?o
o`00ooooooooool01oooool00ooo003oooooooooo`07ooooo`04ool00?ooooooooooool003gooooo
00?oo`00oooooooo00002Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Sooooo
00?oo`00ooooooooool01oooool01?oo003ooooooooooooo000mooooo`03ool00?ooooooo`0000Wo
oooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`07ooooo`;oo`002Oooool00ooo003o
ooooool0000mooooo`04ool00?ooooooooooool000Sooooo0_oo0009ooooo`;oo`002Oooool2ool0
00Sooooo00Coo`00ooooooooooooo`00?Oooool01?oo003ooooooooooooo0008ooooo`03ool00?oo
oooooooo00Sooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`008oooool2
o`0000Sooooo0_oo0009ooooo`03ool00?oooooooooo00Oooooo00Coo`00ooooooooooooo`00?Ooo
ool00ooo003oooooool00009ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02?oo
ool00ooo003oooooooooo`07ooooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo00002Ooo
ool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool01ooo
ool00ooo003oooooool0000mooooo`04ool00?ooooooooooool000Wooooo00?oo`00ooooooooool0
1oooool2ool000Wooooo00?oo`00ooooooooool01oooool01?oo003ooooooooooooo000mooooo`04
ool00?ooooooooooool000Sooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`06oooo
o`?o00003?ooool002?ooooo00?o0000ooooooooool07?ooool01?oo003ooooooooooooo000moooo
o`03ool00?ooooooo`0002Wooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Doooo
o`03o`000?oooooooooo01;ooooo00?oo`00oooooooo0000?Oooool01?oo003ooooooooooooo000X
ooooo`04ool00?ooooooooooool003gooooo00Coo`00ooooooooooooo`007_ooool00ol0003ooooo
ooooo`0:ooooo`008oooool00ol0003oooooooooo`0Looooo`04ool00?ooooooooooool003gooooo
00?oo`00oooooooo0000:Oooool00ooo003oooooool0000nooooo`03ool00?ooooooo`0001Cooooo
00?o0000ooooooooool04_ooool00ooo003oooooool0000mooooo`04ool00?ooooooooooool002So
oooo00Coo`00ooooooooooooo`00?Oooool01?oo003ooooooooooooo000Nooooo`03o`000?oooooo
oooo00[ooooo000Sooooo`03o`000?oooooooooo01cooooo00Coo`00ooooooooooooo`00?Oooool0
0ooo003oooooool0000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo00005?ooool0
0ol0003oooooooooo`0Booooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo0000:?ooool0
1?oo003ooooooooooooo000mooooo`04ool00?ooooooooooool001kooooo00?o0000ooooooooool0
2_ooool002?ooooo00?o0000ooooooooool07?ooool01?oo003ooooooooooooo000mooooo`03ool0
0?ooooooo`0002Wooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Dooooo`03o`00
0?oooooooooo01;ooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Xooooo`04ool0
0?ooooooooooool003gooooo00Coo`00ooooooooooooo`007_ooool00ol0003oooooooooo`0:oooo
o`008oooool00ol0003oooooooooo`0Looooo`04ool00?ooooooooooool003gooooo00?oo`00oooo
oooo0000:Oooool00ooo003oooooool0000nooooo`03ool00?ooooooo`0001Cooooo00?o0000oooo
ooooool04_ooool00ooo003oooooool0000nooooo`03ool00?ooooooo`0002Sooooo00Coo`00oooo
ooooooooo`00?Oooool01?oo003ooooooooooooo000Nooooo`03o`000?oooooooooo00[ooooo000S
ooooo`03o`000?oooooooooo01cooooo00Coo`00ooooooooooooo`00?Oooool00ooo003oooooool0
000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo00005?ooool00ol0003ooooooooo
o`0Booooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo0000:?ooool01?oo003ooooooooo
oooo000mooooo`04ool00?ooooooooooool001kooooo00?o0000ooooooooool02_ooool002?ooooo
0_l0000Mooooo`04ool00?ooooooooooool003gooooo00?oo`00oooooooo0000:Oooool00ooo003o
ooooool0000nooooo`03ool00?ooooooo`0001Cooooo00?o0000ooooooooool04_ooool00ooo003o
ooooool0000nooooo`03ool00?ooooooo`0002Sooooo00Coo`00ooooooooooooo`00?Oooool01?oo
003ooooooooooooo000Looooo`?o00003?ooool002?ooooo00?o0000ooooooooool07?ooool01?oo
003ooooooooooooo000mooooo`03ool00?ooooooo`0002Wooooo00?oo`00oooooooo0000?_ooool0
0ooo003oooooool0000Dooooo`03o`000?oooooooooo01;ooooo00?oo`00oooooooo0000?_ooool0
0ooo003oooooool0000Xooooo`04ool00?ooooooooooool003gooooo00Coo`00ooooooooooooo`00
7_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Looooo`04ool00?oo
ooooooooool003gooooo00?oo`00oooooooo0000:Oooool00ooo003oooooool0000nooooo`03ool0
0?ooooooo`0001Cooooo00?o0000ooooooooool04_ooool00ooo003oooooool0000nooooo`03ool0
0?ooooooo`0002Sooooo00Coo`00ooooooooooooo`00?Oooool01?oo003ooooooooooooo000Noooo
o`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo01cooooo00Coo`00oooooooo
ooooo`00?Oooool00ooo003oooooool0000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooo
oooo00005?ooool00ol0003oooooooooo`0Booooo`03ool00?ooooooo`0003kooooo00?oo`00oooo
oooo0000:?ooool01?oo003ooooooooooooo000mooooo`04ool00?ooooooooooool001kooooo00?o
0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool07?ooool01?oo003ooooooooooooo
000mooooo`03ool00?ooooooo`0002Wooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0
000Dooooo`03o`000?oooooooooo01;ooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0
000Xooooo`04ool00?ooooooooooool003gooooo00Coo`00ooooooooooooo`007_ooool00ol0003o
ooooooooo`0:ooooo`004_ooool3o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo01cooooo
00Coo`00ooooooooooooo`00?Oooool00ooo003oooooool0000Yooooo`03ool00?ooooooo`0003ko
oooo00?oo`00oooooooo00005?ooool00ol0003oooooooooo`0Booooo`03ool00?ooooooo`0003ko
oooo00?oo`00oooooooo0000:?ooool01?oo003ooooooooooooo000mooooo`04ool00?oooooooooo
ool001kooooo00?o0000ooooooooool02_ooool0017ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool07?ooool01?oo003ooooooooo
oooo000mooooo`03ool00?ooooooo`0002Wooooo00?oo`00oooooooo0000?_ooool00ooo003ooooo
ool0000Dooooo`03o`000?oooooooooo01;ooooo00?oo`00oooooooo0000?_ooool00ooo003ooooo
ool0000Xooooo`04ool00?ooooooooooool003gooooo00Coo`00ooooooooooooo`007_ooool00ol0
003oooooooooo`0:ooooo`004Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00001oooool3o`0001cooooo00Coo`00ooooooooooooo`00?Oooool00ooo003oooooool0
000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo00005?ooool00ol0003ooooooooo
o`0Booooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo0000:?ooool01?oo003ooooooooo
oooo000mooooo`04ool00?ooooooooooool001_ooooo1?l0000<ooooo`004Oooool4o`0000?ooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Looooo`04ool00?ooooooooooool0
03gooooo00?oo`00oooooooo0000:Oooool00ooo003oooooool0000nooooo`03ool00?ooooooo`00
01Cooooo00?o0000ooooooooool04_ooool00ooo003oooooool0000nooooo`03ool00?ooooooo`00
02Sooooo00Coo`00ooooooooooooo`00?Oooool01?oo003ooooooooooooo000Nooooo`03o`000?oo
oooooooo00[ooooo000Aooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`0Looooo`04ool00?ooooooooooool003gooooo00?oo`00oooooooo0000
:Oooool00ooo003oooooool0000nooooo`03ool00?ooooooo`0001Cooooo00?o0000ooooooooool0
4_ooool00ooo003oooooool0000nooooo`03ool00?ooooooo`0002Sooooo00Coo`00oooooooooooo
o`00?Oooool01?oo003ooooooooooooo000Nooooo`03o`000?oooooooooo00[ooooo000Booooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Loooo
o`04ool00?ooooooooooool003gooooo00?oo`00oooooooo0000:Oooool00ooo003oooooool0000n
ooooo`03ool00?ooooooo`0001Cooooo00?o0000ooooooooool04_ooool00ooo003oooooool0000n
ooooo`03ool00?ooooooo`0002Sooooo00Coo`00ooooooooooooo`00?Oooool01?oo003ooooooooo
oooo000Nooooo`03o`000?oooooooooo00[ooooo000Cooooo`;o00001?ooool2o`0000Sooooo00?o
0000ooooooooool07?ooool01?oo003ooooooooooooo000mooooo`03ool00?ooooooo`0002Wooooo
00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Dooooo`03o`000?oooooooooo01;ooooo
00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Xooooo`04ool00?ooooooooooool003go
oooo00Coo`00ooooooooooooo`007_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003o
ooooooooo`0Looooo`04ool00?ooooooooooool003gooooo00?oo`00oooooooo0000:Oooool00ooo
003oooooool0000nooooo`03ool00?ooooooo`0001Cooooo00?o0000ooooooooool04_ooool00ooo
003oooooool0000nooooo`03ool00?ooooooo`0002Sooooo00Coo`00ooooooooooooo`00?Oooool0
1?oo003ooooooooooooo000Nooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooo
oooo01cooooo00Coo`00ooooooooooooo`00?Oooool00ooo003oooooool0000Yooooo`03ool00?oo
ooooo`0003kooooo00?oo`00oooooooo00005?ooool00ol0003oooooooooo`0Booooo`03ool00?oo
ooooo`0003kooooo00?oo`00oooooooo0000:?ooool01?oo003ooooooooooooo000mooooo`04ool0
0?ooooooooooool001kooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool0
7?ooool01?oo003ooooooooooooo000mooooo`03ool00?ooooooo`0002Wooooo00?oo`00oooooooo
0000?_ooool00ooo003oooooool0000Dooooo`03o`000?oooooooooo01;ooooo00?oo`00oooooooo
0000?_ooool00ooo003oooooool0000Xooooo`04ool00?ooooooooooool003gooooo00?oo`00oooo
oooo00007oooool00ol0003oooooooooo`0:ooooo`008oooool2o`0001gooooo00Coo`00oooooooo
ooooo`00?Oooool00ooo003oooooool0000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooo
oooo00005?ooool00ol0003oooooooooo`0Booooo`03ool00?ooooooo`0003kooooo00?oo`00oooo
oooo0000:?ooool00ooo003oooooool0000nooooo`03ool00?ooooooo`0001gooooo0ol0000<oooo
o`008oooool00ol0003oooooooooo`0Looooo`04ool00?ooooooooooool003gooooo00?oo`00oooo
oooo0000:Oooool00ooo003oooooool0000nooooo`03ool00?ooooooo`0001Cooooo00?o0000oooo
ooooool04_ooool00ooo003oooooool0000nooooo`03ool00?ooooooo`0002Sooooo00?oo`00oooo
oooo0000?_ooool00ooo003oooooool0000Oooooo`03o`000?oooooooooo00[ooooo000Sooooo`03
o`000?oooooooooo01cooooo00Coo`00ooooooooooooo`00?Oooool00ooo003oooooool0000Yoooo
o`03ool00?ooooooo`0003kooooo00?oo`00oooooooo00005?ooool00ol0003oooooooooo`0Boooo
o`03ool00?ooooooo`0003kooooo00?oo`00oooooooo0000:?ooool00ooo003oooooool0000noooo
o`03ool00?ooooooo`0001oooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000oooooooo
ool07?ooool01?oo003ooooooooooooo000mooooo`03ool00?ooooooo`0002Wooooo00?oo`00oooo
oooo0000?_ooool00ooo003oooooool0000Dooooo`03o`000?oooooooooo01;ooooo00?oo`00oooo
oooo0000?_ooool00ooo003oooooool0000Xooooo`03ool00?ooooooo`0003kooooo00?oo`00oooo
oooo00007oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Looooo`04
ool00?ooooooooooool003gooooo00?oo`00oooooooo0000:Oooool00ooo003oooooool0000noooo
o`03ool00?ooooooo`0001Cooooo00?o0000ooooooooool04_ooool00ooo003oooooool0000noooo
o`03ool00?ooooooo`0002Sooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Ooooo
o`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo01cooooo00Coo`00oooooooo
ooooo`00?Oooool00ooo003oooooool0000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooo
oooo00005?ooool00ol0003oooooooooo`0Booooo`03ool00?ooooooo`0003kooooo00?oo`00oooo
oooo0000:?ooool00ooo003oooooool0000nooooo`03ool00?ooooooo`0001oooooo00?o0000oooo
ooooool02_ooool002?ooooo00?o0000ooooooooool07?ooool00ooo003oooooool0000nooooo`03
ool00?ooooooo`0002Wooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Dooooo`03
o`000?oooooooooo01;ooooo0_oo000oooooo`;oo`00:Oooool00ooo003oooooool0000nooooo`03
ool00?ooooooo`0001oooooo00?o0000ooooooooool02_ooool002?ooooo0_l0000Mooooo`03ool0
0?ooooooo`0003kooooo00?oo`00oooooooo0000:Oooool00ooo003oooooool0000nooooo`03ool0
0?ooooooo`0001Cooooo00?o0000ooooooooool04_ooool2ool003oooooo0_oo000Yooooo`03ool0
0?ooooooo`0003kooooo00?oo`00oooooooo00007Oooool3o`0000cooooo000Sooooo`03o`000?oo
oooooooo01cooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Yooooo`03ool00?oo
ooooo`0003kooooo00?oo`00oooooooo00005?ooool00ol0003oooooooooo`0Booooo`;oo`00?ooo
ool2ool002Wooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Oooooo`03o`000?oo
oooooooo00[ooooo000Sooooo`03o`000?oooooooooo01cooooo00?oo`00oooooooo0000?_ooool0
0ooo003oooooool0000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo00005?ooool0
0ol0003oooooooooo`0Booooo`;oo`00?oooool2ool002Wooooo00?oo`00oooooooo0000?_ooool0
0ooo003oooooool0000Oooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo
01cooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Yooooo`03ool00?ooooooo`00
03kooooo00?oo`00oooooooo00005?ooool00ol0003oooooooooo`0Booooo`;oo`00?oooool2ool0
02Wooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Oooooo`03o`000?oooooooooo
00[ooooo000Sooooo`03o`000?oooooooooo01cooooo00?oo`00oooooooo0000?_ooool00ooo003o
ooooool0000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo00005?ooool00ol0003o
ooooooooo`0Booooo`;oo`00?oooool2ool002Wooooo00?oo`00oooooooo0000?_ooool00ooo003o
ooooool0000Oooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo01cooooo
00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Yooooo`03ool00?ooooooo`0003kooooo
00?oo`00oooooooo00005?ooool00ol0003oooooooooo`0Booooo`;oo`00?oooool2ool002Wooooo
00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Oooooo`03o`000?oooooooooo00[ooooo
000Sooooo`03o`000?oooooooooo01cooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0
000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo00005?ooool00ol0003ooooooooo
o`0Booooo`;oo`00?oooool2ool002Wooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0
000Oooooo`03o`000?oooooooooo00[ooooo000Sooooo`;o00007Oooool00ooo003oooooool0000n
ooooo`03ool00?ooooooo`0002Wooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000D
ooooo`03o`000?oooooooooo01;ooooo0_oo000oooooo`;oo`00:Oooool00ooo003oooooool0000n
ooooo`03ool00?ooooooo`0001gooooo0ol0000<ooooo`008oooool00ol0003oooooooooo`0Loooo
o`03ool00?ooooooo`0003kooooo00?oo`00oooooooo0000:Oooool00ooo003oooooool0000noooo
o`03ool00?ooooooo`0001Cooooo00?o0000ooooooooool04_ooool2ool003oooooo0_oo000Yoooo
o`03ool00?ooooooo`0003kooooo00?oo`00oooooooo00007oooool00ol0003oooooooooo`0:oooo
o`008oooool00ol0003oooooooooo`0Looooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo
0000:Oooool00ooo003oooooool0000nooooo`03ool00?ooooooo`0001Cooooo00?o0000oooooooo
ool04_ooool2ool003oooooo0_oo000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo
00007oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Looooo`03ool0
0?ooooooo`0003kooooo00?oo`00oooooooo0000:Oooool00ooo003oooooool0000nooooo`03ool0
0?ooooooo`0001Cooooo00?o0000ooooooooool04_ooool2ool003oooooo0_oo000Yooooo`03ool0
0?ooooooo`0003kooooo00?oo`00oooooooo00007oooool00ol0003oooooooooo`0:ooooo`008ooo
ool00ol0003oooooooooo`0Looooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo0000:Ooo
ool00ooo003oooooool0000nooooo`03ool00?ooooooo`0001Cooooo00?o0000ooooooooool04_oo
ool2ool003oooooo0_oo000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo00007ooo
ool00ol0003oooooooooo`0:ooooo`004_ooool3o`0000Cooooo0_l00008ooooo`03o`000?oooooo
oooo01cooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Yooooo`03ool00?oooooo
o`0003kooooo00?oo`00oooooooo00005?ooool00ol0003oooooooooo`0Booooo`;oo`00?oooool2
ool002Wooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Oooooo`03o`000?oooooo
oooo00[ooooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo01cooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0
000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo00005?ooool00ol0003ooooooooo
o`0Booooo`;oo`00?oooool2ool002Wooooo00?oo`00oooooooo0000?oooool2ool001oooooo00?o
0000ooooooooool02_ooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Oooooo0ol0000Mooooo`;oo`00?_ooool00ooo003oooooool0000Yooooo`03ool0
0?ooooooo`0003kooooo00?oo`00oooooooo00005?ooool00ol0003oooooooooo`0Booooo`;oo`00
?oooool2ool002[ooooo0_oo000oooooo`;oo`007?ooool4o`0000cooooo000Booooo`?o00000ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01gooooo0_oo000nooooo`03ool0
0?ooooooo`0002Wooooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Dooooo`03o`00
0?oooooooooo01;ooooo0_oo000oooooo`;oo`00:_ooool2ool003oooooo0_oo000Oooooo`03o`00
0?oooooooooo00[ooooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo01gooooo0_oo000nooooo`03ool00?ooooooo`0002Wo
oooo00?oo`00oooooooo0000?_ooool00ooo003oooooool0000Dooooo`03o`000?oooooooooo01;o
oooo0_oo000oooooo`;oo`00:_ooool2ool003oooooo0_oo000Oooooo`03o`000?oooooooooo00[o
oooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo01gooooo0_oo000oooooo`;oo`00:Oooool00ooo003oooooool0000noooo
o`03ool00?ooooooo`0001Cooooo00?o0000ooooooooool04_ooool2ool003oooooo0_oo000Zoooo
o`;oo`00?oooool2ool001oooooo00?o0000ooooooooool02_ooool001;ooooo0ol00004ooooo`;o
00002?ooool00ol0003oooooooooo`0Mooooo`;oo`00?oooool2ool002Wooooo00?oo`00oooooooo
0000?_ooool00ooo003oooooool0000Dooooo`03o`000?oooooooooo01;ooooo0_oo000oooooo`;o
o`00:_ooool2ool003oooooo0_oo000Oooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`00
0?oooooooooo01gooooo0_oo000oooooo`;oo`00:Oooool00ooo003oooooool0000nooooo`03ool0
0?ooooooo`0001Cooooo00?o0000ooooooooool04_ooool2ool003oooooo0_oo000Zooooo`;oo`00
?oooool2ool001oooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool07Ooo
ool2ool003oooooo0_oo000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo00005?oo
ool00ol0003oooooooooo`0Booooo`;oo`00?oooool2ool002[ooooo0_oo000oooooo`;oo`007ooo
ool00ol0003oooooooooo`0:ooooo`008oooool2o`0001kooooo0_oo000oooooo`;oo`00:Oooool0
0ooo003oooooool0000nooooo`03ool00?ooooooo`0001Cooooo00?o0000ooooooooool04_ooool2
ool003oooooo0_oo000Zooooo`;oo`00?oooool2ool001gooooo0ol0000<ooooo`008oooool00ol0
003oooooooooo`0Mooooo`;oo`00?oooool2ool002Wooooo00?oo`00oooooooo0000?_ooool00ooo
003oooooool0000Dooooo`03o`000?oooooooooo01;ooooo0_oo000oooooo`;oo`00:_ooool2ool0
03oooooo0_oo000Oooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo01go
oooo0_oo000oooooo`;oo`00:Oooool00ooo003oooooool0000nooooo`03ool00?ooooooo`0001Co
oooo00?o0000ooooooooool04_ooool2ool003oooooo0_oo000Zooooo`;oo`00?oooool2ool001oo
oooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool07Oooool2ool003oooooo
0_oo000Yooooo`03ool00?ooooooo`0003kooooo00?oo`00oooooooo00005?ooool00ol0003ooooo
ooooo`0Booooo`;oo`00?oooool2ool002[ooooo0_oo000oooooo`;oo`007oooool00ol0003ooooo
ooooo`0:ooooo`008oooool00ol0003oooooooooo`0Mooooo`;oo`00?oooool2ool002Wooooo0_oo
000oooooo`03ool00?ooooooo`0001Cooooo00?o0000ooooooooool04_ooool2ool003oooooo0_oo
000Zooooo`;oo`00?oooool2ool001oooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000
ooooooooool07Oooool2ool003oooooo0_oo000Yooooo`;oo`00?oooool00ooo003oooooool0000D
ooooo`03o`000?oooooooooo01;ooooo0_oo000oooooo`;oo`00:_ooool2ool003oooooo0_oo000O
ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo01gooooo0_oo000ooooo
o`;oo`00:Oooool2ool003oooooo00?oo`00oooooooo00005?ooool00ol0003oooooooooo`0Boooo
o`;oo`00?oooool2ool002[ooooo0_oo000oooooo`;oo`007oooool00ol0003oooooooooo`0:oooo
o`008oooool00ol0003oooooooooo`0Mooooo`;oo`00?oooool2ool002Wooooo0_oo000oooooo`03
ool00?ooooooo`0001Cooooo00?o0000ooooooooool04_ooool2ool003oooooo0_oo000Zooooo`;o
o`00?oooool2ool001oooooo00?o0000ooooooooool02_ooool002?ooooo0_l0000Nooooo`;oo`00
?oooool2ool002Wooooo0_oo000oooooo`03ool00?ooooooo`0001Cooooo00?o0000ooooooooool0
4_ooool2ool003oooooo0_oo000Zooooo`;oo`00?oooool2ool001gooooo0ol0000<ooooo`008ooo
ool00ol0003oooooooooo`0Mooooo`;oo`00?oooool2ool002Wooooo0_oo000oooooo`03ool00?oo
ooooo`0001Cooooo00?o0000ooooooooool04_ooool2ool003oooooo0_oo000Zooooo`;oo`00?ooo
ool2ool001oooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool07Oooool2
ool003oooooo0_oo000Yooooo`;oo`00?oooool00ooo003oooooool0000Dooooo`03o`000?oooooo
oooo01;ooooo0_oo000oooooo`;oo`00:_ooool2ool003oooooo0_oo000Oooooo`03o`000?oooooo
oooo00[ooooo000Sooooo`03o`000?oooooooooo01gooooo0_oo000oooooo`;oo`00:_ooool00ooo
003oooooooooo`0nooooo`03ool00?oooooooooo01?ooooo00?o0000ooooooooool04_ooool2ool0
03oooooo0_oo000Zooooo`;oo`00?oooool2ool001oooooo00?o0000ooooooooool02_ooool002?o
oooo00?o0000ooooooooool07Oooool2ool003oooooo0_oo000Zooooo`03ool00?oooooooooo03ko
oooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`0Booooo`;oo`00?oooool2ool002[o
oooo0_oo000oooooo`;oo`007oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003ooooo
ooooo`0Mooooo`;oo`00?oooool2ool002[ooooo00?oo`00ooooooooool0?_ooool00ooo003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo0_oo000oooooo`;oo`00:_ooool2ool003oooooo
0_oo000Oooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo01gooooo0_oo
000oooooo`;oo`00:_ooool00ooo003oooooooooo`0nooooo`03ool00?oooooooooo01?ooooo00?o
0000ooooooooool04_ooool2ool003oooooo0_oo000Zooooo`;oo`00?oooool2ool001oooooo00?o
0000ooooooooool02_ooool002?ooooo0_l0000Nooooo`;oo`00?oooool2ool002[ooooo00?oo`00
ooooooooool0?_ooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo0_oo000o
ooooo`;oo`00:_ooool2ool003oooooo0_oo000Mooooo`?o00003?ooool002?ooooo00?o0000oooo
ooooool07Oooool2ool003oooooo0_oo000Zooooo`03ool00?oooooooooo03kooooo00?oo`00oooo
ooooool04oooool00ol0003oooooooooo`0Booooo`;oo`00?oooool2ool002[ooooo0_oo000ooooo
o`;oo`007oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0Mooooo`;o
o`00?oooool2ool002[ooooo00?oo`00ooooooooool0?_ooool00ooo003oooooooooo`0Cooooo`03
o`000?oooooooooo01;ooooo0_oo000oooooo`;oo`00:_ooool2ool003oooooo0_oo000Oooooo`03
o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo01gooooo0_oo000oooooo`;oo`00
:_ooool00ooo003oooooooooo`0nooooo`03ool00?oooooooooo01?ooooo00?o0000ooooooooool0
4_ooool2ool003oooooo0_oo000Zooooo`;oo`00?oooool2ool001oooooo00?o0000ooooooooool0
2_ooool000cooooo0ol00004ooooo`;o00001?ooool2o`0000Sooooo00?o0000ooooooooool07Ooo
ool2ool003oooooo0_oo000Zooooo`03ool00?oooooooooo03kooooo00?oo`00ooooooooool04ooo
ool00ol0003oooooooooo`0Booooo`;oo`00?oooool2ool002[ooooo0_oo000oooooo`;oo`007ooo
ool00ol0003oooooooooo`0:ooooo`003Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Mooooo`;oo`00
?oooool2ool002[ooooo00?oo`00ooooooooool0?_ooool00ooo003oooooooooo`0Cooooo`03o`00
0?oooooooooo01;ooooo0_oo000oooooo`;oo`00:_ooool2ool003oooooo0_oo000Oooooo`03o`00
0?oooooooooo00[ooooo000=ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01gooooo00?oo`00oooooooo
ool0?_ooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo03kooooo00?oo`00oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`;oo`00?oooool2ool002[ooooo00?oo`00oooooooo
ool0?_ooool00ooo003oooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo000=ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00007oooo
o`?o00007Oooool00ooo003oooooooooo`0nooooo`03ool00?oooooooooo02Wooooo00?oo`00oooo
ooooool0?_ooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?oo`00oooo
ooooool0?_ooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo03kooooo0_oo000Loooo
o`Co00003?ooool000gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0C
ooooo`03ool00?oooooooooo03kooooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03ool00?oooooooooo03kooooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`0C
ooooo`03ool00?oooooooooo03kooooo00?oo`00ooooooooool04_ooool00ol0003oooooooooo`0C
ooooo`03ool00?oooooooooo03kooooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo000<ooooo`;o00001?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Zooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`1Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool000gooooo00?o0000
ooooooooool00oooool2o`0000Cooooo0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02_ooool002?oooooool0003:o`0000cooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {167, 0}} -> {-24.2281, -12.7111, 0.0920207, \
0.693609}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show all", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ga\  = \ 
        Show[GraphicsArray[{{gxt, gxn}, {gX, \ gXXs}}], 
          ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.00393652 0.196826 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.02381 .00394 m
.02427 .00394 L
.02478 .00394 L
.02525 .00394 L
.02571 .00394 L
.0262 .00394 L
.02667 .00394 L
.02716 .00394 L
.02764 .00394 L
.0281 .00394 L
.02859 .00394 L
.02907 .00394 L
.02952 .00394 L
.03 .00394 L
.03047 .00394 L
.03097 .00394 L
.03144 .00394 L
.0319 .00394 L
.03239 .00394 L
.03286 .00394 L
.03336 .00394 L
.03384 .00394 L
.0343 .00394 L
.03479 .00394 L
.03527 .00394 L
.03572 .00394 L
.03621 .00394 L
.03668 .00394 L
.03717 .00394 L
.03765 .00394 L
.03811 .00394 L
.0386 .00394 L
.03907 .00394 L
.03953 .00394 L
.04001 .00394 L
.04047 .00394 L
.04097 .00394 L
.04144 .00394 L
.0419 .00394 L
.04239 .00394 L
.04286 .00394 L
.04335 .00394 L
.04383 .00394 L
.0443 .00394 L
.04479 .00394 L
.04526 .00394 L
.04572 .00394 L
.0462 .00394 L
.04667 .00394 L
.04716 .00394 L
Mistroke
.04764 .00394 L
.0481 .00394 L
.04859 .00394 L
.04906 .00394 L
.04956 .00394 L
.05004 .00394 L
.0505 .00394 L
.05099 .00394 L
.05147 .00394 L
.05193 .00394 L
.05241 .00394 L
.05288 .00394 L
.05338 .00394 L
.05386 .00394 L
.05432 .00394 L
.05481 .00394 L
.05528 .00394 L
.05573 .00394 L
.05622 .00394 L
.05668 .00394 L
.05718 .00394 L
.05765 .00394 L
.05811 .00394 L
.0586 .00394 L
.05907 .00394 L
.05957 .00394 L
.06005 .00394 L
.06051 .00394 L
.061 .00394 L
.06147 .00394 L
.06193 .00394 L
.06242 .00394 L
.06288 .00394 L
.06338 .00394 L
.06386 .00394 L
.06432 .00394 L
.06481 .00394 L
.06528 .00394 L
.06573 .00394 L
.06621 .00394 L
.06668 .00394 L
.06717 .00394 L
.06764 .00394 L
.0681 .00394 L
.06859 .00394 L
.06906 .00394 L
.06955 .00394 L
.07003 .00394 L
.0705 .00394 L
.07099 .00394 L
Mistroke
.07146 .00394 L
.07191 .00394 L
.0724 .00394 L
.07286 .00394 L
.07336 .00394 L
.07384 .00394 L
.07429 .00394 L
.07478 .00394 L
.07525 .00394 L
.07575 .00394 L
.07623 .00394 L
.0767 .00394 L
.07719 .00394 L
.07766 .00394 L
.07812 .00394 L
.0786 .00394 L
.07907 .00394 L
.07957 .00394 L
.08005 .00394 L
.08051 .00394 L
.081 .00394 L
.08147 .00394 L
.08192 .00394 L
.08241 .00394 L
.08287 .00394 L
.08336 .00394 L
.08384 .00394 L
.0843 .00394 L
.08479 .00394 L
.08525 .00394 L
.08575 .00394 L
.08623 .00394 L
.0867 .00394 L
.08719 .00394 L
.08766 .00394 L
.08812 .00394 L
.0886 .00394 L
.08907 .00394 L
.08956 .00394 L
.09004 .00394 L
.0905 .00394 L
.09099 .00394 L
.09146 .00394 L
.09196 .00394 L
.09244 .00394 L
.0929 .00394 L
.0934 .00394 L
.09387 .00394 L
.09433 .00394 L
.09482 .00394 L
Mistroke
.09528 .00394 L
.09578 .00394 L
.09626 .00394 L
.09672 .00394 L
.09721 .00394 L
.09768 .00394 L
.09814 .00394 L
.09862 .00394 L
.09909 .00394 L
.09958 .00394 L
.10006 .00394 L
.10052 .00394 L
.101 .00394 L
.10147 .00394 L
.10197 .00394 L
.10245 .00394 L
.10292 .00394 L
.10341 .00394 L
.10388 .00394 L
.10434 .00394 L
.10482 .00394 L
.10529 .00394 L
.10579 .00394 L
.10627 .00394 L
.10673 .00394 L
.10722 .00394 L
.10769 .00394 L
.10814 .00394 L
.10862 .00394 L
.10909 .00394 L
.10958 .00394 L
.11006 .00394 L
.11051 .00394 L
.111 .00394 L
.11147 .00394 L
.11197 .00394 L
.11245 .00394 L
.11291 .00394 L
.1134 .00394 L
.11387 .00394 L
.11433 .00394 L
.11481 .00394 L
.11528 .00394 L
.11577 .00394 L
.11625 .00394 L
.11671 .00394 L
.1172 .00394 L
.11767 .00394 L
.11817 .00394 L
.11865 .00394 L
Mistroke
.11911 .00394 L
.1196 .00394 L
.12008 .00394 L
.12054 .00394 L
.12102 .00394 L
.12149 .00394 L
.12199 .00394 L
.12247 .00394 L
.12293 .00394 L
.12342 .00394 L
.12389 .00394 L
.12434 .00394 L
.12482 .00394 L
.12529 .00394 L
.12578 .00394 L
.12626 .00394 L
.12672 .00394 L
.12721 .00394 L
.12768 .00394 L
.12817 .00394 L
.12865 .00394 L
.12912 .00394 L
.12961 .00394 L
.13008 .00394 L
.13054 .00394 L
.13102 .00394 L
.13149 .00394 L
.13198 .00394 L
.13246 .00394 L
.13292 .00394 L
.13341 .00394 L
.13388 .00394 L
.13433 .00394 L
.13482 .00394 L
.13528 .00394 L
.13577 .00394 L
.13625 .00394 L
.13671 .00394 L
.13719 .00394 L
.13766 .00394 L
.13816 .00394 L
.13864 .00394 L
.1391 .00394 L
.13959 .00394 L
.14006 .00394 L
.14052 .00394 L
.141 .00394 L
.14147 .00394 L
.14196 .00394 L
.14244 .00394 L
Mistroke
.1429 .00394 L
.14339 .00394 L
.14386 .00394 L
.14435 .00394 L
.14484 .00394 L
.1453 .00394 L
.14579 .00394 L
.14627 .00394 L
.14672 .00394 L
.14721 .00394 L
.14767 .00394 L
.14817 .00394 L
.14865 .00394 L
.14911 .00394 L
.1496 .00394 L
.15007 .00394 L
.15052 .00394 L
.15101 .00394 L
.15147 .00394 L
.15197 .00394 L
.15244 .00394 L
.1529 .00394 L
.15339 .00394 L
.15385 .00394 L
.15435 .00394 L
.15483 .00394 L
.15529 .00394 L
.15579 .00394 L
.15626 .00394 L
.15671 .00394 L
.1572 .00394 L
.15766 .00394 L
.15816 .00394 L
.15864 .00394 L
.1591 .00394 L
.15959 .00394 L
.16006 .00394 L
.16056 .00394 L
.16104 .00394 L
.1615 .00394 L
.16199 .00394 L
.16247 .00394 L
.16293 .00394 L
.16341 .00394 L
.16388 .00394 L
.16438 .00394 L
.16486 .00394 L
.16532 .00394 L
.16581 .00394 L
.16628 .00394 L
Mistroke
.16673 .00394 L
.16722 .00394 L
.16768 .00394 L
.16818 .00394 L
.16865 .00394 L
.16911 .00394 L
.1696 .00394 L
.17007 .00394 L
.17057 .00394 L
.17105 .00394 L
.17151 .00394 L
.172 .00394 L
.17248 .00394 L
.17293 .00394 L
.17342 .00394 L
.17388 .00394 L
.17438 .00394 L
.17486 .00394 L
.17532 .00394 L
.17581 .00394 L
.17628 .00394 L
.17673 .00394 L
.17721 .00394 L
.17768 .00394 L
.17817 .00394 L
.17865 .00394 L
.1791 .00394 L
.17959 .00394 L
.18006 .00394 L
.18056 .00394 L
.18104 .00394 L
.1815 .00394 L
.18199 .00394 L
.18246 .00394 L
.18292 .00394 L
.1834 .00394 L
.18387 .00394 L
.18436 .00394 L
.18484 .00394 L
.1853 .00394 L
.18579 .00394 L
.18626 .00394 L
.18676 .00394 L
.18724 .00394 L
.1877 .00394 L
.18819 .00394 L
.18867 .00394 L
.18912 .00394 L
.18961 .00394 L
.19008 .00394 L
Mistroke
.19057 .00394 L
.19105 .00394 L
.19151 .00394 L
.192 .00394 L
.19248 .00394 L
.19293 .00394 L
.19341 .00394 L
.19388 .00394 L
.19437 .00394 L
.19485 .00394 L
.19531 .00394 L
.19579 .00394 L
.19626 .00394 L
.19676 .00394 L
.19724 .00394 L
.1977 .00394 L
.19819 .00394 L
.19867 .00394 L
.19912 .00394 L
.19961 .00394 L
.20007 .00394 L
.20057 .00394 L
.20105 .00394 L
.20151 .00394 L
.202 .00394 L
.20247 .00394 L
.20297 .00394 L
.20345 .00394 L
.20391 .00394 L
.20441 .00394 L
.20488 .00394 L
.20534 .00394 L
.20582 .00394 L
.20629 .00394 L
.20679 .00394 L
.20727 .00394 L
.20773 .00394 L
.20822 .00394 L
.20869 .00394 L
.20915 .00394 L
.20963 .00394 L
.2101 .00394 L
.21059 .00394 L
.21107 .00394 L
.21153 .00394 L
.21201 .00394 L
.21248 .00394 L
.21298 .00394 L
.21346 .00394 L
.21393 .00394 L
Mistroke
.21442 .00394 L
.21489 .00394 L
.21535 .00394 L
.21583 .00394 L
.2163 .00394 L
.2168 .00394 L
.21728 .00394 L
.21774 .00394 L
.21823 .00394 L
.2187 .00394 L
.21915 .00394 L
.21963 .00394 L
.2201 .00394 L
.22059 .00394 L
.22107 .00394 L
.22152 .00394 L
.22201 .00394 L
.22248 .00394 L
.22298 .00394 L
.22346 .00394 L
.22392 .00394 L
.22441 .00394 L
.22488 .00394 L
.22534 .00394 L
.22582 .00394 L
.22629 .00394 L
.22679 .00394 L
.22726 .00394 L
.22772 .00394 L
.22821 .00394 L
.22868 .00394 L
.22918 .00394 L
.22966 .00394 L
.23013 .00394 L
.23062 .00394 L
.23109 .00394 L
.23155 .00394 L
.23204 .00394 L
.2325 .00394 L
.233 .00394 L
.23348 .00394 L
.23394 .00394 L
.23443 .00394 L
.2349 .00394 L
.23536 .00394 L
.23584 .00394 L
.2363 .00394 L
.2368 .00394 L
.23727 .00394 L
.23773 .00394 L
Mistroke
.23822 .00394 L
.23869 .00394 L
.23919 .00394 L
.23967 .00394 L
.24013 .00394 L
.24062 .00394 L
.2411 .00394 L
.24155 .00394 L
.24204 .00394 L
.2425 .00394 L
.243 .00394 L
.24348 .00394 L
.24394 .00394 L
.24443 .00394 L
.2449 .00394 L
.24535 .00394 L
.24583 .00394 L
.2463 .00394 L
.24679 .00394 L
.24727 .00394 L
.24772 .00394 L
.24821 .00394 L
.24868 .00394 L
.24918 .00394 L
.24966 .00394 L
.25012 .00394 L
.25061 .00394 L
.25108 .00394 L
.25153 .00394 L
.25202 .00394 L
.25248 .00394 L
.25298 .00394 L
.25346 .00394 L
.25391 .00394 L
.2544 .00394 L
.25487 .00394 L
.25537 .00394 L
.25585 .00394 L
.25632 .00394 L
.25681 .00394 L
.25728 .00394 L
.25774 .00394 L
.25822 .00394 L
.25869 .00394 L
.25919 .00394 L
.25967 .00394 L
.26013 .00394 L
.26062 .00394 L
.26109 .00394 L
.26154 .00394 L
Mistroke
.26203 .00394 L
.26249 .00394 L
.26298 .00394 L
.26346 .00394 L
.26392 .00394 L
.26441 .00394 L
.26487 .00394 L
.26537 .00394 L
.26585 .00394 L
.26631 .00394 L
.26681 .00394 L
.26728 .00394 L
.26773 .00394 L
.26822 .00394 L
.26869 .00394 L
.26918 .00394 L
.26966 .00394 L
.27012 .00394 L
.27061 .00394 L
.27108 .00394 L
.27158 .00394 L
.27206 .00394 L
.27252 .00394 L
.27302 .00394 L
.27349 .00394 L
.27395 .00394 L
.27443 .00394 L
.2749 .00394 L
.2754 .00394 L
.27588 .00394 L
.27634 .00394 L
.27683 .00394 L
.2773 .00394 L
.27776 .00394 L
.27824 .00394 L
.2787 .00394 L
.2792 .00394 L
.27968 .00394 L
.28013 .00394 L
.28062 .00394 L
.28109 .00394 L
.28159 .00394 L
.28207 .00394 L
.28253 .00394 L
.28303 .00394 L
.2835 .00394 L
.28396 .00394 L
.28444 .00394 L
.28491 .00394 L
.2854 .00394 L
Mistroke
.28588 .00394 L
.28634 .00394 L
.28683 .00394 L
.2873 .00394 L
.28776 .00394 L
.28824 .00394 L
.2887 .00394 L
.2892 .00394 L
.28967 .00394 L
.29013 .00394 L
.29062 .00394 L
.29108 .00394 L
.29158 .00394 L
.29206 .00394 L
.29252 .00394 L
.29302 .00394 L
.29349 .00394 L
.29394 .00394 L
.29443 .00394 L
.29489 .00394 L
.29539 .00394 L
.29587 .00394 L
.29632 .00394 L
.29681 .00394 L
.29728 .00394 L
.29778 .00394 L
.29826 .00394 L
.29873 .00394 L
.29922 .00394 L
.29969 .00394 L
.30015 .00394 L
.30064 .00394 L
.3011 .00394 L
.3016 .00394 L
.30208 .00394 L
.30254 .00394 L
.30303 .00394 L
.3035 .00394 L
.30396 .00394 L
.30444 .00394 L
.3049 .00394 L
.3054 .00394 L
.30587 .00394 L
.30633 .00394 L
.30682 .00394 L
.30729 .00394 L
.30779 .00394 L
.30827 .00394 L
.30873 .00394 L
.30922 .00394 L
Mistroke
.3097 .00394 L
.31015 .00394 L
.31064 .00394 L
.3111 .00394 L
.3116 .00394 L
.31208 .00394 L
.31254 .00394 L
.31302 .00394 L
.3135 .00394 L
.31395 .00394 L
.31443 .00394 L
.31489 .00394 L
.31539 .00394 L
.31586 .00394 L
.31632 .00394 L
.31681 .00394 L
.31727 .00394 L
.31777 .00394 L
.31825 .00394 L
.31871 .00394 L
.3192 .00394 L
.31968 .00394 L
.32013 .00394 L
.32061 .00394 L
.32108 .00394 L
.32157 .00394 L
.32205 .00394 L
.32251 .00394 L
.323 .00394 L
.32347 .00394 L
.32397 .00394 L
.32445 .00394 L
.32491 .00394 L
.3254 .00394 L
.32588 .00394 L
.32633 .00394 L
.32682 .00394 L
.32729 .00394 L
.32778 .00394 L
.32826 .00394 L
.32872 .00394 L
.32921 .00394 L
.32968 .00394 L
.33014 .00394 L
.33062 .00394 L
.33108 .00394 L
.33158 .00394 L
.33205 .00394 L
.33251 .00394 L
.333 .00394 L
Mistroke
.33347 .00394 L
.33396 .00394 L
.33444 .00394 L
.33491 .00394 L
.3354 .00394 L
.33587 .00394 L
.33633 .00394 L
.33681 .00394 L
.33728 .00394 L
.33777 .00394 L
.33825 .00394 L
.33871 .00394 L
.3392 .00394 L
.33967 .00394 L
.34017 .00394 L
.34065 .00394 L
.34111 .00394 L
.34161 .00394 L
.34208 .00394 L
.34254 .00394 L
.34302 .00394 L
.34349 .00394 L
.34399 .00394 L
.34447 .00394 L
.34493 .00394 L
.34542 .00394 L
.34589 .00394 L
.34634 .00394 L
.34683 .00394 L
.34729 .00394 L
.34779 .00394 L
.34826 .00394 L
.34872 .00394 L
.34921 .00394 L
.34968 .00394 L
.35018 .00394 L
.35066 .00394 L
.35112 .00394 L
.35161 .00394 L
.35209 .00394 L
.35254 .00394 L
.35303 .00394 L
.35349 .00394 L
.35399 .00394 L
.35447 .00394 L
.35493 .00394 L
.35542 .00394 L
.35589 .00394 L
.35634 .00394 L
.35682 .00394 L
Mistroke
.35729 .00394 L
.35778 .00394 L
.35826 .00394 L
.35871 .00394 L
.3592 .00394 L
.35967 .00394 L
.36017 .00394 L
.36065 .00394 L
.36111 .00394 L
.3616 .00394 L
.36207 .00394 L
.36253 .00394 L
.36301 .00394 L
.36348 .00394 L
.36397 .00394 L
.36445 .00394 L
.36491 .00394 L
.36539 .00394 L
.36586 .00394 L
.36636 .00394 L
.36685 .00394 L
.36731 .00394 L
.3678 .00394 L
.36828 .00394 L
.36873 .00394 L
.36922 .00394 L
.36968 .00394 L
.37018 .00394 L
.37066 .00394 L
.37112 .00394 L
.37161 .00394 L
.37208 .00394 L
.37254 .00394 L
.37302 .00394 L
.37348 .00394 L
.37398 .00394 L
.37445 .00394 L
.37491 .00394 L
.3754 .00394 L
.37587 .00394 L
.37637 .00394 L
.37685 .00394 L
.37731 .00394 L
.3778 .00394 L
.37827 .00394 L
.37873 .00394 L
.37921 .00394 L
.37968 .00394 L
.38018 .00394 L
.38065 .00394 L
Mistroke
.38111 .00394 L
.3816 .00394 L
.38207 .00394 L
.38257 .00394 L
.38305 .00394 L
.38352 .00394 L
.38401 .00394 L
.38449 .00394 L
.38494 .00394 L
.38543 .00394 L
.3859 .00394 L
.38639 .00394 L
.38687 .00394 L
.38734 .00394 L
.38783 .00394 L
.3883 .00394 L
.38875 .00394 L
.38924 .00394 L
.3897 .00394 L
.3902 .00394 L
.39067 .00394 L
.39113 .00394 L
.39162 .00394 L
.39209 .00394 L
.39259 .00394 L
.39307 .00394 L
.39353 .00394 L
.39402 .00394 L
.3945 .00394 L
.39495 .00394 L
.39544 .00394 L
.39591 .00394 L
.3964 .00394 L
.39688 .00394 L
.39734 .00394 L
.39783 .00394 L
.3983 .00394 L
.39875 .00394 L
.39924 .00394 L
.3997 .00394 L
.40019 .00394 L
.40067 .00394 L
.40113 .00394 L
.40161 .00394 L
.40208 .00394 L
.40258 .00394 L
.40306 .00394 L
.40352 .00394 L
.40401 .00394 L
.40449 .00394 L
Mistroke
.40494 .00394 L
.40543 .00394 L
.40589 .00394 L
.40639 .00394 L
.40686 .00394 L
.40732 .00394 L
.40781 .00394 L
.40828 .00394 L
.40878 .00394 L
.40926 .00394 L
.40973 .00394 L
.41022 .00394 L
.41069 .00394 L
.41115 .00394 L
.41164 .00394 L
.4121 .00394 L
.4126 .00394 L
.41308 .00394 L
.41354 .00394 L
.41403 .00394 L
.4145 .00394 L
.41496 .00394 L
.41544 .00394 L
.41591 .00394 L
.4164 .00394 L
.41688 .00394 L
.41733 .00394 L
.41782 .00394 L
.41829 .00394 L
.41879 .00394 L
.41927 .00394 L
.41973 .00394 L
.42022 .00394 L
.4207 .00394 L
.42115 .00394 L
.42164 .00394 L
.4221 .00394 L
.4226 .00394 L
.42308 .00394 L
.42354 .00394 L
.42403 .00394 L
.4245 .00394 L
.42495 .00394 L
.42543 .00394 L
.4259 .00394 L
.42639 .00394 L
.42687 .00394 L
.42732 .00394 L
.42781 .00394 L
.42828 .00394 L
Mistroke
.42878 .00394 L
.42926 .00394 L
.42972 .00394 L
.43021 .00394 L
.43068 .00394 L
.43113 .00394 L
.43162 .00394 L
.43208 .00394 L
.43258 .00394 L
.43306 .00394 L
.43351 .00394 L
.434 .00394 L
.43447 .00394 L
.43497 .00394 L
.43545 .00394 L
.43592 .00394 L
.43641 .00394 L
.43688 .00394 L
.43734 .00394 L
.43782 .00394 L
.43829 .00394 L
.43879 .00394 L
.43927 .00394 L
.43973 .00394 L
.44022 .00394 L
.44069 .00394 L
.44114 .00394 L
.44162 .00394 L
.44209 .00394 L
.44258 .00394 L
.44306 .00394 L
.44352 .00394 L
.444 .00394 L
.44447 .00394 L
.44497 .00394 L
.44545 .00394 L
.44591 .00394 L
.4464 .00394 L
.44688 .00394 L
.44733 .00394 L
.44782 .00394 L
.44828 .00394 L
.44878 .00394 L
.44926 .00394 L
.44972 .00394 L
.4502 .00394 L
.45067 .00394 L
.45117 .00394 L
.45143 .00394 L
.45166 .00394 L
Mistroke
.45177 .00394 L
.45183 .00394 L
.45186 .00394 L
.45188 .00394 L
.4519 .00394 L
.45191 .39759 L
.45192 .39759 L
.45194 .39759 L
.452 .39759 L
.45212 .39759 L
.45257 .39759 L
.45269 .39759 L
.45275 .39759 L
.45281 .39759 L
.45284 .39759 L
.45285 .39759 L
.45285 .39759 L
.45287 .00394 L
.45288 .00394 L
.45289 .00394 L
.4529 .00394 L
.45294 .00394 L
.45306 .00394 L
.45351 .00394 L
.454 .00394 L
.45447 .00394 L
.45496 .00394 L
.45544 .00394 L
.4559 .00394 L
.45639 .00394 L
.45686 .00394 L
.45731 .00394 L
.4578 .00394 L
.45826 .00394 L
.45875 .00394 L
.45923 .00394 L
.45969 .00394 L
.46017 .00394 L
.46064 .00394 L
.46114 .00394 L
.46162 .00394 L
.46208 .00394 L
.46257 .00394 L
.46304 .00394 L
.4635 .00394 L
.46398 .00394 L
.46445 .00394 L
.46494 .00394 L
.46542 .00394 L
.46588 .00394 L
Mistroke
.46637 .00394 L
.46684 .00394 L
.46734 .00394 L
.46782 .00394 L
.46828 .00394 L
.46878 .00394 L
.46925 .00394 L
.46971 .00394 L
.47019 .00394 L
.47066 .00394 L
.47116 .00394 L
.47164 .00394 L
.4721 .00394 L
.47259 .00394 L
.47306 .00394 L
.47351 .00394 L
.47399 .00394 L
.47446 .00394 L
.47495 .00394 L
.4752 .00394 L
.47543 .00394 L
.47554 .00394 L
.47565 .00394 L
.47568 .00394 L
.4757 .00394 L
.47571 .00394 L
.47572 .20076 L
.47573 .20076 L
.47574 .20076 L
.47577 .20076 L
.47589 .20076 L
.47612 .20076 L
.47638 .20076 L
.4765 .20076 L
.47657 .20076 L
.4766 .20076 L
.47663 .20076 L
.47665 .20076 L
.47666 .20076 L
.47667 .00394 L
.47669 .00394 L
.47675 .00394 L
.47686 .00394 L
.47733 .00394 L
.47783 .00394 L
.47831 .00394 L
.47877 .00394 L
.47926 .00394 L
.47973 .00394 L
.48018 .00394 L
Mistroke
.48067 .00394 L
.48113 .00394 L
.48163 .00394 L
.48211 .00394 L
.48256 .00394 L
.48305 .00394 L
.48352 .00394 L
.48402 .00394 L
.4845 .00394 L
.48496 .00394 L
.48546 .00394 L
.48593 .00394 L
.48639 .00394 L
.48687 .00394 L
.48734 .00394 L
.48784 .00394 L
.48831 .00394 L
.48877 .00394 L
.48926 .00394 L
.48974 .00394 L
.49019 .00394 L
.49067 .00394 L
.49114 .00394 L
.49163 .00394 L
.49211 .00394 L
.49256 .00394 L
.49305 .00394 L
.49352 .00394 L
.49402 .00394 L
.4945 .00394 L
.49496 .00394 L
.49545 .00394 L
.49592 .00394 L
.49638 .00394 L
.49686 .00394 L
.49733 .00394 L
.49782 .00394 L
.4983 .00394 L
.49876 .00394 L
.49902 .00394 L
.49925 .00394 L
.49937 .00394 L
.49943 .00394 L
.49946 .00394 L
.49949 .00394 L
.49951 .00394 L
.49952 .00394 L
.49953 .20076 L
.49955 .20076 L
.49961 .20076 L
Mistroke
.49972 .20076 L
.50018 .20076 L
.5003 .20076 L
.50042 .20076 L
.50045 .20076 L
.50046 .20076 L
.50048 .20076 L
.50049 .00394 L
.5005 .00394 L
.50051 .00394 L
.50054 .00394 L
.50067 .00394 L
.50117 .00394 L
.50165 .00394 L
.50211 .00394 L
.5026 .00394 L
.50308 .00394 L
.50353 .00394 L
.50402 .00394 L
.50448 .00394 L
.50498 .00394 L
.50546 .00394 L
.50592 .00394 L
.50641 .00394 L
.50688 .00394 L
.50733 .00394 L
.50781 .00394 L
.50828 .00394 L
.50877 .00394 L
.50925 .00394 L
.5097 .00394 L
.51019 .00394 L
.51066 .00394 L
.51116 .00394 L
.51164 .00394 L
.5121 .00394 L
.51259 .00394 L
.51306 .00394 L
.51352 .00394 L
.514 .00394 L
.51447 .00394 L
.51496 .00394 L
.51544 .00394 L
.5159 .00394 L
.51638 .00394 L
.51685 .00394 L
.51735 .00394 L
.51784 .00394 L
.5183 .00394 L
.51879 .00394 L
Mistroke
.51927 .00394 L
.51972 .00394 L
.52021 .00394 L
.52067 .00394 L
.52117 .00394 L
.52165 .00394 L
.52211 .00394 L
.5226 .00394 L
.52284 .00394 L
.52307 .00394 L
.52318 .00394 L
.52324 .00394 L
.52329 .00394 L
.5233 .00394 L
.52332 .00394 L
.52333 .20076 L
.52335 .20076 L
.52341 .20076 L
.52352 .20076 L
.52399 .20076 L
.52411 .20076 L
.52423 .20076 L
.52426 .20076 L
.52427 .20076 L
.52428 .20076 L
.5243 .00394 L
.52431 .00394 L
.52432 .00394 L
.52435 .00394 L
.52448 .00394 L
.52498 .00394 L
.52546 .00394 L
.52592 .00394 L
.52642 .00394 L
.52689 .00394 L
.52735 .00394 L
.52784 .00394 L
.5283 .00394 L
.5288 .00394 L
.52928 .00394 L
.52974 .00394 L
.53023 .00394 L
.5307 .00394 L
.53116 .00394 L
.53164 .00394 L
.53211 .00394 L
.5326 .00394 L
.53308 .00394 L
.53354 .00394 L
.53402 .00394 L
Mistroke
.53449 .00394 L
.53499 .00394 L
.53547 .00394 L
.53594 .00394 L
.53643 .00394 L
.5369 .00394 L
.53736 .00394 L
.53784 .00394 L
.53831 .00394 L
.53881 .00394 L
.53928 .00394 L
.53974 .00394 L
.54023 .00394 L
.54071 .00394 L
.54116 .00394 L
.54164 .00394 L
.54211 .00394 L
.5426 .00394 L
.54307 .00394 L
.54353 .00394 L
.54402 .00394 L
.54449 .00394 L
.54499 .00394 L
.54547 .00394 L
.54593 .00394 L
.54642 .00394 L
.54666 .00394 L
.54689 .00394 L
.547 .00394 L
.54706 .00394 L
.54711 .00394 L
.54712 .00394 L
.54714 .00394 L
.54715 .39759 L
.54715 .39759 L
.54717 .39759 L
.54723 .39759 L
.54735 .39759 L
.54758 .39759 L
.54784 .39759 L
.54796 .39759 L
.54802 .39759 L
.54805 .39759 L
.54807 .39759 L
.54808 .39759 L
.5481 .00394 L
.54811 .00394 L
.54814 .00394 L
.5482 .00394 L
.54831 .00394 L
Mistroke
.54878 .00394 L
.54927 .00394 L
.54975 .00394 L
.55021 .00394 L
.55069 .00394 L
.55116 .00394 L
.55166 .00394 L
.55214 .00394 L
.5526 .00394 L
.5531 .00394 L
.55357 .00394 L
.55403 .00394 L
.55451 .00394 L
.55498 .00394 L
.55547 .00394 L
.55595 .00394 L
.55641 .00394 L
.5569 .00394 L
.55737 .00394 L
.55782 .00394 L
.5583 .00394 L
.55877 .00394 L
.55926 .00394 L
.55974 .00394 L
.56019 .00394 L
.56068 .00394 L
.56115 .00394 L
.56165 .00394 L
.56213 .00394 L
.56259 .00394 L
.56308 .00394 L
.56355 .00394 L
.564 .00394 L
.56449 .00394 L
.56495 .00394 L
.56545 .00394 L
.56593 .00394 L
.56638 .00394 L
.56687 .00394 L
.56734 .00394 L
.56784 .00394 L
.56832 .00394 L
.56879 .00394 L
.56928 .00394 L
.56975 .00394 L
.57021 .00394 L
.57069 .00394 L
.57116 .00394 L
.57166 .00394 L
.57214 .00394 L
Mistroke
.5726 .00394 L
.57309 .00394 L
.57356 .00394 L
.57401 .00394 L
.57449 .00394 L
.57496 .00394 L
.57545 .00394 L
.57593 .00394 L
.57639 .00394 L
.57687 .00394 L
.57734 .00394 L
.57784 .00394 L
.57832 .00394 L
.57878 .00394 L
.57927 .00394 L
.57975 .00394 L
.5802 .00394 L
.58069 .00394 L
.58115 .00394 L
.58165 .00394 L
.58212 .00394 L
.58258 .00394 L
.58307 .00394 L
.58354 .00394 L
.58404 .00394 L
.58452 .00394 L
.58499 .00394 L
.58548 .00394 L
.58596 .00394 L
.58641 .00394 L
.5869 .00394 L
.58737 .00394 L
.58786 .00394 L
.58834 .00394 L
.5888 .00394 L
.58929 .00394 L
.58977 .00394 L
.59022 .00394 L
.5907 .00394 L
.59117 .00394 L
.59166 .00394 L
.59214 .00394 L
.5926 .00394 L
.59309 .00394 L
.59356 .00394 L
.59405 .00394 L
.59453 .00394 L
.595 .00394 L
.59549 .00394 L
.59596 .00394 L
Mistroke
.59642 .00394 L
.5969 .00394 L
.59737 .00394 L
.59787 .00394 L
.59834 .00394 L
.5988 .00394 L
.59929 .00394 L
.59976 .00394 L
.60022 .00394 L
.6007 .00394 L
.60116 .00394 L
.60166 .00394 L
.60213 .00394 L
.60259 .00394 L
.60308 .00394 L
.60355 .00394 L
.60404 .00394 L
.60452 .00394 L
.60498 .00394 L
.60548 .00394 L
.60595 .00394 L
.6064 .00394 L
.60689 .00394 L
.60735 .00394 L
.60785 .00394 L
.60833 .00394 L
.60878 .00394 L
.60927 .00394 L
.60974 .00394 L
.61024 .00394 L
.61072 .00394 L
.61119 .00394 L
.61168 .00394 L
.61215 .00394 L
.61261 .00394 L
.6131 .00394 L
.61356 .00394 L
.61406 .00394 L
.61454 .00394 L
.615 .00394 L
.61549 .00394 L
.61596 .00394 L
.61641 .00394 L
.6169 .00394 L
.61736 .00394 L
.61786 .00394 L
.61833 .00394 L
.61879 .00394 L
.61928 .00394 L
.61975 .00394 L
Mistroke
.62024 .00394 L
.62073 .00394 L
.62119 .00394 L
.62168 .00394 L
.62215 .00394 L
.62261 .00394 L
.62309 .00394 L
.62356 .00394 L
.62405 .00394 L
.62453 .00394 L
.62499 .00394 L
.62548 .00394 L
.62595 .00394 L
.62645 .00394 L
.62693 .00394 L
.6274 .00394 L
.62789 .00394 L
.62837 .00394 L
.62882 .00394 L
.62931 .00394 L
.62978 .00394 L
.63027 .00394 L
.63075 .00394 L
.63121 .00394 L
.63171 .00394 L
.63218 .00394 L
.63263 .00394 L
.63312 .00394 L
.63358 .00394 L
.63408 .00394 L
.63455 .00394 L
.63501 .00394 L
.6355 .00394 L
.63597 .00394 L
.63647 .00394 L
.63695 .00394 L
.63741 .00394 L
.6379 .00394 L
.63838 .00394 L
.63883 .00394 L
.63932 .00394 L
.63979 .00394 L
.64028 .00394 L
.64076 .00394 L
.64122 .00394 L
.64171 .00394 L
.64218 .00394 L
.64263 .00394 L
.64312 .00394 L
.64358 .00394 L
Mistroke
.64408 .00394 L
.64455 .00394 L
.64501 .00394 L
.6455 .00394 L
.64596 .00394 L
.64646 .00394 L
.64694 .00394 L
.6474 .00394 L
.6479 .00394 L
.64837 .00394 L
.64882 .00394 L
.64931 .00394 L
.64977 .00394 L
.65027 .00394 L
.65075 .00394 L
.65121 .00394 L
.65169 .00394 L
.65216 .00394 L
.65266 .00394 L
.65315 .00394 L
.65361 .00394 L
.6541 .00394 L
.65458 .00394 L
.65503 .00394 L
.65552 .00394 L
.65599 .00394 L
.65648 .00394 L
.65696 .00394 L
.65742 .00394 L
.65791 .00394 L
.65839 .00394 L
.65884 .00394 L
.65932 .00394 L
.65979 .00394 L
.66028 .00394 L
.66076 .00394 L
.66122 .00394 L
.6617 .00394 L
.66217 .00394 L
.66267 .00394 L
.66315 .00394 L
.66361 .00394 L
.66411 .00394 L
.66458 .00394 L
.66504 .00394 L
.66552 .00394 L
.66599 .00394 L
.66648 .00394 L
.66696 .00394 L
.66742 .00394 L
Mistroke
.66791 .00394 L
.66838 .00394 L
.66883 .00394 L
.66932 .00394 L
.66978 .00394 L
.67027 .00394 L
.67075 .00394 L
.67121 .00394 L
.67169 .00394 L
.67216 .00394 L
.67266 .00394 L
.67314 .00394 L
.6736 .00394 L
.67409 .00394 L
.67456 .00394 L
.67502 .00394 L
.6755 .00394 L
.67597 .00394 L
.67646 .00394 L
.67694 .00394 L
.6774 .00394 L
.67789 .00394 L
.67836 .00394 L
.67885 .00394 L
.67934 .00394 L
.6798 .00394 L
.68029 .00394 L
.68077 .00394 L
.68122 .00394 L
.68171 .00394 L
.68217 .00394 L
.68267 .00394 L
.68315 .00394 L
.68361 .00394 L
.6841 .00394 L
.68457 .00394 L
.68502 .00394 L
.68551 .00394 L
.68597 .00394 L
.68647 .00394 L
.68694 .00394 L
.6874 .00394 L
.68789 .00394 L
.68836 .00394 L
.68885 .00394 L
.68933 .00394 L
.6898 .00394 L
.69029 .00394 L
.69076 .00394 L
.69122 .00394 L
Mistroke
.6917 .00394 L
.69217 .00394 L
.69266 .00394 L
.69314 .00394 L
.6936 .00394 L
.69409 .00394 L
.69456 .00394 L
.69506 .00394 L
.69554 .00394 L
.696 .00394 L
.6965 .00394 L
.69697 .00394 L
.69743 .00394 L
.69792 .00394 L
.69838 .00394 L
.69888 .00394 L
.69936 .00394 L
.69982 .00394 L
.70031 .00394 L
.70078 .00394 L
.70124 .00394 L
.70172 .00394 L
.70219 .00394 L
.70268 .00394 L
.70316 .00394 L
.70362 .00394 L
.7041 .00394 L
.70457 .00394 L
.70507 .00394 L
.70555 .00394 L
.70602 .00394 L
.70651 .00394 L
.70698 .00394 L
.70744 .00394 L
.70792 .00394 L
.70839 .00394 L
.70889 .00394 L
.70936 .00394 L
.70982 .00394 L
.71031 .00394 L
.71078 .00394 L
.71124 .00394 L
.71172 .00394 L
.71218 .00394 L
.71268 .00394 L
.71315 .00394 L
.71361 .00394 L
.7141 .00394 L
.71457 .00394 L
.71506 .00394 L
Mistroke
.71554 .00394 L
.716 .00394 L
.7165 .00394 L
.71697 .00394 L
.71742 .00394 L
.71791 .00394 L
.71837 .00394 L
.71887 .00394 L
.71935 .00394 L
.7198 .00394 L
.72029 .00394 L
.72076 .00394 L
.72126 .00394 L
.72174 .00394 L
.72221 .00394 L
.7227 .00394 L
.72318 .00394 L
.72363 .00394 L
.72412 .00394 L
.72458 .00394 L
.72508 .00394 L
.72556 .00394 L
.72602 .00394 L
.72651 .00394 L
.72698 .00394 L
.72744 .00394 L
.72792 .00394 L
.72838 .00394 L
.72888 .00394 L
.72935 .00394 L
.72981 .00394 L
.7303 .00394 L
.73077 .00394 L
.73127 .00394 L
.73175 .00394 L
.73221 .00394 L
.7327 .00394 L
.73318 .00394 L
.73363 .00394 L
.73412 .00394 L
.73458 .00394 L
.73508 .00394 L
.73556 .00394 L
.73602 .00394 L
.7365 .00394 L
.73698 .00394 L
.73743 .00394 L
.73791 .00394 L
.73837 .00394 L
.73887 .00394 L
Mistroke
.73934 .00394 L
.7398 .00394 L
.74029 .00394 L
.74075 .00394 L
.74125 .00394 L
.74173 .00394 L
.74219 .00394 L
.74268 .00394 L
.74316 .00394 L
.74361 .00394 L
.74409 .00394 L
.74456 .00394 L
.74505 .00394 L
.74553 .00394 L
.74599 .00394 L
.74648 .00394 L
.74695 .00394 L
.74745 .00394 L
.74793 .00394 L
.74839 .00394 L
.74888 .00394 L
.74936 .00394 L
.74981 .00394 L
.7503 .00394 L
.75076 .00394 L
.75126 .00394 L
.75174 .00394 L
.7522 .00394 L
.75269 .00394 L
.75316 .00394 L
.75361 .00394 L
.7541 .00394 L
.75456 .00394 L
.75506 .00394 L
.75553 .00394 L
.75599 .00394 L
.75648 .00394 L
.75694 .00394 L
.75744 .00394 L
.75792 .00394 L
.75838 .00394 L
.75888 .00394 L
.75935 .00394 L
.7598 .00394 L
.76029 .00394 L
.76075 .00394 L
.76125 .00394 L
.76173 .00394 L
.76219 .00394 L
.76267 .00394 L
Mistroke
.76315 .00394 L
.76365 .00394 L
.76413 .00394 L
.76459 .00394 L
.76508 .00394 L
.76556 .00394 L
.76601 .00394 L
.7665 .00394 L
.76697 .00394 L
.76747 .00394 L
.76794 .00394 L
.76841 .00394 L
.7689 .00394 L
.76937 .00394 L
.76982 .00394 L
.7703 .00394 L
.77077 .00394 L
.77126 .00394 L
.77174 .00394 L
.7722 .00394 L
.77269 .00394 L
.77316 .00394 L
.77366 .00394 L
.77414 .00394 L
.7746 .00394 L
.77509 .00394 L
.77556 .00394 L
.77602 .00394 L
.7765 .00394 L
.77697 .00394 L
.77747 .00394 L
.77795 .00394 L
.77841 .00394 L
.77889 .00394 L
.77937 .00394 L
.77982 .00394 L
.7803 .00394 L
.78076 .00394 L
.78126 .00394 L
.78173 .00394 L
.78219 .00394 L
.78268 .00394 L
.78315 .00394 L
.78364 .00394 L
.78412 .00394 L
.78458 .00394 L
.78508 .00394 L
.78555 .00394 L
.786 .00394 L
.78649 .00394 L
Mistroke
.78695 .00394 L
.78745 .00394 L
.78792 .00394 L
.78838 .00394 L
.78887 .00394 L
.78934 .00394 L
.78984 .00394 L
.79032 .00394 L
.79079 .00394 L
.79128 .00394 L
.79175 .00394 L
.79221 .00394 L
.79269 .00394 L
.79316 .00394 L
.79366 .00394 L
.79414 .00394 L
.7946 .00394 L
.79509 .00394 L
.79556 .00394 L
.79601 .00394 L
.7965 .00394 L
.79696 .00394 L
.79745 .00394 L
.79793 .00394 L
.79839 .00394 L
.79888 .00394 L
.79934 .00394 L
.79984 .00394 L
.80032 .00394 L
.80079 .00394 L
.80128 .00394 L
.80175 .00394 L
.80221 .00394 L
.80269 .00394 L
.80316 .00394 L
.80365 .00394 L
.80413 .00394 L
.80459 .00394 L
.80508 .00394 L
.80555 .00394 L
.80605 .00394 L
.80653 .00394 L
.80699 .00394 L
.80749 .00394 L
.80796 .00394 L
.80842 .00394 L
.80891 .00394 L
.80937 .00394 L
.80987 .00394 L
.81035 .00394 L
Mistroke
.81081 .00394 L
.8113 .00394 L
.81177 .00394 L
.81223 .00394 L
.81271 .00394 L
.81318 .00394 L
.81367 .00394 L
.81415 .00394 L
.81461 .00394 L
.81509 .00394 L
.81556 .00394 L
.81606 .00394 L
.81654 .00394 L
.81701 .00394 L
.8175 .00394 L
.81797 .00394 L
.81843 .00394 L
.81891 .00394 L
.81938 .00394 L
.81988 .00394 L
.82036 .00394 L
.82082 .00394 L
.82131 .00394 L
.82178 .00394 L
.82223 .00394 L
.82271 .00394 L
.82318 .00394 L
.82367 .00394 L
.82415 .00394 L
.8246 .00394 L
.82509 .00394 L
.82556 .00394 L
.82606 .00394 L
.82654 .00394 L
.827 .00394 L
.82749 .00394 L
.82796 .00394 L
.82842 .00394 L
.8289 .00394 L
.82937 .00394 L
.82986 .00394 L
.83034 .00394 L
.8308 .00394 L
.83129 .00394 L
.83176 .00394 L
.83226 .00394 L
.83274 .00394 L
.8332 .00394 L
.8337 .00394 L
.83417 .00394 L
Mistroke
.83463 .00394 L
.83511 .00394 L
.83558 .00394 L
.83608 .00394 L
.83656 .00394 L
.83702 .00394 L
.83751 .00394 L
.83798 .00394 L
.83843 .00394 L
.83892 .00394 L
.83938 .00394 L
.83987 .00394 L
.84035 .00394 L
.84081 .00394 L
.8413 .00394 L
.84177 .00394 L
.84226 .00394 L
.84275 .00394 L
.84321 .00394 L
.8437 .00394 L
.84417 .00394 L
.84463 .00394 L
.84511 .00394 L
.84558 .00394 L
.84608 .00394 L
.84655 .00394 L
.84701 .00394 L
.8475 .00394 L
.84797 .00394 L
.84843 .00394 L
.84891 .00394 L
.84937 .00394 L
.84987 .00394 L
.85034 .00394 L
.8508 .00394 L
.85128 .00394 L
.85175 .00394 L
.85225 .00394 L
.85273 .00394 L
.85319 .00394 L
.85368 .00394 L
.85415 .00394 L
.85461 .00394 L
.85509 .00394 L
.85556 .00394 L
.85605 .00394 L
.85653 .00394 L
.85699 .00394 L
.85748 .00394 L
.85795 .00394 L
Mistroke
.85845 .00394 L
.85893 .00394 L
.85939 .00394 L
.85988 .00394 L
.86036 .00394 L
.86081 .00394 L
.8613 .00394 L
.86177 .00394 L
.86226 .00394 L
.86274 .00394 L
.8632 .00394 L
.86369 .00394 L
.86416 .00394 L
.86462 .00394 L
.8651 .00394 L
.86556 .00394 L
.86606 .00394 L
.86653 .00394 L
.86699 .00394 L
.86748 .00394 L
.86795 .00394 L
.86844 .00394 L
.86892 .00394 L
.86939 .00394 L
.86988 .00394 L
.87035 .00394 L
.87081 .00394 L
.87129 .00394 L
.87176 .00394 L
.87225 .00394 L
.87273 .00394 L
.87319 .00394 L
.87368 .00394 L
.87415 .00394 L
.87465 .00394 L
.87513 .00394 L
.87559 .00394 L
.87609 .00394 L
.87656 .00394 L
.87702 .00394 L
.8775 .00394 L
.87797 .00394 L
.87847 .00394 L
.87895 .00394 L
.87941 .00394 L
.8799 .00394 L
.88037 .00394 L
.88083 .00394 L
.88131 .00394 L
.88177 .00394 L
Mistroke
.88227 .00394 L
.88275 .00394 L
.8832 .00394 L
.88369 .00394 L
.88416 .00394 L
.88466 .00394 L
.88514 .00394 L
.8856 .00394 L
.8861 .00394 L
.88657 .00394 L
.88702 .00394 L
.88751 .00394 L
.88798 .00394 L
.88847 .00394 L
.88895 .00394 L
.88941 .00394 L
.8899 .00394 L
.89037 .00394 L
.89082 .00394 L
.89131 .00394 L
.89177 .00394 L
.89226 .00394 L
.89274 .00394 L
.8932 .00394 L
.89368 .00394 L
.89415 .00394 L
.89465 .00394 L
.89513 .00394 L
.89559 .00394 L
.89608 .00394 L
.89656 .00394 L
.89701 .00394 L
.89749 .00394 L
.89796 .00394 L
.89846 .00394 L
.89893 .00394 L
.89939 .00394 L
.89988 .00394 L
.90035 .00394 L
.90085 .00394 L
.90133 .00394 L
.90179 .00394 L
.90229 .00394 L
.90276 .00394 L
.90322 .00394 L
.9037 .00394 L
.90417 .00394 L
.90467 .00394 L
.90515 .00394 L
.90561 .00394 L
Mistroke
.9061 .00394 L
.90657 .00394 L
.90702 .00394 L
.9075 .00394 L
.90797 .00394 L
.90846 .00394 L
.90894 .00394 L
.9094 .00394 L
.90989 .00394 L
.91035 .00394 L
.91085 .00394 L
.91133 .00394 L
.9118 .00394 L
.91229 .00394 L
.91276 .00394 L
.91322 .00394 L
.9137 .00394 L
.91417 .00394 L
.91466 .00394 L
.91514 .00394 L
.9156 .00394 L
.91609 .00394 L
.91656 .00394 L
.91706 .00394 L
.91754 .00394 L
.91801 .00394 L
.9185 .00394 L
.91897 .00394 L
.91943 .00394 L
.91992 .00394 L
.92039 .00394 L
.92088 .00394 L
.92136 .00394 L
.92182 .00394 L
.92231 .00394 L
.92279 .00394 L
.92324 .00394 L
.92372 .00394 L
.92419 .00394 L
.92468 .00394 L
.92516 .00394 L
.92562 .00394 L
.92611 .00394 L
.92658 .00394 L
.92708 .00394 L
.92756 .00394 L
.92802 .00394 L
.92851 .00394 L
.92899 .00394 L
.92944 .00394 L
Mistroke
.92993 .00394 L
.93039 .00394 L
.93089 .00394 L
.93137 .00394 L
.93183 .00394 L
.93232 .00394 L
.93279 .00394 L
.93324 .00394 L
.93373 .00394 L
.93419 .00394 L
.93469 .00394 L
.93516 .00394 L
.93562 .00394 L
.93611 .00394 L
.93657 .00394 L
.93707 .00394 L
.93755 .00394 L
.93801 .00394 L
.93851 .00394 L
.93898 .00394 L
.93943 .00394 L
.93992 .00394 L
.94038 .00394 L
.94088 .00394 L
.94136 .00394 L
.94182 .00394 L
.9423 .00394 L
.94277 .00394 L
.94327 .00394 L
.94376 .00394 L
.94422 .00394 L
.94471 .00394 L
.94519 .00394 L
.94564 .00394 L
.94613 .00394 L
.9466 .00394 L
.94709 .00394 L
.94757 .00394 L
.94803 .00394 L
.94852 .00394 L
.949 .00394 L
.94945 .00394 L
.94993 .00394 L
.9504 .00394 L
.95089 .00394 L
.95137 .00394 L
.95183 .00394 L
.95231 .00394 L
.95278 .00394 L
.95328 .00394 L
Mistroke
.95376 .00394 L
.95423 .00394 L
.95472 .00394 L
.95519 .00394 L
.95565 .00394 L
.95613 .00394 L
.9566 .00394 L
.95709 .00394 L
.95757 .00394 L
.95803 .00394 L
.95852 .00394 L
.95899 .00394 L
.95945 .00394 L
.95993 .00394 L
.96039 .00394 L
.96088 .00394 L
.96136 .00394 L
.96182 .00394 L
.9623 .00394 L
.96277 .00394 L
.96327 .00394 L
.96375 .00394 L
.96421 .00394 L
.9647 .00394 L
.96517 .00394 L
.96563 .00394 L
.96611 .00394 L
.96658 .00394 L
.96707 .00394 L
.96755 .00394 L
.96801 .00394 L
.9685 .00394 L
.96897 .00394 L
.96947 .00394 L
.96995 .00394 L
.97041 .00394 L
.9709 .00394 L
.97138 .00394 L
.97183 .00394 L
.97232 .00394 L
.97279 .00394 L
.97328 .00394 L
.97376 .00394 L
.97422 .00394 L
.97471 .00394 L
.97518 .00394 L
.97564 .00394 L
.97612 .00394 L
.97619 .00394 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 0.00393652 0.196826 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00394 -6 -4.5 ]
[-0.0125 .00394 0 4.5 ]
[-0.0125 .10235 -18 -4.5 ]
[-0.0125 .10235 0 4.5 ]
[-0.0125 .20076 -6 -4.5 ]
[-0.0125 .20076 0 4.5 ]
[-0.0125 .29918 -18 -4.5 ]
[-0.0125 .29918 0 4.5 ]
[-0.0125 .39759 -6 -4.5 ]
[-0.0125 .39759 0 4.5 ]
[-0.0125 .496 -18 -4.5 ]
[-0.0125 .496 0 4.5 ]
[-0.0125 .59441 -6 -4.5 ]
[-0.0125 .59441 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00394 m
.00625 .00394 L
s
[(0)] -0.0125 .00394 1 0 Mshowa
0 .10235 m
.00625 .10235 L
s
[(0.5)] -0.0125 .10235 1 0 Mshowa
0 .20076 m
.00625 .20076 L
s
[(1)] -0.0125 .20076 1 0 Mshowa
0 .29918 m
.00625 .29918 L
s
[(1.5)] -0.0125 .29918 1 0 Mshowa
0 .39759 m
.00625 .39759 L
s
[(2)] -0.0125 .39759 1 0 Mshowa
0 .496 m
.00625 .496 L
s
[(2.5)] -0.0125 .496 1 0 Mshowa
0 .59441 m
.00625 .59441 L
s
[(3)] -0.0125 .59441 1 0 Mshowa
.125 Mabswid
0 .02362 m
.00375 .02362 L
s
0 .0433 m
.00375 .0433 L
s
0 .06298 m
.00375 .06298 L
s
0 .08267 m
.00375 .08267 L
s
0 .12203 m
.00375 .12203 L
s
0 .14171 m
.00375 .14171 L
s
0 .1614 m
.00375 .1614 L
s
0 .18108 m
.00375 .18108 L
s
0 .22045 m
.00375 .22045 L
s
0 .24013 m
.00375 .24013 L
s
0 .25981 m
.00375 .25981 L
s
0 .27949 m
.00375 .27949 L
s
0 .31886 m
.00375 .31886 L
s
0 .33854 m
.00375 .33854 L
s
0 .35822 m
.00375 .35822 L
s
0 .37791 m
.00375 .37791 L
s
0 .41727 m
.00375 .41727 L
s
0 .43695 m
.00375 .43695 L
s
0 .45664 m
.00375 .45664 L
s
0 .47632 m
.00375 .47632 L
s
0 .51568 m
.00375 .51568 L
s
0 .53537 m
.00375 .53537 L
s
0 .55505 m
.00375 .55505 L
s
0 .57473 m
.00375 .57473 L
s
0 .6141 m
.00375 .6141 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00394 m
1 .00394 L
s
.99375 .10235 m
1 .10235 L
s
.99375 .20076 m
1 .20076 L
s
.99375 .29918 m
1 .29918 L
s
.99375 .39759 m
1 .39759 L
s
.99375 .496 m
1 .496 L
s
.99375 .59441 m
1 .59441 L
s
.125 Mabswid
.99625 .02362 m
1 .02362 L
s
.99625 .0433 m
1 .0433 L
s
.99625 .06298 m
1 .06298 L
s
.99625 .08267 m
1 .08267 L
s
.99625 .12203 m
1 .12203 L
s
.99625 .14171 m
1 .14171 L
s
.99625 .1614 m
1 .1614 L
s
.99625 .18108 m
1 .18108 L
s
.99625 .22045 m
1 .22045 L
s
.99625 .24013 m
1 .24013 L
s
.99625 .25981 m
1 .25981 L
s
.99625 .27949 m
1 .27949 L
s
.99625 .31886 m
1 .31886 L
s
.99625 .33854 m
1 .33854 L
s
.99625 .35822 m
1 .35822 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .41727 m
1 .41727 L
s
.99625 .43695 m
1 .43695 L
s
.99625 .45664 m
1 .45664 L
s
.99625 .47632 m
1 .47632 L
s
.99625 .51568 m
1 .51568 L
s
.99625 .53537 m
1 .53537 L
s
.99625 .55505 m
1 .55505 L
s
.99625 .57473 m
1 .57473 L
s
.99625 .6141 m
1 .6141 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .20076 m
.02403 .20076 L
.02426 .20076 L
.02432 .20076 L
.02435 .20076 L
.02438 .20076 L
.0244 .20076 L
.02441 .00394 L
.02443 .00394 L
.02445 .00394 L
.02451 .00394 L
.02474 .00394 L
.02575 .00394 L
.02672 .00394 L
.02765 .00394 L
.02864 .00394 L
.02959 .00394 L
.03051 .00394 L
.03149 .00394 L
.03243 .00394 L
.03343 .00394 L
.03439 .00394 L
.03532 .00394 L
.0363 .00394 L
.03725 .00394 L
.03816 .00394 L
.03913 .00394 L
.04007 .00394 L
.04106 .00394 L
.04202 .00394 L
.04294 .00394 L
.04392 .00394 L
.04486 .00394 L
.04577 .00394 L
.04627 .00394 L
.04649 .00394 L
.04673 .00394 L
.04685 .00394 L
.04691 .00394 L
.04694 .00394 L
.04697 .00394 L
.047 .00394 L
.04702 .20076 L
.04705 .20076 L
.04708 .20076 L
.04719 .20076 L
.04766 .20076 L
.0479 .20076 L
.04802 .20076 L
.04813 .20076 L
Mistroke
.04816 .20076 L
.04819 .20076 L
.04821 .20076 L
.04823 .00394 L
.04826 .00394 L
.04839 .00394 L
.04863 .00394 L
.04962 .00394 L
.05057 .00394 L
.05148 .00394 L
.05246 .00394 L
.05339 .00394 L
.05439 .00394 L
.05534 .00394 L
.05627 .00394 L
.05725 .00394 L
.05819 .00394 L
.0591 .00394 L
.06007 .00394 L
.061 .00394 L
.06199 .00394 L
.06294 .00394 L
.06386 .00394 L
.06483 .00394 L
.06577 .00394 L
.06677 .00394 L
.06773 .00394 L
.06866 .00394 L
.06964 .00394 L
.07013 .00394 L
.07037 .00394 L
.07059 .00394 L
.0707 .00394 L
.07076 .00394 L
.07079 .00394 L
.07082 .00394 L
.07084 .39759 L
.07087 .39759 L
.07093 .39759 L
.07103 .39759 L
.0715 .39759 L
.07175 .39759 L
.07187 .39759 L
.07193 .39759 L
.07198 .39759 L
.07201 .39759 L
.07204 .00394 L
.07207 .00394 L
.0721 .00394 L
.07222 .00394 L
Mistroke
.07249 .00394 L
.0734 .00394 L
.07437 .00394 L
.0753 .00394 L
.07629 .00394 L
.07724 .00394 L
.07816 .00394 L
.07914 .00394 L
.08008 .00394 L
.08108 .00394 L
.08204 .00394 L
.08297 .00394 L
.08395 .00394 L
.0849 .00394 L
.08582 .00394 L
.08679 .00394 L
.08772 .00394 L
.08872 .00394 L
.08968 .00394 L
.0906 .00394 L
.09158 .00394 L
.09252 .00394 L
.09343 .00394 L
.09439 .00394 L
.09532 .00394 L
.09631 .00394 L
.09727 .00394 L
.09818 .00394 L
.09916 .00394 L
.10009 .00394 L
.10109 .00394 L
.10205 .00394 L
.10298 .00394 L
.10396 .00394 L
.10491 .00394 L
.10582 .00394 L
.10679 .00394 L
.10772 .00394 L
.10871 .00394 L
.10967 .00394 L
.11059 .00394 L
.11157 .00394 L
.11251 .00394 L
.11351 .00394 L
.11447 .00394 L
.1154 .00394 L
.11639 .00394 L
.11734 .00394 L
.11825 .00394 L
.11923 .00394 L
Mistroke
.12016 .00394 L
.12116 .00394 L
.12212 .00394 L
.12304 .00394 L
.12402 .00394 L
.12497 .00394 L
.12587 .00394 L
.12684 .00394 L
.12777 .00394 L
.12876 .00394 L
.12972 .00394 L
.13063 .00394 L
.13161 .00394 L
.13255 .00394 L
.13355 .00394 L
.13451 .00394 L
.13544 .00394 L
.13642 .00394 L
.13737 .00394 L
.13828 .00394 L
.13925 .00394 L
.14019 .00394 L
.14118 .00394 L
.14214 .00394 L
.14306 .00394 L
.14404 .00394 L
.14498 .00394 L
.14589 .00394 L
.14685 .00394 L
.14778 .00394 L
.14877 .00394 L
.14972 .00394 L
.15064 .00394 L
.15161 .00394 L
.15255 .00394 L
.15355 .00394 L
.15451 .00394 L
.15543 .00394 L
.15641 .00394 L
.15736 .00394 L
.15827 .00394 L
.15924 .00394 L
.16017 .00394 L
.16116 .00394 L
.16212 .00394 L
.16303 .00394 L
.16401 .00394 L
.16495 .00394 L
.16595 .00394 L
.16692 .00394 L
Mistroke
.16784 .00394 L
.16883 .00394 L
.16978 .00394 L
.17069 .00394 L
.17166 .00394 L
.1726 .00394 L
.17359 .00394 L
.17455 .00394 L
.17547 .00394 L
.17646 .00394 L
.1774 .00394 L
.17831 .00394 L
.17927 .00394 L
.1802 .00394 L
.18119 .00394 L
.18215 .00394 L
.18306 .00394 L
.18404 .00394 L
.18498 .00394 L
.18598 .00394 L
.18694 .00394 L
.18786 .00394 L
.18885 .00394 L
.18979 .00394 L
.19071 .00394 L
.19168 .00394 L
.19261 .00394 L
.1936 .00394 L
.19456 .00394 L
.19548 .00394 L
.19646 .00394 L
.1974 .00394 L
.1983 .00394 L
.19927 .00394 L
.2002 .00394 L
.20118 .00394 L
.20214 .00394 L
.20305 .00394 L
.20402 .00394 L
.20496 .00394 L
.20596 .00394 L
.20692 .00394 L
.20784 .00394 L
.20882 .00394 L
.20977 .00394 L
.21068 .00394 L
.21164 .00394 L
.21257 .00394 L
.21305 .00394 L
.2133 .00394 L
Mistroke
.21344 .00394 L
.21357 .00394 L
.21363 .00394 L
.21366 .00394 L
.21369 .00394 L
.21371 .39759 L
.21372 .39759 L
.21376 .39759 L
.21382 .39759 L
.21406 .39759 L
.21452 .39759 L
.21464 .39759 L
.21476 .39759 L
.21483 .39759 L
.21485 .39759 L
.21487 .39759 L
.21489 .00394 L
.2149 .00394 L
.21503 .00394 L
.21551 .00394 L
.21647 .00394 L
.21738 .00394 L
.21836 .00394 L
.21929 .00394 L
.22029 .00394 L
.22125 .00394 L
.22218 .00394 L
.22316 .00394 L
.22411 .00394 L
.22502 .00394 L
.22599 .00394 L
.22692 .00394 L
.22791 .00394 L
.22887 .00394 L
.22978 .00394 L
.23076 .00394 L
.2317 .00394 L
.2327 .00394 L
.23367 .00394 L
.2346 .00394 L
.23558 .00394 L
.23653 .00394 L
.23701 .00394 L
.23722 .00394 L
.23733 .00394 L
.23739 .00394 L
.23745 .00394 L
.23748 .00394 L
.23751 .20076 L
.23752 .20076 L
Mistroke
.23754 .20076 L
.23757 .20076 L
.23769 .20076 L
.23792 .20076 L
.23816 .20076 L
.23842 .20076 L
.23855 .20076 L
.23861 .20076 L
.23864 .20076 L
.23867 .20076 L
.2387 .00394 L
.23872 .00394 L
.23878 .00394 L
.23889 .00394 L
.23934 .00394 L
.24027 .00394 L
.24126 .00394 L
.24222 .00394 L
.24314 .00394 L
.24412 .00394 L
.24506 .00394 L
.24597 .00394 L
.24693 .00394 L
.24786 .00394 L
.24885 .00394 L
.2498 .00394 L
.25072 .00394 L
.25169 .00394 L
.25263 .00394 L
.25362 .00394 L
.25458 .00394 L
.25551 .00394 L
.25649 .00394 L
.25744 .00394 L
.25835 .00394 L
.25931 .00394 L
.26025 .00394 L
.26072 .00394 L
.26097 .00394 L
.26111 .00394 L
.26118 .00394 L
.26124 .00394 L
.26127 .00394 L
.2613 .00394 L
.26133 .20076 L
.26134 .20076 L
.26136 .20076 L
.2615 .20076 L
.26173 .20076 L
.26219 .20076 L
Mistroke
.26231 .20076 L
.26238 .20076 L
.26244 .20076 L
.26247 .20076 L
.26249 .20076 L
.2625 .00394 L
.26252 .00394 L
.26254 .00394 L
.26258 .00394 L
.2627 .00394 L
.26319 .00394 L
.26416 .00394 L
.2651 .00394 L
.2661 .00394 L
.26706 .00394 L
.26798 .00394 L
.26897 .00394 L
.26991 .00394 L
.27083 .00394 L
.2718 .00394 L
.27273 .00394 L
.27372 .00394 L
.27468 .00394 L
.2756 .00394 L
.27657 .00394 L
.27752 .00394 L
.27852 .00394 L
.27948 .00394 L
.28041 .00394 L
.2814 .00394 L
.28235 .00394 L
.28326 .00394 L
.28377 .00394 L
.28423 .00394 L
.28447 .00394 L
.28472 .00394 L
.28483 .00394 L
.28495 .00394 L
.28506 .00394 L
.28509 .00394 L
.28512 .00394 L
.28515 .20076 L
.28517 .20076 L
.28567 .20076 L
.28591 .20076 L
.28613 .20076 L
.28624 .20076 L
.28627 .20076 L
.28628 .20076 L
.2863 .20076 L
Mistroke
.28632 .00394 L
.28635 .00394 L
.28657 .00394 L
.28704 .00394 L
.28798 .00394 L
.28897 .00394 L
.28993 .00394 L
.29085 .00394 L
.29183 .00394 L
.29277 .00394 L
.29368 .00394 L
.29464 .00394 L
.29557 .00394 L
.29656 .00394 L
.29751 .00394 L
.29843 .00394 L
.2994 .00394 L
.30034 .00394 L
.30134 .00394 L
.3023 .00394 L
.30322 .00394 L
.30421 .00394 L
.30515 .00394 L
.30606 .00394 L
.30703 .00394 L
.30796 .00394 L
.30821 .00394 L
.30847 .00394 L
.30859 .00394 L
.30872 .00394 L
.30879 .00394 L
.30884 .00394 L
.3089 .00394 L
.30893 .00394 L
.30896 .39759 L
.30899 .39759 L
.30901 .39759 L
.30907 .39759 L
.30919 .39759 L
.30941 .39759 L
.30965 .39759 L
.30978 .39759 L
.3099 .39759 L
.31001 .39759 L
.31004 .39759 L
.31008 .39759 L
.3101 .39759 L
.31013 .00394 L
.31015 .00394 L
.31017 .00394 L
Mistroke
.3102 .00394 L
.31026 .00394 L
.31038 .00394 L
.31083 .00394 L
.31175 .00394 L
.31274 .00394 L
.31368 .00394 L
.3146 .00394 L
.31557 .00394 L
.3165 .00394 L
.31749 .00394 L
.31845 .00394 L
.31937 .00394 L
.32035 .00394 L
.32129 .00394 L
.3222 .00394 L
.32316 .00394 L
.32409 .00394 L
.32508 .00394 L
.32603 .00394 L
.32694 .00394 L
.32792 .00394 L
.32885 .00394 L
.32985 .00394 L
.33081 .00394 L
.33173 .00394 L
.33271 .00394 L
.33366 .00394 L
.33457 .00394 L
.33554 .00394 L
.33647 .00394 L
.33746 .00394 L
.33841 .00394 L
.33933 .00394 L
.34031 .00394 L
.34125 .00394 L
.34225 .00394 L
.34321 .00394 L
.34414 .00394 L
.34512 .00394 L
.34607 .00394 L
.34699 .00394 L
.34796 .00394 L
.34889 .00394 L
.34989 .00394 L
.35084 .00394 L
.35176 .00394 L
.35275 .00394 L
.35369 .00394 L
.3546 .00394 L
Mistroke
.35556 .00394 L
.35649 .00394 L
.35748 .00394 L
.35843 .00394 L
.35935 .00394 L
.36032 .00394 L
.36126 .00394 L
.36226 .00394 L
.36322 .00394 L
.36414 .00394 L
.36513 .00394 L
.36608 .00394 L
.36699 .00394 L
.36796 .00394 L
.36889 .00394 L
.36988 .00394 L
.37084 .00394 L
.37176 .00394 L
.37273 .00394 L
.37367 .00394 L
.37468 .00394 L
.37564 .00394 L
.37657 .00394 L
.37755 .00394 L
.3785 .00394 L
.37942 .00394 L
.38039 .00394 L
.38133 .00394 L
.38232 .00394 L
.38328 .00394 L
.3842 .00394 L
.38519 .00394 L
.38613 .00394 L
.38704 .00394 L
.38801 .00394 L
.38894 .00394 L
.38993 .00394 L
.39088 .00394 L
.3918 .00394 L
.39277 .00394 L
.39371 .00394 L
.39471 .00394 L
.39567 .00394 L
.3966 .00394 L
.39758 .00394 L
.39853 .00394 L
.39944 .00394 L
.40042 .00394 L
.40135 .00394 L
.40234 .00394 L
Mistroke
.4033 .00394 L
.40422 .00394 L
.4052 .00394 L
.40614 .00394 L
.40705 .00394 L
.40801 .00394 L
.40894 .00394 L
.40993 .00394 L
.41088 .00394 L
.4118 .00394 L
.41277 .00394 L
.41371 .00394 L
.41471 .00394 L
.41567 .00394 L
.41659 .00394 L
.41757 .00394 L
.41852 .00394 L
.41943 .00394 L
.4204 .00394 L
.42133 .00394 L
.42232 .00394 L
.42328 .00394 L
.42419 .00394 L
.42517 .00394 L
.42611 .00394 L
.42711 .00394 L
.42808 .00394 L
.429 .00394 L
.42999 .00394 L
.43094 .00394 L
.43185 .00394 L
.43282 .00394 L
.43376 .00394 L
.43475 .00394 L
.43571 .00394 L
.43663 .00394 L
.43761 .00394 L
.43856 .00394 L
.43947 .00394 L
.44043 .00394 L
.44136 .00394 L
.44235 .00394 L
.4433 .00394 L
.44422 .00394 L
.4452 .00394 L
.44613 .00394 L
.44713 .00394 L
.44809 .00394 L
.44902 .00394 L
.45 .00394 L
Mistroke
.45049 .00394 L
.45095 .00394 L
.45139 .00394 L
.45152 .00394 L
.45164 .00394 L
.45169 .00394 L
.45174 .00394 L
.45177 .00394 L
.45179 .39759 L
.45181 .39759 L
.45186 .39759 L
.4523 .39759 L
.45256 .39759 L
.45268 .39759 L
.45279 .39759 L
.45285 .39759 L
.45291 .39759 L
.45294 .39759 L
.45297 .39759 L
.45299 .00394 L
.45302 .00394 L
.45327 .00394 L
.45378 .00394 L
.45474 .00394 L
.45568 .00394 L
.45667 .00394 L
.45762 .00394 L
.45854 .00394 L
.45952 .00394 L
.46046 .00394 L
.46145 .00394 L
.46242 .00394 L
.46334 .00394 L
.46433 .00394 L
.46528 .00394 L
.46619 .00394 L
.46716 .00394 L
.4681 .00394 L
.46909 .00394 L
.47005 .00394 L
.47097 .00394 L
.47195 .00394 L
.47289 .00394 L
.4738 .00394 L
.4743 .00394 L
.47476 .00394 L
.47522 .00394 L
.47544 .00394 L
.47551 .00394 L
.47554 .00394 L
Mistroke
.47556 .00394 L
.47557 .00394 L
.4756 .20076 L
.47562 .20076 L
.47564 .20076 L
.47569 .20076 L
.47617 .20076 L
.47638 .20076 L
.4766 .20076 L
.47666 .20076 L
.4767 .20076 L
.47673 .20076 L
.47676 .20076 L
.47679 .00394 L
.47682 .00394 L
.47684 .00394 L
.47707 .00394 L
.47757 .00394 L
.47852 .00394 L
.47944 .00394 L
.48041 .00394 L
.48134 .00394 L
.48234 .00394 L
.4833 .00394 L
.48422 .00394 L
.4852 .00394 L
.48615 .00394 L
.48705 .00394 L
.48802 .00394 L
.48895 .00394 L
.48994 .00394 L
.49089 .00394 L
.49181 .00394 L
.49279 .00394 L
.49373 .00394 L
.49473 .00394 L
.49569 .00394 L
.49661 .00394 L
.4976 .00394 L
.49809 .00394 L
.49854 .00394 L
.49898 .00394 L
.49911 .00394 L
.49923 .00394 L
.49934 .00394 L
.49937 .00394 L
.4994 .00394 L
.49943 .20076 L
.49946 .20076 L
.49996 .20076 L
Mistroke
.50018 .20076 L
.5003 .20076 L
.50042 .20076 L
.50048 .20076 L
.50052 .20076 L
.50054 .20076 L
.50057 .20076 L
.5006 .00394 L
.50063 .00394 L
.50066 .00394 L
.50087 .00394 L
.50135 .00394 L
.50232 .00394 L
.50325 .00394 L
.50424 .00394 L
.5052 .00394 L
.50611 .00394 L
.50709 .00394 L
.50803 .00394 L
.50903 .00394 L
.50999 .00394 L
.51092 .00394 L
.51191 .00394 L
.51286 .00394 L
.51377 .00394 L
.51474 .00394 L
.51568 .00394 L
.51667 .00394 L
.51763 .00394 L
.51855 .00394 L
.51953 .00394 L
.52047 .00394 L
.52138 .00394 L
.52188 .00394 L
.52235 .00394 L
.5228 .00394 L
.52303 .00394 L
.52309 .00394 L
.52312 .00394 L
.52316 .00394 L
.52319 .00394 L
.5232 .00394 L
.52322 .20076 L
.52325 .20076 L
.52328 .20076 L
.52375 .20076 L
.52396 .20076 L
.52419 .20076 L
.52425 .20076 L
.52431 .20076 L
Mistroke
.52434 .20076 L
.52437 .20076 L
.5244 .20076 L
.52443 .00394 L
.52446 .00394 L
.52449 .00394 L
.52455 .00394 L
.52466 .00394 L
.52516 .00394 L
.52613 .00394 L
.52707 .00394 L
.52806 .00394 L
.52902 .00394 L
.52994 .00394 L
.53093 .00394 L
.53187 .00394 L
.53278 .00394 L
.53375 .00394 L
.53468 .00394 L
.53567 .00394 L
.53662 .00394 L
.53754 .00394 L
.53852 .00394 L
.53946 .00394 L
.54045 .00394 L
.54142 .00394 L
.54234 .00394 L
.54333 .00394 L
.54428 .00394 L
.54519 .00394 L
.5457 .00394 L
.54616 .00394 L
.54639 .00394 L
.54664 .00394 L
.54675 .00394 L
.54687 .00394 L
.54692 .00394 L
.54698 .00394 L
.54701 .00394 L
.54704 .39759 L
.54706 .39759 L
.54709 .39759 L
.54757 .39759 L
.54778 .39759 L
.54801 .39759 L
.54807 .39759 L
.54813 .39759 L
.54816 .39759 L
.54819 .39759 L
.54822 .00394 L
Mistroke
.54825 .00394 L
.54848 .00394 L
.54898 .00394 L
.54997 .00394 L
.55093 .00394 L
.55185 .00394 L
.55283 .00394 L
.55377 .00394 L
.55477 .00394 L
.55573 .00394 L
.55666 .00394 L
.55764 .00394 L
.55859 .00394 L
.55951 .00394 L
.56048 .00394 L
.56141 .00394 L
.56241 .00394 L
.56337 .00394 L
.56429 .00394 L
.56527 .00394 L
.56621 .00394 L
.56712 .00394 L
.56809 .00394 L
.56902 .00394 L
.57001 .00394 L
.57096 .00394 L
.57188 .00394 L
.57285 .00394 L
.57379 .00394 L
.57479 .00394 L
.57575 .00394 L
.57668 .00394 L
.57766 .00394 L
.57861 .00394 L
.57952 .00394 L
.58049 .00394 L
.58142 .00394 L
.58242 .00394 L
.58337 .00394 L
.58429 .00394 L
.58527 .00394 L
.58621 .00394 L
.58712 .00394 L
.58808 .00394 L
.58901 .00394 L
.59 .00394 L
.59095 .00394 L
.59187 .00394 L
.59284 .00394 L
.59378 .00394 L
Mistroke
.59477 .00394 L
.59573 .00394 L
.59665 .00394 L
.59764 .00394 L
.59858 .00394 L
.59949 .00394 L
.60046 .00394 L
.60139 .00394 L
.60238 .00394 L
.60334 .00394 L
.60425 .00394 L
.60523 .00394 L
.60617 .00394 L
.60717 .00394 L
.60813 .00394 L
.60906 .00394 L
.61005 .00394 L
.61099 .00394 L
.61191 .00394 L
.61288 .00394 L
.61381 .00394 L
.61481 .00394 L
.61576 .00394 L
.61669 .00394 L
.61767 .00394 L
.61861 .00394 L
.61952 .00394 L
.62048 .00394 L
.62141 .00394 L
.6224 .00394 L
.62335 .00394 L
.62427 .00394 L
.62524 .00394 L
.62618 .00394 L
.62718 .00394 L
.62814 .00394 L
.62906 .00394 L
.63005 .00394 L
.63099 .00394 L
.6319 .00394 L
.63287 .00394 L
.63381 .00394 L
.6348 .00394 L
.63575 .00394 L
.63667 .00394 L
.63765 .00394 L
.63859 .00394 L
.63959 .00394 L
.64056 .00394 L
.64148 .00394 L
Mistroke
.64247 .00394 L
.64342 .00394 L
.64434 .00394 L
.64531 .00394 L
.64624 .00394 L
.64724 .00394 L
.6482 .00394 L
.64912 .00394 L
.6501 .00394 L
.65105 .00394 L
.65196 .00394 L
.65292 .00394 L
.65385 .00394 L
.65484 .00394 L
.6558 .00394 L
.65671 .00394 L
.65769 .00394 L
.65863 .00394 L
.65963 .00394 L
.66059 .00394 L
.66152 .00394 L
.6625 .00394 L
.66345 .00394 L
.66436 .00394 L
.66533 .00394 L
.66626 .00394 L
.66726 .00394 L
.66821 .00394 L
.66913 .00394 L
.67011 .00394 L
.67106 .00394 L
.67196 .00394 L
.67293 .00394 L
.67386 .00394 L
.67485 .00394 L
.6758 .00394 L
.67671 .00394 L
.67769 .00394 L
.67862 .00394 L
.67962 .00394 L
.68058 .00394 L
.6815 .00394 L
.68249 .00394 L
.68343 .00394 L
.68434 .00394 L
.68531 .00394 L
.68624 .00394 L
.68723 .00394 L
.68819 .00394 L
.68911 .00394 L
Mistroke
.68958 .00394 L
.68972 .00394 L
.68978 .00394 L
.68981 .00394 L
.68984 .00394 L
.68987 .00394 L
.6899 .39759 L
.68993 .39759 L
.68996 .39759 L
.69008 .39759 L
.69033 .39759 L
.69059 .39759 L
.69072 .39759 L
.69085 .39759 L
.69096 .39759 L
.69099 .39759 L
.69102 .39759 L
.69105 .39759 L
.69108 .00394 L
.69111 .00394 L
.69114 .00394 L
.69119 .00394 L
.69131 .00394 L
.69153 .00394 L
.69203 .00394 L
.69296 .00394 L
.69394 .00394 L
.69489 .00394 L
.6958 .00394 L
.69677 .00394 L
.6977 .00394 L
.69869 .00394 L
.69965 .00394 L
.70057 .00394 L
.70155 .00394 L
.70249 .00394 L
.70349 .00394 L
.70445 .00394 L
.70538 .00394 L
.70637 .00394 L
.70732 .00394 L
.70823 .00394 L
.70921 .00394 L
.71014 .00394 L
.71114 .00394 L
.7121 .00394 L
.71302 .00394 L
.71327 .00394 L
.7135 .00394 L
.71361 .00394 L
Mistroke
.71365 .00394 L
.71368 .00394 L
.71371 .20076 L
.71374 .20076 L
.714 .20076 L
.71448 .20076 L
.71461 .20076 L
.71474 .20076 L
.7148 .20076 L
.71483 .20076 L
.71486 .20076 L
.71489 .00394 L
.7149 .00394 L
.71492 .00394 L
.71498 .00394 L
.71597 .00394 L
.71693 .00394 L
.71785 .00394 L
.71883 .00394 L
.71977 .00394 L
.72068 .00394 L
.72165 .00394 L
.72258 .00394 L
.72357 .00394 L
.72452 .00394 L
.72543 .00394 L
.72641 .00394 L
.72734 .00394 L
.72834 .00394 L
.7293 .00394 L
.73023 .00394 L
.73121 .00394 L
.73216 .00394 L
.73307 .00394 L
.73404 .00394 L
.73497 .00394 L
.73596 .00394 L
.73645 .00394 L
.73691 .00394 L
.73714 .00394 L
.73736 .00394 L
.73742 .00394 L
.73745 .00394 L
.73748 .00394 L
.73749 .00394 L
.73751 .20076 L
.73753 .20076 L
.73755 .20076 L
.73761 .20076 L
.73783 .20076 L
Mistroke
.73829 .20076 L
.73842 .20076 L
.73855 .20076 L
.73861 .20076 L
.73864 .20076 L
.73867 .20076 L
.73868 .20076 L
.7387 .00394 L
.73873 .00394 L
.73879 .00394 L
.73977 .00394 L
.74071 .00394 L
.7417 .00394 L
.74267 .00394 L
.74359 .00394 L
.74458 .00394 L
.74552 .00394 L
.74644 .00394 L
.74741 .00394 L
.74834 .00394 L
.74933 .00394 L
.75029 .00394 L
.75121 .00394 L
.75219 .00394 L
.75313 .00394 L
.75404 .00394 L
.755 .00394 L
.75593 .00394 L
.75692 .00394 L
.75787 .00394 L
.75878 .00394 L
.75976 .00394 L
.76069 .00394 L
.76094 .00394 L
.76107 .00394 L
.76114 .00394 L
.76121 .00394 L
.76126 .00394 L
.76128 .00394 L
.7613 .00394 L
.76133 .20076 L
.76134 .20076 L
.76136 .20076 L
.76139 .20076 L
.76146 .20076 L
.76169 .20076 L
.76194 .20076 L
.76221 .20076 L
.76233 .20076 L
.76239 .20076 L
Mistroke
.76243 .20076 L
.76246 .20076 L
.76249 .20076 L
.76251 .00394 L
.76254 .00394 L
.76257 .00394 L
.76269 .00394 L
.76367 .00394 L
.76461 .00394 L
.76552 .00394 L
.76649 .00394 L
.76742 .00394 L
.76841 .00394 L
.76936 .00394 L
.77027 .00394 L
.77125 .00394 L
.77219 .00394 L
.77319 .00394 L
.77415 .00394 L
.77507 .00394 L
.77605 .00394 L
.777 .00394 L
.77791 .00394 L
.77888 .00394 L
.77981 .00394 L
.78081 .00394 L
.78176 .00394 L
.78268 .00394 L
.78366 .00394 L
.7846 .00394 L
.78485 .00394 L
.78498 .00394 L
.78505 .00394 L
.78509 .00394 L
.78512 .00394 L
.78515 .39759 L
.78518 .39759 L
.78524 .39759 L
.78537 .39759 L
.7856 .39759 L
.78583 .39759 L
.78608 .39759 L
.78618 .39759 L
.78624 .39759 L
.78627 .39759 L
.78629 .39759 L
.78632 .00394 L
.78634 .00394 L
.78635 .00394 L
.78641 .00394 L
Mistroke
.78652 .00394 L
.78752 .00394 L
.78849 .00394 L
.78941 .00394 L
.7904 .00394 L
.79134 .00394 L
.79226 .00394 L
.79323 .00394 L
.79416 .00394 L
.79515 .00394 L
.79611 .00394 L
.79703 .00394 L
.79801 .00394 L
.79895 .00394 L
.79986 .00394 L
.80083 .00394 L
.80176 .00394 L
.80274 .00394 L
.8037 .00394 L
.80461 .00394 L
.80558 .00394 L
.80652 .00394 L
.80752 .00394 L
.80848 .00394 L
.8094 .00394 L
.81039 .00394 L
.81133 .00394 L
.81224 .00394 L
.81321 .00394 L
.81414 .00394 L
.81513 .00394 L
.81609 .00394 L
.81701 .00394 L
.81798 .00394 L
.81893 .00394 L
.81993 .00394 L
.82089 .00394 L
.82182 .00394 L
.8228 .00394 L
.82375 .00394 L
.82466 .00394 L
.82564 .00394 L
.82657 .00394 L
.82757 .00394 L
.82853 .00394 L
.82945 .00394 L
.83043 .00394 L
.83137 .00394 L
.83228 .00394 L
.83325 .00394 L
Mistroke
.83418 .00394 L
.83517 .00394 L
.83612 .00394 L
.83704 .00394 L
.83801 .00394 L
.83895 .00394 L
.83995 .00394 L
.84091 .00394 L
.84183 .00394 L
.84282 .00394 L
.84377 .00394 L
.84468 .00394 L
.84565 .00394 L
.84658 .00394 L
.84757 .00394 L
.84853 .00394 L
.84945 .00394 L
.85043 .00394 L
.85137 .00394 L
.85228 .00394 L
.85324 .00394 L
.85417 .00394 L
.85516 .00394 L
.85611 .00394 L
.85702 .00394 L
.85799 .00394 L
.85893 .00394 L
.85993 .00394 L
.86089 .00394 L
.86181 .00394 L
.86279 .00394 L
.86374 .00394 L
.86465 .00394 L
.86561 .00394 L
.86655 .00394 L
.86754 .00394 L
.86849 .00394 L
.86941 .00394 L
.87038 .00394 L
.87132 .00394 L
.87232 .00394 L
.87329 .00394 L
.87421 .00394 L
.8752 .00394 L
.87615 .00394 L
.87706 .00394 L
.87803 .00394 L
.87897 .00394 L
.87996 .00394 L
.88092 .00394 L
Mistroke
.88184 .00394 L
.88282 .00394 L
.88376 .00394 L
.88467 .00394 L
.88563 .00394 L
.88656 .00394 L
.88755 .00394 L
.8885 .00394 L
.88942 .00394 L
.89039 .00394 L
.89133 .00394 L
.89233 .00394 L
.89329 .00394 L
.89421 .00394 L
.8952 .00394 L
.89614 .00394 L
.89705 .00394 L
.89802 .00394 L
.89896 .00394 L
.89995 .00394 L
.9009 .00394 L
.90182 .00394 L
.9028 .00394 L
.90374 .00394 L
.90474 .00394 L
.90571 .00394 L
.90663 .00394 L
.90762 .00394 L
.90857 .00394 L
.90948 .00394 L
.91046 .00394 L
.91139 .00394 L
.91239 .00394 L
.91335 .00394 L
.91427 .00394 L
.91525 .00394 L
.91619 .00394 L
.9171 .00394 L
.91807 .00394 L
.919 .00394 L
.91999 .00394 L
.92094 .00394 L
.92186 .00394 L
.92284 .00394 L
.92378 .00394 L
.92477 .00394 L
.92574 .00394 L
.92666 .00394 L
.92713 .00394 L
.92738 .00394 L
Mistroke
.92765 .00394 L
.92778 .00394 L
.92784 .00394 L
.9279 .00394 L
.92793 .00394 L
.92796 .00394 L
.92798 .39759 L
.92801 .39759 L
.92814 .39759 L
.92859 .39759 L
.92883 .39759 L
.92896 .39759 L
.92902 .39759 L
.92908 .39759 L
.9291 .39759 L
.92913 .39759 L
.92916 .39759 L
.92918 .00394 L
.92921 .00394 L
.92923 .00394 L
.92929 .00394 L
.92952 .00394 L
.93049 .00394 L
.93142 .00394 L
.93241 .00394 L
.93337 .00394 L
.93429 .00394 L
.93526 .00394 L
.93621 .00394 L
.9372 .00394 L
.93817 .00394 L
.93909 .00394 L
.94008 .00394 L
.94103 .00394 L
.94194 .00394 L
.94291 .00394 L
.94385 .00394 L
.94484 .00394 L
.9458 .00394 L
.94672 .00394 L
.9477 .00394 L
.94865 .00394 L
.94955 .00394 L
.95052 .00394 L
.95097 .00394 L
.95122 .00394 L
.95145 .00394 L
.95157 .00394 L
.95168 .00394 L
.95175 .00394 L
Mistroke
.95176 .00394 L
.95178 .00394 L
.9518 .20076 L
.95181 .20076 L
.95193 .20076 L
.95244 .20076 L
.95268 .20076 L
.9528 .20076 L
.95291 .20076 L
.95294 .20076 L
.95297 .20076 L
.95299 .00394 L
.953 .00394 L
.95303 .00394 L
.95317 .00394 L
.95341 .00394 L
.9544 .00394 L
.95535 .00394 L
.95626 .00394 L
.95723 .00394 L
.95817 .00394 L
.95917 .00394 L
.96013 .00394 L
.96105 .00394 L
.96203 .00394 L
.96298 .00394 L
.96388 .00394 L
.96485 .00394 L
.96578 .00394 L
.96677 .00394 L
.96773 .00394 L
.96864 .00394 L
.96962 .00394 L
.97056 .00394 L
.97156 .00394 L
.97252 .00394 L
.97345 .00394 L
.97443 .00394 L
.97492 .00394 L
.97516 .00394 L
.97538 .00394 L
.97548 .00394 L
.97553 .00394 L
.97556 .00394 L
.97558 .00394 L
.9756 .20076 L
.97563 .20076 L
.97568 .20076 L
.97577 .20076 L
.97619 .20076 L
Mistroke
Mfstroke
0 0 1 r
.005 w
.02381 .00394 m
.02427 .00394 L
.02478 .00394 L
.02525 .00394 L
.02571 .00394 L
.0262 .00394 L
.02667 .00394 L
.02716 .00394 L
.02764 .00394 L
.0281 .00394 L
.02859 .00394 L
.02907 .00394 L
.02952 .00394 L
.03 .00394 L
.03047 .00394 L
.03097 .00394 L
.03144 .00394 L
.0319 .00394 L
.03239 .00394 L
.03286 .00394 L
.03336 .00394 L
.03384 .00394 L
.0343 .00394 L
.03479 .00394 L
.03527 .00394 L
.03572 .00394 L
.03621 .00394 L
.03668 .00394 L
.03717 .00394 L
.03765 .00394 L
.03811 .00394 L
.0386 .00394 L
.03907 .00394 L
.03953 .00394 L
.04001 .00394 L
.04047 .00394 L
.04097 .00394 L
.04144 .00394 L
.0419 .00394 L
.04239 .00394 L
.04286 .00394 L
.04335 .00394 L
.04383 .00394 L
.0443 .00394 L
.04479 .00394 L
.04526 .00394 L
.04572 .00394 L
.0462 .00394 L
.04667 .00394 L
.04716 .00394 L
Mistroke
.04764 .00394 L
.0481 .00394 L
.04859 .00394 L
.04906 .00394 L
.04956 .00394 L
.05004 .00394 L
.0505 .00394 L
.05099 .00394 L
.05147 .00394 L
.05193 .00394 L
.05241 .00394 L
.05288 .00394 L
.05338 .00394 L
.05386 .00394 L
.05432 .00394 L
.05481 .00394 L
.05528 .00394 L
.05573 .00394 L
.05622 .00394 L
.05668 .00394 L
.05718 .00394 L
.05765 .00394 L
.05811 .00394 L
.0586 .00394 L
.05907 .00394 L
.05957 .00394 L
.06005 .00394 L
.06051 .00394 L
.061 .00394 L
.06147 .00394 L
.06193 .00394 L
.06242 .00394 L
.06288 .00394 L
.06338 .00394 L
.06386 .00394 L
.06432 .00394 L
.06481 .00394 L
.06528 .00394 L
.06573 .00394 L
.06621 .00394 L
.06668 .00394 L
.06717 .00394 L
.06764 .00394 L
.0681 .00394 L
.06859 .00394 L
.06906 .00394 L
.06955 .00394 L
.07003 .00394 L
.0705 .00394 L
.07099 .00394 L
Mistroke
.07146 .00394 L
.07191 .00394 L
.0724 .00394 L
.07286 .00394 L
.07336 .00394 L
.07384 .00394 L
.07429 .00394 L
.07478 .00394 L
.07525 .00394 L
.07575 .00394 L
.07623 .00394 L
.0767 .00394 L
.07719 .00394 L
.07766 .00394 L
.07812 .00394 L
.0786 .00394 L
.07907 .00394 L
.07957 .00394 L
.08005 .00394 L
.08051 .00394 L
.081 .00394 L
.08147 .00394 L
.08192 .00394 L
.08241 .00394 L
.08287 .00394 L
.08336 .00394 L
.08384 .00394 L
.0843 .00394 L
.08479 .00394 L
.08525 .00394 L
.08575 .00394 L
.08623 .00394 L
.0867 .00394 L
.08719 .00394 L
.08766 .00394 L
.08812 .00394 L
.0886 .00394 L
.08907 .00394 L
.08956 .00394 L
.09004 .00394 L
.0905 .00394 L
.09099 .00394 L
.09146 .00394 L
.09196 .00394 L
.09244 .00394 L
.0929 .00394 L
.0934 .00394 L
.09387 .00394 L
.09433 .00394 L
.09482 .00394 L
Mistroke
.09528 .00394 L
.09578 .00394 L
.09626 .00394 L
.09672 .00394 L
.09721 .00394 L
.09768 .00394 L
.09814 .00394 L
.09862 .00394 L
.09909 .00394 L
.09958 .00394 L
.10006 .00394 L
.10052 .00394 L
.101 .00394 L
.10147 .00394 L
.10197 .00394 L
.10245 .00394 L
.10292 .00394 L
.10341 .00394 L
.10388 .00394 L
.10434 .00394 L
.10482 .00394 L
.10529 .00394 L
.10579 .00394 L
.10627 .00394 L
.10673 .00394 L
.10722 .00394 L
.10769 .00394 L
.10814 .00394 L
.10862 .00394 L
.10909 .00394 L
.10958 .00394 L
.11006 .00394 L
.11051 .00394 L
.111 .00394 L
.11147 .00394 L
.11197 .00394 L
.11245 .00394 L
.11291 .00394 L
.1134 .00394 L
.11387 .00394 L
.11433 .00394 L
.11481 .00394 L
.11528 .00394 L
.11577 .00394 L
.11625 .00394 L
.11671 .00394 L
.1172 .00394 L
.11767 .00394 L
.11817 .00394 L
.11865 .00394 L
Mistroke
.11911 .00394 L
.1196 .00394 L
.12008 .00394 L
.12054 .00394 L
.12102 .00394 L
.12149 .00394 L
.12199 .00394 L
.12247 .00394 L
.12293 .00394 L
.12342 .00394 L
.12389 .00394 L
.12434 .00394 L
.12482 .00394 L
.12529 .00394 L
.12578 .00394 L
.12626 .00394 L
.12672 .00394 L
.12721 .00394 L
.12768 .00394 L
.12817 .00394 L
.12865 .00394 L
.12912 .00394 L
.12961 .00394 L
.13008 .00394 L
.13054 .00394 L
.13102 .00394 L
.13149 .00394 L
.13198 .00394 L
.13246 .00394 L
.13292 .00394 L
.13341 .00394 L
.13388 .00394 L
.13433 .00394 L
.13482 .00394 L
.13528 .00394 L
.13577 .00394 L
.13625 .00394 L
.13671 .00394 L
.13719 .00394 L
.13766 .00394 L
.13816 .00394 L
.13864 .00394 L
.1391 .00394 L
.13959 .00394 L
.14006 .00394 L
.14052 .00394 L
.141 .00394 L
.14147 .00394 L
.14196 .00394 L
.14244 .00394 L
Mistroke
.1429 .00394 L
.14339 .00394 L
.14386 .00394 L
.14435 .00394 L
.14484 .00394 L
.1453 .00394 L
.14579 .00394 L
.14627 .00394 L
.14672 .00394 L
.14721 .00394 L
.14767 .00394 L
.14817 .00394 L
.14865 .00394 L
.14911 .00394 L
.1496 .00394 L
.15007 .00394 L
.15052 .00394 L
.15101 .00394 L
.15147 .00394 L
.15197 .00394 L
.15244 .00394 L
.1529 .00394 L
.15339 .00394 L
.15385 .00394 L
.15435 .00394 L
.15483 .00394 L
.15529 .00394 L
.15579 .00394 L
.15626 .00394 L
.15671 .00394 L
.1572 .00394 L
.15766 .00394 L
.15816 .00394 L
.15864 .00394 L
.1591 .00394 L
.15959 .00394 L
.16006 .00394 L
.16056 .00394 L
.16104 .00394 L
.1615 .00394 L
.16199 .00394 L
.16247 .00394 L
.16293 .00394 L
.16341 .00394 L
.16388 .00394 L
.16438 .00394 L
.16486 .00394 L
.16532 .00394 L
.16581 .00394 L
.16628 .00394 L
Mistroke
.16673 .00394 L
.16722 .00394 L
.16768 .00394 L
.16818 .00394 L
.16865 .00394 L
.16911 .00394 L
.1696 .00394 L
.17007 .00394 L
.17057 .00394 L
.17105 .00394 L
.17151 .00394 L
.172 .00394 L
.17248 .00394 L
.17293 .00394 L
.17342 .00394 L
.17388 .00394 L
.17438 .00394 L
.17486 .00394 L
.17532 .00394 L
.17581 .00394 L
.17628 .00394 L
.17673 .00394 L
.17721 .00394 L
.17768 .00394 L
.17817 .00394 L
.17865 .00394 L
.1791 .00394 L
.17959 .00394 L
.18006 .00394 L
.18056 .00394 L
.18104 .00394 L
.1815 .00394 L
.18199 .00394 L
.18246 .00394 L
.18292 .00394 L
.1834 .00394 L
.18387 .00394 L
.18436 .00394 L
.18484 .00394 L
.1853 .00394 L
.18579 .00394 L
.18626 .00394 L
.18676 .00394 L
.18724 .00394 L
.1877 .00394 L
.18819 .00394 L
.18867 .00394 L
.18912 .00394 L
.18961 .00394 L
.19008 .00394 L
Mistroke
.19057 .00394 L
.19105 .00394 L
.19151 .00394 L
.192 .00394 L
.19248 .00394 L
.19293 .00394 L
.19341 .00394 L
.19388 .00394 L
.19437 .00394 L
.19485 .00394 L
.19531 .00394 L
.19579 .00394 L
.19626 .00394 L
.19676 .00394 L
.19724 .00394 L
.1977 .00394 L
.19819 .00394 L
.19867 .00394 L
.19912 .00394 L
.19961 .00394 L
.20007 .00394 L
.20057 .00394 L
.20105 .00394 L
.20151 .00394 L
.202 .00394 L
.20247 .00394 L
.20297 .00394 L
.20345 .00394 L
.20391 .00394 L
.20441 .00394 L
.20488 .00394 L
.20534 .00394 L
.20582 .00394 L
.20629 .00394 L
.20679 .00394 L
.20727 .00394 L
.20773 .00394 L
.20822 .00394 L
.20869 .00394 L
.20915 .00394 L
.20963 .00394 L
.2101 .00394 L
.21059 .00394 L
.21107 .00394 L
.21153 .00394 L
.21201 .00394 L
.21248 .00394 L
.21298 .00394 L
.21346 .00394 L
.21393 .00394 L
Mistroke
.21442 .00394 L
.21489 .00394 L
.21535 .00394 L
.21583 .00394 L
.2163 .00394 L
.2168 .00394 L
.21728 .00394 L
.21774 .00394 L
.21823 .00394 L
.2187 .00394 L
.21915 .00394 L
.21963 .00394 L
.2201 .00394 L
.22059 .00394 L
.22107 .00394 L
.22152 .00394 L
.22201 .00394 L
.22248 .00394 L
.22298 .00394 L
.22346 .00394 L
.22392 .00394 L
.22441 .00394 L
.22488 .00394 L
.22534 .00394 L
.22582 .00394 L
.22629 .00394 L
.22679 .00394 L
.22726 .00394 L
.22772 .00394 L
.22821 .00394 L
.22868 .00394 L
.22918 .00394 L
.22966 .00394 L
.23013 .00394 L
.23062 .00394 L
.23109 .00394 L
.23155 .00394 L
.23204 .00394 L
.2325 .00394 L
.233 .00394 L
.23348 .00394 L
.23394 .00394 L
.23443 .00394 L
.2349 .00394 L
.23536 .00394 L
.23584 .00394 L
.2363 .00394 L
.2368 .00394 L
.23727 .00394 L
.23773 .00394 L
Mistroke
.23822 .00394 L
.23869 .00394 L
.23919 .00394 L
.23967 .00394 L
.24013 .00394 L
.24062 .00394 L
.2411 .00394 L
.24155 .00394 L
.24204 .00394 L
.2425 .00394 L
.243 .00394 L
.24348 .00394 L
.24394 .00394 L
.24443 .00394 L
.2449 .00394 L
.24535 .00394 L
.24583 .00394 L
.2463 .00394 L
.24679 .00394 L
.24727 .00394 L
.24772 .00394 L
.24821 .00394 L
.24868 .00394 L
.24918 .00394 L
.24966 .00394 L
.25012 .00394 L
.25061 .00394 L
.25108 .00394 L
.25153 .00394 L
.25202 .00394 L
.25248 .00394 L
.25298 .00394 L
.25346 .00394 L
.25391 .00394 L
.2544 .00394 L
.25487 .00394 L
.25537 .00394 L
.25585 .00394 L
.25632 .00394 L
.25681 .00394 L
.25728 .00394 L
.25774 .00394 L
.25822 .00394 L
.25869 .00394 L
.25919 .00394 L
.25967 .00394 L
.26013 .00394 L
.26062 .00394 L
.26109 .00394 L
.26154 .00394 L
Mistroke
.26203 .00394 L
.26249 .00394 L
.26298 .00394 L
.26346 .00394 L
.26392 .00394 L
.26441 .00394 L
.26487 .00394 L
.26537 .00394 L
.26585 .00394 L
.26631 .00394 L
.26681 .00394 L
.26728 .00394 L
.26773 .00394 L
.26822 .00394 L
.26869 .00394 L
.26918 .00394 L
.26966 .00394 L
.27012 .00394 L
.27061 .00394 L
.27108 .00394 L
.27158 .00394 L
.27206 .00394 L
.27252 .00394 L
.27302 .00394 L
.27349 .00394 L
.27395 .00394 L
.27443 .00394 L
.2749 .00394 L
.2754 .00394 L
.27588 .00394 L
.27634 .00394 L
.27683 .00394 L
.2773 .00394 L
.27776 .00394 L
.27824 .00394 L
.2787 .00394 L
.2792 .00394 L
.27968 .00394 L
.28013 .00394 L
.28062 .00394 L
.28109 .00394 L
.28159 .00394 L
.28207 .00394 L
.28253 .00394 L
.28303 .00394 L
.2835 .00394 L
.28396 .00394 L
.28444 .00394 L
.28491 .00394 L
.2854 .00394 L
Mistroke
.28588 .00394 L
.28634 .00394 L
.28683 .00394 L
.2873 .00394 L
.28776 .00394 L
.28824 .00394 L
.2887 .00394 L
.2892 .00394 L
.28967 .00394 L
.29013 .00394 L
.29062 .00394 L
.29108 .00394 L
.29158 .00394 L
.29206 .00394 L
.29252 .00394 L
.29302 .00394 L
.29349 .00394 L
.29394 .00394 L
.29443 .00394 L
.29489 .00394 L
.29539 .00394 L
.29587 .00394 L
.29632 .00394 L
.29681 .00394 L
.29728 .00394 L
.29778 .00394 L
.29826 .00394 L
.29873 .00394 L
.29922 .00394 L
.29969 .00394 L
.30015 .00394 L
.30064 .00394 L
.3011 .00394 L
.3016 .00394 L
.30208 .00394 L
.30254 .00394 L
.30303 .00394 L
.3035 .00394 L
.30396 .00394 L
.30444 .00394 L
.3049 .00394 L
.3054 .00394 L
.30587 .00394 L
.30633 .00394 L
.30682 .00394 L
.30729 .00394 L
.30779 .00394 L
.30827 .00394 L
.30873 .00394 L
.30922 .00394 L
Mistroke
.3097 .00394 L
.31015 .00394 L
.31064 .00394 L
.3111 .00394 L
.3116 .00394 L
.31208 .00394 L
.31254 .00394 L
.31302 .00394 L
.3135 .00394 L
.31395 .00394 L
.31443 .00394 L
.31489 .00394 L
.31539 .00394 L
.31586 .00394 L
.31632 .00394 L
.31681 .00394 L
.31727 .00394 L
.31777 .00394 L
.31825 .00394 L
.31871 .00394 L
.3192 .00394 L
.31968 .00394 L
.32013 .00394 L
.32061 .00394 L
.32108 .00394 L
.32157 .00394 L
.32205 .00394 L
.32251 .00394 L
.323 .00394 L
.32347 .00394 L
.32397 .00394 L
.32445 .00394 L
.32491 .00394 L
.3254 .00394 L
.32588 .00394 L
.32633 .00394 L
.32682 .00394 L
.32729 .00394 L
.32778 .00394 L
.32826 .00394 L
.32872 .00394 L
.32921 .00394 L
.32968 .00394 L
.33014 .00394 L
.33062 .00394 L
.33108 .00394 L
.33158 .00394 L
.33205 .00394 L
.33251 .00394 L
.333 .00394 L
Mistroke
.33347 .00394 L
.33396 .00394 L
.33444 .00394 L
.33491 .00394 L
.3354 .00394 L
.33587 .00394 L
.33633 .00394 L
.33681 .00394 L
.33728 .00394 L
.33777 .00394 L
.33825 .00394 L
.33871 .00394 L
.3392 .00394 L
.33967 .00394 L
.34017 .00394 L
.34065 .00394 L
.34111 .00394 L
.34161 .00394 L
.34208 .00394 L
.34254 .00394 L
.34302 .00394 L
.34349 .00394 L
.34399 .00394 L
.34447 .00394 L
.34493 .00394 L
.34542 .00394 L
.34589 .00394 L
.34634 .00394 L
.34683 .00394 L
.34729 .00394 L
.34779 .00394 L
.34826 .00394 L
.34872 .00394 L
.34921 .00394 L
.34968 .00394 L
.35018 .00394 L
.35066 .00394 L
.35112 .00394 L
.35161 .00394 L
.35209 .00394 L
.35254 .00394 L
.35303 .00394 L
.35349 .00394 L
.35399 .00394 L
.35447 .00394 L
.35493 .00394 L
.35542 .00394 L
.35589 .00394 L
.35634 .00394 L
.35682 .00394 L
Mistroke
.35729 .00394 L
.35778 .00394 L
.35826 .00394 L
.35871 .00394 L
.3592 .00394 L
.35967 .00394 L
.36017 .00394 L
.36065 .00394 L
.36111 .00394 L
.3616 .00394 L
.36207 .00394 L
.36253 .00394 L
.36301 .00394 L
.36348 .00394 L
.36397 .00394 L
.36445 .00394 L
.36491 .00394 L
.36539 .00394 L
.36586 .00394 L
.36636 .00394 L
.36685 .00394 L
.36731 .00394 L
.3678 .00394 L
.36828 .00394 L
.36873 .00394 L
.36922 .00394 L
.36968 .00394 L
.37018 .00394 L
.37066 .00394 L
.37112 .00394 L
.37161 .00394 L
.37208 .00394 L
.37254 .00394 L
.37302 .00394 L
.37348 .00394 L
.37398 .00394 L
.37445 .00394 L
.37491 .00394 L
.3754 .00394 L
.37587 .00394 L
.37637 .00394 L
.37685 .00394 L
.37731 .00394 L
.3778 .00394 L
.37827 .00394 L
.37873 .00394 L
.37921 .00394 L
.37968 .00394 L
.38018 .00394 L
.38065 .00394 L
Mistroke
.38111 .00394 L
.3816 .00394 L
.38207 .00394 L
.38257 .00394 L
.38305 .00394 L
.38352 .00394 L
.38401 .00394 L
.38449 .00394 L
.38494 .00394 L
.38543 .00394 L
.3859 .00394 L
.38639 .00394 L
.38687 .00394 L
.38734 .00394 L
.38783 .00394 L
.3883 .00394 L
.38875 .00394 L
.38924 .00394 L
.3897 .00394 L
.3902 .00394 L
.39067 .00394 L
.39113 .00394 L
.39162 .00394 L
.39209 .00394 L
.39259 .00394 L
.39307 .00394 L
.39353 .00394 L
.39402 .00394 L
.3945 .00394 L
.39495 .00394 L
.39544 .00394 L
.39591 .00394 L
.3964 .00394 L
.39688 .00394 L
.39734 .00394 L
.39783 .00394 L
.3983 .00394 L
.39875 .00394 L
.39924 .00394 L
.3997 .00394 L
.40019 .00394 L
.40067 .00394 L
.40113 .00394 L
.40161 .00394 L
.40208 .00394 L
.40258 .00394 L
.40306 .00394 L
.40352 .00394 L
.40401 .00394 L
.40449 .00394 L
Mistroke
.40494 .00394 L
.40543 .00394 L
.40589 .00394 L
.40639 .00394 L
.40686 .00394 L
.40732 .00394 L
.40781 .00394 L
.40828 .00394 L
.40878 .00394 L
.40926 .00394 L
.40973 .00394 L
.41022 .00394 L
.41069 .00394 L
.41115 .00394 L
.41164 .00394 L
.4121 .00394 L
.4126 .00394 L
.41308 .00394 L
.41354 .00394 L
.41403 .00394 L
.4145 .00394 L
.41496 .00394 L
.41544 .00394 L
.41591 .00394 L
.4164 .00394 L
.41688 .00394 L
.41733 .00394 L
.41782 .00394 L
.41829 .00394 L
.41879 .00394 L
.41927 .00394 L
.41973 .00394 L
.42022 .00394 L
.4207 .00394 L
.42115 .00394 L
.42164 .00394 L
.4221 .00394 L
.4226 .00394 L
.42308 .00394 L
.42354 .00394 L
.42403 .00394 L
.4245 .00394 L
.42495 .00394 L
.42543 .00394 L
.4259 .00394 L
.42639 .00394 L
.42687 .00394 L
.42732 .00394 L
.42781 .00394 L
.42828 .00394 L
Mistroke
.42878 .00394 L
.42926 .00394 L
.42972 .00394 L
.43021 .00394 L
.43068 .00394 L
.43113 .00394 L
.43162 .00394 L
.43208 .00394 L
.43258 .00394 L
.43306 .00394 L
.43351 .00394 L
.434 .00394 L
.43447 .00394 L
.43497 .00394 L
.43545 .00394 L
.43592 .00394 L
.43641 .00394 L
.43688 .00394 L
.43734 .00394 L
.43782 .00394 L
.43829 .00394 L
.43879 .00394 L
.43927 .00394 L
.43973 .00394 L
.44022 .00394 L
.44069 .00394 L
.44114 .00394 L
.44162 .00394 L
.44209 .00394 L
.44258 .00394 L
.44306 .00394 L
.44352 .00394 L
.444 .00394 L
.44447 .00394 L
.44497 .00394 L
.44545 .00394 L
.44591 .00394 L
.4464 .00394 L
.44688 .00394 L
.44733 .00394 L
.44782 .00394 L
.44828 .00394 L
.44878 .00394 L
.44926 .00394 L
.44972 .00394 L
.4502 .00394 L
.45067 .00394 L
.45117 .00394 L
.45143 .00394 L
.45166 .00394 L
Mistroke
.45177 .00394 L
.45183 .00394 L
.45186 .00394 L
.45188 .00394 L
.4519 .00394 L
.45191 .39759 L
.45192 .39759 L
.45194 .39759 L
.452 .39759 L
.45212 .39759 L
.45257 .39759 L
.45269 .39759 L
.45275 .39759 L
.45281 .39759 L
.45284 .39759 L
.45285 .39759 L
.45285 .39759 L
.45287 .00394 L
.45288 .00394 L
.45289 .00394 L
.4529 .00394 L
.45294 .00394 L
.45306 .00394 L
.45351 .00394 L
.454 .00394 L
.45447 .00394 L
.45496 .00394 L
.45544 .00394 L
.4559 .00394 L
.45639 .00394 L
.45686 .00394 L
.45731 .00394 L
.4578 .00394 L
.45826 .00394 L
.45875 .00394 L
.45923 .00394 L
.45969 .00394 L
.46017 .00394 L
.46064 .00394 L
.46114 .00394 L
.46162 .00394 L
.46208 .00394 L
.46257 .00394 L
.46304 .00394 L
.4635 .00394 L
.46398 .00394 L
.46445 .00394 L
.46494 .00394 L
.46542 .00394 L
.46588 .00394 L
Mistroke
.46637 .00394 L
.46684 .00394 L
.46734 .00394 L
.46782 .00394 L
.46828 .00394 L
.46878 .00394 L
.46925 .00394 L
.46971 .00394 L
.47019 .00394 L
.47066 .00394 L
.47116 .00394 L
.47164 .00394 L
.4721 .00394 L
.47259 .00394 L
.47306 .00394 L
.47351 .00394 L
.47399 .00394 L
.47446 .00394 L
.47495 .00394 L
.4752 .00394 L
.47543 .00394 L
.47554 .00394 L
.47565 .00394 L
.47568 .00394 L
.4757 .00394 L
.47571 .00394 L
.47572 .20076 L
.47573 .20076 L
.47574 .20076 L
.47577 .20076 L
.47589 .20076 L
.47612 .20076 L
.47638 .20076 L
.4765 .20076 L
.47657 .20076 L
.4766 .20076 L
.47663 .20076 L
.47665 .20076 L
.47666 .20076 L
.47667 .00394 L
.47669 .00394 L
.47675 .00394 L
.47686 .00394 L
.47733 .00394 L
.47783 .00394 L
.47831 .00394 L
.47877 .00394 L
.47926 .00394 L
.47973 .00394 L
.48018 .00394 L
Mistroke
.48067 .00394 L
.48113 .00394 L
.48163 .00394 L
.48211 .00394 L
.48256 .00394 L
.48305 .00394 L
.48352 .00394 L
.48402 .00394 L
.4845 .00394 L
.48496 .00394 L
.48546 .00394 L
.48593 .00394 L
.48639 .00394 L
.48687 .00394 L
.48734 .00394 L
.48784 .00394 L
.48831 .00394 L
.48877 .00394 L
.48926 .00394 L
.48974 .00394 L
.49019 .00394 L
.49067 .00394 L
.49114 .00394 L
.49163 .00394 L
.49211 .00394 L
.49256 .00394 L
.49305 .00394 L
.49352 .00394 L
.49402 .00394 L
.4945 .00394 L
.49496 .00394 L
.49545 .00394 L
.49592 .00394 L
.49638 .00394 L
.49686 .00394 L
.49733 .00394 L
.49782 .00394 L
.4983 .00394 L
.49876 .00394 L
.49902 .00394 L
.49925 .00394 L
.49937 .00394 L
.49943 .00394 L
.49946 .00394 L
.49949 .00394 L
.49951 .00394 L
.49952 .00394 L
.49953 .20076 L
.49955 .20076 L
.49961 .20076 L
Mistroke
.49972 .20076 L
.50018 .20076 L
.5003 .20076 L
.50042 .20076 L
.50045 .20076 L
.50046 .20076 L
.50048 .20076 L
.50049 .00394 L
.5005 .00394 L
.50051 .00394 L
.50054 .00394 L
.50067 .00394 L
.50117 .00394 L
.50165 .00394 L
.50211 .00394 L
.5026 .00394 L
.50308 .00394 L
.50353 .00394 L
.50402 .00394 L
.50448 .00394 L
.50498 .00394 L
.50546 .00394 L
.50592 .00394 L
.50641 .00394 L
.50688 .00394 L
.50733 .00394 L
.50781 .00394 L
.50828 .00394 L
.50877 .00394 L
.50925 .00394 L
.5097 .00394 L
.51019 .00394 L
.51066 .00394 L
.51116 .00394 L
.51164 .00394 L
.5121 .00394 L
.51259 .00394 L
.51306 .00394 L
.51352 .00394 L
.514 .00394 L
.51447 .00394 L
.51496 .00394 L
.51544 .00394 L
.5159 .00394 L
.51638 .00394 L
.51685 .00394 L
.51735 .00394 L
.51784 .00394 L
.5183 .00394 L
.51879 .00394 L
Mistroke
.51927 .00394 L
.51972 .00394 L
.52021 .00394 L
.52067 .00394 L
.52117 .00394 L
.52165 .00394 L
.52211 .00394 L
.5226 .00394 L
.52284 .00394 L
.52307 .00394 L
.52318 .00394 L
.52324 .00394 L
.52329 .00394 L
.5233 .00394 L
.52332 .00394 L
.52333 .20076 L
.52335 .20076 L
.52341 .20076 L
.52352 .20076 L
.52399 .20076 L
.52411 .20076 L
.52423 .20076 L
.52426 .20076 L
.52427 .20076 L
.52428 .20076 L
.5243 .00394 L
.52431 .00394 L
.52432 .00394 L
.52435 .00394 L
.52448 .00394 L
.52498 .00394 L
.52546 .00394 L
.52592 .00394 L
.52642 .00394 L
.52689 .00394 L
.52735 .00394 L
.52784 .00394 L
.5283 .00394 L
.5288 .00394 L
.52928 .00394 L
.52974 .00394 L
.53023 .00394 L
.5307 .00394 L
.53116 .00394 L
.53164 .00394 L
.53211 .00394 L
.5326 .00394 L
.53308 .00394 L
.53354 .00394 L
.53402 .00394 L
Mistroke
.53449 .00394 L
.53499 .00394 L
.53547 .00394 L
.53594 .00394 L
.53643 .00394 L
.5369 .00394 L
.53736 .00394 L
.53784 .00394 L
.53831 .00394 L
.53881 .00394 L
.53928 .00394 L
.53974 .00394 L
.54023 .00394 L
.54071 .00394 L
.54116 .00394 L
.54164 .00394 L
.54211 .00394 L
.5426 .00394 L
.54307 .00394 L
.54353 .00394 L
.54402 .00394 L
.54449 .00394 L
.54499 .00394 L
.54547 .00394 L
.54593 .00394 L
.54642 .00394 L
.54666 .00394 L
.54689 .00394 L
.547 .00394 L
.54706 .00394 L
.54711 .00394 L
.54712 .00394 L
.54714 .00394 L
.54715 .39759 L
.54715 .39759 L
.54717 .39759 L
.54723 .39759 L
.54735 .39759 L
.54758 .39759 L
.54784 .39759 L
.54796 .39759 L
.54802 .39759 L
.54805 .39759 L
.54807 .39759 L
.54808 .39759 L
.5481 .00394 L
.54811 .00394 L
.54814 .00394 L
.5482 .00394 L
.54831 .00394 L
Mistroke
.54878 .00394 L
.54927 .00394 L
.54975 .00394 L
.55021 .00394 L
.55069 .00394 L
.55116 .00394 L
.55166 .00394 L
.55214 .00394 L
.5526 .00394 L
.5531 .00394 L
.55357 .00394 L
.55403 .00394 L
.55451 .00394 L
.55498 .00394 L
.55547 .00394 L
.55595 .00394 L
.55641 .00394 L
.5569 .00394 L
.55737 .00394 L
.55782 .00394 L
.5583 .00394 L
.55877 .00394 L
.55926 .00394 L
.55974 .00394 L
.56019 .00394 L
.56068 .00394 L
.56115 .00394 L
.56165 .00394 L
.56213 .00394 L
.56259 .00394 L
.56308 .00394 L
.56355 .00394 L
.564 .00394 L
.56449 .00394 L
.56495 .00394 L
.56545 .00394 L
.56593 .00394 L
.56638 .00394 L
.56687 .00394 L
.56734 .00394 L
.56784 .00394 L
.56832 .00394 L
.56879 .00394 L
.56928 .00394 L
.56975 .00394 L
.57021 .00394 L
.57069 .00394 L
.57116 .00394 L
.57166 .00394 L
.57214 .00394 L
Mistroke
.5726 .00394 L
.57309 .00394 L
.57356 .00394 L
.57401 .00394 L
.57449 .00394 L
.57496 .00394 L
.57545 .00394 L
.57593 .00394 L
.57639 .00394 L
.57687 .00394 L
.57734 .00394 L
.57784 .00394 L
.57832 .00394 L
.57878 .00394 L
.57927 .00394 L
.57975 .00394 L
.5802 .00394 L
.58069 .00394 L
.58115 .00394 L
.58165 .00394 L
.58212 .00394 L
.58258 .00394 L
.58307 .00394 L
.58354 .00394 L
.58404 .00394 L
.58452 .00394 L
.58499 .00394 L
.58548 .00394 L
.58596 .00394 L
.58641 .00394 L
.5869 .00394 L
.58737 .00394 L
.58786 .00394 L
.58834 .00394 L
.5888 .00394 L
.58929 .00394 L
.58977 .00394 L
.59022 .00394 L
.5907 .00394 L
.59117 .00394 L
.59166 .00394 L
.59214 .00394 L
.5926 .00394 L
.59309 .00394 L
.59356 .00394 L
.59405 .00394 L
.59453 .00394 L
.595 .00394 L
.59549 .00394 L
.59596 .00394 L
Mistroke
.59642 .00394 L
.5969 .00394 L
.59737 .00394 L
.59787 .00394 L
.59834 .00394 L
.5988 .00394 L
.59929 .00394 L
.59976 .00394 L
.60022 .00394 L
.6007 .00394 L
.60116 .00394 L
.60166 .00394 L
.60213 .00394 L
.60259 .00394 L
.60308 .00394 L
.60355 .00394 L
.60404 .00394 L
.60452 .00394 L
.60498 .00394 L
.60548 .00394 L
.60595 .00394 L
.6064 .00394 L
.60689 .00394 L
.60735 .00394 L
.60785 .00394 L
.60833 .00394 L
.60878 .00394 L
.60927 .00394 L
.60974 .00394 L
.61024 .00394 L
.61072 .00394 L
.61119 .00394 L
.61168 .00394 L
.61215 .00394 L
.61261 .00394 L
.6131 .00394 L
.61356 .00394 L
.61406 .00394 L
.61454 .00394 L
.615 .00394 L
.61549 .00394 L
.61596 .00394 L
.61641 .00394 L
.6169 .00394 L
.61736 .00394 L
.61786 .00394 L
.61833 .00394 L
.61879 .00394 L
.61928 .00394 L
.61975 .00394 L
Mistroke
.62024 .00394 L
.62073 .00394 L
.62119 .00394 L
.62168 .00394 L
.62215 .00394 L
.62261 .00394 L
.62309 .00394 L
.62356 .00394 L
.62405 .00394 L
.62453 .00394 L
.62499 .00394 L
.62548 .00394 L
.62595 .00394 L
.62645 .00394 L
.62693 .00394 L
.6274 .00394 L
.62789 .00394 L
.62837 .00394 L
.62882 .00394 L
.62931 .00394 L
.62978 .00394 L
.63027 .00394 L
.63075 .00394 L
.63121 .00394 L
.63171 .00394 L
.63218 .00394 L
.63263 .00394 L
.63312 .00394 L
.63358 .00394 L
.63408 .00394 L
.63455 .00394 L
.63501 .00394 L
.6355 .00394 L
.63597 .00394 L
.63647 .00394 L
.63695 .00394 L
.63741 .00394 L
.6379 .00394 L
.63838 .00394 L
.63883 .00394 L
.63932 .00394 L
.63979 .00394 L
.64028 .00394 L
.64076 .00394 L
.64122 .00394 L
.64171 .00394 L
.64218 .00394 L
.64263 .00394 L
.64312 .00394 L
.64358 .00394 L
Mistroke
.64408 .00394 L
.64455 .00394 L
.64501 .00394 L
.6455 .00394 L
.64596 .00394 L
.64646 .00394 L
.64694 .00394 L
.6474 .00394 L
.6479 .00394 L
.64837 .00394 L
.64882 .00394 L
.64931 .00394 L
.64977 .00394 L
.65027 .00394 L
.65075 .00394 L
.65121 .00394 L
.65169 .00394 L
.65216 .00394 L
.65266 .00394 L
.65315 .00394 L
.65361 .00394 L
.6541 .00394 L
.65458 .00394 L
.65503 .00394 L
.65552 .00394 L
.65599 .00394 L
.65648 .00394 L
.65696 .00394 L
.65742 .00394 L
.65791 .00394 L
.65839 .00394 L
.65884 .00394 L
.65932 .00394 L
.65979 .00394 L
.66028 .00394 L
.66076 .00394 L
.66122 .00394 L
.6617 .00394 L
.66217 .00394 L
.66267 .00394 L
.66315 .00394 L
.66361 .00394 L
.66411 .00394 L
.66458 .00394 L
.66504 .00394 L
.66552 .00394 L
.66599 .00394 L
.66648 .00394 L
.66696 .00394 L
.66742 .00394 L
Mistroke
.66791 .00394 L
.66838 .00394 L
.66883 .00394 L
.66932 .00394 L
.66978 .00394 L
.67027 .00394 L
.67075 .00394 L
.67121 .00394 L
.67169 .00394 L
.67216 .00394 L
.67266 .00394 L
.67314 .00394 L
.6736 .00394 L
.67409 .00394 L
.67456 .00394 L
.67502 .00394 L
.6755 .00394 L
.67597 .00394 L
.67646 .00394 L
.67694 .00394 L
.6774 .00394 L
.67789 .00394 L
.67836 .00394 L
.67885 .00394 L
.67934 .00394 L
.6798 .00394 L
.68029 .00394 L
.68077 .00394 L
.68122 .00394 L
.68171 .00394 L
.68217 .00394 L
.68267 .00394 L
.68315 .00394 L
.68361 .00394 L
.6841 .00394 L
.68457 .00394 L
.68502 .00394 L
.68551 .00394 L
.68597 .00394 L
.68647 .00394 L
.68694 .00394 L
.6874 .00394 L
.68789 .00394 L
.68836 .00394 L
.68885 .00394 L
.68933 .00394 L
.6898 .00394 L
.69029 .00394 L
.69076 .00394 L
.69122 .00394 L
Mistroke
.6917 .00394 L
.69217 .00394 L
.69266 .00394 L
.69314 .00394 L
.6936 .00394 L
.69409 .00394 L
.69456 .00394 L
.69506 .00394 L
.69554 .00394 L
.696 .00394 L
.6965 .00394 L
.69697 .00394 L
.69743 .00394 L
.69792 .00394 L
.69838 .00394 L
.69888 .00394 L
.69936 .00394 L
.69982 .00394 L
.70031 .00394 L
.70078 .00394 L
.70124 .00394 L
.70172 .00394 L
.70219 .00394 L
.70268 .00394 L
.70316 .00394 L
.70362 .00394 L
.7041 .00394 L
.70457 .00394 L
.70507 .00394 L
.70555 .00394 L
.70602 .00394 L
.70651 .00394 L
.70698 .00394 L
.70744 .00394 L
.70792 .00394 L
.70839 .00394 L
.70889 .00394 L
.70936 .00394 L
.70982 .00394 L
.71031 .00394 L
.71078 .00394 L
.71124 .00394 L
.71172 .00394 L
.71218 .00394 L
.71268 .00394 L
.71315 .00394 L
.71361 .00394 L
.7141 .00394 L
.71457 .00394 L
.71506 .00394 L
Mistroke
.71554 .00394 L
.716 .00394 L
.7165 .00394 L
.71697 .00394 L
.71742 .00394 L
.71791 .00394 L
.71837 .00394 L
.71887 .00394 L
.71935 .00394 L
.7198 .00394 L
.72029 .00394 L
.72076 .00394 L
.72126 .00394 L
.72174 .00394 L
.72221 .00394 L
.7227 .00394 L
.72318 .00394 L
.72363 .00394 L
.72412 .00394 L
.72458 .00394 L
.72508 .00394 L
.72556 .00394 L
.72602 .00394 L
.72651 .00394 L
.72698 .00394 L
.72744 .00394 L
.72792 .00394 L
.72838 .00394 L
.72888 .00394 L
.72935 .00394 L
.72981 .00394 L
.7303 .00394 L
.73077 .00394 L
.73127 .00394 L
.73175 .00394 L
.73221 .00394 L
.7327 .00394 L
.73318 .00394 L
.73363 .00394 L
.73412 .00394 L
.73458 .00394 L
.73508 .00394 L
.73556 .00394 L
.73602 .00394 L
.7365 .00394 L
.73698 .00394 L
.73743 .00394 L
.73791 .00394 L
.73837 .00394 L
.73887 .00394 L
Mistroke
.73934 .00394 L
.7398 .00394 L
.74029 .00394 L
.74075 .00394 L
.74125 .00394 L
.74173 .00394 L
.74219 .00394 L
.74268 .00394 L
.74316 .00394 L
.74361 .00394 L
.74409 .00394 L
.74456 .00394 L
.74505 .00394 L
.74553 .00394 L
.74599 .00394 L
.74648 .00394 L
.74695 .00394 L
.74745 .00394 L
.74793 .00394 L
.74839 .00394 L
.74888 .00394 L
.74936 .00394 L
.74981 .00394 L
.7503 .00394 L
.75076 .00394 L
.75126 .00394 L
.75174 .00394 L
.7522 .00394 L
.75269 .00394 L
.75316 .00394 L
.75361 .00394 L
.7541 .00394 L
.75456 .00394 L
.75506 .00394 L
.75553 .00394 L
.75599 .00394 L
.75648 .00394 L
.75694 .00394 L
.75744 .00394 L
.75792 .00394 L
.75838 .00394 L
.75888 .00394 L
.75935 .00394 L
.7598 .00394 L
.76029 .00394 L
.76075 .00394 L
.76125 .00394 L
.76173 .00394 L
.76219 .00394 L
.76267 .00394 L
Mistroke
.76315 .00394 L
.76365 .00394 L
.76413 .00394 L
.76459 .00394 L
.76508 .00394 L
.76556 .00394 L
.76601 .00394 L
.7665 .00394 L
.76697 .00394 L
.76747 .00394 L
.76794 .00394 L
.76841 .00394 L
.7689 .00394 L
.76937 .00394 L
.76982 .00394 L
.7703 .00394 L
.77077 .00394 L
.77126 .00394 L
.77174 .00394 L
.7722 .00394 L
.77269 .00394 L
.77316 .00394 L
.77366 .00394 L
.77414 .00394 L
.7746 .00394 L
.77509 .00394 L
.77556 .00394 L
.77602 .00394 L
.7765 .00394 L
.77697 .00394 L
.77747 .00394 L
.77795 .00394 L
.77841 .00394 L
.77889 .00394 L
.77937 .00394 L
.77982 .00394 L
.7803 .00394 L
.78076 .00394 L
.78126 .00394 L
.78173 .00394 L
.78219 .00394 L
.78268 .00394 L
.78315 .00394 L
.78364 .00394 L
.78412 .00394 L
.78458 .00394 L
.78508 .00394 L
.78555 .00394 L
.786 .00394 L
.78649 .00394 L
Mistroke
.78695 .00394 L
.78745 .00394 L
.78792 .00394 L
.78838 .00394 L
.78887 .00394 L
.78934 .00394 L
.78984 .00394 L
.79032 .00394 L
.79079 .00394 L
.79128 .00394 L
.79175 .00394 L
.79221 .00394 L
.79269 .00394 L
.79316 .00394 L
.79366 .00394 L
.79414 .00394 L
.7946 .00394 L
.79509 .00394 L
.79556 .00394 L
.79601 .00394 L
.7965 .00394 L
.79696 .00394 L
.79745 .00394 L
.79793 .00394 L
.79839 .00394 L
.79888 .00394 L
.79934 .00394 L
.79984 .00394 L
.80032 .00394 L
.80079 .00394 L
.80128 .00394 L
.80175 .00394 L
.80221 .00394 L
.80269 .00394 L
.80316 .00394 L
.80365 .00394 L
.80413 .00394 L
.80459 .00394 L
.80508 .00394 L
.80555 .00394 L
.80605 .00394 L
.80653 .00394 L
.80699 .00394 L
.80749 .00394 L
.80796 .00394 L
.80842 .00394 L
.80891 .00394 L
.80937 .00394 L
.80987 .00394 L
.81035 .00394 L
Mistroke
.81081 .00394 L
.8113 .00394 L
.81177 .00394 L
.81223 .00394 L
.81271 .00394 L
.81318 .00394 L
.81367 .00394 L
.81415 .00394 L
.81461 .00394 L
.81509 .00394 L
.81556 .00394 L
.81606 .00394 L
.81654 .00394 L
.81701 .00394 L
.8175 .00394 L
.81797 .00394 L
.81843 .00394 L
.81891 .00394 L
.81938 .00394 L
.81988 .00394 L
.82036 .00394 L
.82082 .00394 L
.82131 .00394 L
.82178 .00394 L
.82223 .00394 L
.82271 .00394 L
.82318 .00394 L
.82367 .00394 L
.82415 .00394 L
.8246 .00394 L
.82509 .00394 L
.82556 .00394 L
.82606 .00394 L
.82654 .00394 L
.827 .00394 L
.82749 .00394 L
.82796 .00394 L
.82842 .00394 L
.8289 .00394 L
.82937 .00394 L
.82986 .00394 L
.83034 .00394 L
.8308 .00394 L
.83129 .00394 L
.83176 .00394 L
.83226 .00394 L
.83274 .00394 L
.8332 .00394 L
.8337 .00394 L
.83417 .00394 L
Mistroke
.83463 .00394 L
.83511 .00394 L
.83558 .00394 L
.83608 .00394 L
.83656 .00394 L
.83702 .00394 L
.83751 .00394 L
.83798 .00394 L
.83843 .00394 L
.83892 .00394 L
.83938 .00394 L
.83987 .00394 L
.84035 .00394 L
.84081 .00394 L
.8413 .00394 L
.84177 .00394 L
.84226 .00394 L
.84275 .00394 L
.84321 .00394 L
.8437 .00394 L
.84417 .00394 L
.84463 .00394 L
.84511 .00394 L
.84558 .00394 L
.84608 .00394 L
.84655 .00394 L
.84701 .00394 L
.8475 .00394 L
.84797 .00394 L
.84843 .00394 L
.84891 .00394 L
.84937 .00394 L
.84987 .00394 L
.85034 .00394 L
.8508 .00394 L
.85128 .00394 L
.85175 .00394 L
.85225 .00394 L
.85273 .00394 L
.85319 .00394 L
.85368 .00394 L
.85415 .00394 L
.85461 .00394 L
.85509 .00394 L
.85556 .00394 L
.85605 .00394 L
.85653 .00394 L
.85699 .00394 L
.85748 .00394 L
.85795 .00394 L
Mistroke
.85845 .00394 L
.85893 .00394 L
.85939 .00394 L
.85988 .00394 L
.86036 .00394 L
.86081 .00394 L
.8613 .00394 L
.86177 .00394 L
.86226 .00394 L
.86274 .00394 L
.8632 .00394 L
.86369 .00394 L
.86416 .00394 L
.86462 .00394 L
.8651 .00394 L
.86556 .00394 L
.86606 .00394 L
.86653 .00394 L
.86699 .00394 L
.86748 .00394 L
.86795 .00394 L
.86844 .00394 L
.86892 .00394 L
.86939 .00394 L
.86988 .00394 L
.87035 .00394 L
.87081 .00394 L
.87129 .00394 L
.87176 .00394 L
.87225 .00394 L
.87273 .00394 L
.87319 .00394 L
.87368 .00394 L
.87415 .00394 L
.87465 .00394 L
.87513 .00394 L
.87559 .00394 L
.87609 .00394 L
.87656 .00394 L
.87702 .00394 L
.8775 .00394 L
.87797 .00394 L
.87847 .00394 L
.87895 .00394 L
.87941 .00394 L
.8799 .00394 L
.88037 .00394 L
.88083 .00394 L
.88131 .00394 L
.88177 .00394 L
Mistroke
.88227 .00394 L
.88275 .00394 L
.8832 .00394 L
.88369 .00394 L
.88416 .00394 L
.88466 .00394 L
.88514 .00394 L
.8856 .00394 L
.8861 .00394 L
.88657 .00394 L
.88702 .00394 L
.88751 .00394 L
.88798 .00394 L
.88847 .00394 L
.88895 .00394 L
.88941 .00394 L
.8899 .00394 L
.89037 .00394 L
.89082 .00394 L
.89131 .00394 L
.89177 .00394 L
.89226 .00394 L
.89274 .00394 L
.8932 .00394 L
.89368 .00394 L
.89415 .00394 L
.89465 .00394 L
.89513 .00394 L
.89559 .00394 L
.89608 .00394 L
.89656 .00394 L
.89701 .00394 L
.89749 .00394 L
.89796 .00394 L
.89846 .00394 L
.89893 .00394 L
.89939 .00394 L
.89988 .00394 L
.90035 .00394 L
.90085 .00394 L
.90133 .00394 L
.90179 .00394 L
.90229 .00394 L
.90276 .00394 L
.90322 .00394 L
.9037 .00394 L
.90417 .00394 L
.90467 .00394 L
.90515 .00394 L
.90561 .00394 L
Mistroke
.9061 .00394 L
.90657 .00394 L
.90702 .00394 L
.9075 .00394 L
.90797 .00394 L
.90846 .00394 L
.90894 .00394 L
.9094 .00394 L
.90989 .00394 L
.91035 .00394 L
.91085 .00394 L
.91133 .00394 L
.9118 .00394 L
.91229 .00394 L
.91276 .00394 L
.91322 .00394 L
.9137 .00394 L
.91417 .00394 L
.91466 .00394 L
.91514 .00394 L
.9156 .00394 L
.91609 .00394 L
.91656 .00394 L
.91706 .00394 L
.91754 .00394 L
.91801 .00394 L
.9185 .00394 L
.91897 .00394 L
.91943 .00394 L
.91992 .00394 L
.92039 .00394 L
.92088 .00394 L
.92136 .00394 L
.92182 .00394 L
.92231 .00394 L
.92279 .00394 L
.92324 .00394 L
.92372 .00394 L
.92419 .00394 L
.92468 .00394 L
.92516 .00394 L
.92562 .00394 L
.92611 .00394 L
.92658 .00394 L
.92708 .00394 L
.92756 .00394 L
.92802 .00394 L
.92851 .00394 L
.92899 .00394 L
.92944 .00394 L
Mistroke
.92993 .00394 L
.93039 .00394 L
.93089 .00394 L
.93137 .00394 L
.93183 .00394 L
.93232 .00394 L
.93279 .00394 L
.93324 .00394 L
.93373 .00394 L
.93419 .00394 L
.93469 .00394 L
.93516 .00394 L
.93562 .00394 L
.93611 .00394 L
.93657 .00394 L
.93707 .00394 L
.93755 .00394 L
.93801 .00394 L
.93851 .00394 L
.93898 .00394 L
.93943 .00394 L
.93992 .00394 L
.94038 .00394 L
.94088 .00394 L
.94136 .00394 L
.94182 .00394 L
.9423 .00394 L
.94277 .00394 L
.94327 .00394 L
.94376 .00394 L
.94422 .00394 L
.94471 .00394 L
.94519 .00394 L
.94564 .00394 L
.94613 .00394 L
.9466 .00394 L
.94709 .00394 L
.94757 .00394 L
.94803 .00394 L
.94852 .00394 L
.949 .00394 L
.94945 .00394 L
.94993 .00394 L
.9504 .00394 L
.95089 .00394 L
.95137 .00394 L
.95183 .00394 L
.95231 .00394 L
.95278 .00394 L
.95328 .00394 L
Mistroke
.95376 .00394 L
.95423 .00394 L
.95472 .00394 L
.95519 .00394 L
.95565 .00394 L
.95613 .00394 L
.9566 .00394 L
.95709 .00394 L
.95757 .00394 L
.95803 .00394 L
.95852 .00394 L
.95899 .00394 L
.95945 .00394 L
.95993 .00394 L
.96039 .00394 L
.96088 .00394 L
.96136 .00394 L
.96182 .00394 L
.9623 .00394 L
.96277 .00394 L
.96327 .00394 L
.96375 .00394 L
.96421 .00394 L
.9647 .00394 L
.96517 .00394 L
.96563 .00394 L
.96611 .00394 L
.96658 .00394 L
.96707 .00394 L
.96755 .00394 L
.96801 .00394 L
.9685 .00394 L
.96897 .00394 L
.96947 .00394 L
.96995 .00394 L
.97041 .00394 L
.9709 .00394 L
.97138 .00394 L
.97183 .00394 L
.97232 .00394 L
.97279 .00394 L
.97328 .00394 L
.97376 .00394 L
.97422 .00394 L
.97471 .00394 L
.97518 .00394 L
.97564 .00394 L
.97612 .00394 L
.97619 .00394 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.196383 0.0581337 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -12 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .31265 -6 -4.5 ]
[-0.0125 .31265 0 4.5 ]
[-0.0125 .42892 -6 -4.5 ]
[-0.0125 .42892 0 4.5 ]
[-0.0125 .54519 -6 -4.5 ]
[-0.0125 .54519 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(1)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(2)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(3)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(4)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(-2)] -0.0125 .08012 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(0)] -0.0125 .19638 1 0 Mshowa
0 .31265 m
.00625 .31265 L
s
[(2)] -0.0125 .31265 1 0 Mshowa
0 .42892 m
.00625 .42892 L
s
[(4)] -0.0125 .42892 1 0 Mshowa
0 .54519 m
.00625 .54519 L
s
[(6)] -0.0125 .54519 1 0 Mshowa
.125 Mabswid
0 .10918 m
.00375 .10918 L
s
0 .13825 m
.00375 .13825 L
s
0 .16732 m
.00375 .16732 L
s
0 .22545 m
.00375 .22545 L
s
0 .25452 m
.00375 .25452 L
s
0 .28358 m
.00375 .28358 L
s
0 .34172 m
.00375 .34172 L
s
0 .37078 m
.00375 .37078 L
s
0 .39985 m
.00375 .39985 L
s
0 .45798 m
.00375 .45798 L
s
0 .48705 m
.00375 .48705 L
s
0 .51612 m
.00375 .51612 L
s
0 .05105 m
.00375 .05105 L
s
0 .02198 m
.00375 .02198 L
s
0 .57425 m
.00375 .57425 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .31265 m
1 .31265 L
s
.99375 .42892 m
1 .42892 L
s
.99375 .54519 m
1 .54519 L
s
.125 Mabswid
.99625 .10918 m
1 .10918 L
s
.99625 .13825 m
1 .13825 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .22545 m
1 .22545 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .28358 m
1 .28358 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .37078 m
1 .37078 L
s
.99625 .39985 m
1 .39985 L
s
.99625 .45798 m
1 .45798 L
s
.99625 .48705 m
1 .48705 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .02198 m
1 .02198 L
s
.99625 .57425 m
1 .57425 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .19638 m
1 .19638 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.005 w
.02381 .60332 m
.02409 .60327 L
.02435 .60315 L
.02465 .60291 L
.02494 .6026 L
.02544 .60181 L
.02599 .60063 L
.02659 .59894 L
.02722 .5967 L
.02837 .59157 L
.03066 .57704 L
.03318 .55482 L
.03845 .48973 L
.04339 .4114 L
.05279 .24379 L
.05757 .16395 L
.06278 .0915 L
.0652 .06507 L
.06778 .04268 L
.06903 .0341 L
.07021 .02743 L
.07126 .02263 L
.07241 .01871 L
.07298 .01724 L
.0733 .01658 L
.0736 .01604 L
.07388 .01562 L
.07418 .01526 L
.07446 .01501 L
.07471 .01485 L
.07501 .01474 L
.0753 .01472 L
.07561 .01479 L
.07578 .01487 L
.07594 .01497 L
.07624 .01523 L
.07657 .01561 L
.07724 .01672 L
.07791 .01826 L
.07852 .02003 L
.07989 .02524 L
.08115 .03157 L
.08235 .03879 L
.0872 .07912 L
.09167 .12835 L
.10123 .24727 L
.10603 .30069 L
.11041 .33874 L
.11157 .34657 L
.11283 .35393 L
Mistroke
.11404 .35977 L
.11513 .36402 L
.11574 .36596 L
.1164 .36769 L
.1171 .3691 L
.11741 .3696 L
.11775 .37004 L
.11807 .37036 L
.11837 .37058 L
.11869 .37073 L
.11886 .37077 L
.11902 .37078 L
.11931 .37075 L
.11962 .37064 L
.11992 .37045 L
.12019 .37021 L
.12048 .36988 L
.12078 .36946 L
.12132 .36851 L
.1219 .3672 L
.12253 .36544 L
.12367 .36141 L
.12473 .35669 L
.12714 .34252 L
.12972 .32259 L
.13491 .27024 L
.1398 .21108 L
.14913 .0974 L
.15396 .05168 L
.15639 .03472 L
.15778 .02724 L
.15907 .02176 L
.16028 .01801 L
.16096 .01651 L
.16129 .01595 L
.1616 .01552 L
.16186 .01522 L
.16215 .01497 L
.16247 .0148 L
.16276 .01472 L
.16305 .01473 L
.16336 .01484 L
.16352 .01493 L
.16369 .01505 L
.16399 .01535 L
.1643 .01574 L
.16457 .01618 L
.1652 .01746 L
.16576 .01892 L
.16635 .02081 L
Mistroke
.16737 .02492 L
.16849 .03065 L
.17095 .04758 L
.1732 .06811 L
.17826 .13016 L
.18789 .29 L
.19716 .45192 L
.20233 .52571 L
.20477 .5533 L
.20702 .57375 L
.20936 .58964 L
.2106 .59562 L
.21123 .59802 L
.2119 .60009 L
.2125 .6015 L
.21304 .60243 L
.2133 .60277 L
.21358 .60304 L
.21385 .60321 L
.2141 .6033 L
.21438 .60331 L
.21465 .60324 L
.21495 .60307 L
.21527 .60277 L
.21558 .60236 L
.21591 .60181 L
.21651 .60052 L
.21713 .59872 L
.21772 .59663 L
.21882 .59168 L
.22001 .58487 L
.2213 .5758 L
.22575 .53171 L
.23057 .46515 L
.23567 .38002 L
.24486 .21607 L
.24998 .13491 L
.25465 .0757 L
.25696 .05313 L
.25818 .04321 L
.25948 .03424 L
.26073 .02719 L
.26186 .02216 L
.26241 .02019 L
.263 .0184 L
.26356 .01703 L
.26406 .01606 L
.26434 .01564 L
.26464 .01528 L
.26496 .01499 L
Mistroke
.26526 .01481 L
.26554 .01473 L
.26584 .01472 L
.2661 .01479 L
.26638 .01494 L
.26655 .01507 L
.26671 .01521 L
.26701 .01556 L
.26769 .01665 L
.26827 .01795 L
.26891 .01975 L
.27019 .0245 L
.27156 .03118 L
.27402 .04717 L
.27921 .09495 L
.2841 .15207 L
.29344 .26771 L
.29818 .31668 L
.30087 .33859 L
.30216 .34728 L
.30338 .35432 L
.30454 .35988 L
.30579 .36466 L
.30635 .36634 L
.30694 .36783 L
.30749 .36896 L
.308 .36975 L
.30828 .3701 L
.30858 .37039 L
.30888 .3706 L
.30905 .37069 L
.30921 .37074 L
.3095 .37078 L
.30976 .37076 L
.31006 .37065 L
.31035 .37048 L
.31067 .37021 L
.311 .36982 L
.3116 .36888 L
.31224 .36752 L
.31295 .36561 L
.31421 .36114 L
.31541 .35565 L
.31766 .34223 L
.32008 .32358 L
.32273 .29887 L
.33259 .18173 L
.33715 .12531 L
.34208 .07219 L
.34479 .04892 L
Mistroke
.34598 .04039 L
.34728 .03232 L
.34843 .02639 L
.34966 .02133 L
.35034 .01913 L
.35096 .01751 L
.35159 .01624 L
.35187 .01579 L
.35217 .01539 L
.35247 .01509 L
.35275 .01489 L
.35301 .01477 L
.35329 .01472 L
.35359 .01475 L
.35388 .01486 L
.35419 .01507 L
.35436 .01523 L
.35452 .01541 L
.35513 .01632 L
.35548 .01701 L
.3558 .01775 L
.35701 .02147 L
.35804 .02584 L
.35918 .03188 L
.36148 .04798 L
.36394 .07087 L
.3662 .09647 L
.37127 .16804 L
.38091 .33603 L
.39019 .49078 L
.39498 .55056 L
.3974 .57301 L
.3987 .58265 L
.40007 .59088 L
.40124 .59627 L
.40185 .59851 L
.40251 .60044 L
.40282 .60118 L
.40312 .60178 L
.40341 .60227 L
.40367 .60264 L
.40392 .60292 L
.40419 .60313 L
.40446 .60327 L
.40475 .60332 L
.40491 .60331 L
.40509 .60326 L
.40541 .60308 L
.40572 .6028 L
.40601 .60243 L
Mistroke
.40635 .60188 L
.40666 .60126 L
.40736 .59948 L
.40797 .59749 L
.40862 .59488 L
.40981 .58896 L
.41211 .57312 L
.41464 .54953 L
.41975 .48471 L
.42955 .31903 L
.43898 .15677 L
.44145 .12088 L
.44413 .08679 L
.44645 .06212 L
.44901 .04059 L
.4502 .03272 L
.45149 .02582 L
.4527 .02082 L
.45381 .01754 L
.45442 .01626 L
.45472 .01579 L
.45499 .01542 L
.45515 .01525 L
.45532 .01508 L
.45562 .01487 L
.45579 .01479 L
.45597 .01474 L
.45612 .01472 L
.45629 .01472 L
.45646 .01476 L
.45663 .01482 L
.45694 .015 L
.45711 .01515 L
.45727 .01531 L
.45764 .01577 L
.45825 .01683 L
.4589 .01835 L
.4602 .0226 L
.4614 .02787 L
.4641 .04428 L
.46648 .06342 L
.469 .08767 L
.47822 .19798 L
.48335 .26118 L
.48803 .31092 L
.49036 .33113 L
.49289 .34882 L
.49404 .3553 L
.49527 .36097 L
.49632 .36482 L
Mistroke
.49748 .36797 L
.49808 .36915 L
.4984 .36965 L
.49874 .37008 L
.49906 .37039 L
.49936 .3706 L
.49965 .37073 L
.49993 .37078 L
.5002 .37077 L
.50049 .37068 L
.50074 .37054 L
.50101 .37033 L
.5013 .37003 L
.50161 .36963 L
.50218 .36869 L
.50283 .36725 L
.50354 .36527 L
.50482 .36058 L
.50724 .34807 L
.50951 .33214 L
.51203 .31037 L
.51712 .25564 L
.52686 .13451 L
.53133 .08427 L
.53387 .06032 L
.53623 .04192 L
.53858 .02797 L
.53989 .02224 L
.54109 .01839 L
.54174 .01684 L
.54235 .01579 L
.54266 .01538 L
.54301 .01504 L
.54319 .01491 L
.54337 .01481 L
.54355 .01475 L
.54371 .01472 L
.54403 .01474 L
.54432 .01484 L
.54449 .01494 L
.54465 .01506 L
.54499 .0154 L
.54529 .0158 L
.54561 .01633 L
.5462 .01756 L
.54678 .01911 L
.54739 .02114 L
.54851 .02578 L
.54983 .03293 L
.55104 .04095 L
Mistroke
.55366 .06324 L
.55615 .09009 L
.56544 .22957 L
.57534 .40593 L
.58025 .48472 L
.58266 .51787 L
.58486 .5442 L
.58697 .56528 L
.58927 .5833 L
.59047 .59048 L
.59159 .59576 L
.59219 .59806 L
.59276 .59984 L
.59342 .60145 L
.59371 .60199 L
.59402 .60248 L
.59433 .60284 L
.5946 .60309 L
.59488 .60325 L
.59515 .60331 L
.59545 .60329 L
.59574 .60318 L
.59605 .60294 L
.59622 .60277 L
.59638 .60257 L
.597 .60155 L
.59735 .60079 L
.59767 .59996 L
.59888 .59581 L
.59992 .59094 L
.60106 .58426 L
.60335 .56664 L
.60584 .54171 L
.6081 .51423 L
.61317 .43891 L
.62285 .26805 L
.63216 .11766 L
.63697 .06173 L
.6394 .04126 L
.64077 .0322 L
.64207 .02532 L
.64324 .02058 L
.64391 .01851 L
.64453 .01699 L
.64482 .01641 L
.6451 .01593 L
.64535 .01557 L
.64561 .01526 L
.6459 .015 L
.64617 .01483 L
Mistroke
.64646 .01473 L
.64677 .01472 L
.64694 .01475 L
.64711 .01482 L
.64728 .01491 L
.64743 .01502 L
.64773 .01528 L
.64804 .01566 L
.64868 .01673 L
.64939 .01839 L
.65065 .02249 L
.65183 .02766 L
.65422 .04173 L
.65673 .06136 L
.66121 .10646 L
.67045 .22014 L
.6756 .28122 L
.68028 .32665 L
.68262 .34411 L
.68385 .35167 L
.68515 .35836 L
.68629 .36307 L
.68689 .36512 L
.68754 .36698 L
.68814 .36836 L
.68868 .36936 L
.68894 .36974 L
.68923 .37009 L
.68948 .37034 L
.68975 .37055 L
.6899 .37064 L
.69007 .37071 L
.69037 .37078 L
.69053 .37078 L
.69071 .37076 L
.69088 .37071 L
.69104 .37064 L
.69134 .37046 L
.69151 .37031 L
.69166 .37016 L
.69225 .36939 L
.69278 .36845 L
.69335 .36713 L
.69452 .36358 L
.69579 .35843 L
.69715 .35142 L
.69961 .33506 L
.70448 .29062 L
.7096 .23143 L
.71885 .11665 L
Mistroke
.7215 .08744 L
.72401 .0633 L
.72644 .04377 L
.72751 .03661 L
.72869 .02983 L
.72976 .02471 L
.7309 .02035 L
.73153 .01846 L
.73211 .01707 L
.73269 .01599 L
.73297 .01558 L
.73324 .01527 L
.73352 .01501 L
.73383 .01482 L
.73414 .01473 L
.73431 .01472 L
.73446 .01473 L
.73473 .01481 L
.73502 .01497 L
.73532 .01524 L
.7356 .01556 L
.73625 .01663 L
.73684 .01797 L
.73752 .01995 L
.73817 .02226 L
.74052 .03423 L
.74171 .04236 L
.74301 .05288 L
.74748 .1006 L
.75219 .16762 L
.75725 .25296 L
.76725 .4302 L
.77225 .50611 L
.77468 .53673 L
.77688 .56004 L
.77919 .57943 L
.78025 .58648 L
.78136 .59262 L
.78194 .59523 L
.78256 .59768 L
.78314 .59954 L
.78366 .60092 L
.78428 .60215 L
.78462 .60264 L
.78478 .60282 L
.78495 .60298 L
.78524 .60319 L
.78552 .6033 L
.78582 .60331 L
.78598 .60328 L
Mistroke
.78614 .60321 L
.78643 .60303 L
.78673 .60273 L
.78702 .60235 L
.78728 .60192 L
.78792 .60054 L
.78853 .59882 L
.78973 .59417 L
.79104 .58733 L
.79337 .57056 L
.79553 .55024 L
.80008 .4937 L
.80508 .41503 L
.81486 .24079 L
.81937 .16554 L
.82428 .09644 L
.82695 .06664 L
.82942 .04468 L
.83178 .02917 L
.8331 .02292 L
.83367 .02076 L
.83429 .01877 L
.83486 .0173 L
.83548 .01609 L
.83582 .01558 L
.83613 .01522 L
.83644 .01496 L
.83673 .0148 L
.837 .01472 L
.83729 .01473 L
.83753 .01479 L
.8378 .01494 L
.83809 .01517 L
.8384 .01552 L
.83897 .01638 L
.83961 .01775 L
.84032 .01969 L
.84161 .02443 L
.84286 .03047 L
.84402 .03728 L
.84899 .07799 L
.8535 .12742 L
.86321 .24822 L
.86766 .29799 L
.87019 .32185 L
.87255 .34042 L
.87488 .35471 L
.87619 .36083 L
.87738 .36517 L
.87799 .36692 L
Mistroke
.87864 .36842 L
.87898 .36906 L
.87935 .36964 L
.87969 .37008 L
.88 .37039 L
.8803 .3706 L
.88062 .37074 L
.88094 .37078 L
.88112 .37077 L
.88129 .37073 L
.88159 .3706 L
.88187 .37041 L
.88219 .37011 L
.88249 .36974 L
.88307 .36881 L
.88361 .36767 L
.88484 .36412 L
.88605 .35942 L
.88734 .35303 L
.88967 .33812 L
.89181 .32102 L
.90144 .21431 L
.91071 .10096 L
.91549 .05473 L
.91816 .03559 L
.91931 .02909 L
.92057 .02329 L
.92176 .01917 L
.9224 .01747 L
.92301 .01625 L
.9233 .01579 L
.92357 .01543 L
.92382 .01516 L
.92409 .01495 L
.92438 .01479 L
.92464 .01472 L
.92493 .01473 L
.92525 .01483 L
.92556 .01503 L
.92573 .01517 L
.9259 .01535 L
.9265 .01621 L
.92684 .01686 L
.9272 .01768 L
.92785 .01948 L
.92913 .02429 L
.9303 .03009 L
.93272 .04649 L
.93495 .06658 L
.94 .12776 L
Mistroke
.94956 .28566 L
.95875 .44693 L
.96387 .52113 L
.9661 .54732 L
.96854 .57063 L
.97058 .58557 L
.97147 .59075 L
.97247 .59546 L
.9734 .59888 L
.97427 .60122 L
.97475 .60214 L
.97519 .60275 L
.97543 .60299 L
.97568 .60317 L
.97594 .60328 L
.97619 .60332 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0194363 0.196383 0.0581337 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21817 -0.0125 -6 -9 ]
[.21817 -0.0125 6 0 ]
[.41254 -0.0125 -6 -9 ]
[.41254 -0.0125 6 0 ]
[.6069 -0.0125 -6 -9 ]
[.6069 -0.0125 6 0 ]
[.80126 -0.0125 -6 -9 ]
[.80126 -0.0125 6 0 ]
[.99563 -0.0125 -6 -9 ]
[.99563 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08012 -12 -4.5 ]
[-0.0125 .08012 0 4.5 ]
[-0.0125 .19638 -6 -4.5 ]
[-0.0125 .19638 0 4.5 ]
[-0.0125 .31265 -6 -4.5 ]
[-0.0125 .31265 0 4.5 ]
[-0.0125 .42892 -6 -4.5 ]
[-0.0125 .42892 0 4.5 ]
[-0.0125 .54519 -6 -4.5 ]
[-0.0125 .54519 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21817 0 m
.21817 .00625 L
s
[(10)] .21817 -0.0125 0 1 Mshowa
.41254 0 m
.41254 .00625 L
s
[(20)] .41254 -0.0125 0 1 Mshowa
.6069 0 m
.6069 .00625 L
s
[(30)] .6069 -0.0125 0 1 Mshowa
.80126 0 m
.80126 .00625 L
s
[(40)] .80126 -0.0125 0 1 Mshowa
.99563 0 m
.99563 .00625 L
s
[(50)] .99563 -0.0125 0 1 Mshowa
.125 Mabswid
.06268 0 m
.06268 .00375 L
s
.10155 0 m
.10155 .00375 L
s
.14043 0 m
.14043 .00375 L
s
.1793 0 m
.1793 .00375 L
s
.25705 0 m
.25705 .00375 L
s
.29592 0 m
.29592 .00375 L
s
.33479 0 m
.33479 .00375 L
s
.37366 0 m
.37366 .00375 L
s
.45141 0 m
.45141 .00375 L
s
.49028 0 m
.49028 .00375 L
s
.52915 0 m
.52915 .00375 L
s
.56803 0 m
.56803 .00375 L
s
.64577 0 m
.64577 .00375 L
s
.68465 0 m
.68465 .00375 L
s
.72352 0 m
.72352 .00375 L
s
.76239 0 m
.76239 .00375 L
s
.84014 0 m
.84014 .00375 L
s
.87901 0 m
.87901 .00375 L
s
.91788 0 m
.91788 .00375 L
s
.95675 0 m
.95675 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08012 m
.00625 .08012 L
s
[(-2)] -0.0125 .08012 1 0 Mshowa
0 .19638 m
.00625 .19638 L
s
[(0)] -0.0125 .19638 1 0 Mshowa
0 .31265 m
.00625 .31265 L
s
[(2)] -0.0125 .31265 1 0 Mshowa
0 .42892 m
.00625 .42892 L
s
[(4)] -0.0125 .42892 1 0 Mshowa
0 .54519 m
.00625 .54519 L
s
[(6)] -0.0125 .54519 1 0 Mshowa
.125 Mabswid
0 .10918 m
.00375 .10918 L
s
0 .13825 m
.00375 .13825 L
s
0 .16732 m
.00375 .16732 L
s
0 .22545 m
.00375 .22545 L
s
0 .25452 m
.00375 .25452 L
s
0 .28358 m
.00375 .28358 L
s
0 .34172 m
.00375 .34172 L
s
0 .37078 m
.00375 .37078 L
s
0 .39985 m
.00375 .39985 L
s
0 .45798 m
.00375 .45798 L
s
0 .48705 m
.00375 .48705 L
s
0 .51612 m
.00375 .51612 L
s
0 .05105 m
.00375 .05105 L
s
0 .02198 m
.00375 .02198 L
s
0 .57425 m
.00375 .57425 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21817 .61178 m
.21817 .61803 L
s
.41254 .61178 m
.41254 .61803 L
s
.6069 .61178 m
.6069 .61803 L
s
.80126 .61178 m
.80126 .61803 L
s
.99563 .61178 m
.99563 .61803 L
s
.125 Mabswid
.06268 .61428 m
.06268 .61803 L
s
.10155 .61428 m
.10155 .61803 L
s
.14043 .61428 m
.14043 .61803 L
s
.1793 .61428 m
.1793 .61803 L
s
.25705 .61428 m
.25705 .61803 L
s
.29592 .61428 m
.29592 .61803 L
s
.33479 .61428 m
.33479 .61803 L
s
.37366 .61428 m
.37366 .61803 L
s
.45141 .61428 m
.45141 .61803 L
s
.49028 .61428 m
.49028 .61803 L
s
.52915 .61428 m
.52915 .61803 L
s
.56803 .61428 m
.56803 .61803 L
s
.64577 .61428 m
.64577 .61803 L
s
.68465 .61428 m
.68465 .61803 L
s
.72352 .61428 m
.72352 .61803 L
s
.76239 .61428 m
.76239 .61803 L
s
.84014 .61428 m
.84014 .61803 L
s
.87901 .61428 m
.87901 .61803 L
s
.91788 .61428 m
.91788 .61803 L
s
.95675 .61428 m
.95675 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08012 m
1 .08012 L
s
.99375 .19638 m
1 .19638 L
s
.99375 .31265 m
1 .31265 L
s
.99375 .42892 m
1 .42892 L
s
.99375 .54519 m
1 .54519 L
s
.125 Mabswid
.99625 .10918 m
1 .10918 L
s
.99625 .13825 m
1 .13825 L
s
.99625 .16732 m
1 .16732 L
s
.99625 .22545 m
1 .22545 L
s
.99625 .25452 m
1 .25452 L
s
.99625 .28358 m
1 .28358 L
s
.99625 .34172 m
1 .34172 L
s
.99625 .37078 m
1 .37078 L
s
.99625 .39985 m
1 .39985 L
s
.99625 .45798 m
1 .45798 L
s
.99625 .48705 m
1 .48705 L
s
.99625 .51612 m
1 .51612 L
s
.99625 .05105 m
1 .05105 L
s
.99625 .02198 m
1 .02198 L
s
.99625 .57425 m
1 .57425 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .19638 m
1 .19638 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .19638 m
.02381 .60332 L
s
.04325 .19638 m
.04325 .42044 L
s
.06268 .19638 m
.06268 .10232 L
s
.08212 .19638 m
.08212 .03046 L
s
.10155 .19638 m
.10155 .23231 L
s
.12099 .19638 m
.12099 .37078 L
s
.14043 .19638 m
.14043 .23231 L
s
.15986 .19638 m
.15986 .03046 L
s
.1793 .19638 m
.1793 .10232 L
s
.19874 .19638 m
.19874 .42044 L
s
.21817 .19638 m
.21817 .60332 L
s
.23761 .19638 m
.23761 .42044 L
s
.25705 .19638 m
.25705 .10232 L
s
.27648 .19638 m
.27648 .03046 L
s
.29592 .19638 m
.29592 .23231 L
s
.31535 .19638 m
.31535 .37078 L
s
.33479 .19638 m
.33479 .23231 L
s
.35423 .19638 m
.35423 .03046 L
s
.37366 .19638 m
.37366 .10232 L
s
.3931 .19638 m
.3931 .42044 L
s
.41254 .19638 m
.41254 .60332 L
s
.43197 .19638 m
.43197 .42044 L
s
.45141 .19638 m
.45141 .10232 L
s
.47085 .19638 m
.47085 .03046 L
s
.49028 .19638 m
.49028 .23231 L
s
.50972 .19638 m
.50972 .37078 L
s
.52915 .19638 m
.52915 .23231 L
s
.54859 .19638 m
.54859 .03046 L
s
.56803 .19638 m
.56803 .10232 L
s
.58746 .19638 m
.58746 .42044 L
s
.6069 .19638 m
.6069 .60332 L
s
.62634 .19638 m
.62634 .42044 L
s
.64577 .19638 m
.64577 .10232 L
s
.66521 .19638 m
.66521 .03046 L
s
.68465 .19638 m
.68465 .23231 L
s
.70408 .19638 m
.70408 .37078 L
s
.72352 .19638 m
.72352 .23231 L
s
.74295 .19638 m
.74295 .03046 L
s
.76239 .19638 m
.76239 .10232 L
s
.78183 .19638 m
.78183 .42044 L
s
.80126 .19638 m
.80126 .60332 L
s
.8207 .19638 m
.8207 .42044 L
s
.84014 .19638 m
.84014 .10232 L
s
.85957 .19638 m
.85957 .03046 L
s
.87901 .19638 m
.87901 .23231 L
s
.89845 .19638 m
.89845 .37078 L
s
.91788 .19638 m
.91788 .23231 L
s
.93732 .19638 m
.93732 .03046 L
s
.95675 .19638 m
.95675 .10232 L
s
.97619 .19638 m
.97619 .42044 L
s
.015 w
.02381 .60332 Mdot
.04325 .42044 Mdot
.06268 .10232 Mdot
.08212 .03046 Mdot
.10155 .23231 Mdot
.12099 .37078 Mdot
.14043 .23231 Mdot
.15986 .03046 Mdot
.1793 .10232 Mdot
.19874 .42044 Mdot
.21817 .60332 Mdot
.23761 .42044 Mdot
.25705 .10232 Mdot
.27648 .03046 Mdot
.29592 .23231 Mdot
.31535 .37078 Mdot
.33479 .23231 Mdot
.35423 .03046 Mdot
.37366 .10232 Mdot
.3931 .42044 Mdot
.41254 .60332 Mdot
.43197 .42044 Mdot
.45141 .10232 Mdot
.47085 .03046 Mdot
.49028 .23231 Mdot
.50972 .37078 Mdot
.52915 .23231 Mdot
.54859 .03046 Mdot
.56803 .10232 Mdot
.58746 .42044 Mdot
.6069 .60332 Mdot
.62634 .42044 Mdot
.64577 .10232 Mdot
.66521 .03046 Mdot
.68465 .23231 Mdot
.70408 .37078 Mdot
.72352 .23231 Mdot
.74295 .03046 Mdot
.76239 .10232 Mdot
.78183 .42044 Mdot
.80126 .60332 Mdot
.8207 .42044 Mdot
.84014 .10232 Mdot
.85957 .03046 Mdot
.87901 .23231 Mdot
.89845 .37078 Mdot
.91788 .23231 Mdot
.93732 .03046 Mdot
.95675 .10232 Mdot
.97619 .42044 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`008_ooool5o`0000?ooooo0_l0
000Xooooo`?o00001?ooool2o`0002Wooooo0_l0000[ooooo`?o00001?ooool2o`0002Sooooo1Ol0
0003ooooo`;o0000;oooool5o`0000?ooooo0_l0000Xooooo`?o00001?ooool2o`0002Wooooo0_l0
000[ooooo`?o00001?ooool2o`0002Oooooo1Ol00003ooooo`;o00004?ooool002?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00009oooool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo0000:?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0002oooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Xoooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009oooool01?l0003oooooooooool0
000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000oooooo000Looooo`Go00000oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`00023ooooo1Ol00003ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00009oooool01?l0003oooooooooool0000[ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000:Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0002Sooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00008?ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000W
ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Xooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00003oooool002Gooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`0002_ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Zooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`0_ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009oooool01?l0
003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool03Oooool002;ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002Sooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`0002_ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool0000^ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Xooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009ooo
ool01?l0003oooooooooool0000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00009_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00003oooool0
02;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002Oooooo0_l0
0004ooooo`04o`000?ooooooooooo`0002Oooooo00Co0000oooooooooooo0000:_ooool2o`0000Co
oooo00Co0000oooooooooooo00009oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo0000;_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00009oooool2o`0000Cooooo00Co0000oooooooooooo00009oooool01?l0003oooooooooool0000Z
ooooo`;o00001?ooool01?l0003oooooooooool0000Vooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool0000?ooooo`008oooool3o`0000Cooooo0_l0000Yooooo`03o`00
0?oooooooooo00?ooooo0_l0000Yooooo`;o0000;?ooool00ol0003oooooooooo`03ooooo`;o0000
:Oooool3o`0000Cooooo0_l0000`ooooo`?o00001?ooool2o`0002Wooooo00?o0000ooooooooool0
0oooool2o`0002Wooooo0_l0000/ooooo`03o`000?oooooooooo00?ooooo0_l0000Xooooo`?o0000
1?ooool2o`00013ooooo003oooooooWooooo003oooooooWooooo000Jooooo`;o0000n?ooool2o`00
0>;ooooo000Iooooo`04o`000?ooooooooooo`000?Kooooo00Co0000oooooooooooo0000hOooool0
01Wooooo00Co0000oooooooooooo00000oooooo?o`0002Cooooo00Co0000oooooooooooo00001?oo
ool4o`0000?oo`000_l00002ool000?o00000_oo000Ko`0000?oo`000_l00003ool000;o00000ooo
0002o`0000;oo`000ol00002ool001co00000_oo0002o`0000?oo`000_l00003ool000;o00000ooo
0002o`0000;oo`007?l00002ool000;o00000ooo0002o`0000?oo`000_l00003ool000;o00000ooo
000Ko`0000;oo`000ol00002ool000?o00000_oo0004o`0000kooooo000Iooooo`04o`000?oooooo
ooooo`0000?ooooo0ol00002ooooolKo003o0_ooool2o`0002Cooooo00Co0000oooooooooooo0000
1?ooool2o`0000;ooooo00?oo`00o`00ool00?l0`ol00?l00ooo003oooooooooo`02o`0000kooooo
000Iooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0Foooool01?l00?oooooo
ooooooooool2o`00o`?ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0F_ooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooo
ooooooooooooFOoo00000ol00?ooo`00ool00002ool00003o`00oooo003oo`0000;oo`0000?o003o
ool00?oo00000_oo00000ol00?ooo`00ool00002ool00003o`00oooo003oo`0005Koo`001?ooool0
0ol0003oooooooooo`0<ooooo`006Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo05_ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`;o003o0oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool08_ooool01?l0003ooooooooo
ool00004ooooo`04o`000?ooooooooooooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`;o
o`000oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo00?oo`00o`00oooo
ool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00oooo
ool00_ooool00ooo003o003oooooo`0Jooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;o
o`000oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?o0000oooooooo
ool03?ooool001[ooooo0_l00004ooooo`03o`000?oooooooooo05_ooooo00Co003ooooooooooooo
oooo0_l00?l3ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[o
oooo00?o0000ooooooooool08oooool2o`0000Gooooo00Co0000oooooooooooooooo0_oo0003oooo
o`;oo`000oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003oooo
o`;oo`006oooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00
ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo01[ooooo0_oo0003oooo
o`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool000?ooooo0_oo0003oooo
o`;oo`001?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0005cooooo00Co003ooooooooo
oooooooo0_l00?l3ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
05[ooooo00?o0000ooooooooool0:_ooool2o`0000;ooooo0_oo0003ooooo`;oo`000oooool2ool0
01_ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool00ooo
003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo
003o003oooooo`02ooooo`03ool00?l00?oooooo01[ooooo0_oo0003ooooo`;oo`000oooool2ool0
00?ooooo0_oo0003ooooo`;oo`006oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2o`00
00kooooo000Pooooo`03o`000?oooooooooo05_ooooo00Co003ooooooooooooooooo0_l00?l3oooo
o`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000oooo
ooooool0:_ooool01?l0003oooooooooooooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2
ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`03ool00?l00?oo
oooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oo
oooo00;ooooo00?oo`00o`00ooooool06_ooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2
ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo05_ooooo00Co003ooooooooooooooooo0_l00?l3
ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o0000
ooooooooool0:_ooool01?l0003oooooooooooooool2ool000?ooooo0_oo0003ooooo`;oo`006ooo
ool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`03ool00?l0
0?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l0
0?oooooo00;ooooo00?oo`00o`00ooooool06_ooool2ool000?ooooo0_oo0003ooooo`;oo`000ooo
ool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03o`000?oo
oooooooo00cooooo000Pooooo`03o`000?oooooooooo05_ooooo00Co003ooooooooooooooooo0_l0
0?l3ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o
0000ooooooooool0:_ooool01?l0003oooooooooooooool2ool000?ooooo0_oo0003ooooo`;oo`00
6oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`03ool0
0?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool0
0?l00?oooooo00;ooooo00?oo`00o`00ooooool06_ooool2ool000?ooooo0_oo0003ooooo`;oo`00
0oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03o`00
0?oooooooooo00cooooo000Pooooo`;o0000G?ooool01?l00?ooooooooooooooool2o`00o`?ooooo
0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003ooooo
ooooo`0Zooooo`;o00000_ooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool000?ooooo
0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`03ool00?l00?oooooo00;ooooo
00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo
00?oo`00o`00ooooool06_ooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo
0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;o00003_ooool0023ooooo00?o
0000ooooooooool0Foooool01?l00?ooooooooooooooool2o`00o`?ooooo0_l00?l3ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Zooooo`04o`00
0?ooooooooooooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?o
oooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo00?oo`00o`00ooooool00_ooool00ooo003o
003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o
003oooooo`0Jooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool001_o
oooo0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?o0000ooooooooool03?ooool0023ooooo
00?o0000ooooooooool0Foooool01?l00?ooooooooooooooool2o`00o`?ooooo0_l00?l3ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Zooooo`04
o`000?ooooooooooooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool0
00?ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo00?oo`00o`00ooooool00_ooool00ooo
003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo
003o003oooooo`0Jooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool0
01_ooooo0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?o0000ooooooooool03?ooool0023o
oooo00?o0000ooooooooool0Foooool01?l00?ooooooooooooooool2o`00o`?ooooo0_l00?l3oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Zoooo
o`04o`000?ooooooooooooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2
ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo00?oo`00o`00ooooool00_ooool0
0ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool0
0ooo003o003oooooo`0Jooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2
ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?o0000ooooooooool03?ooool0
023ooooo0_l0001Looooo`04o`00ooooooooooooooooo`;o003o0oooool2o`00o`?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02[ooooo0_l00002
ooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0003
ooooo`;oo`000oooool2ool001_ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02
ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`0J
ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo0_oo0003
ooooo`;oo`000oooool2ool000?ooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1Koooo
o`04o`00ooooooooooooooooo`;o003o0oooool2o`00o`?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooooooo0_oo
0003ooooo`;oo`000oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo
0003ooooo`;oo`006oooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?o
o`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo01[ooooo0_oo
0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool000?ooooo0_oo
0003ooooo`;oo`001?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1K
ooooo`04o`00ooooooooooooooooo`;o003o0oooool2o`00o`?ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooooooo
0_oo0003ooooo`;oo`000oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo
0_oo0003ooooo`;oo`006oooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo
00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo01[ooooo
0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool000?ooooo
0_oo0003ooooo`;oo`001?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003ooooooooo
o`1Kooooo`04o`00ooooooooooooooooo`;o003o0oooool2o`00o`?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo
oooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000?o
oooo0_oo0003ooooo`;oo`006oooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;o
oooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo01[o
oooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool000?o
oooo0_oo0003ooooo`;oo`001?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0005cooooo
00Co003ooooooooooooooooo0_l00?l3ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo05[ooooo00?o0000ooooooooool0:_ooool2o`0000;ooooo0_oo0003ooooo`;o
o`000oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;o
o`006oooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00oooo
ool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo01[ooooo0_oo0003ooooo`;o
o`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool000?ooooo0_oo0003ooooo`;o
o`000oooool2o`0000kooooo000Pooooo`03o`000?oooooooooo05_ooooo00Co003ooooooooooooo
oooo0_l00?l3ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[o
oooo00?o0000ooooooooool0:_ooool01?l0003oooooooooooooool2ool000?ooooo0_oo0003oooo
o`;oo`006oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo000Koooo
o`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02oooo
o`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool06_ooool2ool000?ooooo0_oo0003oooo
o`;oo`000oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0004oooo
o`03o`000?oooooooooo00cooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00001?ooool00ol0003oooooooooo`1Kooooo`04o`00ooooooooooooooooo`;o003o0oooool2o`00
o`?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo
01Oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`04o`000?oooooooooo
ooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0003
ooooo`;oo`000oooool2ool001_ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02
ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`0J
ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo0_oo0003
ooooo`;oo`000oooool2ool000Cooooo00?o0000ooooooooool03?ooool000gooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0Fooo
ool01?l00?ooooooooooooooool2o`00o`?ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Fooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooooooo`;oo`000oooool2
ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2
ool001_ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oo
oooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`0Jooooo`;oo`000oooool2
ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2
ool000Cooooo00?o0000ooooooooool03?ooool000gooooo00Co0000oooooooooooo00002oooool0
1?l0003oooooooooooooool3o`0005_ooooo00Co003ooooooooooooooooo0_l00?l3ooooo`;o003o
0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05Wooooo0_l0000Hooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_oo0003ooooo`;o
o`000oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;o
o`006oooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00oooo
ool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo01[ooooo0_oo0003ooooo`;o
o`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool000?ooooo0_oo0003ooooo`;o
o`000oooool2o`0000kooooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000oooooooo
ooooooooo`00001Mooooo`04o`00ooooooooooooooooo`;o003o0oooool2o`00o`?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo01Kooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;oo`00
0oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`00
0oooool2ool001_ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool0
0?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`0Jooooo`;oo`00
0oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo0_oo0003ooooo`;oo`00
0oooool2ool000Cooooo00?o0000ooooooooool03?ooool000gooooo00Co0000oooooooooooo0000
1oooool4o`0000Cooooo00?o0000ooooooooool0Foooool01?l00?ooooooooooooooool2o`00o`?o
oooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003o
ooooooooo`0Fooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`04o`000?oooooooooo
ooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0003
ooooo`;oo`000oooool2ool001_ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02
ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`0J
ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo0_oo0003
ooooo`;oo`000oooool2ool000Cooooo00?o0000ooooooooool03?ooool000gooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo00Co003o
oooooooooooooooo0_l00?l3ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo05[ooooo00?o0000ooooooooool05_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00Kooooo00Co0000oooooooooooooooo0_oo0003ooooo`;oo`000oooool2ool001_o
oooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool00ooo003o
003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o
003oooooo`02ooooo`03ool00?l00?oooooo01[ooooo0_oo0003ooooo`;oo`000oooool2ool000?o
oooo0_oo0003ooooo`;oo`006oooool2ool000?ooooo0_oo0003ooooo`;oo`001?ooool00ol0003o
ooooooooo`0<ooooo`003_ooool2o`0000Sooooo1Ol00003ooooo`;o0000G?ooool01?l00?oooooo
ooooooooool2o`00o`?ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool0F_ooool00ol0003oooooooooo`0Gooooo`;o00002?ooool5o`0000Cooooo0_l00002ooooo`;o
o`000oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;o
o`000oooool2ool001_ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03
ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`0Jooooo`;o
o`000oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo0_oo0003ooooo`;o
o`000oooool2ool000?ooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1Kooooo`04o`00
ooooooooooooooooo`;o003o0oooool2o`00o`?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1Jooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooooooo0_oo0003oooo
o`;oo`000oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003oooo
o`;oo`006oooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00
ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo01[ooooo0_oo0003oooo
o`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool000?ooooo0_oo0003oooo
o`;oo`001?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Kooooo`04
o`00ooooooooooooooooo`;o003o0oooool2o`00o`?ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`1Jooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooooooo0_oo0003
ooooo`;oo`000oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003
ooooo`;oo`006oooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00
o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo01[ooooo0_oo0003
ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool000?ooooo0_oo0003
ooooo`;oo`001?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Koooo
o`04o`00ooooooooooooooooo`;o003o0oooool2o`00o`?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooooooo0_oo
0003ooooo`;oo`000oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo
0003ooooo`;oo`006oooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?o
o`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo01[ooooo0_oo
0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool000?ooooo0_oo
0003ooooo`;oo`001?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0005cooooo00Co003o
oooooooooooooooo0_l00?l3ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo05[ooooo00?o0000ooooooooool0:_ooool2o`0000;ooooo0_oo0003ooooo`;oo`000ooo
ool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006ooo
ool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_oo
ool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo01[ooooo0_oo0003ooooo`;oo`000ooo
ool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool000?ooooo0_oo0003ooooo`;oo`000ooo
ool2o`0000kooooo000Pooooo`03o`000?oooooooooo05_ooooo00Co003ooooooooooooooooo0_l0
0?l3ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo00?o
0000ooooooooool0:_ooool01?l0003oooooooooooooool2ool000?ooooo0_oo0003ooooo`;oo`00
6oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`03ool0
0?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool0
0?l00?oooooo00;ooooo00?oo`00o`00ooooool06_ooool2ool000?ooooo0_oo0003ooooo`;oo`00
0oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03o`00
0?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05_ooooo00Co003ooooooooooooooooo
0_l00?l3ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[ooooo
00?o0000ooooooooool0:_ooool01?l0003oooooooooooooool2ool000?ooooo0_oo0003ooooo`;o
o`006oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`03
ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03
ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool06_ooool2ool000?ooooo0_oo0003ooooo`;o
o`000oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05_ooooo00Co003ooooooooooooo
oooo0_l00?l3ooooo`;o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo05[o
oooo00?o0000ooooooooool0:_ooool01?l0003oooooooooooooool2ool000?ooooo0_oo0003oooo
o`;oo`006oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo000Koooo
o`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02oooo
o`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool06_ooool2ool000?ooooo0_oo0003oooo
o`;oo`000oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0004oooo
o`03o`000?oooooooooo00cooooo000Pooooo`;o0000G?ooool01?l00?ooooooooooooooool2o`00
o`?ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0
003oooooooooo`0Zooooo`;o00000_ooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool0
00?ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`03ool00?l00?oooooo
00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo
00;ooooo00?oo`00o`00ooooool06_ooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool0
00?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;o00003_ooool0023o
oooo00?o0000ooooooooool0Foooool01?l00?ooooooooooooooool2o`00o`?ooooo0_l00?l3oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Zoooo
o`04o`000?ooooooooooooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2
ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo00?oo`00o`00ooooool00_ooool0
0ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool0
0ooo003o003oooooo`0Jooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2
ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool0Foooool01?l00?ooooooooooooooool2o`00o`?ooooo0_l00?l3
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Z
ooooo`04o`000?ooooooooooooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`;oo`000ooo
ool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo00?oo`00o`00ooooool00_oo
ool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_oo
ool00ooo003o003oooooo`0Jooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`000ooo
ool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?o0000ooooooooool03?oo
ool0023ooooo00?o0000ooooooooool0Foooool01?l00?ooooooooooooooool2o`00o`?ooooo0_l0
0?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003ooooooooo
o`0Zooooo`04o`000?ooooooooooooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`;oo`00
0oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo00?oo`00o`00ooooool0
0_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool0
0_ooool00ooo003o003oooooo`0Jooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`00
0oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000Cooooo00?o0000ooooooooool0
3?ooool0023ooooo0_l0001Looooo`04o`00ooooooooooooooooo`;o003o0oooool2o`00o`?ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02[ooooo
0_l00002ooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo
0_oo0003ooooo`;oo`000oooool2ool001_ooooo00?oo`00o`00ooooool00_ooool00ooo003o003o
ooooo`02ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003o
ooooo`0Jooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo
0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_l0000>ooooo`008?ooool00ol0003ooooooooo
o`1Kooooo`04o`00ooooooooooooooooo`;o003o0oooool2o`00o`?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo
oooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2ool000?o
oooo0_oo0003ooooo`;oo`006oooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00;o
oooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo01[o
oooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool000?o
oooo0_oo0003ooooo`;oo`001?ooool00ol0003oooooooooo`0<ooooo`006Oooool3o`0000Cooooo
00?o0000ooooooooool0Foooool01?l00?ooooooooooooooool2o`00o`?ooooo0_l00?l3ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Rooooo`?o
00001Oooool01?l0003oooooooooooooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2ool0
00?ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo000Kooooo`03ool00?l00?oooooo
00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo
00;ooooo00?oo`00o`00ooooool06_ooool2ool000?ooooo0_oo0003ooooo`;oo`000oooool2ool0
00?ooooo0_oo000Kooooo`;oo`000oooool2ool000?ooooo0_oo0004ooooo`03o`000?oooooooooo
00cooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Foooool01?l00?oo
ooooooooooooool2o`00o`?ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0F_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo0_oo0003ooooo`;oo`000oooool2
ool000?ooooo0_oo0003ooooo`;oo`006oooool00ooo003o003oooooo`02ooooo`03ool00?l00?oo
oooo00;ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oo
oooo01[ooooo0_oo0003ooooo`;oo`000oooool2ool000?ooooo0_oo0003ooooo`;oo`006oooool2
ool000?ooooo0_oo0003ooooo`;oo`001?ooool00ol0003oooooooooo`0<ooooo`006_ooool00ol0
003oooooooooo`03ooooo`?o0000Foooool01?l00?ooooooooooooooool2o`00o`?ooooo0_l00?l3
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0FOooool2o`0002Gooooo00?o0000
ooooooooool01?ooool2o`0000;ooooo0_oo0003ooooo`;oo`000oooool2ool001_ooooo0_oo0003
ooooo`?oo`000_ooool3ool000;ooooo0_oo0003ooooo`;oo`006oooool00ooo003o003oooooo`02
ooooo`03ool00?l00?ooo`0000;ooooo00?oo`00o`00oooo00000_ooool00ooo003o003oool00002
ooooo`03ool00?l00?oooooo01[ooooo0_oo0003ooooo`?oo`000_ooool3ool000;ooooo0ooo0002
ooooo`;oo`006oooool2ool000?ooooo0ooo0002ooooo`?oo`000_ooool2o`0000kooooo000Joooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo0_oo0003ooooo`;oo`000oooool2
ool001_ooooo0_oo0003ooooo`?oo`000_ooool3ool000;ooooo0_oo0003ooooo`;oo`006oooool0
0ooo003o003oooooo`02ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`03ool00?l00?oo
oooo01[ooooo0_oo0003ooooo`?oo`000_ooool3ool000;ooooo0ooo0002ooooo`;oo`006oooool2
ool000?ooooo0ooo0002ooooo`?oo`000oooool00ol0003oooooooooo`0<ooooo`006_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2ool0
01_ooooo00?oo`00o`00ooooool02?ooool00ol0003oooooooooo`06ooooo`03ool00?l00?oooooo
01[ooooo0_oo000Booooo`;oo`006oooool2ool000kooooo00?o0000ooooooooool03?ooool001Wo
oooo0_l00005ooooo`03o`000?oooooooooo05_ooooo00?o003oooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`00oooooooooooo05[ooooo00?o0000ooooooooool08_ooool2o`0000Ko
oooo00?o0000ooooooooool02oooool2ool001_ooooo0_oo000Booooo`;oo`006oooool00ooo003o
003oooooo`08ooooo`03o`000?oooooooooo00Kooooo00?oo`00o`00ooooool06_ooool2ool001;o
oooo0_oo000Kooooo`;oo`003_ooool00ol0003oooooooooo`0<ooooo`006_ooool00ol0003ooooo
ooooo`03ooooo`;o0000G?ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo
0_l0000<ooooo`;oo`006oooool2ool001;ooooo0_oo000Kooooo`03ool00?l00?oooooo00Sooooo
00?o0000ooooooooool01_ooool00ooo003o003oooooo`0Jooooo`;oo`004_ooool2ool001_ooooo
0_oo000=ooooo`;o00003_ooool0023ooooo00?o0000ooooooooool0Foooool00ol00?oooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0F_ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo00?o
o`00o`00ooooool02?ooool00ol0003oooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo0_oo
000Booooo`;oo`006oooool2ool000kooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000
ooooooooool0Foooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o003o
ooooooooool0F_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo0_oo000K
ooooo`;oo`004_ooool2ool001_ooooo00?oo`00o`00ooooool02?ooool00ol0003oooooooooo`06
ooooo`03ool00?l00?oooooo01[ooooo0_oo000Booooo`;oo`006oooool2ool000kooooo00?o0000
ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo00?oo`00o`00
ooooool02?ooool00ol0003oooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo0_oo000Boooo
o`;oo`006oooool2ool000kooooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Looooo`03
o`00oooooooooooo00Kooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`1Jooooo`03
o`000?oooooooooo02[ooooo0_l0000<ooooo`;oo`006oooool2ool001;ooooo0_oo000Kooooo`03
ool00?l00?oooooo00Sooooo00?o0000ooooooooool01_ooool00ooo003o003oooooo`0Jooooo`;o
o`004_ooool2ool001_ooooo0_oo000=ooooo`;o00003_ooool0023ooooo00?o0000ooooooooool0
Foooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0
F_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo0_oo000Kooooo`;oo`00
4_ooool2ool001_ooooo00?oo`00o`00ooooool02?ooool00ol0003oooooooooo`06ooooo`03ool0
0?l00?oooooo01[ooooo0_oo000Booooo`;oo`006oooool2ool000kooooo00?o0000ooooooooool0
3?ooool0023ooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo00?oo`00o`00ooooool02?oo
ool00ol0003oooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo0_oo000Booooo`;oo`006ooo
ool2ool000kooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Foooool0
0ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0F_ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2
ool001_ooooo00?oo`00o`00ooooool02?ooool00ol0003oooooooooo`06ooooo`03ool00?l00?oo
oooo01[ooooo0_oo000Booooo`;oo`006oooool2ool000kooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00_ooooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo00?oo`00o`00ooooool02?ooool00ol0
003oooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo0_oo000Booooo`;oo`006oooool2ool0
00kooooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Looooo`03o`00oooooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02[o
oooo0_l0000<ooooo`;oo`006oooool2ool001;ooooo0_oo000Kooooo`03ool00?l00?oooooo00So
oooo00?o0000ooooooooool01_ooool00ooo003o003oooooo`0Jooooo`;oo`004_ooool2ool001_o
oooo0_oo000=ooooo`;o00003_ooool0023ooooo00?o0000ooooooooool0Foooool00ol00?oooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0F_ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo
00?oo`00o`00ooooool02?ooool00ol0003oooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo
0_oo000Booooo`;oo`006oooool2ool000kooooo00?o0000ooooooooool03?ooool0023ooooo00?o
0000ooooooooool0Foooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
003oooooooooool0F_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo0_oo
000Kooooo`;oo`004_ooool2ool001_ooooo00?oo`00o`00ooooool02?ooool00ol0003ooooooooo
o`06ooooo`03ool00?l00?oooooo01[ooooo0_oo000Booooo`;oo`006oooool2ool000kooooo00?o
0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo00?oo`00
o`00ooooool02?ooool00ol0003oooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo0_oo000B
ooooo`;oo`006oooool2ool000kooooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Loooo
o`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`1Joooo
o`03o`000?oooooooooo02[ooooo0_l0000<ooooo`;oo`006oooool2ool001;ooooo0_oo000Koooo
o`03ool00?l00?oooooo00Sooooo00?o0000ooooooooool01_ooool00ooo003o003oooooo`0Joooo
o`;oo`004_ooool2ool001_ooooo0_oo000=ooooo`;o00003_ooool000gooooo0ol00004ooooo`03
o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo05_ooooo00?o003ooooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo05[ooooo00?o0000oooooooo
ool05_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooooooo
ool02oooool2ool001_ooooo0_oo000Booooo`;oo`006oooool00ooo003o003oooooo`08ooooo`03
o`000?oooooooooo00Kooooo00?oo`00o`00ooooool06_ooool2ool001;ooooo0_oo000Kooooo`;o
o`003_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`07ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`1Kooooo`03o`00oooooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool02oooool2ool001_ooooo0_oo000Booooo`;oo`006oooool00ooo003o003oooooo`08oooo
o`03o`000?oooooooooo00Kooooo00?oo`00o`00ooooool06_ooool2ool001;ooooo0_oo000Koooo
o`;oo`003_ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`0;ooooo`05
o`000?ooooooooooooooool00000GOooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`;oo`006oooool2ool0
01;ooooo0_oo000Kooooo`03ool00?l00?oooooo00Sooooo00?o0000ooooooooool01_ooool00ooo
003o003oooooo`0Jooooo`;oo`004_ooool2ool001_ooooo0_oo000>ooooo`03o`000?oooooooooo
00cooooo000>ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0ol0001Koooo
o`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`1Ioooo
o`;o00006Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l0000<oooo
o`;oo`006oooool2ool001;ooooo0_oo000Kooooo`03ool00?l00?oooooo00Sooooo00?o0000oooo
ooooool01_ooool00ooo003o003oooooo`0Jooooo`;oo`004_ooool2ool001_ooooo0_oo000=oooo
o`;o00003_ooool000kooooo00?o0000ooooooooool01oooool4o`0000Cooooo00?o0000oooooooo
ool0Foooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool0F_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo1?l00005ooooo`03
o`000?oooooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo00?oo`00o`00oooo
ool02?ooool00ol0003oooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo0_oo000Booooo`;o
o`006oooool2ool000kooooo00?o0000ooooooooool03?ooool000gooooo0_l00009ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Fooooo`;o0000
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo0_oo000Kooooo`;oo`00
4_ooool2ool001_ooooo00?oo`00o`00ooooool02?ooool00ol0003oooooooooo`06ooooo`03ool0
0?l00?oooooo01[ooooo0_oo000Booooo`;oo`006oooool2ool000kooooo00?o0000ooooooooool0
3?ooool000kooooo00?o0000ooooooooool01oooool5o`0000?ooooo00?o0000ooooooooool0Fooo
ool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0F_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`03o`000?oo
oooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo00?oo`00o`00ooooool02?oo
ool00ol0003oooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo0_oo000Booooo`;oo`006ooo
ool2ool000kooooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Looooo`03o`00oooooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooo
oooo02[ooooo0_l0000<ooooo`;oo`006oooool2ool001;ooooo0_oo000Kooooo`03ool00?l00?oo
oooo00Sooooo00?o0000ooooooooool01_ooool00ooo003o003oooooo`0Jooooo`;oo`004_ooool2
ool001_ooooo0_oo000=ooooo`;o00003_ooool0023ooooo00?o0000ooooooooool0Foooool00ol0
0?ooooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0F_ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2ool0
01_ooooo00?oo`00o`00ooooool02?ooool00ol0003oooooooooo`06ooooo`03ool00?l00?oooooo
01[ooooo0_oo000Booooo`;oo`006oooool2ool000kooooo00?o0000ooooooooool03?ooool0023o
oooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Oo
oooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_o
oooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo00?oo`00o`00ooooool02?ooool00ol0003o
ooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo0_oo000Booooo`;oo`006oooool2ool000ko
oooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Foooool00ol00?oooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0F_ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo
00?oo`00o`00ooooool02?ooool00ol0003oooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo
0_oo000Booooo`;oo`006oooool2ool000kooooo00?o0000ooooooooool03?ooool0023ooooo0_l0
001Looooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01oooool00ol00?oooooooooo
o`1Jooooo`03o`000?oooooooooo02[ooooo0_l0000<ooooo`;oo`006oooool2ool001;ooooo0_oo
000Kooooo`03ool00?l00?oooooo00Sooooo00?o0000ooooooooool01_ooool00ooo003o003ooooo
o`0Jooooo`;oo`004_ooool2ool001_ooooo0_oo000=ooooo`;o00003_ooool0023ooooo00?o0000
ooooooooool0Foooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o003o
ooooooooool0F_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo0_oo000K
ooooo`;oo`004_ooool2ool001_ooooo00?oo`00o`00ooooool02?ooool00ol0003oooooooooo`06
ooooo`03ool00?l00?oooooo01[ooooo0_oo000Booooo`;oo`006oooool2ool000kooooo00?o0000
ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo00?oo`00o`00
ooooool02?ooool00ol0003oooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo0_oo000Boooo
o`;oo`006oooool2ool000kooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooooooo
ool0Foooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool0F_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo0_oo000Kooooo`;o
o`004_ooool2ool001_ooooo00?oo`00o`00ooooool02?ooool00ol0003oooooooooo`06ooooo`03
ool00?l00?oooooo01[ooooo0_oo000Booooo`;oo`006oooool2ool000kooooo00?o0000oooooooo
ool03?ooool0023ooooo0_l0001Looooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02[ooooo0_l0000<ooooo`;oo`00
6oooool2ool001;ooooo0_oo000Kooooo`03ool00?l00?oooooo00Sooooo00?o0000ooooooooool0
1_ooool00ooo003o003oooooo`0Jooooo`;oo`004_ooool2ool001_ooooo0_oo000=ooooo`;o0000
3_ooool0023ooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo00?oo`00o`00ooooool02?oo
ool00ol0003oooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo0_oo000Booooo`;oo`006ooo
ool2ool000kooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Foooool0
0ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0F_ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo0_oo000Kooooo`;oo`004_ooool2
ool001_ooooo00?oo`00o`00ooooool02?ooool00ol0003oooooooooo`06ooooo`03ool00?l00?oo
oooo01[ooooo0_oo000Booooo`;oo`006oooool2ool000kooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o003oooooooooool0F_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00_ooooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo00?oo`00o`00ooooool02?ooool00ol0
003oooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo0_oo000Booooo`;oo`006oooool2ool0
00kooooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Looooo`03o`00oooooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`1Jooooo`03o`000?oooooooooo02[o
oooo0_l0000<ooooo`;oo`006oooool2ool001;ooooo0_oo000Kooooo`03ool00?l00?oooooo00So
oooo00?o0000ooooooooool01_ooool00ooo003o003oooooo`0Jooooo`;oo`004_ooool2ool001_o
oooo0_oo000=ooooo`;o00003_ooool001Sooooo1Ol00003ooooo`03o`000?oooooooooo05_ooooo
00?o003oooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo05[ooooo
00?o0000ooooooooool08Oooool5o`0000Cooooo00?o0000ooooooooool02oooool2ool001_ooooo
0_oo000Booooo`;oo`006oooool00ooo003o003oooooo`08ooooo`03o`000?oooooooooo00Kooooo
00?oo`00o`00ooooool06_ooool2ool001;ooooo0_oo000Kooooo`;oo`003_ooool00ol0003ooooo
ooooo`0<ooooo`006Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo05_ooooo
00?o003oooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo05[ooooo
00?o0000ooooooooool08_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00_o
oooo0_oo000Kooooo`;oo`004_ooool2ool001_ooooo00?oo`00o`00ooooool02?ooool00ol0003o
ooooooooo`06ooooo`03ool00?l00?oooooo01[ooooo0_oo000Booooo`;oo`006oooool2ool000ko
oooo00?o0000ooooooooool03?ooool001[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Kooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01oooool00ol00?oooooo
ooooo`1Jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0;ooooo`;oo`006oooool3ool0017ooooo0_oo000Kooooo`03ool00?l00?ooo`0000Sooooo
00?o0000ooooooooool01_ooool00ooo003o003oooooo`0Jooooo`?oo`004Oooool3ool001[ooooo
0ooo000=ooooo`03o`000?oooooooooo00cooooo000Kooooo`03o`000?oooooooooo00;ooooo0ol0
001Kooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01oooool00ol00?oooooooooo
o`1Iooooo`;o00009_ooool00ol0003oooooooooo`03ooooo`;o00003?ooool2ool001_ooooo0ooo
000Aooooo`;oo`006oooool00ooo003o003oool00008ooooo`03o`000?oooooooooo00Kooooo00?o
o`00o`00ooooool06_ooool3ool0017ooooo0ooo000Jooooo`?oo`003?ooool2o`0000kooooo000H
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool02oooool2ool001_ooooo0_oo000Booooo`;oo`006oooool2ool000Wooooo
00?o0000ooooooooool01_ooool2ool001_ooooo0_oo000Booooo`;oo`006oooool2ool000kooooo
00?o0000ooooooooool03?ooool001Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Qooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool03?ooool001Wooooo0ol00004ooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Rooooo`?o00001Oooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03?ooool0023ooooo0_l0
001Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:_ooool2o`0006Gooooo00?o
0000ooooooooool0Hoooool2o`0000kooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000
IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo0_l0001Uooooo`03o`00
0?oooooooooo06?ooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0006Go
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`;o0000IOooool00ol0003o
ooooooooo`1Sooooo`;o00003_ooool0023ooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Uoooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:_ooool2o`0006Gooooo00?o0000oooo
ooooool0Hoooool2o`0000kooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0<ooooo`003?ooool5o`0000?ooooo00?o0000ooooooooool0
0_ooool3o`0000Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo01Gooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0<ooooo`003Ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool05_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03?ooool000kooooo00?o0000oooo
ooooool02oooool01?l0003oooooooooooooool3o`0006Cooooo00?o0000ooooooooool0Hoooool2
o`0001Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`;o0000IOooool0
0ol0003oooooooooo`1Sooooo`;o00003_ooool000oooooo00?o0000ooooooooool02_ooool01Ol0
003ooooooooooooooooo000006Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03?ooool000cooooo00Go0000oooo
ooooooooooooo`000007ooooo`Co00001?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo000000Oooooo1?l0
0005ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0<ooooo`003?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool05Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool03?ooool000gooooo0ol0
0008ooooo`Go00000oooool2o`0006Gooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0Fooooo`?o00002?ooool5o`0000Cooooo0_l0001Uooooo`03o`000?oooooooooo06?ooooo0_l0
000>ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool03?ooool0023ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0006Gooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Zooooo`;o0000IOooool00ol0003oooooooooo`1Sooooo`;o0000
3_ooool0023ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00cooooo000Pooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Uooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool0:_ooool2o`0006Gooooo00?o0000ooooooooool0Hoooool2o`0000ko
oooo000Pooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000IOooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo02[ooooo0_l0001Uooooo`03o`000?oooooooooo06?ooooo0_l0000>oooo
o`008?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool03?ooool001Wooooo0ol00004ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Rooooo`?o00001Oooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool03?ooool001Sooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`0Qooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool03?ooool001cooooo00Co0000oooooooooooo
oooo0ol0001Tooooo`03o`000?oooooooooo06?ooooo0_l0000Wooooo`03o`000?oooooooooo00;o
oooo0_l0001Uooooo`03o`000?oooooooooo06?ooooo0_l0000>ooooo`006_ooool2o`0000Cooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02?ooooo
0_l00005ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`0<ooooo`007?ooool01Ol0003ooooooooooooooooo000006Kooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00cooooo000Hooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00cooooo000Iooooo`?o0000
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00Go0000oooooooooooo
ooooo`00000Tooooo`?o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`008?ooooo?o`0002cooooo
col0000>ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`008?ooool2o`0002Gooooo0ol0000Tooooo`Go00009?ooool3o`0002Kooooo0ol0
000Sooooo`?o0000ooooool@ooooo`007oooool01?l0003oooooooooool0000Uooooo`03o`000?oo
oooooooo02Cooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000002Ko
oooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo000002oooooo0_l0000Roooo
o`?o00001?ooool2o`0001oooooo1Ol00003ooooo`;o00007oooool3o`0000Cooooo0_l0000Qoooo
o`?o00000oooool2o`0001oooooo0ol00004ooooo`;o00004?ooool001oooooo00Co0000oooooooo
oooo00009Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool08Oooool5o`0002Kooooo00?o0000ooooooooool0;?ooool01?l0003oooooooooool0000R
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0001gooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`00027ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo01_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000oo
oooo000Oooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Tooooo`;o00009?ooool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo
02cooooo00Co0000oooooooooooo00008_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`00023ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Qooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool07?ooool5o`0000;ooooo00Co0000oooooooo
oooo00008Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00gooooo000Ooooo
o`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooo
oooo000002Oooooo00?o0000ooooooooool08_ooool00ol0003oooooo`00000Sooooo`Co0000;ooo
ool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00008Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool07Oooool2o`00
00?ooooo00Co0000oooooooooooo00007_ooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`00027ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0=ooooo`00
7oooool01?l0003oooooooooool0000Tooooo`;o00009Oooool01Ol0003ooooooooooooooooo0000
02?ooooo00Go0000ooooooooooooooooo`00000Uooooo`;o00008oooool00ol0003oooooooooo`0`
ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Nooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Qoooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07Oooool00ol0003oooooo`000003
ooooo`04o`000?ooooooooooo`0001gooooo1?l00003ooooo`04o`000?ooooooooooo`0000oooooo
000Pooooo`;o00009_ooool00ol0003oooooooooo`0Tooooo`?o00009Oooool3o`0002Oooooo00?o
0000ooooooooool08Oooool5o`0002kooooo00Co0000oooooooooooo00008Oooool2o`0000Cooooo
00Co0000oooooooooooo00007_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00007Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
8?ooool2o`0000?ooooo00Co0000oooooooooooo00007Oooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000oooooo003ooooooa[ooooo0_l0000Sooooo`03o`000?oooooooooo00?o
oooo0_l0000Pooooo`?o00001?ooool2o`0001oooooo0ol00004ooooo`;o00008_ooool00ol0003o
ooooooooo`02ooooo`;o00007_ooool5o`0000?ooooo0_l0000@ooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`007?oooooBo`0002OooooodOl0000Booooo`007?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0001;o
oooo000Looooo`03o`000?oooooooooo0<kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09Oooool2o`0001;ooooo
000Looooo`03o`000?oooooooooo00gooooo0_l00?l@ooooo`;o003o5?ooool00ol00?oooooooooo
o`0?ooooo`;o003o4oooool2o`00oa7ooooo00?o003oooooooooool04_ooool2o`00oa7ooooo00?o
003oooooooooool04_ooool2o`00oa3ooooo0_l00?l>ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0cOooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`0=
ooooo`;o003o4?ooool2o`00oa?ooooo0ol00?l@ooooo`;o003o4oooool2o`00oa7ooooo0_l00?lC
ooooo`;o003o4?ooool3o`00oa?ooooo0_l00?l@ooooo`;o003o3_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo0<gooooo00?o0000ooooooooool04?ooool001cooooo0_l0000=oooo
o`03o`00oooooooo003o013ooooo0_l00?lCooooo`03o`00oooooooo003o00oooooo00?o003ooooo
ool00?l04oooool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooo003o01?ooooo0_l00?l@oooo
o`03o`00oooooooo003o01?ooooo0_l00?l@ooooo`03o`00oooooooo003o00gooooo00?o0000oooo
ooooool09Oooool2o`000<gooooo0_l0000Booooo`007?ooool00ol0003oooooooooo`0<ooooo`03
o`00oooooooo003o00oooooo00Co003ooooooooooooo003o4_ooool00ol00?ooooooo`00o`0?oooo
o`03o`00oooooooo003o01?ooooo00?o003oooooool00?l03oooool00ol00?ooooooo`00o`0Coooo
o`03o`00oooooooo003o00oooooo00?o003oooooool00?l04_ooool01?l00?ooooooooooool00?l?
ooooo`03o`00oooooooo003o00gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0=
ooooo`?o003o3Oooool3o`00oaKooooo0ol00?l=ooooo`?o003o5Oooool3o`00o`gooooo0ol00?lE
ooooo`?o003o3_ooool3o`00oaGooooo0ol00?l=ooooo`?o003o2oooool00ol0003oooooooooo`0@
ooooo`007?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooo003o00oooooo00Co003ooooo
oooooooo003o4_ooool00ol00?ooooooo`00o`0?ooooo`04o`00ooooooooooooo`00oa;ooooo00?o
003oooooool00?l03oooool00ol00?ooooooo`00o`0Booooo`04o`00ooooooooooooo`00o`oooooo
00?o003oooooool00?l04_ooool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00
o`gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`?o003o3Oooool3o`00
oaKooooo0ol00?l=ooooo`?o003o5Oooool3o`00o`gooooo0ol00?lEooooo`?o003o3_ooool3o`00
oaGooooo0ol00?l=ooooo`?o003o2oooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003o
ooooooooo`0<ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o4_ooool0
0ol00?ooooooo`00o`0?ooooo`04o`00ooooooooooooo`00oa7ooooo00Co003ooooooooooooo003o
3oooool00ol00?ooooooo`00o`0Booooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooo
oooo003o4_ooool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`?o003o3Oooool3o`00oaKooooo0ol0
0?l=ooooo`?o003o5Oooool3o`00o`gooooo0ol00?lEooooo`?o003o3_ooool3o`00oaGooooo0ol0
0?l=ooooo`?o003o2oooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`0<
ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o4Oooool01Ol00?oooooo
oooooooooooo003o00kooooo00Co003ooooooooooooo003o4Oooool01?l00?ooooooooooool00?l?
ooooo`04o`00ooooooooooooo`00oa7ooooo00Co003ooooooooooooo003o3_ooool01?l00?oooooo
ooooool00?lBooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o3Oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00kooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool0
0ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`0<ooooo`04o`00oooooooooooo
o`00o`kooooo00Co003ooooooooooooo003o4Oooool01Ol00?oooooooooooooooooo003o00kooooo
00Co003ooooooooooooo003o4Oooool01?l00?ooooooooooool00?l?ooooo`04o`00oooooooooooo
o`00oa7ooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?lBooooo`04o`00
ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o3Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Eoooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`0@oooo
o`007?ooool2o`0000gooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?lA
ooooo`05o`00ooooooooooooooooool00?l03_ooool01?l00?ooooooooooool00?lAooooo`04o`00
ooooooooooooo`00o`oooooo00Co003ooooooooooooo003o4Oooool01?l00?ooooooooooool00?l>
ooooo`05o`00ooooooooooooooooool00?l04Oooool01?l00?ooooooooooool00?l>ooooo`04o`00
ooooooooooooo`00o`gooooo00?o0000ooooooooool09Oooool2o`0000oooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool02Oooool2o`0001;ooooo000Looooo`03o`000?oooooooooo00_ooooo00Go003ooooooooooooo
ooooo`00o`0>ooooo`04o`00ooooooooooooo`00oa7ooooo00Go003oooooooooooooooooo`00o`0>
ooooo`04o`00ooooooooooooo`00oa7ooooo00Go003oooooooooooooooooo`00o`0=ooooo`05o`00
ooooooooooooooooool00?l04Oooool01Ol00?oooooooooooooooooo003o00gooooo00Go003ooooo
ooooooooooooo`00o`0@ooooo`05o`00ooooooooooooooooool00?l03_ooool01?l00?oooooooooo
ool00?l=ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`0:ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo00_ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`05o`00ooooooooooooooooool00?l0
4?ooool01Ol00?oooooooooooooooooo003o00gooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l03Oooool01Ol00?oooooooooooooooooo
003o017ooooo00Go003oooooooooooooooooo`00o`0=ooooo`05o`00ooooooooooooooooool00?l0
4?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00_ooooo00Go003ooooooooooooo
ooooo`00o`0<ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000Dooooo`Go00000oooool00ol0003ooooo
ooooo`0;ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02oooool01Ol00?oooooo
oooooooooooo003o013ooooo00Go003oooooooooooooooooo`00o`0=ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool03_ooool01Ol00?oooooooooooooooooo003o00gooooo00Go003o
ooooooooooooooooo`00o`0Aooooo`05o`00ooooooooooooooooool00?l03Oooool01Ol00?oooooo
oooooooooooo003o013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`05
o`00ooooooooooooooooool00?l03?ooool00ol0003oooooooooo`0Looooo`Go00001?ooool00ol0
003oooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool04?ooool001Go
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool02oooool01Ol00?oooooooooooooooooo003o013ooooo00Go003o
ooooooooooooooooo`00o`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_oo
ool01Ol00?oooooooooooooooooo003o00gooooo00Go003oooooooooooooooooo`00o`0Aooooo`05
o`00ooooooooooooooooool00?l03Oooool01Ol00?oooooooooooooooooo003o013ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`05o`00ooooooooooooooooool00?l03?oo
ool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
3_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000>ooooo`Go00000ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00oooooo00Go003ooooooooooooooooo
o`00o`0<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00_ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03
o`000?oooooooooo01Kooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000Gooooo`03o`00
0?oooooooooo00;ooooo0ol0000;ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l03?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02Oooool2o`00027o
oooo00?o0000ooooooooool00oooool2o`0000oooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`0Fooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02Oooool2o`0001;o
oooo000Dooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0;ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`0Looooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00[ooooo00?o0000ooooooooool04?ooool001Cooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:oooo
o`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`0@ooooo`005Oooool3o`00
00Cooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00[ooooo00?o0000ooooooooool07Oooool3o`0000Gooooo00?o0000ooooooooool03_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0:ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo00_o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool02Oooool3o`00o`;ooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`03o`00o`gooooo0ol00?l3ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool00ol00?l=ooooo`?o003o0_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?o
003o3Oooool3o`00o`;ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`03o`00o`go
oooo0ol00?l2ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00ol00?l7ooooo`03
o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo00_ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
2Oooool3o`00o`;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03o`00o`gooooo
0ol00?l3ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00ol00?l=ooooo`?o003o
0_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?o003o3Oooool3o`00o`;ooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`03o`00o`gooooo0ol00?l2ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool00ol00?l7ooooo`03o`000?oooooooooo013ooooo
000Looooo`;o00003?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o
0000ooooooooool09Oooool2o`0000[ooooo0ol00?l2ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool00ol00?l=ooooo`?o003o0oooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo00?o003o3Oooool3o`00o`;ooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`03o`00o`gooooo0ol00?l2ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool00ol0
0?l=ooooo`?o003o0_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?o003o1_oo
ool2o`0001;ooooo000Looooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool0
1Ol00?oooooooooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00oo
oooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l03oooool0
1Ol00?oooooooooooooooooo003o013ooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00
ooooooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o00Sooooo00?o0000oooo
ooooool04?ooool001cooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`05
o`00ooooooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o00oooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l03ooo
ool01Ol00?oooooooooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`05
o`00ooooooooooooooooool00?l04?ooool01Ol00?oooooooooooooooooo003o00oooooo00Go003o
ooooooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0003ooooo
ooooo`0@ooooo`007?ooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool02Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo00Go
003oooooooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l03oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`0?oooo
o`05o`00ooooooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o00oooooo00Go
003oooooooooooooooooo`00o`0@ooooo`05o`00ooooooooooooooooool00?l03oooool01Ol00?oo
oooooooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`000?oooooo
oooo013ooooo000Looooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`09ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool01Ol0
0?oooooooooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00oooooo
00Go003oooooooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l03oooool01Ol0
0?oooooooooooooooooo003o013ooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00oooo
ooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o00Sooooo00?o0000oooooooo
ool04?ooool001cooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`05o`00
ooooooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o00oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l03oooool0
1Ol00?oooooooooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00
ooooooooooooooooool00?l04?ooool01Ol00?oooooooooooooooooo003o00oooooo00Go003ooooo
ooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0003ooooooooo
o`0@ooooo`007?ooool2o`0000_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09
ooooo`03o`000?oooooooooo02Gooooo0_l0000;ooooo`05o`00ooooooooooooooooool00?l03ooo
ool01Ol00?oooooooooooooooooo003o00oooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0=ooooo`05o`00ooooooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o
00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l04?oo
ool01Ol00?oooooooooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`05
o`00ooooooooooooooooool00?l01oooool2o`0001;ooooo000Looooo`03o`000?oooooooooo00[o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool02_ooool01Ol00?oooooooooooooooooo003o00oooooo00Go003ooooo
ooooooooooooo`00o`0?ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool0
1Ol00?oooooooooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00
ooooooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o013ooooo00Go003ooooo
ooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l03oooool01Ol00?oooooooooo
oooooooo003o00Sooooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool02Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l03oooool01Ol00?oooooo
oooooooooooo003o00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0=ooooo`05
o`00ooooooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o00oooooo00Go003o
ooooooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l04?ooool01Ol00?oooooo
oooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00oooooooooooo
ooooool00?l02?ooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`09oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00[ooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00oooooooo
ooooooooool00?l03oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00gooooo00Go
003oooooooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l03oooool01Ol00?oo
oooooooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0@ooooo`05o`00oooooooo
ooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o00oooooo00Go003ooooooooooooo
ooooo`00o`08ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo00Wooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool02_ooool01Ol00?oooooooooooooooooo003o00oooooo00Go003ooooooooo
ooooooooo`00o`0?ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool01Ol0
0?oooooooooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00oooo
ooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o013ooooo00Go003ooooooooo
ooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l03oooool01Ol00?oooooooooooooo
oooo003o00Sooooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool02Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l03oooool01Ol00?oooooooooo
oooooooo003o00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0=ooooo`05o`00
ooooooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o00oooooo00Go003ooooo
ooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l04?ooool01Ol00?oooooooooo
oooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00oooooooooooooooo
ool00?l02?ooool00ol0003oooooooooo`0@ooooo`007?ooool2o`0000[ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02Gooooo0_l0000;ooooo`05
o`00ooooooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o00oooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l03ooo
ool01Ol00?oooooooooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`05
o`00ooooooooooooooooool00?l04?ooool01Ol00?oooooooooooooooooo003o00oooooo00Go003o
ooooooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l01oooool2o`0001;ooooo
000Looooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`08ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool01Ol00?oooooooooo
oooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00oooooo00Go003ooooo
ooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l03oooool01Ol00?oooooooooo
oooooooo003o013ooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00oooooooooooooooo
ool00?l03oooool01Ol00?oooooooooooooooooo003o00Sooooo00?o0000ooooooooool04?ooool0
01cooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`05o`00oooooooooooo
ooooool00?l03oooool01Ol00?oooooooooooooooooo003o00oooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l03oooool01Ol00?oooooo
oooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00oooooooooooo
ooooool00?l04?ooool01Ol00?oooooooooooooooooo003o00oooooo00Go003ooooooooooooooooo
o`00o`0?ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0003oooooooooo`0@ooooo`00
7?ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
2?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo00Go003ooooooooooooo
ooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l03oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00oooooooo
ooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o00oooooo00Go003ooooooooooooo
ooooo`00o`0@ooooo`05o`00ooooooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo
003o00oooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`000?oooooooooo013ooooo000F
ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`;o00001Oooool00ol0003oooooooooo`0:
ooooo`05o`00ooooooooooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o00oooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool0
0?l03oooool01Ol00?oooooooooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?
ooooo`05o`00ooooooooooooooooool00?l04?ooool01Ol00?oooooooooooooooooo003o00oooooo
00Go003oooooooooooooooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0
003oooooooooo`0@ooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
01gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0:ooooo`05o`00oooooooo
ooooooooool00?l03oooool01Ol00?oooooooooooooooooo003o00oooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l03oooool01Ol00?oo
oooooooooooooooo003o00oooooo00Go003oooooooooooooooooo`00o`0?ooooo`05o`00oooooooo
ooooooooool00?l04?ooool01Ol00?oooooooooooooooooo003o00oooooo00Go003ooooooooooooo
ooooo`00o`0?ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol0003oooooooooo`0@oooo
o`005Oooool01?l0003oooooooooool00003ooooo`co000000?o003oo`000?l000001_l000000ol0
0?oo0000o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000002_l000000ol0
0?oo0000o`000006o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001Ol000000ol0
0?oo0000o`00000;o`000003o`00ool0003o000000Go000000?o003oo`000?l000001ol000000ol0
0?oo0000o`000005o`000003o`00ool0003o000000_o000000?o003oo`000?l000001_l000000ol0
0?oo0000o`000006o`000003o`00ool0003o000000Go000000?o003oo`000?l000002ol000000ol0
0?oo0000o`000005o`000003o`00ool0003o000000Ko000000?o003oo`000?l000001_l000000ol0
0?oo0000o`000009o`0001oooooo00Co0000oooooooooooo00001?ooool5o`000005o`00ool0003o
0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o
0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o
003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000003o`00ool0003o000000;o000000Go
003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo
0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o
0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o
0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o
003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l0
1?l000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`00
0005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go
003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo
0000o`000?l0003o003o00?o000000?o003oo`000?l000000ol0000Booooo`005Oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`08ooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`02ooooo`05o`00ooooooooooooooooool00?l02oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool02Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool02Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool02Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool02Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l02oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool02Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Eooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Sooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`0;ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`09ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`09
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`09ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`09ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`0;ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`09
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00;ooooo00?o0000ooooooooool04?ooool001Gooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?oo
ool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00_ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Wooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Wooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00Wooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Wooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
0_ooool00ol0003oooooooooo`0@ooooo`005_ooool2o`0000Cooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool07_oo
ool2o`0000Gooooo00?o0000ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00_ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Wooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Wooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00_ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0@ooooo`007?ooool0
0ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00Go003oooooooooooooooooo`00
o`0;ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`09ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0:ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`09ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`09ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`09ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0;ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`09ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool04?ooool0
01cooooo0_l00009ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol0
003oooooooooo`0Uooooo`;o00000oooool01Ol00?oooooooooooooooooo003o00_ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Wooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Wooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00Wooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00Wooooo00Co003ooooooooooooooooo0_l0000Booooo`007?ooool00ol0003oooooooooo`08oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0:ooooo`?o003o0_ooool0
0ol00?ooooooooooo`03o`00o`[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00Wooooo0ol00?l2ooooo`03o`00oooooooooooo00?o003o2_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool02?ooool3o`00o`;ooooo00?o003oooooooooool0
0ol00?l:ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`08ooooo`?o
003o0oooool00ol00?ooooooooooo`03o`00o`[ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00Sooooo0ol00?l2ooooo`03o`00oooooooooooo00?o003o2_ooool00ol0
0?ooooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo00So
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00[ooooo0ol00?l2oooo
o`03o`00oooooooooooo00?o003o2_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool02Oooool3o`00o`;ooooo00?o003oooooooooool00ol00?l:ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`08ooooo`?o003o0_ooool00ol00?oooooooooo
o`03o`00o`[ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Sooooo
0ol00?l3ooooo`03o`00oooooooooooo00?o003o2_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool02?ooool3o`00o`;ooooo00?o003oooooooooool00ol00?l:ooooo`03
o`00oooooooooooo00;ooooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool0
2?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02ooooo`05o`00ooooooooooooooooool00?l02_ooool3o`00o`;o
oooo00?o003oooooooooool00ol00?l:ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`09ooooo`?o003o0_ooool00ol00?ooooooooooo`03o`00o`[ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Sooooo0ol00?l2ooooo`03o`00oooooooo
oooo00?o003o2_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool02?oo
ool3o`00o`?ooooo00?o003oooooooooool00ol00?l:ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`08ooooo`?o003o0_ooool00ol00?ooooooooooo`03o`00o`[ooooo
00?o003oooooooooool00_ooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003ooooooooo
o`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0?ooooo`03o`00
oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`02ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo00Sooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00oooooo00?o003oooooooooool03Ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o0000
ooooooooool04?ooool001cooooo0_l00009ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool01oooool00ol0003oooooooooo`0Uooooo`;o00000oooool01Ol00?oooooooooooooooooo
003o00oooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=oooo
o`04o`00ooooooooooooooooo`;o00004_ooool001cooooo00?o0000ooooooooool02?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`02ooooo`05o`00ooooooooooooooooool00?l03oooool00ol00?ooooooooooo`0=
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol0
003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`0?ooooo`03o`00oooooooooooo00gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo013o
oooo000Looooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`07ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00oooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0=ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03Ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool04?ooool001cooooo00?o
0000ooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
3oooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0=ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool00_ooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`08
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo00Go003oooooooooooooooooo`00o`0?ooooo`03o`00oooo
oooooooo00gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`02
ooooo`03o`000?oooooooooo013ooooo000Looooo`;o00002Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00Oooooo00?o0000ooooooooool09Oooool2o`0000?ooooo00Go003ooooo
ooooooooooooo`00o`0?ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00go
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool03Oooool01?l00?ooooooooooooooool2o`0001;ooooo000Looooo`03o`000?oooooooooo
00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00oooooo00?o003o
ooooooooool03Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00;ooooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool02?ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02ooooo`05o`00ooooooooooooooooool00?l03oooool00ol00?ooooooooooo`0=oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo00gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol0003o
ooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`0?ooooo`03o`00oooooooooooo00gooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo013ooooo
000Dooooo`Go00000oooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool01oooool00ol0003oooooooooo`0Looooo`Go00001?ooool00ol0003ooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l03oooool00ol00?ooooooooooo`0=ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00go
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool03Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol0003ooooooooo
o`0@ooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo01gooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`05o`00ooooooooooooooooool0
0?l03oooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0=ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool00_ooool00ol0003oooooooooo`0@ooooo`005_ooool00ol0003ooooooooo
o`03ooooo`?o00002?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo0_l0
000Pooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`05o`00ooooooooooooooooool00?l0
3oooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0=ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00Co
003ooooooooooooooooo0_l0000Booooo`005oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Sooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`05o`00oooo
ooooooooooooool00?l03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00cooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`05o`00ooooooooooooooooool00?l03oooool00ol0
0?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool00_ooool00ol0003oooooooooo`0@ooooo`005?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wo
oooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l03?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool07?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00oooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0=ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool04?ooool001Cooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool02_oo
ool01Ol00?oooooooooooooooooo003o00_ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`09ooooo`05o`00ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo01cooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`0?ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Eooooo`?o00001?ooool0
0ol0003oooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00Go003oooooooooooooooooo`00
o`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02Oooool01Ol00?oooooooooo
oooooooo003o00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`05o`00
ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[o
oooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool01_ooool00ol0003oooooooooo`0Mooooo`?o00001Oooool00ol0003oooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l03oooool00ol00?ooooooooooo`0=ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
3Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0@oooo
o`007?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooo
oooo003o3Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Wooooo00Go003ooooo
ooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool0
1Ol00?oooooooooooooooooo003o00cooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0:ooooo`05o`00ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00[ooooo00Co003ooooooooooooo003o3Oooool00ol00?ooooooooooo`06ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00oooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool03Oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00;ooooo00?o0000ooooooooool04?ooool001cooooo0_l00008ooooo`03o`00
oooooooooooo00_ooooo00Co003ooooooooooooo003o3Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o00cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l03?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo00Co003ooooooooooooo003o
3Oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo02Gooooo0_l00003ooooo`05o`00
ooooooooooooooooool00?l03oooool00ol00?ooooooooooo`0=ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00gooooo00Co003ooooooooooooooooo0_l0000Booooo`007?ooool00ol0003ooooo
ooooo`07ooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooooooo003o3Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`0<oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool01?l00?ooooooooooool00?l=
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool01?l00?ooooooooooool0
0?l=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02_ooool01?l00?oooooooooo
ool00?l=ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`02ooooo`05o`00ooooooooooooooooool00?l03oooool00ol00?ooooooooooo`0=ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool03Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol0003ooooo
ooooo`0@ooooo`007?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00Co
003ooooooooooooo003o3Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooool00?l03Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[ooooo
00Co003ooooooooooooo003o3Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00[o
oooo00Co003ooooooooooooo003o3Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00[ooooo00Co003ooooooooooooo003o3Oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00oooooo00?o
003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00;ooooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool01oooool00ol0
0?ooooooooooo`0;ooooo`04o`00ooooooooooooo`00o`gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooo003o00gooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooo003o00gooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0:ooooo`04o`00ooooooooooooo`00o`gooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0:ooooo`04o`00ooooooooooooo`00o`gooooo00?o003oooooooooool0
1_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00Go003ooooooooooooo
ooooo`00o`0?ooooo`03o`00oooooooooooo00gooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0=ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oo
oooooooo00Oooooo00?o003oooooooooool02oooool01?l00?ooooooooooool00?l=ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool02oooool00ol00?ooooooo`00o`0=ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooo`00o`0=ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooo`00o`0=ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooo`00o`0=ooooo`03o`00
oooooooooooo00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l03oooool00ol00?ooooooooooo`0=ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`0=ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0@ooooo`007?oo
ool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00cooooo0_l00?l>ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool02oooool00ol00?ooooooo`00o`0=ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooo`00o`0=ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooo`00o`0=ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02oooool2o`00o`kooooo00?o003oooooooooool01_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`0>ooooo`?o003o3_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool03Oooool3o`00o`kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00cooooo0ol00?l>ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0=
ooooo`?o003o3_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool03?oo
ool3o`00o`kooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0@ooooo`007?ooool2
o`0000Sooooo00?o003oooooooooool03?ooool2o`00o`kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0;ooooo`?o003o3Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00cooooo0ol00?l>ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02oooool2
o`00o`kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`;o003o3_ooool0
0ol00?ooooooooooo`06ooooo`03o`000?oooooooooo02Gooooo0_l00003ooooo`05o`00oooooooo
ooooooooool00?l03_ooool3o`00o`kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00gooooo0ol00?l>ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0<ooooo`?o003o3_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool03Oooool3o`00o`kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00cooooo0ol00?l>ooooo`04o`00ooooooooooooooooo`;o00004_ooool001cooooo00?o0000
ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00kooooo0ol00?l>ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0=ooooo`?o003o3_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool03?ooool3o`00o`kooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00gooooo0ol00?l>ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0<ooooo`?o003o3_ooool00ol00?ooooooooooo`02
ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo00Oooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool01_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`0Oooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Nooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Mooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Nooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00;ooooo00?o0000oooo
ooooool04?ooool001cooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Kooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`06ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool01Ol00?oooooooooooooooooo003o
01oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01kooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01gooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0@ooooo`00
7?ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`02ooooo`05o`00ooooooooooooooooool00?l07oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool07_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool07Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool07_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oo
oooooooo00Oooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`0Oooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Mooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0N
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo00;ooooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool01oooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`06ooooo`03o`000?oooooooooo02Gooooo0_l00003ooooo`05o`00oooooooo
ooooooooool00?l07oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
7_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool07_ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool07Oooool01?l00?ooooooooooooooool2o`0001;ooooo000L
ooooo`;o00002?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o01oooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01kooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`07oooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l07oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool07_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
7Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool07_ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`02oooo
o`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo00Oooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003ooooooooo
ool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`0Oooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0N
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Mooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Nooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00;ooooo00?o0000oooooooo
ool04?ooool001Kooooo0ol00003ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
1Oooool00ol0003oooooooooo`0Nooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`03o`00
oooooooooooo00?o003o7Oooool3o`00o`;ooooo00?o003oooooooooool00ol00?lNooooo`?o003o
0_ooool00ol00?ooooooooooo`03o`00oagooooo0ol00?l2ooooo`03o`00oooooooooooo00?o003o
7_ooool3o`00o`;ooooo00?o003oooooooooool00ol00?lMooooo`?o003o0oooool00ol0003ooooo
ooooo`0@ooooo`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool01Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol00?ooooooooooo`03o`00oagooooo0ol00?l2ooooo`03o`00oooo
oooooooo00?o003o7_ooool3o`00o`;ooooo00?o003oooooooooool00ol00?lMooooo`?o003o0_oo
ool00ol00?ooooooooooo`03o`00oakooooo0ol00?l2ooooo`03o`00oooooooooooo00?o003o7Ooo
ool3o`00o`?ooooo00?o0000ooooooooool04?ooool001Cooooo1Ol00003ooooo`03o`000?oooooo
oooo00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo01gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo01gooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`0Looooo`Go00001?ooool0
0ol0003oooooooooo`02ooooo`03o`00oooooooooooo00?o003o7Oooool3o`00o`;ooooo00?o003o
ooooooooool00ol00?lNooooo`?o003o0_ooool00ol00?ooooooooooo`03o`00oagooooo0ol00?l2
ooooo`03o`00oooooooooooo00?o003o7_ooool3o`00o`;ooooo00?o003oooooooooool00ol00?lM
ooooo`?o003o0oooool00ol0003oooooooooo`0@ooooo`005?ooool01?l0003oooooooooool00004
ooooo`?o00001oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`04ooooo`;o00007_ooool01?l0003oooooooooool0
0005ooooo`;o00000oooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o
003oooooooooool09Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo02Gooooo0_l0
000Booooo`005Oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?o003o
ooooooooool07_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo02Kooooo00?o0000
ooooooooool04?ooool001Kooooo0_l00004ooooo`03o`000?oooooooooo00Kooooo00?o003ooooo
ooooool07_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool01Oooool00ol0003oooooooooo`0Nooooo`;o00001Oooool00ol0003oooooooooo`02oooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0Uoooo
o`03o`00oooooooooooo02Kooooo00?o003oooooooooool09_ooool00ol0003oooooooooo`0@oooo
o`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o003ooooooooo
ool07_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01gooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool07Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01gooooo00?o003ooooooooo
ool01Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003ooooooooo
ool09Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo02Kooooo00?o0000oooooooo
ool04?ooool001cooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0Nooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo01oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Mooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`05ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00
oooooooooooo02Kooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Vooooo`03o`00
oooooooooooo02Kooooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool01_oo
ool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool07Ooo
ool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
ool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool09Ooo
ool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool04?oo
ool001cooooo0_l00007ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool09Oooool2
o`0000?ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooo
oooo02Gooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0Uooooo`;o00004_ooool0
01cooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
01oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo
02Kooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo
02Kooooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool01_ooool00ol00?oo
ooooooooo`0Nooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0Mooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07_ooool00ol00?oo
ooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol00?oo
ooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`0Vooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool04?ooool001cooooo
00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool07_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo
00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo02Kooooo
00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool01Oooool00ol00?oooooooooo
o`0Oooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool07_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0Oooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07_ooool00ol00?oooooooooo
o`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol00?oooooooooo
o`0Uooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool09Oooool00ol00?oooooooooo
o`0Vooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool04?ooool001cooooo00?o0000
ooooooooool01Oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool07_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool07_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003o
ooooooooool09Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo02Kooooo00?o0000
ooooooooool04?ooool001cooooo0_l00006ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool07oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool09Oooool2o`0000?ooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Voooo
o`03o`00oooooooooooo02Gooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0Uoooo
o`;o00004_ooool001cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0Pooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo01oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03
o`00oooooooooooo02Kooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Vooooo`03
o`00oooooooooooo02Kooooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool0
1Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
7_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
7oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0
9Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool0
4?ooool001cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo01oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooo
oooooooo02Kooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooo
oooooooo02Kooooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool01Oooool0
0ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool0
0ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool09Oooool0
0ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool04?ooool0
01cooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
01oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo
02Kooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo
02Kooooo00?o0000ooooooooool04?ooool001cooooo0_l00006ooooo`03o`00oooooooooooo023o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool07oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00Co
oooo00?o0000ooooooooool09Oooool2o`0000?ooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`0Vooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09_ooool00ol00?oo
ooooooooo`0Uooooo`;o00004_ooool001cooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`0Pooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool07oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0Oooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool07oooool00ol00?oooooo
ooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool09Oooool00ol00?oooooo
ooooo`0Vooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool04?ooool001cooooo00?o
0000ooooooooool01?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool08?ooool01Ol00?oooooooooooooooooo003o02;ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
8?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0
9Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool0
4?ooool001Gooooo0ol00004ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool08Ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo023ooooo00Go003ooooooooooooooooo
o`00o`0Rooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool08?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool01?ooool00ol0003ooooo
ooooo`0Mooooo`?o00001Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Gooooo
00?o003oooooooooool09_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo
00?o003oooooooooool09_ooool00ol0003oooooooooo`0@ooooo`005?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Qooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool08?ooool01Ol00?oooooooooooooooooo003o02?o
oooo00Go003oooooooooooooooooo`00o`0Rooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool08?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo01cooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool09Oooool0
0ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09_ooool0
0ol00?ooooooooooo`0Vooooo`03o`000?oooooooooo013ooooo000Dooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo027ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Pooooo`05o`00ooooooooooooooooool00?l08ooo
ool01Ol00?oooooooooooooooooo003o02;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Pooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool07?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Uooooo`03
o`00oooooooooooo02Kooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Vooooo`03
o`00oooooooooooo02Kooooo00?o0000ooooooooool04?ooool001Cooooo1?l00004ooooo`?o0000
1?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
8?ooool01Ol00?oooooooooooooooooo003o02?ooooo00Go003oooooooooooooooooo`00o`0Roooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`03oooo
o`;o00007_ooool4o`0000Gooooo0_l00003ooooo`03o`00oooooooooooo02Gooooo00?o003ooooo
ooooool09_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003ooooo
ooooool09Oooool2o`0001;ooooo000Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool08?ooool01Ol00?oooooooooooooooooo003o02?ooooo00Go003oooooooooooooooooo`00o`0S
ooooo`05o`00ooooooooooooooooool00?l08_ooool00ol00?ooooooooooo`04ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00oooo
oooooooo02Gooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooo
oooooooo02Kooooo00?o003oooooooooool09_ooool00ol0003oooooooooo`0@ooooo`005Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool08Oooool0
1Ol00?oooooooooooooooooo003o02?ooooo00Go003oooooooooooooooooo`00o`0Sooooo`05o`00
ooooooooooooooooool00?l08oooool01Ol00?oooooooooooooooooo003o02;ooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003ooooo
ooooool09Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo02Kooooo00?o0000oooo
ooooool04?ooool001Kooooo0_l00004ooooo`03o`000?oooooooooo00Cooooo00?o003ooooooooo
ool08Oooool01Ol00?oooooooooooooooooo003o02?ooooo00Go003oooooooooooooooooo`00o`0S
ooooo`05o`00ooooooooooooooooool00?l08oooool01Ol00?oooooooooooooooooo003o02?ooooo
00?o003oooooooooool00oooool00ol0003oooooooooo`0Nooooo`;o00001Oooool00ol0003ooooo
ooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09_ooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool09_ooool00ol0003ooooo
ooooo`0@ooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo027ooooo00Go
003oooooooooooooooooo`00o`0Sooooo`05o`00ooooooooooooooooool00?l08oooool01Ol00?oo
oooooooooooooooo003o02?ooooo00Co003ooooooooooooo003o9?ooool00ol00?ooooooooooo`03
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0U
ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0V
ooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool04?ooool001cooooo00?o0000oooo
ooooool01?ooool00ol00?ooooooooooo`0Rooooo`04o`00ooooooooooooo`00ob?ooooo00Go003o
ooooooooooooooooo`00o`0Sooooo`05o`00ooooooooooooooooool00?l08oooool01?l00?oooooo
ooooool00?lTooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09_ooool00ol00?oo
ooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool09_ooool00ol0003o
ooooooooo`0@ooooo`007?ooool2o`0000Gooooo00?o003oooooooooool08_ooool01?l00?oooooo
ooooool00?lSooooo`05o`00ooooooooooooooooool00?l08oooool01Ol00?oooooooooooooooooo
003o02?ooooo00Co003ooooooooooooo003o9?ooool00ol00?ooooooooooo`03ooooo`03o`000?oo
oooooooo02Gooooo0_l00003ooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09_oo
ool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool09Ooo
ool2o`0001;ooooo000Looooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool08_ooool0
1?l00?ooooooooooool00?lSooooo`05o`00ooooooooooooooooool00?l09?ooool00ol00?oooooo
o`00o`0Tooooo`04o`00ooooooooooooo`00obCooooo00?o003oooooooooool00oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`0Vooooo`03o`00oooooooooooo02Gooooo00?o003oooooooooool09_ooool00ol00?oo
ooooooooo`0Vooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo00Cooooo
00?o003oooooooooool08_ooool00ol00?ooooooo`00o`0Uooooo`03o`00oooooooo003o02Gooooo
00?o003oooooool00?l09?ooool01?l00?ooooooooooool00?lTooooo`03o`00oooooooooooo00?o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02Go
oooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`0Uooooo`03o`00oooooooooooo02Ko
oooo00?o003oooooooooool09_ooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003ooooo
ooooo`03ooooo`03o`00oooooooooooo02?ooooo00?o003oooooool00?l09Oooool00ol00?oooooo
o`00o`0Uooooo`03o`00oooooooo003o02Cooooo00Co003ooooooooooooo003o9?ooool00ol00?oo
ooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol00?oo
ooooooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool09Oooool00ol00?oo
ooooooooo`0Vooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool04?ooool001cooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooo003o02Gooooo
00?o003oooooool00?l09Oooool00ol00?ooooooo`00o`0Uooooo`;o003o9_ooool00ol00?oooooo
ooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol00?oooooo
ooooo`0Uooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool09Oooool00ol00?oooooo
ooooo`0Vooooo`03o`00oooooooooooo02Kooooo00?o0000ooooooooool04?ooool001cooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`0Tooooo`;o003o9Oooool3o`00obGooooo0_l0
0?lVooooo`;o003o9_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooooooo0ol00?lUooooo`?o003o9_ooool3o`00obGooooo0ol00?lVooooo`?o003o
9oooool00ol0003oooooooooo`0@ooooo`007?ooool2o`0000?ooooo0_l00?lVooooo`;o003o9_oo
ool00ol00?ooooooooooo`0Tooooo`;o003o9_ooool2o`00obKooooo00?o003oooooooooool00_oo
ool00ol0003oooooooooo`0Uooooo`;o00000_ooool3o`00obGooooo0ol00?lVooooo`?o003o9Ooo
ool3o`00obKooooo0ol00?lVooooo`;o00004_ooool001cooooo00?o0000ooooooooool0c_ooool0
0ol0003oooooooooo`0Uooooo`04o`000?ooooooooooooooo`?o003o9Oooool3o`00obKooooo0ol0
0?lUooooo`?o003o9_ooool3o`00obOooooo00?o0000ooooooooool04?ooool001cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l0000B
ooooo`007?oooooBo`0002OooooodOl0000Booooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-27.7031, \
-0.511082, 0.203806, 0.0246538}, {{262.875, 490.688}, {303, 162.25}} -> \
{-78.7516, -0.510459, 0.203743, 0.0246463}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-0.852551, -17.6965, 0.0251258, 0.082325}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-69.8218, -17.7744, 0.247216, 0.0826536}}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 578}},
ScreenStyleEnvironment->"Working",
WindowSize->{841, 718},
WindowMargins->{{22, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 64, 0, 62, "Title"],

Cell[CellGroupData[{
Cell[1794, 54, 99, 4, 59, "Section"],

Cell[CellGroupData[{
Cell[1918, 62, 60, 0, 49, "Subsection"],
Cell[1981, 64, 127, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2145, 71, 37, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2207, 75, 59, 0, 43, "Subsubsection"],
Cell[2269, 77, 118, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2424, 84, 67, 0, 35, "Subsubsection"],
Cell[2494, 86, 820, 15, 159, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3363, 107, 45, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3433, 111, 62, 0, 43, "Subsubsection"],
Cell[3498, 113, 330, 6, 111, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3865, 124, 67, 0, 35, "Subsubsection"],
Cell[3935, 126, 227, 4, 46, "Text"],
Cell[4165, 132, 551, 10, 159, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4753, 147, 48, 0, 35, "Subsubsection"],
Cell[4804, 149, 367, 8, 64, "Text"],
Cell[5174, 159, 302, 4, 111, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5513, 168, 83, 1, 35, "Subsubsection"],
Cell[5599, 171, 683, 12, 191, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6319, 188, 83, 1, 35, "Subsubsection"],
Cell[6405, 191, 684, 12, 191, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7138, 209, 39, 0, 33, "Subsection"],
Cell[7180, 211, 333, 7, 46, "Text"],
Cell[7516, 220, 541, 10, 143, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8094, 235, 41, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[8160, 239, 45, 0, 43, "Subsubsection"],
Cell[8208, 241, 67, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8312, 247, 43, 0, 43, "Subsubsection"],
Cell[8358, 249, 58, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8453, 255, 104, 4, 43, "Subsubsection"],
Cell[8560, 261, 74, 1, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8683, 268, 109, 4, 33, "Subsection"],
Cell[8795, 274, 136, 3, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8968, 282, 50, 0, 33, "Subsection"],
Cell[9021, 284, 181, 3, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9239, 292, 48, 0, 33, "Subsection"],
Cell[9290, 294, 141, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9468, 301, 40, 0, 33, "Subsection"],
Cell[9511, 303, 396, 7, 127, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9956, 316, 74, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[10055, 320, 53, 0, 49, "Subsection"],
Cell[10111, 322, 111, 2, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10259, 329, 63, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[10347, 333, 168, 3, 90, "Input"],
Cell[10518, 338, 265, 4, 66, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[10820, 347, 172, 3, 63, "Input"],
Cell[10995, 352, 116, 2, 63, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11160, 360, 52, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[11237, 364, 30, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[11292, 368, 1291, 24, 191, "Input"],
Cell[12586, 394, 70561, 2390, 320, 21951, 1787, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[83196, 2790, 30, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[83251, 2794, 1291, 24, 191, "Input"],
Cell[84545, 2820, 122616, 3322, 320, 27525, 2145, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[207210, 6148, 30, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[207265, 6152, 1291, 24, 191, "Input"],
Cell[208559, 6178, 147436, 4038, 320, 34163, 2636, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[356044, 10222, 30, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[356099, 10226, 1291, 24, 191, "Input"],
Cell[357393, 10252, 165984, 4398, 320, 37775, 2812, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[523426, 14656, 30, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[523481, 14660, 1315, 24, 191, "Input"],
Cell[524799, 14686, 201130, 6087, 320, 62076, 4367, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[725978, 20779, 43, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[726046, 20783, 166, 3, 63, "Input"],
Cell[726215, 20788, 282734, 8169, 809, 69850, 5537, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1009010, 28964, 76, 0, 33, "Subsection"],
Cell[1009089, 28966, 219791, 8508, 483, 102576, 7057, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1228929, 37480, 93, 3, 59, "Section"],

Cell[CellGroupData[{
Cell[1229047, 37487, 76, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1229148, 37491, 336, 6, 95, "Input"],
Cell[1229487, 37499, 86819, 1570, 176, 7291, 585, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[1316343, 39074, 29, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1316397, 39078, 138, 2, 63, "Input"],
Cell[1316538, 39082, 4063, 78, 308, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1320638, 39165, 156, 3, 63, "Input"],
Cell[1320797, 39170, 1332, 18, 100, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1322178, 39194, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1322241, 39198, 592, 11, 111, "Input"],
Cell[1322836, 39211, 152503, 4774, 157, 51555, 3524, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1475388, 43991, 61, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1475474, 43995, 686, 13, 111, "Input"],
Cell[1476163, 44010, 148687, 4593, 157, 49731, 3368, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1624899, 48609, 99, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1625023, 48616, 292, 5, 63, "Input"],
Cell[1625318, 48623, 179897, 8205, 176, 114002, 7388, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1805276, 56835, 78, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1805379, 56839, 44, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1805448, 56843, 262, 4, 63, "Input"],
Cell[1805713, 56849, 67878, 1422, 176, 9299, 695, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[1873628, 58276, 234, 5, 63, "Input"],
Cell[1873865, 58283, 194, 3, 69, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[1874096, 58291, 526, 9, 111, "Input"],
Cell[1874625, 58302, 146510, 4588, 157, 50013, 3393, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2021184, 62896, 45, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2021254, 62900, 181, 3, 63, "Input"],
Cell[2021438, 62905, 84106, 1603, 186, 9269, 675, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[2105581, 64513, 176, 4, 63, "Input"],
Cell[2105760, 64519, 645, 9, 126, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2106442, 64533, 526, 9, 111, "Input"],
Cell[2106971, 64544, 150942, 6025, 157, 76794, 5106, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2257974, 70576, 95, 3, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2258094, 70583, 41, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2258160, 70587, 347, 6, 95, "Input"],
Cell[2258510, 70595, 165318, 3014, 176, 14761, 1152, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2423877, 73615, 29, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2423931, 73619, 138, 2, 63, "Input"],
Cell[2424072, 73623, 16463, 318, 1183, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2440572, 73946, 156, 3, 63, "Input"],
Cell[2440731, 73951, 4513, 58, 172, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2445293, 74015, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2445356, 74019, 592, 11, 111, "Input"],
Cell[2445951, 74032, 155525, 8098, 157, 115411, 7600, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2601525, 82136, 61, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2601611, 82140, 686, 13, 111, "Input"],
Cell[2602300, 82155, 151628, 7917, 157, 113587, 7444, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2753989, 90079, 84, 1, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2754098, 90084, 47, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2754170, 90088, 283, 4, 79, "Input"],
Cell[2754456, 90094, 86237, 1711, 176, 10741, 775, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2840742, 91811, 53, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2840820, 91815, 365, 6, 95, "Input"],
Cell[2841188, 91823, 78057, 1462, 176, 7277, 585, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2919294, 93291, 29, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2919348, 93295, 138, 2, 63, "Input"],
Cell[2919489, 93299, 5007, 91, 448, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[2924533, 93395, 156, 3, 63, "Input"],
Cell[2924692, 93400, 1215, 19, 103, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2925956, 93425, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2926019, 93429, 606, 12, 111, "Input"],
Cell[2926628, 93443, 157327, 4677, 157, 48784, 3334, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3084004, 98126, 61, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3084090, 98130, 701, 14, 111, "Input"],
Cell[3084794, 98146, 153551, 4497, 157, 46960, 3178, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3238394, 102649, 99, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3238518, 102656, 292, 5, 63, "Input"],
Cell[3238813, 102663, 200751, 8196, 176, 109034, 7060, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3439625, 110866, 179, 5, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3439829, 110875, 43, 0, 43, "Subsubsection"],
Cell[3439875, 110877, 92, 2, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3440004, 110884, 42, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3440071, 110888, 283, 4, 79, "Input"],
Cell[3440357, 110894, 86237, 1711, 176, 10741, 775, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3526643, 112611, 66, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3526734, 112615, 227, 5, 47, "Input"],
Cell[3526964, 112622, 150, 2, 47, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[3527151, 112629, 250, 5, 63, "Input"],
Cell[3527404, 112636, 41445, 1721, 186, 21908, 1475, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3568898, 114363, 61, 0, 43, "Subsubsection"],
Cell[3568962, 114365, 89, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[3569076, 114370, 295, 5, 63, "Input"],
Cell[3569374, 114377, 96997, 2755, 176, 28459, 1905, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3666444, 117140, 57, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[3666526, 117144, 40, 0, 49, "Subsection"],
Cell[3666569, 117146, 91, 2, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3666697, 117153, 44, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3666766, 117157, 250, 5, 63, "Input"],
Cell[3667019, 117164, 92103, 1975, 186, 14450, 1012, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3759171, 119145, 50, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3759246, 119149, 303, 6, 79, "Input"],
Cell[3759552, 119157, 1000, 30, 48, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[3760589, 119192, 261, 5, 79, "Input"],
Cell[3760853, 119199, 45094, 1885, 186, 23533, 1614, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3805996, 121090, 48, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3806069, 121094, 205, 4, 63, "Input"],
Cell[3806277, 121100, 229, 3, 82, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[3806543, 121108, 170, 3, 63, "Input"],
Cell[3806716, 121113, 85440, 2858, 186, 33355, 2210, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3892205, 123977, 54, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3892284, 123981, 374, 8, 79, "Input"],
Cell[3892661, 123991, 47009, 995, 186, 5949, 484, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3939719, 124992, 60, 0, 33, "Subsection"],
Cell[3939782, 124994, 89, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[3939896, 124999, 270, 5, 63, "Input"],
Cell[3940169, 125006, 58485, 1804, 186, 18699, 1308, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[3998691, 126815, 58, 1, 47, "Input"],
Cell[3998752, 126818, 81959, 3002, 186, 36463, 2436, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4080760, 129826, 58, 0, 33, "Subsection"],
Cell[4080821, 129828, 86, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[4080932, 129833, 326, 6, 63, "Input"],
Cell[4081261, 129841, 164575, 4458, 176, 44927, 2977, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4245885, 134305, 30, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[4245940, 134309, 137, 3, 47, "Input"],
Cell[4246080, 134314, 228808, 7379, 320, 80355, 5543, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4474949, 141700, 57, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[4475031, 141704, 40, 0, 49, "Subsection"],
Cell[4475074, 141706, 93, 2, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4475204, 141713, 44, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[4475273, 141717, 250, 5, 63, "Input"],
Cell[4475526, 141724, 92164, 1976, 186, 14450, 1012, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4567739, 143706, 50, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[4567814, 143710, 303, 6, 63, "Input"],
Cell[4568120, 143718, 1000, 30, 48, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[4569157, 143753, 261, 5, 63, "Input"],
Cell[4569421, 143760, 46629, 1935, 186, 23906, 1650, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4616099, 145701, 48, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[4616172, 145705, 205, 4, 63, "Input"],
Cell[4616380, 145711, 229, 3, 69, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[4616646, 145719, 170, 3, 63, "Input"],
Cell[4616819, 145724, 85440, 2858, 186, 33355, 2210, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4702308, 148588, 54, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[4702387, 148592, 374, 8, 79, "Input"],
Cell[4702764, 148602, 43817, 981, 186, 6240, 513, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4746630, 149589, 60, 0, 33, "Subsection"],
Cell[4746693, 149591, 89, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[4746807, 149596, 270, 5, 63, "Input"],
Cell[4747080, 149603, 63150, 2066, 186, 22457, 1559, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[4810267, 151674, 58, 1, 47, "Input"],
Cell[4810328, 151677, 85919, 3256, 186, 40212, 2687, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4896296, 154939, 58, 0, 33, "Subsection"],
Cell[4896357, 154941, 86, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[4896468, 154946, 326, 6, 63, "Input"],
Cell[4896797, 154954, 178190, 5100, 176, 53330, 3555, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5075036, 160060, 30, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[5075091, 160064, 137, 3, 47, "Input"],
Cell[5075231, 160069, 230276, 7658, 320, 84768, 5859, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5305568, 167734, 49, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[5305642, 167738, 40, 0, 49, "Subsection"],
Cell[5305685, 167740, 92, 2, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5305814, 167747, 44, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[5305883, 167751, 250, 5, 63, "Input"],
Cell[5306136, 167758, 92103, 1975, 186, 14450, 1012, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5398288, 169739, 50, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[5398363, 169743, 303, 6, 63, "Input"],
Cell[5398669, 169751, 1000, 30, 48, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[5399706, 169786, 257, 5, 63, "Input"],
Cell[5399966, 169793, 63212, 2870, 186, 38676, 2563, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5463227, 172669, 48, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[5463300, 172673, 205, 4, 63, "Input"],
Cell[5463508, 172679, 229, 3, 69, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[5463774, 172687, 177, 3, 63, "Input"],
Cell[5463954, 172692, 107313, 5390, 186, 77144, 5013, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5571316, 178088, 54, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[5571395, 178092, 374, 8, 79, "Input"],
Cell[5571772, 178102, 80695, 1495, 186, 7292, 584, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5652516, 179603, 60, 0, 33, "Subsection"],
Cell[5652579, 179605, 89, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[5652693, 179610, 267, 5, 63, "Input"],
Cell[5652963, 179617, 63176, 2296, 186, 27518, 1851, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[5716176, 181918, 58, 1, 47, "Input"],
Cell[5716237, 181921, 101930, 4501, 186, 61214, 3994, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5818216, 186428, 58, 0, 33, "Subsection"],
Cell[5818277, 186430, 86, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[5818388, 186435, 322, 6, 63, "Input"],
Cell[5818713, 186443, 163707, 5865, 176, 72932, 4741, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5982469, 192314, 30, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[5982524, 192318, 137, 3, 47, "Input"],
Cell[5982664, 192323, 283138, 10147, 320, 121592, 8150, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

